""" Cisco_IOS_XR_ipv4_bgp_oper 

This module contains a collection of YANG definitions
for Cisco IOS\-XR ipv4\-bgp package operational data.

This module contains definitions
for the following management objects\:
  bgp\: BGP operational data

Copyright (c) 2013\-2016 by Cisco Systems, Inc.
All rights reserved.

"""


import re
import collections

from enum import Enum

from ydk.types import Empty, YList, YLeafList, DELETE, Decimal64, FixedBitsDict

from ydk.errors import YPYError, YPYModelError



class BgpAfiEnum(Enum):
    """
    BgpAfiEnum

    BGP Address family

    .. data:: ipv4 = 0

    	IP v4 unicast

    .. data:: ipv4_multicast = 1

    	IP v4 multicast

    .. data:: ipv4_labeled = 2

    	IP v4 label

    .. data:: ipv4_tunnel = 3

    	IP v4 Tunnel

    .. data:: vp_nv4 = 4

    	IP v4 virtual private network

    .. data:: ipv6 = 5

    	IP v6 unicast

    .. data:: ipv6_multicast = 6

    	IP v6 multicast

    .. data:: ipv6_labeled = 7

    	IP v6 label

    .. data:: vp_nv6 = 8

    	IP v6 virtual private network

    .. data:: ipv4mdt = 9

    	IP v4 Multicast  Distribution Tree

    .. data:: l2vpn_vpls = 10

    	L2VPN VPLS

    .. data:: rt_constraint = 11

    	IP RT-Constraint

    .. data:: ipv4mvpn = 12

    	IP v4 mvpn

    .. data:: ipv6mvpn = 13

    	IP v6 mvpn

    .. data:: l2vpn_evpn = 14

    	L2VPN EVPN

    .. data:: ls_ls = 15

    	Link-state Link-state

    .. data:: vp_nv4_multicast = 16

    	IP v4 virtual private network for multicast

    .. data:: vp_nv6_multicast = 17

    	IP v6 virtual private network for multicast

    .. data:: ipv4_flowspec = 18

    	IP v4 flowspec

    .. data:: ipv6_flowspec = 19

    	IP v6 flowspec

    .. data:: vp_nv4_flowspec = 20

    	IP v4 vpn flowspec

    .. data:: vp_nv6_flowspec = 21

    	IP v6 vpn flowspec

    .. data:: l2vpn_mspw = 22

    	L2VPN Multi-segment pseudowire

    .. data:: ipv4sr_policy = 23

    	IP v4 SR Policy

    .. data:: ipv6sr_policy = 24

    	IP v6 SR Policy

    .. data:: no_address_family = 25

    	Address-family not applicable

    .. data:: all_address_families = 26

    	All address-families

    """

    ipv4 = 0

    ipv4_multicast = 1

    ipv4_labeled = 2

    ipv4_tunnel = 3

    vp_nv4 = 4

    ipv6 = 5

    ipv6_multicast = 6

    ipv6_labeled = 7

    vp_nv6 = 8

    ipv4mdt = 9

    l2vpn_vpls = 10

    rt_constraint = 11

    ipv4mvpn = 12

    ipv6mvpn = 13

    l2vpn_evpn = 14

    ls_ls = 15

    vp_nv4_multicast = 16

    vp_nv6_multicast = 17

    ipv4_flowspec = 18

    ipv6_flowspec = 19

    vp_nv4_flowspec = 20

    vp_nv6_flowspec = 21

    l2vpn_mspw = 22

    ipv4sr_policy = 23

    ipv6sr_policy = 24

    no_address_family = 25

    all_address_families = 26


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpAfiEnum']


class BgpBagUpdErrActionEnum(Enum):
    """
    BgpBagUpdErrActionEnum

    Bgp bag upd err action

    .. data:: bgp_bag_upd_err_action_none = 0

    	No Action

    .. data:: bgp_bag_upd_err_action_discard_msg = 1

    	Discard Message

    .. data:: bgp_bag_upd_err_action_reset = 2

    	Session Reset

    .. data:: bgp_bag_upd_err_action_wdr_or_reset = 3

    	Withdraw NLRI or Reset

    .. data:: bgp_bag_upd_err_action_wdr = 4

    	Withdraw NLRI

    .. data:: bgp_bag_upd_err_action_discard_attr = 5

    	Discard Attribute

    .. data:: bgp_bag_upd_err_action_local_repair = 6

    	Local Repair

    .. data:: bgp_bag_upd_err_action_max = 7

    	Maximum number of actions

    """

    bgp_bag_upd_err_action_none = 0

    bgp_bag_upd_err_action_discard_msg = 1

    bgp_bag_upd_err_action_reset = 2

    bgp_bag_upd_err_action_wdr_or_reset = 3

    bgp_bag_upd_err_action_wdr = 4

    bgp_bag_upd_err_action_discard_attr = 5

    bgp_bag_upd_err_action_local_repair = 6

    bgp_bag_upd_err_action_max = 7


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpBagUpdErrActionEnum']


class BgpBagUpdFilterActionEnum(Enum):
    """
    BgpBagUpdFilterActionEnum

    Bgp bag upd filter action

    .. data:: none = 0

    	No Action

    .. data:: withdraw = 1

    	Withdraw NLRI

    .. data:: attribute_discard = 2

    	Discard Attribute

    """

    none = 0

    withdraw = 1

    attribute_discard = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpBagUpdFilterActionEnum']


class BgpBfdEnableModeEnum(Enum):
    """
    BgpBfdEnableModeEnum

    BFD enable mode

    .. data:: bgp_bfd_enable_mode_disable = 0

    	BFD fast detect disabled 

    .. data:: bgp_bfd_enable_mode_def = 1

    	BFD fast detect default mode 

    .. data:: bgp_bfd_enable_mode_strict = 2

    	BFD fast detect hold down aka strict mode

    """

    bgp_bfd_enable_mode_disable = 0

    bgp_bfd_enable_mode_def = 1

    bgp_bfd_enable_mode_strict = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpBfdEnableModeEnum']


class BgpBfdStateEnum(Enum):
    """
    BgpBfdStateEnum

    BFD session state

    .. data:: bgp_bfd_state_not_configured = 0

    	BFD not configured

    .. data:: bgp_bfd_state_admin_down = 1

    	BFD session disabled (neighbor shutdown)

    .. data:: bgp_bfd_state_not_supported = 2

    	BFD session disabled (interface type not

    	supported)

    .. data:: bgp_bfd_state_not_created = 3

    	BFD session configured, not yet created

    .. data:: bgp_bfd_state_created = 4

    	BFD session created, state notification not

    	received

    .. data:: bgp_bfd_state_up = 5

    	BFD session up

    .. data:: bgp_bfd_state_down = 6

    	BFD session down

    .. data:: bgp_bfd_state_nbr_not_configured = 7

    	BFD session down (peer not configured)

    .. data:: bgp_bfd_state_none = 8

    	BFD session (yet ro rcv Notification)

    """

    bgp_bfd_state_not_configured = 0

    bgp_bfd_state_admin_down = 1

    bgp_bfd_state_not_supported = 2

    bgp_bfd_state_not_created = 3

    bgp_bfd_state_created = 4

    bgp_bfd_state_up = 5

    bgp_bfd_state_down = 6

    bgp_bfd_state_nbr_not_configured = 7

    bgp_bfd_state_none = 8


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpBfdStateEnum']


class BgpBindingSidEnum(Enum):
    """
    BgpBindingSidEnum

    BGP Binding SID type

    .. data:: none = 0

    	None

    .. data:: label = 1

    	Binding SID type MPLS label

    .. data:: v6 = 2

    	Binding SID type ipv6

    """

    none = 0

    label = 1

    v6 = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpBindingSidEnum']


class BgpBmpStateEnum(Enum):
    """
    BgpBmpStateEnum

    BMP Connection State

    .. data:: none = 0

    	BMP NOT Connected

    .. data:: connecting = 1

    	BMP Under Connection

    .. data:: established = 2

    	BMP Connection Established

    .. data:: closing = 3

    	BMP Connection Closing

    """

    none = 0

    connecting = 1

    established = 2

    closing = 3


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpBmpStateEnum']


class BgpBmpUpdModeEnum(Enum):
    """
    BgpBmpUpdModeEnum

    Bgp bmp upd mode

    .. data:: bgp_bmp_upd_n_either = 0

    	Neither of the modes are enabled

    .. data:: bgp_bmp_upd_route_mon = 1

    	Route Monotoring mode enabled

    .. data:: bgp_bmp_upd_route_mirr = 2

    	Route Mirroring mode is enabled

    """

    bgp_bmp_upd_n_either = 0

    bgp_bmp_upd_route_mon = 1

    bgp_bmp_upd_route_mirr = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpBmpUpdModeEnum']


class BgpBpStageEnum(Enum):
    """
    BgpBpStageEnum

    Bgp bp stage

    .. data:: bgp_bp_comp_not_compared = 0

    	Best path comparison not performed

    .. data:: bgp_bp_comp_imulti_path = 1

    	Path is an iBGP multipath

    .. data:: bgp_bp_comp_emulti_path = 2

    	Path is an eBGP multipath

    .. data:: bgp_bp_comp_eimulti_path = 3

    	Path is an eiBGP multipath

    .. data:: bgp_bp_invalid_path = 4

    	Invalid path

    .. data:: bgp_bp_comp_pre_cost_comm = 5

    	TODO

    .. data:: bgp_bp_comp_weight = 6

    	Path has a lower weight

    .. data:: bgp_bp_comp_locpref = 7

    	Path has a lower local preference

    .. data:: bgp_bp_comp_rpki = 8

    	Path has worse origin validation state

    .. data:: bgp_bp_comp_aigp = 9

    	TODO

    .. data:: bgp_bp_comp_local = 10

    	Path is not local

    .. data:: bgp_bp_comp_local_rib = 11

    	TODO

    .. data:: bgp_bp_comp_as_path_len = 12

    	Path has a longer AS path

    .. data:: bgp_bp_comp_origin = 13

    	Path has a less favorable origin

    .. data:: bgp_bp_comp_med = 14

    	Path has a lower MED

    .. data:: bgp_bp_comp_ebgp = 15

    	Path lost to an eBGP path

    .. data:: bgp_bp_comp_ao = 16

    	Path has Accept-Own community

    .. data:: bgp_bp_comp_igp_metric = 17

    	Path has a higher IGP metric

    .. data:: bgp_bp_comp_igp_cost_comm = 18

    	TODO

    .. data:: bgp_bp_comp_rtr_id = 19

    	Path has a higher router ID

    .. data:: bgp_bp_comp_clstr_len = 20

    	Path has a longer cluster length

    .. data:: bgp_bp_comp_nbr_addr = 21

    	Path has a higher neighbor address

    .. data:: bgp_bp_comp_suppressed = 22

    	Path is newer than best path

    .. data:: bgp_bp_comp_mismatch = 23

    	Best path comparison failed, perhaps due to

    	recent configuration changes

    .. data:: bgp_bp_comp_persistence = 24

    	Path is persistent

    """

    bgp_bp_comp_not_compared = 0

    bgp_bp_comp_imulti_path = 1

    bgp_bp_comp_emulti_path = 2

    bgp_bp_comp_eimulti_path = 3

    bgp_bp_invalid_path = 4

    bgp_bp_comp_pre_cost_comm = 5

    bgp_bp_comp_weight = 6

    bgp_bp_comp_locpref = 7

    bgp_bp_comp_rpki = 8

    bgp_bp_comp_aigp = 9

    bgp_bp_comp_local = 10

    bgp_bp_comp_local_rib = 11

    bgp_bp_comp_as_path_len = 12

    bgp_bp_comp_origin = 13

    bgp_bp_comp_med = 14

    bgp_bp_comp_ebgp = 15

    bgp_bp_comp_ao = 16

    bgp_bp_comp_igp_metric = 17

    bgp_bp_comp_igp_cost_comm = 18

    bgp_bp_comp_rtr_id = 19

    bgp_bp_comp_clstr_len = 20

    bgp_bp_comp_nbr_addr = 21

    bgp_bp_comp_suppressed = 22

    bgp_bp_comp_mismatch = 23

    bgp_bp_comp_persistence = 24


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpBpStageEnum']


class BgpConnStateEnum(Enum):
    """
    BgpConnStateEnum

    Bgp conn state

    .. data:: bgp_st_dont_care = 0

    	DontCare

    .. data:: bgp_st_idle = 1

    	Idle

    .. data:: bgp_st_connect = 2

    	Connect

    .. data:: bgp_st_active = 3

    	Active

    .. data:: bgp_st_open_sent = 4

    	OpenSent

    .. data:: bgp_st_open_confirm = 5

    	OpenConfirm

    .. data:: bgp_st_estab = 6

    	Established

    .. data:: bgp_st_closing = 7

    	Closing

    .. data:: bgp_st_closing_sync = 8

    	ClosingSync

    """

    bgp_st_dont_care = 0

    bgp_st_idle = 1

    bgp_st_connect = 2

    bgp_st_active = 3

    bgp_st_open_sent = 4

    bgp_st_open_confirm = 5

    bgp_st_estab = 6

    bgp_st_closing = 7

    bgp_st_closing_sync = 8


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpConnStateEnum']


class BgpDsConnStateEnum(Enum):
    """
    BgpDsConnStateEnum

    Bgp ds conn state

    .. data:: none = 0

    	DS connection not initiated - ST 0

    .. data:: connect_init = 1

    	DS connection initiated - ST 1

    .. data:: connect_fail = 2

    	DS connection failed - ST 2

    .. data:: connect_estb = 3

    	DS connection established - ST 3

    .. data:: disconnect_init = 4

    	DS disconnect initiated - ST 4

    .. data:: disconnect_fail = 5

    	DS disconnect failed - ST 5

    .. data:: disconnect_done = 6

    	DS disconnect done - ST 6

    """

    none = 0

    connect_init = 1

    connect_fail = 2

    connect_estb = 3

    disconnect_init = 4

    disconnect_fail = 5

    disconnect_done = 6


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpDsConnStateEnum']


class BgpEbgpSendDmzEnableModeEnum(Enum):
    """
    BgpEbgpSendDmzEnableModeEnum

    EBGP send extended community dmz link bandwidth

    enable mode

    .. data:: bgp_ebgp_send_dmz_disable = 0

    	EBGP send extended community dmz link bandwidth

    	disabled 

    .. data:: bgp_ebgp_send_dmz_dflt = 1

    	EBGP send extended community dmz link bandwidth

    	default mode 

    .. data:: bgp_ebgp_send_dmz_cumulative = 2

    	EBGP send extended community dmz link bandwidth

    	cumulative mode

    """

    bgp_ebgp_send_dmz_disable = 0

    bgp_ebgp_send_dmz_dflt = 1

    bgp_ebgp_send_dmz_cumulative = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpEbgpSendDmzEnableModeEnum']


class BgpEntitiesEnum(Enum):
    """
    BgpEntitiesEnum

    Entity type

    .. data:: af_group = 0

    	AF groups

    .. data:: session_group = 1

    	Session Groups

    .. data:: neighbor_group = 2

    	Neighbor Groups

    .. data:: neighbor = 3

    	Neighbors

    """

    af_group = 0

    session_group = 1

    neighbor_group = 2

    neighbor = 3


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpEntitiesEnum']


class BgpEntityEnum(Enum):
    """
    BgpEntityEnum

    Bgp entity

    .. data:: af_group = 0

    	Address family group

    .. data:: session_group = 1

    	Session group

    .. data:: neighbor_group = 2

    	Neighbor group

    .. data:: neighbor = 3

    	Neighbor

    """

    af_group = 0

    session_group = 1

    neighbor_group = 2

    neighbor = 3


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpEntityEnum']


class BgpGwAddrLenEnum(Enum):
    """
    BgpGwAddrLenEnum

    BGP GW Address Length

    .. data:: gwnone = 0

    	NO address length

    .. data:: gwipv4 = 4

    	IP v4 address length

    .. data:: gwipv6 = 16

    	IP v6 address length

    """

    gwnone = 0

    gwipv4 = 4

    gwipv6 = 16


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpGwAddrLenEnum']


class BgpIsmConnStateEnum(Enum):
    """
    BgpIsmConnStateEnum

    Bgp ism conn state

    .. data:: none = 0

    	None - ST 0

    .. data:: connect_done = 1

    	ISSUMgr connection done - ST 1

    """

    none = 0

    connect_done = 1


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpIsmConnStateEnum']


class BgpLabelRpfInstallEnum(Enum):
    """
    BgpLabelRpfInstallEnum

    BGP Label RPF Install Path

    .. data:: bgp_label_rpf_install_rib = 0

    	Install via RIB

    .. data:: bgp_label_rpf_install_lsd = 1

    	Install via LSD

    """

    bgp_label_rpf_install_rib = 0

    bgp_label_rpf_install_lsd = 1


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpLabelRpfInstallEnum']


class BgpNhEventEnum(Enum):
    """
    BgpNhEventEnum

    Bgp nh event

    .. data:: bgp_nh_event_crit_not_f = 0

    	Last event received is a crit notf

    .. data:: bgp_nh_event_non_crit_not_f = 1

    	Last event received is a non-crit notf

    .. data:: bgp_nh_event_registration = 2

    	Last event sent is a registration

    """

    bgp_nh_event_crit_not_f = 0

    bgp_nh_event_non_crit_not_f = 1

    bgp_nh_event_registration = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpNhEventEnum']


class BgpNhUpdateEnum(Enum):
    """
    BgpNhUpdateEnum

    Bgp nh update

    .. data:: bgp_nh_update_none = 0

    	No nh update yet

    .. data:: bgp_nh_update_crit_not_f = 1

    	Last nh update is crit notf

    .. data:: bgp_nh_update_crit_sync = 2

    	Last nh update is crit sync update

    .. data:: bgp_nh_update_crit_rib_conv = 3

    	Last nh update is crit update caused by rib

    	converge

    .. data:: bgp_nh_update_crit_table_down = 4

    	Last nh update is crit update caused by table

    	down

    .. data:: bgp_nh_update_non_crit_not_f = 5

    	Last nh update is non-crit notf

    .. data:: bgp_nh_update_non_crit_sync = 6

    	Last nh update is non-crit sync update

    .. data:: bgp_nh_update_non_crit_rib_conv = 7

    	Last nh update is non-crit update caused by rib

    	converge

    .. data:: bgp_nh_update_non_crit_table_down = 8

    	Last nh update is non-crit update caused by

    	table down

    """

    bgp_nh_update_none = 0

    bgp_nh_update_crit_not_f = 1

    bgp_nh_update_crit_sync = 2

    bgp_nh_update_crit_rib_conv = 3

    bgp_nh_update_crit_table_down = 4

    bgp_nh_update_non_crit_not_f = 5

    bgp_nh_update_non_crit_sync = 6

    bgp_nh_update_non_crit_rib_conv = 7

    bgp_nh_update_non_crit_table_down = 8


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpNhUpdateEnum']


class BgpNhValidateEnum(Enum):
    """
    BgpNhValidateEnum

    Bgp nh validate

    .. data:: bgp_nh_validate_sync = 0

    	bgp nh validate sync

    .. data:: bgp_nh_validate_async = 1

    	bgp nh validate async

    .. data:: bgp_nh_validate_none = 2

    	bgp nh validate none

    """

    bgp_nh_validate_sync = 0

    bgp_nh_validate_async = 1

    bgp_nh_validate_none = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpNhValidateEnum']


class BgpOpenCheckErrEnum(Enum):
    """
    BgpOpenCheckErrEnum

    BGP open check error types

    .. data:: none = 0

    	No error

    .. data:: neighbor_down = 1

    	Neighbor down

    .. data:: no_update_group_set = 2

    	No update-group set

    .. data:: no_af_config = 3

    	No AF configured

    .. data:: update_group_pending = 4

    	Update-group pending

    .. data:: low_memory = 5

    	Low memory

    .. data:: neighbor_shutdown = 6

    	Neighbor shutdown

    .. data:: ebgp_neighbor_remote = 7

    	eBGP neighbor is remote

    .. data:: update_source_interface_null = 8

    	Update source invalid

    .. data:: no_ipv6_address = 9

    	No global IPv6 address found

    .. data:: first_hop_interface_null = 10

    	First-hop interface invalid

    .. data:: no_ipv6ll_address = 11

    	No LL IPv6 address found

    .. data:: no_update_source_config = 12

    	No update-source configured

    .. data:: no_router_id = 13

    	No router-identifier

    .. data:: update_source_interface_get_failed = 14

    	Update-source interface get failed

    .. data:: update_source_interface_state_get_failed = 15

    	Update-source interface state get failed

    .. data:: update_source_interface_down = 16

    	Update-source interface down

    .. data:: update_source_interface_ll_get_failed = 17

    	Update-source interface LL get failed

    .. data:: update_source_interface_address_get_failed = 18

    	Update-source interface address get failed

    .. data:: source_address_af_invalid = 19

    	Source-address AF invalid

    .. data:: no_update_source_ll_peering = 20

    	No update-source for LL peering

    .. data:: local_address_get_failed = 21

    	Local-address get failed

    .. data:: no_best_local_address = 22

    	No best local-address

    .. data:: neighbor_address_equals_local_address = 23

    	Neighbor address is local address

    .. data:: neighbor_closing = 24

    	Neighbor in closing state

    .. data:: neighbor_pending_reset = 25

    	Neighbor in pending reset state

    .. data:: out_interface_set_failed = 26

    	Out-interface set failed

    .. data:: local_address_mismatch = 27

    	Local-address mismatch

    .. data:: neighbor_active_only = 28

    	Neighbor in active only mode

    .. data:: socket_init_failed = 29

    	Socket init failed

    .. data:: socket_operation_failed = 30

    	Socket operation failed

    .. data:: local_neighbor = 31

    	Neighbor is local

    .. data:: multi_hop_neighbor = 32

    	No router to multi-hop neighbor

    """

    none = 0

    neighbor_down = 1

    no_update_group_set = 2

    no_af_config = 3

    update_group_pending = 4

    low_memory = 5

    neighbor_shutdown = 6

    ebgp_neighbor_remote = 7

    update_source_interface_null = 8

    no_ipv6_address = 9

    first_hop_interface_null = 10

    no_ipv6ll_address = 11

    no_update_source_config = 12

    no_router_id = 13

    update_source_interface_get_failed = 14

    update_source_interface_state_get_failed = 15

    update_source_interface_down = 16

    update_source_interface_ll_get_failed = 17

    update_source_interface_address_get_failed = 18

    source_address_af_invalid = 19

    no_update_source_ll_peering = 20

    local_address_get_failed = 21

    no_best_local_address = 22

    neighbor_address_equals_local_address = 23

    neighbor_closing = 24

    neighbor_pending_reset = 25

    out_interface_set_failed = 26

    local_address_mismatch = 27

    neighbor_active_only = 28

    socket_init_failed = 29

    socket_operation_failed = 30

    local_neighbor = 31

    multi_hop_neighbor = 32


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpOpenCheckErrEnum']


class BgpPeerResetReasonIndexEnum(Enum):
    """
    BgpPeerResetReasonIndexEnum

    Bgp peer reset reason index

    .. data:: bgp_read_remote_closed = 1

    	Remote closed the session

    .. data:: bgp_read_failed = 2

    	Read failed

    .. data:: bgp_write_failed = 3

    	Write failed

    .. data:: bgp_sock_disconnected = 4

    	Socket disconnected

    .. data:: bgp_sock_select_failed = 5

    	Socket select failed

    .. data:: bgp_peer_reset_reason_none = 6

    	None

    """

    bgp_read_remote_closed = 1

    bgp_read_failed = 2

    bgp_write_failed = 3

    bgp_sock_disconnected = 4

    bgp_sock_select_failed = 5

    bgp_peer_reset_reason_none = 6


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpPeerResetReasonIndexEnum']


class BgpResetReasonIndexEnum(Enum):
    """
    BgpResetReasonIndexEnum

    Bgp reset reason index

    .. data:: bgp_none = 0

    	None

    .. data:: bgp_init = 1

    	BGP neighbor initialized

    .. data:: bgp_no_memory = 2

    	No memory

    .. data:: not_received = 3

    	BGP Notification received

    .. data:: not_sent = 4

    	BGP Notification sent

    .. data:: conn_collision = 5

    	Error during connection collision

    .. data:: peer_closed = 6

    	Peer closing down the session

    .. data:: max_prefix_exceeded = 7

    	Peer exceeding maximum prefix limit

    .. data:: interface_flap = 8

    	Interface flap

    .. data:: neighbor_deleted = 9

    	Neighbor deleted

    .. data:: admin_shutdown = 10

    	Admin. shutdown

    .. data:: af_activated = 11

    	Address family activated

    .. data:: af_deactivated = 12

    	Address family removed

    .. data:: protocol_error = 13

    	Protocol Error

    .. data:: listen_closed = 14

    	Listen socket was closed

    .. data:: rib_failed = 15

    	Routing Table process not responding

    .. data:: user_clear = 16

    	User clear requested

    .. data:: user_clear_gr = 17

    	User clear with graceful restart requested

    .. data:: router_id_changed = 18

    	Router ID changed

    .. data:: remote_as_changed = 19

    	Remote AS configuration changed

    .. data:: orf_changed = 20

    	Outbound route filter configuration changed

    .. data:: rr_client_changed = 21

    	RR client configuration changed

    .. data:: legacy_pe_rt_changed = 22

    	Legacy-pe-RT configuration changed

    .. data:: softre_config_changed = 23

    	Soft reconfiguration configuration changed

    .. data:: local_as_changed = 24

    	Local AS configuration changed

    .. data:: low_memory = 25

    	Shutdown during SEVERE low memory condition

    .. data:: bfd_down = 26

    	BFD (Bidirectional forwarding detection)

    	session down

    .. data:: allow_as_in_changed = 27

    	Allowas-in configuration has changed

    .. data:: recv_dmz_cfg = 28

    	Recv DMZ Config changed

    .. data:: cap_4byteas_changed = 29

    	Capablity 4-byte-as configuration has changed

    .. data:: tcp_oper_down = 30

    	Received tcp oper down

    .. data:: scoped_sync_retry = 31

    	Scoped sync is repeated due to strict          

    	prefix check failure

    .. data:: cluster_id_changed = 32

    	Neighbor moved to a new cluster

    .. data:: rr_disable_changed = 33

    	Client-to-client reflection disabled/enabled   

    	for cluster to which neighbor belongs

    .. data:: aigp_changed = 34

    	AIGP configuration has changed                 

    	for cluster to which neighbor belongs

    .. data:: signalling_changed = 35

    	L2VPN Signalling Changed

    .. data:: open_check_s_failed = 36

    	Session open checks failed

    .. data:: ao_changed = 37

    	Accept-own changed

    .. data:: llgr_staletime_changed = 38

    	Long-lived graceful-restart stale-time

    	configuration changed

    .. data:: llgr_capable_changed = 39

    	Long-lived graceful-restart capable

    	configuration changed

    .. data:: nbr_local_addr_changed = 40

    	Neighbor local address configuration changed

    .. data:: internal_vpn_client_changed = 41

    	Internal-vpn-client configuration changed

    .. data:: cap_suppress_all_changed = 42

    	All capabilities suppression changed

    """

    bgp_none = 0

    bgp_init = 1

    bgp_no_memory = 2

    not_received = 3

    not_sent = 4

    conn_collision = 5

    peer_closed = 6

    max_prefix_exceeded = 7

    interface_flap = 8

    neighbor_deleted = 9

    admin_shutdown = 10

    af_activated = 11

    af_deactivated = 12

    protocol_error = 13

    listen_closed = 14

    rib_failed = 15

    user_clear = 16

    user_clear_gr = 17

    router_id_changed = 18

    remote_as_changed = 19

    orf_changed = 20

    rr_client_changed = 21

    legacy_pe_rt_changed = 22

    softre_config_changed = 23

    local_as_changed = 24

    low_memory = 25

    bfd_down = 26

    allow_as_in_changed = 27

    recv_dmz_cfg = 28

    cap_4byteas_changed = 29

    tcp_oper_down = 30

    scoped_sync_retry = 31

    cluster_id_changed = 32

    rr_disable_changed = 33

    aigp_changed = 34

    signalling_changed = 35

    open_check_s_failed = 36

    ao_changed = 37

    llgr_staletime_changed = 38

    llgr_capable_changed = 39

    nbr_local_addr_changed = 40

    internal_vpn_client_changed = 41

    cap_suppress_all_changed = 42


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpResetReasonIndexEnum']


class BgpRnhAddrLenEnum(Enum):
    """
    BgpRnhAddrLenEnum

    BGP RNH Address Length

    .. data:: none = 0

    	NO address length

    .. data:: v4 = 4

    	IP v4 address length

    .. data:: mac = 6

    	MAC address length

    .. data:: v6 = 16

    	IP v6 address length

    """

    none = 0

    v4 = 4

    mac = 6

    v6 = 16


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpRnhAddrLenEnum']


class BgpRoute1Enum(Enum):
    """
    BgpRoute1Enum

    Bgp route1

    .. data:: bgp_route_type_used = 0

    	Used path from neighbor

    .. data:: bgp_route_type_rcvd_only = 1

    	Received only path from neighbor

    .. data:: bgp_route_type_safi_label_ed_ucast_used = 2

    	Used path from neighbor received via

    	labeled-unicast SAFI

    .. data:: bgp_route_type_safi_label_ed_ucast_rcvd_only = 3

    	Received only path from neighbor received via

    	labeled-unicast SAFI

    .. data:: bgp_route_type_rib = 4

    	Redistributed from the RIB

    .. data:: bgp_route_type_aggregate = 5

    	Locally generated aggregate

    .. data:: bgp_route_type_max = 6

    	Number of route types

    """

    bgp_route_type_used = 0

    bgp_route_type_rcvd_only = 1

    bgp_route_type_safi_label_ed_ucast_used = 2

    bgp_route_type_safi_label_ed_ucast_rcvd_only = 3

    bgp_route_type_rib = 4

    bgp_route_type_aggregate = 5

    bgp_route_type_max = 6


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpRoute1Enum']


class BgpRouteEnum(Enum):
    """
    BgpRouteEnum

    Bgp route

    .. data:: used = 0

    	Used path from neighbor

    .. data:: received_only = 1

    	Received only path from neighbor

    .. data:: safi_labeled_unicast_used = 2

    	Used path from neighbor received via

    	labeled-unicast SAFI

    .. data:: safi_labeled_unicast_received_only = 3

    	Received only path from neighbor received via

    	labeled-unicast SAFI

    .. data:: rib = 4

    	Redistributed from the RIB

    .. data:: aggregate = 5

    	Locally generated aggregate

    """

    used = 0

    received_only = 1

    safi_labeled_unicast_used = 2

    safi_labeled_unicast_received_only = 3

    rib = 4

    aggregate = 5


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpRouteEnum']


class BgpRpkiAfEnum(Enum):
    """
    BgpRpkiAfEnum

    Bgp rpki af

    .. data:: ipv4 = 2

    	IPv4

    .. data:: ipv6 = 26

    	IPv6

    """

    ipv4 = 2

    ipv6 = 26


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpRpkiAfEnum']


class BgpRpkiCreasonEnum(Enum):
    """
    BgpRpkiCreasonEnum

    Bgp rpki creason

    .. data:: no_close_reason = 0

    	No close reason

    .. data:: read_error = 1

    	Socket Read error

    .. data:: write_error = 2

    	Socket Write error

    .. data:: proto_error = 3

    	Protocol error

    .. data:: config_shutdown = 4

    	Shutdown by configuration

    .. data:: config_removed = 5

    	Configuration removed

    .. data:: config_changed = 6

    	Configuration changed

    .. data:: nsr_disabled = 7

    	NSR disabled

    .. data:: user_clear = 8

    	Explicity user clear

    .. data:: ssh_died = 9

    	SSH process died

    .. data:: tcp_died = 10

    	TCP process died

    """

    no_close_reason = 0

    read_error = 1

    write_error = 2

    proto_error = 3

    config_shutdown = 4

    config_removed = 5

    config_changed = 6

    nsr_disabled = 7

    user_clear = 8

    ssh_died = 9

    tcp_died = 10


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpRpkiCreasonEnum']


class BgpRpkiEdmAfEnum(Enum):
    """
    BgpRpkiEdmAfEnum

    Bgp rpki edm af

    .. data:: ipv4 = 2

    	IPv4

    .. data:: ipv6 = 10

    	IPv6

    """

    ipv4 = 2

    ipv6 = 10


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpRpkiEdmAfEnum']


class BgpRpkiPerrorEnum(Enum):
    """
    BgpRpkiPerrorEnum

    Bgp rpki perror

    .. data:: none = 0

    	No protocol error

    .. data:: message_version = 1

    	Message version error

    .. data:: message_type = 2

    	Message type error

    .. data:: message_length = 3

    	Message length error

    .. data:: nonce_mismatch = 4

    	Server nonce mismatch

    .. data:: bad_prefix = 5

    	Bad ROA

    .. data:: fsm = 6

    	FSM error

    .. data:: no_response = 7

    	No response from server

    .. data:: error_report = 8

    	Server sent error-report

    """

    none = 0

    message_version = 1

    message_type = 2

    message_length = 3

    nonce_mismatch = 4

    bad_prefix = 5

    fsm = 6

    no_response = 7

    error_report = 8


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpRpkiPerrorEnum']


class BgpRpkiPstateEnum(Enum):
    """
    BgpRpkiPstateEnum

    Bgp rpki pstate

    .. data:: not_started = 0

    	Server protocol has not started

    .. data:: reset = 1

    	Server protocol reset

    .. data:: refresh = 2

    	Server protocol resumed

    .. data:: reset_query_sent = 3

    	Reset query sent to server

    .. data:: serial_query_sent = 4

    	Serial query sent to server

    .. data:: data_start = 5

    	Server started sending data

    .. data:: data_end = 6

    	Server ended sending data

    """

    not_started = 0

    reset = 1

    refresh = 2

    reset_query_sent = 3

    serial_query_sent = 4

    data_start = 5

    data_end = 6


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpRpkiPstateEnum']


class BgpRpkiStateEnum(Enum):
    """
    BgpRpkiStateEnum

    Bgp rpki state

    .. data:: idle = 0

    	Server is idle

    .. data:: attempt_connect = 1

    	Connect attempt made to server

    .. data:: connected = 2

    	Server is connected

    """

    idle = 0

    attempt_connect = 1

    connected = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpRpkiStateEnum']


class BgpRtrStateEnum(Enum):
    """
    BgpRtrStateEnum

    Bgp rtr state

    .. data:: bgp_router_read_only = 0

    	Read only mode

    .. data:: bgp_router_do_best_path = 1

    	Bestpath calculation mode

    .. data:: bgp_router_do_tunnel_update = 2

    	Tunnel update mode

    .. data:: bgp_router_do_import = 3

    	Import mode

    .. data:: bgp_router_do_label_alloc = 4

    	Label Allocation mode

    .. data:: bgp_router_do_ribupd = 5

    	RIB update mode

    .. data:: bgp_router_read_write = 6

    	Normal (read/write) mode

    .. data:: bgp_router_mode_count = 7

    	Number of router modes

    """

    bgp_router_read_only = 0

    bgp_router_do_best_path = 1

    bgp_router_do_tunnel_update = 2

    bgp_router_do_import = 3

    bgp_router_do_label_alloc = 4

    bgp_router_do_ribupd = 5

    bgp_router_read_write = 6

    bgp_router_mode_count = 7


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpRtrStateEnum']


class BgpScopedSyncStateEnum(Enum):
    """
    BgpScopedSyncStateEnum

    Bgp scoped sync state

    .. data:: bgp_scope_sync_state_none = 0

    	State none

    .. data:: bgp_scope_sync_state_not_nsr_ready = 1

    	Oper Down when NSR not ready

    .. data:: bgp_scope_sync_state_timer_start = 2

    	Timer started for active batch

    .. data:: bgp_scope_sync_state_add_list = 3

    	Start adding neighbors to pending batch

    .. data:: bgp_scope_sync_state_batch_acitve = 4

    	Active batch

    """

    bgp_scope_sync_state_none = 0

    bgp_scope_sync_state_not_nsr_ready = 1

    bgp_scope_sync_state_timer_start = 2

    bgp_scope_sync_state_add_list = 3

    bgp_scope_sync_state_batch_acitve = 4


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpScopedSyncStateEnum']


class BgpSrpolicyTunReqStateEnum(Enum):
    """
    BgpSrpolicyTunReqStateEnum

    BGP SR Policy Tunnel Internal State

    .. data:: tunnel_state_request_pending = 0

    	Tunnel install in dataplane not requested yet

    .. data:: tunnel_state_requested = 1

    	Requested create of tunnel in data plane

    .. data:: tunnel_state_notified_up = 2

    	Tunnel is UP

    .. data:: tunnel_state_notified_down = 4

    	Tunnel is notified Down by tunnel manager

    .. data:: tunnel_state_marked_stale = 8

    	Tunnel is marked stale Due to tunnel manager

    	down

    .. data:: tunnel_state_marked_disable = 16

    	Tunnel is marked  disabled from the config in

    	tunnel manager

    """

    tunnel_state_request_pending = 0

    tunnel_state_requested = 1

    tunnel_state_notified_up = 2

    tunnel_state_notified_down = 4

    tunnel_state_marked_stale = 8

    tunnel_state_marked_disable = 16


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpSrpolicyTunReqStateEnum']


class BgpSyncNbrNsrStateEnum(Enum):
    """
    BgpSyncNbrNsrStateEnum

    Bgp sync nbr nsr state

    .. data:: bgp_nbr_nsr_st_none = 0

    	None - ST 0

    .. data:: bgp_nbr_nsr_st_oper_down = 1

    	TCP OPER_DOWN notfn received - ST 1

    .. data:: bgp_nbr_nsr_st_tcp_init_sync = 2

    	TCP initial sync in progress - ST 2

    .. data:: bgp_nbr_nsr_st_tcp_phase_two = 3

    	TCP initial sync phase two in progress - ST 3

    .. data:: bgp_nbr_nsr_st_bgp_init_sync = 4

    	BGP initial sync in progress - ST 4

    .. data:: bgp_nbr_nsr_st_nsr_ready = 5

    	Neighbor NSR ready - ST 5

    """

    bgp_nbr_nsr_st_none = 0

    bgp_nbr_nsr_st_oper_down = 1

    bgp_nbr_nsr_st_tcp_init_sync = 2

    bgp_nbr_nsr_st_tcp_phase_two = 3

    bgp_nbr_nsr_st_bgp_init_sync = 4

    bgp_nbr_nsr_st_nsr_ready = 5


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpSyncNbrNsrStateEnum']


class BgpTcpModeEnum(Enum):
    """
    BgpTcpModeEnum

    Bgp tcp mode

    .. data:: bgp_tcp_mode_type_either = 0

    	Use either active or passive mode

    .. data:: bgp_tcp_mode_type_active_only = 1

    	Use active mode only

    .. data:: bgp_tcp_mode_type_passive_only = 2

    	Use passive mode only

    """

    bgp_tcp_mode_type_either = 0

    bgp_tcp_mode_type_active_only = 1

    bgp_tcp_mode_type_passive_only = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpTcpModeEnum']


class BgpTeInfraTunnelEnum(Enum):
    """
    BgpTeInfraTunnelEnum

    BGP TE infra Tunnel type

    .. data:: bgp_te_infra_default_tunnel_type = 0

    	BGP TE infra default type

    .. data:: bgp_te_infra_attr_set_tunnel_type = 1

    	BGP TE infra attribute set type

    .. data:: bgp_te_infra_multi_path_exp_tunnel_type = 2

    	BGP TE infra explicit path type

    """

    bgp_te_infra_default_tunnel_type = 0

    bgp_te_infra_attr_set_tunnel_type = 1

    bgp_te_infra_multi_path_exp_tunnel_type = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpTeInfraTunnelEnum']


class BgpteTunnelEnum(Enum):
    """
    BgpteTunnelEnum

    BGP MPLS TE tunnel type

    .. data:: attrset = 0

    	Attribute set TE tunnel

    .. data:: srpolicy = 1

    	SR Policy TE tunnel

    """

    attrset = 0

    srpolicy = 1


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['BgpteTunnelEnum']



class Bgp(object):
    """
    BGP operational data
    
    .. attribute:: bpm_instances_table
    
    	BGP instances information
    	**type**\:   :py:class:`BpmInstancesTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.BpmInstancesTable>`
    
    .. attribute:: config_instances
    
    	Instance specific BGP data
    	**type**\:   :py:class:`ConfigInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances>`
    
    .. attribute:: instances
    
    	Instance specific BGP data
    	**type**\:   :py:class:`Instances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances>`
    
    

    """

    _prefix = 'ipv4-bgp-oper'
    _revision = '2015-08-27'

    def __init__(self):
        self.bpm_instances_table = Bgp.BpmInstancesTable()
        self.bpm_instances_table.parent = self
        self.config_instances = Bgp.ConfigInstances()
        self.config_instances.parent = self
        self.instances = Bgp.Instances()
        self.instances.parent = self


    class ConfigInstances(object):
        """
        Instance specific BGP data
        
        .. attribute:: config_instance
        
        	Instance specific BGP data
        	**type**\: list of    :py:class:`ConfigInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance>`
        
        

        """

        _prefix = 'ipv4-bgp-oper'
        _revision = '2015-08-27'

        def __init__(self):
            self.parent = None
            self.config_instance = YList()
            self.config_instance.parent = self
            self.config_instance.name = 'config_instance'


        class ConfigInstance(object):
            """
            Instance specific BGP data
            
            .. attribute:: instance_name  <key>
            
            	Name of the BGP instance
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            .. attribute:: config_instance_default_vrf
            
            	Default VRF related configuration data
            	**type**\:   :py:class:`ConfigInstanceDefaultVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf>`
            
            .. attribute:: config_vrfs
            
            	VRF related configuration data
            	**type**\:   :py:class:`ConfigVrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs>`
            
            

            """

            _prefix = 'ipv4-bgp-oper'
            _revision = '2015-08-27'

            def __init__(self):
                self.parent = None
                self.instance_name = None
                self.config_instance_default_vrf = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf()
                self.config_instance_default_vrf.parent = self
                self.config_vrfs = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs()
                self.config_vrfs.parent = self


            class ConfigInstanceDefaultVrf(object):
                """
                Default VRF related configuration data
                
                .. attribute:: configuration_inheritances
                
                	The BGP configurataion inheritance table
                	**type**\:   :py:class:`ConfigurationInheritances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances>`
                
                .. attribute:: configuration_users
                
                	The BGP configuration users table
                	**type**\:   :py:class:`ConfigurationUsers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers>`
                
                .. attribute:: entity_configurations
                
                	The BGP Entity Configuration table
                	**type**\:   :py:class:`EntityConfigurations <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations>`
                
                

                """

                _prefix = 'ipv4-bgp-oper'
                _revision = '2015-08-27'

                def __init__(self):
                    self.parent = None
                    self.configuration_inheritances = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances()
                    self.configuration_inheritances.parent = self
                    self.configuration_users = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers()
                    self.configuration_users.parent = self
                    self.entity_configurations = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations()
                    self.entity_configurations.parent = self


                class EntityConfigurations(object):
                    """
                    The BGP Entity Configuration table
                    
                    .. attribute:: entity_configuration
                    
                    	A BGP Entity Configuration table entry
                    	**type**\: list of    :py:class:`EntityConfiguration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2015-08-27'

                    def __init__(self):
                        self.parent = None
                        self.entity_configuration = YList()
                        self.entity_configuration.parent = self
                        self.entity_configuration.name = 'entity_configuration'


                    class EntityConfiguration(object):
                        """
                        A BGP Entity Configuration table entry
                        
                        .. attribute:: address_family_identifier
                        
                        	AF identifier
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: af_dependent_config
                        
                        	Af\-dependent config
                        	**type**\: list of    :py:class:`AfDependentConfig <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig>`
                        
                        .. attribute:: af_independent_config
                        
                        	AF\-independent config
                        	**type**\:   :py:class:`AfIndependentConfig <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig>`
                        
                        .. attribute:: configuration_type
                        
                        	Entity type
                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                        
                        .. attribute:: entity_name
                        
                        	Entity name
                        	**type**\:  str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: entity_type
                        
                        	Entity type
                        	**type**\:   :py:class:`BgpEntityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntityEnum>`
                        
                        .. attribute:: group_name
                        
                        	Entity/group name
                        	**type**\:  str
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: neighbor_address_xr
                        
                        	Neighbor Address
                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.address_family_identifier = None
                            self.af_dependent_config = YList()
                            self.af_dependent_config.parent = self
                            self.af_dependent_config.name = 'af_dependent_config'
                            self.af_independent_config = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig()
                            self.af_independent_config.parent = self
                            self.configuration_type = None
                            self.entity_name = None
                            self.entity_type = None
                            self.group_name = None
                            self.neighbor_address = None
                            self.neighbor_address_xr = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr()
                            self.neighbor_address_xr.parent = self


                        class NeighborAddressXr(object):
                            """
                            Neighbor Address
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4_flowspec_address
                            
                            	IPV4 Flowspec Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4096}
                            
                            .. attribute:: ipv4_label_address
                            
                            	IPv4 Label Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4_mcast_address
                            
                            	IPv4 Mcast Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4_tunnel_address
                            
                            	IPv4 Tunnel
                            	**type**\:  str
                            
                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                            
                            .. attribute:: ipv4mdt_address
                            
                            	IPv4 MDT Addr
                            	**type**\:  str
                            
                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                            
                            .. attribute:: ipv4mvpn_address
                            
                            	MVPN4 addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{56}
                            
                            .. attribute:: ipv4sr_policy_address
                            
                            	IPV4 Policy Addr
                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv4SrPolicyAddress>`
                            
                            .. attribute:: ipv4vpn_address
                            
                            	IPv4 VPN Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4vpn_flowspec_address
                            
                            	IPV4 VPN Flowspec Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4096}
                            
                            .. attribute:: ipv4vpna_mcastddress
                            
                            	IPv4 VPN Mcast Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_flowspec_address
                            
                            	IPV6 Flowspec Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4096}
                            
                            .. attribute:: ipv6_label_address
                            
                            	IPv6 Label Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_mcast_address
                            
                            	IPV6 Mcast Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6mvpn_address
                            
                            	MVPN addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{104}
                            
                            .. attribute:: ipv6sr_policy_address
                            
                            	IPV6 Policy Addr
                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv6SrPolicyAddress>`
                            
                            .. attribute:: ipv6vpn_address
                            
                            	IPv6 VPN Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6vpn_flowspec_address
                            
                            	IPV6 VPN Flowspec Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4096}
                            
                            .. attribute:: ipv6vpn_mcast_address
                            
                            	IPv6 VPN Mcast Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: l2vpn_evpn_address
                            
                            	L2VPN EVPN Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{58}
                            
                            .. attribute:: l2vpn_mspw_address
                            
                            	L2VPN MSPW Addr
                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2VpnMspwAddress>`
                            
                            .. attribute:: l2vpnvpls_address
                            
                            	L2VPN VPLS Addr
                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2VpnvplsAddress>`
                            
                            .. attribute:: ls_ls_address
                            
                            	LINKSTATE LINKSTATE Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]+
                            
                            .. attribute:: rt_constraint_address
                            
                            	RT Constrt Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{24}
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.afi = None
                                self.ipv4_address = None
                                self.ipv4_flowspec_address = None
                                self.ipv4_label_address = None
                                self.ipv4_mcast_address = None
                                self.ipv4_tunnel_address = None
                                self.ipv4mdt_address = None
                                self.ipv4mvpn_address = None
                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv4SrPolicyAddress()
                                self.ipv4sr_policy_address.parent = self
                                self.ipv4vpn_address = None
                                self.ipv4vpn_flowspec_address = None
                                self.ipv4vpna_mcastddress = None
                                self.ipv6_address = None
                                self.ipv6_flowspec_address = None
                                self.ipv6_label_address = None
                                self.ipv6_mcast_address = None
                                self.ipv6mvpn_address = None
                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv6SrPolicyAddress()
                                self.ipv6sr_policy_address.parent = self
                                self.ipv6vpn_address = None
                                self.ipv6vpn_flowspec_address = None
                                self.ipv6vpn_mcast_address = None
                                self.l2vpn_evpn_address = None
                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2VpnMspwAddress()
                                self.l2vpn_mspw_address.parent = self
                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2VpnvplsAddress()
                                self.l2vpnvpls_address.parent = self
                                self.ls_ls_address = None
                                self.rt_constraint_address = None


                            class L2VpnvplsAddress(object):
                                """
                                L2VPN VPLS Addr
                                
                                .. attribute:: l2vpn_address
                                
                                	l2vpn address
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.l2vpn_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.l2vpn_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                            class L2VpnMspwAddress(object):
                                """
                                L2VPN MSPW Addr
                                
                                .. attribute:: l2vpn_address
                                
                                	l2vpn address
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.l2vpn_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.l2vpn_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                            class Ipv4SrPolicyAddress(object):
                                """
                                IPV4 Policy Addr
                                
                                .. attribute:: ipv4_srpolicy_address
                                
                                	ipv4 srpolicy address
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.ipv4_srpolicy_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ipv4_srpolicy_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                            class Ipv6SrPolicyAddress(object):
                                """
                                IPV6 Policy Addr
                                
                                .. attribute:: ipv6_srpolicy_address
                                
                                	ipv6 srpolicy address
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.ipv6_srpolicy_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ipv6_srpolicy_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.afi is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv4_flowspec_address is not None:
                                    return True

                                if self.ipv4_label_address is not None:
                                    return True

                                if self.ipv4_mcast_address is not None:
                                    return True

                                if self.ipv4_tunnel_address is not None:
                                    return True

                                if self.ipv4mdt_address is not None:
                                    return True

                                if self.ipv4mvpn_address is not None:
                                    return True

                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                    return True

                                if self.ipv4vpn_address is not None:
                                    return True

                                if self.ipv4vpn_flowspec_address is not None:
                                    return True

                                if self.ipv4vpna_mcastddress is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                if self.ipv6_flowspec_address is not None:
                                    return True

                                if self.ipv6_label_address is not None:
                                    return True

                                if self.ipv6_mcast_address is not None:
                                    return True

                                if self.ipv6mvpn_address is not None:
                                    return True

                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                    return True

                                if self.ipv6vpn_address is not None:
                                    return True

                                if self.ipv6vpn_flowspec_address is not None:
                                    return True

                                if self.ipv6vpn_mcast_address is not None:
                                    return True

                                if self.l2vpn_evpn_address is not None:
                                    return True

                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                    return True

                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                    return True

                                if self.ls_ls_address is not None:
                                    return True

                                if self.rt_constraint_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr']['meta_info']


                        class AfIndependentConfig(object):
                            """
                            AF\-independent config
                            
                            .. attribute:: addpath_receive_capability
                            
                            	Indicates if addpath receive capability is enabled or disabled
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: addpath_receive_capability_info
                            
                            	Addpath receive capability info
                            	**type**\:   :py:class:`AddpathReceiveCapabilityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo>`
                            
                            .. attribute:: addpath_send_capability
                            
                            	Indicates if addpath send capability is enabled or disabled
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: addpath_send_capability_info
                            
                            	Addpath send capability info
                            	**type**\:   :py:class:`AddpathSendCapabilityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo>`
                            
                            .. attribute:: adminstrative_shutdown
                            
                            	Administrative shutdown
                            	**type**\:  bool
                            
                            .. attribute:: bestpath_use_origin_as_validity
                            
                            	Bestpath Use Origin\-AS Va
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd
                            
                            	Fast failure detection using BFD
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_info
                            
                            	BFD item info
                            	**type**\:   :py:class:`BfdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo>`
                            
                            .. attribute:: bfd_mininterval
                            
                            	BFD Minimum Interval
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_mininterval_info
                            
                            	BFD Mininterval item info
                            	**type**\:   :py:class:`BfdMinintervalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo>`
                            
                            .. attribute:: bfd_multiplier
                            
                            	BFD Multiplier
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_multiplier_info
                            
                            	BFD Multiplier item info
                            	**type**\:   :py:class:`BfdMultiplierInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo>`
                            
                            .. attribute:: bgp_buffer_receive_size
                            
                            	BGP receive buffer size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bgp_buffer_send_size
                            
                            	BGP send buffer size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bmp_servers
                            
                            	BMP Servers activated
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bmp_servers_info
                            
                            	BMP Servers Configuredinfo
                            	**type**\:   :py:class:`BmpServersInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo>`
                            
                            .. attribute:: capability_negotiation_suppressed
                            
                            	Capability negotiation is suppressed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: capability_negotiation_suppressed_info
                            
                            	Capability negotiation suppressed info
                            	**type**\:   :py:class:`CapabilityNegotiationSuppressedInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo>`
                            
                            .. attribute:: cluster_id_info
                            
                            	Cluster ID item info
                            	**type**\:   :py:class:`ClusterIdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo>`
                            
                            .. attribute:: configured_speaker_id
                            
                            	Configured speaker ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: description
                            
                            	Description
                            	**type**\:  str
                            
                            .. attribute:: description_info
                            
                            	Description item info
                            	**type**\:   :py:class:`DescriptionInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo>`
                            
                            .. attribute:: dmz_link_bandwidth
                            
                            	Propagate the DMZ link bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: dmz_link_bandwidth_info
                            
                            	DMZ link bandwidth item 
                            	**type**\:   :py:class:`DmzLinkBandwidthInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo>`
                            
                            .. attribute:: ebgp_hop_count
                            
                            	EBGP neighbors hop count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ebgp_hop_count_info
                            
                            	EBGP neighbors hop count item info
                            	**type**\:   :py:class:`EbgpHopCountInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo>`
                            
                            .. attribute:: ebgp_recv_dmz
                            
                            	Receive Bandwidth of link to single\-hop eBGP peer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ebgp_recv_dmz_info
                            
                            	EBGP receive DMZ link bandwidth item info
                            	**type**\:   :py:class:`EbgpRecvDmzInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo>`
                            
                            .. attribute:: ebgp_send_dmz_info
                            
                            	EBGP send DMZ link bandwidth item info
                            	**type**\:   :py:class:`EbgpSendDmzInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo>`
                            
                            .. attribute:: ebgp_send_dmz_mode
                            
                            	Send DMZ link bandwidthto ebgp peer
                            	**type**\:   :py:class:`BgpEbgpSendDmzEnableModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableModeEnum>`
                            
                            .. attribute:: egress_peer_engineering
                            
                            	Indicates egress peer engineering is enabled
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: egress_peer_engineering_info
                            
                            	Egress Peer Engineering info
                            	**type**\:   :py:class:`EgressPeerEngineeringInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo>`
                            
                            .. attribute:: graceful_restart_disabled
                            
                            	Support for graceful\-restart
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: graceful_restart_disabled_info
                            
                            	Graceful\-restart item info
                            	**type**\:   :py:class:`GracefulRestartDisabledInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo>`
                            
                            .. attribute:: graceful_shutdown_activate
                            
                            	Graceful Shutdown state is activated
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: graceful_shutdown_activate_info
                            
                            	GracefulShutdownAcivate info
                            	**type**\:   :py:class:`GracefulShutdownActivateInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo>`
                            
                            .. attribute:: graceful_shutdown_as_prepends
                            
                            	Prepend the local AS this many times to the AS path of routes advertised during Graceful Shutdown
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: graceful_shutdown_as_prepends_info
                            
                            	GracefulShutdownASPrepends info
                            	**type**\:   :py:class:`GracefulShutdownAsPrependsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo>`
                            
                            .. attribute:: graceful_shutdown_exists
                            
                            	re\-advertise all routes to and from this neighbor with the GSHUT community during Shutdown or bring\-up
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: graceful_shutdown_info
                            
                            	GracefulShutdown info
                            	**type**\:   :py:class:`GracefulShutdownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo>`
                            
                            .. attribute:: graceful_shutdown_loc_pref
                            
                            	Local Preference to advertise routes with during Graceful Shutdown to IBGP. Default=No Touch
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: graceful_shutdown_loc_pref_info
                            
                            	GracefulShutdownLocPref info
                            	**type**\:   :py:class:`GracefulShutdownLocPrefInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo>`
                            
                            .. attribute:: hold_time_value
                            
                            	Holdtime
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: idle_watch_time
                            
                            	Idle Watch time(in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: idle_watch_time_info
                            
                            	Idle Watch time item info
                            	**type**\:   :py:class:`IdleWatchTimeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo>`
                            
                            .. attribute:: ignore_connected_check
                            
                            	If true, don't do NHconnected check for nbr
                            	**type**\:  bool
                            
                            .. attribute:: ignore_connected_info
                            
                            	Ignore Connected Info
                            	**type**\:   :py:class:`IgnoreConnectedInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo>`
                            
                            .. attribute:: internal_vpn_client
                            
                            	If true, the VPN client isan iBGP CE peer
                            	**type**\:  bool
                            
                            .. attribute:: internal_vpn_client_info
                            
                            	Internal VPN Client Info
                            	**type**\:   :py:class:`InternalVpnClientInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo>`
                            
                            .. attribute:: is_ebgp_multihop_bgpmpls_forwarding_disabled
                            
                            	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                            	**type**\:  bool
                            
                            .. attribute:: keepalive_interval
                            
                            	Keepalive interval
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: keychain
                            
                            	Neighbor keychain Name
                            	**type**\:  str
                            
                            .. attribute:: keychain_info
                            
                            	Neighbor Keychain item info
                            	**type**\:   :py:class:`KeychainInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo>`
                            
                            .. attribute:: local_address_info
                            
                            	Local address item info
                            	**type**\:   :py:class:`LocalAddressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo>`
                            
                            .. attribute:: local_as_dual_as
                            
                            	Local AS Dual\-AS option
                            	**type**\:  bool
                            
                            .. attribute:: local_as_info
                            
                            	Local AS number item info
                            	**type**\:   :py:class:`LocalAsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo>`
                            
                            .. attribute:: local_as_no_prepend
                            
                            	Local AS no\-prepend option
                            	**type**\:  bool
                            
                            .. attribute:: local_as_number_xx
                            
                            	First half of Local ASN
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_as_number_yy
                            
                            	Second half of Local ASN
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_as_replace_as
                            
                            	Local AS Replace\-AS option
                            	**type**\:  bool
                            
                            .. attribute:: local_ip_address
                            
                            	Local ipv4 or ipv6 address for neighbor connection
                            	**type**\:   :py:class:`LocalIpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress>`
                            
                            .. attribute:: max_peers
                            
                            	Maximum dynamic nbrs in range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_peers_info
                            
                            	Max dynamic nbrs in range info
                            	**type**\:   :py:class:`MaxPeersInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo>`
                            
                            .. attribute:: min_acc_hold_time_value
                            
                            	Min acceptable holdtimefrom neighbor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: min_advertisement_info
                            
                            	Minimum advertisement interval item info
                            	**type**\:   :py:class:`MinAdvertisementInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo>`
                            
                            .. attribute:: min_advertisement_interval
                            
                            	Minimum advertisement interval, secs part
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: min_advertisement_interval_msecs
                            
                            	Minimum advertisement interval, msecs part
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: millisecond
                            
                            .. attribute:: msg_log_in_buf_count
                            
                            	Message Log Inbound buffer count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msg_log_in_info
                            
                            	Message Log Inbound item info
                            	**type**\:   :py:class:`MsgLogInInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo>`
                            
                            .. attribute:: msg_log_out_buf_count
                            
                            	Message Log Outbound buffer count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msg_log_out_info
                            
                            	Message Log Outbound item info
                            	**type**\:   :py:class:`MsgLogOutInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo>`
                            
                            .. attribute:: nbr_cluster_id_info
                            
                            	Cluster ID value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nbr_cluster_id_type_info
                            
                            	Cluster ID Type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: nbr_enforce_first_as_info
                            
                            	Neighbor enforce first AS info
                            	**type**\:   :py:class:`NbrEnforceFirstAsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo>`
                            
                            .. attribute:: nbr_enforce_first_as_status
                            
                            	Neighbor enforce first AS status
                            	**type**\:  bool
                            
                            .. attribute:: nbr_restart_time
                            
                            	Restart time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nbr_restart_time_info
                            
                            	Restart time item info
                            	**type**\:   :py:class:`NbrRestartTimeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo>`
                            
                            .. attribute:: nbr_stale_path_time
                            
                            	Stale\-path time(in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nbr_stale_path_time_info
                            
                            	Stale\-path time item info
                            	**type**\:   :py:class:`NbrStalePathTimeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo>`
                            
                            .. attribute:: neighbor_remote_as_list_group_name
                            
                            	Neighbor Range remote\-as\-list group name
                            	**type**\:  str
                            
                            .. attribute:: neighbor_remote_as_list_info
                            
                            	Neighbor range  remote\-as\-list group info
                            	**type**\:   :py:class:`NeighborRemoteAsListInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo>`
                            
                            .. attribute:: neighbor_update_filter_attribute_filter_group_name
                            
                            	Neighbor filter attribute\-filter group name
                            	**type**\:  str
                            
                            .. attribute:: neighbor_update_filter_attribute_info
                            
                            	Neighbor update filter attribute\-filter group info
                            	**type**\:   :py:class:`NeighborUpdateFilterAttributeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo>`
                            
                            .. attribute:: neighbor_update_filter_exists
                            
                            	Indicates if neighbor filter configuration exists
                            	**type**\:  bool
                            
                            .. attribute:: neighbor_update_filter_exists_info
                            
                            	Neighbor update filter configuration info
                            	**type**\:   :py:class:`NeighborUpdateFilterExistsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo>`
                            
                            .. attribute:: neighbor_update_filter_logging_disable
                            
                            	Indicates if neighbor filter logging is disabled
                            	**type**\:  bool
                            
                            .. attribute:: neighbor_update_filter_message_buffer_count
                            
                            	Count of neighbor filter message buffers
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_update_filter_message_buffer_count_info
                            
                            	Neighbor update filter message buffer count info
                            	**type**\:   :py:class:`NeighborUpdateFilterMessageBufferCountInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo>`
                            
                            .. attribute:: neighbor_update_filter_message_buffer_is_non_circular
                            
                            	Indicates if neighbor update filter message buffer is circular or not
                            	**type**\:  bool
                            
                            .. attribute:: neighbor_update_filter_syslog_disable_info
                            
                            	Neighbor update filter syslog disable info
                            	**type**\:   :py:class:`NeighborUpdateFilterSyslogDisableInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo>`
                            
                            .. attribute:: nsr_disabled
                            
                            	Support for NSR
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_disabled_info
                            
                            	NSR item info
                            	**type**\:   :py:class:`NsrDisabledInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo>`
                            
                            .. attribute:: password
                            
                            	Neighbor password
                            	**type**\:  str
                            
                            .. attribute:: password_info
                            
                            	Neighbor password item info
                            	**type**\:   :py:class:`PasswordInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo>`
                            
                            .. attribute:: prefix_validation_allow_invalid
                            
                            	Prefix vallidation allow invalid
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: prefix_validation_allow_invalid_info
                            
                            	RPKI allow invalid info
                            	**type**\:   :py:class:`PrefixValidationAllowInvalidInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo>`
                            
                            .. attribute:: prefix_validation_disable
                            
                            	Prefix validation disable
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: prefix_validation_disable_info
                            
                            	RPKI disable info
                            	**type**\:   :py:class:`PrefixValidationDisableInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo>`
                            
                            .. attribute:: prefix_validation_signal_ibgp
                            
                            	Prefix validation signal ibgp
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: prefix_validation_signal_ibgp_info
                            
                            	RPKI signal ibgp info
                            	**type**\:   :py:class:`PrefixValidationSignalIbgpInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo>`
                            
                            .. attribute:: prefix_validation_use_validit_info
                            
                            	RPKI use validity
                            	**type**\:   :py:class:`PrefixValidationUseValiditInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo>`
                            
                            .. attribute:: receive_buffer_info
                            
                            	Receive buffer sizes item info
                            	**type**\:   :py:class:`ReceiveBufferInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo>`
                            
                            .. attribute:: remote_as_info
                            
                            	Remote AS number item info
                            	**type**\:   :py:class:`RemoteAsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo>`
                            
                            .. attribute:: remote_as_number_xx
                            
                            	First half of Remote ASN
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_as_number_yy
                            
                            	Second half of Remote ASN
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_updates_source
                            
                            	Source of routing updates
                            	**type**\:  str
                            
                            .. attribute:: send_buffer_info
                            
                            	Send buffer sizes item info
                            	**type**\:   :py:class:`SendBufferInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo>`
                            
                            .. attribute:: session_open_mode
                            
                            	TCP open mode to be used 
                            	**type**\:   :py:class:`BgpTcpModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpModeEnum>`
                            
                            .. attribute:: session_open_mode_info
                            
                            	TCP conn open mode info
                            	**type**\:   :py:class:`SessionOpenModeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo>`
                            
                            .. attribute:: shutdown_info
                            
                            	Shutdown item info
                            	**type**\:   :py:class:`ShutdownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo>`
                            
                            .. attribute:: socket_buffer_receive_size
                            
                            	Socket receive buffer size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: socket_buffer_send_size
                            
                            	Socket send buffer size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: speaker_id_info
                            
                            	Configured speaker ID item info
                            	**type**\:   :py:class:`SpeakerIdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo>`
                            
                            .. attribute:: suppress4_bbyte_as_info
                            
                            	BGP suppress 4byte\-as item info
                            	**type**\:   :py:class:`Suppress4BbyteAsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo>`
                            
                            .. attribute:: suppress4_byte_as
                            
                            	Suppress BGP 4byteas Cap
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tcp_mss
                            
                            	Maximum Segment Size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tcpmss_info
                            
                            	TCP Maximum Segment Size item info
                            	**type**\:   :py:class:`TcpmssInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo>`
                            
                            .. attribute:: timers_info
                            
                            	Timers item info
                            	**type**\:   :py:class:`TimersInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo>`
                            
                            .. attribute:: tos_info
                            
                            	TOS item info
                            	**type**\:   :py:class:`TosInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo>`
                            
                            .. attribute:: tos_type_info
                            
                            	Precedence or DSCP type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tos_value_info
                            
                            	Precedence or DSCP value
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ttl_security
                            
                            	Enable BGP TTL Security
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ttl_security_info
                            
                            	BGP TTL Security item info
                            	**type**\:   :py:class:`TtlSecurityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo>`
                            
                            .. attribute:: update_error_handling_no_reset
                            
                            	Indicates if avoid\-reset behavior is enabled during update error\-handling
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_error_handling_no_reset_info
                            
                            	Error\-handling avoid\-reset config info
                            	**type**\:   :py:class:`UpdateErrorHandlingNoResetInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo>`
                            
                            .. attribute:: update_source_info
                            
                            	Update source item info
                            	**type**\:   :py:class:`UpdateSourceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.addpath_receive_capability = None
                                self.addpath_receive_capability_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo()
                                self.addpath_receive_capability_info.parent = self
                                self.addpath_send_capability = None
                                self.addpath_send_capability_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo()
                                self.addpath_send_capability_info.parent = self
                                self.adminstrative_shutdown = None
                                self.bestpath_use_origin_as_validity = None
                                self.bfd = None
                                self.bfd_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo()
                                self.bfd_info.parent = self
                                self.bfd_mininterval = None
                                self.bfd_mininterval_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo()
                                self.bfd_mininterval_info.parent = self
                                self.bfd_multiplier = None
                                self.bfd_multiplier_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo()
                                self.bfd_multiplier_info.parent = self
                                self.bgp_buffer_receive_size = None
                                self.bgp_buffer_send_size = None
                                self.bmp_servers = None
                                self.bmp_servers_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo()
                                self.bmp_servers_info.parent = self
                                self.capability_negotiation_suppressed = None
                                self.capability_negotiation_suppressed_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo()
                                self.capability_negotiation_suppressed_info.parent = self
                                self.cluster_id_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo()
                                self.cluster_id_info.parent = self
                                self.configured_speaker_id = None
                                self.description = None
                                self.description_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo()
                                self.description_info.parent = self
                                self.dmz_link_bandwidth = None
                                self.dmz_link_bandwidth_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo()
                                self.dmz_link_bandwidth_info.parent = self
                                self.ebgp_hop_count = None
                                self.ebgp_hop_count_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo()
                                self.ebgp_hop_count_info.parent = self
                                self.ebgp_recv_dmz = None
                                self.ebgp_recv_dmz_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo()
                                self.ebgp_recv_dmz_info.parent = self
                                self.ebgp_send_dmz_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo()
                                self.ebgp_send_dmz_info.parent = self
                                self.ebgp_send_dmz_mode = None
                                self.egress_peer_engineering = None
                                self.egress_peer_engineering_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo()
                                self.egress_peer_engineering_info.parent = self
                                self.graceful_restart_disabled = None
                                self.graceful_restart_disabled_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo()
                                self.graceful_restart_disabled_info.parent = self
                                self.graceful_shutdown_activate = None
                                self.graceful_shutdown_activate_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo()
                                self.graceful_shutdown_activate_info.parent = self
                                self.graceful_shutdown_as_prepends = None
                                self.graceful_shutdown_as_prepends_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo()
                                self.graceful_shutdown_as_prepends_info.parent = self
                                self.graceful_shutdown_exists = None
                                self.graceful_shutdown_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo()
                                self.graceful_shutdown_info.parent = self
                                self.graceful_shutdown_loc_pref = None
                                self.graceful_shutdown_loc_pref_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo()
                                self.graceful_shutdown_loc_pref_info.parent = self
                                self.hold_time_value = None
                                self.idle_watch_time = None
                                self.idle_watch_time_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo()
                                self.idle_watch_time_info.parent = self
                                self.ignore_connected_check = None
                                self.ignore_connected_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo()
                                self.ignore_connected_info.parent = self
                                self.internal_vpn_client = None
                                self.internal_vpn_client_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo()
                                self.internal_vpn_client_info.parent = self
                                self.is_ebgp_multihop_bgpmpls_forwarding_disabled = None
                                self.keepalive_interval = None
                                self.keychain = None
                                self.keychain_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo()
                                self.keychain_info.parent = self
                                self.local_address_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo()
                                self.local_address_info.parent = self
                                self.local_as_dual_as = None
                                self.local_as_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo()
                                self.local_as_info.parent = self
                                self.local_as_no_prepend = None
                                self.local_as_number_xx = None
                                self.local_as_number_yy = None
                                self.local_as_replace_as = None
                                self.local_ip_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress()
                                self.local_ip_address.parent = self
                                self.max_peers = None
                                self.max_peers_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo()
                                self.max_peers_info.parent = self
                                self.min_acc_hold_time_value = None
                                self.min_advertisement_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo()
                                self.min_advertisement_info.parent = self
                                self.min_advertisement_interval = None
                                self.min_advertisement_interval_msecs = None
                                self.msg_log_in_buf_count = None
                                self.msg_log_in_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo()
                                self.msg_log_in_info.parent = self
                                self.msg_log_out_buf_count = None
                                self.msg_log_out_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo()
                                self.msg_log_out_info.parent = self
                                self.nbr_cluster_id_info = None
                                self.nbr_cluster_id_type_info = None
                                self.nbr_enforce_first_as_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo()
                                self.nbr_enforce_first_as_info.parent = self
                                self.nbr_enforce_first_as_status = None
                                self.nbr_restart_time = None
                                self.nbr_restart_time_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo()
                                self.nbr_restart_time_info.parent = self
                                self.nbr_stale_path_time = None
                                self.nbr_stale_path_time_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo()
                                self.nbr_stale_path_time_info.parent = self
                                self.neighbor_remote_as_list_group_name = None
                                self.neighbor_remote_as_list_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo()
                                self.neighbor_remote_as_list_info.parent = self
                                self.neighbor_update_filter_attribute_filter_group_name = None
                                self.neighbor_update_filter_attribute_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo()
                                self.neighbor_update_filter_attribute_info.parent = self
                                self.neighbor_update_filter_exists = None
                                self.neighbor_update_filter_exists_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo()
                                self.neighbor_update_filter_exists_info.parent = self
                                self.neighbor_update_filter_logging_disable = None
                                self.neighbor_update_filter_message_buffer_count = None
                                self.neighbor_update_filter_message_buffer_count_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo()
                                self.neighbor_update_filter_message_buffer_count_info.parent = self
                                self.neighbor_update_filter_message_buffer_is_non_circular = None
                                self.neighbor_update_filter_syslog_disable_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo()
                                self.neighbor_update_filter_syslog_disable_info.parent = self
                                self.nsr_disabled = None
                                self.nsr_disabled_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo()
                                self.nsr_disabled_info.parent = self
                                self.password = None
                                self.password_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo()
                                self.password_info.parent = self
                                self.prefix_validation_allow_invalid = None
                                self.prefix_validation_allow_invalid_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo()
                                self.prefix_validation_allow_invalid_info.parent = self
                                self.prefix_validation_disable = None
                                self.prefix_validation_disable_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo()
                                self.prefix_validation_disable_info.parent = self
                                self.prefix_validation_signal_ibgp = None
                                self.prefix_validation_signal_ibgp_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo()
                                self.prefix_validation_signal_ibgp_info.parent = self
                                self.prefix_validation_use_validit_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo()
                                self.prefix_validation_use_validit_info.parent = self
                                self.receive_buffer_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo()
                                self.receive_buffer_info.parent = self
                                self.remote_as_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo()
                                self.remote_as_info.parent = self
                                self.remote_as_number_xx = None
                                self.remote_as_number_yy = None
                                self.route_updates_source = None
                                self.send_buffer_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo()
                                self.send_buffer_info.parent = self
                                self.session_open_mode = None
                                self.session_open_mode_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo()
                                self.session_open_mode_info.parent = self
                                self.shutdown_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo()
                                self.shutdown_info.parent = self
                                self.socket_buffer_receive_size = None
                                self.socket_buffer_send_size = None
                                self.speaker_id_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo()
                                self.speaker_id_info.parent = self
                                self.suppress4_bbyte_as_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo()
                                self.suppress4_bbyte_as_info.parent = self
                                self.suppress4_byte_as = None
                                self.tcp_mss = None
                                self.tcpmss_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo()
                                self.tcpmss_info.parent = self
                                self.timers_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo()
                                self.timers_info.parent = self
                                self.tos_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo()
                                self.tos_info.parent = self
                                self.tos_type_info = None
                                self.tos_value_info = None
                                self.ttl_security = None
                                self.ttl_security_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo()
                                self.ttl_security_info.parent = self
                                self.update_error_handling_no_reset = None
                                self.update_error_handling_no_reset_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo()
                                self.update_error_handling_no_reset_info.parent = self
                                self.update_source_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo()
                                self.update_source_info.parent = self


                            class LocalIpAddress(object):
                                """
                                Local ipv4 or ipv6 address for neighbor
                                connection
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpnvpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2VpnvplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4mdt_address = None
                                    self.ipv4mvpn_address = None
                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv4SrPolicyAddress()
                                    self.ipv4sr_policy_address.parent = self
                                    self.ipv4vpn_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv6SrPolicyAddress()
                                    self.ipv6sr_policy_address.parent = self
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_flowspec_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.l2vpn_evpn_address = None
                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2VpnvplsAddress()
                                    self.l2vpnvpls_address.parent = self
                                    self.ls_ls_address = None
                                    self.rt_constraint_address = None


                                class L2VpnvplsAddress(object):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2VpnvplsAddress']['meta_info']


                                class L2VpnMspwAddress(object):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2VpnMspwAddress']['meta_info']


                                class Ipv4SrPolicyAddress(object):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv4SrPolicyAddress']['meta_info']


                                class Ipv6SrPolicyAddress(object):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv6_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv6_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv6SrPolicyAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-ip-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.afi is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv4_flowspec_address is not None:
                                        return True

                                    if self.ipv4_label_address is not None:
                                        return True

                                    if self.ipv4_mcast_address is not None:
                                        return True

                                    if self.ipv4_tunnel_address is not None:
                                        return True

                                    if self.ipv4mdt_address is not None:
                                        return True

                                    if self.ipv4mvpn_address is not None:
                                        return True

                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                        return True

                                    if self.ipv4vpn_address is not None:
                                        return True

                                    if self.ipv4vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv4vpna_mcastddress is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    if self.ipv6_flowspec_address is not None:
                                        return True

                                    if self.ipv6_label_address is not None:
                                        return True

                                    if self.ipv6_mcast_address is not None:
                                        return True

                                    if self.ipv6mvpn_address is not None:
                                        return True

                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                        return True

                                    if self.ipv6vpn_address is not None:
                                        return True

                                    if self.ipv6vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv6vpn_mcast_address is not None:
                                        return True

                                    if self.l2vpn_evpn_address is not None:
                                        return True

                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                        return True

                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                        return True

                                    if self.ls_ls_address is not None:
                                        return True

                                    if self.rt_constraint_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress']['meta_info']


                            class RemoteAsInfo(object):
                                """
                                Remote AS number item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:remote-as-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo']['meta_info']


                            class SpeakerIdInfo(object):
                                """
                                Configured speaker ID item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:speaker-id-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo']['meta_info']


                            class MinAdvertisementInfo(object):
                                """
                                Minimum advertisement interval item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:min-advertisement-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo']['meta_info']


                            class DescriptionInfo(object):
                                """
                                Description item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:description-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo']['meta_info']


                            class EbgpHopCountInfo(object):
                                """
                                EBGP neighbors hop count item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ebgp-hop-count-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo']['meta_info']


                            class TcpmssInfo(object):
                                """
                                TCP Maximum Segment Size item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tcpmss-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo']['meta_info']


                            class BmpServersInfo(object):
                                """
                                BMP Servers Configuredinfo
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-servers-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo']['meta_info']


                            class KeychainInfo(object):
                                """
                                Neighbor Keychain item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:keychain-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo']['meta_info']


                            class LocalAsInfo(object):
                                """
                                Local AS number item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-as-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo']['meta_info']


                            class PasswordInfo(object):
                                """
                                Neighbor password item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:password-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo']['meta_info']


                            class ReceiveBufferInfo(object):
                                """
                                Receive buffer sizes item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:receive-buffer-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo']['meta_info']


                            class SendBufferInfo(object):
                                """
                                Send buffer sizes item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:send-buffer-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo']['meta_info']


                            class ShutdownInfo(object):
                                """
                                Shutdown item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:shutdown-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo']['meta_info']


                            class TimersInfo(object):
                                """
                                Timers item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:timers-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo']['meta_info']


                            class LocalAddressInfo(object):
                                """
                                Local address item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-address-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo']['meta_info']


                            class MsgLogInInfo(object):
                                """
                                Message Log Inbound item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:msg-log-in-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo']['meta_info']


                            class MsgLogOutInfo(object):
                                """
                                Message Log Outbound item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:msg-log-out-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo']['meta_info']


                            class UpdateSourceInfo(object):
                                """
                                Update source item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-source-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo']['meta_info']


                            class DmzLinkBandwidthInfo(object):
                                """
                                DMZ link bandwidth item 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:dmz-link-bandwidth-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo']['meta_info']


                            class EbgpRecvDmzInfo(object):
                                """
                                EBGP receive DMZ link bandwidth item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ebgp-recv-dmz-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo']['meta_info']


                            class EbgpSendDmzInfo(object):
                                """
                                EBGP send DMZ link bandwidth item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ebgp-send-dmz-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo']['meta_info']


                            class TtlSecurityInfo(object):
                                """
                                BGP TTL Security item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ttl-security-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo']['meta_info']


                            class Suppress4BbyteAsInfo(object):
                                """
                                BGP suppress 4byte\-as item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:suppress4-bbyte-as-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo']['meta_info']


                            class SessionOpenModeInfo(object):
                                """
                                TCP conn open mode info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:session-open-mode-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo']['meta_info']


                            class BfdInfo(object):
                                """
                                BFD item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bfd-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo']['meta_info']


                            class BfdMinintervalInfo(object):
                                """
                                BFD Mininterval item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bfd-mininterval-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo']['meta_info']


                            class BfdMultiplierInfo(object):
                                """
                                BFD Multiplier item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bfd-multiplier-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo']['meta_info']


                            class TosInfo(object):
                                """
                                TOS item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tos-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo']['meta_info']


                            class NsrDisabledInfo(object):
                                """
                                NSR item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nsr-disabled-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo']['meta_info']


                            class GracefulRestartDisabledInfo(object):
                                """
                                Graceful\-restart item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:graceful-restart-disabled-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo']['meta_info']


                            class NbrRestartTimeInfo(object):
                                """
                                Restart time item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nbr-restart-time-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo']['meta_info']


                            class NbrStalePathTimeInfo(object):
                                """
                                Stale\-path time item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nbr-stale-path-time-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo']['meta_info']


                            class NbrEnforceFirstAsInfo(object):
                                """
                                Neighbor enforce first AS info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nbr-enforce-first-as-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo']['meta_info']


                            class ClusterIdInfo(object):
                                """
                                Cluster ID item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster-id-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo']['meta_info']


                            class IgnoreConnectedInfo(object):
                                """
                                Ignore Connected Info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ignore-connected-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo']['meta_info']


                            class InternalVpnClientInfo(object):
                                """
                                Internal VPN Client Info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:internal-vpn-client-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo']['meta_info']


                            class AddpathSendCapabilityInfo(object):
                                """
                                Addpath send capability info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:addpath-send-capability-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo']['meta_info']


                            class AddpathReceiveCapabilityInfo(object):
                                """
                                Addpath receive capability info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:addpath-receive-capability-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo']['meta_info']


                            class EgressPeerEngineeringInfo(object):
                                """
                                Egress Peer Engineering info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:egress-peer-engineering-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo']['meta_info']


                            class UpdateErrorHandlingNoResetInfo(object):
                                """
                                Error\-handling avoid\-reset config info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-error-handling-no-reset-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo']['meta_info']


                            class PrefixValidationDisableInfo(object):
                                """
                                RPKI disable info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix-validation-disable-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo']['meta_info']


                            class PrefixValidationUseValiditInfo(object):
                                """
                                RPKI use validity
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix-validation-use-validit-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo']['meta_info']


                            class PrefixValidationAllowInvalidInfo(object):
                                """
                                RPKI allow invalid info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix-validation-allow-invalid-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo']['meta_info']


                            class PrefixValidationSignalIbgpInfo(object):
                                """
                                RPKI signal ibgp info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix-validation-signal-ibgp-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo']['meta_info']


                            class NeighborUpdateFilterExistsInfo(object):
                                """
                                Neighbor update filter configuration info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-update-filter-exists-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo']['meta_info']


                            class NeighborUpdateFilterMessageBufferCountInfo(object):
                                """
                                Neighbor update filter message buffer count info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-update-filter-message-buffer-count-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo']['meta_info']


                            class NeighborUpdateFilterSyslogDisableInfo(object):
                                """
                                Neighbor update filter syslog disable info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-update-filter-syslog-disable-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo']['meta_info']


                            class NeighborUpdateFilterAttributeInfo(object):
                                """
                                Neighbor update filter attribute\-filter group
                                info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-update-filter-attribute-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo']['meta_info']


                            class GracefulShutdownInfo(object):
                                """
                                GracefulShutdown info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:graceful-shutdown-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo']['meta_info']


                            class GracefulShutdownLocPrefInfo(object):
                                """
                                GracefulShutdownLocPref info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:graceful-shutdown-loc-pref-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo']['meta_info']


                            class GracefulShutdownAsPrependsInfo(object):
                                """
                                GracefulShutdownASPrepends info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:graceful-shutdown-as-prepends-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo']['meta_info']


                            class GracefulShutdownActivateInfo(object):
                                """
                                GracefulShutdownAcivate info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:graceful-shutdown-activate-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo']['meta_info']


                            class CapabilityNegotiationSuppressedInfo(object):
                                """
                                Capability negotiation suppressed info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:capability-negotiation-suppressed-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo']['meta_info']


                            class NeighborRemoteAsListInfo(object):
                                """
                                Neighbor range  remote\-as\-list group info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-remote-as-list-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo']['meta_info']


                            class MaxPeersInfo(object):
                                """
                                Max dynamic nbrs in range info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:max-peers-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo']['meta_info']


                            class IdleWatchTimeInfo(object):
                                """
                                Idle Watch time item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:idle-watch-time-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af-independent-config'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.addpath_receive_capability is not None:
                                    return True

                                if self.addpath_receive_capability_info is not None and self.addpath_receive_capability_info._has_data():
                                    return True

                                if self.addpath_send_capability is not None:
                                    return True

                                if self.addpath_send_capability_info is not None and self.addpath_send_capability_info._has_data():
                                    return True

                                if self.adminstrative_shutdown is not None:
                                    return True

                                if self.bestpath_use_origin_as_validity is not None:
                                    return True

                                if self.bfd is not None:
                                    return True

                                if self.bfd_info is not None and self.bfd_info._has_data():
                                    return True

                                if self.bfd_mininterval is not None:
                                    return True

                                if self.bfd_mininterval_info is not None and self.bfd_mininterval_info._has_data():
                                    return True

                                if self.bfd_multiplier is not None:
                                    return True

                                if self.bfd_multiplier_info is not None and self.bfd_multiplier_info._has_data():
                                    return True

                                if self.bgp_buffer_receive_size is not None:
                                    return True

                                if self.bgp_buffer_send_size is not None:
                                    return True

                                if self.bmp_servers is not None:
                                    return True

                                if self.bmp_servers_info is not None and self.bmp_servers_info._has_data():
                                    return True

                                if self.capability_negotiation_suppressed is not None:
                                    return True

                                if self.capability_negotiation_suppressed_info is not None and self.capability_negotiation_suppressed_info._has_data():
                                    return True

                                if self.cluster_id_info is not None and self.cluster_id_info._has_data():
                                    return True

                                if self.configured_speaker_id is not None:
                                    return True

                                if self.description is not None:
                                    return True

                                if self.description_info is not None and self.description_info._has_data():
                                    return True

                                if self.dmz_link_bandwidth is not None:
                                    return True

                                if self.dmz_link_bandwidth_info is not None and self.dmz_link_bandwidth_info._has_data():
                                    return True

                                if self.ebgp_hop_count is not None:
                                    return True

                                if self.ebgp_hop_count_info is not None and self.ebgp_hop_count_info._has_data():
                                    return True

                                if self.ebgp_recv_dmz is not None:
                                    return True

                                if self.ebgp_recv_dmz_info is not None and self.ebgp_recv_dmz_info._has_data():
                                    return True

                                if self.ebgp_send_dmz_info is not None and self.ebgp_send_dmz_info._has_data():
                                    return True

                                if self.ebgp_send_dmz_mode is not None:
                                    return True

                                if self.egress_peer_engineering is not None:
                                    return True

                                if self.egress_peer_engineering_info is not None and self.egress_peer_engineering_info._has_data():
                                    return True

                                if self.graceful_restart_disabled is not None:
                                    return True

                                if self.graceful_restart_disabled_info is not None and self.graceful_restart_disabled_info._has_data():
                                    return True

                                if self.graceful_shutdown_activate is not None:
                                    return True

                                if self.graceful_shutdown_activate_info is not None and self.graceful_shutdown_activate_info._has_data():
                                    return True

                                if self.graceful_shutdown_as_prepends is not None:
                                    return True

                                if self.graceful_shutdown_as_prepends_info is not None and self.graceful_shutdown_as_prepends_info._has_data():
                                    return True

                                if self.graceful_shutdown_exists is not None:
                                    return True

                                if self.graceful_shutdown_info is not None and self.graceful_shutdown_info._has_data():
                                    return True

                                if self.graceful_shutdown_loc_pref is not None:
                                    return True

                                if self.graceful_shutdown_loc_pref_info is not None and self.graceful_shutdown_loc_pref_info._has_data():
                                    return True

                                if self.hold_time_value is not None:
                                    return True

                                if self.idle_watch_time is not None:
                                    return True

                                if self.idle_watch_time_info is not None and self.idle_watch_time_info._has_data():
                                    return True

                                if self.ignore_connected_check is not None:
                                    return True

                                if self.ignore_connected_info is not None and self.ignore_connected_info._has_data():
                                    return True

                                if self.internal_vpn_client is not None:
                                    return True

                                if self.internal_vpn_client_info is not None and self.internal_vpn_client_info._has_data():
                                    return True

                                if self.is_ebgp_multihop_bgpmpls_forwarding_disabled is not None:
                                    return True

                                if self.keepalive_interval is not None:
                                    return True

                                if self.keychain is not None:
                                    return True

                                if self.keychain_info is not None and self.keychain_info._has_data():
                                    return True

                                if self.local_address_info is not None and self.local_address_info._has_data():
                                    return True

                                if self.local_as_dual_as is not None:
                                    return True

                                if self.local_as_info is not None and self.local_as_info._has_data():
                                    return True

                                if self.local_as_no_prepend is not None:
                                    return True

                                if self.local_as_number_xx is not None:
                                    return True

                                if self.local_as_number_yy is not None:
                                    return True

                                if self.local_as_replace_as is not None:
                                    return True

                                if self.local_ip_address is not None and self.local_ip_address._has_data():
                                    return True

                                if self.max_peers is not None:
                                    return True

                                if self.max_peers_info is not None and self.max_peers_info._has_data():
                                    return True

                                if self.min_acc_hold_time_value is not None:
                                    return True

                                if self.min_advertisement_info is not None and self.min_advertisement_info._has_data():
                                    return True

                                if self.min_advertisement_interval is not None:
                                    return True

                                if self.min_advertisement_interval_msecs is not None:
                                    return True

                                if self.msg_log_in_buf_count is not None:
                                    return True

                                if self.msg_log_in_info is not None and self.msg_log_in_info._has_data():
                                    return True

                                if self.msg_log_out_buf_count is not None:
                                    return True

                                if self.msg_log_out_info is not None and self.msg_log_out_info._has_data():
                                    return True

                                if self.nbr_cluster_id_info is not None:
                                    return True

                                if self.nbr_cluster_id_type_info is not None:
                                    return True

                                if self.nbr_enforce_first_as_info is not None and self.nbr_enforce_first_as_info._has_data():
                                    return True

                                if self.nbr_enforce_first_as_status is not None:
                                    return True

                                if self.nbr_restart_time is not None:
                                    return True

                                if self.nbr_restart_time_info is not None and self.nbr_restart_time_info._has_data():
                                    return True

                                if self.nbr_stale_path_time is not None:
                                    return True

                                if self.nbr_stale_path_time_info is not None and self.nbr_stale_path_time_info._has_data():
                                    return True

                                if self.neighbor_remote_as_list_group_name is not None:
                                    return True

                                if self.neighbor_remote_as_list_info is not None and self.neighbor_remote_as_list_info._has_data():
                                    return True

                                if self.neighbor_update_filter_attribute_filter_group_name is not None:
                                    return True

                                if self.neighbor_update_filter_attribute_info is not None and self.neighbor_update_filter_attribute_info._has_data():
                                    return True

                                if self.neighbor_update_filter_exists is not None:
                                    return True

                                if self.neighbor_update_filter_exists_info is not None and self.neighbor_update_filter_exists_info._has_data():
                                    return True

                                if self.neighbor_update_filter_logging_disable is not None:
                                    return True

                                if self.neighbor_update_filter_message_buffer_count is not None:
                                    return True

                                if self.neighbor_update_filter_message_buffer_count_info is not None and self.neighbor_update_filter_message_buffer_count_info._has_data():
                                    return True

                                if self.neighbor_update_filter_message_buffer_is_non_circular is not None:
                                    return True

                                if self.neighbor_update_filter_syslog_disable_info is not None and self.neighbor_update_filter_syslog_disable_info._has_data():
                                    return True

                                if self.nsr_disabled is not None:
                                    return True

                                if self.nsr_disabled_info is not None and self.nsr_disabled_info._has_data():
                                    return True

                                if self.password is not None:
                                    return True

                                if self.password_info is not None and self.password_info._has_data():
                                    return True

                                if self.prefix_validation_allow_invalid is not None:
                                    return True

                                if self.prefix_validation_allow_invalid_info is not None and self.prefix_validation_allow_invalid_info._has_data():
                                    return True

                                if self.prefix_validation_disable is not None:
                                    return True

                                if self.prefix_validation_disable_info is not None and self.prefix_validation_disable_info._has_data():
                                    return True

                                if self.prefix_validation_signal_ibgp is not None:
                                    return True

                                if self.prefix_validation_signal_ibgp_info is not None and self.prefix_validation_signal_ibgp_info._has_data():
                                    return True

                                if self.prefix_validation_use_validit_info is not None and self.prefix_validation_use_validit_info._has_data():
                                    return True

                                if self.receive_buffer_info is not None and self.receive_buffer_info._has_data():
                                    return True

                                if self.remote_as_info is not None and self.remote_as_info._has_data():
                                    return True

                                if self.remote_as_number_xx is not None:
                                    return True

                                if self.remote_as_number_yy is not None:
                                    return True

                                if self.route_updates_source is not None:
                                    return True

                                if self.send_buffer_info is not None and self.send_buffer_info._has_data():
                                    return True

                                if self.session_open_mode is not None:
                                    return True

                                if self.session_open_mode_info is not None and self.session_open_mode_info._has_data():
                                    return True

                                if self.shutdown_info is not None and self.shutdown_info._has_data():
                                    return True

                                if self.socket_buffer_receive_size is not None:
                                    return True

                                if self.socket_buffer_send_size is not None:
                                    return True

                                if self.speaker_id_info is not None and self.speaker_id_info._has_data():
                                    return True

                                if self.suppress4_bbyte_as_info is not None and self.suppress4_bbyte_as_info._has_data():
                                    return True

                                if self.suppress4_byte_as is not None:
                                    return True

                                if self.tcp_mss is not None:
                                    return True

                                if self.tcpmss_info is not None and self.tcpmss_info._has_data():
                                    return True

                                if self.timers_info is not None and self.timers_info._has_data():
                                    return True

                                if self.tos_info is not None and self.tos_info._has_data():
                                    return True

                                if self.tos_type_info is not None:
                                    return True

                                if self.tos_value_info is not None:
                                    return True

                                if self.ttl_security is not None:
                                    return True

                                if self.ttl_security_info is not None and self.ttl_security_info._has_data():
                                    return True

                                if self.update_error_handling_no_reset is not None:
                                    return True

                                if self.update_error_handling_no_reset_info is not None and self.update_error_handling_no_reset_info._has_data():
                                    return True

                                if self.update_source_info is not None and self.update_source_info._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig']['meta_info']


                        class AfDependentConfig(object):
                            """
                            Af\-dependent config
                            
                            .. attribute:: accept_own
                            
                            	Accept Own
                            	**type**\:  bool
                            
                            .. attribute:: accept_own_info
                            
                            	Accept\-Own info
                            	**type**\:   :py:class:`AcceptOwnInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo>`
                            
                            .. attribute:: accept_route_legacy_pe_rt
                            
                            	accept\-legacy\-pe RT route
                            	**type**\:  bool
                            
                            .. attribute:: advertise_def_vrf_imp_disable_afi_v4_info
                            
                            	Advertise Afi Info 
                            	**type**\:   :py:class:`AdvertiseDefVrfImpDisableAfiV4Info <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info>`
                            
                            .. attribute:: advertise_def_vrf_imp_disable_afi_v6_info
                            
                            	Advertise Afi Info 
                            	**type**\:   :py:class:`AdvertiseDefVrfImpDisableAfiV6Info <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info>`
                            
                            .. attribute:: advertise_def_vrf_imp_disable_v4
                            
                            	Advertise afi
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: advertise_def_vrf_imp_disable_v6
                            
                            	Advertise afi
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: advertise_dis_info
                            
                            	Advertise Afi Info 
                            	**type**\:   :py:class:`AdvertiseDisInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo>`
                            
                            .. attribute:: advertise_disable
                            
                            	Advertise afi
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: advertise_l2vpnevpn
                            
                            	Advertise afi
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: advertise_l2vpnevpn_afi_info
                            
                            	Advertise Afi Info 
                            	**type**\:   :py:class:`AdvertiseL2VpnevpnAfiInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo>`
                            
                            .. attribute:: advertise_local_labeled_route
                            
                            	Advertise routes with local\-label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: advertise_local_labeled_route_info
                            
                            	Advertise routes with local\-label
                            	**type**\:   :py:class:`AdvertiseLocalLabeledRouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo>`
                            
                            .. attribute:: advertise_v4
                            
                            	Advertise afi
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: advertise_v4_afi_info
                            
                            	Advertise Afi Info 
                            	**type**\:   :py:class:`AdvertiseV4AfiInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo>`
                            
                            .. attribute:: advertise_v6
                            
                            	Advertise afi
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: advertise_v6_afi_info
                            
                            	Advertise Afi Info 
                            	**type**\:   :py:class:`AdvertiseV6AfiInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo>`
                            
                            .. attribute:: advertise_vrf_re_imp_disable_afi_v4_info
                            
                            	Advertise Afi Info 
                            	**type**\:   :py:class:`AdvertiseVrfReImpDisableAfiV4Info <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info>`
                            
                            .. attribute:: advertise_vrf_re_imp_disable_afi_v6_info
                            
                            	Advertise Afi Info 
                            	**type**\:   :py:class:`AdvertiseVrfReImpDisableAfiV6Info <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info>`
                            
                            .. attribute:: advertise_vrf_re_imp_disable_v4
                            
                            	Advertise afi
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: advertise_vrf_re_imp_disable_v6
                            
                            	Advertise afi
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: af_enabled_info
                            
                            	Address family activate item info
                            	**type**\:   :py:class:`AfEnabledInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo>`
                            
                            .. attribute:: af_encapsulation_type_info
                            
                            	Encapsulation type Info 
                            	**type**\:   :py:class:`AfEncapsulationTypeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo>`
                            
                            .. attribute:: af_long_lived_graceful_restart_capable
                            
                            	Long\-lived graceful\-restart capable
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: af_long_lived_graceful_restart_stale_time_accept
                            
                            	Maxmimum acceptable long\-lived stale time acceptable from neighbor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: af_long_lived_graceful_restart_stale_time_send
                            
                            	Stale time to be sent in long\-lived graceful\-restart capability
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: af_long_lived_graceful_start_capable_info
                            
                            	Long\-lived\-time item info
                            	**type**\:   :py:class:`AfLongLivedGracefulStartCapableInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo>`
                            
                            .. attribute:: af_long_lived_graceful_start_stale_time_info
                            
                            	Long\-lived\-time item info
                            	**type**\:   :py:class:`AfLongLivedGracefulStartStaleTimeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo>`
                            
                            .. attribute:: aigp_cost_community_info
                            
                            	AIGP Cost Community info 
                            	**type**\:   :py:class:`AigpCostCommunityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo>`
                            
                            .. attribute:: aigp_cost_community_poi
                            
                            	Point of insertion for AIGP cost community
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: aigp_info
                            
                            	AIGP info 
                            	**type**\:   :py:class:`AigpInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo>`
                            
                            .. attribute:: aigp_med
                            
                            	AIGP MED info 
                            	**type**\:   :py:class:`AigpMed <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed>`
                            
                            .. attribute:: allowas_in_info
                            
                            	Allowas\-in item info
                            	**type**\:   :py:class:`AllowasInInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo>`
                            
                            .. attribute:: alway_use_soft_reconfig
                            
                            	Always use soft reconfig
                            	**type**\:  bool
                            
                            .. attribute:: as_override_info
                            
                            	As\-override info 
                            	**type**\:   :py:class:`AsOverrideInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo>`
                            
                            .. attribute:: client_route_reflector
                            
                            	Route\-reflector client
                            	**type**\:  bool
                            
                            .. attribute:: default_allowas
                            
                            	Default allowas\_in count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: default_originate_info
                            
                            	Default\-originate item info
                            	**type**\:   :py:class:`DefaultOriginateInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo>`
                            
                            .. attribute:: default_originate_route_policy
                            
                            	Default\-originate route policy name
                            	**type**\:  str
                            
                            .. attribute:: default_weight
                            
                            	Default weight
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: encapsulation_type
                            
                            	Encapsulation type
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: entire_aspath_in
                            
                            	Inbound private\-AS removal if the entire AS Path has private ASes
                            	**type**\:  bool
                            
                            .. attribute:: entire_aspath_out
                            
                            	Outbound private\-AS removalif the entire AS Path hasprivate ASes
                            	**type**\:  bool
                            
                            .. attribute:: fspec_valid_info
                            
                            	FSPEC Valid info
                            	**type**\:   :py:class:`FspecValidInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo>`
                            
                            .. attribute:: has_orf_capability
                            
                            	ORF capability
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: import_
                            
                            	Import
                            	**type**\:  bool
                            
                            .. attribute:: import_afi_info
                            
                            	Import Afi Info 
                            	**type**\:   :py:class:`ImportAfiInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo>`
                            
                            .. attribute:: import_reoriginate
                            
                            	Import reoriginate
                            	**type**\:  bool
                            
                            .. attribute:: import_reoriginate_stitching
                            
                            	Import reoriginate stitching RTs
                            	**type**\:  bool
                            
                            .. attribute:: import_stitching
                            
                            	Import stitching RTs
                            	**type**\:  bool
                            
                            .. attribute:: is_af_enabled
                            
                            	Entity is activated for this address family
                            	**type**\:  bool
                            
                            .. attribute:: is_aigp_cost_community_enabled
                            
                            	AIGP cost community enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_aigp_cost_community_id
                            
                            	AIGP cost community ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_aigp_cost_community_transitive
                            
                            	AIGP cost community ID is transitive
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_aigp_enabled
                            
                            	AIGP enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_aigp_med_enabled
                            
                            	AIGP to MED enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_as_override_disabled
                            
                            	Disable as override
                            	**type**\:  bool
                            
                            .. attribute:: is_default_originate_not_disabled
                            
                            	TRUE if default\-originate is not disabled
                            	**type**\:  bool
                            
                            .. attribute:: is_fspec_valid_enabled
                            
                            	FSPEC VALID enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_max_prefix_discard_extra_paths
                            
                            	Discard extra paths
                            	**type**\:  bool
                            
                            .. attribute:: is_max_prefix_warn_only
                            
                            	Warning messages only
                            	**type**\:  bool
                            
                            .. attribute:: is_next_hop_self_disabled
                            
                            	Disable next\-hop calc
                            	**type**\:  bool
                            
                            .. attribute:: is_next_hop_unchanged
                            
                            	Don't change next\-hop
                            	**type**\:  bool
                            
                            .. attribute:: is_next_hop_unchanged_mpath
                            
                            	Don't change mpath next\-hop
                            	**type**\:  bool
                            
                            .. attribute:: is_send_mcast_attr_enabled
                            
                            	Send mcast attr enabled
                            	**type**\:  bool
                            
                            .. attribute:: legacy_pe_rt_info
                            
                            	Accept\-legacy\-pe\-RT item info
                            	**type**\:   :py:class:`LegacyPeRtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo>`
                            
                            .. attribute:: max_prefix_restart_time
                            
                            	Restart time Value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_prefix_warn_threshold
                            
                            	Warning message threshhold
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_prefixes
                            
                            	Maximum prefixes to accept
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_prefixes_info
                            
                            	Maximum prefixes to accept item info
                            	**type**\:   :py:class:`MaxPrefixesInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo>`
                            
                            .. attribute:: multipath
                            
                            	multipath
                            	**type**\:  bool
                            
                            .. attribute:: multipath_info
                            
                            	Multipath info
                            	**type**\:   :py:class:`MultipathInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo>`
                            
                            .. attribute:: next_hop_self_info
                            
                            	Next hop self item info
                            	**type**\:   :py:class:`NextHopSelfInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo>`
                            
                            .. attribute:: next_hop_unchanged_info
                            
                            	Next hop unchanged info
                            	**type**\:   :py:class:`NextHopUnchangedInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo>`
                            
                            .. attribute:: next_hop_unchanged_mpath_info
                            
                            	Next hop unchanged mpath info
                            	**type**\:   :py:class:`NextHopUnchangedMpathInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo>`
                            
                            .. attribute:: orf_capability_info
                            
                            	ORF capability item info
                            	**type**\:   :py:class:`OrfCapabilityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo>`
                            
                            .. attribute:: orr_info
                            
                            	Orr item info
                            	**type**\:   :py:class:`OrrInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo>`
                            
                            .. attribute:: orr_root_address
                            
                            	ORR Root Address
                            	**type**\:   :py:class:`OrrRootAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress>`
                            
                            .. attribute:: permanent_network
                            
                            	Permanent Network
                            	**type**\:  bool
                            
                            .. attribute:: permanent_network_info
                            
                            	Permanent network Info 
                            	**type**\:   :py:class:`PermanentNetworkInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo>`
                            
                            .. attribute:: prefix_filter_info
                            
                            	Inbound prefix based filter item info
                            	**type**\:   :py:class:`PrefixFilterInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo>`
                            
                            .. attribute:: prefix_orf_filter
                            
                            	Inbound prefix based filter
                            	**type**\:  str
                            
                            .. attribute:: remove_private_as_in_info
                            
                            	Inbound private\-AS removal item info
                            	**type**\:   :py:class:`RemovePrivateAsInInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo>`
                            
                            .. attribute:: remove_private_as_info
                            
                            	Outbound private\-AS removal item info
                            	**type**\:   :py:class:`RemovePrivateAsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo>`
                            
                            .. attribute:: remove_private_as_out
                            
                            	Outbound private\-AS removal
                            	**type**\:  bool
                            
                            .. attribute:: remove_private_asin
                            
                            	Inbound private\-AS removal
                            	**type**\:  bool
                            
                            .. attribute:: route_policy_in
                            
                            	Inbound route policy name
                            	**type**\:  str
                            
                            .. attribute:: route_policy_in_info
                            
                            	Inbound route policy item info
                            	**type**\:   :py:class:`RoutePolicyInInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo>`
                            
                            .. attribute:: route_policy_out
                            
                            	Outbound route policy name
                            	**type**\:  str
                            
                            .. attribute:: route_policy_out_info
                            
                            	Outbound route policy item info
                            	**type**\:   :py:class:`RoutePolicyOutInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo>`
                            
                            .. attribute:: route_reflector_info
                            
                            	Route\-reflector client item info
                            	**type**\:   :py:class:`RouteReflectorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo>`
                            
                            .. attribute:: send_community_attribute
                            
                            	Send community attribute
                            	**type**\:  bool
                            
                            .. attribute:: send_community_info
                            
                            	Send community attribute item info
                            	**type**\:   :py:class:`SendCommunityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo>`
                            
                            .. attribute:: send_extended_community_attribute
                            
                            	Send extended community attribute
                            	**type**\:  bool
                            
                            .. attribute:: send_extended_community_info
                            
                            	Send extended community  item info
                            	**type**\:   :py:class:`SendExtendedCommunityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo>`
                            
                            .. attribute:: send_graceful_shut_community_attributes
                            
                            	Send Graceful shutdown related community attributes
                            	**type**\:  bool
                            
                            .. attribute:: send_graceful_shutdown_community_info
                            
                            	Send Graceful shutdown related community attribute item info
                            	**type**\:   :py:class:`SendGracefulShutdownCommunityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo>`
                            
                            .. attribute:: send_mcast_attr_info
                            
                            	Send mcast attr info
                            	**type**\:   :py:class:`SendMcastAttrInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo>`
                            
                            .. attribute:: site_of_origin
                            
                            	Site of Origin
                            	**type**\:  str
                            
                            .. attribute:: so_o_info
                            
                            	BGP Site\-of\-Origin info
                            	**type**\:   :py:class:`SoOInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo>`
                            
                            .. attribute:: soft_reconfig_info
                            
                            	Soft reconf item info
                            	**type**\:   :py:class:`SoftReconfigInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo>`
                            
                            .. attribute:: soft_reconfig_not_disabled
                            
                            	TRUE if soft reconf is not disabled
                            	**type**\:  bool
                            
                            .. attribute:: weight_info
                            
                            	Default weight item info
                            	**type**\:   :py:class:`WeightInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.accept_own = None
                                self.accept_own_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo()
                                self.accept_own_info.parent = self
                                self.accept_route_legacy_pe_rt = None
                                self.advertise_def_vrf_imp_disable_afi_v4_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info()
                                self.advertise_def_vrf_imp_disable_afi_v4_info.parent = self
                                self.advertise_def_vrf_imp_disable_afi_v6_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info()
                                self.advertise_def_vrf_imp_disable_afi_v6_info.parent = self
                                self.advertise_def_vrf_imp_disable_v4 = None
                                self.advertise_def_vrf_imp_disable_v6 = None
                                self.advertise_dis_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo()
                                self.advertise_dis_info.parent = self
                                self.advertise_disable = None
                                self.advertise_l2vpnevpn = None
                                self.advertise_l2vpnevpn_afi_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo()
                                self.advertise_l2vpnevpn_afi_info.parent = self
                                self.advertise_local_labeled_route = None
                                self.advertise_local_labeled_route_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo()
                                self.advertise_local_labeled_route_info.parent = self
                                self.advertise_v4 = None
                                self.advertise_v4_afi_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo()
                                self.advertise_v4_afi_info.parent = self
                                self.advertise_v6 = None
                                self.advertise_v6_afi_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo()
                                self.advertise_v6_afi_info.parent = self
                                self.advertise_vrf_re_imp_disable_afi_v4_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info()
                                self.advertise_vrf_re_imp_disable_afi_v4_info.parent = self
                                self.advertise_vrf_re_imp_disable_afi_v6_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info()
                                self.advertise_vrf_re_imp_disable_afi_v6_info.parent = self
                                self.advertise_vrf_re_imp_disable_v4 = None
                                self.advertise_vrf_re_imp_disable_v6 = None
                                self.af_enabled_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo()
                                self.af_enabled_info.parent = self
                                self.af_encapsulation_type_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo()
                                self.af_encapsulation_type_info.parent = self
                                self.af_long_lived_graceful_restart_capable = None
                                self.af_long_lived_graceful_restart_stale_time_accept = None
                                self.af_long_lived_graceful_restart_stale_time_send = None
                                self.af_long_lived_graceful_start_capable_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo()
                                self.af_long_lived_graceful_start_capable_info.parent = self
                                self.af_long_lived_graceful_start_stale_time_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo()
                                self.af_long_lived_graceful_start_stale_time_info.parent = self
                                self.aigp_cost_community_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo()
                                self.aigp_cost_community_info.parent = self
                                self.aigp_cost_community_poi = None
                                self.aigp_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo()
                                self.aigp_info.parent = self
                                self.aigp_med = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed()
                                self.aigp_med.parent = self
                                self.allowas_in_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo()
                                self.allowas_in_info.parent = self
                                self.alway_use_soft_reconfig = None
                                self.as_override_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo()
                                self.as_override_info.parent = self
                                self.client_route_reflector = None
                                self.default_allowas = None
                                self.default_originate_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo()
                                self.default_originate_info.parent = self
                                self.default_originate_route_policy = None
                                self.default_weight = None
                                self.encapsulation_type = None
                                self.entire_aspath_in = None
                                self.entire_aspath_out = None
                                self.fspec_valid_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo()
                                self.fspec_valid_info.parent = self
                                self.has_orf_capability = None
                                self.import_ = None
                                self.import_afi_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo()
                                self.import_afi_info.parent = self
                                self.import_reoriginate = None
                                self.import_reoriginate_stitching = None
                                self.import_stitching = None
                                self.is_af_enabled = None
                                self.is_aigp_cost_community_enabled = None
                                self.is_aigp_cost_community_id = None
                                self.is_aigp_cost_community_transitive = None
                                self.is_aigp_enabled = None
                                self.is_aigp_med_enabled = None
                                self.is_as_override_disabled = None
                                self.is_default_originate_not_disabled = None
                                self.is_fspec_valid_enabled = None
                                self.is_max_prefix_discard_extra_paths = None
                                self.is_max_prefix_warn_only = None
                                self.is_next_hop_self_disabled = None
                                self.is_next_hop_unchanged = None
                                self.is_next_hop_unchanged_mpath = None
                                self.is_send_mcast_attr_enabled = None
                                self.legacy_pe_rt_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo()
                                self.legacy_pe_rt_info.parent = self
                                self.max_prefix_restart_time = None
                                self.max_prefix_warn_threshold = None
                                self.max_prefixes = None
                                self.max_prefixes_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo()
                                self.max_prefixes_info.parent = self
                                self.multipath = None
                                self.multipath_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo()
                                self.multipath_info.parent = self
                                self.next_hop_self_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo()
                                self.next_hop_self_info.parent = self
                                self.next_hop_unchanged_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo()
                                self.next_hop_unchanged_info.parent = self
                                self.next_hop_unchanged_mpath_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo()
                                self.next_hop_unchanged_mpath_info.parent = self
                                self.orf_capability_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo()
                                self.orf_capability_info.parent = self
                                self.orr_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo()
                                self.orr_info.parent = self
                                self.orr_root_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress()
                                self.orr_root_address.parent = self
                                self.permanent_network = None
                                self.permanent_network_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo()
                                self.permanent_network_info.parent = self
                                self.prefix_filter_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo()
                                self.prefix_filter_info.parent = self
                                self.prefix_orf_filter = None
                                self.remove_private_as_in_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo()
                                self.remove_private_as_in_info.parent = self
                                self.remove_private_as_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo()
                                self.remove_private_as_info.parent = self
                                self.remove_private_as_out = None
                                self.remove_private_asin = None
                                self.route_policy_in = None
                                self.route_policy_in_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo()
                                self.route_policy_in_info.parent = self
                                self.route_policy_out = None
                                self.route_policy_out_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo()
                                self.route_policy_out_info.parent = self
                                self.route_reflector_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo()
                                self.route_reflector_info.parent = self
                                self.send_community_attribute = None
                                self.send_community_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo()
                                self.send_community_info.parent = self
                                self.send_extended_community_attribute = None
                                self.send_extended_community_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo()
                                self.send_extended_community_info.parent = self
                                self.send_graceful_shut_community_attributes = None
                                self.send_graceful_shutdown_community_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo()
                                self.send_graceful_shutdown_community_info.parent = self
                                self.send_mcast_attr_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo()
                                self.send_mcast_attr_info.parent = self
                                self.site_of_origin = None
                                self.so_o_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo()
                                self.so_o_info.parent = self
                                self.soft_reconfig_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo()
                                self.soft_reconfig_info.parent = self
                                self.soft_reconfig_not_disabled = None
                                self.weight_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo()
                                self.weight_info.parent = self


                            class OrrRootAddress(object):
                                """
                                ORR Root Address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpnvpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2VpnvplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4mdt_address = None
                                    self.ipv4mvpn_address = None
                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv4SrPolicyAddress()
                                    self.ipv4sr_policy_address.parent = self
                                    self.ipv4vpn_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv6SrPolicyAddress()
                                    self.ipv6sr_policy_address.parent = self
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_flowspec_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.l2vpn_evpn_address = None
                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2VpnvplsAddress()
                                    self.l2vpnvpls_address.parent = self
                                    self.ls_ls_address = None
                                    self.rt_constraint_address = None


                                class L2VpnvplsAddress(object):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2VpnvplsAddress']['meta_info']


                                class L2VpnMspwAddress(object):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2VpnMspwAddress']['meta_info']


                                class Ipv4SrPolicyAddress(object):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv4SrPolicyAddress']['meta_info']


                                class Ipv6SrPolicyAddress(object):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv6_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv6_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv6SrPolicyAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:orr-root-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.afi is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv4_flowspec_address is not None:
                                        return True

                                    if self.ipv4_label_address is not None:
                                        return True

                                    if self.ipv4_mcast_address is not None:
                                        return True

                                    if self.ipv4_tunnel_address is not None:
                                        return True

                                    if self.ipv4mdt_address is not None:
                                        return True

                                    if self.ipv4mvpn_address is not None:
                                        return True

                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                        return True

                                    if self.ipv4vpn_address is not None:
                                        return True

                                    if self.ipv4vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv4vpna_mcastddress is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    if self.ipv6_flowspec_address is not None:
                                        return True

                                    if self.ipv6_label_address is not None:
                                        return True

                                    if self.ipv6_mcast_address is not None:
                                        return True

                                    if self.ipv6mvpn_address is not None:
                                        return True

                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                        return True

                                    if self.ipv6vpn_address is not None:
                                        return True

                                    if self.ipv6vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv6vpn_mcast_address is not None:
                                        return True

                                    if self.l2vpn_evpn_address is not None:
                                        return True

                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                        return True

                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                        return True

                                    if self.ls_ls_address is not None:
                                        return True

                                    if self.rt_constraint_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress']['meta_info']


                            class OrfCapabilityInfo(object):
                                """
                                ORF capability item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:orf-capability-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo']['meta_info']


                            class DefaultOriginateInfo(object):
                                """
                                Default\-originate item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:default-originate-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo']['meta_info']


                            class MaxPrefixesInfo(object):
                                """
                                Maximum prefixes to accept item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:max-prefixes-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo']['meta_info']


                            class OrrInfo(object):
                                """
                                Orr item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:orr-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo']['meta_info']


                            class NextHopSelfInfo(object):
                                """
                                Next hop self item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop-self-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo']['meta_info']


                            class NextHopUnchangedInfo(object):
                                """
                                Next hop unchanged info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop-unchanged-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo']['meta_info']


                            class RoutePolicyInInfo(object):
                                """
                                Inbound route policy item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:route-policy-in-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo']['meta_info']


                            class RoutePolicyOutInfo(object):
                                """
                                Outbound route policy item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:route-policy-out-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo']['meta_info']


                            class PrefixFilterInfo(object):
                                """
                                Inbound prefix based filter item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix-filter-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo']['meta_info']


                            class RemovePrivateAsInfo(object):
                                """
                                Outbound private\-AS removal item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:remove-private-as-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo']['meta_info']


                            class RemovePrivateAsInInfo(object):
                                """
                                Inbound private\-AS removal item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:remove-private-as-in-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo']['meta_info']


                            class RouteReflectorInfo(object):
                                """
                                Route\-reflector client item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:route-reflector-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo']['meta_info']


                            class LegacyPeRtInfo(object):
                                """
                                Accept\-legacy\-pe\-RT item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:legacy-pe-rt-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo']['meta_info']


                            class AfEnabledInfo(object):
                                """
                                Address family activate item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af-enabled-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo']['meta_info']


                            class SendCommunityInfo(object):
                                """
                                Send community attribute item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:send-community-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo']['meta_info']


                            class SendGracefulShutdownCommunityInfo(object):
                                """
                                Send Graceful shutdown related community
                                attribute item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:send-graceful-shutdown-community-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo']['meta_info']


                            class SendExtendedCommunityInfo(object):
                                """
                                Send extended community  item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:send-extended-community-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo']['meta_info']


                            class SoftReconfigInfo(object):
                                """
                                Soft reconf item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:soft-reconfig-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo']['meta_info']


                            class SoOInfo(object):
                                """
                                BGP Site\-of\-Origin info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:so-o-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo']['meta_info']


                            class WeightInfo(object):
                                """
                                Default weight item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:weight-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo']['meta_info']


                            class AllowasInInfo(object):
                                """
                                Allowas\-in item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:allowas-in-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo']['meta_info']


                            class AfLongLivedGracefulStartStaleTimeInfo(object):
                                """
                                Long\-lived\-time item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af-long-lived-graceful-start-stale-time-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo']['meta_info']


                            class AfLongLivedGracefulStartCapableInfo(object):
                                """
                                Long\-lived\-time item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af-long-lived-graceful-start-capable-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo']['meta_info']


                            class AsOverrideInfo(object):
                                """
                                As\-override info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:as-override-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo']['meta_info']


                            class AigpInfo(object):
                                """
                                AIGP info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:aigp-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo']['meta_info']


                            class AigpCostCommunityInfo(object):
                                """
                                AIGP Cost Community info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:aigp-cost-community-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo']['meta_info']


                            class AigpMed(object):
                                """
                                AIGP MED info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:aigp-med'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed']['meta_info']


                            class AcceptOwnInfo(object):
                                """
                                Accept\-Own info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:accept-own-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo']['meta_info']


                            class MultipathInfo(object):
                                """
                                Multipath info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:multipath-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo']['meta_info']


                            class FspecValidInfo(object):
                                """
                                FSPEC Valid info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:fspec-valid-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo']['meta_info']


                            class NextHopUnchangedMpathInfo(object):
                                """
                                Next hop unchanged mpath info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop-unchanged-mpath-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo']['meta_info']


                            class PermanentNetworkInfo(object):
                                """
                                Permanent network Info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:permanent-network-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo']['meta_info']


                            class SendMcastAttrInfo(object):
                                """
                                Send mcast attr info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:send-mcast-attr-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo']['meta_info']


                            class AdvertiseV4AfiInfo(object):
                                """
                                Advertise Afi Info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertise-v4-afi-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo']['meta_info']


                            class AdvertiseV6AfiInfo(object):
                                """
                                Advertise Afi Info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertise-v6-afi-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo']['meta_info']


                            class AdvertiseL2VpnevpnAfiInfo(object):
                                """
                                Advertise Afi Info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertise-l2vpnevpn-afi-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo']['meta_info']


                            class AdvertiseDisInfo(object):
                                """
                                Advertise Afi Info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertise-dis-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo']['meta_info']


                            class AdvertiseDefVrfImpDisableAfiV4Info(object):
                                """
                                Advertise Afi Info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertise-def-vrf-imp-disable-afi-v4-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info']['meta_info']


                            class AdvertiseDefVrfImpDisableAfiV6Info(object):
                                """
                                Advertise Afi Info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertise-def-vrf-imp-disable-afi-v6-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info']['meta_info']


                            class AdvertiseVrfReImpDisableAfiV4Info(object):
                                """
                                Advertise Afi Info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertise-vrf-re-imp-disable-afi-v4-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info']['meta_info']


                            class AdvertiseVrfReImpDisableAfiV6Info(object):
                                """
                                Advertise Afi Info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertise-vrf-re-imp-disable-afi-v6-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info']['meta_info']


                            class AfEncapsulationTypeInfo(object):
                                """
                                Encapsulation type Info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af-encapsulation-type-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo']['meta_info']


                            class ImportAfiInfo(object):
                                """
                                Import Afi Info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:import-afi-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo']['meta_info']


                            class AdvertiseLocalLabeledRouteInfo(object):
                                """
                                Advertise routes with local\-label
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self.is_item_configured = None


                                class InheritanceChain(object):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bgp_config_entid = YList()
                                        self.bgp_config_entid.parent = self
                                        self.bgp_config_entid.name = 'bgp_config_entid'


                                    class BgpConfigEntid(object):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\:  str
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None
                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address_family_identifier is not None:
                                                return True

                                            if self.configuration_type is not None:
                                                return True

                                            if self.group_name is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bgp_config_entid is not None:
                                            for child_ref in self.bgp_config_entid:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertise-local-labeled-route-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                        return True

                                    if self.is_item_configured is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af-dependent-config'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.accept_own is not None:
                                    return True

                                if self.accept_own_info is not None and self.accept_own_info._has_data():
                                    return True

                                if self.accept_route_legacy_pe_rt is not None:
                                    return True

                                if self.advertise_def_vrf_imp_disable_afi_v4_info is not None and self.advertise_def_vrf_imp_disable_afi_v4_info._has_data():
                                    return True

                                if self.advertise_def_vrf_imp_disable_afi_v6_info is not None and self.advertise_def_vrf_imp_disable_afi_v6_info._has_data():
                                    return True

                                if self.advertise_def_vrf_imp_disable_v4 is not None:
                                    return True

                                if self.advertise_def_vrf_imp_disable_v6 is not None:
                                    return True

                                if self.advertise_dis_info is not None and self.advertise_dis_info._has_data():
                                    return True

                                if self.advertise_disable is not None:
                                    return True

                                if self.advertise_l2vpnevpn is not None:
                                    return True

                                if self.advertise_l2vpnevpn_afi_info is not None and self.advertise_l2vpnevpn_afi_info._has_data():
                                    return True

                                if self.advertise_local_labeled_route is not None:
                                    return True

                                if self.advertise_local_labeled_route_info is not None and self.advertise_local_labeled_route_info._has_data():
                                    return True

                                if self.advertise_v4 is not None:
                                    return True

                                if self.advertise_v4_afi_info is not None and self.advertise_v4_afi_info._has_data():
                                    return True

                                if self.advertise_v6 is not None:
                                    return True

                                if self.advertise_v6_afi_info is not None and self.advertise_v6_afi_info._has_data():
                                    return True

                                if self.advertise_vrf_re_imp_disable_afi_v4_info is not None and self.advertise_vrf_re_imp_disable_afi_v4_info._has_data():
                                    return True

                                if self.advertise_vrf_re_imp_disable_afi_v6_info is not None and self.advertise_vrf_re_imp_disable_afi_v6_info._has_data():
                                    return True

                                if self.advertise_vrf_re_imp_disable_v4 is not None:
                                    return True

                                if self.advertise_vrf_re_imp_disable_v6 is not None:
                                    return True

                                if self.af_enabled_info is not None and self.af_enabled_info._has_data():
                                    return True

                                if self.af_encapsulation_type_info is not None and self.af_encapsulation_type_info._has_data():
                                    return True

                                if self.af_long_lived_graceful_restart_capable is not None:
                                    return True

                                if self.af_long_lived_graceful_restart_stale_time_accept is not None:
                                    return True

                                if self.af_long_lived_graceful_restart_stale_time_send is not None:
                                    return True

                                if self.af_long_lived_graceful_start_capable_info is not None and self.af_long_lived_graceful_start_capable_info._has_data():
                                    return True

                                if self.af_long_lived_graceful_start_stale_time_info is not None and self.af_long_lived_graceful_start_stale_time_info._has_data():
                                    return True

                                if self.aigp_cost_community_info is not None and self.aigp_cost_community_info._has_data():
                                    return True

                                if self.aigp_cost_community_poi is not None:
                                    return True

                                if self.aigp_info is not None and self.aigp_info._has_data():
                                    return True

                                if self.aigp_med is not None and self.aigp_med._has_data():
                                    return True

                                if self.allowas_in_info is not None and self.allowas_in_info._has_data():
                                    return True

                                if self.alway_use_soft_reconfig is not None:
                                    return True

                                if self.as_override_info is not None and self.as_override_info._has_data():
                                    return True

                                if self.client_route_reflector is not None:
                                    return True

                                if self.default_allowas is not None:
                                    return True

                                if self.default_originate_info is not None and self.default_originate_info._has_data():
                                    return True

                                if self.default_originate_route_policy is not None:
                                    return True

                                if self.default_weight is not None:
                                    return True

                                if self.encapsulation_type is not None:
                                    return True

                                if self.entire_aspath_in is not None:
                                    return True

                                if self.entire_aspath_out is not None:
                                    return True

                                if self.fspec_valid_info is not None and self.fspec_valid_info._has_data():
                                    return True

                                if self.has_orf_capability is not None:
                                    return True

                                if self.import_ is not None:
                                    return True

                                if self.import_afi_info is not None and self.import_afi_info._has_data():
                                    return True

                                if self.import_reoriginate is not None:
                                    return True

                                if self.import_reoriginate_stitching is not None:
                                    return True

                                if self.import_stitching is not None:
                                    return True

                                if self.is_af_enabled is not None:
                                    return True

                                if self.is_aigp_cost_community_enabled is not None:
                                    return True

                                if self.is_aigp_cost_community_id is not None:
                                    return True

                                if self.is_aigp_cost_community_transitive is not None:
                                    return True

                                if self.is_aigp_enabled is not None:
                                    return True

                                if self.is_aigp_med_enabled is not None:
                                    return True

                                if self.is_as_override_disabled is not None:
                                    return True

                                if self.is_default_originate_not_disabled is not None:
                                    return True

                                if self.is_fspec_valid_enabled is not None:
                                    return True

                                if self.is_max_prefix_discard_extra_paths is not None:
                                    return True

                                if self.is_max_prefix_warn_only is not None:
                                    return True

                                if self.is_next_hop_self_disabled is not None:
                                    return True

                                if self.is_next_hop_unchanged is not None:
                                    return True

                                if self.is_next_hop_unchanged_mpath is not None:
                                    return True

                                if self.is_send_mcast_attr_enabled is not None:
                                    return True

                                if self.legacy_pe_rt_info is not None and self.legacy_pe_rt_info._has_data():
                                    return True

                                if self.max_prefix_restart_time is not None:
                                    return True

                                if self.max_prefix_warn_threshold is not None:
                                    return True

                                if self.max_prefixes is not None:
                                    return True

                                if self.max_prefixes_info is not None and self.max_prefixes_info._has_data():
                                    return True

                                if self.multipath is not None:
                                    return True

                                if self.multipath_info is not None and self.multipath_info._has_data():
                                    return True

                                if self.next_hop_self_info is not None and self.next_hop_self_info._has_data():
                                    return True

                                if self.next_hop_unchanged_info is not None and self.next_hop_unchanged_info._has_data():
                                    return True

                                if self.next_hop_unchanged_mpath_info is not None and self.next_hop_unchanged_mpath_info._has_data():
                                    return True

                                if self.orf_capability_info is not None and self.orf_capability_info._has_data():
                                    return True

                                if self.orr_info is not None and self.orr_info._has_data():
                                    return True

                                if self.orr_root_address is not None and self.orr_root_address._has_data():
                                    return True

                                if self.permanent_network is not None:
                                    return True

                                if self.permanent_network_info is not None and self.permanent_network_info._has_data():
                                    return True

                                if self.prefix_filter_info is not None and self.prefix_filter_info._has_data():
                                    return True

                                if self.prefix_orf_filter is not None:
                                    return True

                                if self.remove_private_as_in_info is not None and self.remove_private_as_in_info._has_data():
                                    return True

                                if self.remove_private_as_info is not None and self.remove_private_as_info._has_data():
                                    return True

                                if self.remove_private_as_out is not None:
                                    return True

                                if self.remove_private_asin is not None:
                                    return True

                                if self.route_policy_in is not None:
                                    return True

                                if self.route_policy_in_info is not None and self.route_policy_in_info._has_data():
                                    return True

                                if self.route_policy_out is not None:
                                    return True

                                if self.route_policy_out_info is not None and self.route_policy_out_info._has_data():
                                    return True

                                if self.route_reflector_info is not None and self.route_reflector_info._has_data():
                                    return True

                                if self.send_community_attribute is not None:
                                    return True

                                if self.send_community_info is not None and self.send_community_info._has_data():
                                    return True

                                if self.send_extended_community_attribute is not None:
                                    return True

                                if self.send_extended_community_info is not None and self.send_extended_community_info._has_data():
                                    return True

                                if self.send_graceful_shut_community_attributes is not None:
                                    return True

                                if self.send_graceful_shutdown_community_info is not None and self.send_graceful_shutdown_community_info._has_data():
                                    return True

                                if self.send_mcast_attr_info is not None and self.send_mcast_attr_info._has_data():
                                    return True

                                if self.site_of_origin is not None:
                                    return True

                                if self.so_o_info is not None and self.so_o_info._has_data():
                                    return True

                                if self.soft_reconfig_info is not None and self.soft_reconfig_info._has_data():
                                    return True

                                if self.soft_reconfig_not_disabled is not None:
                                    return True

                                if self.weight_info is not None and self.weight_info._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:entity-configuration'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.address_family_identifier is not None:
                                return True

                            if self.af_dependent_config is not None:
                                for child_ref in self.af_dependent_config:
                                    if child_ref._has_data():
                                        return True

                            if self.af_independent_config is not None and self.af_independent_config._has_data():
                                return True

                            if self.configuration_type is not None:
                                return True

                            if self.entity_name is not None:
                                return True

                            if self.entity_type is not None:
                                return True

                            if self.group_name is not None:
                                return True

                            if self.neighbor_address is not None:
                                return True

                            if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:entity-configurations'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.entity_configuration is not None:
                            for child_ref in self.entity_configuration:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations']['meta_info']


                class ConfigurationUsers(object):
                    """
                    The BGP configuration users table
                    
                    .. attribute:: configuration_user
                    
                    	A BGP configuration user table entry
                    	**type**\: list of    :py:class:`ConfigurationUser <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2015-08-27'

                    def __init__(self):
                        self.parent = None
                        self.configuration_user = YList()
                        self.configuration_user.parent = self
                        self.configuration_user.name = 'configuration_user'


                    class ConfigurationUser(object):
                        """
                        A BGP configuration user table entry
                        
                        .. attribute:: address_family_identifier
                        
                        	AF identifier
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: af_dependent_relative
                        
                        	AF\-dependent relatives
                        	**type**\: list of    :py:class:`AfDependentRelative <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative>`
                        
                        .. attribute:: af_independent_relatives
                        
                        	AF\-independent relatives
                        	**type**\:   :py:class:`AfIndependentRelatives <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives>`
                        
                        .. attribute:: configuration_type
                        
                        	Entity type
                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                        
                        .. attribute:: entity_name
                        
                        	Entity name
                        	**type**\:  str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: entity_type
                        
                        	Entity type
                        	**type**\:   :py:class:`BgpEntityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntityEnum>`
                        
                        .. attribute:: group_name
                        
                        	Entity/group name
                        	**type**\:  str
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: neighbor_address_xr
                        
                        	Neighbor Address
                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.address_family_identifier = None
                            self.af_dependent_relative = YList()
                            self.af_dependent_relative.parent = self
                            self.af_dependent_relative.name = 'af_dependent_relative'
                            self.af_independent_relatives = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives()
                            self.af_independent_relatives.parent = self
                            self.configuration_type = None
                            self.entity_name = None
                            self.entity_type = None
                            self.group_name = None
                            self.neighbor_address = None
                            self.neighbor_address_xr = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr()
                            self.neighbor_address_xr.parent = self


                        class NeighborAddressXr(object):
                            """
                            Neighbor Address
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4_flowspec_address
                            
                            	IPV4 Flowspec Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4096}
                            
                            .. attribute:: ipv4_label_address
                            
                            	IPv4 Label Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4_mcast_address
                            
                            	IPv4 Mcast Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4_tunnel_address
                            
                            	IPv4 Tunnel
                            	**type**\:  str
                            
                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                            
                            .. attribute:: ipv4mdt_address
                            
                            	IPv4 MDT Addr
                            	**type**\:  str
                            
                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                            
                            .. attribute:: ipv4mvpn_address
                            
                            	MVPN4 addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{56}
                            
                            .. attribute:: ipv4sr_policy_address
                            
                            	IPV4 Policy Addr
                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv4SrPolicyAddress>`
                            
                            .. attribute:: ipv4vpn_address
                            
                            	IPv4 VPN Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4vpn_flowspec_address
                            
                            	IPV4 VPN Flowspec Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4096}
                            
                            .. attribute:: ipv4vpna_mcastddress
                            
                            	IPv4 VPN Mcast Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_flowspec_address
                            
                            	IPV6 Flowspec Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4096}
                            
                            .. attribute:: ipv6_label_address
                            
                            	IPv6 Label Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_mcast_address
                            
                            	IPV6 Mcast Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6mvpn_address
                            
                            	MVPN addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{104}
                            
                            .. attribute:: ipv6sr_policy_address
                            
                            	IPV6 Policy Addr
                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv6SrPolicyAddress>`
                            
                            .. attribute:: ipv6vpn_address
                            
                            	IPv6 VPN Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6vpn_flowspec_address
                            
                            	IPV6 VPN Flowspec Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4096}
                            
                            .. attribute:: ipv6vpn_mcast_address
                            
                            	IPv6 VPN Mcast Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: l2vpn_evpn_address
                            
                            	L2VPN EVPN Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{58}
                            
                            .. attribute:: l2vpn_mspw_address
                            
                            	L2VPN MSPW Addr
                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2VpnMspwAddress>`
                            
                            .. attribute:: l2vpnvpls_address
                            
                            	L2VPN VPLS Addr
                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2VpnvplsAddress>`
                            
                            .. attribute:: ls_ls_address
                            
                            	LINKSTATE LINKSTATE Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]+
                            
                            .. attribute:: rt_constraint_address
                            
                            	RT Constrt Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{24}
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.afi = None
                                self.ipv4_address = None
                                self.ipv4_flowspec_address = None
                                self.ipv4_label_address = None
                                self.ipv4_mcast_address = None
                                self.ipv4_tunnel_address = None
                                self.ipv4mdt_address = None
                                self.ipv4mvpn_address = None
                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv4SrPolicyAddress()
                                self.ipv4sr_policy_address.parent = self
                                self.ipv4vpn_address = None
                                self.ipv4vpn_flowspec_address = None
                                self.ipv4vpna_mcastddress = None
                                self.ipv6_address = None
                                self.ipv6_flowspec_address = None
                                self.ipv6_label_address = None
                                self.ipv6_mcast_address = None
                                self.ipv6mvpn_address = None
                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv6SrPolicyAddress()
                                self.ipv6sr_policy_address.parent = self
                                self.ipv6vpn_address = None
                                self.ipv6vpn_flowspec_address = None
                                self.ipv6vpn_mcast_address = None
                                self.l2vpn_evpn_address = None
                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2VpnMspwAddress()
                                self.l2vpn_mspw_address.parent = self
                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2VpnvplsAddress()
                                self.l2vpnvpls_address.parent = self
                                self.ls_ls_address = None
                                self.rt_constraint_address = None


                            class L2VpnvplsAddress(object):
                                """
                                L2VPN VPLS Addr
                                
                                .. attribute:: l2vpn_address
                                
                                	l2vpn address
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.l2vpn_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.l2vpn_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                            class L2VpnMspwAddress(object):
                                """
                                L2VPN MSPW Addr
                                
                                .. attribute:: l2vpn_address
                                
                                	l2vpn address
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.l2vpn_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.l2vpn_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                            class Ipv4SrPolicyAddress(object):
                                """
                                IPV4 Policy Addr
                                
                                .. attribute:: ipv4_srpolicy_address
                                
                                	ipv4 srpolicy address
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.ipv4_srpolicy_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ipv4_srpolicy_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                            class Ipv6SrPolicyAddress(object):
                                """
                                IPV6 Policy Addr
                                
                                .. attribute:: ipv6_srpolicy_address
                                
                                	ipv6 srpolicy address
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.ipv6_srpolicy_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ipv6_srpolicy_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.afi is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv4_flowspec_address is not None:
                                    return True

                                if self.ipv4_label_address is not None:
                                    return True

                                if self.ipv4_mcast_address is not None:
                                    return True

                                if self.ipv4_tunnel_address is not None:
                                    return True

                                if self.ipv4mdt_address is not None:
                                    return True

                                if self.ipv4mvpn_address is not None:
                                    return True

                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                    return True

                                if self.ipv4vpn_address is not None:
                                    return True

                                if self.ipv4vpn_flowspec_address is not None:
                                    return True

                                if self.ipv4vpna_mcastddress is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                if self.ipv6_flowspec_address is not None:
                                    return True

                                if self.ipv6_label_address is not None:
                                    return True

                                if self.ipv6_mcast_address is not None:
                                    return True

                                if self.ipv6mvpn_address is not None:
                                    return True

                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                    return True

                                if self.ipv6vpn_address is not None:
                                    return True

                                if self.ipv6vpn_flowspec_address is not None:
                                    return True

                                if self.ipv6vpn_mcast_address is not None:
                                    return True

                                if self.l2vpn_evpn_address is not None:
                                    return True

                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                    return True

                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                    return True

                                if self.ls_ls_address is not None:
                                    return True

                                if self.rt_constraint_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr']['meta_info']


                        class AfIndependentRelatives(object):
                            """
                            AF\-independent relatives
                            
                            .. attribute:: bgp_config_entid
                            
                            	bgp config entid
                            	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.bgp_config_entid = YList()
                                self.bgp_config_entid.parent = self
                                self.bgp_config_entid.name = 'bgp_config_entid'


                            class BgpConfigEntid(object):
                                """
                                bgp config entid
                                
                                .. attribute:: address_family_identifier
                                
                                	Address family identfier
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: configuration_type
                                
                                	Entity type
                                	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                
                                .. attribute:: group_name
                                
                                	Group name
                                	**type**\:  str
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor Address
                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.address_family_identifier = None
                                    self.configuration_type = None
                                    self.group_name = None
                                    self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress()
                                    self.neighbor_address.parent = self


                                class NeighborAddress(object):
                                    """
                                    Neighbor Address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpnvpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4mdt_address = None
                                        self.ipv4mvpn_address = None
                                        self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                        self.ipv4sr_policy_address.parent = self
                                        self.ipv4vpn_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                        self.ipv6sr_policy_address.parent = self
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_flowspec_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.l2vpn_evpn_address = None
                                        self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                        self.l2vpnvpls_address.parent = self
                                        self.ls_ls_address = None
                                        self.rt_constraint_address = None


                                    class L2VpnvplsAddress(object):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                    class L2VpnMspwAddress(object):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                    class Ipv4SrPolicyAddress(object):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                    class Ipv6SrPolicyAddress(object):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv6_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv6_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.afi is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv4_flowspec_address is not None:
                                            return True

                                        if self.ipv4_label_address is not None:
                                            return True

                                        if self.ipv4_mcast_address is not None:
                                            return True

                                        if self.ipv4_tunnel_address is not None:
                                            return True

                                        if self.ipv4mdt_address is not None:
                                            return True

                                        if self.ipv4mvpn_address is not None:
                                            return True

                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                            return True

                                        if self.ipv4vpn_address is not None:
                                            return True

                                        if self.ipv4vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv4vpna_mcastddress is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        if self.ipv6_flowspec_address is not None:
                                            return True

                                        if self.ipv6_label_address is not None:
                                            return True

                                        if self.ipv6_mcast_address is not None:
                                            return True

                                        if self.ipv6mvpn_address is not None:
                                            return True

                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                            return True

                                        if self.ipv6vpn_address is not None:
                                            return True

                                        if self.ipv6vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv6vpn_mcast_address is not None:
                                            return True

                                        if self.l2vpn_evpn_address is not None:
                                            return True

                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                            return True

                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                            return True

                                        if self.ls_ls_address is not None:
                                            return True

                                        if self.rt_constraint_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.address_family_identifier is not None:
                                        return True

                                    if self.configuration_type is not None:
                                        return True

                                    if self.group_name is not None:
                                        return True

                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af-independent-relatives'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bgp_config_entid is not None:
                                    for child_ref in self.bgp_config_entid:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives']['meta_info']


                        class AfDependentRelative(object):
                            """
                            AF\-dependent relatives
                            
                            .. attribute:: bgp_config_entid
                            
                            	bgp config entid
                            	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.bgp_config_entid = YList()
                                self.bgp_config_entid.parent = self
                                self.bgp_config_entid.name = 'bgp_config_entid'


                            class BgpConfigEntid(object):
                                """
                                bgp config entid
                                
                                .. attribute:: address_family_identifier
                                
                                	Address family identfier
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: configuration_type
                                
                                	Entity type
                                	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                
                                .. attribute:: group_name
                                
                                	Group name
                                	**type**\:  str
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor Address
                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.address_family_identifier = None
                                    self.configuration_type = None
                                    self.group_name = None
                                    self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress()
                                    self.neighbor_address.parent = self


                                class NeighborAddress(object):
                                    """
                                    Neighbor Address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpnvpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4mdt_address = None
                                        self.ipv4mvpn_address = None
                                        self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                        self.ipv4sr_policy_address.parent = self
                                        self.ipv4vpn_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                        self.ipv6sr_policy_address.parent = self
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_flowspec_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.l2vpn_evpn_address = None
                                        self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                        self.l2vpnvpls_address.parent = self
                                        self.ls_ls_address = None
                                        self.rt_constraint_address = None


                                    class L2VpnvplsAddress(object):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                    class L2VpnMspwAddress(object):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                    class Ipv4SrPolicyAddress(object):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                    class Ipv6SrPolicyAddress(object):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv6_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv6_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.afi is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv4_flowspec_address is not None:
                                            return True

                                        if self.ipv4_label_address is not None:
                                            return True

                                        if self.ipv4_mcast_address is not None:
                                            return True

                                        if self.ipv4_tunnel_address is not None:
                                            return True

                                        if self.ipv4mdt_address is not None:
                                            return True

                                        if self.ipv4mvpn_address is not None:
                                            return True

                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                            return True

                                        if self.ipv4vpn_address is not None:
                                            return True

                                        if self.ipv4vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv4vpna_mcastddress is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        if self.ipv6_flowspec_address is not None:
                                            return True

                                        if self.ipv6_label_address is not None:
                                            return True

                                        if self.ipv6_mcast_address is not None:
                                            return True

                                        if self.ipv6mvpn_address is not None:
                                            return True

                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                            return True

                                        if self.ipv6vpn_address is not None:
                                            return True

                                        if self.ipv6vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv6vpn_mcast_address is not None:
                                            return True

                                        if self.l2vpn_evpn_address is not None:
                                            return True

                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                            return True

                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                            return True

                                        if self.ls_ls_address is not None:
                                            return True

                                        if self.rt_constraint_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.address_family_identifier is not None:
                                        return True

                                    if self.configuration_type is not None:
                                        return True

                                    if self.group_name is not None:
                                        return True

                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af-dependent-relative'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bgp_config_entid is not None:
                                    for child_ref in self.bgp_config_entid:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:configuration-user'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.address_family_identifier is not None:
                                return True

                            if self.af_dependent_relative is not None:
                                for child_ref in self.af_dependent_relative:
                                    if child_ref._has_data():
                                        return True

                            if self.af_independent_relatives is not None and self.af_independent_relatives._has_data():
                                return True

                            if self.configuration_type is not None:
                                return True

                            if self.entity_name is not None:
                                return True

                            if self.entity_type is not None:
                                return True

                            if self.group_name is not None:
                                return True

                            if self.neighbor_address is not None:
                                return True

                            if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:configuration-users'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.configuration_user is not None:
                            for child_ref in self.configuration_user:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers']['meta_info']


                class ConfigurationInheritances(object):
                    """
                    The BGP configurataion inheritance table
                    
                    .. attribute:: configuration_inheritance
                    
                    	A BGP configuration inheritance table entry
                    	**type**\: list of    :py:class:`ConfigurationInheritance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2015-08-27'

                    def __init__(self):
                        self.parent = None
                        self.configuration_inheritance = YList()
                        self.configuration_inheritance.parent = self
                        self.configuration_inheritance.name = 'configuration_inheritance'


                    class ConfigurationInheritance(object):
                        """
                        A BGP configuration inheritance table entry
                        
                        .. attribute:: address_family_identifier
                        
                        	AF identifier
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: af_dependent_relative
                        
                        	AF\-dependent relatives
                        	**type**\: list of    :py:class:`AfDependentRelative <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative>`
                        
                        .. attribute:: af_independent_relatives
                        
                        	AF\-independent relatives
                        	**type**\:   :py:class:`AfIndependentRelatives <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives>`
                        
                        .. attribute:: configuration_type
                        
                        	Entity type
                        	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                        
                        .. attribute:: entity_name
                        
                        	Entity name
                        	**type**\:  str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: entity_type
                        
                        	Entity type
                        	**type**\:   :py:class:`BgpEntityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntityEnum>`
                        
                        .. attribute:: group_name
                        
                        	Entity/group name
                        	**type**\:  str
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: neighbor_address_xr
                        
                        	Neighbor Address
                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.address_family_identifier = None
                            self.af_dependent_relative = YList()
                            self.af_dependent_relative.parent = self
                            self.af_dependent_relative.name = 'af_dependent_relative'
                            self.af_independent_relatives = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives()
                            self.af_independent_relatives.parent = self
                            self.configuration_type = None
                            self.entity_name = None
                            self.entity_type = None
                            self.group_name = None
                            self.neighbor_address = None
                            self.neighbor_address_xr = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr()
                            self.neighbor_address_xr.parent = self


                        class NeighborAddressXr(object):
                            """
                            Neighbor Address
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4_flowspec_address
                            
                            	IPV4 Flowspec Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4096}
                            
                            .. attribute:: ipv4_label_address
                            
                            	IPv4 Label Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4_mcast_address
                            
                            	IPv4 Mcast Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4_tunnel_address
                            
                            	IPv4 Tunnel
                            	**type**\:  str
                            
                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                            
                            .. attribute:: ipv4mdt_address
                            
                            	IPv4 MDT Addr
                            	**type**\:  str
                            
                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                            
                            .. attribute:: ipv4mvpn_address
                            
                            	MVPN4 addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{56}
                            
                            .. attribute:: ipv4sr_policy_address
                            
                            	IPV4 Policy Addr
                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv4SrPolicyAddress>`
                            
                            .. attribute:: ipv4vpn_address
                            
                            	IPv4 VPN Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4vpn_flowspec_address
                            
                            	IPV4 VPN Flowspec Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4096}
                            
                            .. attribute:: ipv4vpna_mcastddress
                            
                            	IPv4 VPN Mcast Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_flowspec_address
                            
                            	IPV6 Flowspec Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4096}
                            
                            .. attribute:: ipv6_label_address
                            
                            	IPv6 Label Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_mcast_address
                            
                            	IPV6 Mcast Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6mvpn_address
                            
                            	MVPN addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{104}
                            
                            .. attribute:: ipv6sr_policy_address
                            
                            	IPV6 Policy Addr
                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv6SrPolicyAddress>`
                            
                            .. attribute:: ipv6vpn_address
                            
                            	IPv6 VPN Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6vpn_flowspec_address
                            
                            	IPV6 VPN Flowspec Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4096}
                            
                            .. attribute:: ipv6vpn_mcast_address
                            
                            	IPv6 VPN Mcast Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: l2vpn_evpn_address
                            
                            	L2VPN EVPN Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{58}
                            
                            .. attribute:: l2vpn_mspw_address
                            
                            	L2VPN MSPW Addr
                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2VpnMspwAddress>`
                            
                            .. attribute:: l2vpnvpls_address
                            
                            	L2VPN VPLS Addr
                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2VpnvplsAddress>`
                            
                            .. attribute:: ls_ls_address
                            
                            	LINKSTATE LINKSTATE Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]+
                            
                            .. attribute:: rt_constraint_address
                            
                            	RT Constrt Addr
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{24}
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.afi = None
                                self.ipv4_address = None
                                self.ipv4_flowspec_address = None
                                self.ipv4_label_address = None
                                self.ipv4_mcast_address = None
                                self.ipv4_tunnel_address = None
                                self.ipv4mdt_address = None
                                self.ipv4mvpn_address = None
                                self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv4SrPolicyAddress()
                                self.ipv4sr_policy_address.parent = self
                                self.ipv4vpn_address = None
                                self.ipv4vpn_flowspec_address = None
                                self.ipv4vpna_mcastddress = None
                                self.ipv6_address = None
                                self.ipv6_flowspec_address = None
                                self.ipv6_label_address = None
                                self.ipv6_mcast_address = None
                                self.ipv6mvpn_address = None
                                self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv6SrPolicyAddress()
                                self.ipv6sr_policy_address.parent = self
                                self.ipv6vpn_address = None
                                self.ipv6vpn_flowspec_address = None
                                self.ipv6vpn_mcast_address = None
                                self.l2vpn_evpn_address = None
                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2VpnMspwAddress()
                                self.l2vpn_mspw_address.parent = self
                                self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2VpnvplsAddress()
                                self.l2vpnvpls_address.parent = self
                                self.ls_ls_address = None
                                self.rt_constraint_address = None


                            class L2VpnvplsAddress(object):
                                """
                                L2VPN VPLS Addr
                                
                                .. attribute:: l2vpn_address
                                
                                	l2vpn address
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.l2vpn_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.l2vpn_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                            class L2VpnMspwAddress(object):
                                """
                                L2VPN MSPW Addr
                                
                                .. attribute:: l2vpn_address
                                
                                	l2vpn address
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.l2vpn_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.l2vpn_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                            class Ipv4SrPolicyAddress(object):
                                """
                                IPV4 Policy Addr
                                
                                .. attribute:: ipv4_srpolicy_address
                                
                                	ipv4 srpolicy address
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.ipv4_srpolicy_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ipv4_srpolicy_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                            class Ipv6SrPolicyAddress(object):
                                """
                                IPV6 Policy Addr
                                
                                .. attribute:: ipv6_srpolicy_address
                                
                                	ipv6 srpolicy address
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.ipv6_srpolicy_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ipv6_srpolicy_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.afi is not None:
                                    return True

                                if self.ipv4_address is not None:
                                    return True

                                if self.ipv4_flowspec_address is not None:
                                    return True

                                if self.ipv4_label_address is not None:
                                    return True

                                if self.ipv4_mcast_address is not None:
                                    return True

                                if self.ipv4_tunnel_address is not None:
                                    return True

                                if self.ipv4mdt_address is not None:
                                    return True

                                if self.ipv4mvpn_address is not None:
                                    return True

                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                    return True

                                if self.ipv4vpn_address is not None:
                                    return True

                                if self.ipv4vpn_flowspec_address is not None:
                                    return True

                                if self.ipv4vpna_mcastddress is not None:
                                    return True

                                if self.ipv6_address is not None:
                                    return True

                                if self.ipv6_flowspec_address is not None:
                                    return True

                                if self.ipv6_label_address is not None:
                                    return True

                                if self.ipv6_mcast_address is not None:
                                    return True

                                if self.ipv6mvpn_address is not None:
                                    return True

                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                    return True

                                if self.ipv6vpn_address is not None:
                                    return True

                                if self.ipv6vpn_flowspec_address is not None:
                                    return True

                                if self.ipv6vpn_mcast_address is not None:
                                    return True

                                if self.l2vpn_evpn_address is not None:
                                    return True

                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                    return True

                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                    return True

                                if self.ls_ls_address is not None:
                                    return True

                                if self.rt_constraint_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr']['meta_info']


                        class AfIndependentRelatives(object):
                            """
                            AF\-independent relatives
                            
                            .. attribute:: bgp_config_entid
                            
                            	bgp config entid
                            	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.bgp_config_entid = YList()
                                self.bgp_config_entid.parent = self
                                self.bgp_config_entid.name = 'bgp_config_entid'


                            class BgpConfigEntid(object):
                                """
                                bgp config entid
                                
                                .. attribute:: address_family_identifier
                                
                                	Address family identfier
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: configuration_type
                                
                                	Entity type
                                	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                
                                .. attribute:: group_name
                                
                                	Group name
                                	**type**\:  str
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor Address
                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.address_family_identifier = None
                                    self.configuration_type = None
                                    self.group_name = None
                                    self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress()
                                    self.neighbor_address.parent = self


                                class NeighborAddress(object):
                                    """
                                    Neighbor Address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpnvpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4mdt_address = None
                                        self.ipv4mvpn_address = None
                                        self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                        self.ipv4sr_policy_address.parent = self
                                        self.ipv4vpn_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                        self.ipv6sr_policy_address.parent = self
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_flowspec_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.l2vpn_evpn_address = None
                                        self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                        self.l2vpnvpls_address.parent = self
                                        self.ls_ls_address = None
                                        self.rt_constraint_address = None


                                    class L2VpnvplsAddress(object):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                    class L2VpnMspwAddress(object):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                    class Ipv4SrPolicyAddress(object):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                    class Ipv6SrPolicyAddress(object):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv6_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv6_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.afi is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv4_flowspec_address is not None:
                                            return True

                                        if self.ipv4_label_address is not None:
                                            return True

                                        if self.ipv4_mcast_address is not None:
                                            return True

                                        if self.ipv4_tunnel_address is not None:
                                            return True

                                        if self.ipv4mdt_address is not None:
                                            return True

                                        if self.ipv4mvpn_address is not None:
                                            return True

                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                            return True

                                        if self.ipv4vpn_address is not None:
                                            return True

                                        if self.ipv4vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv4vpna_mcastddress is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        if self.ipv6_flowspec_address is not None:
                                            return True

                                        if self.ipv6_label_address is not None:
                                            return True

                                        if self.ipv6_mcast_address is not None:
                                            return True

                                        if self.ipv6mvpn_address is not None:
                                            return True

                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                            return True

                                        if self.ipv6vpn_address is not None:
                                            return True

                                        if self.ipv6vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv6vpn_mcast_address is not None:
                                            return True

                                        if self.l2vpn_evpn_address is not None:
                                            return True

                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                            return True

                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                            return True

                                        if self.ls_ls_address is not None:
                                            return True

                                        if self.rt_constraint_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.address_family_identifier is not None:
                                        return True

                                    if self.configuration_type is not None:
                                        return True

                                    if self.group_name is not None:
                                        return True

                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af-independent-relatives'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bgp_config_entid is not None:
                                    for child_ref in self.bgp_config_entid:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives']['meta_info']


                        class AfDependentRelative(object):
                            """
                            AF\-dependent relatives
                            
                            .. attribute:: bgp_config_entid
                            
                            	bgp config entid
                            	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.bgp_config_entid = YList()
                                self.bgp_config_entid.parent = self
                                self.bgp_config_entid.name = 'bgp_config_entid'


                            class BgpConfigEntid(object):
                                """
                                bgp config entid
                                
                                .. attribute:: address_family_identifier
                                
                                	Address family identfier
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: configuration_type
                                
                                	Entity type
                                	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                
                                .. attribute:: group_name
                                
                                	Group name
                                	**type**\:  str
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor Address
                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.address_family_identifier = None
                                    self.configuration_type = None
                                    self.group_name = None
                                    self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress()
                                    self.neighbor_address.parent = self


                                class NeighborAddress(object):
                                    """
                                    Neighbor Address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpnvpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4mdt_address = None
                                        self.ipv4mvpn_address = None
                                        self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                        self.ipv4sr_policy_address.parent = self
                                        self.ipv4vpn_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                        self.ipv6sr_policy_address.parent = self
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_flowspec_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.l2vpn_evpn_address = None
                                        self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                        self.l2vpnvpls_address.parent = self
                                        self.ls_ls_address = None
                                        self.rt_constraint_address = None


                                    class L2VpnvplsAddress(object):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                    class L2VpnMspwAddress(object):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                    class Ipv4SrPolicyAddress(object):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                    class Ipv6SrPolicyAddress(object):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv6_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv6_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.afi is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv4_flowspec_address is not None:
                                            return True

                                        if self.ipv4_label_address is not None:
                                            return True

                                        if self.ipv4_mcast_address is not None:
                                            return True

                                        if self.ipv4_tunnel_address is not None:
                                            return True

                                        if self.ipv4mdt_address is not None:
                                            return True

                                        if self.ipv4mvpn_address is not None:
                                            return True

                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                            return True

                                        if self.ipv4vpn_address is not None:
                                            return True

                                        if self.ipv4vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv4vpna_mcastddress is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        if self.ipv6_flowspec_address is not None:
                                            return True

                                        if self.ipv6_label_address is not None:
                                            return True

                                        if self.ipv6_mcast_address is not None:
                                            return True

                                        if self.ipv6mvpn_address is not None:
                                            return True

                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                            return True

                                        if self.ipv6vpn_address is not None:
                                            return True

                                        if self.ipv6vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv6vpn_mcast_address is not None:
                                            return True

                                        if self.l2vpn_evpn_address is not None:
                                            return True

                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                            return True

                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                            return True

                                        if self.ls_ls_address is not None:
                                            return True

                                        if self.rt_constraint_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.address_family_identifier is not None:
                                        return True

                                    if self.configuration_type is not None:
                                        return True

                                    if self.group_name is not None:
                                        return True

                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af-dependent-relative'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bgp_config_entid is not None:
                                    for child_ref in self.bgp_config_entid:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:configuration-inheritance'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.address_family_identifier is not None:
                                return True

                            if self.af_dependent_relative is not None:
                                for child_ref in self.af_dependent_relative:
                                    if child_ref._has_data():
                                        return True

                            if self.af_independent_relatives is not None and self.af_independent_relatives._has_data():
                                return True

                            if self.configuration_type is not None:
                                return True

                            if self.entity_name is not None:
                                return True

                            if self.entity_type is not None:
                                return True

                            if self.group_name is not None:
                                return True

                            if self.neighbor_address is not None:
                                return True

                            if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:configuration-inheritances'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.configuration_inheritance is not None:
                            for child_ref in self.configuration_inheritance:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:config-instance-default-vrf'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.configuration_inheritances is not None and self.configuration_inheritances._has_data():
                        return True

                    if self.configuration_users is not None and self.configuration_users._has_data():
                        return True

                    if self.entity_configurations is not None and self.entity_configurations._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf']['meta_info']


            class ConfigVrfs(object):
                """
                VRF related configuration data
                
                .. attribute:: config_vrf
                
                	Configuration data for a particular VRF
                	**type**\: list of    :py:class:`ConfigVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf>`
                
                

                """

                _prefix = 'ipv4-bgp-oper'
                _revision = '2015-08-27'

                def __init__(self):
                    self.parent = None
                    self.config_vrf = YList()
                    self.config_vrf.parent = self
                    self.config_vrf.name = 'config_vrf'


                class ConfigVrf(object):
                    """
                    Configuration data for a particular VRF
                    
                    .. attribute:: vrf_name  <key>
                    
                    	Name of the VRF
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: configuration_inheritances
                    
                    	The BGP configurataion inheritance table
                    	**type**\:   :py:class:`ConfigurationInheritances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances>`
                    
                    .. attribute:: configuration_users
                    
                    	The BGP configuration users table
                    	**type**\:   :py:class:`ConfigurationUsers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers>`
                    
                    .. attribute:: entity_configurations
                    
                    	The BGP Entity Configuration table
                    	**type**\:   :py:class:`EntityConfigurations <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2015-08-27'

                    def __init__(self):
                        self.parent = None
                        self.vrf_name = None
                        self.configuration_inheritances = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances()
                        self.configuration_inheritances.parent = self
                        self.configuration_users = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers()
                        self.configuration_users.parent = self
                        self.entity_configurations = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations()
                        self.entity_configurations.parent = self


                    class EntityConfigurations(object):
                        """
                        The BGP Entity Configuration table
                        
                        .. attribute:: entity_configuration
                        
                        	A BGP Entity Configuration table entry
                        	**type**\: list of    :py:class:`EntityConfiguration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.entity_configuration = YList()
                            self.entity_configuration.parent = self
                            self.entity_configuration.name = 'entity_configuration'


                        class EntityConfiguration(object):
                            """
                            A BGP Entity Configuration table entry
                            
                            .. attribute:: address_family_identifier
                            
                            	AF identifier
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: af_dependent_config
                            
                            	Af\-dependent config
                            	**type**\: list of    :py:class:`AfDependentConfig <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig>`
                            
                            .. attribute:: af_independent_config
                            
                            	AF\-independent config
                            	**type**\:   :py:class:`AfIndependentConfig <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig>`
                            
                            .. attribute:: configuration_type
                            
                            	Entity type
                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                            
                            .. attribute:: entity_name
                            
                            	Entity name
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: entity_type
                            
                            	Entity type
                            	**type**\:   :py:class:`BgpEntityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntityEnum>`
                            
                            .. attribute:: group_name
                            
                            	Entity/group name
                            	**type**\:  str
                            
                            .. attribute:: neighbor_address
                            
                            	Neighbor address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: neighbor_address_xr
                            
                            	Neighbor Address
                            	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.address_family_identifier = None
                                self.af_dependent_config = YList()
                                self.af_dependent_config.parent = self
                                self.af_dependent_config.name = 'af_dependent_config'
                                self.af_independent_config = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig()
                                self.af_independent_config.parent = self
                                self.configuration_type = None
                                self.entity_name = None
                                self.entity_type = None
                                self.group_name = None
                                self.neighbor_address = None
                                self.neighbor_address_xr = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr()
                                self.neighbor_address_xr.parent = self


                            class NeighborAddressXr(object):
                                """
                                Neighbor Address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpnvpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2VpnvplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4mdt_address = None
                                    self.ipv4mvpn_address = None
                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv4SrPolicyAddress()
                                    self.ipv4sr_policy_address.parent = self
                                    self.ipv4vpn_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv6SrPolicyAddress()
                                    self.ipv6sr_policy_address.parent = self
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_flowspec_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.l2vpn_evpn_address = None
                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2VpnvplsAddress()
                                    self.l2vpnvpls_address.parent = self
                                    self.ls_ls_address = None
                                    self.rt_constraint_address = None


                                class L2VpnvplsAddress(object):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                class L2VpnMspwAddress(object):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                class Ipv4SrPolicyAddress(object):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                class Ipv6SrPolicyAddress(object):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv6_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv6_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.afi is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv4_flowspec_address is not None:
                                        return True

                                    if self.ipv4_label_address is not None:
                                        return True

                                    if self.ipv4_mcast_address is not None:
                                        return True

                                    if self.ipv4_tunnel_address is not None:
                                        return True

                                    if self.ipv4mdt_address is not None:
                                        return True

                                    if self.ipv4mvpn_address is not None:
                                        return True

                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                        return True

                                    if self.ipv4vpn_address is not None:
                                        return True

                                    if self.ipv4vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv4vpna_mcastddress is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    if self.ipv6_flowspec_address is not None:
                                        return True

                                    if self.ipv6_label_address is not None:
                                        return True

                                    if self.ipv6_mcast_address is not None:
                                        return True

                                    if self.ipv6mvpn_address is not None:
                                        return True

                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                        return True

                                    if self.ipv6vpn_address is not None:
                                        return True

                                    if self.ipv6vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv6vpn_mcast_address is not None:
                                        return True

                                    if self.l2vpn_evpn_address is not None:
                                        return True

                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                        return True

                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                        return True

                                    if self.ls_ls_address is not None:
                                        return True

                                    if self.rt_constraint_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr']['meta_info']


                            class AfIndependentConfig(object):
                                """
                                AF\-independent config
                                
                                .. attribute:: addpath_receive_capability
                                
                                	Indicates if addpath receive capability is enabled or disabled
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: addpath_receive_capability_info
                                
                                	Addpath receive capability info
                                	**type**\:   :py:class:`AddpathReceiveCapabilityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo>`
                                
                                .. attribute:: addpath_send_capability
                                
                                	Indicates if addpath send capability is enabled or disabled
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: addpath_send_capability_info
                                
                                	Addpath send capability info
                                	**type**\:   :py:class:`AddpathSendCapabilityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo>`
                                
                                .. attribute:: adminstrative_shutdown
                                
                                	Administrative shutdown
                                	**type**\:  bool
                                
                                .. attribute:: bestpath_use_origin_as_validity
                                
                                	Bestpath Use Origin\-AS Va
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd
                                
                                	Fast failure detection using BFD
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_info
                                
                                	BFD item info
                                	**type**\:   :py:class:`BfdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo>`
                                
                                .. attribute:: bfd_mininterval
                                
                                	BFD Minimum Interval
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_mininterval_info
                                
                                	BFD Mininterval item info
                                	**type**\:   :py:class:`BfdMinintervalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo>`
                                
                                .. attribute:: bfd_multiplier
                                
                                	BFD Multiplier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_multiplier_info
                                
                                	BFD Multiplier item info
                                	**type**\:   :py:class:`BfdMultiplierInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo>`
                                
                                .. attribute:: bgp_buffer_receive_size
                                
                                	BGP receive buffer size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bgp_buffer_send_size
                                
                                	BGP send buffer size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_servers
                                
                                	BMP Servers activated
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_servers_info
                                
                                	BMP Servers Configuredinfo
                                	**type**\:   :py:class:`BmpServersInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo>`
                                
                                .. attribute:: capability_negotiation_suppressed
                                
                                	Capability negotiation is suppressed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: capability_negotiation_suppressed_info
                                
                                	Capability negotiation suppressed info
                                	**type**\:   :py:class:`CapabilityNegotiationSuppressedInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo>`
                                
                                .. attribute:: cluster_id_info
                                
                                	Cluster ID item info
                                	**type**\:   :py:class:`ClusterIdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo>`
                                
                                .. attribute:: configured_speaker_id
                                
                                	Configured speaker ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: description
                                
                                	Description
                                	**type**\:  str
                                
                                .. attribute:: description_info
                                
                                	Description item info
                                	**type**\:   :py:class:`DescriptionInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo>`
                                
                                .. attribute:: dmz_link_bandwidth
                                
                                	Propagate the DMZ link bandwidth
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: dmz_link_bandwidth_info
                                
                                	DMZ link bandwidth item 
                                	**type**\:   :py:class:`DmzLinkBandwidthInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo>`
                                
                                .. attribute:: ebgp_hop_count
                                
                                	EBGP neighbors hop count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ebgp_hop_count_info
                                
                                	EBGP neighbors hop count item info
                                	**type**\:   :py:class:`EbgpHopCountInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo>`
                                
                                .. attribute:: ebgp_recv_dmz
                                
                                	Receive Bandwidth of link to single\-hop eBGP peer
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ebgp_recv_dmz_info
                                
                                	EBGP receive DMZ link bandwidth item info
                                	**type**\:   :py:class:`EbgpRecvDmzInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo>`
                                
                                .. attribute:: ebgp_send_dmz_info
                                
                                	EBGP send DMZ link bandwidth item info
                                	**type**\:   :py:class:`EbgpSendDmzInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo>`
                                
                                .. attribute:: ebgp_send_dmz_mode
                                
                                	Send DMZ link bandwidthto ebgp peer
                                	**type**\:   :py:class:`BgpEbgpSendDmzEnableModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableModeEnum>`
                                
                                .. attribute:: egress_peer_engineering
                                
                                	Indicates egress peer engineering is enabled
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: egress_peer_engineering_info
                                
                                	Egress Peer Engineering info
                                	**type**\:   :py:class:`EgressPeerEngineeringInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo>`
                                
                                .. attribute:: graceful_restart_disabled
                                
                                	Support for graceful\-restart
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: graceful_restart_disabled_info
                                
                                	Graceful\-restart item info
                                	**type**\:   :py:class:`GracefulRestartDisabledInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo>`
                                
                                .. attribute:: graceful_shutdown_activate
                                
                                	Graceful Shutdown state is activated
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: graceful_shutdown_activate_info
                                
                                	GracefulShutdownAcivate info
                                	**type**\:   :py:class:`GracefulShutdownActivateInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo>`
                                
                                .. attribute:: graceful_shutdown_as_prepends
                                
                                	Prepend the local AS this many times to the AS path of routes advertised during Graceful Shutdown
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: graceful_shutdown_as_prepends_info
                                
                                	GracefulShutdownASPrepends info
                                	**type**\:   :py:class:`GracefulShutdownAsPrependsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo>`
                                
                                .. attribute:: graceful_shutdown_exists
                                
                                	re\-advertise all routes to and from this neighbor with the GSHUT community during Shutdown or bring\-up
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: graceful_shutdown_info
                                
                                	GracefulShutdown info
                                	**type**\:   :py:class:`GracefulShutdownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo>`
                                
                                .. attribute:: graceful_shutdown_loc_pref
                                
                                	Local Preference to advertise routes with during Graceful Shutdown to IBGP. Default=No Touch
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: graceful_shutdown_loc_pref_info
                                
                                	GracefulShutdownLocPref info
                                	**type**\:   :py:class:`GracefulShutdownLocPrefInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo>`
                                
                                .. attribute:: hold_time_value
                                
                                	Holdtime
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: idle_watch_time
                                
                                	Idle Watch time(in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: idle_watch_time_info
                                
                                	Idle Watch time item info
                                	**type**\:   :py:class:`IdleWatchTimeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo>`
                                
                                .. attribute:: ignore_connected_check
                                
                                	If true, don't do NHconnected check for nbr
                                	**type**\:  bool
                                
                                .. attribute:: ignore_connected_info
                                
                                	Ignore Connected Info
                                	**type**\:   :py:class:`IgnoreConnectedInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo>`
                                
                                .. attribute:: internal_vpn_client
                                
                                	If true, the VPN client isan iBGP CE peer
                                	**type**\:  bool
                                
                                .. attribute:: internal_vpn_client_info
                                
                                	Internal VPN Client Info
                                	**type**\:   :py:class:`InternalVpnClientInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo>`
                                
                                .. attribute:: is_ebgp_multihop_bgpmpls_forwarding_disabled
                                
                                	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                                	**type**\:  bool
                                
                                .. attribute:: keepalive_interval
                                
                                	Keepalive interval
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: keychain
                                
                                	Neighbor keychain Name
                                	**type**\:  str
                                
                                .. attribute:: keychain_info
                                
                                	Neighbor Keychain item info
                                	**type**\:   :py:class:`KeychainInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo>`
                                
                                .. attribute:: local_address_info
                                
                                	Local address item info
                                	**type**\:   :py:class:`LocalAddressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo>`
                                
                                .. attribute:: local_as_dual_as
                                
                                	Local AS Dual\-AS option
                                	**type**\:  bool
                                
                                .. attribute:: local_as_info
                                
                                	Local AS number item info
                                	**type**\:   :py:class:`LocalAsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo>`
                                
                                .. attribute:: local_as_no_prepend
                                
                                	Local AS no\-prepend option
                                	**type**\:  bool
                                
                                .. attribute:: local_as_number_xx
                                
                                	First half of Local ASN
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_as_number_yy
                                
                                	Second half of Local ASN
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_as_replace_as
                                
                                	Local AS Replace\-AS option
                                	**type**\:  bool
                                
                                .. attribute:: local_ip_address
                                
                                	Local ipv4 or ipv6 address for neighbor connection
                                	**type**\:   :py:class:`LocalIpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress>`
                                
                                .. attribute:: max_peers
                                
                                	Maximum dynamic nbrs in range
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max_peers_info
                                
                                	Max dynamic nbrs in range info
                                	**type**\:   :py:class:`MaxPeersInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo>`
                                
                                .. attribute:: min_acc_hold_time_value
                                
                                	Min acceptable holdtimefrom neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: min_advertisement_info
                                
                                	Minimum advertisement interval item info
                                	**type**\:   :py:class:`MinAdvertisementInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo>`
                                
                                .. attribute:: min_advertisement_interval
                                
                                	Minimum advertisement interval, secs part
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: min_advertisement_interval_msecs
                                
                                	Minimum advertisement interval, msecs part
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: msg_log_in_buf_count
                                
                                	Message Log Inbound buffer count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: msg_log_in_info
                                
                                	Message Log Inbound item info
                                	**type**\:   :py:class:`MsgLogInInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo>`
                                
                                .. attribute:: msg_log_out_buf_count
                                
                                	Message Log Outbound buffer count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: msg_log_out_info
                                
                                	Message Log Outbound item info
                                	**type**\:   :py:class:`MsgLogOutInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo>`
                                
                                .. attribute:: nbr_cluster_id_info
                                
                                	Cluster ID value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nbr_cluster_id_type_info
                                
                                	Cluster ID Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: nbr_enforce_first_as_info
                                
                                	Neighbor enforce first AS info
                                	**type**\:   :py:class:`NbrEnforceFirstAsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo>`
                                
                                .. attribute:: nbr_enforce_first_as_status
                                
                                	Neighbor enforce first AS status
                                	**type**\:  bool
                                
                                .. attribute:: nbr_restart_time
                                
                                	Restart time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nbr_restart_time_info
                                
                                	Restart time item info
                                	**type**\:   :py:class:`NbrRestartTimeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo>`
                                
                                .. attribute:: nbr_stale_path_time
                                
                                	Stale\-path time(in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nbr_stale_path_time_info
                                
                                	Stale\-path time item info
                                	**type**\:   :py:class:`NbrStalePathTimeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo>`
                                
                                .. attribute:: neighbor_remote_as_list_group_name
                                
                                	Neighbor Range remote\-as\-list group name
                                	**type**\:  str
                                
                                .. attribute:: neighbor_remote_as_list_info
                                
                                	Neighbor range  remote\-as\-list group info
                                	**type**\:   :py:class:`NeighborRemoteAsListInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo>`
                                
                                .. attribute:: neighbor_update_filter_attribute_filter_group_name
                                
                                	Neighbor filter attribute\-filter group name
                                	**type**\:  str
                                
                                .. attribute:: neighbor_update_filter_attribute_info
                                
                                	Neighbor update filter attribute\-filter group info
                                	**type**\:   :py:class:`NeighborUpdateFilterAttributeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo>`
                                
                                .. attribute:: neighbor_update_filter_exists
                                
                                	Indicates if neighbor filter configuration exists
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_update_filter_exists_info
                                
                                	Neighbor update filter configuration info
                                	**type**\:   :py:class:`NeighborUpdateFilterExistsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo>`
                                
                                .. attribute:: neighbor_update_filter_logging_disable
                                
                                	Indicates if neighbor filter logging is disabled
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_update_filter_message_buffer_count
                                
                                	Count of neighbor filter message buffers
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_update_filter_message_buffer_count_info
                                
                                	Neighbor update filter message buffer count info
                                	**type**\:   :py:class:`NeighborUpdateFilterMessageBufferCountInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo>`
                                
                                .. attribute:: neighbor_update_filter_message_buffer_is_non_circular
                                
                                	Indicates if neighbor update filter message buffer is circular or not
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_update_filter_syslog_disable_info
                                
                                	Neighbor update filter syslog disable info
                                	**type**\:   :py:class:`NeighborUpdateFilterSyslogDisableInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo>`
                                
                                .. attribute:: nsr_disabled
                                
                                	Support for NSR
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_disabled_info
                                
                                	NSR item info
                                	**type**\:   :py:class:`NsrDisabledInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo>`
                                
                                .. attribute:: password
                                
                                	Neighbor password
                                	**type**\:  str
                                
                                .. attribute:: password_info
                                
                                	Neighbor password item info
                                	**type**\:   :py:class:`PasswordInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo>`
                                
                                .. attribute:: prefix_validation_allow_invalid
                                
                                	Prefix vallidation allow invalid
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefix_validation_allow_invalid_info
                                
                                	RPKI allow invalid info
                                	**type**\:   :py:class:`PrefixValidationAllowInvalidInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo>`
                                
                                .. attribute:: prefix_validation_disable
                                
                                	Prefix validation disable
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefix_validation_disable_info
                                
                                	RPKI disable info
                                	**type**\:   :py:class:`PrefixValidationDisableInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo>`
                                
                                .. attribute:: prefix_validation_signal_ibgp
                                
                                	Prefix validation signal ibgp
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefix_validation_signal_ibgp_info
                                
                                	RPKI signal ibgp info
                                	**type**\:   :py:class:`PrefixValidationSignalIbgpInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo>`
                                
                                .. attribute:: prefix_validation_use_validit_info
                                
                                	RPKI use validity
                                	**type**\:   :py:class:`PrefixValidationUseValiditInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo>`
                                
                                .. attribute:: receive_buffer_info
                                
                                	Receive buffer sizes item info
                                	**type**\:   :py:class:`ReceiveBufferInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo>`
                                
                                .. attribute:: remote_as_info
                                
                                	Remote AS number item info
                                	**type**\:   :py:class:`RemoteAsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo>`
                                
                                .. attribute:: remote_as_number_xx
                                
                                	First half of Remote ASN
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_as_number_yy
                                
                                	Second half of Remote ASN
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_updates_source
                                
                                	Source of routing updates
                                	**type**\:  str
                                
                                .. attribute:: send_buffer_info
                                
                                	Send buffer sizes item info
                                	**type**\:   :py:class:`SendBufferInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo>`
                                
                                .. attribute:: session_open_mode
                                
                                	TCP open mode to be used 
                                	**type**\:   :py:class:`BgpTcpModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpModeEnum>`
                                
                                .. attribute:: session_open_mode_info
                                
                                	TCP conn open mode info
                                	**type**\:   :py:class:`SessionOpenModeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo>`
                                
                                .. attribute:: shutdown_info
                                
                                	Shutdown item info
                                	**type**\:   :py:class:`ShutdownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo>`
                                
                                .. attribute:: socket_buffer_receive_size
                                
                                	Socket receive buffer size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: socket_buffer_send_size
                                
                                	Socket send buffer size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: speaker_id_info
                                
                                	Configured speaker ID item info
                                	**type**\:   :py:class:`SpeakerIdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo>`
                                
                                .. attribute:: suppress4_bbyte_as_info
                                
                                	BGP suppress 4byte\-as item info
                                	**type**\:   :py:class:`Suppress4BbyteAsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo>`
                                
                                .. attribute:: suppress4_byte_as
                                
                                	Suppress BGP 4byteas Cap
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tcp_mss
                                
                                	Maximum Segment Size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tcpmss_info
                                
                                	TCP Maximum Segment Size item info
                                	**type**\:   :py:class:`TcpmssInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo>`
                                
                                .. attribute:: timers_info
                                
                                	Timers item info
                                	**type**\:   :py:class:`TimersInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo>`
                                
                                .. attribute:: tos_info
                                
                                	TOS item info
                                	**type**\:   :py:class:`TosInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo>`
                                
                                .. attribute:: tos_type_info
                                
                                	Precedence or DSCP type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_value_info
                                
                                	Precedence or DSCP value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ttl_security
                                
                                	Enable BGP TTL Security
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ttl_security_info
                                
                                	BGP TTL Security item info
                                	**type**\:   :py:class:`TtlSecurityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo>`
                                
                                .. attribute:: update_error_handling_no_reset
                                
                                	Indicates if avoid\-reset behavior is enabled during update error\-handling
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_error_handling_no_reset_info
                                
                                	Error\-handling avoid\-reset config info
                                	**type**\:   :py:class:`UpdateErrorHandlingNoResetInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo>`
                                
                                .. attribute:: update_source_info
                                
                                	Update source item info
                                	**type**\:   :py:class:`UpdateSourceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.addpath_receive_capability = None
                                    self.addpath_receive_capability_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo()
                                    self.addpath_receive_capability_info.parent = self
                                    self.addpath_send_capability = None
                                    self.addpath_send_capability_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo()
                                    self.addpath_send_capability_info.parent = self
                                    self.adminstrative_shutdown = None
                                    self.bestpath_use_origin_as_validity = None
                                    self.bfd = None
                                    self.bfd_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo()
                                    self.bfd_info.parent = self
                                    self.bfd_mininterval = None
                                    self.bfd_mininterval_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo()
                                    self.bfd_mininterval_info.parent = self
                                    self.bfd_multiplier = None
                                    self.bfd_multiplier_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo()
                                    self.bfd_multiplier_info.parent = self
                                    self.bgp_buffer_receive_size = None
                                    self.bgp_buffer_send_size = None
                                    self.bmp_servers = None
                                    self.bmp_servers_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo()
                                    self.bmp_servers_info.parent = self
                                    self.capability_negotiation_suppressed = None
                                    self.capability_negotiation_suppressed_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo()
                                    self.capability_negotiation_suppressed_info.parent = self
                                    self.cluster_id_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo()
                                    self.cluster_id_info.parent = self
                                    self.configured_speaker_id = None
                                    self.description = None
                                    self.description_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo()
                                    self.description_info.parent = self
                                    self.dmz_link_bandwidth = None
                                    self.dmz_link_bandwidth_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo()
                                    self.dmz_link_bandwidth_info.parent = self
                                    self.ebgp_hop_count = None
                                    self.ebgp_hop_count_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo()
                                    self.ebgp_hop_count_info.parent = self
                                    self.ebgp_recv_dmz = None
                                    self.ebgp_recv_dmz_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo()
                                    self.ebgp_recv_dmz_info.parent = self
                                    self.ebgp_send_dmz_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo()
                                    self.ebgp_send_dmz_info.parent = self
                                    self.ebgp_send_dmz_mode = None
                                    self.egress_peer_engineering = None
                                    self.egress_peer_engineering_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo()
                                    self.egress_peer_engineering_info.parent = self
                                    self.graceful_restart_disabled = None
                                    self.graceful_restart_disabled_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo()
                                    self.graceful_restart_disabled_info.parent = self
                                    self.graceful_shutdown_activate = None
                                    self.graceful_shutdown_activate_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo()
                                    self.graceful_shutdown_activate_info.parent = self
                                    self.graceful_shutdown_as_prepends = None
                                    self.graceful_shutdown_as_prepends_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo()
                                    self.graceful_shutdown_as_prepends_info.parent = self
                                    self.graceful_shutdown_exists = None
                                    self.graceful_shutdown_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo()
                                    self.graceful_shutdown_info.parent = self
                                    self.graceful_shutdown_loc_pref = None
                                    self.graceful_shutdown_loc_pref_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo()
                                    self.graceful_shutdown_loc_pref_info.parent = self
                                    self.hold_time_value = None
                                    self.idle_watch_time = None
                                    self.idle_watch_time_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo()
                                    self.idle_watch_time_info.parent = self
                                    self.ignore_connected_check = None
                                    self.ignore_connected_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo()
                                    self.ignore_connected_info.parent = self
                                    self.internal_vpn_client = None
                                    self.internal_vpn_client_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo()
                                    self.internal_vpn_client_info.parent = self
                                    self.is_ebgp_multihop_bgpmpls_forwarding_disabled = None
                                    self.keepalive_interval = None
                                    self.keychain = None
                                    self.keychain_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo()
                                    self.keychain_info.parent = self
                                    self.local_address_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo()
                                    self.local_address_info.parent = self
                                    self.local_as_dual_as = None
                                    self.local_as_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo()
                                    self.local_as_info.parent = self
                                    self.local_as_no_prepend = None
                                    self.local_as_number_xx = None
                                    self.local_as_number_yy = None
                                    self.local_as_replace_as = None
                                    self.local_ip_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress()
                                    self.local_ip_address.parent = self
                                    self.max_peers = None
                                    self.max_peers_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo()
                                    self.max_peers_info.parent = self
                                    self.min_acc_hold_time_value = None
                                    self.min_advertisement_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo()
                                    self.min_advertisement_info.parent = self
                                    self.min_advertisement_interval = None
                                    self.min_advertisement_interval_msecs = None
                                    self.msg_log_in_buf_count = None
                                    self.msg_log_in_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo()
                                    self.msg_log_in_info.parent = self
                                    self.msg_log_out_buf_count = None
                                    self.msg_log_out_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo()
                                    self.msg_log_out_info.parent = self
                                    self.nbr_cluster_id_info = None
                                    self.nbr_cluster_id_type_info = None
                                    self.nbr_enforce_first_as_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo()
                                    self.nbr_enforce_first_as_info.parent = self
                                    self.nbr_enforce_first_as_status = None
                                    self.nbr_restart_time = None
                                    self.nbr_restart_time_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo()
                                    self.nbr_restart_time_info.parent = self
                                    self.nbr_stale_path_time = None
                                    self.nbr_stale_path_time_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo()
                                    self.nbr_stale_path_time_info.parent = self
                                    self.neighbor_remote_as_list_group_name = None
                                    self.neighbor_remote_as_list_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo()
                                    self.neighbor_remote_as_list_info.parent = self
                                    self.neighbor_update_filter_attribute_filter_group_name = None
                                    self.neighbor_update_filter_attribute_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo()
                                    self.neighbor_update_filter_attribute_info.parent = self
                                    self.neighbor_update_filter_exists = None
                                    self.neighbor_update_filter_exists_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo()
                                    self.neighbor_update_filter_exists_info.parent = self
                                    self.neighbor_update_filter_logging_disable = None
                                    self.neighbor_update_filter_message_buffer_count = None
                                    self.neighbor_update_filter_message_buffer_count_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo()
                                    self.neighbor_update_filter_message_buffer_count_info.parent = self
                                    self.neighbor_update_filter_message_buffer_is_non_circular = None
                                    self.neighbor_update_filter_syslog_disable_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo()
                                    self.neighbor_update_filter_syslog_disable_info.parent = self
                                    self.nsr_disabled = None
                                    self.nsr_disabled_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo()
                                    self.nsr_disabled_info.parent = self
                                    self.password = None
                                    self.password_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo()
                                    self.password_info.parent = self
                                    self.prefix_validation_allow_invalid = None
                                    self.prefix_validation_allow_invalid_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo()
                                    self.prefix_validation_allow_invalid_info.parent = self
                                    self.prefix_validation_disable = None
                                    self.prefix_validation_disable_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo()
                                    self.prefix_validation_disable_info.parent = self
                                    self.prefix_validation_signal_ibgp = None
                                    self.prefix_validation_signal_ibgp_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo()
                                    self.prefix_validation_signal_ibgp_info.parent = self
                                    self.prefix_validation_use_validit_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo()
                                    self.prefix_validation_use_validit_info.parent = self
                                    self.receive_buffer_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo()
                                    self.receive_buffer_info.parent = self
                                    self.remote_as_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo()
                                    self.remote_as_info.parent = self
                                    self.remote_as_number_xx = None
                                    self.remote_as_number_yy = None
                                    self.route_updates_source = None
                                    self.send_buffer_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo()
                                    self.send_buffer_info.parent = self
                                    self.session_open_mode = None
                                    self.session_open_mode_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo()
                                    self.session_open_mode_info.parent = self
                                    self.shutdown_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo()
                                    self.shutdown_info.parent = self
                                    self.socket_buffer_receive_size = None
                                    self.socket_buffer_send_size = None
                                    self.speaker_id_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo()
                                    self.speaker_id_info.parent = self
                                    self.suppress4_bbyte_as_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo()
                                    self.suppress4_bbyte_as_info.parent = self
                                    self.suppress4_byte_as = None
                                    self.tcp_mss = None
                                    self.tcpmss_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo()
                                    self.tcpmss_info.parent = self
                                    self.timers_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo()
                                    self.timers_info.parent = self
                                    self.tos_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo()
                                    self.tos_info.parent = self
                                    self.tos_type_info = None
                                    self.tos_value_info = None
                                    self.ttl_security = None
                                    self.ttl_security_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo()
                                    self.ttl_security_info.parent = self
                                    self.update_error_handling_no_reset = None
                                    self.update_error_handling_no_reset_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo()
                                    self.update_error_handling_no_reset_info.parent = self
                                    self.update_source_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo()
                                    self.update_source_info.parent = self


                                class LocalIpAddress(object):
                                    """
                                    Local ipv4 or ipv6 address for neighbor
                                    connection
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpnvpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2VpnvplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4mdt_address = None
                                        self.ipv4mvpn_address = None
                                        self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv4SrPolicyAddress()
                                        self.ipv4sr_policy_address.parent = self
                                        self.ipv4vpn_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv6SrPolicyAddress()
                                        self.ipv6sr_policy_address.parent = self
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_flowspec_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.l2vpn_evpn_address = None
                                        self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2VpnvplsAddress()
                                        self.l2vpnvpls_address.parent = self
                                        self.ls_ls_address = None
                                        self.rt_constraint_address = None


                                    class L2VpnvplsAddress(object):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2VpnvplsAddress']['meta_info']


                                    class L2VpnMspwAddress(object):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2VpnMspwAddress']['meta_info']


                                    class Ipv4SrPolicyAddress(object):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv4SrPolicyAddress']['meta_info']


                                    class Ipv6SrPolicyAddress(object):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv6_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv6_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv6SrPolicyAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-ip-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.afi is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv4_flowspec_address is not None:
                                            return True

                                        if self.ipv4_label_address is not None:
                                            return True

                                        if self.ipv4_mcast_address is not None:
                                            return True

                                        if self.ipv4_tunnel_address is not None:
                                            return True

                                        if self.ipv4mdt_address is not None:
                                            return True

                                        if self.ipv4mvpn_address is not None:
                                            return True

                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                            return True

                                        if self.ipv4vpn_address is not None:
                                            return True

                                        if self.ipv4vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv4vpna_mcastddress is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        if self.ipv6_flowspec_address is not None:
                                            return True

                                        if self.ipv6_label_address is not None:
                                            return True

                                        if self.ipv6_mcast_address is not None:
                                            return True

                                        if self.ipv6mvpn_address is not None:
                                            return True

                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                            return True

                                        if self.ipv6vpn_address is not None:
                                            return True

                                        if self.ipv6vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv6vpn_mcast_address is not None:
                                            return True

                                        if self.l2vpn_evpn_address is not None:
                                            return True

                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                            return True

                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                            return True

                                        if self.ls_ls_address is not None:
                                            return True

                                        if self.rt_constraint_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress']['meta_info']


                                class RemoteAsInfo(object):
                                    """
                                    Remote AS number item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:remote-as-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo']['meta_info']


                                class SpeakerIdInfo(object):
                                    """
                                    Configured speaker ID item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:speaker-id-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo']['meta_info']


                                class MinAdvertisementInfo(object):
                                    """
                                    Minimum advertisement interval item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:min-advertisement-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo']['meta_info']


                                class DescriptionInfo(object):
                                    """
                                    Description item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:description-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo']['meta_info']


                                class EbgpHopCountInfo(object):
                                    """
                                    EBGP neighbors hop count item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ebgp-hop-count-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo']['meta_info']


                                class TcpmssInfo(object):
                                    """
                                    TCP Maximum Segment Size item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tcpmss-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo']['meta_info']


                                class BmpServersInfo(object):
                                    """
                                    BMP Servers Configuredinfo
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-servers-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo']['meta_info']


                                class KeychainInfo(object):
                                    """
                                    Neighbor Keychain item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:keychain-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo']['meta_info']


                                class LocalAsInfo(object):
                                    """
                                    Local AS number item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-as-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo']['meta_info']


                                class PasswordInfo(object):
                                    """
                                    Neighbor password item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:password-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo']['meta_info']


                                class ReceiveBufferInfo(object):
                                    """
                                    Receive buffer sizes item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:receive-buffer-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo']['meta_info']


                                class SendBufferInfo(object):
                                    """
                                    Send buffer sizes item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:send-buffer-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo']['meta_info']


                                class ShutdownInfo(object):
                                    """
                                    Shutdown item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:shutdown-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo']['meta_info']


                                class TimersInfo(object):
                                    """
                                    Timers item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:timers-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo']['meta_info']


                                class LocalAddressInfo(object):
                                    """
                                    Local address item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-address-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo']['meta_info']


                                class MsgLogInInfo(object):
                                    """
                                    Message Log Inbound item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:msg-log-in-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo']['meta_info']


                                class MsgLogOutInfo(object):
                                    """
                                    Message Log Outbound item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:msg-log-out-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo']['meta_info']


                                class UpdateSourceInfo(object):
                                    """
                                    Update source item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-source-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo']['meta_info']


                                class DmzLinkBandwidthInfo(object):
                                    """
                                    DMZ link bandwidth item 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:dmz-link-bandwidth-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo']['meta_info']


                                class EbgpRecvDmzInfo(object):
                                    """
                                    EBGP receive DMZ link bandwidth item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ebgp-recv-dmz-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo']['meta_info']


                                class EbgpSendDmzInfo(object):
                                    """
                                    EBGP send DMZ link bandwidth item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ebgp-send-dmz-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo']['meta_info']


                                class TtlSecurityInfo(object):
                                    """
                                    BGP TTL Security item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ttl-security-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo']['meta_info']


                                class Suppress4BbyteAsInfo(object):
                                    """
                                    BGP suppress 4byte\-as item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:suppress4-bbyte-as-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo']['meta_info']


                                class SessionOpenModeInfo(object):
                                    """
                                    TCP conn open mode info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:session-open-mode-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo']['meta_info']


                                class BfdInfo(object):
                                    """
                                    BFD item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bfd-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo']['meta_info']


                                class BfdMinintervalInfo(object):
                                    """
                                    BFD Mininterval item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bfd-mininterval-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo']['meta_info']


                                class BfdMultiplierInfo(object):
                                    """
                                    BFD Multiplier item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bfd-multiplier-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo']['meta_info']


                                class TosInfo(object):
                                    """
                                    TOS item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tos-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo']['meta_info']


                                class NsrDisabledInfo(object):
                                    """
                                    NSR item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nsr-disabled-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo']['meta_info']


                                class GracefulRestartDisabledInfo(object):
                                    """
                                    Graceful\-restart item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:graceful-restart-disabled-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo']['meta_info']


                                class NbrRestartTimeInfo(object):
                                    """
                                    Restart time item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nbr-restart-time-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo']['meta_info']


                                class NbrStalePathTimeInfo(object):
                                    """
                                    Stale\-path time item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nbr-stale-path-time-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo']['meta_info']


                                class NbrEnforceFirstAsInfo(object):
                                    """
                                    Neighbor enforce first AS info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nbr-enforce-first-as-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo']['meta_info']


                                class ClusterIdInfo(object):
                                    """
                                    Cluster ID item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster-id-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo']['meta_info']


                                class IgnoreConnectedInfo(object):
                                    """
                                    Ignore Connected Info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ignore-connected-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo']['meta_info']


                                class InternalVpnClientInfo(object):
                                    """
                                    Internal VPN Client Info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:internal-vpn-client-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo']['meta_info']


                                class AddpathSendCapabilityInfo(object):
                                    """
                                    Addpath send capability info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:addpath-send-capability-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo']['meta_info']


                                class AddpathReceiveCapabilityInfo(object):
                                    """
                                    Addpath receive capability info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:addpath-receive-capability-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo']['meta_info']


                                class EgressPeerEngineeringInfo(object):
                                    """
                                    Egress Peer Engineering info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:egress-peer-engineering-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo']['meta_info']


                                class UpdateErrorHandlingNoResetInfo(object):
                                    """
                                    Error\-handling avoid\-reset config info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-error-handling-no-reset-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo']['meta_info']


                                class PrefixValidationDisableInfo(object):
                                    """
                                    RPKI disable info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix-validation-disable-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo']['meta_info']


                                class PrefixValidationUseValiditInfo(object):
                                    """
                                    RPKI use validity
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix-validation-use-validit-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo']['meta_info']


                                class PrefixValidationAllowInvalidInfo(object):
                                    """
                                    RPKI allow invalid info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix-validation-allow-invalid-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo']['meta_info']


                                class PrefixValidationSignalIbgpInfo(object):
                                    """
                                    RPKI signal ibgp info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix-validation-signal-ibgp-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo']['meta_info']


                                class NeighborUpdateFilterExistsInfo(object):
                                    """
                                    Neighbor update filter configuration info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-update-filter-exists-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo']['meta_info']


                                class NeighborUpdateFilterMessageBufferCountInfo(object):
                                    """
                                    Neighbor update filter message buffer count info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-update-filter-message-buffer-count-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo']['meta_info']


                                class NeighborUpdateFilterSyslogDisableInfo(object):
                                    """
                                    Neighbor update filter syslog disable info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-update-filter-syslog-disable-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo']['meta_info']


                                class NeighborUpdateFilterAttributeInfo(object):
                                    """
                                    Neighbor update filter attribute\-filter group
                                    info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-update-filter-attribute-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo']['meta_info']


                                class GracefulShutdownInfo(object):
                                    """
                                    GracefulShutdown info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:graceful-shutdown-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo']['meta_info']


                                class GracefulShutdownLocPrefInfo(object):
                                    """
                                    GracefulShutdownLocPref info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:graceful-shutdown-loc-pref-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo']['meta_info']


                                class GracefulShutdownAsPrependsInfo(object):
                                    """
                                    GracefulShutdownASPrepends info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:graceful-shutdown-as-prepends-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo']['meta_info']


                                class GracefulShutdownActivateInfo(object):
                                    """
                                    GracefulShutdownAcivate info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:graceful-shutdown-activate-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo']['meta_info']


                                class CapabilityNegotiationSuppressedInfo(object):
                                    """
                                    Capability negotiation suppressed info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:capability-negotiation-suppressed-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo']['meta_info']


                                class NeighborRemoteAsListInfo(object):
                                    """
                                    Neighbor range  remote\-as\-list group info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-remote-as-list-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo']['meta_info']


                                class MaxPeersInfo(object):
                                    """
                                    Max dynamic nbrs in range info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:max-peers-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo']['meta_info']


                                class IdleWatchTimeInfo(object):
                                    """
                                    Idle Watch time item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:idle-watch-time-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af-independent-config'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.addpath_receive_capability is not None:
                                        return True

                                    if self.addpath_receive_capability_info is not None and self.addpath_receive_capability_info._has_data():
                                        return True

                                    if self.addpath_send_capability is not None:
                                        return True

                                    if self.addpath_send_capability_info is not None and self.addpath_send_capability_info._has_data():
                                        return True

                                    if self.adminstrative_shutdown is not None:
                                        return True

                                    if self.bestpath_use_origin_as_validity is not None:
                                        return True

                                    if self.bfd is not None:
                                        return True

                                    if self.bfd_info is not None and self.bfd_info._has_data():
                                        return True

                                    if self.bfd_mininterval is not None:
                                        return True

                                    if self.bfd_mininterval_info is not None and self.bfd_mininterval_info._has_data():
                                        return True

                                    if self.bfd_multiplier is not None:
                                        return True

                                    if self.bfd_multiplier_info is not None and self.bfd_multiplier_info._has_data():
                                        return True

                                    if self.bgp_buffer_receive_size is not None:
                                        return True

                                    if self.bgp_buffer_send_size is not None:
                                        return True

                                    if self.bmp_servers is not None:
                                        return True

                                    if self.bmp_servers_info is not None and self.bmp_servers_info._has_data():
                                        return True

                                    if self.capability_negotiation_suppressed is not None:
                                        return True

                                    if self.capability_negotiation_suppressed_info is not None and self.capability_negotiation_suppressed_info._has_data():
                                        return True

                                    if self.cluster_id_info is not None and self.cluster_id_info._has_data():
                                        return True

                                    if self.configured_speaker_id is not None:
                                        return True

                                    if self.description is not None:
                                        return True

                                    if self.description_info is not None and self.description_info._has_data():
                                        return True

                                    if self.dmz_link_bandwidth is not None:
                                        return True

                                    if self.dmz_link_bandwidth_info is not None and self.dmz_link_bandwidth_info._has_data():
                                        return True

                                    if self.ebgp_hop_count is not None:
                                        return True

                                    if self.ebgp_hop_count_info is not None and self.ebgp_hop_count_info._has_data():
                                        return True

                                    if self.ebgp_recv_dmz is not None:
                                        return True

                                    if self.ebgp_recv_dmz_info is not None and self.ebgp_recv_dmz_info._has_data():
                                        return True

                                    if self.ebgp_send_dmz_info is not None and self.ebgp_send_dmz_info._has_data():
                                        return True

                                    if self.ebgp_send_dmz_mode is not None:
                                        return True

                                    if self.egress_peer_engineering is not None:
                                        return True

                                    if self.egress_peer_engineering_info is not None and self.egress_peer_engineering_info._has_data():
                                        return True

                                    if self.graceful_restart_disabled is not None:
                                        return True

                                    if self.graceful_restart_disabled_info is not None and self.graceful_restart_disabled_info._has_data():
                                        return True

                                    if self.graceful_shutdown_activate is not None:
                                        return True

                                    if self.graceful_shutdown_activate_info is not None and self.graceful_shutdown_activate_info._has_data():
                                        return True

                                    if self.graceful_shutdown_as_prepends is not None:
                                        return True

                                    if self.graceful_shutdown_as_prepends_info is not None and self.graceful_shutdown_as_prepends_info._has_data():
                                        return True

                                    if self.graceful_shutdown_exists is not None:
                                        return True

                                    if self.graceful_shutdown_info is not None and self.graceful_shutdown_info._has_data():
                                        return True

                                    if self.graceful_shutdown_loc_pref is not None:
                                        return True

                                    if self.graceful_shutdown_loc_pref_info is not None and self.graceful_shutdown_loc_pref_info._has_data():
                                        return True

                                    if self.hold_time_value is not None:
                                        return True

                                    if self.idle_watch_time is not None:
                                        return True

                                    if self.idle_watch_time_info is not None and self.idle_watch_time_info._has_data():
                                        return True

                                    if self.ignore_connected_check is not None:
                                        return True

                                    if self.ignore_connected_info is not None and self.ignore_connected_info._has_data():
                                        return True

                                    if self.internal_vpn_client is not None:
                                        return True

                                    if self.internal_vpn_client_info is not None and self.internal_vpn_client_info._has_data():
                                        return True

                                    if self.is_ebgp_multihop_bgpmpls_forwarding_disabled is not None:
                                        return True

                                    if self.keepalive_interval is not None:
                                        return True

                                    if self.keychain is not None:
                                        return True

                                    if self.keychain_info is not None and self.keychain_info._has_data():
                                        return True

                                    if self.local_address_info is not None and self.local_address_info._has_data():
                                        return True

                                    if self.local_as_dual_as is not None:
                                        return True

                                    if self.local_as_info is not None and self.local_as_info._has_data():
                                        return True

                                    if self.local_as_no_prepend is not None:
                                        return True

                                    if self.local_as_number_xx is not None:
                                        return True

                                    if self.local_as_number_yy is not None:
                                        return True

                                    if self.local_as_replace_as is not None:
                                        return True

                                    if self.local_ip_address is not None and self.local_ip_address._has_data():
                                        return True

                                    if self.max_peers is not None:
                                        return True

                                    if self.max_peers_info is not None and self.max_peers_info._has_data():
                                        return True

                                    if self.min_acc_hold_time_value is not None:
                                        return True

                                    if self.min_advertisement_info is not None and self.min_advertisement_info._has_data():
                                        return True

                                    if self.min_advertisement_interval is not None:
                                        return True

                                    if self.min_advertisement_interval_msecs is not None:
                                        return True

                                    if self.msg_log_in_buf_count is not None:
                                        return True

                                    if self.msg_log_in_info is not None and self.msg_log_in_info._has_data():
                                        return True

                                    if self.msg_log_out_buf_count is not None:
                                        return True

                                    if self.msg_log_out_info is not None and self.msg_log_out_info._has_data():
                                        return True

                                    if self.nbr_cluster_id_info is not None:
                                        return True

                                    if self.nbr_cluster_id_type_info is not None:
                                        return True

                                    if self.nbr_enforce_first_as_info is not None and self.nbr_enforce_first_as_info._has_data():
                                        return True

                                    if self.nbr_enforce_first_as_status is not None:
                                        return True

                                    if self.nbr_restart_time is not None:
                                        return True

                                    if self.nbr_restart_time_info is not None and self.nbr_restart_time_info._has_data():
                                        return True

                                    if self.nbr_stale_path_time is not None:
                                        return True

                                    if self.nbr_stale_path_time_info is not None and self.nbr_stale_path_time_info._has_data():
                                        return True

                                    if self.neighbor_remote_as_list_group_name is not None:
                                        return True

                                    if self.neighbor_remote_as_list_info is not None and self.neighbor_remote_as_list_info._has_data():
                                        return True

                                    if self.neighbor_update_filter_attribute_filter_group_name is not None:
                                        return True

                                    if self.neighbor_update_filter_attribute_info is not None and self.neighbor_update_filter_attribute_info._has_data():
                                        return True

                                    if self.neighbor_update_filter_exists is not None:
                                        return True

                                    if self.neighbor_update_filter_exists_info is not None and self.neighbor_update_filter_exists_info._has_data():
                                        return True

                                    if self.neighbor_update_filter_logging_disable is not None:
                                        return True

                                    if self.neighbor_update_filter_message_buffer_count is not None:
                                        return True

                                    if self.neighbor_update_filter_message_buffer_count_info is not None and self.neighbor_update_filter_message_buffer_count_info._has_data():
                                        return True

                                    if self.neighbor_update_filter_message_buffer_is_non_circular is not None:
                                        return True

                                    if self.neighbor_update_filter_syslog_disable_info is not None and self.neighbor_update_filter_syslog_disable_info._has_data():
                                        return True

                                    if self.nsr_disabled is not None:
                                        return True

                                    if self.nsr_disabled_info is not None and self.nsr_disabled_info._has_data():
                                        return True

                                    if self.password is not None:
                                        return True

                                    if self.password_info is not None and self.password_info._has_data():
                                        return True

                                    if self.prefix_validation_allow_invalid is not None:
                                        return True

                                    if self.prefix_validation_allow_invalid_info is not None and self.prefix_validation_allow_invalid_info._has_data():
                                        return True

                                    if self.prefix_validation_disable is not None:
                                        return True

                                    if self.prefix_validation_disable_info is not None and self.prefix_validation_disable_info._has_data():
                                        return True

                                    if self.prefix_validation_signal_ibgp is not None:
                                        return True

                                    if self.prefix_validation_signal_ibgp_info is not None and self.prefix_validation_signal_ibgp_info._has_data():
                                        return True

                                    if self.prefix_validation_use_validit_info is not None and self.prefix_validation_use_validit_info._has_data():
                                        return True

                                    if self.receive_buffer_info is not None and self.receive_buffer_info._has_data():
                                        return True

                                    if self.remote_as_info is not None and self.remote_as_info._has_data():
                                        return True

                                    if self.remote_as_number_xx is not None:
                                        return True

                                    if self.remote_as_number_yy is not None:
                                        return True

                                    if self.route_updates_source is not None:
                                        return True

                                    if self.send_buffer_info is not None and self.send_buffer_info._has_data():
                                        return True

                                    if self.session_open_mode is not None:
                                        return True

                                    if self.session_open_mode_info is not None and self.session_open_mode_info._has_data():
                                        return True

                                    if self.shutdown_info is not None and self.shutdown_info._has_data():
                                        return True

                                    if self.socket_buffer_receive_size is not None:
                                        return True

                                    if self.socket_buffer_send_size is not None:
                                        return True

                                    if self.speaker_id_info is not None and self.speaker_id_info._has_data():
                                        return True

                                    if self.suppress4_bbyte_as_info is not None and self.suppress4_bbyte_as_info._has_data():
                                        return True

                                    if self.suppress4_byte_as is not None:
                                        return True

                                    if self.tcp_mss is not None:
                                        return True

                                    if self.tcpmss_info is not None and self.tcpmss_info._has_data():
                                        return True

                                    if self.timers_info is not None and self.timers_info._has_data():
                                        return True

                                    if self.tos_info is not None and self.tos_info._has_data():
                                        return True

                                    if self.tos_type_info is not None:
                                        return True

                                    if self.tos_value_info is not None:
                                        return True

                                    if self.ttl_security is not None:
                                        return True

                                    if self.ttl_security_info is not None and self.ttl_security_info._has_data():
                                        return True

                                    if self.update_error_handling_no_reset is not None:
                                        return True

                                    if self.update_error_handling_no_reset_info is not None and self.update_error_handling_no_reset_info._has_data():
                                        return True

                                    if self.update_source_info is not None and self.update_source_info._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig']['meta_info']


                            class AfDependentConfig(object):
                                """
                                Af\-dependent config
                                
                                .. attribute:: accept_own
                                
                                	Accept Own
                                	**type**\:  bool
                                
                                .. attribute:: accept_own_info
                                
                                	Accept\-Own info
                                	**type**\:   :py:class:`AcceptOwnInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo>`
                                
                                .. attribute:: accept_route_legacy_pe_rt
                                
                                	accept\-legacy\-pe RT route
                                	**type**\:  bool
                                
                                .. attribute:: advertise_def_vrf_imp_disable_afi_v4_info
                                
                                	Advertise Afi Info 
                                	**type**\:   :py:class:`AdvertiseDefVrfImpDisableAfiV4Info <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info>`
                                
                                .. attribute:: advertise_def_vrf_imp_disable_afi_v6_info
                                
                                	Advertise Afi Info 
                                	**type**\:   :py:class:`AdvertiseDefVrfImpDisableAfiV6Info <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info>`
                                
                                .. attribute:: advertise_def_vrf_imp_disable_v4
                                
                                	Advertise afi
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: advertise_def_vrf_imp_disable_v6
                                
                                	Advertise afi
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: advertise_dis_info
                                
                                	Advertise Afi Info 
                                	**type**\:   :py:class:`AdvertiseDisInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo>`
                                
                                .. attribute:: advertise_disable
                                
                                	Advertise afi
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: advertise_l2vpnevpn
                                
                                	Advertise afi
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: advertise_l2vpnevpn_afi_info
                                
                                	Advertise Afi Info 
                                	**type**\:   :py:class:`AdvertiseL2VpnevpnAfiInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo>`
                                
                                .. attribute:: advertise_local_labeled_route
                                
                                	Advertise routes with local\-label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: advertise_local_labeled_route_info
                                
                                	Advertise routes with local\-label
                                	**type**\:   :py:class:`AdvertiseLocalLabeledRouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo>`
                                
                                .. attribute:: advertise_v4
                                
                                	Advertise afi
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: advertise_v4_afi_info
                                
                                	Advertise Afi Info 
                                	**type**\:   :py:class:`AdvertiseV4AfiInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo>`
                                
                                .. attribute:: advertise_v6
                                
                                	Advertise afi
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: advertise_v6_afi_info
                                
                                	Advertise Afi Info 
                                	**type**\:   :py:class:`AdvertiseV6AfiInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo>`
                                
                                .. attribute:: advertise_vrf_re_imp_disable_afi_v4_info
                                
                                	Advertise Afi Info 
                                	**type**\:   :py:class:`AdvertiseVrfReImpDisableAfiV4Info <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info>`
                                
                                .. attribute:: advertise_vrf_re_imp_disable_afi_v6_info
                                
                                	Advertise Afi Info 
                                	**type**\:   :py:class:`AdvertiseVrfReImpDisableAfiV6Info <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info>`
                                
                                .. attribute:: advertise_vrf_re_imp_disable_v4
                                
                                	Advertise afi
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: advertise_vrf_re_imp_disable_v6
                                
                                	Advertise afi
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: af_enabled_info
                                
                                	Address family activate item info
                                	**type**\:   :py:class:`AfEnabledInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo>`
                                
                                .. attribute:: af_encapsulation_type_info
                                
                                	Encapsulation type Info 
                                	**type**\:   :py:class:`AfEncapsulationTypeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo>`
                                
                                .. attribute:: af_long_lived_graceful_restart_capable
                                
                                	Long\-lived graceful\-restart capable
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: af_long_lived_graceful_restart_stale_time_accept
                                
                                	Maxmimum acceptable long\-lived stale time acceptable from neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: af_long_lived_graceful_restart_stale_time_send
                                
                                	Stale time to be sent in long\-lived graceful\-restart capability
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: af_long_lived_graceful_start_capable_info
                                
                                	Long\-lived\-time item info
                                	**type**\:   :py:class:`AfLongLivedGracefulStartCapableInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo>`
                                
                                .. attribute:: af_long_lived_graceful_start_stale_time_info
                                
                                	Long\-lived\-time item info
                                	**type**\:   :py:class:`AfLongLivedGracefulStartStaleTimeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo>`
                                
                                .. attribute:: aigp_cost_community_info
                                
                                	AIGP Cost Community info 
                                	**type**\:   :py:class:`AigpCostCommunityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo>`
                                
                                .. attribute:: aigp_cost_community_poi
                                
                                	Point of insertion for AIGP cost community
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: aigp_info
                                
                                	AIGP info 
                                	**type**\:   :py:class:`AigpInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo>`
                                
                                .. attribute:: aigp_med
                                
                                	AIGP MED info 
                                	**type**\:   :py:class:`AigpMed <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed>`
                                
                                .. attribute:: allowas_in_info
                                
                                	Allowas\-in item info
                                	**type**\:   :py:class:`AllowasInInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo>`
                                
                                .. attribute:: alway_use_soft_reconfig
                                
                                	Always use soft reconfig
                                	**type**\:  bool
                                
                                .. attribute:: as_override_info
                                
                                	As\-override info 
                                	**type**\:   :py:class:`AsOverrideInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo>`
                                
                                .. attribute:: client_route_reflector
                                
                                	Route\-reflector client
                                	**type**\:  bool
                                
                                .. attribute:: default_allowas
                                
                                	Default allowas\_in count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: default_originate_info
                                
                                	Default\-originate item info
                                	**type**\:   :py:class:`DefaultOriginateInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo>`
                                
                                .. attribute:: default_originate_route_policy
                                
                                	Default\-originate route policy name
                                	**type**\:  str
                                
                                .. attribute:: default_weight
                                
                                	Default weight
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation type
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: entire_aspath_in
                                
                                	Inbound private\-AS removal if the entire AS Path has private ASes
                                	**type**\:  bool
                                
                                .. attribute:: entire_aspath_out
                                
                                	Outbound private\-AS removalif the entire AS Path hasprivate ASes
                                	**type**\:  bool
                                
                                .. attribute:: fspec_valid_info
                                
                                	FSPEC Valid info
                                	**type**\:   :py:class:`FspecValidInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo>`
                                
                                .. attribute:: has_orf_capability
                                
                                	ORF capability
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: import_
                                
                                	Import
                                	**type**\:  bool
                                
                                .. attribute:: import_afi_info
                                
                                	Import Afi Info 
                                	**type**\:   :py:class:`ImportAfiInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo>`
                                
                                .. attribute:: import_reoriginate
                                
                                	Import reoriginate
                                	**type**\:  bool
                                
                                .. attribute:: import_reoriginate_stitching
                                
                                	Import reoriginate stitching RTs
                                	**type**\:  bool
                                
                                .. attribute:: import_stitching
                                
                                	Import stitching RTs
                                	**type**\:  bool
                                
                                .. attribute:: is_af_enabled
                                
                                	Entity is activated for this address family
                                	**type**\:  bool
                                
                                .. attribute:: is_aigp_cost_community_enabled
                                
                                	AIGP cost community enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_aigp_cost_community_id
                                
                                	AIGP cost community ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_aigp_cost_community_transitive
                                
                                	AIGP cost community ID is transitive
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_aigp_enabled
                                
                                	AIGP enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_aigp_med_enabled
                                
                                	AIGP to MED enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_as_override_disabled
                                
                                	Disable as override
                                	**type**\:  bool
                                
                                .. attribute:: is_default_originate_not_disabled
                                
                                	TRUE if default\-originate is not disabled
                                	**type**\:  bool
                                
                                .. attribute:: is_fspec_valid_enabled
                                
                                	FSPEC VALID enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_max_prefix_discard_extra_paths
                                
                                	Discard extra paths
                                	**type**\:  bool
                                
                                .. attribute:: is_max_prefix_warn_only
                                
                                	Warning messages only
                                	**type**\:  bool
                                
                                .. attribute:: is_next_hop_self_disabled
                                
                                	Disable next\-hop calc
                                	**type**\:  bool
                                
                                .. attribute:: is_next_hop_unchanged
                                
                                	Don't change next\-hop
                                	**type**\:  bool
                                
                                .. attribute:: is_next_hop_unchanged_mpath
                                
                                	Don't change mpath next\-hop
                                	**type**\:  bool
                                
                                .. attribute:: is_send_mcast_attr_enabled
                                
                                	Send mcast attr enabled
                                	**type**\:  bool
                                
                                .. attribute:: legacy_pe_rt_info
                                
                                	Accept\-legacy\-pe\-RT item info
                                	**type**\:   :py:class:`LegacyPeRtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo>`
                                
                                .. attribute:: max_prefix_restart_time
                                
                                	Restart time Value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max_prefix_warn_threshold
                                
                                	Warning message threshhold
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max_prefixes
                                
                                	Maximum prefixes to accept
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max_prefixes_info
                                
                                	Maximum prefixes to accept item info
                                	**type**\:   :py:class:`MaxPrefixesInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo>`
                                
                                .. attribute:: multipath
                                
                                	multipath
                                	**type**\:  bool
                                
                                .. attribute:: multipath_info
                                
                                	Multipath info
                                	**type**\:   :py:class:`MultipathInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo>`
                                
                                .. attribute:: next_hop_self_info
                                
                                	Next hop self item info
                                	**type**\:   :py:class:`NextHopSelfInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo>`
                                
                                .. attribute:: next_hop_unchanged_info
                                
                                	Next hop unchanged info
                                	**type**\:   :py:class:`NextHopUnchangedInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo>`
                                
                                .. attribute:: next_hop_unchanged_mpath_info
                                
                                	Next hop unchanged mpath info
                                	**type**\:   :py:class:`NextHopUnchangedMpathInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo>`
                                
                                .. attribute:: orf_capability_info
                                
                                	ORF capability item info
                                	**type**\:   :py:class:`OrfCapabilityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo>`
                                
                                .. attribute:: orr_info
                                
                                	Orr item info
                                	**type**\:   :py:class:`OrrInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo>`
                                
                                .. attribute:: orr_root_address
                                
                                	ORR Root Address
                                	**type**\:   :py:class:`OrrRootAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress>`
                                
                                .. attribute:: permanent_network
                                
                                	Permanent Network
                                	**type**\:  bool
                                
                                .. attribute:: permanent_network_info
                                
                                	Permanent network Info 
                                	**type**\:   :py:class:`PermanentNetworkInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo>`
                                
                                .. attribute:: prefix_filter_info
                                
                                	Inbound prefix based filter item info
                                	**type**\:   :py:class:`PrefixFilterInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo>`
                                
                                .. attribute:: prefix_orf_filter
                                
                                	Inbound prefix based filter
                                	**type**\:  str
                                
                                .. attribute:: remove_private_as_in_info
                                
                                	Inbound private\-AS removal item info
                                	**type**\:   :py:class:`RemovePrivateAsInInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo>`
                                
                                .. attribute:: remove_private_as_info
                                
                                	Outbound private\-AS removal item info
                                	**type**\:   :py:class:`RemovePrivateAsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo>`
                                
                                .. attribute:: remove_private_as_out
                                
                                	Outbound private\-AS removal
                                	**type**\:  bool
                                
                                .. attribute:: remove_private_asin
                                
                                	Inbound private\-AS removal
                                	**type**\:  bool
                                
                                .. attribute:: route_policy_in
                                
                                	Inbound route policy name
                                	**type**\:  str
                                
                                .. attribute:: route_policy_in_info
                                
                                	Inbound route policy item info
                                	**type**\:   :py:class:`RoutePolicyInInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo>`
                                
                                .. attribute:: route_policy_out
                                
                                	Outbound route policy name
                                	**type**\:  str
                                
                                .. attribute:: route_policy_out_info
                                
                                	Outbound route policy item info
                                	**type**\:   :py:class:`RoutePolicyOutInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo>`
                                
                                .. attribute:: route_reflector_info
                                
                                	Route\-reflector client item info
                                	**type**\:   :py:class:`RouteReflectorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo>`
                                
                                .. attribute:: send_community_attribute
                                
                                	Send community attribute
                                	**type**\:  bool
                                
                                .. attribute:: send_community_info
                                
                                	Send community attribute item info
                                	**type**\:   :py:class:`SendCommunityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo>`
                                
                                .. attribute:: send_extended_community_attribute
                                
                                	Send extended community attribute
                                	**type**\:  bool
                                
                                .. attribute:: send_extended_community_info
                                
                                	Send extended community  item info
                                	**type**\:   :py:class:`SendExtendedCommunityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo>`
                                
                                .. attribute:: send_graceful_shut_community_attributes
                                
                                	Send Graceful shutdown related community attributes
                                	**type**\:  bool
                                
                                .. attribute:: send_graceful_shutdown_community_info
                                
                                	Send Graceful shutdown related community attribute item info
                                	**type**\:   :py:class:`SendGracefulShutdownCommunityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo>`
                                
                                .. attribute:: send_mcast_attr_info
                                
                                	Send mcast attr info
                                	**type**\:   :py:class:`SendMcastAttrInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo>`
                                
                                .. attribute:: site_of_origin
                                
                                	Site of Origin
                                	**type**\:  str
                                
                                .. attribute:: so_o_info
                                
                                	BGP Site\-of\-Origin info
                                	**type**\:   :py:class:`SoOInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo>`
                                
                                .. attribute:: soft_reconfig_info
                                
                                	Soft reconf item info
                                	**type**\:   :py:class:`SoftReconfigInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo>`
                                
                                .. attribute:: soft_reconfig_not_disabled
                                
                                	TRUE if soft reconf is not disabled
                                	**type**\:  bool
                                
                                .. attribute:: weight_info
                                
                                	Default weight item info
                                	**type**\:   :py:class:`WeightInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.accept_own = None
                                    self.accept_own_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo()
                                    self.accept_own_info.parent = self
                                    self.accept_route_legacy_pe_rt = None
                                    self.advertise_def_vrf_imp_disable_afi_v4_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info()
                                    self.advertise_def_vrf_imp_disable_afi_v4_info.parent = self
                                    self.advertise_def_vrf_imp_disable_afi_v6_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info()
                                    self.advertise_def_vrf_imp_disable_afi_v6_info.parent = self
                                    self.advertise_def_vrf_imp_disable_v4 = None
                                    self.advertise_def_vrf_imp_disable_v6 = None
                                    self.advertise_dis_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo()
                                    self.advertise_dis_info.parent = self
                                    self.advertise_disable = None
                                    self.advertise_l2vpnevpn = None
                                    self.advertise_l2vpnevpn_afi_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo()
                                    self.advertise_l2vpnevpn_afi_info.parent = self
                                    self.advertise_local_labeled_route = None
                                    self.advertise_local_labeled_route_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo()
                                    self.advertise_local_labeled_route_info.parent = self
                                    self.advertise_v4 = None
                                    self.advertise_v4_afi_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo()
                                    self.advertise_v4_afi_info.parent = self
                                    self.advertise_v6 = None
                                    self.advertise_v6_afi_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo()
                                    self.advertise_v6_afi_info.parent = self
                                    self.advertise_vrf_re_imp_disable_afi_v4_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info()
                                    self.advertise_vrf_re_imp_disable_afi_v4_info.parent = self
                                    self.advertise_vrf_re_imp_disable_afi_v6_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info()
                                    self.advertise_vrf_re_imp_disable_afi_v6_info.parent = self
                                    self.advertise_vrf_re_imp_disable_v4 = None
                                    self.advertise_vrf_re_imp_disable_v6 = None
                                    self.af_enabled_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo()
                                    self.af_enabled_info.parent = self
                                    self.af_encapsulation_type_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo()
                                    self.af_encapsulation_type_info.parent = self
                                    self.af_long_lived_graceful_restart_capable = None
                                    self.af_long_lived_graceful_restart_stale_time_accept = None
                                    self.af_long_lived_graceful_restart_stale_time_send = None
                                    self.af_long_lived_graceful_start_capable_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo()
                                    self.af_long_lived_graceful_start_capable_info.parent = self
                                    self.af_long_lived_graceful_start_stale_time_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo()
                                    self.af_long_lived_graceful_start_stale_time_info.parent = self
                                    self.aigp_cost_community_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo()
                                    self.aigp_cost_community_info.parent = self
                                    self.aigp_cost_community_poi = None
                                    self.aigp_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo()
                                    self.aigp_info.parent = self
                                    self.aigp_med = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed()
                                    self.aigp_med.parent = self
                                    self.allowas_in_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo()
                                    self.allowas_in_info.parent = self
                                    self.alway_use_soft_reconfig = None
                                    self.as_override_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo()
                                    self.as_override_info.parent = self
                                    self.client_route_reflector = None
                                    self.default_allowas = None
                                    self.default_originate_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo()
                                    self.default_originate_info.parent = self
                                    self.default_originate_route_policy = None
                                    self.default_weight = None
                                    self.encapsulation_type = None
                                    self.entire_aspath_in = None
                                    self.entire_aspath_out = None
                                    self.fspec_valid_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo()
                                    self.fspec_valid_info.parent = self
                                    self.has_orf_capability = None
                                    self.import_ = None
                                    self.import_afi_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo()
                                    self.import_afi_info.parent = self
                                    self.import_reoriginate = None
                                    self.import_reoriginate_stitching = None
                                    self.import_stitching = None
                                    self.is_af_enabled = None
                                    self.is_aigp_cost_community_enabled = None
                                    self.is_aigp_cost_community_id = None
                                    self.is_aigp_cost_community_transitive = None
                                    self.is_aigp_enabled = None
                                    self.is_aigp_med_enabled = None
                                    self.is_as_override_disabled = None
                                    self.is_default_originate_not_disabled = None
                                    self.is_fspec_valid_enabled = None
                                    self.is_max_prefix_discard_extra_paths = None
                                    self.is_max_prefix_warn_only = None
                                    self.is_next_hop_self_disabled = None
                                    self.is_next_hop_unchanged = None
                                    self.is_next_hop_unchanged_mpath = None
                                    self.is_send_mcast_attr_enabled = None
                                    self.legacy_pe_rt_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo()
                                    self.legacy_pe_rt_info.parent = self
                                    self.max_prefix_restart_time = None
                                    self.max_prefix_warn_threshold = None
                                    self.max_prefixes = None
                                    self.max_prefixes_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo()
                                    self.max_prefixes_info.parent = self
                                    self.multipath = None
                                    self.multipath_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo()
                                    self.multipath_info.parent = self
                                    self.next_hop_self_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo()
                                    self.next_hop_self_info.parent = self
                                    self.next_hop_unchanged_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo()
                                    self.next_hop_unchanged_info.parent = self
                                    self.next_hop_unchanged_mpath_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo()
                                    self.next_hop_unchanged_mpath_info.parent = self
                                    self.orf_capability_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo()
                                    self.orf_capability_info.parent = self
                                    self.orr_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo()
                                    self.orr_info.parent = self
                                    self.orr_root_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress()
                                    self.orr_root_address.parent = self
                                    self.permanent_network = None
                                    self.permanent_network_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo()
                                    self.permanent_network_info.parent = self
                                    self.prefix_filter_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo()
                                    self.prefix_filter_info.parent = self
                                    self.prefix_orf_filter = None
                                    self.remove_private_as_in_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo()
                                    self.remove_private_as_in_info.parent = self
                                    self.remove_private_as_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo()
                                    self.remove_private_as_info.parent = self
                                    self.remove_private_as_out = None
                                    self.remove_private_asin = None
                                    self.route_policy_in = None
                                    self.route_policy_in_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo()
                                    self.route_policy_in_info.parent = self
                                    self.route_policy_out = None
                                    self.route_policy_out_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo()
                                    self.route_policy_out_info.parent = self
                                    self.route_reflector_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo()
                                    self.route_reflector_info.parent = self
                                    self.send_community_attribute = None
                                    self.send_community_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo()
                                    self.send_community_info.parent = self
                                    self.send_extended_community_attribute = None
                                    self.send_extended_community_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo()
                                    self.send_extended_community_info.parent = self
                                    self.send_graceful_shut_community_attributes = None
                                    self.send_graceful_shutdown_community_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo()
                                    self.send_graceful_shutdown_community_info.parent = self
                                    self.send_mcast_attr_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo()
                                    self.send_mcast_attr_info.parent = self
                                    self.site_of_origin = None
                                    self.so_o_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo()
                                    self.so_o_info.parent = self
                                    self.soft_reconfig_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo()
                                    self.soft_reconfig_info.parent = self
                                    self.soft_reconfig_not_disabled = None
                                    self.weight_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo()
                                    self.weight_info.parent = self


                                class OrrRootAddress(object):
                                    """
                                    ORR Root Address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpnvpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2VpnvplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4mdt_address = None
                                        self.ipv4mvpn_address = None
                                        self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv4SrPolicyAddress()
                                        self.ipv4sr_policy_address.parent = self
                                        self.ipv4vpn_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv6SrPolicyAddress()
                                        self.ipv6sr_policy_address.parent = self
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_flowspec_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.l2vpn_evpn_address = None
                                        self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2VpnvplsAddress()
                                        self.l2vpnvpls_address.parent = self
                                        self.ls_ls_address = None
                                        self.rt_constraint_address = None


                                    class L2VpnvplsAddress(object):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2VpnvplsAddress']['meta_info']


                                    class L2VpnMspwAddress(object):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2VpnMspwAddress']['meta_info']


                                    class Ipv4SrPolicyAddress(object):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv4SrPolicyAddress']['meta_info']


                                    class Ipv6SrPolicyAddress(object):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv6_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv6_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv6SrPolicyAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:orr-root-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.afi is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv4_flowspec_address is not None:
                                            return True

                                        if self.ipv4_label_address is not None:
                                            return True

                                        if self.ipv4_mcast_address is not None:
                                            return True

                                        if self.ipv4_tunnel_address is not None:
                                            return True

                                        if self.ipv4mdt_address is not None:
                                            return True

                                        if self.ipv4mvpn_address is not None:
                                            return True

                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                            return True

                                        if self.ipv4vpn_address is not None:
                                            return True

                                        if self.ipv4vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv4vpna_mcastddress is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        if self.ipv6_flowspec_address is not None:
                                            return True

                                        if self.ipv6_label_address is not None:
                                            return True

                                        if self.ipv6_mcast_address is not None:
                                            return True

                                        if self.ipv6mvpn_address is not None:
                                            return True

                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                            return True

                                        if self.ipv6vpn_address is not None:
                                            return True

                                        if self.ipv6vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv6vpn_mcast_address is not None:
                                            return True

                                        if self.l2vpn_evpn_address is not None:
                                            return True

                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                            return True

                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                            return True

                                        if self.ls_ls_address is not None:
                                            return True

                                        if self.rt_constraint_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress']['meta_info']


                                class OrfCapabilityInfo(object):
                                    """
                                    ORF capability item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:orf-capability-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo']['meta_info']


                                class DefaultOriginateInfo(object):
                                    """
                                    Default\-originate item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:default-originate-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo']['meta_info']


                                class MaxPrefixesInfo(object):
                                    """
                                    Maximum prefixes to accept item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:max-prefixes-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo']['meta_info']


                                class OrrInfo(object):
                                    """
                                    Orr item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:orr-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo']['meta_info']


                                class NextHopSelfInfo(object):
                                    """
                                    Next hop self item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop-self-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo']['meta_info']


                                class NextHopUnchangedInfo(object):
                                    """
                                    Next hop unchanged info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop-unchanged-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo']['meta_info']


                                class RoutePolicyInInfo(object):
                                    """
                                    Inbound route policy item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:route-policy-in-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo']['meta_info']


                                class RoutePolicyOutInfo(object):
                                    """
                                    Outbound route policy item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:route-policy-out-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo']['meta_info']


                                class PrefixFilterInfo(object):
                                    """
                                    Inbound prefix based filter item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix-filter-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo']['meta_info']


                                class RemovePrivateAsInfo(object):
                                    """
                                    Outbound private\-AS removal item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:remove-private-as-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo']['meta_info']


                                class RemovePrivateAsInInfo(object):
                                    """
                                    Inbound private\-AS removal item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:remove-private-as-in-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo']['meta_info']


                                class RouteReflectorInfo(object):
                                    """
                                    Route\-reflector client item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:route-reflector-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo']['meta_info']


                                class LegacyPeRtInfo(object):
                                    """
                                    Accept\-legacy\-pe\-RT item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:legacy-pe-rt-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo']['meta_info']


                                class AfEnabledInfo(object):
                                    """
                                    Address family activate item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af-enabled-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo']['meta_info']


                                class SendCommunityInfo(object):
                                    """
                                    Send community attribute item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:send-community-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo']['meta_info']


                                class SendGracefulShutdownCommunityInfo(object):
                                    """
                                    Send Graceful shutdown related community
                                    attribute item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:send-graceful-shutdown-community-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo']['meta_info']


                                class SendExtendedCommunityInfo(object):
                                    """
                                    Send extended community  item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:send-extended-community-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo']['meta_info']


                                class SoftReconfigInfo(object):
                                    """
                                    Soft reconf item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:soft-reconfig-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo']['meta_info']


                                class SoOInfo(object):
                                    """
                                    BGP Site\-of\-Origin info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:so-o-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo']['meta_info']


                                class WeightInfo(object):
                                    """
                                    Default weight item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:weight-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo']['meta_info']


                                class AllowasInInfo(object):
                                    """
                                    Allowas\-in item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:allowas-in-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo']['meta_info']


                                class AfLongLivedGracefulStartStaleTimeInfo(object):
                                    """
                                    Long\-lived\-time item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af-long-lived-graceful-start-stale-time-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo']['meta_info']


                                class AfLongLivedGracefulStartCapableInfo(object):
                                    """
                                    Long\-lived\-time item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af-long-lived-graceful-start-capable-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo']['meta_info']


                                class AsOverrideInfo(object):
                                    """
                                    As\-override info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:as-override-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo']['meta_info']


                                class AigpInfo(object):
                                    """
                                    AIGP info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:aigp-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo']['meta_info']


                                class AigpCostCommunityInfo(object):
                                    """
                                    AIGP Cost Community info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:aigp-cost-community-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo']['meta_info']


                                class AigpMed(object):
                                    """
                                    AIGP MED info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:aigp-med'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed']['meta_info']


                                class AcceptOwnInfo(object):
                                    """
                                    Accept\-Own info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:accept-own-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo']['meta_info']


                                class MultipathInfo(object):
                                    """
                                    Multipath info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:multipath-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo']['meta_info']


                                class FspecValidInfo(object):
                                    """
                                    FSPEC Valid info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:fspec-valid-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo']['meta_info']


                                class NextHopUnchangedMpathInfo(object):
                                    """
                                    Next hop unchanged mpath info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop-unchanged-mpath-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo']['meta_info']


                                class PermanentNetworkInfo(object):
                                    """
                                    Permanent network Info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:permanent-network-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo']['meta_info']


                                class SendMcastAttrInfo(object):
                                    """
                                    Send mcast attr info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:send-mcast-attr-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo']['meta_info']


                                class AdvertiseV4AfiInfo(object):
                                    """
                                    Advertise Afi Info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertise-v4-afi-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo']['meta_info']


                                class AdvertiseV6AfiInfo(object):
                                    """
                                    Advertise Afi Info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertise-v6-afi-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo']['meta_info']


                                class AdvertiseL2VpnevpnAfiInfo(object):
                                    """
                                    Advertise Afi Info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertise-l2vpnevpn-afi-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2VpnevpnAfiInfo']['meta_info']


                                class AdvertiseDisInfo(object):
                                    """
                                    Advertise Afi Info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertise-dis-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo']['meta_info']


                                class AdvertiseDefVrfImpDisableAfiV4Info(object):
                                    """
                                    Advertise Afi Info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertise-def-vrf-imp-disable-afi-v4-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info']['meta_info']


                                class AdvertiseDefVrfImpDisableAfiV6Info(object):
                                    """
                                    Advertise Afi Info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertise-def-vrf-imp-disable-afi-v6-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info']['meta_info']


                                class AdvertiseVrfReImpDisableAfiV4Info(object):
                                    """
                                    Advertise Afi Info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertise-vrf-re-imp-disable-afi-v4-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info']['meta_info']


                                class AdvertiseVrfReImpDisableAfiV6Info(object):
                                    """
                                    Advertise Afi Info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertise-vrf-re-imp-disable-afi-v6-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info']['meta_info']


                                class AfEncapsulationTypeInfo(object):
                                    """
                                    Encapsulation type Info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af-encapsulation-type-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo']['meta_info']


                                class ImportAfiInfo(object):
                                    """
                                    Import Afi Info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:import-afi-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo']['meta_info']


                                class AdvertiseLocalLabeledRouteInfo(object):
                                    """
                                    Advertise routes with local\-label
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:   :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self.is_item_configured = None


                                    class InheritanceChain(object):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_config_entid = YList()
                                            self.bgp_config_entid.parent = self
                                            self.bgp_config_entid.name = 'bgp_config_entid'


                                        class BgpConfigEntid(object):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\:  str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None
                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.address_family_identifier is not None:
                                                    return True

                                                if self.configuration_type is not None:
                                                    return True

                                                if self.group_name is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:inheritance-chain'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_config_entid is not None:
                                                for child_ref in self.bgp_config_entid:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertise-local-labeled-route-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.inheritance_chain is not None and self.inheritance_chain._has_data():
                                            return True

                                        if self.is_item_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af-dependent-config'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.accept_own is not None:
                                        return True

                                    if self.accept_own_info is not None and self.accept_own_info._has_data():
                                        return True

                                    if self.accept_route_legacy_pe_rt is not None:
                                        return True

                                    if self.advertise_def_vrf_imp_disable_afi_v4_info is not None and self.advertise_def_vrf_imp_disable_afi_v4_info._has_data():
                                        return True

                                    if self.advertise_def_vrf_imp_disable_afi_v6_info is not None and self.advertise_def_vrf_imp_disable_afi_v6_info._has_data():
                                        return True

                                    if self.advertise_def_vrf_imp_disable_v4 is not None:
                                        return True

                                    if self.advertise_def_vrf_imp_disable_v6 is not None:
                                        return True

                                    if self.advertise_dis_info is not None and self.advertise_dis_info._has_data():
                                        return True

                                    if self.advertise_disable is not None:
                                        return True

                                    if self.advertise_l2vpnevpn is not None:
                                        return True

                                    if self.advertise_l2vpnevpn_afi_info is not None and self.advertise_l2vpnevpn_afi_info._has_data():
                                        return True

                                    if self.advertise_local_labeled_route is not None:
                                        return True

                                    if self.advertise_local_labeled_route_info is not None and self.advertise_local_labeled_route_info._has_data():
                                        return True

                                    if self.advertise_v4 is not None:
                                        return True

                                    if self.advertise_v4_afi_info is not None and self.advertise_v4_afi_info._has_data():
                                        return True

                                    if self.advertise_v6 is not None:
                                        return True

                                    if self.advertise_v6_afi_info is not None and self.advertise_v6_afi_info._has_data():
                                        return True

                                    if self.advertise_vrf_re_imp_disable_afi_v4_info is not None and self.advertise_vrf_re_imp_disable_afi_v4_info._has_data():
                                        return True

                                    if self.advertise_vrf_re_imp_disable_afi_v6_info is not None and self.advertise_vrf_re_imp_disable_afi_v6_info._has_data():
                                        return True

                                    if self.advertise_vrf_re_imp_disable_v4 is not None:
                                        return True

                                    if self.advertise_vrf_re_imp_disable_v6 is not None:
                                        return True

                                    if self.af_enabled_info is not None and self.af_enabled_info._has_data():
                                        return True

                                    if self.af_encapsulation_type_info is not None and self.af_encapsulation_type_info._has_data():
                                        return True

                                    if self.af_long_lived_graceful_restart_capable is not None:
                                        return True

                                    if self.af_long_lived_graceful_restart_stale_time_accept is not None:
                                        return True

                                    if self.af_long_lived_graceful_restart_stale_time_send is not None:
                                        return True

                                    if self.af_long_lived_graceful_start_capable_info is not None and self.af_long_lived_graceful_start_capable_info._has_data():
                                        return True

                                    if self.af_long_lived_graceful_start_stale_time_info is not None and self.af_long_lived_graceful_start_stale_time_info._has_data():
                                        return True

                                    if self.aigp_cost_community_info is not None and self.aigp_cost_community_info._has_data():
                                        return True

                                    if self.aigp_cost_community_poi is not None:
                                        return True

                                    if self.aigp_info is not None and self.aigp_info._has_data():
                                        return True

                                    if self.aigp_med is not None and self.aigp_med._has_data():
                                        return True

                                    if self.allowas_in_info is not None and self.allowas_in_info._has_data():
                                        return True

                                    if self.alway_use_soft_reconfig is not None:
                                        return True

                                    if self.as_override_info is not None and self.as_override_info._has_data():
                                        return True

                                    if self.client_route_reflector is not None:
                                        return True

                                    if self.default_allowas is not None:
                                        return True

                                    if self.default_originate_info is not None and self.default_originate_info._has_data():
                                        return True

                                    if self.default_originate_route_policy is not None:
                                        return True

                                    if self.default_weight is not None:
                                        return True

                                    if self.encapsulation_type is not None:
                                        return True

                                    if self.entire_aspath_in is not None:
                                        return True

                                    if self.entire_aspath_out is not None:
                                        return True

                                    if self.fspec_valid_info is not None and self.fspec_valid_info._has_data():
                                        return True

                                    if self.has_orf_capability is not None:
                                        return True

                                    if self.import_ is not None:
                                        return True

                                    if self.import_afi_info is not None and self.import_afi_info._has_data():
                                        return True

                                    if self.import_reoriginate is not None:
                                        return True

                                    if self.import_reoriginate_stitching is not None:
                                        return True

                                    if self.import_stitching is not None:
                                        return True

                                    if self.is_af_enabled is not None:
                                        return True

                                    if self.is_aigp_cost_community_enabled is not None:
                                        return True

                                    if self.is_aigp_cost_community_id is not None:
                                        return True

                                    if self.is_aigp_cost_community_transitive is not None:
                                        return True

                                    if self.is_aigp_enabled is not None:
                                        return True

                                    if self.is_aigp_med_enabled is not None:
                                        return True

                                    if self.is_as_override_disabled is not None:
                                        return True

                                    if self.is_default_originate_not_disabled is not None:
                                        return True

                                    if self.is_fspec_valid_enabled is not None:
                                        return True

                                    if self.is_max_prefix_discard_extra_paths is not None:
                                        return True

                                    if self.is_max_prefix_warn_only is not None:
                                        return True

                                    if self.is_next_hop_self_disabled is not None:
                                        return True

                                    if self.is_next_hop_unchanged is not None:
                                        return True

                                    if self.is_next_hop_unchanged_mpath is not None:
                                        return True

                                    if self.is_send_mcast_attr_enabled is not None:
                                        return True

                                    if self.legacy_pe_rt_info is not None and self.legacy_pe_rt_info._has_data():
                                        return True

                                    if self.max_prefix_restart_time is not None:
                                        return True

                                    if self.max_prefix_warn_threshold is not None:
                                        return True

                                    if self.max_prefixes is not None:
                                        return True

                                    if self.max_prefixes_info is not None and self.max_prefixes_info._has_data():
                                        return True

                                    if self.multipath is not None:
                                        return True

                                    if self.multipath_info is not None and self.multipath_info._has_data():
                                        return True

                                    if self.next_hop_self_info is not None and self.next_hop_self_info._has_data():
                                        return True

                                    if self.next_hop_unchanged_info is not None and self.next_hop_unchanged_info._has_data():
                                        return True

                                    if self.next_hop_unchanged_mpath_info is not None and self.next_hop_unchanged_mpath_info._has_data():
                                        return True

                                    if self.orf_capability_info is not None and self.orf_capability_info._has_data():
                                        return True

                                    if self.orr_info is not None and self.orr_info._has_data():
                                        return True

                                    if self.orr_root_address is not None and self.orr_root_address._has_data():
                                        return True

                                    if self.permanent_network is not None:
                                        return True

                                    if self.permanent_network_info is not None and self.permanent_network_info._has_data():
                                        return True

                                    if self.prefix_filter_info is not None and self.prefix_filter_info._has_data():
                                        return True

                                    if self.prefix_orf_filter is not None:
                                        return True

                                    if self.remove_private_as_in_info is not None and self.remove_private_as_in_info._has_data():
                                        return True

                                    if self.remove_private_as_info is not None and self.remove_private_as_info._has_data():
                                        return True

                                    if self.remove_private_as_out is not None:
                                        return True

                                    if self.remove_private_asin is not None:
                                        return True

                                    if self.route_policy_in is not None:
                                        return True

                                    if self.route_policy_in_info is not None and self.route_policy_in_info._has_data():
                                        return True

                                    if self.route_policy_out is not None:
                                        return True

                                    if self.route_policy_out_info is not None and self.route_policy_out_info._has_data():
                                        return True

                                    if self.route_reflector_info is not None and self.route_reflector_info._has_data():
                                        return True

                                    if self.send_community_attribute is not None:
                                        return True

                                    if self.send_community_info is not None and self.send_community_info._has_data():
                                        return True

                                    if self.send_extended_community_attribute is not None:
                                        return True

                                    if self.send_extended_community_info is not None and self.send_extended_community_info._has_data():
                                        return True

                                    if self.send_graceful_shut_community_attributes is not None:
                                        return True

                                    if self.send_graceful_shutdown_community_info is not None and self.send_graceful_shutdown_community_info._has_data():
                                        return True

                                    if self.send_mcast_attr_info is not None and self.send_mcast_attr_info._has_data():
                                        return True

                                    if self.site_of_origin is not None:
                                        return True

                                    if self.so_o_info is not None and self.so_o_info._has_data():
                                        return True

                                    if self.soft_reconfig_info is not None and self.soft_reconfig_info._has_data():
                                        return True

                                    if self.soft_reconfig_not_disabled is not None:
                                        return True

                                    if self.weight_info is not None and self.weight_info._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:entity-configuration'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.address_family_identifier is not None:
                                    return True

                                if self.af_dependent_config is not None:
                                    for child_ref in self.af_dependent_config:
                                        if child_ref._has_data():
                                            return True

                                if self.af_independent_config is not None and self.af_independent_config._has_data():
                                    return True

                                if self.configuration_type is not None:
                                    return True

                                if self.entity_name is not None:
                                    return True

                                if self.entity_type is not None:
                                    return True

                                if self.group_name is not None:
                                    return True

                                if self.neighbor_address is not None:
                                    return True

                                if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:entity-configurations'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.entity_configuration is not None:
                                for child_ref in self.entity_configuration:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations']['meta_info']


                    class ConfigurationUsers(object):
                        """
                        The BGP configuration users table
                        
                        .. attribute:: configuration_user
                        
                        	A BGP configuration user table entry
                        	**type**\: list of    :py:class:`ConfigurationUser <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.configuration_user = YList()
                            self.configuration_user.parent = self
                            self.configuration_user.name = 'configuration_user'


                        class ConfigurationUser(object):
                            """
                            A BGP configuration user table entry
                            
                            .. attribute:: address_family_identifier
                            
                            	AF identifier
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: af_dependent_relative
                            
                            	AF\-dependent relatives
                            	**type**\: list of    :py:class:`AfDependentRelative <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative>`
                            
                            .. attribute:: af_independent_relatives
                            
                            	AF\-independent relatives
                            	**type**\:   :py:class:`AfIndependentRelatives <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives>`
                            
                            .. attribute:: configuration_type
                            
                            	Entity type
                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                            
                            .. attribute:: entity_name
                            
                            	Entity name
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: entity_type
                            
                            	Entity type
                            	**type**\:   :py:class:`BgpEntityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntityEnum>`
                            
                            .. attribute:: group_name
                            
                            	Entity/group name
                            	**type**\:  str
                            
                            .. attribute:: neighbor_address
                            
                            	Neighbor address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: neighbor_address_xr
                            
                            	Neighbor Address
                            	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.address_family_identifier = None
                                self.af_dependent_relative = YList()
                                self.af_dependent_relative.parent = self
                                self.af_dependent_relative.name = 'af_dependent_relative'
                                self.af_independent_relatives = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives()
                                self.af_independent_relatives.parent = self
                                self.configuration_type = None
                                self.entity_name = None
                                self.entity_type = None
                                self.group_name = None
                                self.neighbor_address = None
                                self.neighbor_address_xr = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr()
                                self.neighbor_address_xr.parent = self


                            class NeighborAddressXr(object):
                                """
                                Neighbor Address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpnvpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2VpnvplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4mdt_address = None
                                    self.ipv4mvpn_address = None
                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv4SrPolicyAddress()
                                    self.ipv4sr_policy_address.parent = self
                                    self.ipv4vpn_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv6SrPolicyAddress()
                                    self.ipv6sr_policy_address.parent = self
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_flowspec_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.l2vpn_evpn_address = None
                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2VpnvplsAddress()
                                    self.l2vpnvpls_address.parent = self
                                    self.ls_ls_address = None
                                    self.rt_constraint_address = None


                                class L2VpnvplsAddress(object):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                class L2VpnMspwAddress(object):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                class Ipv4SrPolicyAddress(object):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                class Ipv6SrPolicyAddress(object):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv6_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv6_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.afi is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv4_flowspec_address is not None:
                                        return True

                                    if self.ipv4_label_address is not None:
                                        return True

                                    if self.ipv4_mcast_address is not None:
                                        return True

                                    if self.ipv4_tunnel_address is not None:
                                        return True

                                    if self.ipv4mdt_address is not None:
                                        return True

                                    if self.ipv4mvpn_address is not None:
                                        return True

                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                        return True

                                    if self.ipv4vpn_address is not None:
                                        return True

                                    if self.ipv4vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv4vpna_mcastddress is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    if self.ipv6_flowspec_address is not None:
                                        return True

                                    if self.ipv6_label_address is not None:
                                        return True

                                    if self.ipv6_mcast_address is not None:
                                        return True

                                    if self.ipv6mvpn_address is not None:
                                        return True

                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                        return True

                                    if self.ipv6vpn_address is not None:
                                        return True

                                    if self.ipv6vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv6vpn_mcast_address is not None:
                                        return True

                                    if self.l2vpn_evpn_address is not None:
                                        return True

                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                        return True

                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                        return True

                                    if self.ls_ls_address is not None:
                                        return True

                                    if self.rt_constraint_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr']['meta_info']


                            class AfIndependentRelatives(object):
                                """
                                AF\-independent relatives
                                
                                .. attribute:: bgp_config_entid
                                
                                	bgp config entid
                                	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.bgp_config_entid = YList()
                                    self.bgp_config_entid.parent = self
                                    self.bgp_config_entid.name = 'bgp_config_entid'


                                class BgpConfigEntid(object):
                                    """
                                    bgp config entid
                                    
                                    .. attribute:: address_family_identifier
                                    
                                    	Address family identfier
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: configuration_type
                                    
                                    	Entity type
                                    	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                    
                                    .. attribute:: group_name
                                    
                                    	Group name
                                    	**type**\:  str
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.address_family_identifier = None
                                        self.configuration_type = None
                                        self.group_name = None
                                        self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress()
                                        self.neighbor_address.parent = self


                                    class NeighborAddress(object):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.address_family_identifier is not None:
                                            return True

                                        if self.configuration_type is not None:
                                            return True

                                        if self.group_name is not None:
                                            return True

                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af-independent-relatives'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bgp_config_entid is not None:
                                        for child_ref in self.bgp_config_entid:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives']['meta_info']


                            class AfDependentRelative(object):
                                """
                                AF\-dependent relatives
                                
                                .. attribute:: bgp_config_entid
                                
                                	bgp config entid
                                	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.bgp_config_entid = YList()
                                    self.bgp_config_entid.parent = self
                                    self.bgp_config_entid.name = 'bgp_config_entid'


                                class BgpConfigEntid(object):
                                    """
                                    bgp config entid
                                    
                                    .. attribute:: address_family_identifier
                                    
                                    	Address family identfier
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: configuration_type
                                    
                                    	Entity type
                                    	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                    
                                    .. attribute:: group_name
                                    
                                    	Group name
                                    	**type**\:  str
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.address_family_identifier = None
                                        self.configuration_type = None
                                        self.group_name = None
                                        self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress()
                                        self.neighbor_address.parent = self


                                    class NeighborAddress(object):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.address_family_identifier is not None:
                                            return True

                                        if self.configuration_type is not None:
                                            return True

                                        if self.group_name is not None:
                                            return True

                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af-dependent-relative'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bgp_config_entid is not None:
                                        for child_ref in self.bgp_config_entid:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:configuration-user'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.address_family_identifier is not None:
                                    return True

                                if self.af_dependent_relative is not None:
                                    for child_ref in self.af_dependent_relative:
                                        if child_ref._has_data():
                                            return True

                                if self.af_independent_relatives is not None and self.af_independent_relatives._has_data():
                                    return True

                                if self.configuration_type is not None:
                                    return True

                                if self.entity_name is not None:
                                    return True

                                if self.entity_type is not None:
                                    return True

                                if self.group_name is not None:
                                    return True

                                if self.neighbor_address is not None:
                                    return True

                                if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:configuration-users'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.configuration_user is not None:
                                for child_ref in self.configuration_user:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers']['meta_info']


                    class ConfigurationInheritances(object):
                        """
                        The BGP configurataion inheritance table
                        
                        .. attribute:: configuration_inheritance
                        
                        	A BGP configuration inheritance table entry
                        	**type**\: list of    :py:class:`ConfigurationInheritance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.configuration_inheritance = YList()
                            self.configuration_inheritance.parent = self
                            self.configuration_inheritance.name = 'configuration_inheritance'


                        class ConfigurationInheritance(object):
                            """
                            A BGP configuration inheritance table entry
                            
                            .. attribute:: address_family_identifier
                            
                            	AF identifier
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: af_dependent_relative
                            
                            	AF\-dependent relatives
                            	**type**\: list of    :py:class:`AfDependentRelative <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative>`
                            
                            .. attribute:: af_independent_relatives
                            
                            	AF\-independent relatives
                            	**type**\:   :py:class:`AfIndependentRelatives <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives>`
                            
                            .. attribute:: configuration_type
                            
                            	Entity type
                            	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                            
                            .. attribute:: entity_name
                            
                            	Entity name
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: entity_type
                            
                            	Entity type
                            	**type**\:   :py:class:`BgpEntityEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntityEnum>`
                            
                            .. attribute:: group_name
                            
                            	Entity/group name
                            	**type**\:  str
                            
                            .. attribute:: neighbor_address
                            
                            	Neighbor address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: neighbor_address_xr
                            
                            	Neighbor Address
                            	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.address_family_identifier = None
                                self.af_dependent_relative = YList()
                                self.af_dependent_relative.parent = self
                                self.af_dependent_relative.name = 'af_dependent_relative'
                                self.af_independent_relatives = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives()
                                self.af_independent_relatives.parent = self
                                self.configuration_type = None
                                self.entity_name = None
                                self.entity_type = None
                                self.group_name = None
                                self.neighbor_address = None
                                self.neighbor_address_xr = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr()
                                self.neighbor_address_xr.parent = self


                            class NeighborAddressXr(object):
                                """
                                Neighbor Address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpnvpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2VpnvplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4mdt_address = None
                                    self.ipv4mvpn_address = None
                                    self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv4SrPolicyAddress()
                                    self.ipv4sr_policy_address.parent = self
                                    self.ipv4vpn_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv6SrPolicyAddress()
                                    self.ipv6sr_policy_address.parent = self
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_flowspec_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.l2vpn_evpn_address = None
                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2VpnvplsAddress()
                                    self.l2vpnvpls_address.parent = self
                                    self.ls_ls_address = None
                                    self.rt_constraint_address = None


                                class L2VpnvplsAddress(object):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                class L2VpnMspwAddress(object):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                class Ipv4SrPolicyAddress(object):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                class Ipv6SrPolicyAddress(object):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv6_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv6_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.afi is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv4_flowspec_address is not None:
                                        return True

                                    if self.ipv4_label_address is not None:
                                        return True

                                    if self.ipv4_mcast_address is not None:
                                        return True

                                    if self.ipv4_tunnel_address is not None:
                                        return True

                                    if self.ipv4mdt_address is not None:
                                        return True

                                    if self.ipv4mvpn_address is not None:
                                        return True

                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                        return True

                                    if self.ipv4vpn_address is not None:
                                        return True

                                    if self.ipv4vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv4vpna_mcastddress is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    if self.ipv6_flowspec_address is not None:
                                        return True

                                    if self.ipv6_label_address is not None:
                                        return True

                                    if self.ipv6_mcast_address is not None:
                                        return True

                                    if self.ipv6mvpn_address is not None:
                                        return True

                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                        return True

                                    if self.ipv6vpn_address is not None:
                                        return True

                                    if self.ipv6vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv6vpn_mcast_address is not None:
                                        return True

                                    if self.l2vpn_evpn_address is not None:
                                        return True

                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                        return True

                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                        return True

                                    if self.ls_ls_address is not None:
                                        return True

                                    if self.rt_constraint_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr']['meta_info']


                            class AfIndependentRelatives(object):
                                """
                                AF\-independent relatives
                                
                                .. attribute:: bgp_config_entid
                                
                                	bgp config entid
                                	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.bgp_config_entid = YList()
                                    self.bgp_config_entid.parent = self
                                    self.bgp_config_entid.name = 'bgp_config_entid'


                                class BgpConfigEntid(object):
                                    """
                                    bgp config entid
                                    
                                    .. attribute:: address_family_identifier
                                    
                                    	Address family identfier
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: configuration_type
                                    
                                    	Entity type
                                    	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                    
                                    .. attribute:: group_name
                                    
                                    	Group name
                                    	**type**\:  str
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.address_family_identifier = None
                                        self.configuration_type = None
                                        self.group_name = None
                                        self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress()
                                        self.neighbor_address.parent = self


                                    class NeighborAddress(object):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.address_family_identifier is not None:
                                            return True

                                        if self.configuration_type is not None:
                                            return True

                                        if self.group_name is not None:
                                            return True

                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af-independent-relatives'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bgp_config_entid is not None:
                                        for child_ref in self.bgp_config_entid:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives']['meta_info']


                            class AfDependentRelative(object):
                                """
                                AF\-dependent relatives
                                
                                .. attribute:: bgp_config_entid
                                
                                	bgp config entid
                                	**type**\: list of    :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.bgp_config_entid = YList()
                                    self.bgp_config_entid.parent = self
                                    self.bgp_config_entid.name = 'bgp_config_entid'


                                class BgpConfigEntid(object):
                                    """
                                    bgp config entid
                                    
                                    .. attribute:: address_family_identifier
                                    
                                    	Address family identfier
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: configuration_type
                                    
                                    	Entity type
                                    	**type**\:   :py:class:`BgpEntitiesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntitiesEnum>`
                                    
                                    .. attribute:: group_name
                                    
                                    	Group name
                                    	**type**\:  str
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.address_family_identifier = None
                                        self.configuration_type = None
                                        self.group_name = None
                                        self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress()
                                        self.neighbor_address.parent = self


                                    class NeighborAddress(object):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-config-entid'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.address_family_identifier is not None:
                                            return True

                                        if self.configuration_type is not None:
                                            return True

                                        if self.group_name is not None:
                                            return True

                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af-dependent-relative'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bgp_config_entid is not None:
                                        for child_ref in self.bgp_config_entid:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:configuration-inheritance'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.address_family_identifier is not None:
                                    return True

                                if self.af_dependent_relative is not None:
                                    for child_ref in self.af_dependent_relative:
                                        if child_ref._has_data():
                                            return True

                                if self.af_independent_relatives is not None and self.af_independent_relatives._has_data():
                                    return True

                                if self.configuration_type is not None:
                                    return True

                                if self.entity_name is not None:
                                    return True

                                if self.entity_type is not None:
                                    return True

                                if self.group_name is not None:
                                    return True

                                if self.neighbor_address is not None:
                                    return True

                                if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:configuration-inheritances'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.configuration_inheritance is not None:
                                for child_ref in self.configuration_inheritance:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')
                        if self.vrf_name is None:
                            raise YPYModelError('Key property vrf_name is None')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:config-vrf[Cisco-IOS-XR-ipv4-bgp-oper:vrf-name = ' + str(self.vrf_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.vrf_name is not None:
                            return True

                        if self.configuration_inheritances is not None and self.configuration_inheritances._has_data():
                            return True

                        if self.configuration_users is not None and self.configuration_users._has_data():
                            return True

                        if self.entity_configurations is not None and self.entity_configurations._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                        return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:config-vrfs'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.config_vrf is not None:
                        for child_ref in self.config_vrf:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                    return meta._meta_table['Bgp.ConfigInstances.ConfigInstance.ConfigVrfs']['meta_info']

            @property
            def _common_path(self):
                if self.instance_name is None:
                    raise YPYModelError('Key property instance_name is None')

                return '/Cisco-IOS-XR-ipv4-bgp-oper:bgp/Cisco-IOS-XR-ipv4-bgp-oper:config-instances/Cisco-IOS-XR-ipv4-bgp-oper:config-instance[Cisco-IOS-XR-ipv4-bgp-oper:instance-name = ' + str(self.instance_name) + ']'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.instance_name is not None:
                    return True

                if self.config_instance_default_vrf is not None and self.config_instance_default_vrf._has_data():
                    return True

                if self.config_vrfs is not None and self.config_vrfs._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                return meta._meta_table['Bgp.ConfigInstances.ConfigInstance']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-ipv4-bgp-oper:bgp/Cisco-IOS-XR-ipv4-bgp-oper:config-instances'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.config_instance is not None:
                for child_ref in self.config_instance:
                    if child_ref._has_data():
                        return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
            return meta._meta_table['Bgp.ConfigInstances']['meta_info']


    class Instances(object):
        """
        Instance specific BGP data
        
        .. attribute:: instance
        
        	Instance specific BGP data
        	**type**\: list of    :py:class:`Instance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance>`
        
        

        """

        _prefix = 'ipv4-bgp-oper'
        _revision = '2015-08-27'

        def __init__(self):
            self.parent = None
            self.instance = YList()
            self.instance.parent = self
            self.instance.name = 'instance'


        class Instance(object):
            """
            Instance specific BGP data
            
            .. attribute:: instance_name  <key>
            
            	Name of the BGP instance
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            .. attribute:: instance_active
            
            	Active BGP operational data
            	**type**\:   :py:class:`InstanceActive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive>`
            
            .. attribute:: instance_standby
            
            	Standby BGP operational data
            	**type**\:   :py:class:`InstanceStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby>`
            
            

            """

            _prefix = 'ipv4-bgp-oper'
            _revision = '2015-08-27'

            def __init__(self):
                self.parent = None
                self.instance_name = None
                self.instance_active = Bgp.Instances.Instance.InstanceActive()
                self.instance_active.parent = self
                self.instance_standby = Bgp.Instances.Instance.InstanceStandby()
                self.instance_standby.parent = self


            class InstanceActive(object):
                """
                Active BGP operational data
                
                .. attribute:: attribute_filter_groups
                
                	All attribute\-filter groups in this instance
                	**type**\:   :py:class:`AttributeFilterGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.AttributeFilterGroups>`
                
                .. attribute:: attributes
                
                	The BGP Attribute table
                	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes>`
                
                .. attribute:: default_vrf
                
                	Default VRF related operational data
                	**type**\:   :py:class:`DefaultVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf>`
                
                .. attribute:: label_entries
                
                	BGP Label Table
                	**type**\:   :py:class:`LabelEntries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.LabelEntries>`
                
                .. attribute:: label_rpf_entries
                
                	BGP Label RPF Table
                	**type**\:   :py:class:`LabelRpfEntries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.LabelRpfEntries>`
                
                .. attribute:: label_summary
                
                	BGP Label Summary
                	**type**\:   :py:class:`LabelSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.LabelSummary>`
                
                .. attribute:: rpki_refresh_afs
                
                	RPKI Refresh Table (per AF)
                	**type**\:   :py:class:`RpkiRefreshAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.RpkiRefreshAfs>`
                
                .. attribute:: rpki_routes
                
                	BGP RPKI ROA table
                	**type**\:   :py:class:`RpkiRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.RpkiRoutes>`
                
                .. attribute:: rpki_server_list
                
                	RPKI Server Table
                	**type**\:   :py:class:`RpkiServerList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.RpkiServerList>`
                
                .. attribute:: rpki_summary
                
                	RPKI Summary Info
                	**type**\:   :py:class:`RpkiSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.RpkiSummary>`
                
                .. attribute:: rt_entries
                
                	BGP Route Target Sets Table
                	**type**\:   :py:class:`RtEntries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.RtEntries>`
                
                .. attribute:: update_generation_process
                
                	Update generation for the process
                	**type**\:   :py:class:`UpdateGenerationProcess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess>`
                
                .. attribute:: update_inbound_error_process
                
                	Update inbound error information for the process
                	**type**\:   :py:class:`UpdateInboundErrorProcess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.UpdateInboundErrorProcess>`
                
                .. attribute:: update_inbound_filter_process
                
                	Update inbound filtering information for the process
                	**type**\:   :py:class:`UpdateInboundFilterProcess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.UpdateInboundFilterProcess>`
                
                .. attribute:: vrfs
                
                	VRF related operational data
                	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs>`
                
                

                """

                _prefix = 'ipv4-bgp-oper'
                _revision = '2015-08-27'

                def __init__(self):
                    self.parent = None
                    self.attribute_filter_groups = Bgp.Instances.Instance.InstanceActive.AttributeFilterGroups()
                    self.attribute_filter_groups.parent = self
                    self.attributes = Bgp.Instances.Instance.InstanceActive.Attributes()
                    self.attributes.parent = self
                    self.default_vrf = Bgp.Instances.Instance.InstanceActive.DefaultVrf()
                    self.default_vrf.parent = self
                    self.label_entries = Bgp.Instances.Instance.InstanceActive.LabelEntries()
                    self.label_entries.parent = self
                    self.label_rpf_entries = Bgp.Instances.Instance.InstanceActive.LabelRpfEntries()
                    self.label_rpf_entries.parent = self
                    self.label_summary = Bgp.Instances.Instance.InstanceActive.LabelSummary()
                    self.label_summary.parent = self
                    self.rpki_refresh_afs = Bgp.Instances.Instance.InstanceActive.RpkiRefreshAfs()
                    self.rpki_refresh_afs.parent = self
                    self.rpki_routes = Bgp.Instances.Instance.InstanceActive.RpkiRoutes()
                    self.rpki_routes.parent = self
                    self.rpki_server_list = Bgp.Instances.Instance.InstanceActive.RpkiServerList()
                    self.rpki_server_list.parent = self
                    self.rpki_summary = Bgp.Instances.Instance.InstanceActive.RpkiSummary()
                    self.rpki_summary.parent = self
                    self.rt_entries = Bgp.Instances.Instance.InstanceActive.RtEntries()
                    self.rt_entries.parent = self
                    self.update_generation_process = Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess()
                    self.update_generation_process.parent = self
                    self.update_inbound_error_process = Bgp.Instances.Instance.InstanceActive.UpdateInboundErrorProcess()
                    self.update_inbound_error_process.parent = self
                    self.update_inbound_filter_process = Bgp.Instances.Instance.InstanceActive.UpdateInboundFilterProcess()
                    self.update_inbound_filter_process.parent = self
                    self.vrfs = Bgp.Instances.Instance.InstanceActive.Vrfs()
                    self.vrfs.parent = self


                class LabelEntries(object):
                    """
                    BGP Label Table
                    
                    .. attribute:: label_entry
                    
                    	BGP Label Entry
                    	**type**\: list of    :py:class:`LabelEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.LabelEntries.LabelEntry>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2015-08-27'

                    def __init__(self):
                        self.parent = None
                        self.label_entry = YList()
                        self.label_entry.parent = self
                        self.label_entry.name = 'label_entry'


                    class LabelEntry(object):
                        """
                        BGP Label Entry
                        
                        .. attribute:: label  <key>
                        
                        	Label index
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: entry
                        
                        	entry
                        	**type**\:   :py:class:`Entry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.LabelEntries.LabelEntry.Entry>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.label = None
                            self.entry = Bgp.Instances.Instance.InstanceActive.LabelEntries.LabelEntry.Entry()
                            self.entry.parent = self


                        class Entry(object):
                            """
                            entry
                            
                            .. attribute:: inactive
                            
                            	inactive
                            	**type**\:  bool
                            
                            .. attribute:: info
                            
                            	info
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: ip
                            
                            	ip
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ip6
                            
                            	ip6
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: label
                            
                            	label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: masklen
                            
                            	masklen
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: rds
                            
                            	rds
                            	**type**\:  str
                            
                            .. attribute:: refcount
                            
                            	refcount
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rpc_set_id
                            
                            	rpc set id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ts_sec
                            
                            	ts sec
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ts_ssec
                            
                            	ts ssec
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vrf
                            
                            	vrf
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.inactive = None
                                self.info = None
                                self.ip = None
                                self.ip6 = None
                                self.label = None
                                self.masklen = None
                                self.rds = None
                                self.refcount = None
                                self.rpc_set_id = None
                                self.ts_sec = None
                                self.ts_ssec = None
                                self.vrf = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:entry'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.inactive is not None:
                                    return True

                                if self.info is not None:
                                    return True

                                if self.ip is not None:
                                    return True

                                if self.ip6 is not None:
                                    return True

                                if self.label is not None:
                                    return True

                                if self.masklen is not None:
                                    return True

                                if self.rds is not None:
                                    return True

                                if self.refcount is not None:
                                    return True

                                if self.rpc_set_id is not None:
                                    return True

                                if self.ts_sec is not None:
                                    return True

                                if self.ts_ssec is not None:
                                    return True

                                if self.vrf is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.LabelEntries.LabelEntry.Entry']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.label is None:
                                raise YPYModelError('Key property label is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-entry[Cisco-IOS-XR-ipv4-bgp-oper:label = ' + str(self.label) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.label is not None:
                                return True

                            if self.entry is not None and self.entry._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.LabelEntries.LabelEntry']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-entries'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.label_entry is not None:
                            for child_ref in self.label_entry:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.LabelEntries']['meta_info']


                class LabelSummary(object):
                    """
                    BGP Label Summary
                    
                    .. attribute:: stats
                    
                    	stats
                    	**type**\:   :py:class:`Stats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.LabelSummary.Stats>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2015-08-27'

                    def __init__(self):
                        self.parent = None
                        self.stats = Bgp.Instances.Instance.InstanceActive.LabelSummary.Stats()
                        self.stats.parent = self


                    class Stats(object):
                        """
                        stats
                        
                        .. attribute:: bgp_label_rpf_lists
                        
                        	bgp label rpf lists
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bgp_label_rpf_nodes
                        
                        	bgp label rpf nodes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbgp_label_alloc_type_asbr_nh
                        
                        	nBGP LABEL ALLOC TYPE ASBR NH
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbgp_label_alloc_type_ce_ipv4
                        
                        	nBGP LABEL ALLOC TYPE CE IPv4
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbgp_label_alloc_type_ce_ipv6
                        
                        	nBGP LABEL ALLOC TYPE CE IPv6
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbgp_label_alloc_type_gbl_ipv4
                        
                        	nBGP LABEL ALLOC TYPE GBL IPv4
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbgp_label_alloc_type_gbl_ipv6
                        
                        	nBGP LABEL ALLOC TYPE GBL IPv6
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbgp_label_alloc_type_tbl_ipv4
                        
                        	nBGP LABEL ALLOC TYPE TBL IPv4
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbgp_label_alloc_type_tbl_ipv6
                        
                        	nBGP LABEL ALLOC TYPE TBL IPv6
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbgp_label_alloc_type_vpn_ipv4
                        
                        	nBGP LABEL ALLOC TYPE VPN IPv4
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbgp_label_alloc_type_vpn_ipv6
                        
                        	nBGP LABEL ALLOC TYPE VPN IPv6
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbgp_label_alloc_type_vrf_ipv4
                        
                        	nBGP LABEL ALLOC TYPE VRF IPv4
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbgp_label_alloc_type_vrf_ipv6
                        
                        	nBGP LABEL ALLOC TYPE VRF IPv6
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbgp_labels
                        
                        	nBGP LABELS
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.bgp_label_rpf_lists = None
                            self.bgp_label_rpf_nodes = None
                            self.nbgp_label_alloc_type_asbr_nh = None
                            self.nbgp_label_alloc_type_ce_ipv4 = None
                            self.nbgp_label_alloc_type_ce_ipv6 = None
                            self.nbgp_label_alloc_type_gbl_ipv4 = None
                            self.nbgp_label_alloc_type_gbl_ipv6 = None
                            self.nbgp_label_alloc_type_tbl_ipv4 = None
                            self.nbgp_label_alloc_type_tbl_ipv6 = None
                            self.nbgp_label_alloc_type_vpn_ipv4 = None
                            self.nbgp_label_alloc_type_vpn_ipv6 = None
                            self.nbgp_label_alloc_type_vrf_ipv4 = None
                            self.nbgp_label_alloc_type_vrf_ipv6 = None
                            self.nbgp_labels = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:stats'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bgp_label_rpf_lists is not None:
                                return True

                            if self.bgp_label_rpf_nodes is not None:
                                return True

                            if self.nbgp_label_alloc_type_asbr_nh is not None:
                                return True

                            if self.nbgp_label_alloc_type_ce_ipv4 is not None:
                                return True

                            if self.nbgp_label_alloc_type_ce_ipv6 is not None:
                                return True

                            if self.nbgp_label_alloc_type_gbl_ipv4 is not None:
                                return True

                            if self.nbgp_label_alloc_type_gbl_ipv6 is not None:
                                return True

                            if self.nbgp_label_alloc_type_tbl_ipv4 is not None:
                                return True

                            if self.nbgp_label_alloc_type_tbl_ipv6 is not None:
                                return True

                            if self.nbgp_label_alloc_type_vpn_ipv4 is not None:
                                return True

                            if self.nbgp_label_alloc_type_vpn_ipv6 is not None:
                                return True

                            if self.nbgp_label_alloc_type_vrf_ipv4 is not None:
                                return True

                            if self.nbgp_label_alloc_type_vrf_ipv6 is not None:
                                return True

                            if self.nbgp_labels is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.LabelSummary.Stats']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-summary'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.stats is not None and self.stats._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.LabelSummary']['meta_info']


                class LabelRpfEntries(object):
                    """
                    BGP Label RPF Table
                    
                    .. attribute:: label_rpf_entry
                    
                    	BGP Label RPF Entry
                    	**type**\: list of    :py:class:`LabelRpfEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.LabelRpfEntries.LabelRpfEntry>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2015-08-27'

                    def __init__(self):
                        self.parent = None
                        self.label_rpf_entry = YList()
                        self.label_rpf_entry.parent = self
                        self.label_rpf_entry.name = 'label_rpf_entry'


                    class LabelRpfEntry(object):
                        """
                        BGP Label RPF Entry
                        
                        .. attribute:: label  <key>
                        
                        	Label index
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: rpf
                        
                        	rpf
                        	**type**\:   :py:class:`Rpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.LabelRpfEntries.LabelRpfEntry.Rpf>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.label = None
                            self.rpf = Bgp.Instances.Instance.InstanceActive.LabelRpfEntries.LabelRpfEntry.Rpf()
                            self.rpf.parent = self


                        class Rpf(object):
                            """
                            rpf
                            
                            .. attribute:: flags
                            
                            	flags
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: install
                            
                            	install
                            	**type**\:   :py:class:`BgpLabelRpfInstallEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpLabelRpfInstallEnum>`
                            
                            .. attribute:: label
                            
                            	label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rpf
                            
                            	rpf
                            	**type**\: list of    :py:class:`Rpf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.LabelRpfEntries.LabelRpfEntry.Rpf.Rpf_>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.flags = None
                                self.install = None
                                self.label = None
                                self.rpf = YList()
                                self.rpf.parent = self
                                self.rpf.name = 'rpf'


                            class Rpf_(object):
                                """
                                rpf
                                
                                .. attribute:: count
                                
                                	count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: flags
                                
                                	flags
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ip
                                
                                	ip
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ip6
                                
                                	ip6
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.count = None
                                    self.flags = None
                                    self.ip = None
                                    self.ip6 = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rpf'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.count is not None:
                                        return True

                                    if self.flags is not None:
                                        return True

                                    if self.ip is not None:
                                        return True

                                    if self.ip6 is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.LabelRpfEntries.LabelRpfEntry.Rpf.Rpf_']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rpf'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.flags is not None:
                                    return True

                                if self.install is not None:
                                    return True

                                if self.label is not None:
                                    return True

                                if self.rpf is not None:
                                    for child_ref in self.rpf:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.LabelRpfEntries.LabelRpfEntry.Rpf']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.label is None:
                                raise YPYModelError('Key property label is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-rpf-entry[Cisco-IOS-XR-ipv4-bgp-oper:label = ' + str(self.label) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.label is not None:
                                return True

                            if self.rpf is not None and self.rpf._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.LabelRpfEntries.LabelRpfEntry']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-rpf-entries'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.label_rpf_entry is not None:
                            for child_ref in self.label_rpf_entry:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.LabelRpfEntries']['meta_info']


                class UpdateGenerationProcess(object):
                    """
                    Update generation for the process
                    
                    .. attribute:: configured_update_limit_process
                    
                    	Configured Process update limit
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: current_update_limit_process
                    
                    	Current Process update limit
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update_address_family
                    
                    	List of address\-families
                    	**type**\: list of    :py:class:`UpdateAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateAddressFamily>`
                    
                    .. attribute:: update_out_logging
                    
                    	Enable syslog messages for update generation events
                    	**type**\:  bool
                    
                    .. attribute:: update_out_queue_messages
                    
                    	OutQueue messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update_out_queue_size
                    
                    	OutQueue size
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update_statistics
                    
                    	Update statistics
                    	**type**\:   :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics>`
                    
                    .. attribute:: update_throttled
                    
                    	Is update throttled
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2015-08-27'

                    def __init__(self):
                        self.parent = None
                        self.configured_update_limit_process = None
                        self.current_update_limit_process = None
                        self.update_address_family = YList()
                        self.update_address_family.parent = self
                        self.update_address_family.name = 'update_address_family'
                        self.update_out_logging = None
                        self.update_out_queue_messages = None
                        self.update_out_queue_size = None
                        self.update_statistics = Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics()
                        self.update_statistics.parent = self
                        self.update_throttled = None


                    class UpdateStatistics(object):
                        """
                        Update statistics
                        
                        .. attribute:: last_update_cleard_age
                        
                        	Time since last Clear event (in seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: last_update_cleared_timestamp
                        
                        	Last Cleared time
                        	**type**\:   :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateClearedTimestamp>`
                        
                        .. attribute:: last_update_discard_age
                        
                        	Time since last Discard event (in seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: last_update_discard_timestamp
                        
                        	Last Discarded time
                        	**type**\:   :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateDiscardTimestamp>`
                        
                        .. attribute:: last_update_memory_allocation_fail_age
                        
                        	Time since last memory allocation failure event (in seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: last_update_memory_allocation_fail_timestamp
                        
                        	Memory allocation failure time
                        	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                        
                        .. attribute:: last_update_recovery_age
                        
                        	Time since last Recovery event (in seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: last_update_recovery_timestamp
                        
                        	Last Recovery time
                        	**type**\:   :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                        
                        .. attribute:: last_update_throttle_age
                        
                        	Time since last Throttle event (in seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: last_update_throttle_timestamp
                        
                        	Last Throttled time
                        	**type**\:   :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateThrottleTimestamp>`
                        
                        .. attribute:: update_memory_allocation_fail_count
                        
                        	Memory allocation failure count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_messages_cleared
                        
                        	OutQueue Cleared Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_messages_cumulative
                        
                        	OutQueue Cumulative Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_messages_discarded
                        
                        	OutQueue Discarded Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_messages_high
                        
                        	OutQueue High Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_size_cleared
                        
                        	OutQueue Cleared Size
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: update_out_queue_size_cumulative
                        
                        	OutQueue Cumulative Size
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: update_out_queue_size_discarded
                        
                        	OutQueue Discarded Size
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: update_out_queue_size_high
                        
                        	OutQueue Hi Size
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_recovery_count
                        
                        	Recovery Count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_throttle_count
                        
                        	Throttle Count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.last_update_cleard_age = None
                            self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateClearedTimestamp()
                            self.last_update_cleared_timestamp.parent = self
                            self.last_update_discard_age = None
                            self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateDiscardTimestamp()
                            self.last_update_discard_timestamp.parent = self
                            self.last_update_memory_allocation_fail_age = None
                            self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                            self.last_update_memory_allocation_fail_timestamp.parent = self
                            self.last_update_recovery_age = None
                            self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateRecoveryTimestamp()
                            self.last_update_recovery_timestamp.parent = self
                            self.last_update_throttle_age = None
                            self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateThrottleTimestamp()
                            self.last_update_throttle_timestamp.parent = self
                            self.update_memory_allocation_fail_count = None
                            self.update_out_queue_messages_cleared = None
                            self.update_out_queue_messages_cumulative = None
                            self.update_out_queue_messages_discarded = None
                            self.update_out_queue_messages_high = None
                            self.update_out_queue_size_cleared = None
                            self.update_out_queue_size_cumulative = None
                            self.update_out_queue_size_discarded = None
                            self.update_out_queue_size_high = None
                            self.update_recovery_count = None
                            self.update_throttle_count = None


                        class LastUpdateDiscardTimestamp(object):
                            """
                            Last Discarded time
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.nanoseconds = None
                                self.seconds = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-discard-timestamp'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.nanoseconds is not None:
                                    return True

                                if self.seconds is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateDiscardTimestamp']['meta_info']


                        class LastUpdateClearedTimestamp(object):
                            """
                            Last Cleared time
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.nanoseconds = None
                                self.seconds = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-cleared-timestamp'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.nanoseconds is not None:
                                    return True

                                if self.seconds is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateClearedTimestamp']['meta_info']


                        class LastUpdateThrottleTimestamp(object):
                            """
                            Last Throttled time
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.nanoseconds = None
                                self.seconds = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-throttle-timestamp'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.nanoseconds is not None:
                                    return True

                                if self.seconds is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateThrottleTimestamp']['meta_info']


                        class LastUpdateRecoveryTimestamp(object):
                            """
                            Last Recovery time
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.nanoseconds = None
                                self.seconds = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-recovery-timestamp'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.nanoseconds is not None:
                                    return True

                                if self.seconds is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateRecoveryTimestamp']['meta_info']


                        class LastUpdateMemoryAllocationFailTimestamp(object):
                            """
                            Memory allocation failure time
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.nanoseconds = None
                                self.seconds = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-memory-allocation-fail-timestamp'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.nanoseconds is not None:
                                    return True

                                if self.seconds is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-statistics'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.last_update_cleard_age is not None:
                                return True

                            if self.last_update_cleared_timestamp is not None and self.last_update_cleared_timestamp._has_data():
                                return True

                            if self.last_update_discard_age is not None:
                                return True

                            if self.last_update_discard_timestamp is not None and self.last_update_discard_timestamp._has_data():
                                return True

                            if self.last_update_memory_allocation_fail_age is not None:
                                return True

                            if self.last_update_memory_allocation_fail_timestamp is not None and self.last_update_memory_allocation_fail_timestamp._has_data():
                                return True

                            if self.last_update_recovery_age is not None:
                                return True

                            if self.last_update_recovery_timestamp is not None and self.last_update_recovery_timestamp._has_data():
                                return True

                            if self.last_update_throttle_age is not None:
                                return True

                            if self.last_update_throttle_timestamp is not None and self.last_update_throttle_timestamp._has_data():
                                return True

                            if self.update_memory_allocation_fail_count is not None:
                                return True

                            if self.update_out_queue_messages_cleared is not None:
                                return True

                            if self.update_out_queue_messages_cumulative is not None:
                                return True

                            if self.update_out_queue_messages_discarded is not None:
                                return True

                            if self.update_out_queue_messages_high is not None:
                                return True

                            if self.update_out_queue_size_cleared is not None:
                                return True

                            if self.update_out_queue_size_cumulative is not None:
                                return True

                            if self.update_out_queue_size_discarded is not None:
                                return True

                            if self.update_out_queue_size_high is not None:
                                return True

                            if self.update_recovery_count is not None:
                                return True

                            if self.update_throttle_count is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics']['meta_info']


                    class UpdateAddressFamily(object):
                        """
                        List of address\-families
                        
                        .. attribute:: current_update_limit_af
                        
                        	Current AF update limit
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: filter_group_count
                        
                        	Filter\-group count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: neighbor_count
                        
                        	Neighbor count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: refresh_sub_group_count
                        
                        	Refresh sub\-group count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: refresh_sub_group_throttled_count
                        
                        	Throttled refresh sub\-group count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sub_group_throttled_count
                        
                        	Throttled sub\-group count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_group_af_name
                        
                        	Address family identifier
                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                        
                        .. attribute:: update_out_queue_messages
                        
                        	OutQueue messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_size
                        
                        	OutQueue size
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_sub_group_count
                        
                        	Sub\-group count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_throttled
                        
                        	Is update throttled
                        	**type**\:  bool
                        
                        .. attribute:: update_update_group_count
                        
                        	Update\-group count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.current_update_limit_af = None
                            self.filter_group_count = None
                            self.neighbor_count = None
                            self.refresh_sub_group_count = None
                            self.refresh_sub_group_throttled_count = None
                            self.sub_group_throttled_count = None
                            self.update_group_af_name = None
                            self.update_out_queue_messages = None
                            self.update_out_queue_size = None
                            self.update_sub_group_count = None
                            self.update_throttled = None
                            self.update_update_group_count = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-address-family'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.current_update_limit_af is not None:
                                return True

                            if self.filter_group_count is not None:
                                return True

                            if self.neighbor_count is not None:
                                return True

                            if self.refresh_sub_group_count is not None:
                                return True

                            if self.refresh_sub_group_throttled_count is not None:
                                return True

                            if self.sub_group_throttled_count is not None:
                                return True

                            if self.update_group_af_name is not None:
                                return True

                            if self.update_out_queue_messages is not None:
                                return True

                            if self.update_out_queue_size is not None:
                                return True

                            if self.update_sub_group_count is not None:
                                return True

                            if self.update_throttled is not None:
                                return True

                            if self.update_update_group_count is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateAddressFamily']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-process'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.configured_update_limit_process is not None:
                            return True

                        if self.current_update_limit_process is not None:
                            return True

                        if self.update_address_family is not None:
                            for child_ref in self.update_address_family:
                                if child_ref._has_data():
                                    return True

                        if self.update_out_logging is not None:
                            return True

                        if self.update_out_queue_messages is not None:
                            return True

                        if self.update_out_queue_size is not None:
                            return True

                        if self.update_statistics is not None and self.update_statistics._has_data():
                            return True

                        if self.update_throttled is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess']['meta_info']


                class RpkiRefreshAfs(object):
                    """
                    RPKI Refresh Table (per AF)
                    
                    .. attribute:: rpki_refresh_af
                    
                    	RPKI Refresh List
                    	**type**\: list of    :py:class:`RpkiRefreshAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.RpkiRefreshAfs.RpkiRefreshAf>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2015-08-27'

                    def __init__(self):
                        self.parent = None
                        self.rpki_refresh_af = YList()
                        self.rpki_refresh_af.parent = self
                        self.rpki_refresh_af.name = 'rpki_refresh_af'


                    class RpkiRefreshAf(object):
                        """
                        RPKI Refresh List
                        
                        .. attribute:: af_name  <key>
                        
                        	Adress family
                        	**type**\:   :py:class:`BgpRpkiEdmAfEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiEdmAfEnum>`
                        
                        .. attribute:: refresh_entry
                        
                        	Array of refresh entries
                        	**type**\: list of    :py:class:`RefreshEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.RpkiRefreshAfs.RpkiRefreshAf.RefreshEntry>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.refresh_entry = YList()
                            self.refresh_entry.parent = self
                            self.refresh_entry.name = 'refresh_entry'


                        class RefreshEntry(object):
                            """
                            Array of refresh entries
                            
                            .. attribute:: af_name
                            
                            	Address Family
                            	**type**\:   :py:class:`BgpRpkiAfEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiAfEnum>`
                            
                            .. attribute:: drop
                            
                            	BGP paths were dropped
                            	**type**\:  bool
                            
                            .. attribute:: neighbor
                            
                            	BGP neighbor
                            	**type**\:  str
                            
                            .. attribute:: paths
                            
                            	Number of BGP paths modified or dropped
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: policy
                            
                            	Route Policy
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.drop = None
                                self.neighbor = None
                                self.paths = None
                                self.policy = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:refresh-entry'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.drop is not None:
                                    return True

                                if self.neighbor is not None:
                                    return True

                                if self.paths is not None:
                                    return True

                                if self.policy is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.RpkiRefreshAfs.RpkiRefreshAf.RefreshEntry']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.af_name is None:
                                raise YPYModelError('Key property af_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rpki-refresh-af[Cisco-IOS-XR-ipv4-bgp-oper:af-name = ' + str(self.af_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.refresh_entry is not None:
                                for child_ref in self.refresh_entry:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.RpkiRefreshAfs.RpkiRefreshAf']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rpki-refresh-afs'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.rpki_refresh_af is not None:
                            for child_ref in self.rpki_refresh_af:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.RpkiRefreshAfs']['meta_info']


                class Vrfs(object):
                    """
                    VRF related operational data
                    
                    .. attribute:: vrf
                    
                    	Operational data for a particular VRF
                    	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2015-08-27'

                    def __init__(self):
                        self.parent = None
                        self.vrf = YList()
                        self.vrf.parent = self
                        self.vrf.name = 'vrf'


                    class Vrf(object):
                        """
                        Operational data for a particular VRF
                        
                        .. attribute:: vrf_name  <key>
                        
                        	Name of the VRF
                        	**type**\:  str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: afs
                        
                        	BGP address family table
                        	**type**\:   :py:class:`Afs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs>`
                        
                        .. attribute:: bmp
                        
                        	BMP related Operational Data
                        	**type**\:   :py:class:`Bmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp>`
                        
                        .. attribute:: global_process_info
                        
                        	The Global Process information table
                        	**type**\:   :py:class:`GlobalProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo>`
                        
                        .. attribute:: information
                        
                        	Meta data for VRF
                        	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Information>`
                        
                        .. attribute:: message_logs
                        
                        	The BGP Neighbor Message table
                        	**type**\:   :py:class:`MessageLogs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs>`
                        
                        .. attribute:: neighbor_ranges
                        
                        	The BGP Dynamic Neighbor Range table
                        	**type**\:   :py:class:`NeighborRanges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges>`
                        
                        .. attribute:: neighbors
                        
                        	The BGP Neighbor table
                        	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors>`
                        
                        .. attribute:: next_hop_vrf
                        
                        	A BGP Next\-hop VRF table entry
                        	**type**\:   :py:class:`NextHopVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NextHopVrf>`
                        
                        .. attribute:: postits
                        
                        	The BGP Neighbor table
                        	**type**\:   :py:class:`Postits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits>`
                        
                        .. attribute:: process_info
                        
                        	A Process instance table entry
                        	**type**\:   :py:class:`ProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo>`
                        
                        .. attribute:: sessions
                        
                        	The BGP session table
                        	**type**\:   :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions>`
                        
                        .. attribute:: update_inbound_error_neighbors
                        
                        	Update inbound error information for all neighbors
                        	**type**\:   :py:class:`UpdateInboundErrorNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors>`
                        
                        .. attribute:: update_inbound_error_vrf
                        
                        	Update inbound error information for the VRF
                        	**type**\:   :py:class:`UpdateInboundErrorVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorVrf>`
                        
                        .. attribute:: update_inbound_filter_neighbors
                        
                        	Update inbound filtering information for all neighbors
                        	**type**\:   :py:class:`UpdateInboundFilterNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors>`
                        
                        .. attribute:: update_inbound_filter_vrf
                        
                        	Update inbound filtering information for the VRF
                        	**type**\:   :py:class:`UpdateInboundFilterVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterVrf>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.vrf_name = None
                            self.afs = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs()
                            self.afs.parent = self
                            self.bmp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp()
                            self.bmp.parent = self
                            self.global_process_info = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo()
                            self.global_process_info.parent = self
                            self.information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Information()
                            self.information.parent = self
                            self.message_logs = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs()
                            self.message_logs.parent = self
                            self.neighbor_ranges = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges()
                            self.neighbor_ranges.parent = self
                            self.neighbors = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors()
                            self.neighbors.parent = self
                            self.next_hop_vrf = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NextHopVrf()
                            self.next_hop_vrf.parent = self
                            self.postits = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits()
                            self.postits.parent = self
                            self.process_info = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo()
                            self.process_info.parent = self
                            self.sessions = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions()
                            self.sessions.parent = self
                            self.update_inbound_error_neighbors = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors()
                            self.update_inbound_error_neighbors.parent = self
                            self.update_inbound_error_vrf = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorVrf()
                            self.update_inbound_error_vrf.parent = self
                            self.update_inbound_filter_neighbors = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors()
                            self.update_inbound_filter_neighbors.parent = self
                            self.update_inbound_filter_vrf = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterVrf()
                            self.update_inbound_filter_vrf.parent = self


                        class UpdateInboundErrorVrf(object):
                            """
                            Update inbound error information for the VRF
                            
                            .. attribute:: last_update_malformed_age
                            
                            	Time since last malformed messages received event (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_update_malformed_timestamp
                            
                            	Last malformed messages received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`LastUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp>`
                            
                            .. attribute:: update_malformed_message_count
                            
                            	Malformed messages count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_malformed_neighbor_count
                            
                            	Count of neighbors that received malformed messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_vrf_name
                            
                            	VRF Name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.last_update_malformed_age = None
                                self.last_update_malformed_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp()
                                self.last_update_malformed_timestamp.parent = self
                                self.update_malformed_message_count = None
                                self.update_malformed_neighbor_count = None
                                self.update_vrf_name = None


                            class LastUpdateMalformedTimestamp(object):
                                """
                                Last malformed messages received time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.nanoseconds = None
                                    self.seconds = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-malformed-timestamp'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.nanoseconds is not None:
                                        return True

                                    if self.seconds is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-inbound-error-vrf'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.last_update_malformed_age is not None:
                                    return True

                                if self.last_update_malformed_timestamp is not None and self.last_update_malformed_timestamp._has_data():
                                    return True

                                if self.update_malformed_message_count is not None:
                                    return True

                                if self.update_malformed_neighbor_count is not None:
                                    return True

                                if self.update_vrf_name is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorVrf']['meta_info']


                        class Afs(object):
                            """
                            BGP address family table
                            
                            .. attribute:: af
                            
                            	A particular address family
                            	**type**\: list of    :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.af = YList()
                                self.af.parent = self
                                self.af.name = 'af'


                            class Af(object):
                                """
                                A particular address family
                                
                                .. attribute:: af_name  <key>
                                
                                	Address family
                                	**type**\:   :py:class:`BgpAddressFamilyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamilyEnum>`
                                
                                .. attribute:: advertised_path_counts
                                
                                	The BGP Advertised paths table (bestpath)
                                	**type**\:   :py:class:`AdvertisedPathCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts>`
                                
                                .. attribute:: advertised_path_xr
                                
                                	The BGP Advertised path table (bestpath)
                                	**type**\:   :py:class:`AdvertisedPathXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr>`
                                
                                .. attribute:: advertised_paths
                                
                                	The BGP Advertised paths table (add\-paths)
                                	**type**\:   :py:class:`AdvertisedPaths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths>`
                                
                                .. attribute:: af_process_info
                                
                                	A BGP Process address family table entry
                                	**type**\:   :py:class:`AfProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo>`
                                
                                .. attribute:: attributes
                                
                                	The BGP Attribute table
                                	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes>`
                                
                                .. attribute:: bmp_paths
                                
                                	The paths in BMP Table
                                	**type**\:   :py:class:`BmpPaths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths>`
                                
                                .. attribute:: convergence
                                
                                	A BGP Convergence table entry
                                	**type**\:   :py:class:`Convergence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Convergence>`
                                
                                .. attribute:: dampenings
                                
                                	The BGP Dampening table
                                	**type**\:   :py:class:`Dampenings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings>`
                                
                                .. attribute:: epes
                                
                                	The BGP Egress Engineering table
                                	**type**\:   :py:class:`Epes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes>`
                                
                                .. attribute:: global_af_process_info
                                
                                	The Global Address Family Process information table
                                	**type**\:   :py:class:`GlobalAfProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo>`
                                
                                .. attribute:: neighbor_af_table
                                
                                	The BGP Neighbor AF table
                                	**type**\:   :py:class:`NeighborAfTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable>`
                                
                                .. attribute:: network_all_rds
                                
                                	The BGP Network Lookup Table
                                	**type**\:   :py:class:`NetworkAllRds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds>`
                                
                                .. attribute:: network_lookup_all_rds
                                
                                	The BGP Network Lookup Table
                                	**type**\:   :py:class:`NetworkLookupAllRds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds>`
                                
                                .. attribute:: network_prefixes
                                
                                	The BGP Network Lookup table
                                	**type**\:   :py:class:`NetworkPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes>`
                                
                                .. attribute:: networks
                                
                                	The BGP Network Table
                                	**type**\:   :py:class:`Networks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks>`
                                
                                .. attribute:: next_hop_address_families
                                
                                	Address family of nexthop table
                                	**type**\:   :py:class:`NextHopAddressFamilies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies>`
                                
                                .. attribute:: path_labeled_table
                                
                                	The BGP Path Labeled Table
                                	**type**\:   :py:class:`PathLabeledTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable>`
                                
                                .. attribute:: path_table
                                
                                	The BGP Path Table
                                	**type**\:   :py:class:`PathTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable>`
                                
                                .. attribute:: path_used_table
                                
                                	The BGP Path Used Table
                                	**type**\:   :py:class:`PathUsedTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable>`
                                
                                .. attribute:: policies
                                
                                	The BGP Policy Table
                                	**type**\:   :py:class:`Policies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies>`
                                
                                .. attribute:: prefix_filters
                                
                                	The BGP Prefix Filter table
                                	**type**\:   :py:class:`PrefixFilters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters>`
                                
                                .. attribute:: rpc_sets
                                
                                	BGP next\-hop set table
                                	**type**\:   :py:class:`RpcSets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets>`
                                
                                .. attribute:: rt_set_counters
                                
                                	The RT\-set counter table
                                	**type**\:   :py:class:`RtSetCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters>`
                                
                                .. attribute:: sourced_networks
                                
                                	The BGP Convergence table
                                	**type**\:   :py:class:`SourcedNetworks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks>`
                                
                                .. attribute:: update_generation_address_family
                                
                                	Update generation for address\-family
                                	**type**\:   :py:class:`UpdateGenerationAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily>`
                                
                                .. attribute:: update_generation_filter_groups
                                
                                	Update generation for all filter\-groups under a sub\-group
                                	**type**\:   :py:class:`UpdateGenerationFilterGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups>`
                                
                                .. attribute:: update_generation_neighbors
                                
                                	Update generation for all neighbors
                                	**type**\:   :py:class:`UpdateGenerationNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors>`
                                
                                .. attribute:: update_generation_sub_groups
                                
                                	Update generation for all sub\-groups
                                	**type**\:   :py:class:`UpdateGenerationSubGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups>`
                                
                                .. attribute:: update_generation_update_groups
                                
                                	Update generation for all update\-groups
                                	**type**\:   :py:class:`UpdateGenerationUpdateGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups>`
                                
                                .. attribute:: update_groups
                                
                                	The BGP Update group table
                                	**type**\:   :py:class:`UpdateGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.advertised_path_counts = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts()
                                    self.advertised_path_counts.parent = self
                                    self.advertised_path_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr()
                                    self.advertised_path_xr.parent = self
                                    self.advertised_paths = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths()
                                    self.advertised_paths.parent = self
                                    self.af_process_info = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo()
                                    self.af_process_info.parent = self
                                    self.attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes()
                                    self.attributes.parent = self
                                    self.bmp_paths = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths()
                                    self.bmp_paths.parent = self
                                    self.convergence = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Convergence()
                                    self.convergence.parent = self
                                    self.dampenings = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings()
                                    self.dampenings.parent = self
                                    self.epes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes()
                                    self.epes.parent = self
                                    self.global_af_process_info = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo()
                                    self.global_af_process_info.parent = self
                                    self.neighbor_af_table = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable()
                                    self.neighbor_af_table.parent = self
                                    self.network_all_rds = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds()
                                    self.network_all_rds.parent = self
                                    self.network_lookup_all_rds = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds()
                                    self.network_lookup_all_rds.parent = self
                                    self.network_prefixes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes()
                                    self.network_prefixes.parent = self
                                    self.networks = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks()
                                    self.networks.parent = self
                                    self.next_hop_address_families = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies()
                                    self.next_hop_address_families.parent = self
                                    self.path_labeled_table = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable()
                                    self.path_labeled_table.parent = self
                                    self.path_table = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable()
                                    self.path_table.parent = self
                                    self.path_used_table = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable()
                                    self.path_used_table.parent = self
                                    self.policies = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies()
                                    self.policies.parent = self
                                    self.prefix_filters = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters()
                                    self.prefix_filters.parent = self
                                    self.rpc_sets = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets()
                                    self.rpc_sets.parent = self
                                    self.rt_set_counters = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters()
                                    self.rt_set_counters.parent = self
                                    self.sourced_networks = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks()
                                    self.sourced_networks.parent = self
                                    self.update_generation_address_family = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily()
                                    self.update_generation_address_family.parent = self
                                    self.update_generation_filter_groups = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups()
                                    self.update_generation_filter_groups.parent = self
                                    self.update_generation_neighbors = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors()
                                    self.update_generation_neighbors.parent = self
                                    self.update_generation_sub_groups = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups()
                                    self.update_generation_sub_groups.parent = self
                                    self.update_generation_update_groups = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups()
                                    self.update_generation_update_groups.parent = self
                                    self.update_groups = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups()
                                    self.update_groups.parent = self


                                class NetworkLookupAllRds(object):
                                    """
                                    The BGP Network Lookup Table
                                    
                                    .. attribute:: network_lookup_all_rd
                                    
                                    	The BGP Network Lookup table
                                    	**type**\: list of    :py:class:`NetworkLookupAllRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.network_lookup_all_rd = YList()
                                        self.network_lookup_all_rd.parent = self
                                        self.network_lookup_all_rd.name = 'network_lookup_all_rd'


                                    class NetworkLookupAllRd(object):
                                        """
                                        The BGP Network Lookup table
                                        
                                        .. attribute:: network_prefix  <key>
                                        
                                        	Network 
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: network_lookup_rds
                                        
                                        	The BGP Network Lookup table
                                        	**type**\:   :py:class:`NetworkLookupRds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.network_prefix = None
                                            self.network_lookup_rds = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds()
                                            self.network_lookup_rds.parent = self


                                        class NetworkLookupRds(object):
                                            """
                                            The BGP Network Lookup table
                                            
                                            .. attribute:: network_lookup_rd
                                            
                                            	A BGP Network table entry
                                            	**type**\: list of    :py:class:`NetworkLookupRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.network_lookup_rd = YList()
                                                self.network_lookup_rd.parent = self
                                                self.network_lookup_rd.name = 'network_lookup_rd'


                                            class NetworkLookupRd(object):
                                                """
                                                A BGP Network table entry
                                                
                                                .. attribute:: rd  <key>
                                                
                                                	Route Distinguisher value
                                                	**type**\:  str
                                                
                                                .. attribute:: active_path_element
                                                
                                                	Path element list received from Active inst
                                                	**type**\: list of    :py:class:`ActivePathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement>`
                                                
                                                .. attribute:: active_process_instance_path
                                                
                                                	Active's paths for this net 
                                                	**type**\: list of    :py:class:`ActiveProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath>`
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield>`
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\:  bool
                                                
                                                .. attribute:: af_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield>`
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix>`
                                                
                                                .. attribute:: bit
                                                
                                                	Bit
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: flags
                                                
                                                	Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: gateway_array
                                                
                                                	Gateway array ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_inconsistent_paths
                                                
                                                	Net has inconsistent paths
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_lbl_retained
                                                
                                                	Net has label retained
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_local_label
                                                
                                                	Net has local label
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_net_aggregation_suppressed
                                                
                                                	Net suppressed due to aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_net_ldp_signaled
                                                
                                                	L2VPN Net LDP signaled  aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_permanent_network
                                                
                                                	Permanent Network
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_path_element
                                                
                                                	Local path element list
                                                	**type**\: list of    :py:class:`LocalPathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement>`
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: local_process_instance_path
                                                
                                                	Local (to process instance) paths for this net 
                                                	**type**\: list of    :py:class:`LocalProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath>`
                                                
                                                .. attribute:: net_backup_available
                                                
                                                	Net has backup path
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_backup_label_rewrite_available
                                                
                                                	Net has label rewrite for backup path
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_eibgp_multipath
                                                
                                                	Net has EIBGP multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_extended_flags
                                                
                                                	Net extended flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: net_flags
                                                
                                                	Flags associated with                            net
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: net_local_label
                                                
                                                	Local label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: net_local_label_rewrite
                                                
                                                	Net label has rewrite
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_local_label_srgb
                                                
                                                	Net label allocated fromSegment routing global block
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_multipath
                                                
                                                	Net has multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: num_of_path
                                                
                                                	Number of path for this net
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: process_instance_id
                                                
                                                	Process instance ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: resilient_nexthop_set
                                                
                                                	Resilient nexthop set ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_failed
                                                
                                                	RIB install failed
                                                	**type**\:  bool
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: table_brib_version
                                                
                                                	Table version # for updates
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: table_version
                                                
                                                	Table version # for net
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: version
                                                
                                                	Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: version_age
                                                
                                                	Version age
                                                	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionAge>`
                                                
                                                .. attribute:: version_timestamp
                                                
                                                	Version timestamp
                                                	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionTimestamp>`
                                                
                                                .. attribute:: vrf_name
                                                
                                                	Name of the VRF
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.rd = None
                                                    self.active_path_element = YList()
                                                    self.active_path_element.parent = self
                                                    self.active_path_element.name = 'active_path_element'
                                                    self.active_process_instance_path = YList()
                                                    self.active_process_instance_path.parent = self
                                                    self.active_process_instance_path.name = 'active_process_instance_path'
                                                    self.add_path_orr_bitfield = YList()
                                                    self.add_path_orr_bitfield.parent = self
                                                    self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                    self.advertisedto_pe = None
                                                    self.af_name = None
                                                    self.best_path_orr_bitfield = YList()
                                                    self.best_path_orr_bitfield.parent = self
                                                    self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self.bit = None
                                                    self.flags = None
                                                    self.gateway_array = None
                                                    self.has_inconsistent_paths = None
                                                    self.has_lbl_retained = None
                                                    self.has_local_label = None
                                                    self.is_net_aggregation_suppressed = None
                                                    self.is_net_ldp_signaled = None
                                                    self.is_permanent_network = None
                                                    self.local_path_element = YList()
                                                    self.local_path_element.parent = self
                                                    self.local_path_element.name = 'local_path_element'
                                                    self.local_peers_advertised_to = YList()
                                                    self.local_peers_advertised_to.parent = self
                                                    self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                    self.local_process_instance_path = YList()
                                                    self.local_process_instance_path.parent = self
                                                    self.local_process_instance_path.name = 'local_process_instance_path'
                                                    self.net_backup_available = None
                                                    self.net_backup_label_rewrite_available = None
                                                    self.net_eibgp_multipath = None
                                                    self.net_extended_flags = None
                                                    self.net_flags = None
                                                    self.net_local_label = None
                                                    self.net_local_label_rewrite = None
                                                    self.net_local_label_srgb = None
                                                    self.net_multipath = None
                                                    self.num_of_path = None
                                                    self.pe_peers_advertised_to = YList()
                                                    self.pe_peers_advertised_to.parent = self
                                                    self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                    self.process_instance_id = None
                                                    self.resilient_nexthop_set = None
                                                    self.rib_failed = None
                                                    self.route_distinguisher = None
                                                    self.table_brib_version = None
                                                    self.table_version = None
                                                    self.version = None
                                                    self.version_age = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionAge()
                                                    self.version_age.parent = self
                                                    self.version_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionTimestamp()
                                                    self.version_timestamp.parent = self
                                                    self.vrf_name = None


                                                class BgpPrefix(object):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self.prefix_length = None


                                                    class Prefix(object):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.prefix is not None and self.prefix._has_data():
                                                            return True

                                                        if self.prefix_length is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix']['meta_info']


                                                class VersionTimestamp(object):
                                                    """
                                                    Version timestamp
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-timestamp'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionTimestamp']['meta_info']


                                                class VersionAge(object):
                                                    """
                                                    Version age
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-age'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionAge']['meta_info']


                                                class LocalPeersAdvertisedTo(object):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo']['meta_info']


                                                class PePeersAdvertisedTo(object):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo']['meta_info']


                                                class BestPathOrrBitfield(object):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield']['meta_info']


                                                class AddPathOrrBitfield(object):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield']['meta_info']


                                                class LocalProcessInstancePath(object):
                                                    """
                                                    Local (to process instance) paths for this net 
                                                    
                                                    .. attribute:: af_name
                                                    
                                                    	Address family identifier
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: attributes_after_policy_in
                                                    
                                                    	Attributes after inbound policy applied
                                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn>`
                                                    
                                                    .. attribute:: label_fail
                                                    
                                                    	LSD label allocation failed 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: label_o_or_version
                                                    
                                                    	Label Version when OOR happens
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_oor
                                                    
                                                    	LSD label space is exhausted
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address_xr
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr>`
                                                    
                                                    .. attribute:: no_path
                                                    
                                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: path_information
                                                    
                                                    	Path information
                                                    	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation>`
                                                    
                                                    .. attribute:: prefix_version
                                                    
                                                    	Version of BGP Prefix Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: process_instance_id
                                                    
                                                    	Process instance ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: route_distinguisher
                                                    
                                                    	Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: source_route_distinguisher
                                                    
                                                    	Source Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: source_vrf_name
                                                    
                                                    	Name of the source VRF
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: srcaf_name
                                                    
                                                    	Address family identifier
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: vrf_name
                                                    
                                                    	Name of the VRF
                                                    	**type**\:  str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.af_name = None
                                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn()
                                                        self.attributes_after_policy_in.parent = self
                                                        self.label_fail = None
                                                        self.label_o_or_version = None
                                                        self.label_oor = None
                                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr()
                                                        self.neighbor_address_xr.parent = self
                                                        self.no_path = None
                                                        self.path_information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation()
                                                        self.path_information.parent = self
                                                        self.prefix_version = None
                                                        self.process_instance_id = None
                                                        self.route_distinguisher = None
                                                        self.source_route_distinguisher = None
                                                        self.source_vrf_name = None
                                                        self.srcaf_name = None
                                                        self.vrf_name = None


                                                    class NeighborAddressXr(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr']['meta_info']


                                                    class PathInformation(object):
                                                        """
                                                        Path information
                                                        
                                                        .. attribute:: accept_own_path
                                                        
                                                        	Accept Own
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: accept_own_self_originated_p_ath
                                                        
                                                        	Accept\-Own self\-originated
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: add_path_orr_bitfield
                                                        
                                                        	ORR Add path Bitfields
                                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                        
                                                        .. attribute:: advertisedto_pe
                                                        
                                                        	Net could be advertised                          to PE peers
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: aigp_metric
                                                        
                                                        	Total AIGP metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: best_path_comp_stage
                                                        
                                                        	Stage where the path lost to the best path or group best
                                                        	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                                        
                                                        .. attribute:: best_path_comp_winner
                                                        
                                                        	Neighbor address of the path which won best path comparison
                                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                        
                                                        .. attribute:: best_path_id
                                                        
                                                        	Best path ID; DEPRECATED BYLocalPathId
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: best_path_id_comp_winner
                                                        
                                                        	Path ID of the path which won best path comparison
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: best_path_orr_bitfield
                                                        
                                                        	ORR Best path Bitfields
                                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                        
                                                        .. attribute:: bgp_prefix
                                                        
                                                        	BGP prefix
                                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix>`
                                                        
                                                        .. attribute:: dampen_penalty
                                                        
                                                        	Dampening penalty
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Mvpn Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                        
                                                        .. attribute:: fspec_invalid_path
                                                        
                                                        	Is Fspec invalid path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: graceful_shutdown
                                                        
                                                        	Marked for graceful shutdown
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: gw_addr
                                                        
                                                        	Path GW Address
                                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.GwAddr>`
                                                        
                                                        .. attribute:: halflife_time
                                                        
                                                        	Half\-life time for the penalty
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_esi
                                                        
                                                        	Path has EVPN ESI
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_gw_addr
                                                        
                                                        	Path has GW Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_local_net_label
                                                        
                                                        	Path has local label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mdt_group_addr
                                                        
                                                        	Path has MDT Group Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_extcomm
                                                        
                                                        	Path has MVPN EXTCOMM feedback
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_nbr_addr
                                                        
                                                        	Path has Mvpn nbr Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_nexthop_addr
                                                        
                                                        	Path has MVPN nexthop Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_pmsi
                                                        
                                                        	Path has MVPN PMSI feedback
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_rcvd_label
                                                        
                                                        	Path has received label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_second_label
                                                        
                                                        	Path has second received label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: ibgp_signaled_validity
                                                        
                                                        	IBGP signalled validation
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: igp_metric
                                                        
                                                        	IGP metric to the gateway
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: is_aggregation_suppressed
                                                        
                                                        	Path suppressed due to aggregation
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_best
                                                        
                                                        	Best available path within AS
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_best_path
                                                        
                                                        	Best available path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_import_dampened
                                                        
                                                        	net import dampened
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_import_suspect
                                                        
                                                        	net import suspect
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_internal_path
                                                        
                                                        	Received over an internal link
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_partial_best
                                                        
                                                        	Partial best path within distributed speaker
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_additional_path
                                                        
                                                        	Path is an additional\-path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_advertised_local_as_only
                                                        
                                                        	Not advertised outside local AS
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_af_install_eligible
                                                        
                                                        	Path can be installed in AF RIB
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_backup
                                                        
                                                        	Path is a backup path 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_backup_protect_multipath
                                                        
                                                        	Path is a backup path to protect multipaths
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_best_external
                                                        
                                                        	Path is a best external path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_damped
                                                        
                                                        	Path suppressed due to dampening
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_confederation_peer
                                                        
                                                        	Path received from confederation peer
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_network_command
                                                        
                                                        	Path sourced by network command
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_redistribute_command
                                                        
                                                        	Path sourced by redistribute command
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_route_reflector
                                                        
                                                        	Path received from route reflector
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_history_held
                                                        
                                                        	Path entry held to remember history
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_imp_candidate
                                                        
                                                        	Path is a candidate for multipath import
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_imported
                                                        
                                                        	Path is imported
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_local_aggregate
                                                        
                                                        	Path is a locally created aggregate
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_locally_sourced
                                                        
                                                        	Path sourced locally
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_long_lived_stale
                                                        
                                                        	Long lived stale routes learnt before neighbor restarts
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_multipath
                                                        
                                                        	Path is one of multipath best routes
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_nexthop_discarded
                                                        
                                                        	Path is redirected to Null0
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_not_advertised
                                                        
                                                        	Not advertised to any peer
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_not_advertised_to_ebg_ps
                                                        
                                                        	Not advertised to EBGPs
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_received_only
                                                        
                                                        	Path is received only
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_reoriginated
                                                        
                                                        	Path is reoriginated
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_reoriginated_stitching
                                                        
                                                        	Path is reoriginated with stitching RTs
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_stale
                                                        
                                                        	Stale routes learnt before neighbor restarts
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_synced_with_igp
                                                        
                                                        	Path synchronized with IGP
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_valid
                                                        
                                                        	Path attributes are usable
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_vpn_only
                                                        
                                                        	Path is not in the vrf
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_permanent_path
                                                        
                                                        	Path is of type Permanent path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_received_path_not_modified
                                                        
                                                        	Received path used without modification
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_spkr_as_best
                                                        
                                                        	Best available path within AS in speaker
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2vpn_circuit_status_value
                                                        
                                                        	L2VPN Circuit Status Value
                                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                        
                                                        .. attribute:: l2vpn_evpn_esi
                                                        
                                                        	L2VPN EVPN ESI
                                                        	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi>`
                                                        
                                                        .. attribute:: l2vpn_size
                                                        
                                                        	Path block size
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: labeled_unicast_safi_path
                                                        
                                                        	Path was learnt by labeled\-unicast SAFI
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: local_label
                                                        
                                                        	Path local label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_nh
                                                        
                                                        	Path has local nexthop
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: local_path_id
                                                        
                                                        	Local path ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_peers_advertised_to
                                                        
                                                        	Local peers that this prefix has been advertised to
                                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                        
                                                        .. attribute:: maximum_suppress_time
                                                        
                                                        	Maximum duration to suppress a stable route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mdt_group_addr
                                                        
                                                        	IPv4 MDT Group Address for the path
                                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                        
                                                        .. attribute:: mvpn_nbr_addr
                                                        
                                                        	Mvpn nbr Address for the path
                                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                        
                                                        .. attribute:: mvpn_nexthop_addr
                                                        
                                                        	Mvpn nexthop Address for the path
                                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                        
                                                        .. attribute:: mvpn_path_flags
                                                        
                                                        	Mvpn path flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: mvpn_pmsi_flags
                                                        
                                                        	Mvpn PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: mvpn_pmsi_label
                                                        
                                                        	Mvpn PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mvpn_pmsi_type
                                                        
                                                        	Mvpn PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: mvpn_pmsi_value
                                                        
                                                        	Mvpn PMSI Value
                                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                        
                                                        .. attribute:: mvpn_sfs_path
                                                        
                                                        	Is MVPN single forwarder PE path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress>`
                                                        
                                                        .. attribute:: neighbor_router_id
                                                        
                                                        	Router ID of the neighbor for the path
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: next_hop
                                                        
                                                        	Next hop
                                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop>`
                                                        
                                                        .. attribute:: nhte_tunnel
                                                        
                                                        	NH TE tunnel information
                                                        	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhteTunnel>`
                                                        
                                                        .. attribute:: path_flags
                                                        
                                                        	Flags associated with path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: path_flap_count
                                                        
                                                        	Number of times this route has flapped
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_import_flags
                                                        
                                                        	Path import flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_rt_set_id
                                                        
                                                        	RT\-set id of the path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_rt_set_route_count
                                                        
                                                        	Count in RT\-set
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_table_version
                                                        
                                                        	Table version # for pelem
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_weight
                                                        
                                                        	Weight for the path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pe_peers_advertised_to
                                                        
                                                        	PE peers that this prefix has been advertised to
                                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                        
                                                        .. attribute:: rcvd_label
                                                        
                                                        	Path received label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rcvd_path_id
                                                        
                                                        	Received path ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: reuse_value
                                                        
                                                        	Value to start reusing a route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rib_failed
                                                        
                                                        	Is net failed installed                          in RIB
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route Type of path
                                                        	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                                        
                                                        .. attribute:: rpki_origin_as_validation_disabled
                                                        
                                                        	RPKI originAS V. Disabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: rt_set_limit_enabled
                                                        
                                                        	Path subject to RT\-set net limit
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: second_label
                                                        
                                                        	Path second received label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: seconds_since_first_flap
                                                        
                                                        	Seconds since route first flapped
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: show_rpki_origin_as_validity
                                                        
                                                        	Display validity state ?
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: sn_rpki_origin_as_validity
                                                        
                                                        	RPKI origin validation state
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: suppress_penalty
                                                        
                                                        	Value to start suppressing a route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: time_to_unsuppress
                                                        
                                                        	Seconds until route is unsuppressed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.accept_own_path = None
                                                            self.accept_own_self_originated_p_ath = None
                                                            self.add_path_orr_bitfield = YList()
                                                            self.add_path_orr_bitfield.parent = self
                                                            self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                            self.advertisedto_pe = None
                                                            self.aigp_metric = None
                                                            self.best_path_comp_stage = None
                                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner()
                                                            self.best_path_comp_winner.parent = self
                                                            self.best_path_id = None
                                                            self.best_path_id_comp_winner = None
                                                            self.best_path_orr_bitfield = YList()
                                                            self.best_path_orr_bitfield.parent = self
                                                            self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix()
                                                            self.bgp_prefix.parent = self
                                                            self.dampen_penalty = None
                                                            self.extended_community = YList()
                                                            self.extended_community.parent = self
                                                            self.extended_community.name = 'extended_community'
                                                            self.fspec_invalid_path = None
                                                            self.graceful_shutdown = None
                                                            self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.GwAddr()
                                                            self.gw_addr.parent = self
                                                            self.halflife_time = None
                                                            self.has_esi = None
                                                            self.has_gw_addr = None
                                                            self.has_local_net_label = None
                                                            self.has_mdt_group_addr = None
                                                            self.has_mvpn_extcomm = None
                                                            self.has_mvpn_nbr_addr = None
                                                            self.has_mvpn_nexthop_addr = None
                                                            self.has_mvpn_pmsi = None
                                                            self.has_rcvd_label = None
                                                            self.has_second_label = None
                                                            self.ibgp_signaled_validity = None
                                                            self.igp_metric = None
                                                            self.is_aggregation_suppressed = None
                                                            self.is_as_best = None
                                                            self.is_best_path = None
                                                            self.is_import_dampened = None
                                                            self.is_import_suspect = None
                                                            self.is_internal_path = None
                                                            self.is_partial_best = None
                                                            self.is_path_additional_path = None
                                                            self.is_path_advertised_local_as_only = None
                                                            self.is_path_af_install_eligible = None
                                                            self.is_path_backup = None
                                                            self.is_path_backup_protect_multipath = None
                                                            self.is_path_best_external = None
                                                            self.is_path_damped = None
                                                            self.is_path_from_confederation_peer = None
                                                            self.is_path_from_network_command = None
                                                            self.is_path_from_redistribute_command = None
                                                            self.is_path_from_route_reflector = None
                                                            self.is_path_history_held = None
                                                            self.is_path_imp_candidate = None
                                                            self.is_path_imported = None
                                                            self.is_path_local_aggregate = None
                                                            self.is_path_locally_sourced = None
                                                            self.is_path_long_lived_stale = None
                                                            self.is_path_multipath = None
                                                            self.is_path_nexthop_discarded = None
                                                            self.is_path_not_advertised = None
                                                            self.is_path_not_advertised_to_ebg_ps = None
                                                            self.is_path_received_only = None
                                                            self.is_path_reoriginated = None
                                                            self.is_path_reoriginated_stitching = None
                                                            self.is_path_stale = None
                                                            self.is_path_synced_with_igp = None
                                                            self.is_path_valid = None
                                                            self.is_path_vpn_only = None
                                                            self.is_permanent_path = None
                                                            self.is_received_path_not_modified = None
                                                            self.is_spkr_as_best = None
                                                            self.l2vpn_circuit_status_value = YList()
                                                            self.l2vpn_circuit_status_value.parent = self
                                                            self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                            self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi()
                                                            self.l2vpn_evpn_esi.parent = self
                                                            self.l2vpn_size = None
                                                            self.labeled_unicast_safi_path = None
                                                            self.local_label = None
                                                            self.local_nh = None
                                                            self.local_path_id = None
                                                            self.local_peers_advertised_to = YList()
                                                            self.local_peers_advertised_to.parent = self
                                                            self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                            self.maximum_suppress_time = None
                                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr()
                                                            self.mdt_group_addr.parent = self
                                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                            self.mvpn_nbr_addr.parent = self
                                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                            self.mvpn_nexthop_addr.parent = self
                                                            self.mvpn_path_flags = None
                                                            self.mvpn_pmsi_flags = None
                                                            self.mvpn_pmsi_label = None
                                                            self.mvpn_pmsi_type = None
                                                            self.mvpn_pmsi_value = YList()
                                                            self.mvpn_pmsi_value.parent = self
                                                            self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                            self.mvpn_sfs_path = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.neighbor_router_id = None
                                                            self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop()
                                                            self.next_hop.parent = self
                                                            self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhteTunnel()
                                                            self.nhte_tunnel.parent = self
                                                            self.path_flags = None
                                                            self.path_flap_count = None
                                                            self.path_import_flags = None
                                                            self.path_rt_set_id = None
                                                            self.path_rt_set_route_count = None
                                                            self.path_table_version = None
                                                            self.path_weight = None
                                                            self.pe_peers_advertised_to = YList()
                                                            self.pe_peers_advertised_to.parent = self
                                                            self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                            self.rcvd_label = None
                                                            self.rcvd_path_id = None
                                                            self.reuse_value = None
                                                            self.rib_failed = None
                                                            self.route_type = None
                                                            self.rpki_origin_as_validation_disabled = None
                                                            self.rt_set_limit_enabled = None
                                                            self.second_label = None
                                                            self.seconds_since_first_flap = None
                                                            self.show_rpki_origin_as_validity = None
                                                            self.sn_rpki_origin_as_validity = None
                                                            self.suppress_penalty = None
                                                            self.time_to_unsuppress = None


                                                        class BgpPrefix(object):
                                                            """
                                                            BGP prefix
                                                            
                                                            .. attribute:: prefix
                                                            
                                                            	Prefix
                                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                            
                                                            .. attribute:: prefix_length
                                                            
                                                            	Prefix length
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                                self.prefix.parent = self
                                                                self.prefix_length = None


                                                            class Prefix(object):
                                                                """
                                                                Prefix
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.prefix is not None and self.prefix._has_data():
                                                                    return True

                                                                if self.prefix_length is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix']['meta_info']


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress']['meta_info']


                                                        class NextHop(object):
                                                            """
                                                            Next hop
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop']['meta_info']


                                                        class NhteTunnel(object):
                                                            """
                                                            NH TE tunnel information
                                                            
                                                            .. attribute:: binding_label
                                                            
                                                            	Binding label for the tunnel
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: has_te_tunnel
                                                            
                                                            	NH TE Tunnel info is present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_info_stale
                                                            
                                                            	Tunnel is stale
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_registered
                                                            
                                                            	Tunnel registered flag
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_up
                                                            
                                                            	Tunnel Up flag
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: last_tunnel_update
                                                            
                                                            	Time since the last rib update happened
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_if_handle
                                                            
                                                            	Interface handle for the tunnel
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_name
                                                            
                                                            	tunnel name
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            .. attribute:: tunnel_type
                                                            
                                                            	tunnel type
                                                            	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                            
                                                            .. attribute:: tunnel_v6_enabled
                                                            
                                                            	IPv6 enabled
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_v6_required
                                                            
                                                            	Tunnel need IPv6
                                                            	**type**\:  bool
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.binding_label = None
                                                                self.has_te_tunnel = None
                                                                self.is_tunnel_info_stale = None
                                                                self.is_tunnel_registered = None
                                                                self.is_tunnel_up = None
                                                                self.last_tunnel_update = None
                                                                self.tunnel_if_handle = None
                                                                self.tunnel_name = None
                                                                self.tunnel_type = None
                                                                self.tunnel_v6_enabled = None
                                                                self.tunnel_v6_required = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.binding_label is not None:
                                                                    return True

                                                                if self.has_te_tunnel is not None:
                                                                    return True

                                                                if self.is_tunnel_info_stale is not None:
                                                                    return True

                                                                if self.is_tunnel_registered is not None:
                                                                    return True

                                                                if self.is_tunnel_up is not None:
                                                                    return True

                                                                if self.last_tunnel_update is not None:
                                                                    return True

                                                                if self.tunnel_if_handle is not None:
                                                                    return True

                                                                if self.tunnel_name is not None:
                                                                    return True

                                                                if self.tunnel_type is not None:
                                                                    return True

                                                                if self.tunnel_v6_enabled is not None:
                                                                    return True

                                                                if self.tunnel_v6_required is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhteTunnel']['meta_info']


                                                        class MdtGroupAddr(object):
                                                            """
                                                            IPv4 MDT Group Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr']['meta_info']


                                                        class L2VpnEvpnEsi(object):
                                                            """
                                                            L2VPN EVPN ESI
                                                            
                                                            .. attribute:: esi
                                                            
                                                            	esi
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.esi = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.esi is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi']['meta_info']


                                                        class GwAddr(object):
                                                            """
                                                            Path GW Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self.len = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.len is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.GwAddr']['meta_info']


                                                        class BestPathCompWinner(object):
                                                            """
                                                            Neighbor address of the path which won best path
                                                            comparison
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner']['meta_info']


                                                        class MvpnNbrAddr(object):
                                                            """
                                                            Mvpn nbr Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr']['meta_info']


                                                        class MvpnNexthopAddr(object):
                                                            """
                                                            Mvpn nexthop Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr']['meta_info']


                                                        class L2VpnCircuitStatusValue(object):
                                                            """
                                                            L2VPN Circuit Status Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                                        class MvpnPmsiValue(object):
                                                            """
                                                            Mvpn PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue']['meta_info']


                                                        class ExtendedCommunity(object):
                                                            """
                                                            Mvpn Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity']['meta_info']


                                                        class LocalPeersAdvertisedTo(object):
                                                            """
                                                            Local peers that this prefix has been advertised
                                                            to
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.is_neighbor = None
                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self.update_group_number = None


                                                            class NeighborAddress(object):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.is_neighbor is not None:
                                                                    return True

                                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                    return True

                                                                if self.update_group_number is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                                        class PePeersAdvertisedTo(object):
                                                            """
                                                            PE peers that this prefix has been advertised to
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.is_neighbor = None
                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self.update_group_number = None


                                                            class NeighborAddress(object):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.is_neighbor is not None:
                                                                    return True

                                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                    return True

                                                                if self.update_group_number is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo']['meta_info']


                                                        class BestPathOrrBitfield(object):
                                                            """
                                                            ORR Best path Bitfields
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.is_neighbor = None
                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self.update_group_number = None


                                                            class NeighborAddress(object):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.is_neighbor is not None:
                                                                    return True

                                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                    return True

                                                                if self.update_group_number is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield']['meta_info']


                                                        class AddPathOrrBitfield(object):
                                                            """
                                                            ORR Add path Bitfields
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.is_neighbor = None
                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self.update_group_number = None


                                                            class NeighborAddress(object):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.is_neighbor is not None:
                                                                    return True

                                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                    return True

                                                                if self.update_group_number is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.accept_own_path is not None:
                                                                return True

                                                            if self.accept_own_self_originated_p_ath is not None:
                                                                return True

                                                            if self.add_path_orr_bitfield is not None:
                                                                for child_ref in self.add_path_orr_bitfield:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.advertisedto_pe is not None:
                                                                return True

                                                            if self.aigp_metric is not None:
                                                                return True

                                                            if self.best_path_comp_stage is not None:
                                                                return True

                                                            if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                                return True

                                                            if self.best_path_id is not None:
                                                                return True

                                                            if self.best_path_id_comp_winner is not None:
                                                                return True

                                                            if self.best_path_orr_bitfield is not None:
                                                                for child_ref in self.best_path_orr_bitfield:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                                return True

                                                            if self.dampen_penalty is not None:
                                                                return True

                                                            if self.extended_community is not None:
                                                                for child_ref in self.extended_community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.fspec_invalid_path is not None:
                                                                return True

                                                            if self.graceful_shutdown is not None:
                                                                return True

                                                            if self.gw_addr is not None and self.gw_addr._has_data():
                                                                return True

                                                            if self.halflife_time is not None:
                                                                return True

                                                            if self.has_esi is not None:
                                                                return True

                                                            if self.has_gw_addr is not None:
                                                                return True

                                                            if self.has_local_net_label is not None:
                                                                return True

                                                            if self.has_mdt_group_addr is not None:
                                                                return True

                                                            if self.has_mvpn_extcomm is not None:
                                                                return True

                                                            if self.has_mvpn_nbr_addr is not None:
                                                                return True

                                                            if self.has_mvpn_nexthop_addr is not None:
                                                                return True

                                                            if self.has_mvpn_pmsi is not None:
                                                                return True

                                                            if self.has_rcvd_label is not None:
                                                                return True

                                                            if self.has_second_label is not None:
                                                                return True

                                                            if self.ibgp_signaled_validity is not None:
                                                                return True

                                                            if self.igp_metric is not None:
                                                                return True

                                                            if self.is_aggregation_suppressed is not None:
                                                                return True

                                                            if self.is_as_best is not None:
                                                                return True

                                                            if self.is_best_path is not None:
                                                                return True

                                                            if self.is_import_dampened is not None:
                                                                return True

                                                            if self.is_import_suspect is not None:
                                                                return True

                                                            if self.is_internal_path is not None:
                                                                return True

                                                            if self.is_partial_best is not None:
                                                                return True

                                                            if self.is_path_additional_path is not None:
                                                                return True

                                                            if self.is_path_advertised_local_as_only is not None:
                                                                return True

                                                            if self.is_path_af_install_eligible is not None:
                                                                return True

                                                            if self.is_path_backup is not None:
                                                                return True

                                                            if self.is_path_backup_protect_multipath is not None:
                                                                return True

                                                            if self.is_path_best_external is not None:
                                                                return True

                                                            if self.is_path_damped is not None:
                                                                return True

                                                            if self.is_path_from_confederation_peer is not None:
                                                                return True

                                                            if self.is_path_from_network_command is not None:
                                                                return True

                                                            if self.is_path_from_redistribute_command is not None:
                                                                return True

                                                            if self.is_path_from_route_reflector is not None:
                                                                return True

                                                            if self.is_path_history_held is not None:
                                                                return True

                                                            if self.is_path_imp_candidate is not None:
                                                                return True

                                                            if self.is_path_imported is not None:
                                                                return True

                                                            if self.is_path_local_aggregate is not None:
                                                                return True

                                                            if self.is_path_locally_sourced is not None:
                                                                return True

                                                            if self.is_path_long_lived_stale is not None:
                                                                return True

                                                            if self.is_path_multipath is not None:
                                                                return True

                                                            if self.is_path_nexthop_discarded is not None:
                                                                return True

                                                            if self.is_path_not_advertised is not None:
                                                                return True

                                                            if self.is_path_not_advertised_to_ebg_ps is not None:
                                                                return True

                                                            if self.is_path_received_only is not None:
                                                                return True

                                                            if self.is_path_reoriginated is not None:
                                                                return True

                                                            if self.is_path_reoriginated_stitching is not None:
                                                                return True

                                                            if self.is_path_stale is not None:
                                                                return True

                                                            if self.is_path_synced_with_igp is not None:
                                                                return True

                                                            if self.is_path_valid is not None:
                                                                return True

                                                            if self.is_path_vpn_only is not None:
                                                                return True

                                                            if self.is_permanent_path is not None:
                                                                return True

                                                            if self.is_received_path_not_modified is not None:
                                                                return True

                                                            if self.is_spkr_as_best is not None:
                                                                return True

                                                            if self.l2vpn_circuit_status_value is not None:
                                                                for child_ref in self.l2vpn_circuit_status_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                                return True

                                                            if self.l2vpn_size is not None:
                                                                return True

                                                            if self.labeled_unicast_safi_path is not None:
                                                                return True

                                                            if self.local_label is not None:
                                                                return True

                                                            if self.local_nh is not None:
                                                                return True

                                                            if self.local_path_id is not None:
                                                                return True

                                                            if self.local_peers_advertised_to is not None:
                                                                for child_ref in self.local_peers_advertised_to:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.maximum_suppress_time is not None:
                                                                return True

                                                            if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                                return True

                                                            if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                                return True

                                                            if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                                return True

                                                            if self.mvpn_path_flags is not None:
                                                                return True

                                                            if self.mvpn_pmsi_flags is not None:
                                                                return True

                                                            if self.mvpn_pmsi_label is not None:
                                                                return True

                                                            if self.mvpn_pmsi_type is not None:
                                                                return True

                                                            if self.mvpn_pmsi_value is not None:
                                                                for child_ref in self.mvpn_pmsi_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.mvpn_sfs_path is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.neighbor_router_id is not None:
                                                                return True

                                                            if self.next_hop is not None and self.next_hop._has_data():
                                                                return True

                                                            if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                                return True

                                                            if self.path_flags is not None:
                                                                return True

                                                            if self.path_flap_count is not None:
                                                                return True

                                                            if self.path_import_flags is not None:
                                                                return True

                                                            if self.path_rt_set_id is not None:
                                                                return True

                                                            if self.path_rt_set_route_count is not None:
                                                                return True

                                                            if self.path_table_version is not None:
                                                                return True

                                                            if self.path_weight is not None:
                                                                return True

                                                            if self.pe_peers_advertised_to is not None:
                                                                for child_ref in self.pe_peers_advertised_to:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.rcvd_label is not None:
                                                                return True

                                                            if self.rcvd_path_id is not None:
                                                                return True

                                                            if self.reuse_value is not None:
                                                                return True

                                                            if self.rib_failed is not None:
                                                                return True

                                                            if self.route_type is not None:
                                                                return True

                                                            if self.rpki_origin_as_validation_disabled is not None:
                                                                return True

                                                            if self.rt_set_limit_enabled is not None:
                                                                return True

                                                            if self.second_label is not None:
                                                                return True

                                                            if self.seconds_since_first_flap is not None:
                                                                return True

                                                            if self.show_rpki_origin_as_validity is not None:
                                                                return True

                                                            if self.sn_rpki_origin_as_validity is not None:
                                                                return True

                                                            if self.suppress_penalty is not None:
                                                                return True

                                                            if self.time_to_unsuppress is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation']['meta_info']


                                                    class AttributesAfterPolicyIn(object):
                                                        """
                                                        Attributes after inbound policy applied
                                                        
                                                        .. attribute:: attr_set
                                                        
                                                        	ATTR\_SET attribute
                                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                        
                                                        .. attribute:: attribute_key_number
                                                        
                                                        	Attribute key number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_config
                                                        
                                                        	Attribute reuse ID Configured
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: attribute_reuse_id_current
                                                        
                                                        	Attribute reuse ID current ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_keys
                                                        
                                                        	Attribute reuse ID allocated keys
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_max_id
                                                        
                                                        	Attribute reuse ID maximum ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_node
                                                        
                                                        	Attribute reuse ID nodes
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_recover_sec
                                                        
                                                        	Attribute reuse ID timer in seconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: common_attributes
                                                        
                                                        	Common attributes
                                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                        
                                                        .. attribute:: is_application_gateway_present
                                                        
                                                        	Application gateway present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path2_byte
                                                        
                                                        	AS path encoded as 2\-byte
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_attr_set_present
                                                        
                                                        	BGP ATTR\_SET attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ribrnh_present
                                                        
                                                        	RIB RNH Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_rnh_present
                                                        
                                                        	RNH Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: ribrnh_encap
                                                        
                                                        	RIB RNH Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ribrnh_ip
                                                        
                                                        	RIB RNH IP Address
                                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                        
                                                        .. attribute:: ribrnh_mac
                                                        
                                                        	RIB RNH MAC Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                        
                                                        .. attribute:: ribrnh_table
                                                        
                                                        	RIB RNH Table
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ribrnh_vni
                                                        
                                                        	RIB RNH Vni
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ribrnhip_table
                                                        
                                                        	RIB RNH IP Table
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rnh_addr
                                                        
                                                        	RNH Address
                                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                        
                                                        .. attribute:: rnh_addr_len
                                                        
                                                        	RNH Address Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rnh_len
                                                        
                                                        	RNH Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: rnh_type
                                                        
                                                        	RNH Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: set_aigp_inbound_igp
                                                        
                                                        	AIGP set by policy inbound IGP 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: set_aigp_inbound_metric
                                                        
                                                        	AIGP set by policy inbound metric
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: vpn_distinguisher
                                                        
                                                        	VPN Distinguisher
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                            self.attr_set.parent = self
                                                            self.attribute_key_number = None
                                                            self.attribute_reuse_id_config = None
                                                            self.attribute_reuse_id_current = None
                                                            self.attribute_reuse_id_keys = None
                                                            self.attribute_reuse_id_max_id = None
                                                            self.attribute_reuse_id_node = None
                                                            self.attribute_reuse_id_recover_sec = None
                                                            self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                            self.common_attributes.parent = self
                                                            self.is_application_gateway_present = None
                                                            self.is_as_path2_byte = None
                                                            self.is_attr_set_present = None
                                                            self.is_ribrnh_present = None
                                                            self.is_rnh_present = None
                                                            self.ribrnh_encap = None
                                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                            self.ribrnh_ip.parent = self
                                                            self.ribrnh_mac = None
                                                            self.ribrnh_table = None
                                                            self.ribrnh_vni = None
                                                            self.ribrnhip_table = None
                                                            self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                            self.rnh_addr.parent = self
                                                            self.rnh_addr_len = None
                                                            self.rnh_len = None
                                                            self.rnh_type = None
                                                            self.set_aigp_inbound_igp = None
                                                            self.set_aigp_inbound_metric = None
                                                            self.vpn_distinguisher = None


                                                        class CommonAttributes(object):
                                                            """
                                                            Common attributes
                                                            
                                                            .. attribute:: aggregator_address
                                                            
                                                            	Address where aggregation was performed
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: aggregator_as
                                                            
                                                            	AS where aggregation was last performed
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: aigp_metric_value
                                                            
                                                            	AIGP metric value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..18446744073709551615
                                                            
                                                            .. attribute:: as_path
                                                            
                                                            	AS path attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: cluster
                                                            
                                                            	Cluster list attribute
                                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                            
                                                            .. attribute:: community
                                                            
                                                            	Community attribute
                                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                            
                                                            .. attribute:: connector_type
                                                            
                                                            	Connector Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: connector_value
                                                            
                                                            	Connector Value
                                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                            
                                                            .. attribute:: extended_community
                                                            
                                                            	Extended community attribute
                                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                            
                                                            .. attribute:: extended_community_flags
                                                            
                                                            	Extended community Flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: is_aggregator_present
                                                            
                                                            	Aggregator attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_aigp_present
                                                            
                                                            	AIGP Present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_as_path_present
                                                            
                                                            	AS path attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_atomic_aggregate_present
                                                            
                                                            	Atomic aggregate attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_community_present
                                                            
                                                            	Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_connector_present
                                                            
                                                            	Connector present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_extended_community_present
                                                            
                                                            	Extended community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_label_index_present
                                                            
                                                            	Label Index attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_local_pref_present
                                                            
                                                            	Local Preference attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ls_attribute_present
                                                            
                                                            	BGP LS attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_metric_present
                                                            
                                                            	Metric attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_origin_present
                                                            
                                                            	Origin attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pe_distinguisher_label_present
                                                            
                                                            	PE distinguisher label  attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pmsi_present
                                                            
                                                            	PMSI Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pppmp_present
                                                            
                                                            	PPMP Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ssa_present
                                                            
                                                            	SSA attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_encap_present
                                                            
                                                            	Tunnel Encap attribute present 
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: l2tpv3_cookie
                                                            
                                                            	L2TPv3 Cookie
                                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                            
                                                            .. attribute:: l2tpv3_session_id
                                                            
                                                            	L2TPv3 session id
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: label_index_attr
                                                            
                                                            	Label Index attribute
                                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                            
                                                            .. attribute:: local_preference
                                                            
                                                            	Local preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ls_attr
                                                            
                                                            	BGP LS attribute
                                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	Metric
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: neighbor_as
                                                            
                                                            	Neighbor AS number
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: origin
                                                            
                                                            	Origin
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: originator
                                                            
                                                            	Originator attribute
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: pe_distinguisher_label
                                                            
                                                            	PE distinguisher label attribute
                                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                            
                                                            .. attribute:: pmsi_flags
                                                            
                                                            	PMSI Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pmsi_label
                                                            
                                                            	PMSI label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pmsi_type
                                                            
                                                            	PMSI Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: pmsi_value
                                                            
                                                            	PMSI Value
                                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                            
                                                            .. attribute:: ppm_pvalue
                                                            
                                                            	PPMP Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: sr_policy_allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                            
                                                            .. attribute:: sr_policy_binding_sid
                                                            
                                                            	SR Policy Binding sid
                                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                            
                                                            .. attribute:: sr_policy_explicit_path
                                                            
                                                            	SR Policy Explicit paths
                                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                            
                                                            .. attribute:: sr_policy_preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: sr_tunnel_request_state
                                                            
                                                            	SR Tunnel Request State
                                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                            
                                                            .. attribute:: sr_tunnel_state
                                                            
                                                            	SR Tunnel State
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encap Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: unknown_attribute
                                                            
                                                            	Unknown attributes
                                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.aggregator_address = None
                                                                self.aggregator_as = None
                                                                self.aigp_metric_value = None
                                                                self.as_path = None
                                                                self.cluster = YList()
                                                                self.cluster.parent = self
                                                                self.cluster.name = 'cluster'
                                                                self.community = YList()
                                                                self.community.parent = self
                                                                self.community.name = 'community'
                                                                self.connector_type = None
                                                                self.connector_value = YList()
                                                                self.connector_value.parent = self
                                                                self.connector_value.name = 'connector_value'
                                                                self.extended_community = YList()
                                                                self.extended_community.parent = self
                                                                self.extended_community.name = 'extended_community'
                                                                self.extended_community_flags = None
                                                                self.is_aggregator_present = None
                                                                self.is_aigp_present = None
                                                                self.is_as_path_present = None
                                                                self.is_atomic_aggregate_present = None
                                                                self.is_community_present = None
                                                                self.is_connector_present = None
                                                                self.is_extended_community_present = None
                                                                self.is_label_index_present = None
                                                                self.is_local_pref_present = None
                                                                self.is_ls_attribute_present = None
                                                                self.is_metric_present = None
                                                                self.is_origin_present = None
                                                                self.is_pe_distinguisher_label_present = None
                                                                self.is_pmsi_present = None
                                                                self.is_pppmp_present = None
                                                                self.is_ssa_present = None
                                                                self.is_tunnel_encap_present = None
                                                                self.l2tpv3_cookie = YList()
                                                                self.l2tpv3_cookie.parent = self
                                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                                self.l2tpv3_session_id = None
                                                                self.label_index_attr = YList()
                                                                self.label_index_attr.parent = self
                                                                self.label_index_attr.name = 'label_index_attr'
                                                                self.local_preference = None
                                                                self.ls_attr = YList()
                                                                self.ls_attr.parent = self
                                                                self.ls_attr.name = 'ls_attr'
                                                                self.metric = None
                                                                self.neighbor_as = None
                                                                self.origin = None
                                                                self.originator = None
                                                                self.pe_distinguisher_label = YList()
                                                                self.pe_distinguisher_label.parent = self
                                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                                self.pmsi_flags = None
                                                                self.pmsi_label = None
                                                                self.pmsi_type = None
                                                                self.pmsi_value = YList()
                                                                self.pmsi_value.parent = self
                                                                self.pmsi_value.name = 'pmsi_value'
                                                                self.ppm_pvalue = None
                                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                                self.sr_policy_allocated_binding_sid.parent = self
                                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                                self.sr_policy_binding_sid.parent = self
                                                                self.sr_policy_explicit_path = YList()
                                                                self.sr_policy_explicit_path.parent = self
                                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                                self.sr_policy_preference = None
                                                                self.sr_tunnel_request_state = None
                                                                self.sr_tunnel_state = None
                                                                self.tunnel_encap_type = None
                                                                self.unknown_attribute = YList()
                                                                self.unknown_attribute.parent = self
                                                                self.unknown_attribute.name = 'unknown_attribute'


                                                            class SrPolicyBindingSid(object):
                                                                """
                                                                SR Policy Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_address = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                            class SrPolicyAllocatedBindingSid(object):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_address = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                            class Community(object):
                                                                """
                                                                Community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                            class ExtendedCommunity(object):
                                                                """
                                                                Extended community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                            class UnknownAttribute(object):
                                                                """
                                                                Unknown attributes
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                            class Cluster(object):
                                                                """
                                                                Cluster list attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                            class L2Tpv3Cookie(object):
                                                                """
                                                                L2TPv3 Cookie
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                            class ConnectorValue(object):
                                                                """
                                                                Connector Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                            class PmsiValue(object):
                                                                """
                                                                PMSI Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                            class LsAttr(object):
                                                                """
                                                                BGP LS attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                            class LabelIndexAttr(object):
                                                                """
                                                                Label Index attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                            class PeDistinguisherLabel(object):
                                                                """
                                                                PE distinguisher label attribute
                                                                
                                                                .. attribute:: label
                                                                
                                                                	Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pe_address
                                                                
                                                                	 PE address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.label = None
                                                                    self.pe_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.pe_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                            class SrPolicyExplicitPath(object):
                                                                """
                                                                SR Policy Explicit paths
                                                                
                                                                .. attribute:: sid
                                                                
                                                                	Sidlist for explicit path
                                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of explicit path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.sid = YList()
                                                                    self.sid.parent = self
                                                                    self.sid.name = 'sid'
                                                                    self.weight = None


                                                                class Sid(object):
                                                                    """
                                                                    Sidlist for explicit path
                                                                    
                                                                    .. attribute:: ipv4
                                                                    
                                                                    	IP Address sid
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6
                                                                    
                                                                    	IPv6 address sid
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label sid
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Sid Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4 = None
                                                                        self.ipv6 = None
                                                                        self.label = None
                                                                        self.type = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4 is not None:
                                                                            return True

                                                                        if self.ipv6 is not None:
                                                                            return True

                                                                        if self.label is not None:
                                                                            return True

                                                                        if self.type is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.sid is not None:
                                                                        for child_ref in self.sid:
                                                                            if child_ref._has_data():
                                                                                return True

                                                                    if self.weight is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.aggregator_address is not None:
                                                                    return True

                                                                if self.aggregator_as is not None:
                                                                    return True

                                                                if self.aigp_metric_value is not None:
                                                                    return True

                                                                if self.as_path is not None:
                                                                    return True

                                                                if self.cluster is not None:
                                                                    for child_ref in self.cluster:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.community is not None:
                                                                    for child_ref in self.community:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.connector_type is not None:
                                                                    return True

                                                                if self.connector_value is not None:
                                                                    for child_ref in self.connector_value:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.extended_community is not None:
                                                                    for child_ref in self.extended_community:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.extended_community_flags is not None:
                                                                    return True

                                                                if self.is_aggregator_present is not None:
                                                                    return True

                                                                if self.is_aigp_present is not None:
                                                                    return True

                                                                if self.is_as_path_present is not None:
                                                                    return True

                                                                if self.is_atomic_aggregate_present is not None:
                                                                    return True

                                                                if self.is_community_present is not None:
                                                                    return True

                                                                if self.is_connector_present is not None:
                                                                    return True

                                                                if self.is_extended_community_present is not None:
                                                                    return True

                                                                if self.is_label_index_present is not None:
                                                                    return True

                                                                if self.is_local_pref_present is not None:
                                                                    return True

                                                                if self.is_ls_attribute_present is not None:
                                                                    return True

                                                                if self.is_metric_present is not None:
                                                                    return True

                                                                if self.is_origin_present is not None:
                                                                    return True

                                                                if self.is_pe_distinguisher_label_present is not None:
                                                                    return True

                                                                if self.is_pmsi_present is not None:
                                                                    return True

                                                                if self.is_pppmp_present is not None:
                                                                    return True

                                                                if self.is_ssa_present is not None:
                                                                    return True

                                                                if self.is_tunnel_encap_present is not None:
                                                                    return True

                                                                if self.l2tpv3_cookie is not None:
                                                                    for child_ref in self.l2tpv3_cookie:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.l2tpv3_session_id is not None:
                                                                    return True

                                                                if self.label_index_attr is not None:
                                                                    for child_ref in self.label_index_attr:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.local_preference is not None:
                                                                    return True

                                                                if self.ls_attr is not None:
                                                                    for child_ref in self.ls_attr:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.metric is not None:
                                                                    return True

                                                                if self.neighbor_as is not None:
                                                                    return True

                                                                if self.origin is not None:
                                                                    return True

                                                                if self.originator is not None:
                                                                    return True

                                                                if self.pe_distinguisher_label is not None:
                                                                    for child_ref in self.pe_distinguisher_label:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.pmsi_flags is not None:
                                                                    return True

                                                                if self.pmsi_label is not None:
                                                                    return True

                                                                if self.pmsi_type is not None:
                                                                    return True

                                                                if self.pmsi_value is not None:
                                                                    for child_ref in self.pmsi_value:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.ppm_pvalue is not None:
                                                                    return True

                                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                                    return True

                                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                                    return True

                                                                if self.sr_policy_explicit_path is not None:
                                                                    for child_ref in self.sr_policy_explicit_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.sr_policy_preference is not None:
                                                                    return True

                                                                if self.sr_tunnel_request_state is not None:
                                                                    return True

                                                                if self.sr_tunnel_state is not None:
                                                                    return True

                                                                if self.tunnel_encap_type is not None:
                                                                    return True

                                                                if self.unknown_attribute is not None:
                                                                    for child_ref in self.unknown_attribute:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                                        class AttrSet(object):
                                                            """
                                                            ATTR\_SET attribute
                                                            
                                                            .. attribute:: aggregator_address
                                                            
                                                            	Address where aggregation was performed
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: aggregator_as
                                                            
                                                            	AS where aggregation was last performed
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: aigp_metric_value
                                                            
                                                            	AIGP metric value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..18446744073709551615
                                                            
                                                            .. attribute:: as_path
                                                            
                                                            	AS path attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: cluster
                                                            
                                                            	Cluster list attribute
                                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                            
                                                            .. attribute:: community
                                                            
                                                            	Community attribute
                                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                            
                                                            .. attribute:: connector_type
                                                            
                                                            	Connector Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: connector_value
                                                            
                                                            	Connector Value
                                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                            
                                                            .. attribute:: extended_community
                                                            
                                                            	Extended community attribute
                                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                            
                                                            .. attribute:: extended_community_flags
                                                            
                                                            	Extended community Flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: is_aggregator_present
                                                            
                                                            	Aggregator attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_aigp_present
                                                            
                                                            	AIGP Present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_as_path_present
                                                            
                                                            	AS path attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_atomic_aggregate_present
                                                            
                                                            	Atomic aggregate attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_community_present
                                                            
                                                            	Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_connector_present
                                                            
                                                            	Connector present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_extended_community_present
                                                            
                                                            	Extended community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_label_index_present
                                                            
                                                            	Label Index attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_local_pref_present
                                                            
                                                            	Local Preference attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ls_attribute_present
                                                            
                                                            	BGP LS attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_metric_present
                                                            
                                                            	Metric attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_origin_present
                                                            
                                                            	Origin attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pe_distinguisher_label_present
                                                            
                                                            	PE distinguisher label  attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pmsi_present
                                                            
                                                            	PMSI Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pppmp_present
                                                            
                                                            	PPMP Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ssa_present
                                                            
                                                            	SSA attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_encap_present
                                                            
                                                            	Tunnel Encap attribute present 
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: l2tpv3_cookie
                                                            
                                                            	L2TPv3 Cookie
                                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                            
                                                            .. attribute:: l2tpv3_session_id
                                                            
                                                            	L2TPv3 session id
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: label_index_attr
                                                            
                                                            	Label Index attribute
                                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                            
                                                            .. attribute:: local_preference
                                                            
                                                            	Local preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ls_attr
                                                            
                                                            	BGP LS attribute
                                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	Metric
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: neighbor_as
                                                            
                                                            	Neighbor AS number
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: origin
                                                            
                                                            	Origin
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: originator
                                                            
                                                            	Originator attribute
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: pe_distinguisher_label
                                                            
                                                            	PE distinguisher label attribute
                                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                            
                                                            .. attribute:: pmsi_flags
                                                            
                                                            	PMSI Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pmsi_label
                                                            
                                                            	PMSI label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pmsi_type
                                                            
                                                            	PMSI Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: pmsi_value
                                                            
                                                            	PMSI Value
                                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                            
                                                            .. attribute:: ppm_pvalue
                                                            
                                                            	PPMP Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: sr_policy_allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                            
                                                            .. attribute:: sr_policy_binding_sid
                                                            
                                                            	SR Policy Binding sid
                                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                            
                                                            .. attribute:: sr_policy_explicit_path
                                                            
                                                            	SR Policy Explicit paths
                                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                            
                                                            .. attribute:: sr_policy_preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: sr_tunnel_request_state
                                                            
                                                            	SR Tunnel Request State
                                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                            
                                                            .. attribute:: sr_tunnel_state
                                                            
                                                            	SR Tunnel State
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encap Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: unknown_attribute
                                                            
                                                            	Unknown attributes
                                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.aggregator_address = None
                                                                self.aggregator_as = None
                                                                self.aigp_metric_value = None
                                                                self.as_path = None
                                                                self.cluster = YList()
                                                                self.cluster.parent = self
                                                                self.cluster.name = 'cluster'
                                                                self.community = YList()
                                                                self.community.parent = self
                                                                self.community.name = 'community'
                                                                self.connector_type = None
                                                                self.connector_value = YList()
                                                                self.connector_value.parent = self
                                                                self.connector_value.name = 'connector_value'
                                                                self.extended_community = YList()
                                                                self.extended_community.parent = self
                                                                self.extended_community.name = 'extended_community'
                                                                self.extended_community_flags = None
                                                                self.is_aggregator_present = None
                                                                self.is_aigp_present = None
                                                                self.is_as_path_present = None
                                                                self.is_atomic_aggregate_present = None
                                                                self.is_community_present = None
                                                                self.is_connector_present = None
                                                                self.is_extended_community_present = None
                                                                self.is_label_index_present = None
                                                                self.is_local_pref_present = None
                                                                self.is_ls_attribute_present = None
                                                                self.is_metric_present = None
                                                                self.is_origin_present = None
                                                                self.is_pe_distinguisher_label_present = None
                                                                self.is_pmsi_present = None
                                                                self.is_pppmp_present = None
                                                                self.is_ssa_present = None
                                                                self.is_tunnel_encap_present = None
                                                                self.l2tpv3_cookie = YList()
                                                                self.l2tpv3_cookie.parent = self
                                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                                self.l2tpv3_session_id = None
                                                                self.label_index_attr = YList()
                                                                self.label_index_attr.parent = self
                                                                self.label_index_attr.name = 'label_index_attr'
                                                                self.local_preference = None
                                                                self.ls_attr = YList()
                                                                self.ls_attr.parent = self
                                                                self.ls_attr.name = 'ls_attr'
                                                                self.metric = None
                                                                self.neighbor_as = None
                                                                self.origin = None
                                                                self.originator = None
                                                                self.pe_distinguisher_label = YList()
                                                                self.pe_distinguisher_label.parent = self
                                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                                self.pmsi_flags = None
                                                                self.pmsi_label = None
                                                                self.pmsi_type = None
                                                                self.pmsi_value = YList()
                                                                self.pmsi_value.parent = self
                                                                self.pmsi_value.name = 'pmsi_value'
                                                                self.ppm_pvalue = None
                                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                                self.sr_policy_allocated_binding_sid.parent = self
                                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                                self.sr_policy_binding_sid.parent = self
                                                                self.sr_policy_explicit_path = YList()
                                                                self.sr_policy_explicit_path.parent = self
                                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                                self.sr_policy_preference = None
                                                                self.sr_tunnel_request_state = None
                                                                self.sr_tunnel_state = None
                                                                self.tunnel_encap_type = None
                                                                self.unknown_attribute = YList()
                                                                self.unknown_attribute.parent = self
                                                                self.unknown_attribute.name = 'unknown_attribute'


                                                            class SrPolicyBindingSid(object):
                                                                """
                                                                SR Policy Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_address = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                            class SrPolicyAllocatedBindingSid(object):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_address = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                            class Community(object):
                                                                """
                                                                Community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                            class ExtendedCommunity(object):
                                                                """
                                                                Extended community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                            class UnknownAttribute(object):
                                                                """
                                                                Unknown attributes
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                            class Cluster(object):
                                                                """
                                                                Cluster list attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                            class L2Tpv3Cookie(object):
                                                                """
                                                                L2TPv3 Cookie
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                            class ConnectorValue(object):
                                                                """
                                                                Connector Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                            class PmsiValue(object):
                                                                """
                                                                PMSI Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                            class LsAttr(object):
                                                                """
                                                                BGP LS attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                            class LabelIndexAttr(object):
                                                                """
                                                                Label Index attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                            class PeDistinguisherLabel(object):
                                                                """
                                                                PE distinguisher label attribute
                                                                
                                                                .. attribute:: label
                                                                
                                                                	Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pe_address
                                                                
                                                                	 PE address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.label = None
                                                                    self.pe_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.pe_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                            class SrPolicyExplicitPath(object):
                                                                """
                                                                SR Policy Explicit paths
                                                                
                                                                .. attribute:: sid
                                                                
                                                                	Sidlist for explicit path
                                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of explicit path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.sid = YList()
                                                                    self.sid.parent = self
                                                                    self.sid.name = 'sid'
                                                                    self.weight = None


                                                                class Sid(object):
                                                                    """
                                                                    Sidlist for explicit path
                                                                    
                                                                    .. attribute:: ipv4
                                                                    
                                                                    	IP Address sid
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6
                                                                    
                                                                    	IPv6 address sid
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label sid
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Sid Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4 = None
                                                                        self.ipv6 = None
                                                                        self.label = None
                                                                        self.type = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4 is not None:
                                                                            return True

                                                                        if self.ipv6 is not None:
                                                                            return True

                                                                        if self.label is not None:
                                                                            return True

                                                                        if self.type is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.sid is not None:
                                                                        for child_ref in self.sid:
                                                                            if child_ref._has_data():
                                                                                return True

                                                                    if self.weight is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.aggregator_address is not None:
                                                                    return True

                                                                if self.aggregator_as is not None:
                                                                    return True

                                                                if self.aigp_metric_value is not None:
                                                                    return True

                                                                if self.as_path is not None:
                                                                    return True

                                                                if self.cluster is not None:
                                                                    for child_ref in self.cluster:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.community is not None:
                                                                    for child_ref in self.community:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.connector_type is not None:
                                                                    return True

                                                                if self.connector_value is not None:
                                                                    for child_ref in self.connector_value:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.extended_community is not None:
                                                                    for child_ref in self.extended_community:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.extended_community_flags is not None:
                                                                    return True

                                                                if self.is_aggregator_present is not None:
                                                                    return True

                                                                if self.is_aigp_present is not None:
                                                                    return True

                                                                if self.is_as_path_present is not None:
                                                                    return True

                                                                if self.is_atomic_aggregate_present is not None:
                                                                    return True

                                                                if self.is_community_present is not None:
                                                                    return True

                                                                if self.is_connector_present is not None:
                                                                    return True

                                                                if self.is_extended_community_present is not None:
                                                                    return True

                                                                if self.is_label_index_present is not None:
                                                                    return True

                                                                if self.is_local_pref_present is not None:
                                                                    return True

                                                                if self.is_ls_attribute_present is not None:
                                                                    return True

                                                                if self.is_metric_present is not None:
                                                                    return True

                                                                if self.is_origin_present is not None:
                                                                    return True

                                                                if self.is_pe_distinguisher_label_present is not None:
                                                                    return True

                                                                if self.is_pmsi_present is not None:
                                                                    return True

                                                                if self.is_pppmp_present is not None:
                                                                    return True

                                                                if self.is_ssa_present is not None:
                                                                    return True

                                                                if self.is_tunnel_encap_present is not None:
                                                                    return True

                                                                if self.l2tpv3_cookie is not None:
                                                                    for child_ref in self.l2tpv3_cookie:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.l2tpv3_session_id is not None:
                                                                    return True

                                                                if self.label_index_attr is not None:
                                                                    for child_ref in self.label_index_attr:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.local_preference is not None:
                                                                    return True

                                                                if self.ls_attr is not None:
                                                                    for child_ref in self.ls_attr:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.metric is not None:
                                                                    return True

                                                                if self.neighbor_as is not None:
                                                                    return True

                                                                if self.origin is not None:
                                                                    return True

                                                                if self.originator is not None:
                                                                    return True

                                                                if self.pe_distinguisher_label is not None:
                                                                    for child_ref in self.pe_distinguisher_label:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.pmsi_flags is not None:
                                                                    return True

                                                                if self.pmsi_label is not None:
                                                                    return True

                                                                if self.pmsi_type is not None:
                                                                    return True

                                                                if self.pmsi_value is not None:
                                                                    for child_ref in self.pmsi_value:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.ppm_pvalue is not None:
                                                                    return True

                                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                                    return True

                                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                                    return True

                                                                if self.sr_policy_explicit_path is not None:
                                                                    for child_ref in self.sr_policy_explicit_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.sr_policy_preference is not None:
                                                                    return True

                                                                if self.sr_tunnel_request_state is not None:
                                                                    return True

                                                                if self.sr_tunnel_state is not None:
                                                                    return True

                                                                if self.tunnel_encap_type is not None:
                                                                    return True

                                                                if self.unknown_attribute is not None:
                                                                    for child_ref in self.unknown_attribute:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                                        class RnhAddr(object):
                                                            """
                                                            RNH Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                            
                                                            .. attribute:: mac_address
                                                            
                                                            	MAC Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self.len = None
                                                                self.mac_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.len is not None:
                                                                    return True

                                                                if self.mac_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                                        class RibrnhIp(object):
                                                            """
                                                            RIB RNH IP Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.attr_set is not None and self.attr_set._has_data():
                                                                return True

                                                            if self.attribute_key_number is not None:
                                                                return True

                                                            if self.attribute_reuse_id_config is not None:
                                                                return True

                                                            if self.attribute_reuse_id_current is not None:
                                                                return True

                                                            if self.attribute_reuse_id_keys is not None:
                                                                return True

                                                            if self.attribute_reuse_id_max_id is not None:
                                                                return True

                                                            if self.attribute_reuse_id_node is not None:
                                                                return True

                                                            if self.attribute_reuse_id_recover_sec is not None:
                                                                return True

                                                            if self.common_attributes is not None and self.common_attributes._has_data():
                                                                return True

                                                            if self.is_application_gateway_present is not None:
                                                                return True

                                                            if self.is_as_path2_byte is not None:
                                                                return True

                                                            if self.is_attr_set_present is not None:
                                                                return True

                                                            if self.is_ribrnh_present is not None:
                                                                return True

                                                            if self.is_rnh_present is not None:
                                                                return True

                                                            if self.ribrnh_encap is not None:
                                                                return True

                                                            if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                                return True

                                                            if self.ribrnh_mac is not None:
                                                                return True

                                                            if self.ribrnh_table is not None:
                                                                return True

                                                            if self.ribrnh_vni is not None:
                                                                return True

                                                            if self.ribrnhip_table is not None:
                                                                return True

                                                            if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                                return True

                                                            if self.rnh_addr_len is not None:
                                                                return True

                                                            if self.rnh_len is not None:
                                                                return True

                                                            if self.rnh_type is not None:
                                                                return True

                                                            if self.set_aigp_inbound_igp is not None:
                                                                return True

                                                            if self.set_aigp_inbound_metric is not None:
                                                                return True

                                                            if self.vpn_distinguisher is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-process-instance-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.af_name is not None:
                                                            return True

                                                        if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                            return True

                                                        if self.label_fail is not None:
                                                            return True

                                                        if self.label_o_or_version is not None:
                                                            return True

                                                        if self.label_oor is not None:
                                                            return True

                                                        if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                            return True

                                                        if self.no_path is not None:
                                                            return True

                                                        if self.path_information is not None and self.path_information._has_data():
                                                            return True

                                                        if self.prefix_version is not None:
                                                            return True

                                                        if self.process_instance_id is not None:
                                                            return True

                                                        if self.route_distinguisher is not None:
                                                            return True

                                                        if self.source_route_distinguisher is not None:
                                                            return True

                                                        if self.source_vrf_name is not None:
                                                            return True

                                                        if self.srcaf_name is not None:
                                                            return True

                                                        if self.vrf_name is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath']['meta_info']


                                                class ActiveProcessInstancePath(object):
                                                    """
                                                    Active's paths for this net 
                                                    
                                                    .. attribute:: af_name
                                                    
                                                    	Address family identifier
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: attributes_after_policy_in
                                                    
                                                    	Attributes after inbound policy applied
                                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn>`
                                                    
                                                    .. attribute:: label_fail
                                                    
                                                    	LSD label allocation failed 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: label_o_or_version
                                                    
                                                    	Label Version when OOR happens
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_oor
                                                    
                                                    	LSD label space is exhausted
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address_xr
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr>`
                                                    
                                                    .. attribute:: no_path
                                                    
                                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: path_information
                                                    
                                                    	Path information
                                                    	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation>`
                                                    
                                                    .. attribute:: prefix_version
                                                    
                                                    	Version of BGP Prefix Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: process_instance_id
                                                    
                                                    	Process instance ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: route_distinguisher
                                                    
                                                    	Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: source_route_distinguisher
                                                    
                                                    	Source Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: source_vrf_name
                                                    
                                                    	Name of the source VRF
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: srcaf_name
                                                    
                                                    	Address family identifier
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: vrf_name
                                                    
                                                    	Name of the VRF
                                                    	**type**\:  str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.af_name = None
                                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn()
                                                        self.attributes_after_policy_in.parent = self
                                                        self.label_fail = None
                                                        self.label_o_or_version = None
                                                        self.label_oor = None
                                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr()
                                                        self.neighbor_address_xr.parent = self
                                                        self.no_path = None
                                                        self.path_information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation()
                                                        self.path_information.parent = self
                                                        self.prefix_version = None
                                                        self.process_instance_id = None
                                                        self.route_distinguisher = None
                                                        self.source_route_distinguisher = None
                                                        self.source_vrf_name = None
                                                        self.srcaf_name = None
                                                        self.vrf_name = None


                                                    class NeighborAddressXr(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr']['meta_info']


                                                    class PathInformation(object):
                                                        """
                                                        Path information
                                                        
                                                        .. attribute:: accept_own_path
                                                        
                                                        	Accept Own
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: accept_own_self_originated_p_ath
                                                        
                                                        	Accept\-Own self\-originated
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: add_path_orr_bitfield
                                                        
                                                        	ORR Add path Bitfields
                                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                        
                                                        .. attribute:: advertisedto_pe
                                                        
                                                        	Net could be advertised                          to PE peers
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: aigp_metric
                                                        
                                                        	Total AIGP metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: best_path_comp_stage
                                                        
                                                        	Stage where the path lost to the best path or group best
                                                        	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                                        
                                                        .. attribute:: best_path_comp_winner
                                                        
                                                        	Neighbor address of the path which won best path comparison
                                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                        
                                                        .. attribute:: best_path_id
                                                        
                                                        	Best path ID; DEPRECATED BYLocalPathId
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: best_path_id_comp_winner
                                                        
                                                        	Path ID of the path which won best path comparison
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: best_path_orr_bitfield
                                                        
                                                        	ORR Best path Bitfields
                                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                        
                                                        .. attribute:: bgp_prefix
                                                        
                                                        	BGP prefix
                                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix>`
                                                        
                                                        .. attribute:: dampen_penalty
                                                        
                                                        	Dampening penalty
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Mvpn Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                        
                                                        .. attribute:: fspec_invalid_path
                                                        
                                                        	Is Fspec invalid path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: graceful_shutdown
                                                        
                                                        	Marked for graceful shutdown
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: gw_addr
                                                        
                                                        	Path GW Address
                                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.GwAddr>`
                                                        
                                                        .. attribute:: halflife_time
                                                        
                                                        	Half\-life time for the penalty
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_esi
                                                        
                                                        	Path has EVPN ESI
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_gw_addr
                                                        
                                                        	Path has GW Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_local_net_label
                                                        
                                                        	Path has local label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mdt_group_addr
                                                        
                                                        	Path has MDT Group Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_extcomm
                                                        
                                                        	Path has MVPN EXTCOMM feedback
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_nbr_addr
                                                        
                                                        	Path has Mvpn nbr Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_nexthop_addr
                                                        
                                                        	Path has MVPN nexthop Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_pmsi
                                                        
                                                        	Path has MVPN PMSI feedback
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_rcvd_label
                                                        
                                                        	Path has received label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_second_label
                                                        
                                                        	Path has second received label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: ibgp_signaled_validity
                                                        
                                                        	IBGP signalled validation
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: igp_metric
                                                        
                                                        	IGP metric to the gateway
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: is_aggregation_suppressed
                                                        
                                                        	Path suppressed due to aggregation
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_best
                                                        
                                                        	Best available path within AS
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_best_path
                                                        
                                                        	Best available path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_import_dampened
                                                        
                                                        	net import dampened
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_import_suspect
                                                        
                                                        	net import suspect
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_internal_path
                                                        
                                                        	Received over an internal link
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_partial_best
                                                        
                                                        	Partial best path within distributed speaker
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_additional_path
                                                        
                                                        	Path is an additional\-path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_advertised_local_as_only
                                                        
                                                        	Not advertised outside local AS
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_af_install_eligible
                                                        
                                                        	Path can be installed in AF RIB
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_backup
                                                        
                                                        	Path is a backup path 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_backup_protect_multipath
                                                        
                                                        	Path is a backup path to protect multipaths
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_best_external
                                                        
                                                        	Path is a best external path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_damped
                                                        
                                                        	Path suppressed due to dampening
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_confederation_peer
                                                        
                                                        	Path received from confederation peer
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_network_command
                                                        
                                                        	Path sourced by network command
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_redistribute_command
                                                        
                                                        	Path sourced by redistribute command
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_route_reflector
                                                        
                                                        	Path received from route reflector
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_history_held
                                                        
                                                        	Path entry held to remember history
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_imp_candidate
                                                        
                                                        	Path is a candidate for multipath import
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_imported
                                                        
                                                        	Path is imported
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_local_aggregate
                                                        
                                                        	Path is a locally created aggregate
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_locally_sourced
                                                        
                                                        	Path sourced locally
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_long_lived_stale
                                                        
                                                        	Long lived stale routes learnt before neighbor restarts
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_multipath
                                                        
                                                        	Path is one of multipath best routes
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_nexthop_discarded
                                                        
                                                        	Path is redirected to Null0
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_not_advertised
                                                        
                                                        	Not advertised to any peer
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_not_advertised_to_ebg_ps
                                                        
                                                        	Not advertised to EBGPs
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_received_only
                                                        
                                                        	Path is received only
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_reoriginated
                                                        
                                                        	Path is reoriginated
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_reoriginated_stitching
                                                        
                                                        	Path is reoriginated with stitching RTs
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_stale
                                                        
                                                        	Stale routes learnt before neighbor restarts
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_synced_with_igp
                                                        
                                                        	Path synchronized with IGP
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_valid
                                                        
                                                        	Path attributes are usable
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_vpn_only
                                                        
                                                        	Path is not in the vrf
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_permanent_path
                                                        
                                                        	Path is of type Permanent path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_received_path_not_modified
                                                        
                                                        	Received path used without modification
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_spkr_as_best
                                                        
                                                        	Best available path within AS in speaker
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2vpn_circuit_status_value
                                                        
                                                        	L2VPN Circuit Status Value
                                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                        
                                                        .. attribute:: l2vpn_evpn_esi
                                                        
                                                        	L2VPN EVPN ESI
                                                        	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi>`
                                                        
                                                        .. attribute:: l2vpn_size
                                                        
                                                        	Path block size
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: labeled_unicast_safi_path
                                                        
                                                        	Path was learnt by labeled\-unicast SAFI
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: local_label
                                                        
                                                        	Path local label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_nh
                                                        
                                                        	Path has local nexthop
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: local_path_id
                                                        
                                                        	Local path ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_peers_advertised_to
                                                        
                                                        	Local peers that this prefix has been advertised to
                                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                        
                                                        .. attribute:: maximum_suppress_time
                                                        
                                                        	Maximum duration to suppress a stable route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mdt_group_addr
                                                        
                                                        	IPv4 MDT Group Address for the path
                                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                        
                                                        .. attribute:: mvpn_nbr_addr
                                                        
                                                        	Mvpn nbr Address for the path
                                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                        
                                                        .. attribute:: mvpn_nexthop_addr
                                                        
                                                        	Mvpn nexthop Address for the path
                                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                        
                                                        .. attribute:: mvpn_path_flags
                                                        
                                                        	Mvpn path flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: mvpn_pmsi_flags
                                                        
                                                        	Mvpn PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: mvpn_pmsi_label
                                                        
                                                        	Mvpn PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mvpn_pmsi_type
                                                        
                                                        	Mvpn PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: mvpn_pmsi_value
                                                        
                                                        	Mvpn PMSI Value
                                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                        
                                                        .. attribute:: mvpn_sfs_path
                                                        
                                                        	Is MVPN single forwarder PE path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress>`
                                                        
                                                        .. attribute:: neighbor_router_id
                                                        
                                                        	Router ID of the neighbor for the path
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: next_hop
                                                        
                                                        	Next hop
                                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop>`
                                                        
                                                        .. attribute:: nhte_tunnel
                                                        
                                                        	NH TE tunnel information
                                                        	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhteTunnel>`
                                                        
                                                        .. attribute:: path_flags
                                                        
                                                        	Flags associated with path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: path_flap_count
                                                        
                                                        	Number of times this route has flapped
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_import_flags
                                                        
                                                        	Path import flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_rt_set_id
                                                        
                                                        	RT\-set id of the path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_rt_set_route_count
                                                        
                                                        	Count in RT\-set
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_table_version
                                                        
                                                        	Table version # for pelem
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_weight
                                                        
                                                        	Weight for the path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pe_peers_advertised_to
                                                        
                                                        	PE peers that this prefix has been advertised to
                                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                        
                                                        .. attribute:: rcvd_label
                                                        
                                                        	Path received label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rcvd_path_id
                                                        
                                                        	Received path ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: reuse_value
                                                        
                                                        	Value to start reusing a route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rib_failed
                                                        
                                                        	Is net failed installed                          in RIB
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route Type of path
                                                        	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                                        
                                                        .. attribute:: rpki_origin_as_validation_disabled
                                                        
                                                        	RPKI originAS V. Disabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: rt_set_limit_enabled
                                                        
                                                        	Path subject to RT\-set net limit
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: second_label
                                                        
                                                        	Path second received label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: seconds_since_first_flap
                                                        
                                                        	Seconds since route first flapped
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: show_rpki_origin_as_validity
                                                        
                                                        	Display validity state ?
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: sn_rpki_origin_as_validity
                                                        
                                                        	RPKI origin validation state
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: suppress_penalty
                                                        
                                                        	Value to start suppressing a route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: time_to_unsuppress
                                                        
                                                        	Seconds until route is unsuppressed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.accept_own_path = None
                                                            self.accept_own_self_originated_p_ath = None
                                                            self.add_path_orr_bitfield = YList()
                                                            self.add_path_orr_bitfield.parent = self
                                                            self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                            self.advertisedto_pe = None
                                                            self.aigp_metric = None
                                                            self.best_path_comp_stage = None
                                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner()
                                                            self.best_path_comp_winner.parent = self
                                                            self.best_path_id = None
                                                            self.best_path_id_comp_winner = None
                                                            self.best_path_orr_bitfield = YList()
                                                            self.best_path_orr_bitfield.parent = self
                                                            self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix()
                                                            self.bgp_prefix.parent = self
                                                            self.dampen_penalty = None
                                                            self.extended_community = YList()
                                                            self.extended_community.parent = self
                                                            self.extended_community.name = 'extended_community'
                                                            self.fspec_invalid_path = None
                                                            self.graceful_shutdown = None
                                                            self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.GwAddr()
                                                            self.gw_addr.parent = self
                                                            self.halflife_time = None
                                                            self.has_esi = None
                                                            self.has_gw_addr = None
                                                            self.has_local_net_label = None
                                                            self.has_mdt_group_addr = None
                                                            self.has_mvpn_extcomm = None
                                                            self.has_mvpn_nbr_addr = None
                                                            self.has_mvpn_nexthop_addr = None
                                                            self.has_mvpn_pmsi = None
                                                            self.has_rcvd_label = None
                                                            self.has_second_label = None
                                                            self.ibgp_signaled_validity = None
                                                            self.igp_metric = None
                                                            self.is_aggregation_suppressed = None
                                                            self.is_as_best = None
                                                            self.is_best_path = None
                                                            self.is_import_dampened = None
                                                            self.is_import_suspect = None
                                                            self.is_internal_path = None
                                                            self.is_partial_best = None
                                                            self.is_path_additional_path = None
                                                            self.is_path_advertised_local_as_only = None
                                                            self.is_path_af_install_eligible = None
                                                            self.is_path_backup = None
                                                            self.is_path_backup_protect_multipath = None
                                                            self.is_path_best_external = None
                                                            self.is_path_damped = None
                                                            self.is_path_from_confederation_peer = None
                                                            self.is_path_from_network_command = None
                                                            self.is_path_from_redistribute_command = None
                                                            self.is_path_from_route_reflector = None
                                                            self.is_path_history_held = None
                                                            self.is_path_imp_candidate = None
                                                            self.is_path_imported = None
                                                            self.is_path_local_aggregate = None
                                                            self.is_path_locally_sourced = None
                                                            self.is_path_long_lived_stale = None
                                                            self.is_path_multipath = None
                                                            self.is_path_nexthop_discarded = None
                                                            self.is_path_not_advertised = None
                                                            self.is_path_not_advertised_to_ebg_ps = None
                                                            self.is_path_received_only = None
                                                            self.is_path_reoriginated = None
                                                            self.is_path_reoriginated_stitching = None
                                                            self.is_path_stale = None
                                                            self.is_path_synced_with_igp = None
                                                            self.is_path_valid = None
                                                            self.is_path_vpn_only = None
                                                            self.is_permanent_path = None
                                                            self.is_received_path_not_modified = None
                                                            self.is_spkr_as_best = None
                                                            self.l2vpn_circuit_status_value = YList()
                                                            self.l2vpn_circuit_status_value.parent = self
                                                            self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                            self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi()
                                                            self.l2vpn_evpn_esi.parent = self
                                                            self.l2vpn_size = None
                                                            self.labeled_unicast_safi_path = None
                                                            self.local_label = None
                                                            self.local_nh = None
                                                            self.local_path_id = None
                                                            self.local_peers_advertised_to = YList()
                                                            self.local_peers_advertised_to.parent = self
                                                            self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                            self.maximum_suppress_time = None
                                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr()
                                                            self.mdt_group_addr.parent = self
                                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                            self.mvpn_nbr_addr.parent = self
                                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                            self.mvpn_nexthop_addr.parent = self
                                                            self.mvpn_path_flags = None
                                                            self.mvpn_pmsi_flags = None
                                                            self.mvpn_pmsi_label = None
                                                            self.mvpn_pmsi_type = None
                                                            self.mvpn_pmsi_value = YList()
                                                            self.mvpn_pmsi_value.parent = self
                                                            self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                            self.mvpn_sfs_path = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.neighbor_router_id = None
                                                            self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop()
                                                            self.next_hop.parent = self
                                                            self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhteTunnel()
                                                            self.nhte_tunnel.parent = self
                                                            self.path_flags = None
                                                            self.path_flap_count = None
                                                            self.path_import_flags = None
                                                            self.path_rt_set_id = None
                                                            self.path_rt_set_route_count = None
                                                            self.path_table_version = None
                                                            self.path_weight = None
                                                            self.pe_peers_advertised_to = YList()
                                                            self.pe_peers_advertised_to.parent = self
                                                            self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                            self.rcvd_label = None
                                                            self.rcvd_path_id = None
                                                            self.reuse_value = None
                                                            self.rib_failed = None
                                                            self.route_type = None
                                                            self.rpki_origin_as_validation_disabled = None
                                                            self.rt_set_limit_enabled = None
                                                            self.second_label = None
                                                            self.seconds_since_first_flap = None
                                                            self.show_rpki_origin_as_validity = None
                                                            self.sn_rpki_origin_as_validity = None
                                                            self.suppress_penalty = None
                                                            self.time_to_unsuppress = None


                                                        class BgpPrefix(object):
                                                            """
                                                            BGP prefix
                                                            
                                                            .. attribute:: prefix
                                                            
                                                            	Prefix
                                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                            
                                                            .. attribute:: prefix_length
                                                            
                                                            	Prefix length
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                                self.prefix.parent = self
                                                                self.prefix_length = None


                                                            class Prefix(object):
                                                                """
                                                                Prefix
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.prefix is not None and self.prefix._has_data():
                                                                    return True

                                                                if self.prefix_length is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix']['meta_info']


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress']['meta_info']


                                                        class NextHop(object):
                                                            """
                                                            Next hop
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop']['meta_info']


                                                        class NhteTunnel(object):
                                                            """
                                                            NH TE tunnel information
                                                            
                                                            .. attribute:: binding_label
                                                            
                                                            	Binding label for the tunnel
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: has_te_tunnel
                                                            
                                                            	NH TE Tunnel info is present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_info_stale
                                                            
                                                            	Tunnel is stale
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_registered
                                                            
                                                            	Tunnel registered flag
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_up
                                                            
                                                            	Tunnel Up flag
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: last_tunnel_update
                                                            
                                                            	Time since the last rib update happened
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_if_handle
                                                            
                                                            	Interface handle for the tunnel
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_name
                                                            
                                                            	tunnel name
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            .. attribute:: tunnel_type
                                                            
                                                            	tunnel type
                                                            	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                            
                                                            .. attribute:: tunnel_v6_enabled
                                                            
                                                            	IPv6 enabled
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_v6_required
                                                            
                                                            	Tunnel need IPv6
                                                            	**type**\:  bool
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.binding_label = None
                                                                self.has_te_tunnel = None
                                                                self.is_tunnel_info_stale = None
                                                                self.is_tunnel_registered = None
                                                                self.is_tunnel_up = None
                                                                self.last_tunnel_update = None
                                                                self.tunnel_if_handle = None
                                                                self.tunnel_name = None
                                                                self.tunnel_type = None
                                                                self.tunnel_v6_enabled = None
                                                                self.tunnel_v6_required = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.binding_label is not None:
                                                                    return True

                                                                if self.has_te_tunnel is not None:
                                                                    return True

                                                                if self.is_tunnel_info_stale is not None:
                                                                    return True

                                                                if self.is_tunnel_registered is not None:
                                                                    return True

                                                                if self.is_tunnel_up is not None:
                                                                    return True

                                                                if self.last_tunnel_update is not None:
                                                                    return True

                                                                if self.tunnel_if_handle is not None:
                                                                    return True

                                                                if self.tunnel_name is not None:
                                                                    return True

                                                                if self.tunnel_type is not None:
                                                                    return True

                                                                if self.tunnel_v6_enabled is not None:
                                                                    return True

                                                                if self.tunnel_v6_required is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhteTunnel']['meta_info']


                                                        class MdtGroupAddr(object):
                                                            """
                                                            IPv4 MDT Group Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr']['meta_info']


                                                        class L2VpnEvpnEsi(object):
                                                            """
                                                            L2VPN EVPN ESI
                                                            
                                                            .. attribute:: esi
                                                            
                                                            	esi
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.esi = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.esi is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi']['meta_info']


                                                        class GwAddr(object):
                                                            """
                                                            Path GW Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self.len = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.len is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.GwAddr']['meta_info']


                                                        class BestPathCompWinner(object):
                                                            """
                                                            Neighbor address of the path which won best path
                                                            comparison
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner']['meta_info']


                                                        class MvpnNbrAddr(object):
                                                            """
                                                            Mvpn nbr Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr']['meta_info']


                                                        class MvpnNexthopAddr(object):
                                                            """
                                                            Mvpn nexthop Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr']['meta_info']


                                                        class L2VpnCircuitStatusValue(object):
                                                            """
                                                            L2VPN Circuit Status Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                                        class MvpnPmsiValue(object):
                                                            """
                                                            Mvpn PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue']['meta_info']


                                                        class ExtendedCommunity(object):
                                                            """
                                                            Mvpn Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity']['meta_info']


                                                        class LocalPeersAdvertisedTo(object):
                                                            """
                                                            Local peers that this prefix has been advertised
                                                            to
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.is_neighbor = None
                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self.update_group_number = None


                                                            class NeighborAddress(object):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.is_neighbor is not None:
                                                                    return True

                                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                    return True

                                                                if self.update_group_number is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                                        class PePeersAdvertisedTo(object):
                                                            """
                                                            PE peers that this prefix has been advertised to
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.is_neighbor = None
                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self.update_group_number = None


                                                            class NeighborAddress(object):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.is_neighbor is not None:
                                                                    return True

                                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                    return True

                                                                if self.update_group_number is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo']['meta_info']


                                                        class BestPathOrrBitfield(object):
                                                            """
                                                            ORR Best path Bitfields
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.is_neighbor = None
                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self.update_group_number = None


                                                            class NeighborAddress(object):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.is_neighbor is not None:
                                                                    return True

                                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                    return True

                                                                if self.update_group_number is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield']['meta_info']


                                                        class AddPathOrrBitfield(object):
                                                            """
                                                            ORR Add path Bitfields
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.is_neighbor = None
                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self.update_group_number = None


                                                            class NeighborAddress(object):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.is_neighbor is not None:
                                                                    return True

                                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                    return True

                                                                if self.update_group_number is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.accept_own_path is not None:
                                                                return True

                                                            if self.accept_own_self_originated_p_ath is not None:
                                                                return True

                                                            if self.add_path_orr_bitfield is not None:
                                                                for child_ref in self.add_path_orr_bitfield:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.advertisedto_pe is not None:
                                                                return True

                                                            if self.aigp_metric is not None:
                                                                return True

                                                            if self.best_path_comp_stage is not None:
                                                                return True

                                                            if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                                return True

                                                            if self.best_path_id is not None:
                                                                return True

                                                            if self.best_path_id_comp_winner is not None:
                                                                return True

                                                            if self.best_path_orr_bitfield is not None:
                                                                for child_ref in self.best_path_orr_bitfield:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                                return True

                                                            if self.dampen_penalty is not None:
                                                                return True

                                                            if self.extended_community is not None:
                                                                for child_ref in self.extended_community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.fspec_invalid_path is not None:
                                                                return True

                                                            if self.graceful_shutdown is not None:
                                                                return True

                                                            if self.gw_addr is not None and self.gw_addr._has_data():
                                                                return True

                                                            if self.halflife_time is not None:
                                                                return True

                                                            if self.has_esi is not None:
                                                                return True

                                                            if self.has_gw_addr is not None:
                                                                return True

                                                            if self.has_local_net_label is not None:
                                                                return True

                                                            if self.has_mdt_group_addr is not None:
                                                                return True

                                                            if self.has_mvpn_extcomm is not None:
                                                                return True

                                                            if self.has_mvpn_nbr_addr is not None:
                                                                return True

                                                            if self.has_mvpn_nexthop_addr is not None:
                                                                return True

                                                            if self.has_mvpn_pmsi is not None:
                                                                return True

                                                            if self.has_rcvd_label is not None:
                                                                return True

                                                            if self.has_second_label is not None:
                                                                return True

                                                            if self.ibgp_signaled_validity is not None:
                                                                return True

                                                            if self.igp_metric is not None:
                                                                return True

                                                            if self.is_aggregation_suppressed is not None:
                                                                return True

                                                            if self.is_as_best is not None:
                                                                return True

                                                            if self.is_best_path is not None:
                                                                return True

                                                            if self.is_import_dampened is not None:
                                                                return True

                                                            if self.is_import_suspect is not None:
                                                                return True

                                                            if self.is_internal_path is not None:
                                                                return True

                                                            if self.is_partial_best is not None:
                                                                return True

                                                            if self.is_path_additional_path is not None:
                                                                return True

                                                            if self.is_path_advertised_local_as_only is not None:
                                                                return True

                                                            if self.is_path_af_install_eligible is not None:
                                                                return True

                                                            if self.is_path_backup is not None:
                                                                return True

                                                            if self.is_path_backup_protect_multipath is not None:
                                                                return True

                                                            if self.is_path_best_external is not None:
                                                                return True

                                                            if self.is_path_damped is not None:
                                                                return True

                                                            if self.is_path_from_confederation_peer is not None:
                                                                return True

                                                            if self.is_path_from_network_command is not None:
                                                                return True

                                                            if self.is_path_from_redistribute_command is not None:
                                                                return True

                                                            if self.is_path_from_route_reflector is not None:
                                                                return True

                                                            if self.is_path_history_held is not None:
                                                                return True

                                                            if self.is_path_imp_candidate is not None:
                                                                return True

                                                            if self.is_path_imported is not None:
                                                                return True

                                                            if self.is_path_local_aggregate is not None:
                                                                return True

                                                            if self.is_path_locally_sourced is not None:
                                                                return True

                                                            if self.is_path_long_lived_stale is not None:
                                                                return True

                                                            if self.is_path_multipath is not None:
                                                                return True

                                                            if self.is_path_nexthop_discarded is not None:
                                                                return True

                                                            if self.is_path_not_advertised is not None:
                                                                return True

                                                            if self.is_path_not_advertised_to_ebg_ps is not None:
                                                                return True

                                                            if self.is_path_received_only is not None:
                                                                return True

                                                            if self.is_path_reoriginated is not None:
                                                                return True

                                                            if self.is_path_reoriginated_stitching is not None:
                                                                return True

                                                            if self.is_path_stale is not None:
                                                                return True

                                                            if self.is_path_synced_with_igp is not None:
                                                                return True

                                                            if self.is_path_valid is not None:
                                                                return True

                                                            if self.is_path_vpn_only is not None:
                                                                return True

                                                            if self.is_permanent_path is not None:
                                                                return True

                                                            if self.is_received_path_not_modified is not None:
                                                                return True

                                                            if self.is_spkr_as_best is not None:
                                                                return True

                                                            if self.l2vpn_circuit_status_value is not None:
                                                                for child_ref in self.l2vpn_circuit_status_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                                return True

                                                            if self.l2vpn_size is not None:
                                                                return True

                                                            if self.labeled_unicast_safi_path is not None:
                                                                return True

                                                            if self.local_label is not None:
                                                                return True

                                                            if self.local_nh is not None:
                                                                return True

                                                            if self.local_path_id is not None:
                                                                return True

                                                            if self.local_peers_advertised_to is not None:
                                                                for child_ref in self.local_peers_advertised_to:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.maximum_suppress_time is not None:
                                                                return True

                                                            if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                                return True

                                                            if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                                return True

                                                            if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                                return True

                                                            if self.mvpn_path_flags is not None:
                                                                return True

                                                            if self.mvpn_pmsi_flags is not None:
                                                                return True

                                                            if self.mvpn_pmsi_label is not None:
                                                                return True

                                                            if self.mvpn_pmsi_type is not None:
                                                                return True

                                                            if self.mvpn_pmsi_value is not None:
                                                                for child_ref in self.mvpn_pmsi_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.mvpn_sfs_path is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.neighbor_router_id is not None:
                                                                return True

                                                            if self.next_hop is not None and self.next_hop._has_data():
                                                                return True

                                                            if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                                return True

                                                            if self.path_flags is not None:
                                                                return True

                                                            if self.path_flap_count is not None:
                                                                return True

                                                            if self.path_import_flags is not None:
                                                                return True

                                                            if self.path_rt_set_id is not None:
                                                                return True

                                                            if self.path_rt_set_route_count is not None:
                                                                return True

                                                            if self.path_table_version is not None:
                                                                return True

                                                            if self.path_weight is not None:
                                                                return True

                                                            if self.pe_peers_advertised_to is not None:
                                                                for child_ref in self.pe_peers_advertised_to:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.rcvd_label is not None:
                                                                return True

                                                            if self.rcvd_path_id is not None:
                                                                return True

                                                            if self.reuse_value is not None:
                                                                return True

                                                            if self.rib_failed is not None:
                                                                return True

                                                            if self.route_type is not None:
                                                                return True

                                                            if self.rpki_origin_as_validation_disabled is not None:
                                                                return True

                                                            if self.rt_set_limit_enabled is not None:
                                                                return True

                                                            if self.second_label is not None:
                                                                return True

                                                            if self.seconds_since_first_flap is not None:
                                                                return True

                                                            if self.show_rpki_origin_as_validity is not None:
                                                                return True

                                                            if self.sn_rpki_origin_as_validity is not None:
                                                                return True

                                                            if self.suppress_penalty is not None:
                                                                return True

                                                            if self.time_to_unsuppress is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation']['meta_info']


                                                    class AttributesAfterPolicyIn(object):
                                                        """
                                                        Attributes after inbound policy applied
                                                        
                                                        .. attribute:: attr_set
                                                        
                                                        	ATTR\_SET attribute
                                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                        
                                                        .. attribute:: attribute_key_number
                                                        
                                                        	Attribute key number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_config
                                                        
                                                        	Attribute reuse ID Configured
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: attribute_reuse_id_current
                                                        
                                                        	Attribute reuse ID current ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_keys
                                                        
                                                        	Attribute reuse ID allocated keys
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_max_id
                                                        
                                                        	Attribute reuse ID maximum ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_node
                                                        
                                                        	Attribute reuse ID nodes
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_recover_sec
                                                        
                                                        	Attribute reuse ID timer in seconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: common_attributes
                                                        
                                                        	Common attributes
                                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                        
                                                        .. attribute:: is_application_gateway_present
                                                        
                                                        	Application gateway present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path2_byte
                                                        
                                                        	AS path encoded as 2\-byte
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_attr_set_present
                                                        
                                                        	BGP ATTR\_SET attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ribrnh_present
                                                        
                                                        	RIB RNH Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_rnh_present
                                                        
                                                        	RNH Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: ribrnh_encap
                                                        
                                                        	RIB RNH Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ribrnh_ip
                                                        
                                                        	RIB RNH IP Address
                                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                        
                                                        .. attribute:: ribrnh_mac
                                                        
                                                        	RIB RNH MAC Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                        
                                                        .. attribute:: ribrnh_table
                                                        
                                                        	RIB RNH Table
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ribrnh_vni
                                                        
                                                        	RIB RNH Vni
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ribrnhip_table
                                                        
                                                        	RIB RNH IP Table
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rnh_addr
                                                        
                                                        	RNH Address
                                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                        
                                                        .. attribute:: rnh_addr_len
                                                        
                                                        	RNH Address Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rnh_len
                                                        
                                                        	RNH Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: rnh_type
                                                        
                                                        	RNH Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: set_aigp_inbound_igp
                                                        
                                                        	AIGP set by policy inbound IGP 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: set_aigp_inbound_metric
                                                        
                                                        	AIGP set by policy inbound metric
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: vpn_distinguisher
                                                        
                                                        	VPN Distinguisher
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                            self.attr_set.parent = self
                                                            self.attribute_key_number = None
                                                            self.attribute_reuse_id_config = None
                                                            self.attribute_reuse_id_current = None
                                                            self.attribute_reuse_id_keys = None
                                                            self.attribute_reuse_id_max_id = None
                                                            self.attribute_reuse_id_node = None
                                                            self.attribute_reuse_id_recover_sec = None
                                                            self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                            self.common_attributes.parent = self
                                                            self.is_application_gateway_present = None
                                                            self.is_as_path2_byte = None
                                                            self.is_attr_set_present = None
                                                            self.is_ribrnh_present = None
                                                            self.is_rnh_present = None
                                                            self.ribrnh_encap = None
                                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                            self.ribrnh_ip.parent = self
                                                            self.ribrnh_mac = None
                                                            self.ribrnh_table = None
                                                            self.ribrnh_vni = None
                                                            self.ribrnhip_table = None
                                                            self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                            self.rnh_addr.parent = self
                                                            self.rnh_addr_len = None
                                                            self.rnh_len = None
                                                            self.rnh_type = None
                                                            self.set_aigp_inbound_igp = None
                                                            self.set_aigp_inbound_metric = None
                                                            self.vpn_distinguisher = None


                                                        class CommonAttributes(object):
                                                            """
                                                            Common attributes
                                                            
                                                            .. attribute:: aggregator_address
                                                            
                                                            	Address where aggregation was performed
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: aggregator_as
                                                            
                                                            	AS where aggregation was last performed
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: aigp_metric_value
                                                            
                                                            	AIGP metric value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..18446744073709551615
                                                            
                                                            .. attribute:: as_path
                                                            
                                                            	AS path attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: cluster
                                                            
                                                            	Cluster list attribute
                                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                            
                                                            .. attribute:: community
                                                            
                                                            	Community attribute
                                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                            
                                                            .. attribute:: connector_type
                                                            
                                                            	Connector Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: connector_value
                                                            
                                                            	Connector Value
                                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                            
                                                            .. attribute:: extended_community
                                                            
                                                            	Extended community attribute
                                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                            
                                                            .. attribute:: extended_community_flags
                                                            
                                                            	Extended community Flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: is_aggregator_present
                                                            
                                                            	Aggregator attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_aigp_present
                                                            
                                                            	AIGP Present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_as_path_present
                                                            
                                                            	AS path attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_atomic_aggregate_present
                                                            
                                                            	Atomic aggregate attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_community_present
                                                            
                                                            	Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_connector_present
                                                            
                                                            	Connector present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_extended_community_present
                                                            
                                                            	Extended community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_label_index_present
                                                            
                                                            	Label Index attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_local_pref_present
                                                            
                                                            	Local Preference attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ls_attribute_present
                                                            
                                                            	BGP LS attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_metric_present
                                                            
                                                            	Metric attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_origin_present
                                                            
                                                            	Origin attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pe_distinguisher_label_present
                                                            
                                                            	PE distinguisher label  attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pmsi_present
                                                            
                                                            	PMSI Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pppmp_present
                                                            
                                                            	PPMP Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ssa_present
                                                            
                                                            	SSA attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_encap_present
                                                            
                                                            	Tunnel Encap attribute present 
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: l2tpv3_cookie
                                                            
                                                            	L2TPv3 Cookie
                                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                            
                                                            .. attribute:: l2tpv3_session_id
                                                            
                                                            	L2TPv3 session id
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: label_index_attr
                                                            
                                                            	Label Index attribute
                                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                            
                                                            .. attribute:: local_preference
                                                            
                                                            	Local preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ls_attr
                                                            
                                                            	BGP LS attribute
                                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	Metric
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: neighbor_as
                                                            
                                                            	Neighbor AS number
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: origin
                                                            
                                                            	Origin
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: originator
                                                            
                                                            	Originator attribute
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: pe_distinguisher_label
                                                            
                                                            	PE distinguisher label attribute
                                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                            
                                                            .. attribute:: pmsi_flags
                                                            
                                                            	PMSI Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pmsi_label
                                                            
                                                            	PMSI label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pmsi_type
                                                            
                                                            	PMSI Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: pmsi_value
                                                            
                                                            	PMSI Value
                                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                            
                                                            .. attribute:: ppm_pvalue
                                                            
                                                            	PPMP Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: sr_policy_allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                            
                                                            .. attribute:: sr_policy_binding_sid
                                                            
                                                            	SR Policy Binding sid
                                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                            
                                                            .. attribute:: sr_policy_explicit_path
                                                            
                                                            	SR Policy Explicit paths
                                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                            
                                                            .. attribute:: sr_policy_preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: sr_tunnel_request_state
                                                            
                                                            	SR Tunnel Request State
                                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                            
                                                            .. attribute:: sr_tunnel_state
                                                            
                                                            	SR Tunnel State
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encap Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: unknown_attribute
                                                            
                                                            	Unknown attributes
                                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.aggregator_address = None
                                                                self.aggregator_as = None
                                                                self.aigp_metric_value = None
                                                                self.as_path = None
                                                                self.cluster = YList()
                                                                self.cluster.parent = self
                                                                self.cluster.name = 'cluster'
                                                                self.community = YList()
                                                                self.community.parent = self
                                                                self.community.name = 'community'
                                                                self.connector_type = None
                                                                self.connector_value = YList()
                                                                self.connector_value.parent = self
                                                                self.connector_value.name = 'connector_value'
                                                                self.extended_community = YList()
                                                                self.extended_community.parent = self
                                                                self.extended_community.name = 'extended_community'
                                                                self.extended_community_flags = None
                                                                self.is_aggregator_present = None
                                                                self.is_aigp_present = None
                                                                self.is_as_path_present = None
                                                                self.is_atomic_aggregate_present = None
                                                                self.is_community_present = None
                                                                self.is_connector_present = None
                                                                self.is_extended_community_present = None
                                                                self.is_label_index_present = None
                                                                self.is_local_pref_present = None
                                                                self.is_ls_attribute_present = None
                                                                self.is_metric_present = None
                                                                self.is_origin_present = None
                                                                self.is_pe_distinguisher_label_present = None
                                                                self.is_pmsi_present = None
                                                                self.is_pppmp_present = None
                                                                self.is_ssa_present = None
                                                                self.is_tunnel_encap_present = None
                                                                self.l2tpv3_cookie = YList()
                                                                self.l2tpv3_cookie.parent = self
                                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                                self.l2tpv3_session_id = None
                                                                self.label_index_attr = YList()
                                                                self.label_index_attr.parent = self
                                                                self.label_index_attr.name = 'label_index_attr'
                                                                self.local_preference = None
                                                                self.ls_attr = YList()
                                                                self.ls_attr.parent = self
                                                                self.ls_attr.name = 'ls_attr'
                                                                self.metric = None
                                                                self.neighbor_as = None
                                                                self.origin = None
                                                                self.originator = None
                                                                self.pe_distinguisher_label = YList()
                                                                self.pe_distinguisher_label.parent = self
                                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                                self.pmsi_flags = None
                                                                self.pmsi_label = None
                                                                self.pmsi_type = None
                                                                self.pmsi_value = YList()
                                                                self.pmsi_value.parent = self
                                                                self.pmsi_value.name = 'pmsi_value'
                                                                self.ppm_pvalue = None
                                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                                self.sr_policy_allocated_binding_sid.parent = self
                                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                                self.sr_policy_binding_sid.parent = self
                                                                self.sr_policy_explicit_path = YList()
                                                                self.sr_policy_explicit_path.parent = self
                                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                                self.sr_policy_preference = None
                                                                self.sr_tunnel_request_state = None
                                                                self.sr_tunnel_state = None
                                                                self.tunnel_encap_type = None
                                                                self.unknown_attribute = YList()
                                                                self.unknown_attribute.parent = self
                                                                self.unknown_attribute.name = 'unknown_attribute'


                                                            class SrPolicyBindingSid(object):
                                                                """
                                                                SR Policy Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_address = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                            class SrPolicyAllocatedBindingSid(object):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_address = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                            class Community(object):
                                                                """
                                                                Community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                            class ExtendedCommunity(object):
                                                                """
                                                                Extended community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                            class UnknownAttribute(object):
                                                                """
                                                                Unknown attributes
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                            class Cluster(object):
                                                                """
                                                                Cluster list attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                            class L2Tpv3Cookie(object):
                                                                """
                                                                L2TPv3 Cookie
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                            class ConnectorValue(object):
                                                                """
                                                                Connector Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                            class PmsiValue(object):
                                                                """
                                                                PMSI Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                            class LsAttr(object):
                                                                """
                                                                BGP LS attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                            class LabelIndexAttr(object):
                                                                """
                                                                Label Index attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                            class PeDistinguisherLabel(object):
                                                                """
                                                                PE distinguisher label attribute
                                                                
                                                                .. attribute:: label
                                                                
                                                                	Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pe_address
                                                                
                                                                	 PE address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.label = None
                                                                    self.pe_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.pe_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                            class SrPolicyExplicitPath(object):
                                                                """
                                                                SR Policy Explicit paths
                                                                
                                                                .. attribute:: sid
                                                                
                                                                	Sidlist for explicit path
                                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of explicit path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.sid = YList()
                                                                    self.sid.parent = self
                                                                    self.sid.name = 'sid'
                                                                    self.weight = None


                                                                class Sid(object):
                                                                    """
                                                                    Sidlist for explicit path
                                                                    
                                                                    .. attribute:: ipv4
                                                                    
                                                                    	IP Address sid
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6
                                                                    
                                                                    	IPv6 address sid
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label sid
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Sid Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4 = None
                                                                        self.ipv6 = None
                                                                        self.label = None
                                                                        self.type = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4 is not None:
                                                                            return True

                                                                        if self.ipv6 is not None:
                                                                            return True

                                                                        if self.label is not None:
                                                                            return True

                                                                        if self.type is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.sid is not None:
                                                                        for child_ref in self.sid:
                                                                            if child_ref._has_data():
                                                                                return True

                                                                    if self.weight is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.aggregator_address is not None:
                                                                    return True

                                                                if self.aggregator_as is not None:
                                                                    return True

                                                                if self.aigp_metric_value is not None:
                                                                    return True

                                                                if self.as_path is not None:
                                                                    return True

                                                                if self.cluster is not None:
                                                                    for child_ref in self.cluster:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.community is not None:
                                                                    for child_ref in self.community:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.connector_type is not None:
                                                                    return True

                                                                if self.connector_value is not None:
                                                                    for child_ref in self.connector_value:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.extended_community is not None:
                                                                    for child_ref in self.extended_community:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.extended_community_flags is not None:
                                                                    return True

                                                                if self.is_aggregator_present is not None:
                                                                    return True

                                                                if self.is_aigp_present is not None:
                                                                    return True

                                                                if self.is_as_path_present is not None:
                                                                    return True

                                                                if self.is_atomic_aggregate_present is not None:
                                                                    return True

                                                                if self.is_community_present is not None:
                                                                    return True

                                                                if self.is_connector_present is not None:
                                                                    return True

                                                                if self.is_extended_community_present is not None:
                                                                    return True

                                                                if self.is_label_index_present is not None:
                                                                    return True

                                                                if self.is_local_pref_present is not None:
                                                                    return True

                                                                if self.is_ls_attribute_present is not None:
                                                                    return True

                                                                if self.is_metric_present is not None:
                                                                    return True

                                                                if self.is_origin_present is not None:
                                                                    return True

                                                                if self.is_pe_distinguisher_label_present is not None:
                                                                    return True

                                                                if self.is_pmsi_present is not None:
                                                                    return True

                                                                if self.is_pppmp_present is not None:
                                                                    return True

                                                                if self.is_ssa_present is not None:
                                                                    return True

                                                                if self.is_tunnel_encap_present is not None:
                                                                    return True

                                                                if self.l2tpv3_cookie is not None:
                                                                    for child_ref in self.l2tpv3_cookie:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.l2tpv3_session_id is not None:
                                                                    return True

                                                                if self.label_index_attr is not None:
                                                                    for child_ref in self.label_index_attr:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.local_preference is not None:
                                                                    return True

                                                                if self.ls_attr is not None:
                                                                    for child_ref in self.ls_attr:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.metric is not None:
                                                                    return True

                                                                if self.neighbor_as is not None:
                                                                    return True

                                                                if self.origin is not None:
                                                                    return True

                                                                if self.originator is not None:
                                                                    return True

                                                                if self.pe_distinguisher_label is not None:
                                                                    for child_ref in self.pe_distinguisher_label:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.pmsi_flags is not None:
                                                                    return True

                                                                if self.pmsi_label is not None:
                                                                    return True

                                                                if self.pmsi_type is not None:
                                                                    return True

                                                                if self.pmsi_value is not None:
                                                                    for child_ref in self.pmsi_value:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.ppm_pvalue is not None:
                                                                    return True

                                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                                    return True

                                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                                    return True

                                                                if self.sr_policy_explicit_path is not None:
                                                                    for child_ref in self.sr_policy_explicit_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.sr_policy_preference is not None:
                                                                    return True

                                                                if self.sr_tunnel_request_state is not None:
                                                                    return True

                                                                if self.sr_tunnel_state is not None:
                                                                    return True

                                                                if self.tunnel_encap_type is not None:
                                                                    return True

                                                                if self.unknown_attribute is not None:
                                                                    for child_ref in self.unknown_attribute:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                                        class AttrSet(object):
                                                            """
                                                            ATTR\_SET attribute
                                                            
                                                            .. attribute:: aggregator_address
                                                            
                                                            	Address where aggregation was performed
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: aggregator_as
                                                            
                                                            	AS where aggregation was last performed
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: aigp_metric_value
                                                            
                                                            	AIGP metric value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..18446744073709551615
                                                            
                                                            .. attribute:: as_path
                                                            
                                                            	AS path attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: cluster
                                                            
                                                            	Cluster list attribute
                                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                            
                                                            .. attribute:: community
                                                            
                                                            	Community attribute
                                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                            
                                                            .. attribute:: connector_type
                                                            
                                                            	Connector Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: connector_value
                                                            
                                                            	Connector Value
                                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                            
                                                            .. attribute:: extended_community
                                                            
                                                            	Extended community attribute
                                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                            
                                                            .. attribute:: extended_community_flags
                                                            
                                                            	Extended community Flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: is_aggregator_present
                                                            
                                                            	Aggregator attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_aigp_present
                                                            
                                                            	AIGP Present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_as_path_present
                                                            
                                                            	AS path attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_atomic_aggregate_present
                                                            
                                                            	Atomic aggregate attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_community_present
                                                            
                                                            	Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_connector_present
                                                            
                                                            	Connector present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_extended_community_present
                                                            
                                                            	Extended community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_label_index_present
                                                            
                                                            	Label Index attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_local_pref_present
                                                            
                                                            	Local Preference attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ls_attribute_present
                                                            
                                                            	BGP LS attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_metric_present
                                                            
                                                            	Metric attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_origin_present
                                                            
                                                            	Origin attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pe_distinguisher_label_present
                                                            
                                                            	PE distinguisher label  attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pmsi_present
                                                            
                                                            	PMSI Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pppmp_present
                                                            
                                                            	PPMP Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ssa_present
                                                            
                                                            	SSA attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_encap_present
                                                            
                                                            	Tunnel Encap attribute present 
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: l2tpv3_cookie
                                                            
                                                            	L2TPv3 Cookie
                                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                            
                                                            .. attribute:: l2tpv3_session_id
                                                            
                                                            	L2TPv3 session id
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: label_index_attr
                                                            
                                                            	Label Index attribute
                                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                            
                                                            .. attribute:: local_preference
                                                            
                                                            	Local preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ls_attr
                                                            
                                                            	BGP LS attribute
                                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	Metric
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: neighbor_as
                                                            
                                                            	Neighbor AS number
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: origin
                                                            
                                                            	Origin
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: originator
                                                            
                                                            	Originator attribute
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: pe_distinguisher_label
                                                            
                                                            	PE distinguisher label attribute
                                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                            
                                                            .. attribute:: pmsi_flags
                                                            
                                                            	PMSI Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pmsi_label
                                                            
                                                            	PMSI label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pmsi_type
                                                            
                                                            	PMSI Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: pmsi_value
                                                            
                                                            	PMSI Value
                                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                            
                                                            .. attribute:: ppm_pvalue
                                                            
                                                            	PPMP Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: sr_policy_allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                            
                                                            .. attribute:: sr_policy_binding_sid
                                                            
                                                            	SR Policy Binding sid
                                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                            
                                                            .. attribute:: sr_policy_explicit_path
                                                            
                                                            	SR Policy Explicit paths
                                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                            
                                                            .. attribute:: sr_policy_preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: sr_tunnel_request_state
                                                            
                                                            	SR Tunnel Request State
                                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                            
                                                            .. attribute:: sr_tunnel_state
                                                            
                                                            	SR Tunnel State
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encap Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: unknown_attribute
                                                            
                                                            	Unknown attributes
                                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.aggregator_address = None
                                                                self.aggregator_as = None
                                                                self.aigp_metric_value = None
                                                                self.as_path = None
                                                                self.cluster = YList()
                                                                self.cluster.parent = self
                                                                self.cluster.name = 'cluster'
                                                                self.community = YList()
                                                                self.community.parent = self
                                                                self.community.name = 'community'
                                                                self.connector_type = None
                                                                self.connector_value = YList()
                                                                self.connector_value.parent = self
                                                                self.connector_value.name = 'connector_value'
                                                                self.extended_community = YList()
                                                                self.extended_community.parent = self
                                                                self.extended_community.name = 'extended_community'
                                                                self.extended_community_flags = None
                                                                self.is_aggregator_present = None
                                                                self.is_aigp_present = None
                                                                self.is_as_path_present = None
                                                                self.is_atomic_aggregate_present = None
                                                                self.is_community_present = None
                                                                self.is_connector_present = None
                                                                self.is_extended_community_present = None
                                                                self.is_label_index_present = None
                                                                self.is_local_pref_present = None
                                                                self.is_ls_attribute_present = None
                                                                self.is_metric_present = None
                                                                self.is_origin_present = None
                                                                self.is_pe_distinguisher_label_present = None
                                                                self.is_pmsi_present = None
                                                                self.is_pppmp_present = None
                                                                self.is_ssa_present = None
                                                                self.is_tunnel_encap_present = None
                                                                self.l2tpv3_cookie = YList()
                                                                self.l2tpv3_cookie.parent = self
                                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                                self.l2tpv3_session_id = None
                                                                self.label_index_attr = YList()
                                                                self.label_index_attr.parent = self
                                                                self.label_index_attr.name = 'label_index_attr'
                                                                self.local_preference = None
                                                                self.ls_attr = YList()
                                                                self.ls_attr.parent = self
                                                                self.ls_attr.name = 'ls_attr'
                                                                self.metric = None
                                                                self.neighbor_as = None
                                                                self.origin = None
                                                                self.originator = None
                                                                self.pe_distinguisher_label = YList()
                                                                self.pe_distinguisher_label.parent = self
                                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                                self.pmsi_flags = None
                                                                self.pmsi_label = None
                                                                self.pmsi_type = None
                                                                self.pmsi_value = YList()
                                                                self.pmsi_value.parent = self
                                                                self.pmsi_value.name = 'pmsi_value'
                                                                self.ppm_pvalue = None
                                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                                self.sr_policy_allocated_binding_sid.parent = self
                                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                                self.sr_policy_binding_sid.parent = self
                                                                self.sr_policy_explicit_path = YList()
                                                                self.sr_policy_explicit_path.parent = self
                                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                                self.sr_policy_preference = None
                                                                self.sr_tunnel_request_state = None
                                                                self.sr_tunnel_state = None
                                                                self.tunnel_encap_type = None
                                                                self.unknown_attribute = YList()
                                                                self.unknown_attribute.parent = self
                                                                self.unknown_attribute.name = 'unknown_attribute'


                                                            class SrPolicyBindingSid(object):
                                                                """
                                                                SR Policy Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_address = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                            class SrPolicyAllocatedBindingSid(object):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_address = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                            class Community(object):
                                                                """
                                                                Community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                            class ExtendedCommunity(object):
                                                                """
                                                                Extended community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                            class UnknownAttribute(object):
                                                                """
                                                                Unknown attributes
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                            class Cluster(object):
                                                                """
                                                                Cluster list attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                            class L2Tpv3Cookie(object):
                                                                """
                                                                L2TPv3 Cookie
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                            class ConnectorValue(object):
                                                                """
                                                                Connector Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                            class PmsiValue(object):
                                                                """
                                                                PMSI Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                            class LsAttr(object):
                                                                """
                                                                BGP LS attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                            class LabelIndexAttr(object):
                                                                """
                                                                Label Index attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                            class PeDistinguisherLabel(object):
                                                                """
                                                                PE distinguisher label attribute
                                                                
                                                                .. attribute:: label
                                                                
                                                                	Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pe_address
                                                                
                                                                	 PE address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.label = None
                                                                    self.pe_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.pe_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                            class SrPolicyExplicitPath(object):
                                                                """
                                                                SR Policy Explicit paths
                                                                
                                                                .. attribute:: sid
                                                                
                                                                	Sidlist for explicit path
                                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of explicit path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.sid = YList()
                                                                    self.sid.parent = self
                                                                    self.sid.name = 'sid'
                                                                    self.weight = None


                                                                class Sid(object):
                                                                    """
                                                                    Sidlist for explicit path
                                                                    
                                                                    .. attribute:: ipv4
                                                                    
                                                                    	IP Address sid
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6
                                                                    
                                                                    	IPv6 address sid
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label sid
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Sid Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4 = None
                                                                        self.ipv6 = None
                                                                        self.label = None
                                                                        self.type = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4 is not None:
                                                                            return True

                                                                        if self.ipv6 is not None:
                                                                            return True

                                                                        if self.label is not None:
                                                                            return True

                                                                        if self.type is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.sid is not None:
                                                                        for child_ref in self.sid:
                                                                            if child_ref._has_data():
                                                                                return True

                                                                    if self.weight is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.aggregator_address is not None:
                                                                    return True

                                                                if self.aggregator_as is not None:
                                                                    return True

                                                                if self.aigp_metric_value is not None:
                                                                    return True

                                                                if self.as_path is not None:
                                                                    return True

                                                                if self.cluster is not None:
                                                                    for child_ref in self.cluster:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.community is not None:
                                                                    for child_ref in self.community:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.connector_type is not None:
                                                                    return True

                                                                if self.connector_value is not None:
                                                                    for child_ref in self.connector_value:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.extended_community is not None:
                                                                    for child_ref in self.extended_community:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.extended_community_flags is not None:
                                                                    return True

                                                                if self.is_aggregator_present is not None:
                                                                    return True

                                                                if self.is_aigp_present is not None:
                                                                    return True

                                                                if self.is_as_path_present is not None:
                                                                    return True

                                                                if self.is_atomic_aggregate_present is not None:
                                                                    return True

                                                                if self.is_community_present is not None:
                                                                    return True

                                                                if self.is_connector_present is not None:
                                                                    return True

                                                                if self.is_extended_community_present is not None:
                                                                    return True

                                                                if self.is_label_index_present is not None:
                                                                    return True

                                                                if self.is_local_pref_present is not None:
                                                                    return True

                                                                if self.is_ls_attribute_present is not None:
                                                                    return True

                                                                if self.is_metric_present is not None:
                                                                    return True

                                                                if self.is_origin_present is not None:
                                                                    return True

                                                                if self.is_pe_distinguisher_label_present is not None:
                                                                    return True

                                                                if self.is_pmsi_present is not None:
                                                                    return True

                                                                if self.is_pppmp_present is not None:
                                                                    return True

                                                                if self.is_ssa_present is not None:
                                                                    return True

                                                                if self.is_tunnel_encap_present is not None:
                                                                    return True

                                                                if self.l2tpv3_cookie is not None:
                                                                    for child_ref in self.l2tpv3_cookie:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.l2tpv3_session_id is not None:
                                                                    return True

                                                                if self.label_index_attr is not None:
                                                                    for child_ref in self.label_index_attr:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.local_preference is not None:
                                                                    return True

                                                                if self.ls_attr is not None:
                                                                    for child_ref in self.ls_attr:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.metric is not None:
                                                                    return True

                                                                if self.neighbor_as is not None:
                                                                    return True

                                                                if self.origin is not None:
                                                                    return True

                                                                if self.originator is not None:
                                                                    return True

                                                                if self.pe_distinguisher_label is not None:
                                                                    for child_ref in self.pe_distinguisher_label:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.pmsi_flags is not None:
                                                                    return True

                                                                if self.pmsi_label is not None:
                                                                    return True

                                                                if self.pmsi_type is not None:
                                                                    return True

                                                                if self.pmsi_value is not None:
                                                                    for child_ref in self.pmsi_value:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.ppm_pvalue is not None:
                                                                    return True

                                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                                    return True

                                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                                    return True

                                                                if self.sr_policy_explicit_path is not None:
                                                                    for child_ref in self.sr_policy_explicit_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.sr_policy_preference is not None:
                                                                    return True

                                                                if self.sr_tunnel_request_state is not None:
                                                                    return True

                                                                if self.sr_tunnel_state is not None:
                                                                    return True

                                                                if self.tunnel_encap_type is not None:
                                                                    return True

                                                                if self.unknown_attribute is not None:
                                                                    for child_ref in self.unknown_attribute:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                                        class RnhAddr(object):
                                                            """
                                                            RNH Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                            
                                                            .. attribute:: mac_address
                                                            
                                                            	MAC Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self.len = None
                                                                self.mac_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.len is not None:
                                                                    return True

                                                                if self.mac_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                                        class RibrnhIp(object):
                                                            """
                                                            RIB RNH IP Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.attr_set is not None and self.attr_set._has_data():
                                                                return True

                                                            if self.attribute_key_number is not None:
                                                                return True

                                                            if self.attribute_reuse_id_config is not None:
                                                                return True

                                                            if self.attribute_reuse_id_current is not None:
                                                                return True

                                                            if self.attribute_reuse_id_keys is not None:
                                                                return True

                                                            if self.attribute_reuse_id_max_id is not None:
                                                                return True

                                                            if self.attribute_reuse_id_node is not None:
                                                                return True

                                                            if self.attribute_reuse_id_recover_sec is not None:
                                                                return True

                                                            if self.common_attributes is not None and self.common_attributes._has_data():
                                                                return True

                                                            if self.is_application_gateway_present is not None:
                                                                return True

                                                            if self.is_as_path2_byte is not None:
                                                                return True

                                                            if self.is_attr_set_present is not None:
                                                                return True

                                                            if self.is_ribrnh_present is not None:
                                                                return True

                                                            if self.is_rnh_present is not None:
                                                                return True

                                                            if self.ribrnh_encap is not None:
                                                                return True

                                                            if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                                return True

                                                            if self.ribrnh_mac is not None:
                                                                return True

                                                            if self.ribrnh_table is not None:
                                                                return True

                                                            if self.ribrnh_vni is not None:
                                                                return True

                                                            if self.ribrnhip_table is not None:
                                                                return True

                                                            if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                                return True

                                                            if self.rnh_addr_len is not None:
                                                                return True

                                                            if self.rnh_len is not None:
                                                                return True

                                                            if self.rnh_type is not None:
                                                                return True

                                                            if self.set_aigp_inbound_igp is not None:
                                                                return True

                                                            if self.set_aigp_inbound_metric is not None:
                                                                return True

                                                            if self.vpn_distinguisher is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-process-instance-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.af_name is not None:
                                                            return True

                                                        if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                            return True

                                                        if self.label_fail is not None:
                                                            return True

                                                        if self.label_o_or_version is not None:
                                                            return True

                                                        if self.label_oor is not None:
                                                            return True

                                                        if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                            return True

                                                        if self.no_path is not None:
                                                            return True

                                                        if self.path_information is not None and self.path_information._has_data():
                                                            return True

                                                        if self.prefix_version is not None:
                                                            return True

                                                        if self.process_instance_id is not None:
                                                            return True

                                                        if self.route_distinguisher is not None:
                                                            return True

                                                        if self.source_route_distinguisher is not None:
                                                            return True

                                                        if self.source_vrf_name is not None:
                                                            return True

                                                        if self.srcaf_name is not None:
                                                            return True

                                                        if self.vrf_name is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath']['meta_info']


                                                class LocalPathElement(object):
                                                    """
                                                    Local path element list
                                                    
                                                    .. attribute:: is_perm_path_pelem
                                                    
                                                    	Pelem for permanent path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: nhte_tunnel
                                                    
                                                    	NH TE tunnel information
                                                    	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.NhteTunnel>`
                                                    
                                                    .. attribute:: pelem_flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_gw_metric
                                                    
                                                    	Gateway metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_no_addpath_table_attr_version
                                                    
                                                    	No\-addpath Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_no_bestpath_table_attr_version
                                                    
                                                    	No\-bestpath Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_flags
                                                    
                                                    	Path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: pelem_path_id
                                                    
                                                    	Local Path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_neighbor_addr
                                                    
                                                    	Path neighbor address
                                                    	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr>`
                                                    
                                                    .. attribute:: pelem_path_nexthop
                                                    
                                                    	Path nexthop address
                                                    	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop>`
                                                    
                                                    .. attribute:: pelem_path_peer_path_id
                                                    
                                                    	Path peer path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_table_attr_version
                                                    
                                                    	Path Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_table_attr_version
                                                    
                                                    	Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_version
                                                    
                                                    	Version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_perm_path_pelem = None
                                                        self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.NhteTunnel()
                                                        self.nhte_tunnel.parent = self
                                                        self.pelem_flags = None
                                                        self.pelem_gw_metric = None
                                                        self.pelem_no_addpath_table_attr_version = None
                                                        self.pelem_no_bestpath_table_attr_version = None
                                                        self.pelem_path_flags = None
                                                        self.pelem_path_id = None
                                                        self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr()
                                                        self.pelem_path_neighbor_addr.parent = self
                                                        self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop()
                                                        self.pelem_path_nexthop.parent = self
                                                        self.pelem_path_peer_path_id = None
                                                        self.pelem_path_table_attr_version = None
                                                        self.pelem_table_attr_version = None
                                                        self.pelem_version = None


                                                    class PelemPathNexthop(object):
                                                        """
                                                        Path nexthop address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-nexthop'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop']['meta_info']


                                                    class NhteTunnel(object):
                                                        """
                                                        NH TE tunnel information
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	Binding label for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_te_tunnel
                                                        
                                                        	NH TE Tunnel info is present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_info_stale
                                                        
                                                        	Tunnel is stale
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_registered
                                                        
                                                        	Tunnel registered flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_up
                                                        
                                                        	Tunnel Up flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: last_tunnel_update
                                                        
                                                        	Time since the last rib update happened
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_if_handle
                                                        
                                                        	Interface handle for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_name
                                                        
                                                        	tunnel name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        .. attribute:: tunnel_type
                                                        
                                                        	tunnel type
                                                        	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                        
                                                        .. attribute:: tunnel_v6_enabled
                                                        
                                                        	IPv6 enabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_v6_required
                                                        
                                                        	Tunnel need IPv6
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.binding_label = None
                                                            self.has_te_tunnel = None
                                                            self.is_tunnel_info_stale = None
                                                            self.is_tunnel_registered = None
                                                            self.is_tunnel_up = None
                                                            self.last_tunnel_update = None
                                                            self.tunnel_if_handle = None
                                                            self.tunnel_name = None
                                                            self.tunnel_type = None
                                                            self.tunnel_v6_enabled = None
                                                            self.tunnel_v6_required = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.binding_label is not None:
                                                                return True

                                                            if self.has_te_tunnel is not None:
                                                                return True

                                                            if self.is_tunnel_info_stale is not None:
                                                                return True

                                                            if self.is_tunnel_registered is not None:
                                                                return True

                                                            if self.is_tunnel_up is not None:
                                                                return True

                                                            if self.last_tunnel_update is not None:
                                                                return True

                                                            if self.tunnel_if_handle is not None:
                                                                return True

                                                            if self.tunnel_name is not None:
                                                                return True

                                                            if self.tunnel_type is not None:
                                                                return True

                                                            if self.tunnel_v6_enabled is not None:
                                                                return True

                                                            if self.tunnel_v6_required is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.NhteTunnel']['meta_info']


                                                    class PelemPathNeighborAddr(object):
                                                        """
                                                        Path neighbor address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-neighbor-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-path-element'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_perm_path_pelem is not None:
                                                            return True

                                                        if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                            return True

                                                        if self.pelem_flags is not None:
                                                            return True

                                                        if self.pelem_gw_metric is not None:
                                                            return True

                                                        if self.pelem_no_addpath_table_attr_version is not None:
                                                            return True

                                                        if self.pelem_no_bestpath_table_attr_version is not None:
                                                            return True

                                                        if self.pelem_path_flags is not None:
                                                            return True

                                                        if self.pelem_path_id is not None:
                                                            return True

                                                        if self.pelem_path_neighbor_addr is not None and self.pelem_path_neighbor_addr._has_data():
                                                            return True

                                                        if self.pelem_path_nexthop is not None and self.pelem_path_nexthop._has_data():
                                                            return True

                                                        if self.pelem_path_peer_path_id is not None:
                                                            return True

                                                        if self.pelem_path_table_attr_version is not None:
                                                            return True

                                                        if self.pelem_table_attr_version is not None:
                                                            return True

                                                        if self.pelem_version is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement']['meta_info']


                                                class ActivePathElement(object):
                                                    """
                                                    Path element list received from Active inst
                                                    
                                                    .. attribute:: is_perm_path_pelem
                                                    
                                                    	Pelem for permanent path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: nhte_tunnel
                                                    
                                                    	NH TE tunnel information
                                                    	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.NhteTunnel>`
                                                    
                                                    .. attribute:: pelem_flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_gw_metric
                                                    
                                                    	Gateway metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_no_addpath_table_attr_version
                                                    
                                                    	No\-addpath Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_no_bestpath_table_attr_version
                                                    
                                                    	No\-bestpath Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_flags
                                                    
                                                    	Path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: pelem_path_id
                                                    
                                                    	Local Path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_neighbor_addr
                                                    
                                                    	Path neighbor address
                                                    	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr>`
                                                    
                                                    .. attribute:: pelem_path_nexthop
                                                    
                                                    	Path nexthop address
                                                    	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop>`
                                                    
                                                    .. attribute:: pelem_path_peer_path_id
                                                    
                                                    	Path peer path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_table_attr_version
                                                    
                                                    	Path Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_table_attr_version
                                                    
                                                    	Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_version
                                                    
                                                    	Version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_perm_path_pelem = None
                                                        self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.NhteTunnel()
                                                        self.nhte_tunnel.parent = self
                                                        self.pelem_flags = None
                                                        self.pelem_gw_metric = None
                                                        self.pelem_no_addpath_table_attr_version = None
                                                        self.pelem_no_bestpath_table_attr_version = None
                                                        self.pelem_path_flags = None
                                                        self.pelem_path_id = None
                                                        self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr()
                                                        self.pelem_path_neighbor_addr.parent = self
                                                        self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop()
                                                        self.pelem_path_nexthop.parent = self
                                                        self.pelem_path_peer_path_id = None
                                                        self.pelem_path_table_attr_version = None
                                                        self.pelem_table_attr_version = None
                                                        self.pelem_version = None


                                                    class PelemPathNexthop(object):
                                                        """
                                                        Path nexthop address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-nexthop'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop']['meta_info']


                                                    class NhteTunnel(object):
                                                        """
                                                        NH TE tunnel information
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	Binding label for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_te_tunnel
                                                        
                                                        	NH TE Tunnel info is present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_info_stale
                                                        
                                                        	Tunnel is stale
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_registered
                                                        
                                                        	Tunnel registered flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_up
                                                        
                                                        	Tunnel Up flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: last_tunnel_update
                                                        
                                                        	Time since the last rib update happened
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_if_handle
                                                        
                                                        	Interface handle for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_name
                                                        
                                                        	tunnel name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        .. attribute:: tunnel_type
                                                        
                                                        	tunnel type
                                                        	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                        
                                                        .. attribute:: tunnel_v6_enabled
                                                        
                                                        	IPv6 enabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_v6_required
                                                        
                                                        	Tunnel need IPv6
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.binding_label = None
                                                            self.has_te_tunnel = None
                                                            self.is_tunnel_info_stale = None
                                                            self.is_tunnel_registered = None
                                                            self.is_tunnel_up = None
                                                            self.last_tunnel_update = None
                                                            self.tunnel_if_handle = None
                                                            self.tunnel_name = None
                                                            self.tunnel_type = None
                                                            self.tunnel_v6_enabled = None
                                                            self.tunnel_v6_required = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.binding_label is not None:
                                                                return True

                                                            if self.has_te_tunnel is not None:
                                                                return True

                                                            if self.is_tunnel_info_stale is not None:
                                                                return True

                                                            if self.is_tunnel_registered is not None:
                                                                return True

                                                            if self.is_tunnel_up is not None:
                                                                return True

                                                            if self.last_tunnel_update is not None:
                                                                return True

                                                            if self.tunnel_if_handle is not None:
                                                                return True

                                                            if self.tunnel_name is not None:
                                                                return True

                                                            if self.tunnel_type is not None:
                                                                return True

                                                            if self.tunnel_v6_enabled is not None:
                                                                return True

                                                            if self.tunnel_v6_required is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.NhteTunnel']['meta_info']


                                                    class PelemPathNeighborAddr(object):
                                                        """
                                                        Path neighbor address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-neighbor-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-path-element'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_perm_path_pelem is not None:
                                                            return True

                                                        if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                            return True

                                                        if self.pelem_flags is not None:
                                                            return True

                                                        if self.pelem_gw_metric is not None:
                                                            return True

                                                        if self.pelem_no_addpath_table_attr_version is not None:
                                                            return True

                                                        if self.pelem_no_bestpath_table_attr_version is not None:
                                                            return True

                                                        if self.pelem_path_flags is not None:
                                                            return True

                                                        if self.pelem_path_id is not None:
                                                            return True

                                                        if self.pelem_path_neighbor_addr is not None and self.pelem_path_neighbor_addr._has_data():
                                                            return True

                                                        if self.pelem_path_nexthop is not None and self.pelem_path_nexthop._has_data():
                                                            return True

                                                        if self.pelem_path_peer_path_id is not None:
                                                            return True

                                                        if self.pelem_path_table_attr_version is not None:
                                                            return True

                                                        if self.pelem_table_attr_version is not None:
                                                            return True

                                                        if self.pelem_version is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                                    if self.rd is None:
                                                        raise YPYModelError('Key property rd is None')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-lookup-rd[Cisco-IOS-XR-ipv4-bgp-oper:rd = ' + str(self.rd) + ']'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.rd is not None:
                                                        return True

                                                    if self.active_path_element is not None:
                                                        for child_ref in self.active_path_element:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.active_process_instance_path is not None:
                                                        for child_ref in self.active_process_instance_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.add_path_orr_bitfield is not None:
                                                        for child_ref in self.add_path_orr_bitfield:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.advertisedto_pe is not None:
                                                        return True

                                                    if self.af_name is not None:
                                                        return True

                                                    if self.best_path_orr_bitfield is not None:
                                                        for child_ref in self.best_path_orr_bitfield:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                        return True

                                                    if self.bit is not None:
                                                        return True

                                                    if self.flags is not None:
                                                        return True

                                                    if self.gateway_array is not None:
                                                        return True

                                                    if self.has_inconsistent_paths is not None:
                                                        return True

                                                    if self.has_lbl_retained is not None:
                                                        return True

                                                    if self.has_local_label is not None:
                                                        return True

                                                    if self.is_net_aggregation_suppressed is not None:
                                                        return True

                                                    if self.is_net_ldp_signaled is not None:
                                                        return True

                                                    if self.is_permanent_network is not None:
                                                        return True

                                                    if self.local_path_element is not None:
                                                        for child_ref in self.local_path_element:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_peers_advertised_to is not None:
                                                        for child_ref in self.local_peers_advertised_to:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_process_instance_path is not None:
                                                        for child_ref in self.local_process_instance_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.net_backup_available is not None:
                                                        return True

                                                    if self.net_backup_label_rewrite_available is not None:
                                                        return True

                                                    if self.net_eibgp_multipath is not None:
                                                        return True

                                                    if self.net_extended_flags is not None:
                                                        return True

                                                    if self.net_flags is not None:
                                                        return True

                                                    if self.net_local_label is not None:
                                                        return True

                                                    if self.net_local_label_rewrite is not None:
                                                        return True

                                                    if self.net_local_label_srgb is not None:
                                                        return True

                                                    if self.net_multipath is not None:
                                                        return True

                                                    if self.num_of_path is not None:
                                                        return True

                                                    if self.pe_peers_advertised_to is not None:
                                                        for child_ref in self.pe_peers_advertised_to:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.process_instance_id is not None:
                                                        return True

                                                    if self.resilient_nexthop_set is not None:
                                                        return True

                                                    if self.rib_failed is not None:
                                                        return True

                                                    if self.route_distinguisher is not None:
                                                        return True

                                                    if self.table_brib_version is not None:
                                                        return True

                                                    if self.table_version is not None:
                                                        return True

                                                    if self.version is not None:
                                                        return True

                                                    if self.version_age is not None and self.version_age._has_data():
                                                        return True

                                                    if self.version_timestamp is not None and self.version_timestamp._has_data():
                                                        return True

                                                    if self.vrf_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-lookup-rds'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.network_lookup_rd is not None:
                                                    for child_ref in self.network_lookup_rd:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')
                                            if self.network_prefix is None:
                                                raise YPYModelError('Key property network_prefix is None')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-lookup-all-rd[Cisco-IOS-XR-ipv4-bgp-oper:network-prefix = ' + str(self.network_prefix) + ']'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.network_prefix is not None:
                                                return True

                                            if self.network_lookup_rds is not None and self.network_lookup_rds._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-lookup-all-rds'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.network_lookup_all_rd is not None:
                                            for child_ref in self.network_lookup_all_rd:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds']['meta_info']


                                class Policies(object):
                                    """
                                    The BGP Policy Table
                                    
                                    .. attribute:: policy
                                    
                                    	A BGP Policy table entry
                                    	**type**\: list of    :py:class:`Policy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.policy = YList()
                                        self.policy.parent = self
                                        self.policy.name = 'policy'


                                    class Policy(object):
                                        """
                                        A BGP Policy table entry
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: attributes_after_policy_out
                                        
                                        	Attributes after outbound policy
                                        	**type**\:   :py:class:`AttributesAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut>`
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr>`
                                        
                                        .. attribute:: network
                                        
                                        	Network Prefix in Hex format
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists All 'sp\_path\_in' fields except 'sp\_path\_in\->bag\_prefix' are invalid.  All 'sp\_path\_out' fields are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_info_after_policy_in
                                        
                                        	Path information after inbound policy
                                        	**type**\:   :py:class:`PathInfoAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn>`
                                        
                                        .. attribute:: path_info_after_policy_out
                                        
                                        	Path information after outbound policy
                                        	**type**\:   :py:class:`PathInfoAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self.attributes_after_policy_out = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut()
                                            self.attributes_after_policy_out.parent = self
                                            self.neighbor_address = None
                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self.network = None
                                            self.no_path = None
                                            self.path_info_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn()
                                            self.path_info_after_policy_in.parent = self
                                            self.path_info_after_policy_out = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut()
                                            self.path_info_after_policy_out.parent = self
                                            self.prefix_length = None
                                            self.rd = None
                                            self.route_distinguisher = None
                                            self.source_route_distinguisher = None
                                            self.vrf_name = None


                                        class NeighborAddressXr(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr']['meta_info']


                                        class PathInfoAfterPolicyIn(object):
                                            """
                                            Path information after inbound policy
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_esi
                                            
                                            	Path has EVPN ESI
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_rcvd_label
                                            
                                            	Path has received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebg_ps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2VpnEvpnEsi>`
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop>`
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhteTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_p_ath = None
                                                self.add_path_orr_bitfield = YList()
                                                self.add_path_orr_bitfield.parent = self
                                                self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                self.advertisedto_pe = None
                                                self.aigp_metric = None
                                                self.best_path_comp_stage = None
                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self.best_path_id = None
                                                self.best_path_id_comp_winner = None
                                                self.best_path_orr_bitfield = YList()
                                                self.best_path_orr_bitfield.parent = self
                                                self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self.dampen_penalty = None
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.fspec_invalid_path = None
                                                self.graceful_shutdown = None
                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr()
                                                self.gw_addr.parent = self
                                                self.halflife_time = None
                                                self.has_esi = None
                                                self.has_gw_addr = None
                                                self.has_local_net_label = None
                                                self.has_mdt_group_addr = None
                                                self.has_mvpn_extcomm = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.has_rcvd_label = None
                                                self.has_second_label = None
                                                self.ibgp_signaled_validity = None
                                                self.igp_metric = None
                                                self.is_aggregation_suppressed = None
                                                self.is_as_best = None
                                                self.is_best_path = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_internal_path = None
                                                self.is_partial_best = None
                                                self.is_path_additional_path = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_af_install_eligible = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_damped = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_history_held = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_imported = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_multipath = None
                                                self.is_path_nexthop_discarded = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebg_ps = None
                                                self.is_path_received_only = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_stale = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_valid = None
                                                self.is_path_vpn_only = None
                                                self.is_permanent_path = None
                                                self.is_received_path_not_modified = None
                                                self.is_spkr_as_best = None
                                                self.l2vpn_circuit_status_value = YList()
                                                self.l2vpn_circuit_status_value.parent = self
                                                self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2VpnEvpnEsi()
                                                self.l2vpn_evpn_esi.parent = self
                                                self.l2vpn_size = None
                                                self.labeled_unicast_safi_path = None
                                                self.local_label = None
                                                self.local_nh = None
                                                self.local_path_id = None
                                                self.local_peers_advertised_to = YList()
                                                self.local_peers_advertised_to.parent = self
                                                self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                self.maximum_suppress_time = None
                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self.mvpn_path_flags = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_value = YList()
                                                self.mvpn_pmsi_value.parent = self
                                                self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                self.mvpn_sfs_path = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.neighbor_router_id = None
                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop()
                                                self.next_hop.parent = self
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.path_flags = None
                                                self.path_flap_count = None
                                                self.path_import_flags = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.path_table_version = None
                                                self.path_weight = None
                                                self.pe_peers_advertised_to = YList()
                                                self.pe_peers_advertised_to.parent = self
                                                self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                self.rcvd_label = None
                                                self.rcvd_path_id = None
                                                self.reuse_value = None
                                                self.rib_failed = None
                                                self.route_type = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.rt_set_limit_enabled = None
                                                self.second_label = None
                                                self.seconds_since_first_flap = None
                                                self.show_rpki_origin_as_validity = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.suppress_penalty = None
                                                self.time_to_unsuppress = None


                                            class BgpPrefix(object):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self.prefix_length = None


                                                class Prefix(object):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.prefix is not None and self.prefix._has_data():
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix']['meta_info']


                                            class NeighborAddress(object):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress']['meta_info']


                                            class NextHop(object):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhteTunnel']['meta_info']


                                            class MdtGroupAddr(object):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr']['meta_info']


                                            class L2VpnEvpnEsi(object):
                                                """
                                                L2VPN EVPN ESI
                                                
                                                .. attribute:: esi
                                                
                                                	esi
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.esi = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.esi is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2VpnEvpnEsi']['meta_info']


                                            class GwAddr(object):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr']['meta_info']


                                            class BestPathCompWinner(object):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner']['meta_info']


                                            class MvpnNbrAddr(object):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr']['meta_info']


                                            class MvpnNexthopAddr(object):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr']['meta_info']


                                            class L2VpnCircuitStatusValue(object):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue']['meta_info']


                                            class MvpnPmsiValue(object):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity']['meta_info']


                                            class LocalPeersAdvertisedTo(object):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo']['meta_info']


                                            class PePeersAdvertisedTo(object):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo']['meta_info']


                                            class BestPathOrrBitfield(object):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield']['meta_info']


                                            class AddPathOrrBitfield(object):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-info-after-policy-in'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.accept_own_path is not None:
                                                    return True

                                                if self.accept_own_self_originated_p_ath is not None:
                                                    return True

                                                if self.add_path_orr_bitfield is not None:
                                                    for child_ref in self.add_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.advertisedto_pe is not None:
                                                    return True

                                                if self.aigp_metric is not None:
                                                    return True

                                                if self.best_path_comp_stage is not None:
                                                    return True

                                                if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                    return True

                                                if self.best_path_id is not None:
                                                    return True

                                                if self.best_path_id_comp_winner is not None:
                                                    return True

                                                if self.best_path_orr_bitfield is not None:
                                                    for child_ref in self.best_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                    return True

                                                if self.dampen_penalty is not None:
                                                    return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.fspec_invalid_path is not None:
                                                    return True

                                                if self.graceful_shutdown is not None:
                                                    return True

                                                if self.gw_addr is not None and self.gw_addr._has_data():
                                                    return True

                                                if self.halflife_time is not None:
                                                    return True

                                                if self.has_esi is not None:
                                                    return True

                                                if self.has_gw_addr is not None:
                                                    return True

                                                if self.has_local_net_label is not None:
                                                    return True

                                                if self.has_mdt_group_addr is not None:
                                                    return True

                                                if self.has_mvpn_extcomm is not None:
                                                    return True

                                                if self.has_mvpn_nbr_addr is not None:
                                                    return True

                                                if self.has_mvpn_nexthop_addr is not None:
                                                    return True

                                                if self.has_mvpn_pmsi is not None:
                                                    return True

                                                if self.has_rcvd_label is not None:
                                                    return True

                                                if self.has_second_label is not None:
                                                    return True

                                                if self.ibgp_signaled_validity is not None:
                                                    return True

                                                if self.igp_metric is not None:
                                                    return True

                                                if self.is_aggregation_suppressed is not None:
                                                    return True

                                                if self.is_as_best is not None:
                                                    return True

                                                if self.is_best_path is not None:
                                                    return True

                                                if self.is_import_dampened is not None:
                                                    return True

                                                if self.is_import_suspect is not None:
                                                    return True

                                                if self.is_internal_path is not None:
                                                    return True

                                                if self.is_partial_best is not None:
                                                    return True

                                                if self.is_path_additional_path is not None:
                                                    return True

                                                if self.is_path_advertised_local_as_only is not None:
                                                    return True

                                                if self.is_path_af_install_eligible is not None:
                                                    return True

                                                if self.is_path_backup is not None:
                                                    return True

                                                if self.is_path_backup_protect_multipath is not None:
                                                    return True

                                                if self.is_path_best_external is not None:
                                                    return True

                                                if self.is_path_damped is not None:
                                                    return True

                                                if self.is_path_from_confederation_peer is not None:
                                                    return True

                                                if self.is_path_from_network_command is not None:
                                                    return True

                                                if self.is_path_from_redistribute_command is not None:
                                                    return True

                                                if self.is_path_from_route_reflector is not None:
                                                    return True

                                                if self.is_path_history_held is not None:
                                                    return True

                                                if self.is_path_imp_candidate is not None:
                                                    return True

                                                if self.is_path_imported is not None:
                                                    return True

                                                if self.is_path_local_aggregate is not None:
                                                    return True

                                                if self.is_path_locally_sourced is not None:
                                                    return True

                                                if self.is_path_long_lived_stale is not None:
                                                    return True

                                                if self.is_path_multipath is not None:
                                                    return True

                                                if self.is_path_nexthop_discarded is not None:
                                                    return True

                                                if self.is_path_not_advertised is not None:
                                                    return True

                                                if self.is_path_not_advertised_to_ebg_ps is not None:
                                                    return True

                                                if self.is_path_received_only is not None:
                                                    return True

                                                if self.is_path_reoriginated is not None:
                                                    return True

                                                if self.is_path_reoriginated_stitching is not None:
                                                    return True

                                                if self.is_path_stale is not None:
                                                    return True

                                                if self.is_path_synced_with_igp is not None:
                                                    return True

                                                if self.is_path_valid is not None:
                                                    return True

                                                if self.is_path_vpn_only is not None:
                                                    return True

                                                if self.is_permanent_path is not None:
                                                    return True

                                                if self.is_received_path_not_modified is not None:
                                                    return True

                                                if self.is_spkr_as_best is not None:
                                                    return True

                                                if self.l2vpn_circuit_status_value is not None:
                                                    for child_ref in self.l2vpn_circuit_status_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                    return True

                                                if self.l2vpn_size is not None:
                                                    return True

                                                if self.labeled_unicast_safi_path is not None:
                                                    return True

                                                if self.local_label is not None:
                                                    return True

                                                if self.local_nh is not None:
                                                    return True

                                                if self.local_path_id is not None:
                                                    return True

                                                if self.local_peers_advertised_to is not None:
                                                    for child_ref in self.local_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.maximum_suppress_time is not None:
                                                    return True

                                                if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                    return True

                                                if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                    return True

                                                if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                    return True

                                                if self.mvpn_path_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_label is not None:
                                                    return True

                                                if self.mvpn_pmsi_type is not None:
                                                    return True

                                                if self.mvpn_pmsi_value is not None:
                                                    for child_ref in self.mvpn_pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.mvpn_sfs_path is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.neighbor_router_id is not None:
                                                    return True

                                                if self.next_hop is not None and self.next_hop._has_data():
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.path_flags is not None:
                                                    return True

                                                if self.path_flap_count is not None:
                                                    return True

                                                if self.path_import_flags is not None:
                                                    return True

                                                if self.path_rt_set_id is not None:
                                                    return True

                                                if self.path_rt_set_route_count is not None:
                                                    return True

                                                if self.path_table_version is not None:
                                                    return True

                                                if self.path_weight is not None:
                                                    return True

                                                if self.pe_peers_advertised_to is not None:
                                                    for child_ref in self.pe_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.rcvd_label is not None:
                                                    return True

                                                if self.rcvd_path_id is not None:
                                                    return True

                                                if self.reuse_value is not None:
                                                    return True

                                                if self.rib_failed is not None:
                                                    return True

                                                if self.route_type is not None:
                                                    return True

                                                if self.rpki_origin_as_validation_disabled is not None:
                                                    return True

                                                if self.rt_set_limit_enabled is not None:
                                                    return True

                                                if self.second_label is not None:
                                                    return True

                                                if self.seconds_since_first_flap is not None:
                                                    return True

                                                if self.show_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.sn_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.suppress_penalty is not None:
                                                    return True

                                                if self.time_to_unsuppress is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn']['meta_info']


                                        class PathInfoAfterPolicyOut(object):
                                            """
                                            Path information after outbound policy
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_esi
                                            
                                            	Path has EVPN ESI
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_rcvd_label
                                            
                                            	Path has received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebg_ps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2VpnEvpnEsi>`
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop>`
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhteTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_p_ath = None
                                                self.add_path_orr_bitfield = YList()
                                                self.add_path_orr_bitfield.parent = self
                                                self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                self.advertisedto_pe = None
                                                self.aigp_metric = None
                                                self.best_path_comp_stage = None
                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self.best_path_id = None
                                                self.best_path_id_comp_winner = None
                                                self.best_path_orr_bitfield = YList()
                                                self.best_path_orr_bitfield.parent = self
                                                self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self.dampen_penalty = None
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.fspec_invalid_path = None
                                                self.graceful_shutdown = None
                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr()
                                                self.gw_addr.parent = self
                                                self.halflife_time = None
                                                self.has_esi = None
                                                self.has_gw_addr = None
                                                self.has_local_net_label = None
                                                self.has_mdt_group_addr = None
                                                self.has_mvpn_extcomm = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.has_rcvd_label = None
                                                self.has_second_label = None
                                                self.ibgp_signaled_validity = None
                                                self.igp_metric = None
                                                self.is_aggregation_suppressed = None
                                                self.is_as_best = None
                                                self.is_best_path = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_internal_path = None
                                                self.is_partial_best = None
                                                self.is_path_additional_path = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_af_install_eligible = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_damped = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_history_held = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_imported = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_multipath = None
                                                self.is_path_nexthop_discarded = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebg_ps = None
                                                self.is_path_received_only = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_stale = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_valid = None
                                                self.is_path_vpn_only = None
                                                self.is_permanent_path = None
                                                self.is_received_path_not_modified = None
                                                self.is_spkr_as_best = None
                                                self.l2vpn_circuit_status_value = YList()
                                                self.l2vpn_circuit_status_value.parent = self
                                                self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2VpnEvpnEsi()
                                                self.l2vpn_evpn_esi.parent = self
                                                self.l2vpn_size = None
                                                self.labeled_unicast_safi_path = None
                                                self.local_label = None
                                                self.local_nh = None
                                                self.local_path_id = None
                                                self.local_peers_advertised_to = YList()
                                                self.local_peers_advertised_to.parent = self
                                                self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                self.maximum_suppress_time = None
                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self.mvpn_path_flags = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_value = YList()
                                                self.mvpn_pmsi_value.parent = self
                                                self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                self.mvpn_sfs_path = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.neighbor_router_id = None
                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop()
                                                self.next_hop.parent = self
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.path_flags = None
                                                self.path_flap_count = None
                                                self.path_import_flags = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.path_table_version = None
                                                self.path_weight = None
                                                self.pe_peers_advertised_to = YList()
                                                self.pe_peers_advertised_to.parent = self
                                                self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                self.rcvd_label = None
                                                self.rcvd_path_id = None
                                                self.reuse_value = None
                                                self.rib_failed = None
                                                self.route_type = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.rt_set_limit_enabled = None
                                                self.second_label = None
                                                self.seconds_since_first_flap = None
                                                self.show_rpki_origin_as_validity = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.suppress_penalty = None
                                                self.time_to_unsuppress = None


                                            class BgpPrefix(object):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self.prefix_length = None


                                                class Prefix(object):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.prefix is not None and self.prefix._has_data():
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix']['meta_info']


                                            class NeighborAddress(object):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress']['meta_info']


                                            class NextHop(object):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhteTunnel']['meta_info']


                                            class MdtGroupAddr(object):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr']['meta_info']


                                            class L2VpnEvpnEsi(object):
                                                """
                                                L2VPN EVPN ESI
                                                
                                                .. attribute:: esi
                                                
                                                	esi
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.esi = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.esi is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2VpnEvpnEsi']['meta_info']


                                            class GwAddr(object):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr']['meta_info']


                                            class BestPathCompWinner(object):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner']['meta_info']


                                            class MvpnNbrAddr(object):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr']['meta_info']


                                            class MvpnNexthopAddr(object):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr']['meta_info']


                                            class L2VpnCircuitStatusValue(object):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue']['meta_info']


                                            class MvpnPmsiValue(object):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity']['meta_info']


                                            class LocalPeersAdvertisedTo(object):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo']['meta_info']


                                            class PePeersAdvertisedTo(object):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo']['meta_info']


                                            class BestPathOrrBitfield(object):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield']['meta_info']


                                            class AddPathOrrBitfield(object):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-info-after-policy-out'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.accept_own_path is not None:
                                                    return True

                                                if self.accept_own_self_originated_p_ath is not None:
                                                    return True

                                                if self.add_path_orr_bitfield is not None:
                                                    for child_ref in self.add_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.advertisedto_pe is not None:
                                                    return True

                                                if self.aigp_metric is not None:
                                                    return True

                                                if self.best_path_comp_stage is not None:
                                                    return True

                                                if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                    return True

                                                if self.best_path_id is not None:
                                                    return True

                                                if self.best_path_id_comp_winner is not None:
                                                    return True

                                                if self.best_path_orr_bitfield is not None:
                                                    for child_ref in self.best_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                    return True

                                                if self.dampen_penalty is not None:
                                                    return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.fspec_invalid_path is not None:
                                                    return True

                                                if self.graceful_shutdown is not None:
                                                    return True

                                                if self.gw_addr is not None and self.gw_addr._has_data():
                                                    return True

                                                if self.halflife_time is not None:
                                                    return True

                                                if self.has_esi is not None:
                                                    return True

                                                if self.has_gw_addr is not None:
                                                    return True

                                                if self.has_local_net_label is not None:
                                                    return True

                                                if self.has_mdt_group_addr is not None:
                                                    return True

                                                if self.has_mvpn_extcomm is not None:
                                                    return True

                                                if self.has_mvpn_nbr_addr is not None:
                                                    return True

                                                if self.has_mvpn_nexthop_addr is not None:
                                                    return True

                                                if self.has_mvpn_pmsi is not None:
                                                    return True

                                                if self.has_rcvd_label is not None:
                                                    return True

                                                if self.has_second_label is not None:
                                                    return True

                                                if self.ibgp_signaled_validity is not None:
                                                    return True

                                                if self.igp_metric is not None:
                                                    return True

                                                if self.is_aggregation_suppressed is not None:
                                                    return True

                                                if self.is_as_best is not None:
                                                    return True

                                                if self.is_best_path is not None:
                                                    return True

                                                if self.is_import_dampened is not None:
                                                    return True

                                                if self.is_import_suspect is not None:
                                                    return True

                                                if self.is_internal_path is not None:
                                                    return True

                                                if self.is_partial_best is not None:
                                                    return True

                                                if self.is_path_additional_path is not None:
                                                    return True

                                                if self.is_path_advertised_local_as_only is not None:
                                                    return True

                                                if self.is_path_af_install_eligible is not None:
                                                    return True

                                                if self.is_path_backup is not None:
                                                    return True

                                                if self.is_path_backup_protect_multipath is not None:
                                                    return True

                                                if self.is_path_best_external is not None:
                                                    return True

                                                if self.is_path_damped is not None:
                                                    return True

                                                if self.is_path_from_confederation_peer is not None:
                                                    return True

                                                if self.is_path_from_network_command is not None:
                                                    return True

                                                if self.is_path_from_redistribute_command is not None:
                                                    return True

                                                if self.is_path_from_route_reflector is not None:
                                                    return True

                                                if self.is_path_history_held is not None:
                                                    return True

                                                if self.is_path_imp_candidate is not None:
                                                    return True

                                                if self.is_path_imported is not None:
                                                    return True

                                                if self.is_path_local_aggregate is not None:
                                                    return True

                                                if self.is_path_locally_sourced is not None:
                                                    return True

                                                if self.is_path_long_lived_stale is not None:
                                                    return True

                                                if self.is_path_multipath is not None:
                                                    return True

                                                if self.is_path_nexthop_discarded is not None:
                                                    return True

                                                if self.is_path_not_advertised is not None:
                                                    return True

                                                if self.is_path_not_advertised_to_ebg_ps is not None:
                                                    return True

                                                if self.is_path_received_only is not None:
                                                    return True

                                                if self.is_path_reoriginated is not None:
                                                    return True

                                                if self.is_path_reoriginated_stitching is not None:
                                                    return True

                                                if self.is_path_stale is not None:
                                                    return True

                                                if self.is_path_synced_with_igp is not None:
                                                    return True

                                                if self.is_path_valid is not None:
                                                    return True

                                                if self.is_path_vpn_only is not None:
                                                    return True

                                                if self.is_permanent_path is not None:
                                                    return True

                                                if self.is_received_path_not_modified is not None:
                                                    return True

                                                if self.is_spkr_as_best is not None:
                                                    return True

                                                if self.l2vpn_circuit_status_value is not None:
                                                    for child_ref in self.l2vpn_circuit_status_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                    return True

                                                if self.l2vpn_size is not None:
                                                    return True

                                                if self.labeled_unicast_safi_path is not None:
                                                    return True

                                                if self.local_label is not None:
                                                    return True

                                                if self.local_nh is not None:
                                                    return True

                                                if self.local_path_id is not None:
                                                    return True

                                                if self.local_peers_advertised_to is not None:
                                                    for child_ref in self.local_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.maximum_suppress_time is not None:
                                                    return True

                                                if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                    return True

                                                if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                    return True

                                                if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                    return True

                                                if self.mvpn_path_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_label is not None:
                                                    return True

                                                if self.mvpn_pmsi_type is not None:
                                                    return True

                                                if self.mvpn_pmsi_value is not None:
                                                    for child_ref in self.mvpn_pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.mvpn_sfs_path is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.neighbor_router_id is not None:
                                                    return True

                                                if self.next_hop is not None and self.next_hop._has_data():
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.path_flags is not None:
                                                    return True

                                                if self.path_flap_count is not None:
                                                    return True

                                                if self.path_import_flags is not None:
                                                    return True

                                                if self.path_rt_set_id is not None:
                                                    return True

                                                if self.path_rt_set_route_count is not None:
                                                    return True

                                                if self.path_table_version is not None:
                                                    return True

                                                if self.path_weight is not None:
                                                    return True

                                                if self.pe_peers_advertised_to is not None:
                                                    for child_ref in self.pe_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.rcvd_label is not None:
                                                    return True

                                                if self.rcvd_path_id is not None:
                                                    return True

                                                if self.reuse_value is not None:
                                                    return True

                                                if self.rib_failed is not None:
                                                    return True

                                                if self.route_type is not None:
                                                    return True

                                                if self.rpki_origin_as_validation_disabled is not None:
                                                    return True

                                                if self.rt_set_limit_enabled is not None:
                                                    return True

                                                if self.second_label is not None:
                                                    return True

                                                if self.seconds_since_first_flap is not None:
                                                    return True

                                                if self.show_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.sn_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.suppress_penalty is not None:
                                                    return True

                                                if self.time_to_unsuppress is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut']['meta_info']


                                        class AttributesAfterPolicyIn(object):
                                            """
                                            Attributes after inbound policy
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self.is_application_gateway_present = None
                                                self.is_as_path2_byte = None
                                                self.is_attr_set_present = None
                                                self.is_ribrnh_present = None
                                                self.is_rnh_present = None
                                                self.ribrnh_encap = None
                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self.ribrnh_mac = None
                                                self.ribrnh_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnhip_table = None
                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self.rnh_addr_len = None
                                                self.rnh_len = None
                                                self.rnh_type = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.vpn_distinguisher = None


                                            class CommonAttributes(object):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                            class AttrSet(object):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                            class RnhAddr(object):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None
                                                    self.mac_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    if self.mac_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                            class RibrnhIp(object):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.attr_set is not None and self.attr_set._has_data():
                                                    return True

                                                if self.attribute_key_number is not None:
                                                    return True

                                                if self.attribute_reuse_id_config is not None:
                                                    return True

                                                if self.attribute_reuse_id_current is not None:
                                                    return True

                                                if self.attribute_reuse_id_keys is not None:
                                                    return True

                                                if self.attribute_reuse_id_max_id is not None:
                                                    return True

                                                if self.attribute_reuse_id_node is not None:
                                                    return True

                                                if self.attribute_reuse_id_recover_sec is not None:
                                                    return True

                                                if self.common_attributes is not None and self.common_attributes._has_data():
                                                    return True

                                                if self.is_application_gateway_present is not None:
                                                    return True

                                                if self.is_as_path2_byte is not None:
                                                    return True

                                                if self.is_attr_set_present is not None:
                                                    return True

                                                if self.is_ribrnh_present is not None:
                                                    return True

                                                if self.is_rnh_present is not None:
                                                    return True

                                                if self.ribrnh_encap is not None:
                                                    return True

                                                if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                    return True

                                                if self.ribrnh_mac is not None:
                                                    return True

                                                if self.ribrnh_table is not None:
                                                    return True

                                                if self.ribrnh_vni is not None:
                                                    return True

                                                if self.ribrnhip_table is not None:
                                                    return True

                                                if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                    return True

                                                if self.rnh_addr_len is not None:
                                                    return True

                                                if self.rnh_len is not None:
                                                    return True

                                                if self.rnh_type is not None:
                                                    return True

                                                if self.set_aigp_inbound_igp is not None:
                                                    return True

                                                if self.set_aigp_inbound_metric is not None:
                                                    return True

                                                if self.vpn_distinguisher is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn']['meta_info']


                                        class AttributesAfterPolicyOut(object):
                                            """
                                            Attributes after outbound policy
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet()
                                                self.attr_set.parent = self
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self.is_application_gateway_present = None
                                                self.is_as_path2_byte = None
                                                self.is_attr_set_present = None
                                                self.is_ribrnh_present = None
                                                self.is_rnh_present = None
                                                self.ribrnh_encap = None
                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self.ribrnh_mac = None
                                                self.ribrnh_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnhip_table = None
                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self.rnh_addr_len = None
                                                self.rnh_len = None
                                                self.rnh_type = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.vpn_distinguisher = None


                                            class CommonAttributes(object):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes']['meta_info']


                                            class AttrSet(object):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet']['meta_info']


                                            class RnhAddr(object):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None
                                                    self.mac_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    if self.mac_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr']['meta_info']


                                            class RibrnhIp(object):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-out'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.attr_set is not None and self.attr_set._has_data():
                                                    return True

                                                if self.attribute_key_number is not None:
                                                    return True

                                                if self.attribute_reuse_id_config is not None:
                                                    return True

                                                if self.attribute_reuse_id_current is not None:
                                                    return True

                                                if self.attribute_reuse_id_keys is not None:
                                                    return True

                                                if self.attribute_reuse_id_max_id is not None:
                                                    return True

                                                if self.attribute_reuse_id_node is not None:
                                                    return True

                                                if self.attribute_reuse_id_recover_sec is not None:
                                                    return True

                                                if self.common_attributes is not None and self.common_attributes._has_data():
                                                    return True

                                                if self.is_application_gateway_present is not None:
                                                    return True

                                                if self.is_as_path2_byte is not None:
                                                    return True

                                                if self.is_attr_set_present is not None:
                                                    return True

                                                if self.is_ribrnh_present is not None:
                                                    return True

                                                if self.is_rnh_present is not None:
                                                    return True

                                                if self.ribrnh_encap is not None:
                                                    return True

                                                if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                    return True

                                                if self.ribrnh_mac is not None:
                                                    return True

                                                if self.ribrnh_table is not None:
                                                    return True

                                                if self.ribrnh_vni is not None:
                                                    return True

                                                if self.ribrnhip_table is not None:
                                                    return True

                                                if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                    return True

                                                if self.rnh_addr_len is not None:
                                                    return True

                                                if self.rnh_len is not None:
                                                    return True

                                                if self.rnh_type is not None:
                                                    return True

                                                if self.set_aigp_inbound_igp is not None:
                                                    return True

                                                if self.set_aigp_inbound_metric is not None:
                                                    return True

                                                if self.vpn_distinguisher is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:policy'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                return True

                                            if self.attributes_after_policy_out is not None and self.attributes_after_policy_out._has_data():
                                                return True

                                            if self.neighbor_address is not None:
                                                return True

                                            if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                return True

                                            if self.network is not None:
                                                return True

                                            if self.no_path is not None:
                                                return True

                                            if self.path_info_after_policy_in is not None and self.path_info_after_policy_in._has_data():
                                                return True

                                            if self.path_info_after_policy_out is not None and self.path_info_after_policy_out._has_data():
                                                return True

                                            if self.prefix_length is not None:
                                                return True

                                            if self.rd is not None:
                                                return True

                                            if self.route_distinguisher is not None:
                                                return True

                                            if self.source_route_distinguisher is not None:
                                                return True

                                            if self.vrf_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:policies'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.policy is not None:
                                            for child_ref in self.policy:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies']['meta_info']


                                class Convergence(object):
                                    """
                                    A BGP Convergence table entry
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: are_write_queues_empty
                                    
                                    	All neighbor write queues are empty
                                    	**type**\:  bool
                                    
                                    .. attribute:: has_converged
                                    
                                    	Convergence has been reached
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.are_write_queues_empty = None
                                        self.has_converged = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:convergence'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.are_write_queues_empty is not None:
                                            return True

                                        if self.has_converged is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Convergence']['meta_info']


                                class AfProcessInfo(object):
                                    """
                                    A BGP Process address family table entry
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family id
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: global_
                                    
                                    	Global information
                                    	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_>`
                                    
                                    .. attribute:: performance_statistics
                                    
                                    	Performance statistics
                                    	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics>`
                                    
                                    .. attribute:: process_instance
                                    
                                    	ID for the BGP process instance
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:   :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Vrf_>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    .. attribute:: vrf_totals
                                    
                                    	per VRF information aggregated across all VRFs
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.global_ = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_()
                                        self.global_.parent = self
                                        self.performance_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics()
                                        self.performance_statistics.parent = self
                                        self.process_instance = None
                                        self.vrf = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Vrf_()
                                        self.vrf.parent = self
                                        self.vrf_name = None
                                        self.vrf_totals = None


                                    class Global_(object):
                                        """
                                        Global information
                                        
                                        .. attribute:: freed_rd_count
                                        
                                        	Activity\: Number of RDs freed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_bgp_version
                                        
                                        	BGP version when Import thread is last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_last_trigger
                                        
                                        	Timestamp when Import thread is last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: import_triggers
                                        
                                        	Import thread triggers
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_version
                                        
                                        	Version updated by import thread
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: imported_paths_memory
                                        
                                        	Total imported paths memory
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: imported_paths_num
                                        
                                        	Total impoorted paths 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_bgp_version
                                        
                                        	BGP version when label thread is last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_last_trigger
                                        
                                        	Timestamp when Label thread is last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: label_triggers
                                        
                                        	Label thread triggers
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_version
                                        
                                        	Version updated by label thread
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_import_version
                                        
                                        	Import thread version when last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_label_version
                                        
                                        	Label thread version when last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_rib_version
                                        
                                        	RIB thread version when last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_networks_freed_num
                                        
                                        	Total local networks freed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_networks_malloced_num
                                        
                                        	Total local networks malloced
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_networks_memory
                                        
                                        	Total local networks memory
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_networks_num
                                        
                                        	Total local networks
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_paths_freed_num
                                        
                                        	Total local paths freed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_paths_malloced_num
                                        
                                        	Total local paths malloced
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_paths_memory
                                        
                                        	Total local paths memory
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_paths_num
                                        
                                        	Total local paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: malloced_rd_count
                                        
                                        	Activity\: Number of RDs malloced
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: max_active_pelem_version
                                        
                                        	Maximum Active Pelem Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: merged_table_version
                                        
                                        	Merged Table Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multipath_network_entry_count
                                        
                                        	Number of multipath network entries
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multipath_network_entry_memory
                                        
                                        	Memory (in bytes) used bymultipath network entries
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: multipath_paths_count
                                        
                                        	Number of multipath paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multipath_paths_memory
                                        
                                        	Memory (in bytes) used bymultimpath paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: networks_freed_num
                                        
                                        	Total networks freed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: networks_malloced_num
                                        
                                        	Total networks malloced
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: networks_memory
                                        
                                        	Total networks memory
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: networks_num
                                        
                                        	Total Num of networks
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_init_sync_pfx
                                        
                                        	Num of prefix synced during Initsync
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_elems_freed_num
                                        
                                        	Total path\-elems freed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_elems_malloced_num
                                        
                                        	Total path\-elems malloced
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_elems_memory
                                        
                                        	Total path\-elems memory
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_elems_num
                                        
                                        	Total Num of path\-elems
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: paths_freed_num
                                        
                                        	Total paths freed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: paths_malloced_num
                                        
                                        	Total paths malloced
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: paths_memory
                                        
                                        	Total paths memory
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: paths_num
                                        
                                        	Total Num of paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rd_memory
                                        
                                        	Memory (in bytes) used by RD data
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rib_ack_requests
                                        
                                        	Counter for RIB ack requests
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_acked_table_version
                                        
                                        	Table version acked by RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_acks_received
                                        
                                        	Counter for RIB ack received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_brib_received_version
                                        
                                        	Version received from 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_install
                                        
                                        	RIB install info
                                        	**type**\:   :py:class:`RibInstall <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall>`
                                        
                                        .. attribute:: rib_last_trigger
                                        
                                        	Timestamp when RIB thread is last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: rib_slow_acks
                                        
                                        	Counter for slow RIB acks
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_triggers
                                        
                                        	RIB thread triggers
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribbgp_version
                                        
                                        	BGP version when RIB thread is last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_download_go_active_done_pending
                                        
                                        	Route Download Go Active Done Pending
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: router_state
                                        
                                        	Router state
                                        	**type**\:   :py:class:`BgpRtrStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRtrStateEnum>`
                                        
                                        .. attribute:: send_version
                                        
                                        	Version for sending updates to peers
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: standby_version
                                        
                                        	Version updated by sync thread
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: table_brib_version
                                        
                                        	Version sent to RIB/bRIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: table_version
                                        
                                        	BGP table version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_r_ds_num
                                        
                                        	Total Num of RDs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_remote_r_ds_num
                                        
                                        	Total Num of remote RDs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_same_r_ds_num
                                        
                                        	Total Num of same RDs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: trigger_import
                                        
                                        	Trigger import
                                        	**type**\:   :py:class:`TriggerImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport>`
                                        
                                        .. attribute:: trigger_label
                                        
                                        	Trigger label
                                        	**type**\:   :py:class:`TriggerLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel>`
                                        
                                        .. attribute:: trigger_rib
                                        
                                        	Trigger RIB
                                        	**type**\:   :py:class:`TriggerRib <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib>`
                                        
                                        .. attribute:: trigger_update
                                        
                                        	Trigger update
                                        	**type**\:   :py:class:`TriggerUpdate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate>`
                                        
                                        .. attribute:: update_gen_bgp_version
                                        
                                        	BGP version when Update generation thread is last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_gen_last_trigger
                                        
                                        	Timestamp when Update generation thread is last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_triggers
                                        
                                        	Update thread triggers
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_wait_install_enabled
                                        
                                        	Update wait\-install enabled
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version_wrap_done_time_spec
                                        
                                        	Version Wrap handle Done timestamp
                                        	**type**\:   :py:class:`VersionWrapDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapDoneTimeSpec>`
                                        
                                        .. attribute:: version_wrap_start_time_spec
                                        
                                        	Version Wrap handle start timestamp
                                        	**type**\:   :py:class:`VersionWrapStartTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapStartTimeSpec>`
                                        
                                        .. attribute:: version_wrap_time_spec
                                        
                                        	Version Wrap timestamp
                                        	**type**\:   :py:class:`VersionWrapTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapTimeSpec>`
                                        
                                        .. attribute:: version_wrapped
                                        
                                        	Number of times Version Wrap happened
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version_wrapped_tid
                                        
                                        	Version Wrapped trigger tid
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.freed_rd_count = None
                                            self.import_bgp_version = None
                                            self.import_last_trigger = None
                                            self.import_triggers = None
                                            self.import_version = None
                                            self.imported_paths_memory = None
                                            self.imported_paths_num = None
                                            self.label_bgp_version = None
                                            self.label_last_trigger = None
                                            self.label_triggers = None
                                            self.label_version = None
                                            self.last_import_version = None
                                            self.last_label_version = None
                                            self.last_rib_version = None
                                            self.local_networks_freed_num = None
                                            self.local_networks_malloced_num = None
                                            self.local_networks_memory = None
                                            self.local_networks_num = None
                                            self.local_paths_freed_num = None
                                            self.local_paths_malloced_num = None
                                            self.local_paths_memory = None
                                            self.local_paths_num = None
                                            self.malloced_rd_count = None
                                            self.max_active_pelem_version = None
                                            self.merged_table_version = None
                                            self.multipath_network_entry_count = None
                                            self.multipath_network_entry_memory = None
                                            self.multipath_paths_count = None
                                            self.multipath_paths_memory = None
                                            self.networks_freed_num = None
                                            self.networks_malloced_num = None
                                            self.networks_memory = None
                                            self.networks_num = None
                                            self.num_init_sync_pfx = None
                                            self.path_elems_freed_num = None
                                            self.path_elems_malloced_num = None
                                            self.path_elems_memory = None
                                            self.path_elems_num = None
                                            self.paths_freed_num = None
                                            self.paths_malloced_num = None
                                            self.paths_memory = None
                                            self.paths_num = None
                                            self.rd_memory = None
                                            self.rib_ack_requests = None
                                            self.rib_acked_table_version = None
                                            self.rib_acks_received = None
                                            self.rib_brib_received_version = None
                                            self.rib_install = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall()
                                            self.rib_install.parent = self
                                            self.rib_last_trigger = None
                                            self.rib_slow_acks = None
                                            self.rib_triggers = None
                                            self.ribbgp_version = None
                                            self.route_download_go_active_done_pending = None
                                            self.router_state = None
                                            self.send_version = None
                                            self.standby_version = None
                                            self.table_brib_version = None
                                            self.table_version = None
                                            self.total_r_ds_num = None
                                            self.total_remote_r_ds_num = None
                                            self.total_same_r_ds_num = None
                                            self.trigger_import = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport()
                                            self.trigger_import.parent = self
                                            self.trigger_label = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel()
                                            self.trigger_label.parent = self
                                            self.trigger_rib = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib()
                                            self.trigger_rib.parent = self
                                            self.trigger_update = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate()
                                            self.trigger_update.parent = self
                                            self.update_gen_bgp_version = None
                                            self.update_gen_last_trigger = None
                                            self.update_triggers = None
                                            self.update_wait_install_enabled = None
                                            self.version_wrap_done_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapDoneTimeSpec()
                                            self.version_wrap_done_time_spec.parent = self
                                            self.version_wrap_start_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapStartTimeSpec()
                                            self.version_wrap_start_time_spec.parent = self
                                            self.version_wrap_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapTimeSpec()
                                            self.version_wrap_time_spec.parent = self
                                            self.version_wrapped = None
                                            self.version_wrapped_tid = None


                                        class VersionWrapTimeSpec(object):
                                            """
                                            Version Wrap timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-wrap-time-spec'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapTimeSpec']['meta_info']


                                        class VersionWrapStartTimeSpec(object):
                                            """
                                            Version Wrap handle start timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-wrap-start-time-spec'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapStartTimeSpec']['meta_info']


                                        class VersionWrapDoneTimeSpec(object):
                                            """
                                            Version Wrap handle Done timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-wrap-done-time-spec'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapDoneTimeSpec']['meta_info']


                                        class TriggerRib(object):
                                            """
                                            Trigger RIB
                                            
                                            .. attribute:: statistic
                                            
                                            	statistic
                                            	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic>`
                                            
                                            .. attribute:: triggers
                                            
                                            	Triggers
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.statistic = YList()
                                                self.statistic.parent = self
                                                self.statistic.name = 'statistic'
                                                self.triggers = None


                                            class Statistic(object):
                                                """
                                                statistic
                                                
                                                .. attribute:: trigger_table_version
                                                
                                                	TriggerTableVersion
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: trigger_time_spec
                                                
                                                	trigger time spec
                                                	**type**\:   :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic.TriggerTimeSpec>`
                                                
                                                .. attribute:: trigger_version
                                                
                                                	TriggerVersion
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.trigger_table_version = None
                                                    self.trigger_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic.TriggerTimeSpec()
                                                    self.trigger_time_spec.parent = self
                                                    self.trigger_version = None


                                                class TriggerTimeSpec(object):
                                                    """
                                                    trigger time spec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:trigger-time-spec'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic.TriggerTimeSpec']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:statistic'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.trigger_table_version is not None:
                                                        return True

                                                    if self.trigger_time_spec is not None and self.trigger_time_spec._has_data():
                                                        return True

                                                    if self.trigger_version is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:trigger-rib'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.statistic is not None:
                                                    for child_ref in self.statistic:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.triggers is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib']['meta_info']


                                        class TriggerImport(object):
                                            """
                                            Trigger import
                                            
                                            .. attribute:: statistic
                                            
                                            	statistic
                                            	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic>`
                                            
                                            .. attribute:: triggers
                                            
                                            	Triggers
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.statistic = YList()
                                                self.statistic.parent = self
                                                self.statistic.name = 'statistic'
                                                self.triggers = None


                                            class Statistic(object):
                                                """
                                                statistic
                                                
                                                .. attribute:: trigger_table_version
                                                
                                                	TriggerTableVersion
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: trigger_time_spec
                                                
                                                	trigger time spec
                                                	**type**\:   :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic.TriggerTimeSpec>`
                                                
                                                .. attribute:: trigger_version
                                                
                                                	TriggerVersion
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.trigger_table_version = None
                                                    self.trigger_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic.TriggerTimeSpec()
                                                    self.trigger_time_spec.parent = self
                                                    self.trigger_version = None


                                                class TriggerTimeSpec(object):
                                                    """
                                                    trigger time spec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:trigger-time-spec'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic.TriggerTimeSpec']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:statistic'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.trigger_table_version is not None:
                                                        return True

                                                    if self.trigger_time_spec is not None and self.trigger_time_spec._has_data():
                                                        return True

                                                    if self.trigger_version is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:trigger-import'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.statistic is not None:
                                                    for child_ref in self.statistic:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.triggers is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport']['meta_info']


                                        class TriggerUpdate(object):
                                            """
                                            Trigger update
                                            
                                            .. attribute:: statistic
                                            
                                            	statistic
                                            	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic>`
                                            
                                            .. attribute:: triggers
                                            
                                            	Triggers
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.statistic = YList()
                                                self.statistic.parent = self
                                                self.statistic.name = 'statistic'
                                                self.triggers = None


                                            class Statistic(object):
                                                """
                                                statistic
                                                
                                                .. attribute:: trigger_table_version
                                                
                                                	TriggerTableVersion
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: trigger_time_spec
                                                
                                                	trigger time spec
                                                	**type**\:   :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic.TriggerTimeSpec>`
                                                
                                                .. attribute:: trigger_version
                                                
                                                	TriggerVersion
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.trigger_table_version = None
                                                    self.trigger_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic.TriggerTimeSpec()
                                                    self.trigger_time_spec.parent = self
                                                    self.trigger_version = None


                                                class TriggerTimeSpec(object):
                                                    """
                                                    trigger time spec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:trigger-time-spec'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic.TriggerTimeSpec']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:statistic'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.trigger_table_version is not None:
                                                        return True

                                                    if self.trigger_time_spec is not None and self.trigger_time_spec._has_data():
                                                        return True

                                                    if self.trigger_version is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:trigger-update'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.statistic is not None:
                                                    for child_ref in self.statistic:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.triggers is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate']['meta_info']


                                        class TriggerLabel(object):
                                            """
                                            Trigger label
                                            
                                            .. attribute:: statistic
                                            
                                            	statistic
                                            	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic>`
                                            
                                            .. attribute:: triggers
                                            
                                            	Triggers
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.statistic = YList()
                                                self.statistic.parent = self
                                                self.statistic.name = 'statistic'
                                                self.triggers = None


                                            class Statistic(object):
                                                """
                                                statistic
                                                
                                                .. attribute:: trigger_table_version
                                                
                                                	TriggerTableVersion
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: trigger_time_spec
                                                
                                                	trigger time spec
                                                	**type**\:   :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic.TriggerTimeSpec>`
                                                
                                                .. attribute:: trigger_version
                                                
                                                	TriggerVersion
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.trigger_table_version = None
                                                    self.trigger_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic.TriggerTimeSpec()
                                                    self.trigger_time_spec.parent = self
                                                    self.trigger_version = None


                                                class TriggerTimeSpec(object):
                                                    """
                                                    trigger time spec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:trigger-time-spec'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic.TriggerTimeSpec']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:statistic'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.trigger_table_version is not None:
                                                        return True

                                                    if self.trigger_time_spec is not None and self.trigger_time_spec._has_data():
                                                        return True

                                                    if self.trigger_version is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:trigger-label'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.statistic is not None:
                                                    for child_ref in self.statistic:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.triggers is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel']['meta_info']


                                        class RibInstall(object):
                                            """
                                            RIB install info
                                            
                                            .. attribute:: install_time
                                            
                                            	RIB install time
                                            	**type**\:   :py:class:`InstallTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall.InstallTime>`
                                            
                                            .. attribute:: installed_count
                                            
                                            	Installed routes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: modified_count
                                            
                                            	Modified routes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: start_version
                                            
                                            	Start version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: target_version
                                            
                                            	Target version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_time
                                            
                                            	RIB update time
                                            	**type**\:   :py:class:`UpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall.UpdateTime>`
                                            
                                            .. attribute:: withdrawn_count
                                            
                                            	Withdrawn routes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.install_time = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall.InstallTime()
                                                self.install_time.parent = self
                                                self.installed_count = None
                                                self.modified_count = None
                                                self.start_version = None
                                                self.target_version = None
                                                self.update_time = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall.UpdateTime()
                                                self.update_time.parent = self
                                                self.withdrawn_count = None


                                            class UpdateTime(object):
                                                """
                                                RIB update time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-time'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall.UpdateTime']['meta_info']


                                            class InstallTime(object):
                                                """
                                                RIB install time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:install-time'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall.InstallTime']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rib-install'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.install_time is not None and self.install_time._has_data():
                                                    return True

                                                if self.installed_count is not None:
                                                    return True

                                                if self.modified_count is not None:
                                                    return True

                                                if self.start_version is not None:
                                                    return True

                                                if self.target_version is not None:
                                                    return True

                                                if self.update_time is not None and self.update_time._has_data():
                                                    return True

                                                if self.withdrawn_count is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:global'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.freed_rd_count is not None:
                                                return True

                                            if self.import_bgp_version is not None:
                                                return True

                                            if self.import_last_trigger is not None:
                                                return True

                                            if self.import_triggers is not None:
                                                return True

                                            if self.import_version is not None:
                                                return True

                                            if self.imported_paths_memory is not None:
                                                return True

                                            if self.imported_paths_num is not None:
                                                return True

                                            if self.label_bgp_version is not None:
                                                return True

                                            if self.label_last_trigger is not None:
                                                return True

                                            if self.label_triggers is not None:
                                                return True

                                            if self.label_version is not None:
                                                return True

                                            if self.last_import_version is not None:
                                                return True

                                            if self.last_label_version is not None:
                                                return True

                                            if self.last_rib_version is not None:
                                                return True

                                            if self.local_networks_freed_num is not None:
                                                return True

                                            if self.local_networks_malloced_num is not None:
                                                return True

                                            if self.local_networks_memory is not None:
                                                return True

                                            if self.local_networks_num is not None:
                                                return True

                                            if self.local_paths_freed_num is not None:
                                                return True

                                            if self.local_paths_malloced_num is not None:
                                                return True

                                            if self.local_paths_memory is not None:
                                                return True

                                            if self.local_paths_num is not None:
                                                return True

                                            if self.malloced_rd_count is not None:
                                                return True

                                            if self.max_active_pelem_version is not None:
                                                return True

                                            if self.merged_table_version is not None:
                                                return True

                                            if self.multipath_network_entry_count is not None:
                                                return True

                                            if self.multipath_network_entry_memory is not None:
                                                return True

                                            if self.multipath_paths_count is not None:
                                                return True

                                            if self.multipath_paths_memory is not None:
                                                return True

                                            if self.networks_freed_num is not None:
                                                return True

                                            if self.networks_malloced_num is not None:
                                                return True

                                            if self.networks_memory is not None:
                                                return True

                                            if self.networks_num is not None:
                                                return True

                                            if self.num_init_sync_pfx is not None:
                                                return True

                                            if self.path_elems_freed_num is not None:
                                                return True

                                            if self.path_elems_malloced_num is not None:
                                                return True

                                            if self.path_elems_memory is not None:
                                                return True

                                            if self.path_elems_num is not None:
                                                return True

                                            if self.paths_freed_num is not None:
                                                return True

                                            if self.paths_malloced_num is not None:
                                                return True

                                            if self.paths_memory is not None:
                                                return True

                                            if self.paths_num is not None:
                                                return True

                                            if self.rd_memory is not None:
                                                return True

                                            if self.rib_ack_requests is not None:
                                                return True

                                            if self.rib_acked_table_version is not None:
                                                return True

                                            if self.rib_acks_received is not None:
                                                return True

                                            if self.rib_brib_received_version is not None:
                                                return True

                                            if self.rib_install is not None and self.rib_install._has_data():
                                                return True

                                            if self.rib_last_trigger is not None:
                                                return True

                                            if self.rib_slow_acks is not None:
                                                return True

                                            if self.rib_triggers is not None:
                                                return True

                                            if self.ribbgp_version is not None:
                                                return True

                                            if self.route_download_go_active_done_pending is not None:
                                                return True

                                            if self.router_state is not None:
                                                return True

                                            if self.send_version is not None:
                                                return True

                                            if self.standby_version is not None:
                                                return True

                                            if self.table_brib_version is not None:
                                                return True

                                            if self.table_version is not None:
                                                return True

                                            if self.total_r_ds_num is not None:
                                                return True

                                            if self.total_remote_r_ds_num is not None:
                                                return True

                                            if self.total_same_r_ds_num is not None:
                                                return True

                                            if self.trigger_import is not None and self.trigger_import._has_data():
                                                return True

                                            if self.trigger_label is not None and self.trigger_label._has_data():
                                                return True

                                            if self.trigger_rib is not None and self.trigger_rib._has_data():
                                                return True

                                            if self.trigger_update is not None and self.trigger_update._has_data():
                                                return True

                                            if self.update_gen_bgp_version is not None:
                                                return True

                                            if self.update_gen_last_trigger is not None:
                                                return True

                                            if self.update_triggers is not None:
                                                return True

                                            if self.update_wait_install_enabled is not None:
                                                return True

                                            if self.version_wrap_done_time_spec is not None and self.version_wrap_done_time_spec._has_data():
                                                return True

                                            if self.version_wrap_start_time_spec is not None and self.version_wrap_start_time_spec._has_data():
                                                return True

                                            if self.version_wrap_time_spec is not None and self.version_wrap_time_spec._has_data():
                                                return True

                                            if self.version_wrapped is not None:
                                                return True

                                            if self.version_wrapped_tid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_']['meta_info']


                                    class Vrf_(object):
                                        """
                                        VRF information
                                        
                                        .. attribute:: add_path_install_disable
                                        
                                        	Additional paths installation is disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: add_path_install_enable
                                        
                                        	Additional paths installation is enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: any_ebgp_neighbor_missing_policy
                                        
                                        	Is there any neighbor which is missing either inbound or outbound or both routing policy for this address family?
                                        	**type**\:  bool
                                        
                                        .. attribute:: asbr
                                        
                                        	Router is an ASBR for this AF
                                        	**type**\:  bool
                                        
                                        .. attribute:: attribute_download
                                        
                                        	Attribute download is 
                                        	**type**\:  bool
                                        
                                        .. attribute:: best_external
                                        
                                        	Best External is enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: best_external_disable
                                        
                                        	Best External is enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: bmp_network_entry_count
                                        
                                        	Number of BMP net entries
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_path_memory
                                        
                                        	Memory (in bytes) used by path data
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bmp_paths_count
                                        
                                        	Total Number of BMP paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_prefix_memory
                                        
                                        	Memory (in bytes) used by prefix data
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: damped_path_count
                                        
                                        	Number of dampened paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: freed_path_count
                                        
                                        	Activity\: Number of paths freed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: freed_path_elem_count
                                        
                                        	Activity\: Number of pathelems freed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: freed_prefix_count
                                        
                                        	Activity\: Number of prefixes freed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: history_path_count
                                        
                                        	Number of history paths (for dampening)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ibgp_nexthop_self_count
                                        
                                        	Number of iBGP sessions configured with nh\-self
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: imported_path_memory
                                        
                                        	Memory (in bytes) used by imported paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: imported_paths
                                        
                                        	Number of imported paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_route_reflector
                                        
                                        	Router is an RR for this AF
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_retain
                                        
                                        	Label retention is enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_retainvalue
                                        
                                        	Label retention value enabled
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_path_memory
                                        
                                        	Memory (in bytes) used by local paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: local_paths
                                        
                                        	Number of local paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: malloced_path_count
                                        
                                        	Activity\: Number of paths malloced
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: malloced_path_elem_count
                                        
                                        	Activity\: Number of path elems malloced
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: malloced_prefix_count
                                        
                                        	Activity\: Number of prefixes malloced
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: network_entry_count
                                        
                                        	Number of network entries
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_elem_memory
                                        
                                        	Memory (in bytes) used by pathelem data
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: path_elems_count
                                        
                                        	Number of path elems
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_memory
                                        
                                        	Memory (in bytes) used by path data
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: paths_count
                                        
                                        	Number of paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefix_memory
                                        
                                        	Memory (in bytes) used by prefix data
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: received_path_count
                                        
                                        	Number of (unused) received paths for inbound soft reconfiguration
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: retain_rt_all
                                        
                                        	Retain\-RT\-All enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_target_download
                                        
                                        	Route Target download is enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: tbl_bitf_size
                                        
                                        	Bitfield size on table
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: tbl_chunk_bitf_size
                                        
                                        	Chunk Bitfield size on table
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: use_igpsr_label
                                        
                                        	Use IGP SR label for resolution
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.add_path_install_disable = None
                                            self.add_path_install_enable = None
                                            self.any_ebgp_neighbor_missing_policy = None
                                            self.asbr = None
                                            self.attribute_download = None
                                            self.best_external = None
                                            self.best_external_disable = None
                                            self.bmp_network_entry_count = None
                                            self.bmp_path_memory = None
                                            self.bmp_paths_count = None
                                            self.bmp_prefix_memory = None
                                            self.damped_path_count = None
                                            self.freed_path_count = None
                                            self.freed_path_elem_count = None
                                            self.freed_prefix_count = None
                                            self.history_path_count = None
                                            self.ibgp_nexthop_self_count = None
                                            self.imported_path_memory = None
                                            self.imported_paths = None
                                            self.is_route_reflector = None
                                            self.label_retain = None
                                            self.label_retainvalue = None
                                            self.local_path_memory = None
                                            self.local_paths = None
                                            self.malloced_path_count = None
                                            self.malloced_path_elem_count = None
                                            self.malloced_prefix_count = None
                                            self.network_entry_count = None
                                            self.path_elem_memory = None
                                            self.path_elems_count = None
                                            self.path_memory = None
                                            self.paths_count = None
                                            self.prefix_memory = None
                                            self.received_path_count = None
                                            self.retain_rt_all = None
                                            self.route_target_download = None
                                            self.tbl_bitf_size = None
                                            self.tbl_chunk_bitf_size = None
                                            self.use_igpsr_label = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:vrf'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.add_path_install_disable is not None:
                                                return True

                                            if self.add_path_install_enable is not None:
                                                return True

                                            if self.any_ebgp_neighbor_missing_policy is not None:
                                                return True

                                            if self.asbr is not None:
                                                return True

                                            if self.attribute_download is not None:
                                                return True

                                            if self.best_external is not None:
                                                return True

                                            if self.best_external_disable is not None:
                                                return True

                                            if self.bmp_network_entry_count is not None:
                                                return True

                                            if self.bmp_path_memory is not None:
                                                return True

                                            if self.bmp_paths_count is not None:
                                                return True

                                            if self.bmp_prefix_memory is not None:
                                                return True

                                            if self.damped_path_count is not None:
                                                return True

                                            if self.freed_path_count is not None:
                                                return True

                                            if self.freed_path_elem_count is not None:
                                                return True

                                            if self.freed_prefix_count is not None:
                                                return True

                                            if self.history_path_count is not None:
                                                return True

                                            if self.ibgp_nexthop_self_count is not None:
                                                return True

                                            if self.imported_path_memory is not None:
                                                return True

                                            if self.imported_paths is not None:
                                                return True

                                            if self.is_route_reflector is not None:
                                                return True

                                            if self.label_retain is not None:
                                                return True

                                            if self.label_retainvalue is not None:
                                                return True

                                            if self.local_path_memory is not None:
                                                return True

                                            if self.local_paths is not None:
                                                return True

                                            if self.malloced_path_count is not None:
                                                return True

                                            if self.malloced_path_elem_count is not None:
                                                return True

                                            if self.malloced_prefix_count is not None:
                                                return True

                                            if self.network_entry_count is not None:
                                                return True

                                            if self.path_elem_memory is not None:
                                                return True

                                            if self.path_elems_count is not None:
                                                return True

                                            if self.path_memory is not None:
                                                return True

                                            if self.paths_count is not None:
                                                return True

                                            if self.prefix_memory is not None:
                                                return True

                                            if self.received_path_count is not None:
                                                return True

                                            if self.retain_rt_all is not None:
                                                return True

                                            if self.route_target_download is not None:
                                                return True

                                            if self.tbl_bitf_size is not None:
                                                return True

                                            if self.tbl_chunk_bitf_size is not None:
                                                return True

                                            if self.use_igpsr_label is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Vrf_']['meta_info']


                                    class PerformanceStatistics(object):
                                        """
                                        Performance statistics
                                        
                                        .. attribute:: global_
                                        
                                        	Global information
                                        	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_>`
                                        
                                        .. attribute:: vrf
                                        
                                        	VRF information
                                        	**type**\:   :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.global_ = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_()
                                            self.global_.parent = self
                                            self.vrf = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_()
                                            self.vrf.parent = self


                                        class Global_(object):
                                            """
                                            Global information
                                            
                                            .. attribute:: first_nbr_up_time
                                            
                                            	Time when first peer came up (seconds since Jan 1 1970)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: has_converged
                                            
                                            	TRUE if process has converged
                                            	**type**\:  bool
                                            
                                            .. attribute:: mode_enter_time
                                            
                                            	Time that each mode was entered (seconds since  Jan 1 1970)
                                            	**type**\: list of    :py:class:`ModeEnterTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.ModeEnterTime>`
                                            
                                            .. attribute:: total_pim_callback_add
                                            
                                            	Total number of Pim callbacks for add
                                            	**type**\: list of    :py:class:`TotalPimCallbackAdd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAdd>`
                                            
                                            .. attribute:: total_pim_callback_add_local
                                            
                                            	Total number of Pim callbacks for local add
                                            	**type**\: list of    :py:class:`TotalPimCallbackAddLocal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAddLocal>`
                                            
                                            .. attribute:: total_pim_callback_batch
                                            
                                            	Total number of Pim callback batches
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: total_pim_callback_del
                                            
                                            	Total number of Pim callbacks for del
                                            	**type**\: list of    :py:class:`TotalPimCallbackDel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDel>`
                                            
                                            .. attribute:: total_pim_callback_del_local
                                            
                                            	Total number of Pim callbacks for Local del
                                            	**type**\: list of    :py:class:`TotalPimCallbackDelLocal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDelLocal>`
                                            
                                            .. attribute:: total_pim_callbacks
                                            
                                            	Total number of PIM callbacks
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: total_pim_install
                                            
                                            	Total number of install to PIM
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: total_pim_install_add
                                            
                                            	Total number of install to PIM for add
                                            	**type**\: list of    :py:class:`TotalPimInstallAdd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallAdd>`
                                            
                                            .. attribute:: total_pim_install_del
                                            
                                            	Total number of install to PIM for del
                                            	**type**\: list of    :py:class:`TotalPimInstallDel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallDel>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.first_nbr_up_time = None
                                                self.has_converged = None
                                                self.mode_enter_time = YList()
                                                self.mode_enter_time.parent = self
                                                self.mode_enter_time.name = 'mode_enter_time'
                                                self.total_pim_callback_add = YList()
                                                self.total_pim_callback_add.parent = self
                                                self.total_pim_callback_add.name = 'total_pim_callback_add'
                                                self.total_pim_callback_add_local = YList()
                                                self.total_pim_callback_add_local.parent = self
                                                self.total_pim_callback_add_local.name = 'total_pim_callback_add_local'
                                                self.total_pim_callback_batch = None
                                                self.total_pim_callback_del = YList()
                                                self.total_pim_callback_del.parent = self
                                                self.total_pim_callback_del.name = 'total_pim_callback_del'
                                                self.total_pim_callback_del_local = YList()
                                                self.total_pim_callback_del_local.parent = self
                                                self.total_pim_callback_del_local.name = 'total_pim_callback_del_local'
                                                self.total_pim_callbacks = None
                                                self.total_pim_install = None
                                                self.total_pim_install_add = YList()
                                                self.total_pim_install_add.parent = self
                                                self.total_pim_install_add.name = 'total_pim_install_add'
                                                self.total_pim_install_del = YList()
                                                self.total_pim_install_del.parent = self
                                                self.total_pim_install_del.name = 'total_pim_install_del'


                                            class ModeEnterTime(object):
                                                """
                                                Time that each mode was entered (seconds since
                                                
                                                Jan 1 1970)
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mode-enter-time'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.ModeEnterTime']['meta_info']


                                            class TotalPimInstallAdd(object):
                                                """
                                                Total number of install to PIM for add
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:total-pim-install-add'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallAdd']['meta_info']


                                            class TotalPimInstallDel(object):
                                                """
                                                Total number of install to PIM for del
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:total-pim-install-del'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallDel']['meta_info']


                                            class TotalPimCallbackAdd(object):
                                                """
                                                Total number of Pim callbacks for add
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:total-pim-callback-add'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAdd']['meta_info']


                                            class TotalPimCallbackDel(object):
                                                """
                                                Total number of Pim callbacks for del
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:total-pim-callback-del'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDel']['meta_info']


                                            class TotalPimCallbackAddLocal(object):
                                                """
                                                Total number of Pim callbacks for local add
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:total-pim-callback-add-local'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAddLocal']['meta_info']


                                            class TotalPimCallbackDelLocal(object):
                                                """
                                                Total number of Pim callbacks for Local del
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:total-pim-callback-del-local'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDelLocal']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:global'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.first_nbr_up_time is not None:
                                                    return True

                                                if self.has_converged is not None:
                                                    return True

                                                if self.mode_enter_time is not None:
                                                    for child_ref in self.mode_enter_time:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.total_pim_callback_add is not None:
                                                    for child_ref in self.total_pim_callback_add:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.total_pim_callback_add_local is not None:
                                                    for child_ref in self.total_pim_callback_add_local:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.total_pim_callback_batch is not None:
                                                    return True

                                                if self.total_pim_callback_del is not None:
                                                    for child_ref in self.total_pim_callback_del:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.total_pim_callback_del_local is not None:
                                                    for child_ref in self.total_pim_callback_del_local:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.total_pim_callbacks is not None:
                                                    return True

                                                if self.total_pim_install is not None:
                                                    return True

                                                if self.total_pim_install_add is not None:
                                                    for child_ref in self.total_pim_install_add:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.total_pim_install_del is not None:
                                                    for child_ref in self.total_pim_install_del:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_']['meta_info']


                                        class Vrf_(object):
                                            """
                                            VRF information
                                            
                                            .. attribute:: attributes_recover_from_rib
                                            
                                            	No. of attributes recovered from RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attributes_removed_from_rib
                                            
                                            	No. of attributes withdrawn from RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attributes_sent_to_rib
                                            
                                            	No. of attributes sent to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: first_rib_table_full_timestamp
                                            
                                            	Timestamp when RIB table was full for the first time
                                            	**type**\:   :py:class:`FirstRibTableFullTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.FirstRibTableFullTimestamp>`
                                            
                                            .. attribute:: first_rib_table_full_version
                                            
                                            	Version when RIB table was full for the first time
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: first_rib_table_has_space_timestamp
                                            
                                            	Timestamp when RIB table had space for the first time
                                            	**type**\:   :py:class:`FirstRibTableHasSpaceTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.FirstRibTableHasSpaceTimestamp>`
                                            
                                            .. attribute:: first_rib_table_has_space_version
                                            
                                            	Version when RIB table had space for the first time
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_added_path_count
                                            
                                            	Number of imported paths added
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_calls
                                            
                                            	Number of calls to import processing function
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_dest_net_processed_count
                                            
                                            	Number of destination nets processed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_removed_path_count
                                            
                                            	Number of imported paths removed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_replaced_path_count
                                            
                                            	Number of imported paths 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_src_net_processed_count
                                            
                                            	Number of source nets processed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_time
                                            
                                            	Time spent in import processing (milliseconds) Note time accounted against source nets
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: is_rib_table_full
                                            
                                            	Indicates if RIB table is in prefix\-limit state
                                            	**type**\:  bool
                                            
                                            .. attribute:: label_added_count
                                            
                                            	Number of labels requested
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_calls
                                            
                                            	No. of calls to label allocation processing function
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_release_count
                                            
                                            	Number of labels released
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_rewrite_count
                                            
                                            	Number of label rewrites created
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_time
                                            
                                            	Time spent running label processing (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: last_rib_table_full_age
                                            
                                            	Time since RIB table was full for the last time (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_rib_table_full_timestamp
                                            
                                            	Timestamp when RIB table was full for the last time
                                            	**type**\:   :py:class:`LastRibTableFullTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.LastRibTableFullTimestamp>`
                                            
                                            .. attribute:: last_rib_table_full_version
                                            
                                            	Version when RIB table was full for the last time
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_rib_table_has_space_age
                                            
                                            	Times since RIB table had space for the last time (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_rib_table_has_space_timestamp
                                            
                                            	Timestamp when RIB table had space for the last time
                                            	**type**\:   :py:class:`LastRibTableHasSpaceTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.LastRibTableHasSpaceTimestamp>`
                                            
                                            .. attribute:: last_rib_table_has_space_version
                                            
                                            	Version when RIB table had space for the last time
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_removed_from_rib
                                            
                                            	No. of prefixes withdrawn from RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_resent_to_rib
                                            
                                            	No. of prefixes re\-sent to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_sent_to_rib
                                            
                                            	No. of prefixes sent to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_table_full_version
                                            
                                            	Version when RIB table became full (from non\-full)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_tbl_del_calls
                                            
                                            	No. of rib update skipped on account of table delete
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_tbl_invalid_calls
                                            
                                            	No. of  rib update skipped due to table invalid
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_tbl_local_label
                                            
                                            	No. of rib update skipped. due to no local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_tbl_retry
                                            
                                            	No. of table rib retires
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_tbl_skip_calls
                                            
                                            	No. of rib update skipped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_trigger
                                            
                                            	Rib trigger enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rib_update_calls
                                            
                                            	No. of calls to RIB update function
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_update_time
                                            
                                            	Time spent sending RIB updates (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: scanner_runs
                                            
                                            	# of times scanner has run
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: scanner_time
                                            
                                            	Time spent running scanner (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: subgroup_count
                                            
                                            	No. of update subgroup
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_label_retain
                                            
                                            	Time last label retentiontriggered 
                                            	**type**\:   :py:class:`TimeLabelRetain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeLabelRetain>`
                                            
                                            .. attribute:: time_last_update_sent
                                            
                                            	Time last update was sent (seconds since Jan 1 1970)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: time_rib_coverged
                                            
                                            	Time last RIB ack was sent 
                                            	**type**\:   :py:class:`TimeRibCoverged <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeRibCoverged>`
                                            
                                            .. attribute:: time_rib_down
                                            
                                            	Time last RIB down wassent. This field is deprecated
                                            	**type**\:   :py:class:`TimeRibDown <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeRibDown>`
                                            
                                            .. attribute:: update_generation_be_prefixes_count
                                            
                                            	No. of be prefixes updates generated for
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_calls
                                            
                                            	No. of calls to update generation function
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_messages_count
                                            
                                            	No. of update messages generated
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_prefixes_count
                                            
                                            	No. of prefixes updates generated for
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_time
                                            
                                            	Time spent generating updates (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: update_group_count
                                            
                                            	No. of update group
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vrf_flags
                                            
                                            	VRF flags for debug display
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.attributes_recover_from_rib = None
                                                self.attributes_removed_from_rib = None
                                                self.attributes_sent_to_rib = None
                                                self.first_rib_table_full_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.FirstRibTableFullTimestamp()
                                                self.first_rib_table_full_timestamp.parent = self
                                                self.first_rib_table_full_version = None
                                                self.first_rib_table_has_space_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.FirstRibTableHasSpaceTimestamp()
                                                self.first_rib_table_has_space_timestamp.parent = self
                                                self.first_rib_table_has_space_version = None
                                                self.import_added_path_count = None
                                                self.import_calls = None
                                                self.import_dest_net_processed_count = None
                                                self.import_removed_path_count = None
                                                self.import_replaced_path_count = None
                                                self.import_src_net_processed_count = None
                                                self.import_time = None
                                                self.is_rib_table_full = None
                                                self.label_added_count = None
                                                self.label_calls = None
                                                self.label_release_count = None
                                                self.label_rewrite_count = None
                                                self.label_time = None
                                                self.last_rib_table_full_age = None
                                                self.last_rib_table_full_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.LastRibTableFullTimestamp()
                                                self.last_rib_table_full_timestamp.parent = self
                                                self.last_rib_table_full_version = None
                                                self.last_rib_table_has_space_age = None
                                                self.last_rib_table_has_space_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.LastRibTableHasSpaceTimestamp()
                                                self.last_rib_table_has_space_timestamp.parent = self
                                                self.last_rib_table_has_space_version = None
                                                self.prefixes_removed_from_rib = None
                                                self.prefixes_resent_to_rib = None
                                                self.prefixes_sent_to_rib = None
                                                self.rib_table_full_version = None
                                                self.rib_tbl_del_calls = None
                                                self.rib_tbl_invalid_calls = None
                                                self.rib_tbl_local_label = None
                                                self.rib_tbl_retry = None
                                                self.rib_tbl_skip_calls = None
                                                self.rib_trigger = None
                                                self.rib_update_calls = None
                                                self.rib_update_time = None
                                                self.scanner_runs = None
                                                self.scanner_time = None
                                                self.subgroup_count = None
                                                self.time_label_retain = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeLabelRetain()
                                                self.time_label_retain.parent = self
                                                self.time_last_update_sent = None
                                                self.time_rib_coverged = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeRibCoverged()
                                                self.time_rib_coverged.parent = self
                                                self.time_rib_down = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeRibDown()
                                                self.time_rib_down.parent = self
                                                self.update_generation_be_prefixes_count = None
                                                self.update_generation_calls = None
                                                self.update_generation_messages_count = None
                                                self.update_generation_prefixes_count = None
                                                self.update_generation_time = None
                                                self.update_group_count = None
                                                self.vrf_flags = None


                                            class TimeRibCoverged(object):
                                                """
                                                Time last RIB ack was sent 
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:time-rib-coverged'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeRibCoverged']['meta_info']


                                            class TimeRibDown(object):
                                                """
                                                Time last RIB down wassent. This field is
                                                deprecated
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:time-rib-down'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeRibDown']['meta_info']


                                            class FirstRibTableFullTimestamp(object):
                                                """
                                                Timestamp when RIB table was full for the first
                                                time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-rib-table-full-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.FirstRibTableFullTimestamp']['meta_info']


                                            class LastRibTableFullTimestamp(object):
                                                """
                                                Timestamp when RIB table was full for the last
                                                time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-rib-table-full-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.LastRibTableFullTimestamp']['meta_info']


                                            class FirstRibTableHasSpaceTimestamp(object):
                                                """
                                                Timestamp when RIB table had space for the first
                                                time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-rib-table-has-space-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.FirstRibTableHasSpaceTimestamp']['meta_info']


                                            class LastRibTableHasSpaceTimestamp(object):
                                                """
                                                Timestamp when RIB table had space for the last
                                                time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-rib-table-has-space-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.LastRibTableHasSpaceTimestamp']['meta_info']


                                            class TimeLabelRetain(object):
                                                """
                                                Time last label retentiontriggered 
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:time-label-retain'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeLabelRetain']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:vrf'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.attributes_recover_from_rib is not None:
                                                    return True

                                                if self.attributes_removed_from_rib is not None:
                                                    return True

                                                if self.attributes_sent_to_rib is not None:
                                                    return True

                                                if self.first_rib_table_full_timestamp is not None and self.first_rib_table_full_timestamp._has_data():
                                                    return True

                                                if self.first_rib_table_full_version is not None:
                                                    return True

                                                if self.first_rib_table_has_space_timestamp is not None and self.first_rib_table_has_space_timestamp._has_data():
                                                    return True

                                                if self.first_rib_table_has_space_version is not None:
                                                    return True

                                                if self.import_added_path_count is not None:
                                                    return True

                                                if self.import_calls is not None:
                                                    return True

                                                if self.import_dest_net_processed_count is not None:
                                                    return True

                                                if self.import_removed_path_count is not None:
                                                    return True

                                                if self.import_replaced_path_count is not None:
                                                    return True

                                                if self.import_src_net_processed_count is not None:
                                                    return True

                                                if self.import_time is not None:
                                                    return True

                                                if self.is_rib_table_full is not None:
                                                    return True

                                                if self.label_added_count is not None:
                                                    return True

                                                if self.label_calls is not None:
                                                    return True

                                                if self.label_release_count is not None:
                                                    return True

                                                if self.label_rewrite_count is not None:
                                                    return True

                                                if self.label_time is not None:
                                                    return True

                                                if self.last_rib_table_full_age is not None:
                                                    return True

                                                if self.last_rib_table_full_timestamp is not None and self.last_rib_table_full_timestamp._has_data():
                                                    return True

                                                if self.last_rib_table_full_version is not None:
                                                    return True

                                                if self.last_rib_table_has_space_age is not None:
                                                    return True

                                                if self.last_rib_table_has_space_timestamp is not None and self.last_rib_table_has_space_timestamp._has_data():
                                                    return True

                                                if self.last_rib_table_has_space_version is not None:
                                                    return True

                                                if self.prefixes_removed_from_rib is not None:
                                                    return True

                                                if self.prefixes_resent_to_rib is not None:
                                                    return True

                                                if self.prefixes_sent_to_rib is not None:
                                                    return True

                                                if self.rib_table_full_version is not None:
                                                    return True

                                                if self.rib_tbl_del_calls is not None:
                                                    return True

                                                if self.rib_tbl_invalid_calls is not None:
                                                    return True

                                                if self.rib_tbl_local_label is not None:
                                                    return True

                                                if self.rib_tbl_retry is not None:
                                                    return True

                                                if self.rib_tbl_skip_calls is not None:
                                                    return True

                                                if self.rib_trigger is not None:
                                                    return True

                                                if self.rib_update_calls is not None:
                                                    return True

                                                if self.rib_update_time is not None:
                                                    return True

                                                if self.scanner_runs is not None:
                                                    return True

                                                if self.scanner_time is not None:
                                                    return True

                                                if self.subgroup_count is not None:
                                                    return True

                                                if self.time_label_retain is not None and self.time_label_retain._has_data():
                                                    return True

                                                if self.time_last_update_sent is not None:
                                                    return True

                                                if self.time_rib_coverged is not None and self.time_rib_coverged._has_data():
                                                    return True

                                                if self.time_rib_down is not None and self.time_rib_down._has_data():
                                                    return True

                                                if self.update_generation_be_prefixes_count is not None:
                                                    return True

                                                if self.update_generation_calls is not None:
                                                    return True

                                                if self.update_generation_messages_count is not None:
                                                    return True

                                                if self.update_generation_prefixes_count is not None:
                                                    return True

                                                if self.update_generation_time is not None:
                                                    return True

                                                if self.update_group_count is not None:
                                                    return True

                                                if self.vrf_flags is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:performance-statistics'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.global_ is not None and self.global_._has_data():
                                                return True

                                            if self.vrf is not None and self.vrf._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af-process-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.global_ is not None and self.global_._has_data():
                                            return True

                                        if self.performance_statistics is not None and self.performance_statistics._has_data():
                                            return True

                                        if self.process_instance is not None:
                                            return True

                                        if self.vrf is not None and self.vrf._has_data():
                                            return True

                                        if self.vrf_name is not None:
                                            return True

                                        if self.vrf_totals is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo']['meta_info']


                                class PathUsedTable(object):
                                    """
                                    The BGP Path Used Table
                                    
                                    .. attribute:: path
                                    
                                    	A BGP path table entry
                                    	**type**\: list of    :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.path = YList()
                                        self.path.parent = self
                                        self.path.name = 'path'


                                    class Path(object):
                                        """
                                        A BGP path table entry
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor adddress
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr>`
                                        
                                        .. attribute:: network
                                        
                                        	Network Prefix in Hex format
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_id
                                        
                                        	Received Path ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type
                                        	**type**\:   :py:class:`BgpRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRouteEnum>`
                                        
                                        .. attribute:: source_rd
                                        
                                        	Source Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self.label_fail = None
                                            self.label_o_or_version = None
                                            self.label_oor = None
                                            self.neighbor_address = None
                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self.network = None
                                            self.no_path = None
                                            self.path_id = None
                                            self.path_information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation()
                                            self.path_information.parent = self
                                            self.prefix_length = None
                                            self.prefix_version = None
                                            self.process_instance_id = None
                                            self.rd = None
                                            self.route_distinguisher = None
                                            self.route_type = None
                                            self.source_rd = None
                                            self.source_route_distinguisher = None
                                            self.source_vrf_name = None
                                            self.srcaf_name = None
                                            self.vrf_name = None


                                        class NeighborAddressXr(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr']['meta_info']


                                        class PathInformation(object):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_esi
                                            
                                            	Path has EVPN ESI
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_rcvd_label
                                            
                                            	Path has received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebg_ps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.L2VpnEvpnEsi>`
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop>`
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhteTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_p_ath = None
                                                self.add_path_orr_bitfield = YList()
                                                self.add_path_orr_bitfield.parent = self
                                                self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                self.advertisedto_pe = None
                                                self.aigp_metric = None
                                                self.best_path_comp_stage = None
                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self.best_path_id = None
                                                self.best_path_id_comp_winner = None
                                                self.best_path_orr_bitfield = YList()
                                                self.best_path_orr_bitfield.parent = self
                                                self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self.dampen_penalty = None
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.fspec_invalid_path = None
                                                self.graceful_shutdown = None
                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self.halflife_time = None
                                                self.has_esi = None
                                                self.has_gw_addr = None
                                                self.has_local_net_label = None
                                                self.has_mdt_group_addr = None
                                                self.has_mvpn_extcomm = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.has_rcvd_label = None
                                                self.has_second_label = None
                                                self.ibgp_signaled_validity = None
                                                self.igp_metric = None
                                                self.is_aggregation_suppressed = None
                                                self.is_as_best = None
                                                self.is_best_path = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_internal_path = None
                                                self.is_partial_best = None
                                                self.is_path_additional_path = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_af_install_eligible = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_damped = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_history_held = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_imported = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_multipath = None
                                                self.is_path_nexthop_discarded = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebg_ps = None
                                                self.is_path_received_only = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_stale = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_valid = None
                                                self.is_path_vpn_only = None
                                                self.is_permanent_path = None
                                                self.is_received_path_not_modified = None
                                                self.is_spkr_as_best = None
                                                self.l2vpn_circuit_status_value = YList()
                                                self.l2vpn_circuit_status_value.parent = self
                                                self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.L2VpnEvpnEsi()
                                                self.l2vpn_evpn_esi.parent = self
                                                self.l2vpn_size = None
                                                self.labeled_unicast_safi_path = None
                                                self.local_label = None
                                                self.local_nh = None
                                                self.local_path_id = None
                                                self.local_peers_advertised_to = YList()
                                                self.local_peers_advertised_to.parent = self
                                                self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                self.maximum_suppress_time = None
                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self.mvpn_path_flags = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_value = YList()
                                                self.mvpn_pmsi_value.parent = self
                                                self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                self.mvpn_sfs_path = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.neighbor_router_id = None
                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.path_flags = None
                                                self.path_flap_count = None
                                                self.path_import_flags = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.path_table_version = None
                                                self.path_weight = None
                                                self.pe_peers_advertised_to = YList()
                                                self.pe_peers_advertised_to.parent = self
                                                self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                self.rcvd_label = None
                                                self.rcvd_path_id = None
                                                self.reuse_value = None
                                                self.rib_failed = None
                                                self.route_type = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.rt_set_limit_enabled = None
                                                self.second_label = None
                                                self.seconds_since_first_flap = None
                                                self.show_rpki_origin_as_validity = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.suppress_penalty = None
                                                self.time_to_unsuppress = None


                                            class BgpPrefix(object):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self.prefix_length = None


                                                class Prefix(object):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.prefix is not None and self.prefix._has_data():
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix']['meta_info']


                                            class NeighborAddress(object):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress']['meta_info']


                                            class NextHop(object):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhteTunnel']['meta_info']


                                            class MdtGroupAddr(object):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr']['meta_info']


                                            class L2VpnEvpnEsi(object):
                                                """
                                                L2VPN EVPN ESI
                                                
                                                .. attribute:: esi
                                                
                                                	esi
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.esi = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.esi is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.L2VpnEvpnEsi']['meta_info']


                                            class GwAddr(object):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr']['meta_info']


                                            class BestPathCompWinner(object):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner']['meta_info']


                                            class MvpnNbrAddr(object):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr']['meta_info']


                                            class MvpnNexthopAddr(object):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr']['meta_info']


                                            class L2VpnCircuitStatusValue(object):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                            class MvpnPmsiValue(object):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity']['meta_info']


                                            class LocalPeersAdvertisedTo(object):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                            class PePeersAdvertisedTo(object):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo']['meta_info']


                                            class BestPathOrrBitfield(object):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield']['meta_info']


                                            class AddPathOrrBitfield(object):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.accept_own_path is not None:
                                                    return True

                                                if self.accept_own_self_originated_p_ath is not None:
                                                    return True

                                                if self.add_path_orr_bitfield is not None:
                                                    for child_ref in self.add_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.advertisedto_pe is not None:
                                                    return True

                                                if self.aigp_metric is not None:
                                                    return True

                                                if self.best_path_comp_stage is not None:
                                                    return True

                                                if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                    return True

                                                if self.best_path_id is not None:
                                                    return True

                                                if self.best_path_id_comp_winner is not None:
                                                    return True

                                                if self.best_path_orr_bitfield is not None:
                                                    for child_ref in self.best_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                    return True

                                                if self.dampen_penalty is not None:
                                                    return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.fspec_invalid_path is not None:
                                                    return True

                                                if self.graceful_shutdown is not None:
                                                    return True

                                                if self.gw_addr is not None and self.gw_addr._has_data():
                                                    return True

                                                if self.halflife_time is not None:
                                                    return True

                                                if self.has_esi is not None:
                                                    return True

                                                if self.has_gw_addr is not None:
                                                    return True

                                                if self.has_local_net_label is not None:
                                                    return True

                                                if self.has_mdt_group_addr is not None:
                                                    return True

                                                if self.has_mvpn_extcomm is not None:
                                                    return True

                                                if self.has_mvpn_nbr_addr is not None:
                                                    return True

                                                if self.has_mvpn_nexthop_addr is not None:
                                                    return True

                                                if self.has_mvpn_pmsi is not None:
                                                    return True

                                                if self.has_rcvd_label is not None:
                                                    return True

                                                if self.has_second_label is not None:
                                                    return True

                                                if self.ibgp_signaled_validity is not None:
                                                    return True

                                                if self.igp_metric is not None:
                                                    return True

                                                if self.is_aggregation_suppressed is not None:
                                                    return True

                                                if self.is_as_best is not None:
                                                    return True

                                                if self.is_best_path is not None:
                                                    return True

                                                if self.is_import_dampened is not None:
                                                    return True

                                                if self.is_import_suspect is not None:
                                                    return True

                                                if self.is_internal_path is not None:
                                                    return True

                                                if self.is_partial_best is not None:
                                                    return True

                                                if self.is_path_additional_path is not None:
                                                    return True

                                                if self.is_path_advertised_local_as_only is not None:
                                                    return True

                                                if self.is_path_af_install_eligible is not None:
                                                    return True

                                                if self.is_path_backup is not None:
                                                    return True

                                                if self.is_path_backup_protect_multipath is not None:
                                                    return True

                                                if self.is_path_best_external is not None:
                                                    return True

                                                if self.is_path_damped is not None:
                                                    return True

                                                if self.is_path_from_confederation_peer is not None:
                                                    return True

                                                if self.is_path_from_network_command is not None:
                                                    return True

                                                if self.is_path_from_redistribute_command is not None:
                                                    return True

                                                if self.is_path_from_route_reflector is not None:
                                                    return True

                                                if self.is_path_history_held is not None:
                                                    return True

                                                if self.is_path_imp_candidate is not None:
                                                    return True

                                                if self.is_path_imported is not None:
                                                    return True

                                                if self.is_path_local_aggregate is not None:
                                                    return True

                                                if self.is_path_locally_sourced is not None:
                                                    return True

                                                if self.is_path_long_lived_stale is not None:
                                                    return True

                                                if self.is_path_multipath is not None:
                                                    return True

                                                if self.is_path_nexthop_discarded is not None:
                                                    return True

                                                if self.is_path_not_advertised is not None:
                                                    return True

                                                if self.is_path_not_advertised_to_ebg_ps is not None:
                                                    return True

                                                if self.is_path_received_only is not None:
                                                    return True

                                                if self.is_path_reoriginated is not None:
                                                    return True

                                                if self.is_path_reoriginated_stitching is not None:
                                                    return True

                                                if self.is_path_stale is not None:
                                                    return True

                                                if self.is_path_synced_with_igp is not None:
                                                    return True

                                                if self.is_path_valid is not None:
                                                    return True

                                                if self.is_path_vpn_only is not None:
                                                    return True

                                                if self.is_permanent_path is not None:
                                                    return True

                                                if self.is_received_path_not_modified is not None:
                                                    return True

                                                if self.is_spkr_as_best is not None:
                                                    return True

                                                if self.l2vpn_circuit_status_value is not None:
                                                    for child_ref in self.l2vpn_circuit_status_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                    return True

                                                if self.l2vpn_size is not None:
                                                    return True

                                                if self.labeled_unicast_safi_path is not None:
                                                    return True

                                                if self.local_label is not None:
                                                    return True

                                                if self.local_nh is not None:
                                                    return True

                                                if self.local_path_id is not None:
                                                    return True

                                                if self.local_peers_advertised_to is not None:
                                                    for child_ref in self.local_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.maximum_suppress_time is not None:
                                                    return True

                                                if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                    return True

                                                if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                    return True

                                                if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                    return True

                                                if self.mvpn_path_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_label is not None:
                                                    return True

                                                if self.mvpn_pmsi_type is not None:
                                                    return True

                                                if self.mvpn_pmsi_value is not None:
                                                    for child_ref in self.mvpn_pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.mvpn_sfs_path is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.neighbor_router_id is not None:
                                                    return True

                                                if self.next_hop is not None and self.next_hop._has_data():
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.path_flags is not None:
                                                    return True

                                                if self.path_flap_count is not None:
                                                    return True

                                                if self.path_import_flags is not None:
                                                    return True

                                                if self.path_rt_set_id is not None:
                                                    return True

                                                if self.path_rt_set_route_count is not None:
                                                    return True

                                                if self.path_table_version is not None:
                                                    return True

                                                if self.path_weight is not None:
                                                    return True

                                                if self.pe_peers_advertised_to is not None:
                                                    for child_ref in self.pe_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.rcvd_label is not None:
                                                    return True

                                                if self.rcvd_path_id is not None:
                                                    return True

                                                if self.reuse_value is not None:
                                                    return True

                                                if self.rib_failed is not None:
                                                    return True

                                                if self.route_type is not None:
                                                    return True

                                                if self.rpki_origin_as_validation_disabled is not None:
                                                    return True

                                                if self.rt_set_limit_enabled is not None:
                                                    return True

                                                if self.second_label is not None:
                                                    return True

                                                if self.seconds_since_first_flap is not None:
                                                    return True

                                                if self.show_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.sn_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.suppress_penalty is not None:
                                                    return True

                                                if self.time_to_unsuppress is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation']['meta_info']


                                        class AttributesAfterPolicyIn(object):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self.is_application_gateway_present = None
                                                self.is_as_path2_byte = None
                                                self.is_attr_set_present = None
                                                self.is_ribrnh_present = None
                                                self.is_rnh_present = None
                                                self.ribrnh_encap = None
                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self.ribrnh_mac = None
                                                self.ribrnh_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnhip_table = None
                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self.rnh_addr_len = None
                                                self.rnh_len = None
                                                self.rnh_type = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.vpn_distinguisher = None


                                            class CommonAttributes(object):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                            class AttrSet(object):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                            class RnhAddr(object):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None
                                                    self.mac_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    if self.mac_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                            class RibrnhIp(object):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.attr_set is not None and self.attr_set._has_data():
                                                    return True

                                                if self.attribute_key_number is not None:
                                                    return True

                                                if self.attribute_reuse_id_config is not None:
                                                    return True

                                                if self.attribute_reuse_id_current is not None:
                                                    return True

                                                if self.attribute_reuse_id_keys is not None:
                                                    return True

                                                if self.attribute_reuse_id_max_id is not None:
                                                    return True

                                                if self.attribute_reuse_id_node is not None:
                                                    return True

                                                if self.attribute_reuse_id_recover_sec is not None:
                                                    return True

                                                if self.common_attributes is not None and self.common_attributes._has_data():
                                                    return True

                                                if self.is_application_gateway_present is not None:
                                                    return True

                                                if self.is_as_path2_byte is not None:
                                                    return True

                                                if self.is_attr_set_present is not None:
                                                    return True

                                                if self.is_ribrnh_present is not None:
                                                    return True

                                                if self.is_rnh_present is not None:
                                                    return True

                                                if self.ribrnh_encap is not None:
                                                    return True

                                                if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                    return True

                                                if self.ribrnh_mac is not None:
                                                    return True

                                                if self.ribrnh_table is not None:
                                                    return True

                                                if self.ribrnh_vni is not None:
                                                    return True

                                                if self.ribrnhip_table is not None:
                                                    return True

                                                if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                    return True

                                                if self.rnh_addr_len is not None:
                                                    return True

                                                if self.rnh_len is not None:
                                                    return True

                                                if self.rnh_type is not None:
                                                    return True

                                                if self.set_aigp_inbound_igp is not None:
                                                    return True

                                                if self.set_aigp_inbound_metric is not None:
                                                    return True

                                                if self.vpn_distinguisher is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                return True

                                            if self.label_fail is not None:
                                                return True

                                            if self.label_o_or_version is not None:
                                                return True

                                            if self.label_oor is not None:
                                                return True

                                            if self.neighbor_address is not None:
                                                return True

                                            if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                return True

                                            if self.network is not None:
                                                return True

                                            if self.no_path is not None:
                                                return True

                                            if self.path_id is not None:
                                                return True

                                            if self.path_information is not None and self.path_information._has_data():
                                                return True

                                            if self.prefix_length is not None:
                                                return True

                                            if self.prefix_version is not None:
                                                return True

                                            if self.process_instance_id is not None:
                                                return True

                                            if self.rd is not None:
                                                return True

                                            if self.route_distinguisher is not None:
                                                return True

                                            if self.route_type is not None:
                                                return True

                                            if self.source_rd is not None:
                                                return True

                                            if self.source_route_distinguisher is not None:
                                                return True

                                            if self.source_vrf_name is not None:
                                                return True

                                            if self.srcaf_name is not None:
                                                return True

                                            if self.vrf_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-used-table'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.path is not None:
                                            for child_ref in self.path:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable']['meta_info']


                                class RpcSets(object):
                                    """
                                    BGP next\-hop set table
                                    
                                    .. attribute:: rpc_set
                                    
                                    	A BGP next\-hop set
                                    	**type**\: list of    :py:class:`RpcSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.rpc_set = YList()
                                        self.rpc_set.parent = self
                                        self.rpc_set.name = 'rpc_set'


                                    class RpcSet(object):
                                        """
                                        A BGP next\-hop set
                                        
                                        .. attribute:: rpc_set_index  <key>
                                        
                                        	Nexthop set index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: label
                                        
                                        	Label assigned to the RPCnext\-hop set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: next_hop
                                        
                                        	List of multipath next\-hops
                                        	**type**\: list of    :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop>`
                                        
                                        .. attribute:: next_hop_xr
                                        
                                        	Number of multipath next\-hops
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ref_count
                                        
                                        	Refcount
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.rpc_set_index = None
                                            self.label = None
                                            self.next_hop = YList()
                                            self.next_hop.parent = self
                                            self.next_hop.name = 'next_hop'
                                            self.next_hop_xr = None
                                            self.ref_count = None


                                        class NextHop(object):
                                            """
                                            List of multipath next\-hops
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')
                                            if self.rpc_set_index is None:
                                                raise YPYModelError('Key property rpc_set_index is None')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rpc-set[Cisco-IOS-XR-ipv4-bgp-oper:rpc-set-index = ' + str(self.rpc_set_index) + ']'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.rpc_set_index is not None:
                                                return True

                                            if self.label is not None:
                                                return True

                                            if self.next_hop is not None:
                                                for child_ref in self.next_hop:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.next_hop_xr is not None:
                                                return True

                                            if self.ref_count is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rpc-sets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.rpc_set is not None:
                                            for child_ref in self.rpc_set:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets']['meta_info']


                                class GlobalAfProcessInfo(object):
                                    """
                                    The Global Address Family Process information
                                    table
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family id
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: global_
                                    
                                    	Global information
                                    	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_>`
                                    
                                    .. attribute:: is_nsr_enabled
                                    
                                    	Non\-stop routing enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:   :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Vrf_>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.global_ = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_()
                                        self.global_.parent = self
                                        self.is_nsr_enabled = None
                                        self.vrf = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Vrf_()
                                        self.vrf.parent = self
                                        self.vrf_name = None


                                    class Global_(object):
                                        """
                                        Global information
                                        
                                        .. attribute:: gblafrpki_allow_invalid
                                        
                                        	Prefix v. allow invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: gblafrpki_disable
                                        
                                        	Prefix validation disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: gblafrpki_signal_ibgp
                                        
                                        	Prefix v. signal ibgp
                                        	**type**\:  bool
                                        
                                        .. attribute:: gblafrpki_use_validity
                                        
                                        	Prefix v. use validity
                                        	**type**\:  bool
                                        
                                        .. attribute:: global_mcast_enabled
                                        
                                        	Is global table mcast enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: inter_as_install_enabled
                                        
                                        	Is inter\-AS install to pim on ASBR enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_perm_net_cfg
                                        
                                        	Permanent Network Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: nh_tunnel_version
                                        
                                        	NH Tunnel Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: perm_nbr_count
                                        
                                        	Count of neighbors configured with perm net
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_del_count
                                        
                                        	Count of removed perm paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_existing_count
                                        
                                        	Count of existing perm paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_insert_count
                                        
                                        	Count of inserted perm paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_rpl_process_count
                                        
                                        	Count of perm nets processed in RPL
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_rpl_query_count
                                        
                                        	Count of perm nets given by RPL
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_stale_del_count
                                        
                                        	Count of stale perm paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_stale_mark_count
                                        
                                        	Count of stale marked perm paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_path_refresh_count
                                        
                                        	Count of perm paths refreshed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_pelem_all_bump_count
                                        
                                        	Count of bumped perm pelems
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_pelem_bump_count
                                        
                                        	Count of bumped perm pelems
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_pelem_free_count
                                        
                                        	Count of freed perm pelems
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rib_ack_requests
                                        
                                        	Counter for RIB ack requests
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_acks_received
                                        
                                        	Counter for RIB ack received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_install
                                        
                                        	RIB install info
                                        	**type**\:   :py:class:`RibInstall <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall>`
                                        
                                        .. attribute:: rib_perm_path_found_count
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rib_perm_path_not_found_count
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rib_perm_pelem_found_count
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rib_perm_pelem_not_found_count
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rib_reg_path_found_count
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rib_slow_acks
                                        
                                        	Counter for slow RIB acks
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: scan_prefixes
                                        
                                        	Total prefixes of address\-family scanned
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: scan_segment_prefixes
                                        
                                        	Number of prefixes scanned in a segment of address\-family
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: scan_segments
                                        
                                        	Number of segments to scan all prefixes of address\-family
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: scanner_period
                                        
                                        	Period (in seconds) of address\-family scanner runs
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: segmented_mcast_enabled
                                        
                                        	Is segmented mcast enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: syncgrp_version
                                        
                                        	Sync\-group Version
                                        	**type**\: list of    :py:class:`SyncgrpVersion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.SyncgrpVersion>`
                                        
                                        .. attribute:: update_wait_install_enabled
                                        
                                        	Update wait\-install enabled
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.gblafrpki_allow_invalid = None
                                            self.gblafrpki_disable = None
                                            self.gblafrpki_signal_ibgp = None
                                            self.gblafrpki_use_validity = None
                                            self.global_mcast_enabled = None
                                            self.inter_as_install_enabled = None
                                            self.is_perm_net_cfg = None
                                            self.nh_tunnel_version = None
                                            self.perm_nbr_count = None
                                            self.perm_net_del_count = None
                                            self.perm_net_existing_count = None
                                            self.perm_net_insert_count = None
                                            self.perm_net_rpl_process_count = None
                                            self.perm_net_rpl_query_count = None
                                            self.perm_net_stale_del_count = None
                                            self.perm_net_stale_mark_count = None
                                            self.perm_path_refresh_count = None
                                            self.perm_pelem_all_bump_count = None
                                            self.perm_pelem_bump_count = None
                                            self.perm_pelem_free_count = None
                                            self.rib_ack_requests = None
                                            self.rib_acks_received = None
                                            self.rib_install = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall()
                                            self.rib_install.parent = self
                                            self.rib_perm_path_found_count = None
                                            self.rib_perm_path_not_found_count = None
                                            self.rib_perm_pelem_found_count = None
                                            self.rib_perm_pelem_not_found_count = None
                                            self.rib_reg_path_found_count = None
                                            self.rib_slow_acks = None
                                            self.scan_prefixes = None
                                            self.scan_segment_prefixes = None
                                            self.scan_segments = None
                                            self.scanner_period = None
                                            self.segmented_mcast_enabled = None
                                            self.syncgrp_version = YList()
                                            self.syncgrp_version.parent = self
                                            self.syncgrp_version.name = 'syncgrp_version'
                                            self.update_wait_install_enabled = None


                                        class RibInstall(object):
                                            """
                                            RIB install info
                                            
                                            .. attribute:: install_time
                                            
                                            	RIB install time
                                            	**type**\:   :py:class:`InstallTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.InstallTime>`
                                            
                                            .. attribute:: installed_count
                                            
                                            	Installed routes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: modified_count
                                            
                                            	Modified routes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: start_version
                                            
                                            	Start version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: target_version
                                            
                                            	Target version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_time
                                            
                                            	RIB update time
                                            	**type**\:   :py:class:`UpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.UpdateTime>`
                                            
                                            .. attribute:: withdrawn_count
                                            
                                            	Withdrawn routes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.install_time = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.InstallTime()
                                                self.install_time.parent = self
                                                self.installed_count = None
                                                self.modified_count = None
                                                self.start_version = None
                                                self.target_version = None
                                                self.update_time = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.UpdateTime()
                                                self.update_time.parent = self
                                                self.withdrawn_count = None


                                            class UpdateTime(object):
                                                """
                                                RIB update time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-time'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.UpdateTime']['meta_info']


                                            class InstallTime(object):
                                                """
                                                RIB install time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:install-time'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.InstallTime']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rib-install'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.install_time is not None and self.install_time._has_data():
                                                    return True

                                                if self.installed_count is not None:
                                                    return True

                                                if self.modified_count is not None:
                                                    return True

                                                if self.start_version is not None:
                                                    return True

                                                if self.target_version is not None:
                                                    return True

                                                if self.update_time is not None and self.update_time._has_data():
                                                    return True

                                                if self.withdrawn_count is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall']['meta_info']


                                        class SyncgrpVersion(object):
                                            """
                                            Sync\-group Version
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:syncgrp-version'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.SyncgrpVersion']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:global'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.gblafrpki_allow_invalid is not None:
                                                return True

                                            if self.gblafrpki_disable is not None:
                                                return True

                                            if self.gblafrpki_signal_ibgp is not None:
                                                return True

                                            if self.gblafrpki_use_validity is not None:
                                                return True

                                            if self.global_mcast_enabled is not None:
                                                return True

                                            if self.inter_as_install_enabled is not None:
                                                return True

                                            if self.is_perm_net_cfg is not None:
                                                return True

                                            if self.nh_tunnel_version is not None:
                                                return True

                                            if self.perm_nbr_count is not None:
                                                return True

                                            if self.perm_net_del_count is not None:
                                                return True

                                            if self.perm_net_existing_count is not None:
                                                return True

                                            if self.perm_net_insert_count is not None:
                                                return True

                                            if self.perm_net_rpl_process_count is not None:
                                                return True

                                            if self.perm_net_rpl_query_count is not None:
                                                return True

                                            if self.perm_net_stale_del_count is not None:
                                                return True

                                            if self.perm_net_stale_mark_count is not None:
                                                return True

                                            if self.perm_path_refresh_count is not None:
                                                return True

                                            if self.perm_pelem_all_bump_count is not None:
                                                return True

                                            if self.perm_pelem_bump_count is not None:
                                                return True

                                            if self.perm_pelem_free_count is not None:
                                                return True

                                            if self.rib_ack_requests is not None:
                                                return True

                                            if self.rib_acks_received is not None:
                                                return True

                                            if self.rib_install is not None and self.rib_install._has_data():
                                                return True

                                            if self.rib_perm_path_found_count is not None:
                                                return True

                                            if self.rib_perm_path_not_found_count is not None:
                                                return True

                                            if self.rib_perm_pelem_found_count is not None:
                                                return True

                                            if self.rib_perm_pelem_not_found_count is not None:
                                                return True

                                            if self.rib_reg_path_found_count is not None:
                                                return True

                                            if self.rib_slow_acks is not None:
                                                return True

                                            if self.scan_prefixes is not None:
                                                return True

                                            if self.scan_segment_prefixes is not None:
                                                return True

                                            if self.scan_segments is not None:
                                                return True

                                            if self.scanner_period is not None:
                                                return True

                                            if self.segmented_mcast_enabled is not None:
                                                return True

                                            if self.syncgrp_version is not None:
                                                for child_ref in self.syncgrp_version:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.update_wait_install_enabled is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_']['meta_info']


                                    class Vrf_(object):
                                        """
                                        VRF information
                                        
                                        .. attribute:: aggregates_distance
                                        
                                        	Dist for aggregate routes (local)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: client_reflection_enabled
                                        
                                        	Client reflection enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: dampening_enabled
                                        
                                        	Dampening enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: dynamic_med_enabled
                                        
                                        	Update generation enabled for MED change
                                        	**type**\:  bool
                                        
                                        .. attribute:: dynamic_med_interval
                                        
                                        	Delay in update generation after a MED change (in minutes)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: minute
                                        
                                        .. attribute:: dynamic_med_periodic_timer_running
                                        
                                        	Dynamic MED periodic timer running
                                        	**type**\:  bool
                                        
                                        .. attribute:: dynamic_med_periodic_timer_value
                                        
                                        	Dynamic MED periodic timer value (in seconds) left on the timer
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: dynamic_med_timer_running
                                        
                                        	Dynamic MED timer running
                                        	**type**\:  bool
                                        
                                        .. attribute:: dynamic_med_timer_value
                                        
                                        	Dynamic MED timer value (in seconds) left on the timer
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: ebgp_distance
                                        
                                        	Distance for eBGP routes (external)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ibgp_distance
                                        
                                        	Distance for iBGP routes (internal)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_rib_table_full
                                        
                                        	Indicates if RIB table is in prefix\-limit state
                                        	**type**\:  bool
                                        
                                        .. attribute:: nexthop_resolution_minimum_prefix_length
                                        
                                        	Nexthop resoultion minimum prefix\-length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nexthop_resolution_minimum_prefix_length_configured
                                        
                                        	Is nexthop resoultion minimum prefix\-length configured ?
                                        	**type**\:  bool
                                        
                                        .. attribute:: nsr_conv_version
                                        
                                        	NSR conv version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nsr_is_conv
                                        
                                        	NSR is converged
                                        	**type**\:  bool
                                        
                                        .. attribute:: rd_version
                                        
                                        	RD version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_acked_table_version
                                        
                                        	Table version acked by RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_convergence_version
                                        
                                        	Last convergence version received from RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_has_converged
                                        
                                        	Received convergence notification from RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: rib_table_full_version
                                        
                                        	Version when RIB table became full (from non\-full)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_version
                                        
                                        	Table version synced to RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: selective_ebgp_multipath_enabled
                                        
                                        	Selective eBGP multipath isenabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: selective_eibgp_multipath_enabled
                                        
                                        	Selective eiBGP multipath isenabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: selective_ibgp_multipath_enabled
                                        
                                        	Selective iBGP multipath isenabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: table_id
                                        
                                        	Table ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: table_is_active
                                        
                                        	Table state is active
                                        	**type**\:  bool
                                        
                                        .. attribute:: table_version
                                        
                                        	Table version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.aggregates_distance = None
                                            self.client_reflection_enabled = None
                                            self.dampening_enabled = None
                                            self.dynamic_med_enabled = None
                                            self.dynamic_med_interval = None
                                            self.dynamic_med_periodic_timer_running = None
                                            self.dynamic_med_periodic_timer_value = None
                                            self.dynamic_med_timer_running = None
                                            self.dynamic_med_timer_value = None
                                            self.ebgp_distance = None
                                            self.ibgp_distance = None
                                            self.is_rib_table_full = None
                                            self.nexthop_resolution_minimum_prefix_length = None
                                            self.nexthop_resolution_minimum_prefix_length_configured = None
                                            self.nsr_conv_version = None
                                            self.nsr_is_conv = None
                                            self.rd_version = None
                                            self.rib_acked_table_version = None
                                            self.rib_convergence_version = None
                                            self.rib_has_converged = None
                                            self.rib_table_full_version = None
                                            self.rib_version = None
                                            self.selective_ebgp_multipath_enabled = None
                                            self.selective_eibgp_multipath_enabled = None
                                            self.selective_ibgp_multipath_enabled = None
                                            self.table_id = None
                                            self.table_is_active = None
                                            self.table_version = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:vrf'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.aggregates_distance is not None:
                                                return True

                                            if self.client_reflection_enabled is not None:
                                                return True

                                            if self.dampening_enabled is not None:
                                                return True

                                            if self.dynamic_med_enabled is not None:
                                                return True

                                            if self.dynamic_med_interval is not None:
                                                return True

                                            if self.dynamic_med_periodic_timer_running is not None:
                                                return True

                                            if self.dynamic_med_periodic_timer_value is not None:
                                                return True

                                            if self.dynamic_med_timer_running is not None:
                                                return True

                                            if self.dynamic_med_timer_value is not None:
                                                return True

                                            if self.ebgp_distance is not None:
                                                return True

                                            if self.ibgp_distance is not None:
                                                return True

                                            if self.is_rib_table_full is not None:
                                                return True

                                            if self.nexthop_resolution_minimum_prefix_length is not None:
                                                return True

                                            if self.nexthop_resolution_minimum_prefix_length_configured is not None:
                                                return True

                                            if self.nsr_conv_version is not None:
                                                return True

                                            if self.nsr_is_conv is not None:
                                                return True

                                            if self.rd_version is not None:
                                                return True

                                            if self.rib_acked_table_version is not None:
                                                return True

                                            if self.rib_convergence_version is not None:
                                                return True

                                            if self.rib_has_converged is not None:
                                                return True

                                            if self.rib_table_full_version is not None:
                                                return True

                                            if self.rib_version is not None:
                                                return True

                                            if self.selective_ebgp_multipath_enabled is not None:
                                                return True

                                            if self.selective_eibgp_multipath_enabled is not None:
                                                return True

                                            if self.selective_ibgp_multipath_enabled is not None:
                                                return True

                                            if self.table_id is not None:
                                                return True

                                            if self.table_is_active is not None:
                                                return True

                                            if self.table_version is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Vrf_']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:global-af-process-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.global_ is not None and self.global_._has_data():
                                            return True

                                        if self.is_nsr_enabled is not None:
                                            return True

                                        if self.vrf is not None and self.vrf._has_data():
                                            return True

                                        if self.vrf_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo']['meta_info']


                                class NetworkPrefixes(object):
                                    """
                                    The BGP Network Lookup table
                                    
                                    .. attribute:: network_prefix
                                    
                                    	A BGP Network Lookup prefix entry
                                    	**type**\: list of    :py:class:`NetworkPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.network_prefix = YList()
                                        self.network_prefix.parent = self
                                        self.network_prefix.name = 'network_prefix'


                                    class NetworkPrefix(object):
                                        """
                                        A BGP Network Lookup prefix entry
                                        
                                        .. attribute:: active_path_element
                                        
                                        	Path element list received from Active inst
                                        	**type**\: list of    :py:class:`ActivePathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement>`
                                        
                                        .. attribute:: active_process_instance_path
                                        
                                        	Active's paths for this net 
                                        	**type**\: list of    :py:class:`ActiveProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath>`
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield>`
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix>`
                                        
                                        .. attribute:: bit
                                        
                                        	Bit
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: flags
                                        
                                        	Flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: gateway_array
                                        
                                        	Gateway array ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_inconsistent_paths
                                        
                                        	Net has inconsistent paths
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_lbl_retained
                                        
                                        	Net has label retained
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_local_label
                                        
                                        	Net has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_net_aggregation_suppressed
                                        
                                        	Net suppressed due to aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_net_ldp_signaled
                                        
                                        	L2VPN Net LDP signaled  aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_permanent_network
                                        
                                        	Permanent Network
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_path_element
                                        
                                        	Local path element list
                                        	**type**\: list of    :py:class:`LocalPathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement>`
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: local_process_instance_path
                                        
                                        	Local (to process instance) paths for this net 
                                        	**type**\: list of    :py:class:`LocalProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath>`
                                        
                                        .. attribute:: net_backup_available
                                        
                                        	Net has backup path
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_backup_label_rewrite_available
                                        
                                        	Net has label rewrite for backup path
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_eibgp_multipath
                                        
                                        	Net has EIBGP multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_extended_flags
                                        
                                        	Net extended flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: net_flags
                                        
                                        	Flags associated with                            net
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: net_local_label
                                        
                                        	Local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: net_local_label_rewrite
                                        
                                        	Net label has rewrite
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_local_label_srgb
                                        
                                        	Net label allocated fromSegment routing global block
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_multipath
                                        
                                        	Net has multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: network_prefix
                                        
                                        	Network prefix
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: num_of_path
                                        
                                        	Number of path for this net
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: resilient_nexthop_set
                                        
                                        	Resilient nexthop set ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_failed
                                        
                                        	RIB install failed
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: table_brib_version
                                        
                                        	Table version # for updates
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: table_version
                                        
                                        	Table version # for net
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version
                                        
                                        	Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version_age
                                        
                                        	Version age
                                        	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionAge>`
                                        
                                        .. attribute:: version_timestamp
                                        
                                        	Version timestamp
                                        	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionTimestamp>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.active_path_element = YList()
                                            self.active_path_element.parent = self
                                            self.active_path_element.name = 'active_path_element'
                                            self.active_process_instance_path = YList()
                                            self.active_process_instance_path.parent = self
                                            self.active_process_instance_path.name = 'active_process_instance_path'
                                            self.add_path_orr_bitfield = YList()
                                            self.add_path_orr_bitfield.parent = self
                                            self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                            self.advertisedto_pe = None
                                            self.af_name = None
                                            self.best_path_orr_bitfield = YList()
                                            self.best_path_orr_bitfield.parent = self
                                            self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self.bit = None
                                            self.flags = None
                                            self.gateway_array = None
                                            self.has_inconsistent_paths = None
                                            self.has_lbl_retained = None
                                            self.has_local_label = None
                                            self.is_net_aggregation_suppressed = None
                                            self.is_net_ldp_signaled = None
                                            self.is_permanent_network = None
                                            self.local_path_element = YList()
                                            self.local_path_element.parent = self
                                            self.local_path_element.name = 'local_path_element'
                                            self.local_peers_advertised_to = YList()
                                            self.local_peers_advertised_to.parent = self
                                            self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                            self.local_process_instance_path = YList()
                                            self.local_process_instance_path.parent = self
                                            self.local_process_instance_path.name = 'local_process_instance_path'
                                            self.net_backup_available = None
                                            self.net_backup_label_rewrite_available = None
                                            self.net_eibgp_multipath = None
                                            self.net_extended_flags = None
                                            self.net_flags = None
                                            self.net_local_label = None
                                            self.net_local_label_rewrite = None
                                            self.net_local_label_srgb = None
                                            self.net_multipath = None
                                            self.network_prefix = None
                                            self.num_of_path = None
                                            self.pe_peers_advertised_to = YList()
                                            self.pe_peers_advertised_to.parent = self
                                            self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                            self.process_instance_id = None
                                            self.rd = None
                                            self.resilient_nexthop_set = None
                                            self.rib_failed = None
                                            self.route_distinguisher = None
                                            self.table_brib_version = None
                                            self.table_version = None
                                            self.version = None
                                            self.version_age = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionAge()
                                            self.version_age.parent = self
                                            self.version_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionTimestamp()
                                            self.version_timestamp.parent = self
                                            self.vrf_name = None


                                        class BgpPrefix(object):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self.prefix_length = None


                                            class Prefix(object):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.prefix is not None and self.prefix._has_data():
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix']['meta_info']


                                        class VersionTimestamp(object):
                                            """
                                            Version timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionTimestamp']['meta_info']


                                        class VersionAge(object):
                                            """
                                            Version age
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-age'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionAge']['meta_info']


                                        class LocalPeersAdvertisedTo(object):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo']['meta_info']


                                        class PePeersAdvertisedTo(object):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo']['meta_info']


                                        class BestPathOrrBitfield(object):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield']['meta_info']


                                        class AddPathOrrBitfield(object):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield']['meta_info']


                                        class LocalProcessInstancePath(object):
                                            """
                                            Local (to process instance) paths for this net 
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: attributes_after_policy_in
                                            
                                            	Attributes after inbound policy applied
                                            	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn>`
                                            
                                            .. attribute:: label_fail
                                            
                                            	LSD label allocation failed 
                                            	**type**\:  bool
                                            
                                            .. attribute:: label_o_or_version
                                            
                                            	Label Version when OOR happens
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_oor
                                            
                                            	LSD label space is exhausted
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address_xr
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr>`
                                            
                                            .. attribute:: no_path
                                            
                                            	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                            	**type**\:  bool
                                            
                                            .. attribute:: path_information
                                            
                                            	Path information
                                            	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation>`
                                            
                                            .. attribute:: prefix_version
                                            
                                            	Version of BGP Prefix Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: process_instance_id
                                            
                                            	Process instance ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_route_distinguisher
                                            
                                            	Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_vrf_name
                                            
                                            	Name of the source VRF
                                            	**type**\:  str
                                            
                                            .. attribute:: srcaf_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.af_name = None
                                                self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn()
                                                self.attributes_after_policy_in.parent = self
                                                self.label_fail = None
                                                self.label_o_or_version = None
                                                self.label_oor = None
                                                self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr()
                                                self.neighbor_address_xr.parent = self
                                                self.no_path = None
                                                self.path_information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation()
                                                self.path_information.parent = self
                                                self.prefix_version = None
                                                self.process_instance_id = None
                                                self.route_distinguisher = None
                                                self.source_route_distinguisher = None
                                                self.source_vrf_name = None
                                                self.srcaf_name = None
                                                self.vrf_name = None


                                            class NeighborAddressXr(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr']['meta_info']


                                            class PathInformation(object):
                                                """
                                                Path information
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\:  bool
                                                
                                                .. attribute:: accept_own_self_originated_p_ath
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\:  bool
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\:  bool
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix>`
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\:  bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\:  bool
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.GwAddr>`
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_esi
                                                
                                                	Path has EVPN ESI
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_rcvd_label
                                                
                                                	Path has received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\:  bool
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebg_ps
                                                
                                                	Not advertised to EBGPs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi>`
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress>`
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop>`
                                                
                                                .. attribute:: nhte_tunnel
                                                
                                                	NH TE tunnel information
                                                	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhteTunnel>`
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\:  bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.accept_own_path = None
                                                    self.accept_own_self_originated_p_ath = None
                                                    self.add_path_orr_bitfield = YList()
                                                    self.add_path_orr_bitfield.parent = self
                                                    self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                    self.advertisedto_pe = None
                                                    self.aigp_metric = None
                                                    self.best_path_comp_stage = None
                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self.best_path_id = None
                                                    self.best_path_id_comp_winner = None
                                                    self.best_path_orr_bitfield = YList()
                                                    self.best_path_orr_bitfield.parent = self
                                                    self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self.dampen_penalty = None
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.fspec_invalid_path = None
                                                    self.graceful_shutdown = None
                                                    self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self.halflife_time = None
                                                    self.has_esi = None
                                                    self.has_gw_addr = None
                                                    self.has_local_net_label = None
                                                    self.has_mdt_group_addr = None
                                                    self.has_mvpn_extcomm = None
                                                    self.has_mvpn_nbr_addr = None
                                                    self.has_mvpn_nexthop_addr = None
                                                    self.has_mvpn_pmsi = None
                                                    self.has_rcvd_label = None
                                                    self.has_second_label = None
                                                    self.ibgp_signaled_validity = None
                                                    self.igp_metric = None
                                                    self.is_aggregation_suppressed = None
                                                    self.is_as_best = None
                                                    self.is_best_path = None
                                                    self.is_import_dampened = None
                                                    self.is_import_suspect = None
                                                    self.is_internal_path = None
                                                    self.is_partial_best = None
                                                    self.is_path_additional_path = None
                                                    self.is_path_advertised_local_as_only = None
                                                    self.is_path_af_install_eligible = None
                                                    self.is_path_backup = None
                                                    self.is_path_backup_protect_multipath = None
                                                    self.is_path_best_external = None
                                                    self.is_path_damped = None
                                                    self.is_path_from_confederation_peer = None
                                                    self.is_path_from_network_command = None
                                                    self.is_path_from_redistribute_command = None
                                                    self.is_path_from_route_reflector = None
                                                    self.is_path_history_held = None
                                                    self.is_path_imp_candidate = None
                                                    self.is_path_imported = None
                                                    self.is_path_local_aggregate = None
                                                    self.is_path_locally_sourced = None
                                                    self.is_path_long_lived_stale = None
                                                    self.is_path_multipath = None
                                                    self.is_path_nexthop_discarded = None
                                                    self.is_path_not_advertised = None
                                                    self.is_path_not_advertised_to_ebg_ps = None
                                                    self.is_path_received_only = None
                                                    self.is_path_reoriginated = None
                                                    self.is_path_reoriginated_stitching = None
                                                    self.is_path_stale = None
                                                    self.is_path_synced_with_igp = None
                                                    self.is_path_valid = None
                                                    self.is_path_vpn_only = None
                                                    self.is_permanent_path = None
                                                    self.is_received_path_not_modified = None
                                                    self.is_spkr_as_best = None
                                                    self.l2vpn_circuit_status_value = YList()
                                                    self.l2vpn_circuit_status_value.parent = self
                                                    self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                    self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi()
                                                    self.l2vpn_evpn_esi.parent = self
                                                    self.l2vpn_size = None
                                                    self.labeled_unicast_safi_path = None
                                                    self.local_label = None
                                                    self.local_nh = None
                                                    self.local_path_id = None
                                                    self.local_peers_advertised_to = YList()
                                                    self.local_peers_advertised_to.parent = self
                                                    self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                    self.maximum_suppress_time = None
                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self.mvpn_path_flags = None
                                                    self.mvpn_pmsi_flags = None
                                                    self.mvpn_pmsi_label = None
                                                    self.mvpn_pmsi_type = None
                                                    self.mvpn_pmsi_value = YList()
                                                    self.mvpn_pmsi_value.parent = self
                                                    self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                    self.mvpn_sfs_path = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.neighbor_router_id = None
                                                    self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop()
                                                    self.next_hop.parent = self
                                                    self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhteTunnel()
                                                    self.nhte_tunnel.parent = self
                                                    self.path_flags = None
                                                    self.path_flap_count = None
                                                    self.path_import_flags = None
                                                    self.path_rt_set_id = None
                                                    self.path_rt_set_route_count = None
                                                    self.path_table_version = None
                                                    self.path_weight = None
                                                    self.pe_peers_advertised_to = YList()
                                                    self.pe_peers_advertised_to.parent = self
                                                    self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                    self.rcvd_label = None
                                                    self.rcvd_path_id = None
                                                    self.reuse_value = None
                                                    self.rib_failed = None
                                                    self.route_type = None
                                                    self.rpki_origin_as_validation_disabled = None
                                                    self.rt_set_limit_enabled = None
                                                    self.second_label = None
                                                    self.seconds_since_first_flap = None
                                                    self.show_rpki_origin_as_validity = None
                                                    self.sn_rpki_origin_as_validity = None
                                                    self.suppress_penalty = None
                                                    self.time_to_unsuppress = None


                                                class BgpPrefix(object):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self.prefix_length = None


                                                    class Prefix(object):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.prefix is not None and self.prefix._has_data():
                                                            return True

                                                        if self.prefix_length is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix']['meta_info']


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress']['meta_info']


                                                class NextHop(object):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop']['meta_info']


                                                class NhteTunnel(object):
                                                    """
                                                    NH TE tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_te_tunnel
                                                    
                                                    	NH TE Tunnel info is present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last rib update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	tunnel name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	tunnel type
                                                    	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.binding_label = None
                                                        self.has_te_tunnel = None
                                                        self.is_tunnel_info_stale = None
                                                        self.is_tunnel_registered = None
                                                        self.is_tunnel_up = None
                                                        self.last_tunnel_update = None
                                                        self.tunnel_if_handle = None
                                                        self.tunnel_name = None
                                                        self.tunnel_type = None
                                                        self.tunnel_v6_enabled = None
                                                        self.tunnel_v6_required = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.binding_label is not None:
                                                            return True

                                                        if self.has_te_tunnel is not None:
                                                            return True

                                                        if self.is_tunnel_info_stale is not None:
                                                            return True

                                                        if self.is_tunnel_registered is not None:
                                                            return True

                                                        if self.is_tunnel_up is not None:
                                                            return True

                                                        if self.last_tunnel_update is not None:
                                                            return True

                                                        if self.tunnel_if_handle is not None:
                                                            return True

                                                        if self.tunnel_name is not None:
                                                            return True

                                                        if self.tunnel_type is not None:
                                                            return True

                                                        if self.tunnel_v6_enabled is not None:
                                                            return True

                                                        if self.tunnel_v6_required is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhteTunnel']['meta_info']


                                                class MdtGroupAddr(object):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr']['meta_info']


                                                class L2VpnEvpnEsi(object):
                                                    """
                                                    L2VPN EVPN ESI
                                                    
                                                    .. attribute:: esi
                                                    
                                                    	esi
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.esi = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.esi is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi']['meta_info']


                                                class GwAddr(object):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.len = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.len is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.GwAddr']['meta_info']


                                                class BestPathCompWinner(object):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner']['meta_info']


                                                class MvpnNbrAddr(object):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr']['meta_info']


                                                class MvpnNexthopAddr(object):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr']['meta_info']


                                                class L2VpnCircuitStatusValue(object):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                                class MvpnPmsiValue(object):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnPmsiValue']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.ExtendedCommunity']['meta_info']


                                                class LocalPeersAdvertisedTo(object):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                                class PePeersAdvertisedTo(object):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo']['meta_info']


                                                class BestPathOrrBitfield(object):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield']['meta_info']


                                                class AddPathOrrBitfield(object):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.accept_own_path is not None:
                                                        return True

                                                    if self.accept_own_self_originated_p_ath is not None:
                                                        return True

                                                    if self.add_path_orr_bitfield is not None:
                                                        for child_ref in self.add_path_orr_bitfield:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.advertisedto_pe is not None:
                                                        return True

                                                    if self.aigp_metric is not None:
                                                        return True

                                                    if self.best_path_comp_stage is not None:
                                                        return True

                                                    if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                        return True

                                                    if self.best_path_id is not None:
                                                        return True

                                                    if self.best_path_id_comp_winner is not None:
                                                        return True

                                                    if self.best_path_orr_bitfield is not None:
                                                        for child_ref in self.best_path_orr_bitfield:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                        return True

                                                    if self.dampen_penalty is not None:
                                                        return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.fspec_invalid_path is not None:
                                                        return True

                                                    if self.graceful_shutdown is not None:
                                                        return True

                                                    if self.gw_addr is not None and self.gw_addr._has_data():
                                                        return True

                                                    if self.halflife_time is not None:
                                                        return True

                                                    if self.has_esi is not None:
                                                        return True

                                                    if self.has_gw_addr is not None:
                                                        return True

                                                    if self.has_local_net_label is not None:
                                                        return True

                                                    if self.has_mdt_group_addr is not None:
                                                        return True

                                                    if self.has_mvpn_extcomm is not None:
                                                        return True

                                                    if self.has_mvpn_nbr_addr is not None:
                                                        return True

                                                    if self.has_mvpn_nexthop_addr is not None:
                                                        return True

                                                    if self.has_mvpn_pmsi is not None:
                                                        return True

                                                    if self.has_rcvd_label is not None:
                                                        return True

                                                    if self.has_second_label is not None:
                                                        return True

                                                    if self.ibgp_signaled_validity is not None:
                                                        return True

                                                    if self.igp_metric is not None:
                                                        return True

                                                    if self.is_aggregation_suppressed is not None:
                                                        return True

                                                    if self.is_as_best is not None:
                                                        return True

                                                    if self.is_best_path is not None:
                                                        return True

                                                    if self.is_import_dampened is not None:
                                                        return True

                                                    if self.is_import_suspect is not None:
                                                        return True

                                                    if self.is_internal_path is not None:
                                                        return True

                                                    if self.is_partial_best is not None:
                                                        return True

                                                    if self.is_path_additional_path is not None:
                                                        return True

                                                    if self.is_path_advertised_local_as_only is not None:
                                                        return True

                                                    if self.is_path_af_install_eligible is not None:
                                                        return True

                                                    if self.is_path_backup is not None:
                                                        return True

                                                    if self.is_path_backup_protect_multipath is not None:
                                                        return True

                                                    if self.is_path_best_external is not None:
                                                        return True

                                                    if self.is_path_damped is not None:
                                                        return True

                                                    if self.is_path_from_confederation_peer is not None:
                                                        return True

                                                    if self.is_path_from_network_command is not None:
                                                        return True

                                                    if self.is_path_from_redistribute_command is not None:
                                                        return True

                                                    if self.is_path_from_route_reflector is not None:
                                                        return True

                                                    if self.is_path_history_held is not None:
                                                        return True

                                                    if self.is_path_imp_candidate is not None:
                                                        return True

                                                    if self.is_path_imported is not None:
                                                        return True

                                                    if self.is_path_local_aggregate is not None:
                                                        return True

                                                    if self.is_path_locally_sourced is not None:
                                                        return True

                                                    if self.is_path_long_lived_stale is not None:
                                                        return True

                                                    if self.is_path_multipath is not None:
                                                        return True

                                                    if self.is_path_nexthop_discarded is not None:
                                                        return True

                                                    if self.is_path_not_advertised is not None:
                                                        return True

                                                    if self.is_path_not_advertised_to_ebg_ps is not None:
                                                        return True

                                                    if self.is_path_received_only is not None:
                                                        return True

                                                    if self.is_path_reoriginated is not None:
                                                        return True

                                                    if self.is_path_reoriginated_stitching is not None:
                                                        return True

                                                    if self.is_path_stale is not None:
                                                        return True

                                                    if self.is_path_synced_with_igp is not None:
                                                        return True

                                                    if self.is_path_valid is not None:
                                                        return True

                                                    if self.is_path_vpn_only is not None:
                                                        return True

                                                    if self.is_permanent_path is not None:
                                                        return True

                                                    if self.is_received_path_not_modified is not None:
                                                        return True

                                                    if self.is_spkr_as_best is not None:
                                                        return True

                                                    if self.l2vpn_circuit_status_value is not None:
                                                        for child_ref in self.l2vpn_circuit_status_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                        return True

                                                    if self.l2vpn_size is not None:
                                                        return True

                                                    if self.labeled_unicast_safi_path is not None:
                                                        return True

                                                    if self.local_label is not None:
                                                        return True

                                                    if self.local_nh is not None:
                                                        return True

                                                    if self.local_path_id is not None:
                                                        return True

                                                    if self.local_peers_advertised_to is not None:
                                                        for child_ref in self.local_peers_advertised_to:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.maximum_suppress_time is not None:
                                                        return True

                                                    if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                        return True

                                                    if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                        return True

                                                    if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                        return True

                                                    if self.mvpn_path_flags is not None:
                                                        return True

                                                    if self.mvpn_pmsi_flags is not None:
                                                        return True

                                                    if self.mvpn_pmsi_label is not None:
                                                        return True

                                                    if self.mvpn_pmsi_type is not None:
                                                        return True

                                                    if self.mvpn_pmsi_value is not None:
                                                        for child_ref in self.mvpn_pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.mvpn_sfs_path is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.neighbor_router_id is not None:
                                                        return True

                                                    if self.next_hop is not None and self.next_hop._has_data():
                                                        return True

                                                    if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                        return True

                                                    if self.path_flags is not None:
                                                        return True

                                                    if self.path_flap_count is not None:
                                                        return True

                                                    if self.path_import_flags is not None:
                                                        return True

                                                    if self.path_rt_set_id is not None:
                                                        return True

                                                    if self.path_rt_set_route_count is not None:
                                                        return True

                                                    if self.path_table_version is not None:
                                                        return True

                                                    if self.path_weight is not None:
                                                        return True

                                                    if self.pe_peers_advertised_to is not None:
                                                        for child_ref in self.pe_peers_advertised_to:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.rcvd_label is not None:
                                                        return True

                                                    if self.rcvd_path_id is not None:
                                                        return True

                                                    if self.reuse_value is not None:
                                                        return True

                                                    if self.rib_failed is not None:
                                                        return True

                                                    if self.route_type is not None:
                                                        return True

                                                    if self.rpki_origin_as_validation_disabled is not None:
                                                        return True

                                                    if self.rt_set_limit_enabled is not None:
                                                        return True

                                                    if self.second_label is not None:
                                                        return True

                                                    if self.seconds_since_first_flap is not None:
                                                        return True

                                                    if self.show_rpki_origin_as_validity is not None:
                                                        return True

                                                    if self.sn_rpki_origin_as_validity is not None:
                                                        return True

                                                    if self.suppress_penalty is not None:
                                                        return True

                                                    if self.time_to_unsuppress is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation']['meta_info']


                                            class AttributesAfterPolicyIn(object):
                                                """
                                                Attributes after inbound policy applied
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\:  bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\:  bool
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                    self.attr_set.parent = self
                                                    self.attribute_key_number = None
                                                    self.attribute_reuse_id_config = None
                                                    self.attribute_reuse_id_current = None
                                                    self.attribute_reuse_id_keys = None
                                                    self.attribute_reuse_id_max_id = None
                                                    self.attribute_reuse_id_node = None
                                                    self.attribute_reuse_id_recover_sec = None
                                                    self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self.is_application_gateway_present = None
                                                    self.is_as_path2_byte = None
                                                    self.is_attr_set_present = None
                                                    self.is_ribrnh_present = None
                                                    self.is_rnh_present = None
                                                    self.ribrnh_encap = None
                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self.ribrnh_mac = None
                                                    self.ribrnh_table = None
                                                    self.ribrnh_vni = None
                                                    self.ribrnhip_table = None
                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self.rnh_addr_len = None
                                                    self.rnh_len = None
                                                    self.rnh_type = None
                                                    self.set_aigp_inbound_igp = None
                                                    self.set_aigp_inbound_metric = None
                                                    self.vpn_distinguisher = None


                                                class CommonAttributes(object):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_encap_present
                                                    
                                                    	Tunnel Encap attribute present 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_policy_allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_binding_sid
                                                    
                                                    	SR Policy Binding sid
                                                    	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_explicit_path
                                                    
                                                    	SR Policy Explicit paths
                                                    	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                    
                                                    .. attribute:: sr_policy_preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_tunnel_request_state
                                                    
                                                    	SR Tunnel Request State
                                                    	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                    
                                                    .. attribute:: sr_tunnel_state
                                                    
                                                    	SR Tunnel State
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encap Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.aggregator_address = None
                                                        self.aggregator_as = None
                                                        self.aigp_metric_value = None
                                                        self.as_path = None
                                                        self.cluster = YList()
                                                        self.cluster.parent = self
                                                        self.cluster.name = 'cluster'
                                                        self.community = YList()
                                                        self.community.parent = self
                                                        self.community.name = 'community'
                                                        self.connector_type = None
                                                        self.connector_value = YList()
                                                        self.connector_value.parent = self
                                                        self.connector_value.name = 'connector_value'
                                                        self.extended_community = YList()
                                                        self.extended_community.parent = self
                                                        self.extended_community.name = 'extended_community'
                                                        self.extended_community_flags = None
                                                        self.is_aggregator_present = None
                                                        self.is_aigp_present = None
                                                        self.is_as_path_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_community_present = None
                                                        self.is_connector_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_label_index_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_metric_present = None
                                                        self.is_origin_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_ssa_present = None
                                                        self.is_tunnel_encap_present = None
                                                        self.l2tpv3_cookie = YList()
                                                        self.l2tpv3_cookie.parent = self
                                                        self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                        self.l2tpv3_session_id = None
                                                        self.label_index_attr = YList()
                                                        self.label_index_attr.parent = self
                                                        self.label_index_attr.name = 'label_index_attr'
                                                        self.local_preference = None
                                                        self.ls_attr = YList()
                                                        self.ls_attr.parent = self
                                                        self.ls_attr.name = 'ls_attr'
                                                        self.metric = None
                                                        self.neighbor_as = None
                                                        self.origin = None
                                                        self.originator = None
                                                        self.pe_distinguisher_label = YList()
                                                        self.pe_distinguisher_label.parent = self
                                                        self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.pmsi_type = None
                                                        self.pmsi_value = YList()
                                                        self.pmsi_value.parent = self
                                                        self.pmsi_value.name = 'pmsi_value'
                                                        self.ppm_pvalue = None
                                                        self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                        self.sr_policy_allocated_binding_sid.parent = self
                                                        self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                        self.sr_policy_binding_sid.parent = self
                                                        self.sr_policy_explicit_path = YList()
                                                        self.sr_policy_explicit_path.parent = self
                                                        self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                        self.sr_policy_preference = None
                                                        self.sr_tunnel_request_state = None
                                                        self.sr_tunnel_state = None
                                                        self.tunnel_encap_type = None
                                                        self.unknown_attribute = YList()
                                                        self.unknown_attribute.parent = self
                                                        self.unknown_attribute.name = 'unknown_attribute'


                                                    class SrPolicyBindingSid(object):
                                                        """
                                                        SR Policy Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                    class SrPolicyAllocatedBindingSid(object):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                    class Community(object):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                    class ExtendedCommunity(object):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                    class UnknownAttribute(object):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                    class Cluster(object):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                    class L2Tpv3Cookie(object):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                    class ConnectorValue(object):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                    class PmsiValue(object):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                    class LsAttr(object):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                    class LabelIndexAttr(object):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                    class PeDistinguisherLabel(object):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.label = None
                                                            self.pe_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.label is not None:
                                                                return True

                                                            if self.pe_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                    class SrPolicyExplicitPath(object):
                                                        """
                                                        SR Policy Explicit paths
                                                        
                                                        .. attribute:: sid
                                                        
                                                        	Sidlist for explicit path
                                                        	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of explicit path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.sid = YList()
                                                            self.sid.parent = self
                                                            self.sid.name = 'sid'
                                                            self.weight = None


                                                        class Sid(object):
                                                            """
                                                            Sidlist for explicit path
                                                            
                                                            .. attribute:: ipv4
                                                            
                                                            	IP Address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6
                                                            
                                                            	IPv6 address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label sid
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Sid Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4 = None
                                                                self.ipv6 = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4 is not None:
                                                                    return True

                                                                if self.ipv6 is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.sid is not None:
                                                                for child_ref in self.sid:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.weight is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.aggregator_address is not None:
                                                            return True

                                                        if self.aggregator_as is not None:
                                                            return True

                                                        if self.aigp_metric_value is not None:
                                                            return True

                                                        if self.as_path is not None:
                                                            return True

                                                        if self.cluster is not None:
                                                            for child_ref in self.cluster:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.community is not None:
                                                            for child_ref in self.community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.connector_type is not None:
                                                            return True

                                                        if self.connector_value is not None:
                                                            for child_ref in self.connector_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community is not None:
                                                            for child_ref in self.extended_community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community_flags is not None:
                                                            return True

                                                        if self.is_aggregator_present is not None:
                                                            return True

                                                        if self.is_aigp_present is not None:
                                                            return True

                                                        if self.is_as_path_present is not None:
                                                            return True

                                                        if self.is_atomic_aggregate_present is not None:
                                                            return True

                                                        if self.is_community_present is not None:
                                                            return True

                                                        if self.is_connector_present is not None:
                                                            return True

                                                        if self.is_extended_community_present is not None:
                                                            return True

                                                        if self.is_label_index_present is not None:
                                                            return True

                                                        if self.is_local_pref_present is not None:
                                                            return True

                                                        if self.is_ls_attribute_present is not None:
                                                            return True

                                                        if self.is_metric_present is not None:
                                                            return True

                                                        if self.is_origin_present is not None:
                                                            return True

                                                        if self.is_pe_distinguisher_label_present is not None:
                                                            return True

                                                        if self.is_pmsi_present is not None:
                                                            return True

                                                        if self.is_pppmp_present is not None:
                                                            return True

                                                        if self.is_ssa_present is not None:
                                                            return True

                                                        if self.is_tunnel_encap_present is not None:
                                                            return True

                                                        if self.l2tpv3_cookie is not None:
                                                            for child_ref in self.l2tpv3_cookie:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.l2tpv3_session_id is not None:
                                                            return True

                                                        if self.label_index_attr is not None:
                                                            for child_ref in self.label_index_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.local_preference is not None:
                                                            return True

                                                        if self.ls_attr is not None:
                                                            for child_ref in self.ls_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.metric is not None:
                                                            return True

                                                        if self.neighbor_as is not None:
                                                            return True

                                                        if self.origin is not None:
                                                            return True

                                                        if self.originator is not None:
                                                            return True

                                                        if self.pe_distinguisher_label is not None:
                                                            for child_ref in self.pe_distinguisher_label:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.pmsi_flags is not None:
                                                            return True

                                                        if self.pmsi_label is not None:
                                                            return True

                                                        if self.pmsi_type is not None:
                                                            return True

                                                        if self.pmsi_value is not None:
                                                            for child_ref in self.pmsi_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.ppm_pvalue is not None:
                                                            return True

                                                        if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_explicit_path is not None:
                                                            for child_ref in self.sr_policy_explicit_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.sr_policy_preference is not None:
                                                            return True

                                                        if self.sr_tunnel_request_state is not None:
                                                            return True

                                                        if self.sr_tunnel_state is not None:
                                                            return True

                                                        if self.tunnel_encap_type is not None:
                                                            return True

                                                        if self.unknown_attribute is not None:
                                                            for child_ref in self.unknown_attribute:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                                class AttrSet(object):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_encap_present
                                                    
                                                    	Tunnel Encap attribute present 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_policy_allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_binding_sid
                                                    
                                                    	SR Policy Binding sid
                                                    	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_explicit_path
                                                    
                                                    	SR Policy Explicit paths
                                                    	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                    
                                                    .. attribute:: sr_policy_preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_tunnel_request_state
                                                    
                                                    	SR Tunnel Request State
                                                    	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                    
                                                    .. attribute:: sr_tunnel_state
                                                    
                                                    	SR Tunnel State
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encap Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.aggregator_address = None
                                                        self.aggregator_as = None
                                                        self.aigp_metric_value = None
                                                        self.as_path = None
                                                        self.cluster = YList()
                                                        self.cluster.parent = self
                                                        self.cluster.name = 'cluster'
                                                        self.community = YList()
                                                        self.community.parent = self
                                                        self.community.name = 'community'
                                                        self.connector_type = None
                                                        self.connector_value = YList()
                                                        self.connector_value.parent = self
                                                        self.connector_value.name = 'connector_value'
                                                        self.extended_community = YList()
                                                        self.extended_community.parent = self
                                                        self.extended_community.name = 'extended_community'
                                                        self.extended_community_flags = None
                                                        self.is_aggregator_present = None
                                                        self.is_aigp_present = None
                                                        self.is_as_path_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_community_present = None
                                                        self.is_connector_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_label_index_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_metric_present = None
                                                        self.is_origin_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_ssa_present = None
                                                        self.is_tunnel_encap_present = None
                                                        self.l2tpv3_cookie = YList()
                                                        self.l2tpv3_cookie.parent = self
                                                        self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                        self.l2tpv3_session_id = None
                                                        self.label_index_attr = YList()
                                                        self.label_index_attr.parent = self
                                                        self.label_index_attr.name = 'label_index_attr'
                                                        self.local_preference = None
                                                        self.ls_attr = YList()
                                                        self.ls_attr.parent = self
                                                        self.ls_attr.name = 'ls_attr'
                                                        self.metric = None
                                                        self.neighbor_as = None
                                                        self.origin = None
                                                        self.originator = None
                                                        self.pe_distinguisher_label = YList()
                                                        self.pe_distinguisher_label.parent = self
                                                        self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.pmsi_type = None
                                                        self.pmsi_value = YList()
                                                        self.pmsi_value.parent = self
                                                        self.pmsi_value.name = 'pmsi_value'
                                                        self.ppm_pvalue = None
                                                        self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                        self.sr_policy_allocated_binding_sid.parent = self
                                                        self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                        self.sr_policy_binding_sid.parent = self
                                                        self.sr_policy_explicit_path = YList()
                                                        self.sr_policy_explicit_path.parent = self
                                                        self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                        self.sr_policy_preference = None
                                                        self.sr_tunnel_request_state = None
                                                        self.sr_tunnel_state = None
                                                        self.tunnel_encap_type = None
                                                        self.unknown_attribute = YList()
                                                        self.unknown_attribute.parent = self
                                                        self.unknown_attribute.name = 'unknown_attribute'


                                                    class SrPolicyBindingSid(object):
                                                        """
                                                        SR Policy Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                    class SrPolicyAllocatedBindingSid(object):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                    class Community(object):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                    class ExtendedCommunity(object):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                    class UnknownAttribute(object):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                    class Cluster(object):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                    class L2Tpv3Cookie(object):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                    class ConnectorValue(object):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                    class PmsiValue(object):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                    class LsAttr(object):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                    class LabelIndexAttr(object):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                    class PeDistinguisherLabel(object):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.label = None
                                                            self.pe_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.label is not None:
                                                                return True

                                                            if self.pe_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                    class SrPolicyExplicitPath(object):
                                                        """
                                                        SR Policy Explicit paths
                                                        
                                                        .. attribute:: sid
                                                        
                                                        	Sidlist for explicit path
                                                        	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of explicit path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.sid = YList()
                                                            self.sid.parent = self
                                                            self.sid.name = 'sid'
                                                            self.weight = None


                                                        class Sid(object):
                                                            """
                                                            Sidlist for explicit path
                                                            
                                                            .. attribute:: ipv4
                                                            
                                                            	IP Address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6
                                                            
                                                            	IPv6 address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label sid
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Sid Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4 = None
                                                                self.ipv6 = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4 is not None:
                                                                    return True

                                                                if self.ipv6 is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.sid is not None:
                                                                for child_ref in self.sid:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.weight is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.aggregator_address is not None:
                                                            return True

                                                        if self.aggregator_as is not None:
                                                            return True

                                                        if self.aigp_metric_value is not None:
                                                            return True

                                                        if self.as_path is not None:
                                                            return True

                                                        if self.cluster is not None:
                                                            for child_ref in self.cluster:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.community is not None:
                                                            for child_ref in self.community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.connector_type is not None:
                                                            return True

                                                        if self.connector_value is not None:
                                                            for child_ref in self.connector_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community is not None:
                                                            for child_ref in self.extended_community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community_flags is not None:
                                                            return True

                                                        if self.is_aggregator_present is not None:
                                                            return True

                                                        if self.is_aigp_present is not None:
                                                            return True

                                                        if self.is_as_path_present is not None:
                                                            return True

                                                        if self.is_atomic_aggregate_present is not None:
                                                            return True

                                                        if self.is_community_present is not None:
                                                            return True

                                                        if self.is_connector_present is not None:
                                                            return True

                                                        if self.is_extended_community_present is not None:
                                                            return True

                                                        if self.is_label_index_present is not None:
                                                            return True

                                                        if self.is_local_pref_present is not None:
                                                            return True

                                                        if self.is_ls_attribute_present is not None:
                                                            return True

                                                        if self.is_metric_present is not None:
                                                            return True

                                                        if self.is_origin_present is not None:
                                                            return True

                                                        if self.is_pe_distinguisher_label_present is not None:
                                                            return True

                                                        if self.is_pmsi_present is not None:
                                                            return True

                                                        if self.is_pppmp_present is not None:
                                                            return True

                                                        if self.is_ssa_present is not None:
                                                            return True

                                                        if self.is_tunnel_encap_present is not None:
                                                            return True

                                                        if self.l2tpv3_cookie is not None:
                                                            for child_ref in self.l2tpv3_cookie:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.l2tpv3_session_id is not None:
                                                            return True

                                                        if self.label_index_attr is not None:
                                                            for child_ref in self.label_index_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.local_preference is not None:
                                                            return True

                                                        if self.ls_attr is not None:
                                                            for child_ref in self.ls_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.metric is not None:
                                                            return True

                                                        if self.neighbor_as is not None:
                                                            return True

                                                        if self.origin is not None:
                                                            return True

                                                        if self.originator is not None:
                                                            return True

                                                        if self.pe_distinguisher_label is not None:
                                                            for child_ref in self.pe_distinguisher_label:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.pmsi_flags is not None:
                                                            return True

                                                        if self.pmsi_label is not None:
                                                            return True

                                                        if self.pmsi_type is not None:
                                                            return True

                                                        if self.pmsi_value is not None:
                                                            for child_ref in self.pmsi_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.ppm_pvalue is not None:
                                                            return True

                                                        if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_explicit_path is not None:
                                                            for child_ref in self.sr_policy_explicit_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.sr_policy_preference is not None:
                                                            return True

                                                        if self.sr_tunnel_request_state is not None:
                                                            return True

                                                        if self.sr_tunnel_state is not None:
                                                            return True

                                                        if self.tunnel_encap_type is not None:
                                                            return True

                                                        if self.unknown_attribute is not None:
                                                            for child_ref in self.unknown_attribute:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                                class RnhAddr(object):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.len = None
                                                        self.mac_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.len is not None:
                                                            return True

                                                        if self.mac_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                                class RibrnhIp(object):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.attr_set is not None and self.attr_set._has_data():
                                                        return True

                                                    if self.attribute_key_number is not None:
                                                        return True

                                                    if self.attribute_reuse_id_config is not None:
                                                        return True

                                                    if self.attribute_reuse_id_current is not None:
                                                        return True

                                                    if self.attribute_reuse_id_keys is not None:
                                                        return True

                                                    if self.attribute_reuse_id_max_id is not None:
                                                        return True

                                                    if self.attribute_reuse_id_node is not None:
                                                        return True

                                                    if self.attribute_reuse_id_recover_sec is not None:
                                                        return True

                                                    if self.common_attributes is not None and self.common_attributes._has_data():
                                                        return True

                                                    if self.is_application_gateway_present is not None:
                                                        return True

                                                    if self.is_as_path2_byte is not None:
                                                        return True

                                                    if self.is_attr_set_present is not None:
                                                        return True

                                                    if self.is_ribrnh_present is not None:
                                                        return True

                                                    if self.is_rnh_present is not None:
                                                        return True

                                                    if self.ribrnh_encap is not None:
                                                        return True

                                                    if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                        return True

                                                    if self.ribrnh_mac is not None:
                                                        return True

                                                    if self.ribrnh_table is not None:
                                                        return True

                                                    if self.ribrnh_vni is not None:
                                                        return True

                                                    if self.ribrnhip_table is not None:
                                                        return True

                                                    if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                        return True

                                                    if self.rnh_addr_len is not None:
                                                        return True

                                                    if self.rnh_len is not None:
                                                        return True

                                                    if self.rnh_type is not None:
                                                        return True

                                                    if self.set_aigp_inbound_igp is not None:
                                                        return True

                                                    if self.set_aigp_inbound_metric is not None:
                                                        return True

                                                    if self.vpn_distinguisher is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-process-instance-path'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.af_name is not None:
                                                    return True

                                                if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                    return True

                                                if self.label_fail is not None:
                                                    return True

                                                if self.label_o_or_version is not None:
                                                    return True

                                                if self.label_oor is not None:
                                                    return True

                                                if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                    return True

                                                if self.no_path is not None:
                                                    return True

                                                if self.path_information is not None and self.path_information._has_data():
                                                    return True

                                                if self.prefix_version is not None:
                                                    return True

                                                if self.process_instance_id is not None:
                                                    return True

                                                if self.route_distinguisher is not None:
                                                    return True

                                                if self.source_route_distinguisher is not None:
                                                    return True

                                                if self.source_vrf_name is not None:
                                                    return True

                                                if self.srcaf_name is not None:
                                                    return True

                                                if self.vrf_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath']['meta_info']


                                        class ActiveProcessInstancePath(object):
                                            """
                                            Active's paths for this net 
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: attributes_after_policy_in
                                            
                                            	Attributes after inbound policy applied
                                            	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn>`
                                            
                                            .. attribute:: label_fail
                                            
                                            	LSD label allocation failed 
                                            	**type**\:  bool
                                            
                                            .. attribute:: label_o_or_version
                                            
                                            	Label Version when OOR happens
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_oor
                                            
                                            	LSD label space is exhausted
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address_xr
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr>`
                                            
                                            .. attribute:: no_path
                                            
                                            	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                            	**type**\:  bool
                                            
                                            .. attribute:: path_information
                                            
                                            	Path information
                                            	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation>`
                                            
                                            .. attribute:: prefix_version
                                            
                                            	Version of BGP Prefix Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: process_instance_id
                                            
                                            	Process instance ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_route_distinguisher
                                            
                                            	Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_vrf_name
                                            
                                            	Name of the source VRF
                                            	**type**\:  str
                                            
                                            .. attribute:: srcaf_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.af_name = None
                                                self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn()
                                                self.attributes_after_policy_in.parent = self
                                                self.label_fail = None
                                                self.label_o_or_version = None
                                                self.label_oor = None
                                                self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr()
                                                self.neighbor_address_xr.parent = self
                                                self.no_path = None
                                                self.path_information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation()
                                                self.path_information.parent = self
                                                self.prefix_version = None
                                                self.process_instance_id = None
                                                self.route_distinguisher = None
                                                self.source_route_distinguisher = None
                                                self.source_vrf_name = None
                                                self.srcaf_name = None
                                                self.vrf_name = None


                                            class NeighborAddressXr(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr']['meta_info']


                                            class PathInformation(object):
                                                """
                                                Path information
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\:  bool
                                                
                                                .. attribute:: accept_own_self_originated_p_ath
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\:  bool
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\:  bool
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix>`
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\:  bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\:  bool
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.GwAddr>`
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_esi
                                                
                                                	Path has EVPN ESI
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_rcvd_label
                                                
                                                	Path has received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\:  bool
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebg_ps
                                                
                                                	Not advertised to EBGPs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi>`
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress>`
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop>`
                                                
                                                .. attribute:: nhte_tunnel
                                                
                                                	NH TE tunnel information
                                                	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhteTunnel>`
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\:  bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.accept_own_path = None
                                                    self.accept_own_self_originated_p_ath = None
                                                    self.add_path_orr_bitfield = YList()
                                                    self.add_path_orr_bitfield.parent = self
                                                    self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                    self.advertisedto_pe = None
                                                    self.aigp_metric = None
                                                    self.best_path_comp_stage = None
                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self.best_path_id = None
                                                    self.best_path_id_comp_winner = None
                                                    self.best_path_orr_bitfield = YList()
                                                    self.best_path_orr_bitfield.parent = self
                                                    self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self.dampen_penalty = None
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.fspec_invalid_path = None
                                                    self.graceful_shutdown = None
                                                    self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self.halflife_time = None
                                                    self.has_esi = None
                                                    self.has_gw_addr = None
                                                    self.has_local_net_label = None
                                                    self.has_mdt_group_addr = None
                                                    self.has_mvpn_extcomm = None
                                                    self.has_mvpn_nbr_addr = None
                                                    self.has_mvpn_nexthop_addr = None
                                                    self.has_mvpn_pmsi = None
                                                    self.has_rcvd_label = None
                                                    self.has_second_label = None
                                                    self.ibgp_signaled_validity = None
                                                    self.igp_metric = None
                                                    self.is_aggregation_suppressed = None
                                                    self.is_as_best = None
                                                    self.is_best_path = None
                                                    self.is_import_dampened = None
                                                    self.is_import_suspect = None
                                                    self.is_internal_path = None
                                                    self.is_partial_best = None
                                                    self.is_path_additional_path = None
                                                    self.is_path_advertised_local_as_only = None
                                                    self.is_path_af_install_eligible = None
                                                    self.is_path_backup = None
                                                    self.is_path_backup_protect_multipath = None
                                                    self.is_path_best_external = None
                                                    self.is_path_damped = None
                                                    self.is_path_from_confederation_peer = None
                                                    self.is_path_from_network_command = None
                                                    self.is_path_from_redistribute_command = None
                                                    self.is_path_from_route_reflector = None
                                                    self.is_path_history_held = None
                                                    self.is_path_imp_candidate = None
                                                    self.is_path_imported = None
                                                    self.is_path_local_aggregate = None
                                                    self.is_path_locally_sourced = None
                                                    self.is_path_long_lived_stale = None
                                                    self.is_path_multipath = None
                                                    self.is_path_nexthop_discarded = None
                                                    self.is_path_not_advertised = None
                                                    self.is_path_not_advertised_to_ebg_ps = None
                                                    self.is_path_received_only = None
                                                    self.is_path_reoriginated = None
                                                    self.is_path_reoriginated_stitching = None
                                                    self.is_path_stale = None
                                                    self.is_path_synced_with_igp = None
                                                    self.is_path_valid = None
                                                    self.is_path_vpn_only = None
                                                    self.is_permanent_path = None
                                                    self.is_received_path_not_modified = None
                                                    self.is_spkr_as_best = None
                                                    self.l2vpn_circuit_status_value = YList()
                                                    self.l2vpn_circuit_status_value.parent = self
                                                    self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                    self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi()
                                                    self.l2vpn_evpn_esi.parent = self
                                                    self.l2vpn_size = None
                                                    self.labeled_unicast_safi_path = None
                                                    self.local_label = None
                                                    self.local_nh = None
                                                    self.local_path_id = None
                                                    self.local_peers_advertised_to = YList()
                                                    self.local_peers_advertised_to.parent = self
                                                    self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                    self.maximum_suppress_time = None
                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self.mvpn_path_flags = None
                                                    self.mvpn_pmsi_flags = None
                                                    self.mvpn_pmsi_label = None
                                                    self.mvpn_pmsi_type = None
                                                    self.mvpn_pmsi_value = YList()
                                                    self.mvpn_pmsi_value.parent = self
                                                    self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                    self.mvpn_sfs_path = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.neighbor_router_id = None
                                                    self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop()
                                                    self.next_hop.parent = self
                                                    self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhteTunnel()
                                                    self.nhte_tunnel.parent = self
                                                    self.path_flags = None
                                                    self.path_flap_count = None
                                                    self.path_import_flags = None
                                                    self.path_rt_set_id = None
                                                    self.path_rt_set_route_count = None
                                                    self.path_table_version = None
                                                    self.path_weight = None
                                                    self.pe_peers_advertised_to = YList()
                                                    self.pe_peers_advertised_to.parent = self
                                                    self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                    self.rcvd_label = None
                                                    self.rcvd_path_id = None
                                                    self.reuse_value = None
                                                    self.rib_failed = None
                                                    self.route_type = None
                                                    self.rpki_origin_as_validation_disabled = None
                                                    self.rt_set_limit_enabled = None
                                                    self.second_label = None
                                                    self.seconds_since_first_flap = None
                                                    self.show_rpki_origin_as_validity = None
                                                    self.sn_rpki_origin_as_validity = None
                                                    self.suppress_penalty = None
                                                    self.time_to_unsuppress = None


                                                class BgpPrefix(object):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self.prefix_length = None


                                                    class Prefix(object):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.prefix is not None and self.prefix._has_data():
                                                            return True

                                                        if self.prefix_length is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix']['meta_info']


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress']['meta_info']


                                                class NextHop(object):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop']['meta_info']


                                                class NhteTunnel(object):
                                                    """
                                                    NH TE tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_te_tunnel
                                                    
                                                    	NH TE Tunnel info is present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last rib update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	tunnel name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	tunnel type
                                                    	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.binding_label = None
                                                        self.has_te_tunnel = None
                                                        self.is_tunnel_info_stale = None
                                                        self.is_tunnel_registered = None
                                                        self.is_tunnel_up = None
                                                        self.last_tunnel_update = None
                                                        self.tunnel_if_handle = None
                                                        self.tunnel_name = None
                                                        self.tunnel_type = None
                                                        self.tunnel_v6_enabled = None
                                                        self.tunnel_v6_required = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.binding_label is not None:
                                                            return True

                                                        if self.has_te_tunnel is not None:
                                                            return True

                                                        if self.is_tunnel_info_stale is not None:
                                                            return True

                                                        if self.is_tunnel_registered is not None:
                                                            return True

                                                        if self.is_tunnel_up is not None:
                                                            return True

                                                        if self.last_tunnel_update is not None:
                                                            return True

                                                        if self.tunnel_if_handle is not None:
                                                            return True

                                                        if self.tunnel_name is not None:
                                                            return True

                                                        if self.tunnel_type is not None:
                                                            return True

                                                        if self.tunnel_v6_enabled is not None:
                                                            return True

                                                        if self.tunnel_v6_required is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhteTunnel']['meta_info']


                                                class MdtGroupAddr(object):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr']['meta_info']


                                                class L2VpnEvpnEsi(object):
                                                    """
                                                    L2VPN EVPN ESI
                                                    
                                                    .. attribute:: esi
                                                    
                                                    	esi
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.esi = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.esi is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi']['meta_info']


                                                class GwAddr(object):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.len = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.len is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.GwAddr']['meta_info']


                                                class BestPathCompWinner(object):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner']['meta_info']


                                                class MvpnNbrAddr(object):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr']['meta_info']


                                                class MvpnNexthopAddr(object):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr']['meta_info']


                                                class L2VpnCircuitStatusValue(object):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                                class MvpnPmsiValue(object):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.ExtendedCommunity']['meta_info']


                                                class LocalPeersAdvertisedTo(object):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                                class PePeersAdvertisedTo(object):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo']['meta_info']


                                                class BestPathOrrBitfield(object):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield']['meta_info']


                                                class AddPathOrrBitfield(object):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.accept_own_path is not None:
                                                        return True

                                                    if self.accept_own_self_originated_p_ath is not None:
                                                        return True

                                                    if self.add_path_orr_bitfield is not None:
                                                        for child_ref in self.add_path_orr_bitfield:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.advertisedto_pe is not None:
                                                        return True

                                                    if self.aigp_metric is not None:
                                                        return True

                                                    if self.best_path_comp_stage is not None:
                                                        return True

                                                    if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                        return True

                                                    if self.best_path_id is not None:
                                                        return True

                                                    if self.best_path_id_comp_winner is not None:
                                                        return True

                                                    if self.best_path_orr_bitfield is not None:
                                                        for child_ref in self.best_path_orr_bitfield:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                        return True

                                                    if self.dampen_penalty is not None:
                                                        return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.fspec_invalid_path is not None:
                                                        return True

                                                    if self.graceful_shutdown is not None:
                                                        return True

                                                    if self.gw_addr is not None and self.gw_addr._has_data():
                                                        return True

                                                    if self.halflife_time is not None:
                                                        return True

                                                    if self.has_esi is not None:
                                                        return True

                                                    if self.has_gw_addr is not None:
                                                        return True

                                                    if self.has_local_net_label is not None:
                                                        return True

                                                    if self.has_mdt_group_addr is not None:
                                                        return True

                                                    if self.has_mvpn_extcomm is not None:
                                                        return True

                                                    if self.has_mvpn_nbr_addr is not None:
                                                        return True

                                                    if self.has_mvpn_nexthop_addr is not None:
                                                        return True

                                                    if self.has_mvpn_pmsi is not None:
                                                        return True

                                                    if self.has_rcvd_label is not None:
                                                        return True

                                                    if self.has_second_label is not None:
                                                        return True

                                                    if self.ibgp_signaled_validity is not None:
                                                        return True

                                                    if self.igp_metric is not None:
                                                        return True

                                                    if self.is_aggregation_suppressed is not None:
                                                        return True

                                                    if self.is_as_best is not None:
                                                        return True

                                                    if self.is_best_path is not None:
                                                        return True

                                                    if self.is_import_dampened is not None:
                                                        return True

                                                    if self.is_import_suspect is not None:
                                                        return True

                                                    if self.is_internal_path is not None:
                                                        return True

                                                    if self.is_partial_best is not None:
                                                        return True

                                                    if self.is_path_additional_path is not None:
                                                        return True

                                                    if self.is_path_advertised_local_as_only is not None:
                                                        return True

                                                    if self.is_path_af_install_eligible is not None:
                                                        return True

                                                    if self.is_path_backup is not None:
                                                        return True

                                                    if self.is_path_backup_protect_multipath is not None:
                                                        return True

                                                    if self.is_path_best_external is not None:
                                                        return True

                                                    if self.is_path_damped is not None:
                                                        return True

                                                    if self.is_path_from_confederation_peer is not None:
                                                        return True

                                                    if self.is_path_from_network_command is not None:
                                                        return True

                                                    if self.is_path_from_redistribute_command is not None:
                                                        return True

                                                    if self.is_path_from_route_reflector is not None:
                                                        return True

                                                    if self.is_path_history_held is not None:
                                                        return True

                                                    if self.is_path_imp_candidate is not None:
                                                        return True

                                                    if self.is_path_imported is not None:
                                                        return True

                                                    if self.is_path_local_aggregate is not None:
                                                        return True

                                                    if self.is_path_locally_sourced is not None:
                                                        return True

                                                    if self.is_path_long_lived_stale is not None:
                                                        return True

                                                    if self.is_path_multipath is not None:
                                                        return True

                                                    if self.is_path_nexthop_discarded is not None:
                                                        return True

                                                    if self.is_path_not_advertised is not None:
                                                        return True

                                                    if self.is_path_not_advertised_to_ebg_ps is not None:
                                                        return True

                                                    if self.is_path_received_only is not None:
                                                        return True

                                                    if self.is_path_reoriginated is not None:
                                                        return True

                                                    if self.is_path_reoriginated_stitching is not None:
                                                        return True

                                                    if self.is_path_stale is not None:
                                                        return True

                                                    if self.is_path_synced_with_igp is not None:
                                                        return True

                                                    if self.is_path_valid is not None:
                                                        return True

                                                    if self.is_path_vpn_only is not None:
                                                        return True

                                                    if self.is_permanent_path is not None:
                                                        return True

                                                    if self.is_received_path_not_modified is not None:
                                                        return True

                                                    if self.is_spkr_as_best is not None:
                                                        return True

                                                    if self.l2vpn_circuit_status_value is not None:
                                                        for child_ref in self.l2vpn_circuit_status_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                        return True

                                                    if self.l2vpn_size is not None:
                                                        return True

                                                    if self.labeled_unicast_safi_path is not None:
                                                        return True

                                                    if self.local_label is not None:
                                                        return True

                                                    if self.local_nh is not None:
                                                        return True

                                                    if self.local_path_id is not None:
                                                        return True

                                                    if self.local_peers_advertised_to is not None:
                                                        for child_ref in self.local_peers_advertised_to:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.maximum_suppress_time is not None:
                                                        return True

                                                    if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                        return True

                                                    if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                        return True

                                                    if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                        return True

                                                    if self.mvpn_path_flags is not None:
                                                        return True

                                                    if self.mvpn_pmsi_flags is not None:
                                                        return True

                                                    if self.mvpn_pmsi_label is not None:
                                                        return True

                                                    if self.mvpn_pmsi_type is not None:
                                                        return True

                                                    if self.mvpn_pmsi_value is not None:
                                                        for child_ref in self.mvpn_pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.mvpn_sfs_path is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.neighbor_router_id is not None:
                                                        return True

                                                    if self.next_hop is not None and self.next_hop._has_data():
                                                        return True

                                                    if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                        return True

                                                    if self.path_flags is not None:
                                                        return True

                                                    if self.path_flap_count is not None:
                                                        return True

                                                    if self.path_import_flags is not None:
                                                        return True

                                                    if self.path_rt_set_id is not None:
                                                        return True

                                                    if self.path_rt_set_route_count is not None:
                                                        return True

                                                    if self.path_table_version is not None:
                                                        return True

                                                    if self.path_weight is not None:
                                                        return True

                                                    if self.pe_peers_advertised_to is not None:
                                                        for child_ref in self.pe_peers_advertised_to:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.rcvd_label is not None:
                                                        return True

                                                    if self.rcvd_path_id is not None:
                                                        return True

                                                    if self.reuse_value is not None:
                                                        return True

                                                    if self.rib_failed is not None:
                                                        return True

                                                    if self.route_type is not None:
                                                        return True

                                                    if self.rpki_origin_as_validation_disabled is not None:
                                                        return True

                                                    if self.rt_set_limit_enabled is not None:
                                                        return True

                                                    if self.second_label is not None:
                                                        return True

                                                    if self.seconds_since_first_flap is not None:
                                                        return True

                                                    if self.show_rpki_origin_as_validity is not None:
                                                        return True

                                                    if self.sn_rpki_origin_as_validity is not None:
                                                        return True

                                                    if self.suppress_penalty is not None:
                                                        return True

                                                    if self.time_to_unsuppress is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation']['meta_info']


                                            class AttributesAfterPolicyIn(object):
                                                """
                                                Attributes after inbound policy applied
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\:  bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\:  bool
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                    self.attr_set.parent = self
                                                    self.attribute_key_number = None
                                                    self.attribute_reuse_id_config = None
                                                    self.attribute_reuse_id_current = None
                                                    self.attribute_reuse_id_keys = None
                                                    self.attribute_reuse_id_max_id = None
                                                    self.attribute_reuse_id_node = None
                                                    self.attribute_reuse_id_recover_sec = None
                                                    self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self.is_application_gateway_present = None
                                                    self.is_as_path2_byte = None
                                                    self.is_attr_set_present = None
                                                    self.is_ribrnh_present = None
                                                    self.is_rnh_present = None
                                                    self.ribrnh_encap = None
                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self.ribrnh_mac = None
                                                    self.ribrnh_table = None
                                                    self.ribrnh_vni = None
                                                    self.ribrnhip_table = None
                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self.rnh_addr_len = None
                                                    self.rnh_len = None
                                                    self.rnh_type = None
                                                    self.set_aigp_inbound_igp = None
                                                    self.set_aigp_inbound_metric = None
                                                    self.vpn_distinguisher = None


                                                class CommonAttributes(object):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_encap_present
                                                    
                                                    	Tunnel Encap attribute present 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_policy_allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_binding_sid
                                                    
                                                    	SR Policy Binding sid
                                                    	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_explicit_path
                                                    
                                                    	SR Policy Explicit paths
                                                    	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                    
                                                    .. attribute:: sr_policy_preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_tunnel_request_state
                                                    
                                                    	SR Tunnel Request State
                                                    	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                    
                                                    .. attribute:: sr_tunnel_state
                                                    
                                                    	SR Tunnel State
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encap Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.aggregator_address = None
                                                        self.aggregator_as = None
                                                        self.aigp_metric_value = None
                                                        self.as_path = None
                                                        self.cluster = YList()
                                                        self.cluster.parent = self
                                                        self.cluster.name = 'cluster'
                                                        self.community = YList()
                                                        self.community.parent = self
                                                        self.community.name = 'community'
                                                        self.connector_type = None
                                                        self.connector_value = YList()
                                                        self.connector_value.parent = self
                                                        self.connector_value.name = 'connector_value'
                                                        self.extended_community = YList()
                                                        self.extended_community.parent = self
                                                        self.extended_community.name = 'extended_community'
                                                        self.extended_community_flags = None
                                                        self.is_aggregator_present = None
                                                        self.is_aigp_present = None
                                                        self.is_as_path_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_community_present = None
                                                        self.is_connector_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_label_index_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_metric_present = None
                                                        self.is_origin_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_ssa_present = None
                                                        self.is_tunnel_encap_present = None
                                                        self.l2tpv3_cookie = YList()
                                                        self.l2tpv3_cookie.parent = self
                                                        self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                        self.l2tpv3_session_id = None
                                                        self.label_index_attr = YList()
                                                        self.label_index_attr.parent = self
                                                        self.label_index_attr.name = 'label_index_attr'
                                                        self.local_preference = None
                                                        self.ls_attr = YList()
                                                        self.ls_attr.parent = self
                                                        self.ls_attr.name = 'ls_attr'
                                                        self.metric = None
                                                        self.neighbor_as = None
                                                        self.origin = None
                                                        self.originator = None
                                                        self.pe_distinguisher_label = YList()
                                                        self.pe_distinguisher_label.parent = self
                                                        self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.pmsi_type = None
                                                        self.pmsi_value = YList()
                                                        self.pmsi_value.parent = self
                                                        self.pmsi_value.name = 'pmsi_value'
                                                        self.ppm_pvalue = None
                                                        self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                        self.sr_policy_allocated_binding_sid.parent = self
                                                        self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                        self.sr_policy_binding_sid.parent = self
                                                        self.sr_policy_explicit_path = YList()
                                                        self.sr_policy_explicit_path.parent = self
                                                        self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                        self.sr_policy_preference = None
                                                        self.sr_tunnel_request_state = None
                                                        self.sr_tunnel_state = None
                                                        self.tunnel_encap_type = None
                                                        self.unknown_attribute = YList()
                                                        self.unknown_attribute.parent = self
                                                        self.unknown_attribute.name = 'unknown_attribute'


                                                    class SrPolicyBindingSid(object):
                                                        """
                                                        SR Policy Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                    class SrPolicyAllocatedBindingSid(object):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                    class Community(object):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                    class ExtendedCommunity(object):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                    class UnknownAttribute(object):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                    class Cluster(object):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                    class L2Tpv3Cookie(object):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                    class ConnectorValue(object):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                    class PmsiValue(object):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                    class LsAttr(object):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                    class LabelIndexAttr(object):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                    class PeDistinguisherLabel(object):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.label = None
                                                            self.pe_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.label is not None:
                                                                return True

                                                            if self.pe_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                    class SrPolicyExplicitPath(object):
                                                        """
                                                        SR Policy Explicit paths
                                                        
                                                        .. attribute:: sid
                                                        
                                                        	Sidlist for explicit path
                                                        	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of explicit path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.sid = YList()
                                                            self.sid.parent = self
                                                            self.sid.name = 'sid'
                                                            self.weight = None


                                                        class Sid(object):
                                                            """
                                                            Sidlist for explicit path
                                                            
                                                            .. attribute:: ipv4
                                                            
                                                            	IP Address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6
                                                            
                                                            	IPv6 address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label sid
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Sid Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4 = None
                                                                self.ipv6 = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4 is not None:
                                                                    return True

                                                                if self.ipv6 is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.sid is not None:
                                                                for child_ref in self.sid:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.weight is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.aggregator_address is not None:
                                                            return True

                                                        if self.aggregator_as is not None:
                                                            return True

                                                        if self.aigp_metric_value is not None:
                                                            return True

                                                        if self.as_path is not None:
                                                            return True

                                                        if self.cluster is not None:
                                                            for child_ref in self.cluster:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.community is not None:
                                                            for child_ref in self.community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.connector_type is not None:
                                                            return True

                                                        if self.connector_value is not None:
                                                            for child_ref in self.connector_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community is not None:
                                                            for child_ref in self.extended_community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community_flags is not None:
                                                            return True

                                                        if self.is_aggregator_present is not None:
                                                            return True

                                                        if self.is_aigp_present is not None:
                                                            return True

                                                        if self.is_as_path_present is not None:
                                                            return True

                                                        if self.is_atomic_aggregate_present is not None:
                                                            return True

                                                        if self.is_community_present is not None:
                                                            return True

                                                        if self.is_connector_present is not None:
                                                            return True

                                                        if self.is_extended_community_present is not None:
                                                            return True

                                                        if self.is_label_index_present is not None:
                                                            return True

                                                        if self.is_local_pref_present is not None:
                                                            return True

                                                        if self.is_ls_attribute_present is not None:
                                                            return True

                                                        if self.is_metric_present is not None:
                                                            return True

                                                        if self.is_origin_present is not None:
                                                            return True

                                                        if self.is_pe_distinguisher_label_present is not None:
                                                            return True

                                                        if self.is_pmsi_present is not None:
                                                            return True

                                                        if self.is_pppmp_present is not None:
                                                            return True

                                                        if self.is_ssa_present is not None:
                                                            return True

                                                        if self.is_tunnel_encap_present is not None:
                                                            return True

                                                        if self.l2tpv3_cookie is not None:
                                                            for child_ref in self.l2tpv3_cookie:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.l2tpv3_session_id is not None:
                                                            return True

                                                        if self.label_index_attr is not None:
                                                            for child_ref in self.label_index_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.local_preference is not None:
                                                            return True

                                                        if self.ls_attr is not None:
                                                            for child_ref in self.ls_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.metric is not None:
                                                            return True

                                                        if self.neighbor_as is not None:
                                                            return True

                                                        if self.origin is not None:
                                                            return True

                                                        if self.originator is not None:
                                                            return True

                                                        if self.pe_distinguisher_label is not None:
                                                            for child_ref in self.pe_distinguisher_label:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.pmsi_flags is not None:
                                                            return True

                                                        if self.pmsi_label is not None:
                                                            return True

                                                        if self.pmsi_type is not None:
                                                            return True

                                                        if self.pmsi_value is not None:
                                                            for child_ref in self.pmsi_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.ppm_pvalue is not None:
                                                            return True

                                                        if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_explicit_path is not None:
                                                            for child_ref in self.sr_policy_explicit_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.sr_policy_preference is not None:
                                                            return True

                                                        if self.sr_tunnel_request_state is not None:
                                                            return True

                                                        if self.sr_tunnel_state is not None:
                                                            return True

                                                        if self.tunnel_encap_type is not None:
                                                            return True

                                                        if self.unknown_attribute is not None:
                                                            for child_ref in self.unknown_attribute:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                                class AttrSet(object):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_encap_present
                                                    
                                                    	Tunnel Encap attribute present 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_policy_allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_binding_sid
                                                    
                                                    	SR Policy Binding sid
                                                    	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_explicit_path
                                                    
                                                    	SR Policy Explicit paths
                                                    	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                    
                                                    .. attribute:: sr_policy_preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_tunnel_request_state
                                                    
                                                    	SR Tunnel Request State
                                                    	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                    
                                                    .. attribute:: sr_tunnel_state
                                                    
                                                    	SR Tunnel State
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encap Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.aggregator_address = None
                                                        self.aggregator_as = None
                                                        self.aigp_metric_value = None
                                                        self.as_path = None
                                                        self.cluster = YList()
                                                        self.cluster.parent = self
                                                        self.cluster.name = 'cluster'
                                                        self.community = YList()
                                                        self.community.parent = self
                                                        self.community.name = 'community'
                                                        self.connector_type = None
                                                        self.connector_value = YList()
                                                        self.connector_value.parent = self
                                                        self.connector_value.name = 'connector_value'
                                                        self.extended_community = YList()
                                                        self.extended_community.parent = self
                                                        self.extended_community.name = 'extended_community'
                                                        self.extended_community_flags = None
                                                        self.is_aggregator_present = None
                                                        self.is_aigp_present = None
                                                        self.is_as_path_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_community_present = None
                                                        self.is_connector_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_label_index_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_metric_present = None
                                                        self.is_origin_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_ssa_present = None
                                                        self.is_tunnel_encap_present = None
                                                        self.l2tpv3_cookie = YList()
                                                        self.l2tpv3_cookie.parent = self
                                                        self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                        self.l2tpv3_session_id = None
                                                        self.label_index_attr = YList()
                                                        self.label_index_attr.parent = self
                                                        self.label_index_attr.name = 'label_index_attr'
                                                        self.local_preference = None
                                                        self.ls_attr = YList()
                                                        self.ls_attr.parent = self
                                                        self.ls_attr.name = 'ls_attr'
                                                        self.metric = None
                                                        self.neighbor_as = None
                                                        self.origin = None
                                                        self.originator = None
                                                        self.pe_distinguisher_label = YList()
                                                        self.pe_distinguisher_label.parent = self
                                                        self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.pmsi_type = None
                                                        self.pmsi_value = YList()
                                                        self.pmsi_value.parent = self
                                                        self.pmsi_value.name = 'pmsi_value'
                                                        self.ppm_pvalue = None
                                                        self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                        self.sr_policy_allocated_binding_sid.parent = self
                                                        self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                        self.sr_policy_binding_sid.parent = self
                                                        self.sr_policy_explicit_path = YList()
                                                        self.sr_policy_explicit_path.parent = self
                                                        self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                        self.sr_policy_preference = None
                                                        self.sr_tunnel_request_state = None
                                                        self.sr_tunnel_state = None
                                                        self.tunnel_encap_type = None
                                                        self.unknown_attribute = YList()
                                                        self.unknown_attribute.parent = self
                                                        self.unknown_attribute.name = 'unknown_attribute'


                                                    class SrPolicyBindingSid(object):
                                                        """
                                                        SR Policy Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                    class SrPolicyAllocatedBindingSid(object):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                    class Community(object):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                    class ExtendedCommunity(object):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                    class UnknownAttribute(object):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                    class Cluster(object):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                    class L2Tpv3Cookie(object):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                    class ConnectorValue(object):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                    class PmsiValue(object):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                    class LsAttr(object):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                    class LabelIndexAttr(object):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                    class PeDistinguisherLabel(object):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.label = None
                                                            self.pe_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.label is not None:
                                                                return True

                                                            if self.pe_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                    class SrPolicyExplicitPath(object):
                                                        """
                                                        SR Policy Explicit paths
                                                        
                                                        .. attribute:: sid
                                                        
                                                        	Sidlist for explicit path
                                                        	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of explicit path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.sid = YList()
                                                            self.sid.parent = self
                                                            self.sid.name = 'sid'
                                                            self.weight = None


                                                        class Sid(object):
                                                            """
                                                            Sidlist for explicit path
                                                            
                                                            .. attribute:: ipv4
                                                            
                                                            	IP Address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6
                                                            
                                                            	IPv6 address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label sid
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Sid Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4 = None
                                                                self.ipv6 = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4 is not None:
                                                                    return True

                                                                if self.ipv6 is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.sid is not None:
                                                                for child_ref in self.sid:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.weight is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.aggregator_address is not None:
                                                            return True

                                                        if self.aggregator_as is not None:
                                                            return True

                                                        if self.aigp_metric_value is not None:
                                                            return True

                                                        if self.as_path is not None:
                                                            return True

                                                        if self.cluster is not None:
                                                            for child_ref in self.cluster:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.community is not None:
                                                            for child_ref in self.community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.connector_type is not None:
                                                            return True

                                                        if self.connector_value is not None:
                                                            for child_ref in self.connector_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community is not None:
                                                            for child_ref in self.extended_community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community_flags is not None:
                                                            return True

                                                        if self.is_aggregator_present is not None:
                                                            return True

                                                        if self.is_aigp_present is not None:
                                                            return True

                                                        if self.is_as_path_present is not None:
                                                            return True

                                                        if self.is_atomic_aggregate_present is not None:
                                                            return True

                                                        if self.is_community_present is not None:
                                                            return True

                                                        if self.is_connector_present is not None:
                                                            return True

                                                        if self.is_extended_community_present is not None:
                                                            return True

                                                        if self.is_label_index_present is not None:
                                                            return True

                                                        if self.is_local_pref_present is not None:
                                                            return True

                                                        if self.is_ls_attribute_present is not None:
                                                            return True

                                                        if self.is_metric_present is not None:
                                                            return True

                                                        if self.is_origin_present is not None:
                                                            return True

                                                        if self.is_pe_distinguisher_label_present is not None:
                                                            return True

                                                        if self.is_pmsi_present is not None:
                                                            return True

                                                        if self.is_pppmp_present is not None:
                                                            return True

                                                        if self.is_ssa_present is not None:
                                                            return True

                                                        if self.is_tunnel_encap_present is not None:
                                                            return True

                                                        if self.l2tpv3_cookie is not None:
                                                            for child_ref in self.l2tpv3_cookie:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.l2tpv3_session_id is not None:
                                                            return True

                                                        if self.label_index_attr is not None:
                                                            for child_ref in self.label_index_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.local_preference is not None:
                                                            return True

                                                        if self.ls_attr is not None:
                                                            for child_ref in self.ls_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.metric is not None:
                                                            return True

                                                        if self.neighbor_as is not None:
                                                            return True

                                                        if self.origin is not None:
                                                            return True

                                                        if self.originator is not None:
                                                            return True

                                                        if self.pe_distinguisher_label is not None:
                                                            for child_ref in self.pe_distinguisher_label:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.pmsi_flags is not None:
                                                            return True

                                                        if self.pmsi_label is not None:
                                                            return True

                                                        if self.pmsi_type is not None:
                                                            return True

                                                        if self.pmsi_value is not None:
                                                            for child_ref in self.pmsi_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.ppm_pvalue is not None:
                                                            return True

                                                        if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_explicit_path is not None:
                                                            for child_ref in self.sr_policy_explicit_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.sr_policy_preference is not None:
                                                            return True

                                                        if self.sr_tunnel_request_state is not None:
                                                            return True

                                                        if self.sr_tunnel_state is not None:
                                                            return True

                                                        if self.tunnel_encap_type is not None:
                                                            return True

                                                        if self.unknown_attribute is not None:
                                                            for child_ref in self.unknown_attribute:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                                class RnhAddr(object):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.len = None
                                                        self.mac_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.len is not None:
                                                            return True

                                                        if self.mac_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                                class RibrnhIp(object):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.attr_set is not None and self.attr_set._has_data():
                                                        return True

                                                    if self.attribute_key_number is not None:
                                                        return True

                                                    if self.attribute_reuse_id_config is not None:
                                                        return True

                                                    if self.attribute_reuse_id_current is not None:
                                                        return True

                                                    if self.attribute_reuse_id_keys is not None:
                                                        return True

                                                    if self.attribute_reuse_id_max_id is not None:
                                                        return True

                                                    if self.attribute_reuse_id_node is not None:
                                                        return True

                                                    if self.attribute_reuse_id_recover_sec is not None:
                                                        return True

                                                    if self.common_attributes is not None and self.common_attributes._has_data():
                                                        return True

                                                    if self.is_application_gateway_present is not None:
                                                        return True

                                                    if self.is_as_path2_byte is not None:
                                                        return True

                                                    if self.is_attr_set_present is not None:
                                                        return True

                                                    if self.is_ribrnh_present is not None:
                                                        return True

                                                    if self.is_rnh_present is not None:
                                                        return True

                                                    if self.ribrnh_encap is not None:
                                                        return True

                                                    if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                        return True

                                                    if self.ribrnh_mac is not None:
                                                        return True

                                                    if self.ribrnh_table is not None:
                                                        return True

                                                    if self.ribrnh_vni is not None:
                                                        return True

                                                    if self.ribrnhip_table is not None:
                                                        return True

                                                    if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                        return True

                                                    if self.rnh_addr_len is not None:
                                                        return True

                                                    if self.rnh_len is not None:
                                                        return True

                                                    if self.rnh_type is not None:
                                                        return True

                                                    if self.set_aigp_inbound_igp is not None:
                                                        return True

                                                    if self.set_aigp_inbound_metric is not None:
                                                        return True

                                                    if self.vpn_distinguisher is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-process-instance-path'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.af_name is not None:
                                                    return True

                                                if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                    return True

                                                if self.label_fail is not None:
                                                    return True

                                                if self.label_o_or_version is not None:
                                                    return True

                                                if self.label_oor is not None:
                                                    return True

                                                if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                    return True

                                                if self.no_path is not None:
                                                    return True

                                                if self.path_information is not None and self.path_information._has_data():
                                                    return True

                                                if self.prefix_version is not None:
                                                    return True

                                                if self.process_instance_id is not None:
                                                    return True

                                                if self.route_distinguisher is not None:
                                                    return True

                                                if self.source_route_distinguisher is not None:
                                                    return True

                                                if self.source_vrf_name is not None:
                                                    return True

                                                if self.srcaf_name is not None:
                                                    return True

                                                if self.vrf_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath']['meta_info']


                                        class LocalPathElement(object):
                                            """
                                            Local path element list
                                            
                                            .. attribute:: is_perm_path_pelem
                                            
                                            	Pelem for permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.NhteTunnel>`
                                            
                                            .. attribute:: pelem_flags
                                            
                                            	Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_gw_metric
                                            
                                            	Gateway metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_addpath_table_attr_version
                                            
                                            	No\-addpath Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_bestpath_table_attr_version
                                            
                                            	No\-bestpath Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_flags
                                            
                                            	Path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pelem_path_id
                                            
                                            	Local Path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_neighbor_addr
                                            
                                            	Path neighbor address
                                            	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr>`
                                            
                                            .. attribute:: pelem_path_nexthop
                                            
                                            	Path nexthop address
                                            	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop>`
                                            
                                            .. attribute:: pelem_path_peer_path_id
                                            
                                            	Path peer path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_table_attr_version
                                            
                                            	Path Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_table_attr_version
                                            
                                            	Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_version
                                            
                                            	Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_perm_path_pelem = None
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.pelem_flags = None
                                                self.pelem_gw_metric = None
                                                self.pelem_no_addpath_table_attr_version = None
                                                self.pelem_no_bestpath_table_attr_version = None
                                                self.pelem_path_flags = None
                                                self.pelem_path_id = None
                                                self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr()
                                                self.pelem_path_neighbor_addr.parent = self
                                                self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop()
                                                self.pelem_path_nexthop.parent = self
                                                self.pelem_path_peer_path_id = None
                                                self.pelem_path_table_attr_version = None
                                                self.pelem_table_attr_version = None
                                                self.pelem_version = None


                                            class PelemPathNexthop(object):
                                                """
                                                Path nexthop address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-nexthop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.NhteTunnel']['meta_info']


                                            class PelemPathNeighborAddr(object):
                                                """
                                                Path neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-neighbor-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-path-element'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_perm_path_pelem is not None:
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.pelem_flags is not None:
                                                    return True

                                                if self.pelem_gw_metric is not None:
                                                    return True

                                                if self.pelem_no_addpath_table_attr_version is not None:
                                                    return True

                                                if self.pelem_no_bestpath_table_attr_version is not None:
                                                    return True

                                                if self.pelem_path_flags is not None:
                                                    return True

                                                if self.pelem_path_id is not None:
                                                    return True

                                                if self.pelem_path_neighbor_addr is not None and self.pelem_path_neighbor_addr._has_data():
                                                    return True

                                                if self.pelem_path_nexthop is not None and self.pelem_path_nexthop._has_data():
                                                    return True

                                                if self.pelem_path_peer_path_id is not None:
                                                    return True

                                                if self.pelem_path_table_attr_version is not None:
                                                    return True

                                                if self.pelem_table_attr_version is not None:
                                                    return True

                                                if self.pelem_version is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement']['meta_info']


                                        class ActivePathElement(object):
                                            """
                                            Path element list received from Active inst
                                            
                                            .. attribute:: is_perm_path_pelem
                                            
                                            	Pelem for permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.NhteTunnel>`
                                            
                                            .. attribute:: pelem_flags
                                            
                                            	Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_gw_metric
                                            
                                            	Gateway metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_addpath_table_attr_version
                                            
                                            	No\-addpath Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_bestpath_table_attr_version
                                            
                                            	No\-bestpath Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_flags
                                            
                                            	Path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pelem_path_id
                                            
                                            	Local Path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_neighbor_addr
                                            
                                            	Path neighbor address
                                            	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr>`
                                            
                                            .. attribute:: pelem_path_nexthop
                                            
                                            	Path nexthop address
                                            	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop>`
                                            
                                            .. attribute:: pelem_path_peer_path_id
                                            
                                            	Path peer path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_table_attr_version
                                            
                                            	Path Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_table_attr_version
                                            
                                            	Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_version
                                            
                                            	Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_perm_path_pelem = None
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.pelem_flags = None
                                                self.pelem_gw_metric = None
                                                self.pelem_no_addpath_table_attr_version = None
                                                self.pelem_no_bestpath_table_attr_version = None
                                                self.pelem_path_flags = None
                                                self.pelem_path_id = None
                                                self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr()
                                                self.pelem_path_neighbor_addr.parent = self
                                                self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop()
                                                self.pelem_path_nexthop.parent = self
                                                self.pelem_path_peer_path_id = None
                                                self.pelem_path_table_attr_version = None
                                                self.pelem_table_attr_version = None
                                                self.pelem_version = None


                                            class PelemPathNexthop(object):
                                                """
                                                Path nexthop address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-nexthop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.NhteTunnel']['meta_info']


                                            class PelemPathNeighborAddr(object):
                                                """
                                                Path neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-neighbor-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-path-element'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_perm_path_pelem is not None:
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.pelem_flags is not None:
                                                    return True

                                                if self.pelem_gw_metric is not None:
                                                    return True

                                                if self.pelem_no_addpath_table_attr_version is not None:
                                                    return True

                                                if self.pelem_no_bestpath_table_attr_version is not None:
                                                    return True

                                                if self.pelem_path_flags is not None:
                                                    return True

                                                if self.pelem_path_id is not None:
                                                    return True

                                                if self.pelem_path_neighbor_addr is not None and self.pelem_path_neighbor_addr._has_data():
                                                    return True

                                                if self.pelem_path_nexthop is not None and self.pelem_path_nexthop._has_data():
                                                    return True

                                                if self.pelem_path_peer_path_id is not None:
                                                    return True

                                                if self.pelem_path_table_attr_version is not None:
                                                    return True

                                                if self.pelem_table_attr_version is not None:
                                                    return True

                                                if self.pelem_version is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-prefix'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.active_path_element is not None:
                                                for child_ref in self.active_path_element:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.active_process_instance_path is not None:
                                                for child_ref in self.active_process_instance_path:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.add_path_orr_bitfield is not None:
                                                for child_ref in self.add_path_orr_bitfield:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.advertisedto_pe is not None:
                                                return True

                                            if self.af_name is not None:
                                                return True

                                            if self.best_path_orr_bitfield is not None:
                                                for child_ref in self.best_path_orr_bitfield:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                return True

                                            if self.bit is not None:
                                                return True

                                            if self.flags is not None:
                                                return True

                                            if self.gateway_array is not None:
                                                return True

                                            if self.has_inconsistent_paths is not None:
                                                return True

                                            if self.has_lbl_retained is not None:
                                                return True

                                            if self.has_local_label is not None:
                                                return True

                                            if self.is_net_aggregation_suppressed is not None:
                                                return True

                                            if self.is_net_ldp_signaled is not None:
                                                return True

                                            if self.is_permanent_network is not None:
                                                return True

                                            if self.local_path_element is not None:
                                                for child_ref in self.local_path_element:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.local_peers_advertised_to is not None:
                                                for child_ref in self.local_peers_advertised_to:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.local_process_instance_path is not None:
                                                for child_ref in self.local_process_instance_path:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.net_backup_available is not None:
                                                return True

                                            if self.net_backup_label_rewrite_available is not None:
                                                return True

                                            if self.net_eibgp_multipath is not None:
                                                return True

                                            if self.net_extended_flags is not None:
                                                return True

                                            if self.net_flags is not None:
                                                return True

                                            if self.net_local_label is not None:
                                                return True

                                            if self.net_local_label_rewrite is not None:
                                                return True

                                            if self.net_local_label_srgb is not None:
                                                return True

                                            if self.net_multipath is not None:
                                                return True

                                            if self.network_prefix is not None:
                                                return True

                                            if self.num_of_path is not None:
                                                return True

                                            if self.pe_peers_advertised_to is not None:
                                                for child_ref in self.pe_peers_advertised_to:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.process_instance_id is not None:
                                                return True

                                            if self.rd is not None:
                                                return True

                                            if self.resilient_nexthop_set is not None:
                                                return True

                                            if self.rib_failed is not None:
                                                return True

                                            if self.route_distinguisher is not None:
                                                return True

                                            if self.table_brib_version is not None:
                                                return True

                                            if self.table_version is not None:
                                                return True

                                            if self.version is not None:
                                                return True

                                            if self.version_age is not None and self.version_age._has_data():
                                                return True

                                            if self.version_timestamp is not None and self.version_timestamp._has_data():
                                                return True

                                            if self.vrf_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-prefixes'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.network_prefix is not None:
                                            for child_ref in self.network_prefix:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkPrefixes']['meta_info']


                                class AdvertisedPathXr(object):
                                    """
                                    The BGP Advertised path table (bestpath)
                                    
                                    .. attribute:: advertised_path
                                    
                                    	A BGP Advertised path table entry (bestpath)
                                    	**type**\: list of    :py:class:`AdvertisedPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.advertised_path = YList()
                                        self.advertised_path.parent = self
                                        self.advertised_path.name = 'advertised_path'


                                    class AdvertisedPath(object):
                                        """
                                        A BGP Advertised path table entry (bestpath)
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr>`
                                        
                                        .. attribute:: network
                                        
                                        	Network Prefix in Hex format
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self.label_fail = None
                                            self.label_o_or_version = None
                                            self.label_oor = None
                                            self.neighbor_address = None
                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self.network = None
                                            self.no_path = None
                                            self.path_information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation()
                                            self.path_information.parent = self
                                            self.prefix_length = None
                                            self.prefix_version = None
                                            self.process_instance_id = None
                                            self.rd = None
                                            self.route_distinguisher = None
                                            self.source_route_distinguisher = None
                                            self.source_vrf_name = None
                                            self.srcaf_name = None
                                            self.vrf_name = None


                                        class NeighborAddressXr(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr']['meta_info']


                                        class PathInformation(object):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_esi
                                            
                                            	Path has EVPN ESI
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_rcvd_label
                                            
                                            	Path has received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebg_ps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2VpnEvpnEsi>`
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop>`
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhteTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_p_ath = None
                                                self.add_path_orr_bitfield = YList()
                                                self.add_path_orr_bitfield.parent = self
                                                self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                self.advertisedto_pe = None
                                                self.aigp_metric = None
                                                self.best_path_comp_stage = None
                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self.best_path_id = None
                                                self.best_path_id_comp_winner = None
                                                self.best_path_orr_bitfield = YList()
                                                self.best_path_orr_bitfield.parent = self
                                                self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self.dampen_penalty = None
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.fspec_invalid_path = None
                                                self.graceful_shutdown = None
                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self.halflife_time = None
                                                self.has_esi = None
                                                self.has_gw_addr = None
                                                self.has_local_net_label = None
                                                self.has_mdt_group_addr = None
                                                self.has_mvpn_extcomm = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.has_rcvd_label = None
                                                self.has_second_label = None
                                                self.ibgp_signaled_validity = None
                                                self.igp_metric = None
                                                self.is_aggregation_suppressed = None
                                                self.is_as_best = None
                                                self.is_best_path = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_internal_path = None
                                                self.is_partial_best = None
                                                self.is_path_additional_path = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_af_install_eligible = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_damped = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_history_held = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_imported = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_multipath = None
                                                self.is_path_nexthop_discarded = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebg_ps = None
                                                self.is_path_received_only = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_stale = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_valid = None
                                                self.is_path_vpn_only = None
                                                self.is_permanent_path = None
                                                self.is_received_path_not_modified = None
                                                self.is_spkr_as_best = None
                                                self.l2vpn_circuit_status_value = YList()
                                                self.l2vpn_circuit_status_value.parent = self
                                                self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2VpnEvpnEsi()
                                                self.l2vpn_evpn_esi.parent = self
                                                self.l2vpn_size = None
                                                self.labeled_unicast_safi_path = None
                                                self.local_label = None
                                                self.local_nh = None
                                                self.local_path_id = None
                                                self.local_peers_advertised_to = YList()
                                                self.local_peers_advertised_to.parent = self
                                                self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                self.maximum_suppress_time = None
                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self.mvpn_path_flags = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_value = YList()
                                                self.mvpn_pmsi_value.parent = self
                                                self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                self.mvpn_sfs_path = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.neighbor_router_id = None
                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.path_flags = None
                                                self.path_flap_count = None
                                                self.path_import_flags = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.path_table_version = None
                                                self.path_weight = None
                                                self.pe_peers_advertised_to = YList()
                                                self.pe_peers_advertised_to.parent = self
                                                self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                self.rcvd_label = None
                                                self.rcvd_path_id = None
                                                self.reuse_value = None
                                                self.rib_failed = None
                                                self.route_type = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.rt_set_limit_enabled = None
                                                self.second_label = None
                                                self.seconds_since_first_flap = None
                                                self.show_rpki_origin_as_validity = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.suppress_penalty = None
                                                self.time_to_unsuppress = None


                                            class BgpPrefix(object):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self.prefix_length = None


                                                class Prefix(object):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.prefix is not None and self.prefix._has_data():
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix']['meta_info']


                                            class NeighborAddress(object):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress']['meta_info']


                                            class NextHop(object):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhteTunnel']['meta_info']


                                            class MdtGroupAddr(object):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr']['meta_info']


                                            class L2VpnEvpnEsi(object):
                                                """
                                                L2VPN EVPN ESI
                                                
                                                .. attribute:: esi
                                                
                                                	esi
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.esi = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.esi is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2VpnEvpnEsi']['meta_info']


                                            class GwAddr(object):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr']['meta_info']


                                            class BestPathCompWinner(object):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner']['meta_info']


                                            class MvpnNbrAddr(object):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr']['meta_info']


                                            class MvpnNexthopAddr(object):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr']['meta_info']


                                            class L2VpnCircuitStatusValue(object):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                            class MvpnPmsiValue(object):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity']['meta_info']


                                            class LocalPeersAdvertisedTo(object):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                            class PePeersAdvertisedTo(object):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo']['meta_info']


                                            class BestPathOrrBitfield(object):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield']['meta_info']


                                            class AddPathOrrBitfield(object):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.accept_own_path is not None:
                                                    return True

                                                if self.accept_own_self_originated_p_ath is not None:
                                                    return True

                                                if self.add_path_orr_bitfield is not None:
                                                    for child_ref in self.add_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.advertisedto_pe is not None:
                                                    return True

                                                if self.aigp_metric is not None:
                                                    return True

                                                if self.best_path_comp_stage is not None:
                                                    return True

                                                if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                    return True

                                                if self.best_path_id is not None:
                                                    return True

                                                if self.best_path_id_comp_winner is not None:
                                                    return True

                                                if self.best_path_orr_bitfield is not None:
                                                    for child_ref in self.best_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                    return True

                                                if self.dampen_penalty is not None:
                                                    return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.fspec_invalid_path is not None:
                                                    return True

                                                if self.graceful_shutdown is not None:
                                                    return True

                                                if self.gw_addr is not None and self.gw_addr._has_data():
                                                    return True

                                                if self.halflife_time is not None:
                                                    return True

                                                if self.has_esi is not None:
                                                    return True

                                                if self.has_gw_addr is not None:
                                                    return True

                                                if self.has_local_net_label is not None:
                                                    return True

                                                if self.has_mdt_group_addr is not None:
                                                    return True

                                                if self.has_mvpn_extcomm is not None:
                                                    return True

                                                if self.has_mvpn_nbr_addr is not None:
                                                    return True

                                                if self.has_mvpn_nexthop_addr is not None:
                                                    return True

                                                if self.has_mvpn_pmsi is not None:
                                                    return True

                                                if self.has_rcvd_label is not None:
                                                    return True

                                                if self.has_second_label is not None:
                                                    return True

                                                if self.ibgp_signaled_validity is not None:
                                                    return True

                                                if self.igp_metric is not None:
                                                    return True

                                                if self.is_aggregation_suppressed is not None:
                                                    return True

                                                if self.is_as_best is not None:
                                                    return True

                                                if self.is_best_path is not None:
                                                    return True

                                                if self.is_import_dampened is not None:
                                                    return True

                                                if self.is_import_suspect is not None:
                                                    return True

                                                if self.is_internal_path is not None:
                                                    return True

                                                if self.is_partial_best is not None:
                                                    return True

                                                if self.is_path_additional_path is not None:
                                                    return True

                                                if self.is_path_advertised_local_as_only is not None:
                                                    return True

                                                if self.is_path_af_install_eligible is not None:
                                                    return True

                                                if self.is_path_backup is not None:
                                                    return True

                                                if self.is_path_backup_protect_multipath is not None:
                                                    return True

                                                if self.is_path_best_external is not None:
                                                    return True

                                                if self.is_path_damped is not None:
                                                    return True

                                                if self.is_path_from_confederation_peer is not None:
                                                    return True

                                                if self.is_path_from_network_command is not None:
                                                    return True

                                                if self.is_path_from_redistribute_command is not None:
                                                    return True

                                                if self.is_path_from_route_reflector is not None:
                                                    return True

                                                if self.is_path_history_held is not None:
                                                    return True

                                                if self.is_path_imp_candidate is not None:
                                                    return True

                                                if self.is_path_imported is not None:
                                                    return True

                                                if self.is_path_local_aggregate is not None:
                                                    return True

                                                if self.is_path_locally_sourced is not None:
                                                    return True

                                                if self.is_path_long_lived_stale is not None:
                                                    return True

                                                if self.is_path_multipath is not None:
                                                    return True

                                                if self.is_path_nexthop_discarded is not None:
                                                    return True

                                                if self.is_path_not_advertised is not None:
                                                    return True

                                                if self.is_path_not_advertised_to_ebg_ps is not None:
                                                    return True

                                                if self.is_path_received_only is not None:
                                                    return True

                                                if self.is_path_reoriginated is not None:
                                                    return True

                                                if self.is_path_reoriginated_stitching is not None:
                                                    return True

                                                if self.is_path_stale is not None:
                                                    return True

                                                if self.is_path_synced_with_igp is not None:
                                                    return True

                                                if self.is_path_valid is not None:
                                                    return True

                                                if self.is_path_vpn_only is not None:
                                                    return True

                                                if self.is_permanent_path is not None:
                                                    return True

                                                if self.is_received_path_not_modified is not None:
                                                    return True

                                                if self.is_spkr_as_best is not None:
                                                    return True

                                                if self.l2vpn_circuit_status_value is not None:
                                                    for child_ref in self.l2vpn_circuit_status_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                    return True

                                                if self.l2vpn_size is not None:
                                                    return True

                                                if self.labeled_unicast_safi_path is not None:
                                                    return True

                                                if self.local_label is not None:
                                                    return True

                                                if self.local_nh is not None:
                                                    return True

                                                if self.local_path_id is not None:
                                                    return True

                                                if self.local_peers_advertised_to is not None:
                                                    for child_ref in self.local_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.maximum_suppress_time is not None:
                                                    return True

                                                if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                    return True

                                                if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                    return True

                                                if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                    return True

                                                if self.mvpn_path_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_label is not None:
                                                    return True

                                                if self.mvpn_pmsi_type is not None:
                                                    return True

                                                if self.mvpn_pmsi_value is not None:
                                                    for child_ref in self.mvpn_pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.mvpn_sfs_path is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.neighbor_router_id is not None:
                                                    return True

                                                if self.next_hop is not None and self.next_hop._has_data():
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.path_flags is not None:
                                                    return True

                                                if self.path_flap_count is not None:
                                                    return True

                                                if self.path_import_flags is not None:
                                                    return True

                                                if self.path_rt_set_id is not None:
                                                    return True

                                                if self.path_rt_set_route_count is not None:
                                                    return True

                                                if self.path_table_version is not None:
                                                    return True

                                                if self.path_weight is not None:
                                                    return True

                                                if self.pe_peers_advertised_to is not None:
                                                    for child_ref in self.pe_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.rcvd_label is not None:
                                                    return True

                                                if self.rcvd_path_id is not None:
                                                    return True

                                                if self.reuse_value is not None:
                                                    return True

                                                if self.rib_failed is not None:
                                                    return True

                                                if self.route_type is not None:
                                                    return True

                                                if self.rpki_origin_as_validation_disabled is not None:
                                                    return True

                                                if self.rt_set_limit_enabled is not None:
                                                    return True

                                                if self.second_label is not None:
                                                    return True

                                                if self.seconds_since_first_flap is not None:
                                                    return True

                                                if self.show_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.sn_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.suppress_penalty is not None:
                                                    return True

                                                if self.time_to_unsuppress is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation']['meta_info']


                                        class AttributesAfterPolicyIn(object):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self.is_application_gateway_present = None
                                                self.is_as_path2_byte = None
                                                self.is_attr_set_present = None
                                                self.is_ribrnh_present = None
                                                self.is_rnh_present = None
                                                self.ribrnh_encap = None
                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self.ribrnh_mac = None
                                                self.ribrnh_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnhip_table = None
                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self.rnh_addr_len = None
                                                self.rnh_len = None
                                                self.rnh_type = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.vpn_distinguisher = None


                                            class CommonAttributes(object):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                            class AttrSet(object):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                            class RnhAddr(object):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None
                                                    self.mac_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    if self.mac_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                            class RibrnhIp(object):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.attr_set is not None and self.attr_set._has_data():
                                                    return True

                                                if self.attribute_key_number is not None:
                                                    return True

                                                if self.attribute_reuse_id_config is not None:
                                                    return True

                                                if self.attribute_reuse_id_current is not None:
                                                    return True

                                                if self.attribute_reuse_id_keys is not None:
                                                    return True

                                                if self.attribute_reuse_id_max_id is not None:
                                                    return True

                                                if self.attribute_reuse_id_node is not None:
                                                    return True

                                                if self.attribute_reuse_id_recover_sec is not None:
                                                    return True

                                                if self.common_attributes is not None and self.common_attributes._has_data():
                                                    return True

                                                if self.is_application_gateway_present is not None:
                                                    return True

                                                if self.is_as_path2_byte is not None:
                                                    return True

                                                if self.is_attr_set_present is not None:
                                                    return True

                                                if self.is_ribrnh_present is not None:
                                                    return True

                                                if self.is_rnh_present is not None:
                                                    return True

                                                if self.ribrnh_encap is not None:
                                                    return True

                                                if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                    return True

                                                if self.ribrnh_mac is not None:
                                                    return True

                                                if self.ribrnh_table is not None:
                                                    return True

                                                if self.ribrnh_vni is not None:
                                                    return True

                                                if self.ribrnhip_table is not None:
                                                    return True

                                                if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                    return True

                                                if self.rnh_addr_len is not None:
                                                    return True

                                                if self.rnh_len is not None:
                                                    return True

                                                if self.rnh_type is not None:
                                                    return True

                                                if self.set_aigp_inbound_igp is not None:
                                                    return True

                                                if self.set_aigp_inbound_metric is not None:
                                                    return True

                                                if self.vpn_distinguisher is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertised-path'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                return True

                                            if self.label_fail is not None:
                                                return True

                                            if self.label_o_or_version is not None:
                                                return True

                                            if self.label_oor is not None:
                                                return True

                                            if self.neighbor_address is not None:
                                                return True

                                            if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                return True

                                            if self.network is not None:
                                                return True

                                            if self.no_path is not None:
                                                return True

                                            if self.path_information is not None and self.path_information._has_data():
                                                return True

                                            if self.prefix_length is not None:
                                                return True

                                            if self.prefix_version is not None:
                                                return True

                                            if self.process_instance_id is not None:
                                                return True

                                            if self.rd is not None:
                                                return True

                                            if self.route_distinguisher is not None:
                                                return True

                                            if self.source_route_distinguisher is not None:
                                                return True

                                            if self.source_vrf_name is not None:
                                                return True

                                            if self.srcaf_name is not None:
                                                return True

                                            if self.vrf_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertised-path-xr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.advertised_path is not None:
                                            for child_ref in self.advertised_path:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr']['meta_info']


                                class SourcedNetworks(object):
                                    """
                                    The BGP Convergence table
                                    
                                    .. attribute:: sourced_network
                                    
                                    	A BGP network command table entry
                                    	**type**\: list of    :py:class:`SourcedNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.sourced_network = YList()
                                        self.sourced_network.parent = self
                                        self.sourced_network.name = 'sourced_network'


                                    class SourcedNetwork(object):
                                        """
                                        A BGP network command table entry
                                        
                                        .. attribute:: network  <key>
                                        
                                        	Network in prefix/length format
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        
                                        ----
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: is_backdoor
                                        
                                        	TRUE if net is a backdoor route
                                        	**type**\:  bool
                                        
                                        .. attribute:: sourced_prefix
                                        
                                        	Prefix length
                                        	**type**\:   :py:class:`SourcedPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.network = None
                                            self.af_name = None
                                            self.is_backdoor = None
                                            self.sourced_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix()
                                            self.sourced_prefix.parent = self


                                        class SourcedPrefix(object):
                                            """
                                            Prefix length
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix()
                                                self.prefix.parent = self
                                                self.prefix_length = None


                                            class Prefix(object):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sourced-prefix'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.prefix is not None and self.prefix._has_data():
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')
                                            if self.network is None:
                                                raise YPYModelError('Key property network is None')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sourced-network[Cisco-IOS-XR-ipv4-bgp-oper:network = ' + str(self.network) + ']'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.network is not None:
                                                return True

                                            if self.af_name is not None:
                                                return True

                                            if self.is_backdoor is not None:
                                                return True

                                            if self.sourced_prefix is not None and self.sourced_prefix._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sourced-networks'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.sourced_network is not None:
                                            for child_ref in self.sourced_network:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks']['meta_info']


                                class UpdateGroups(object):
                                    """
                                    The BGP Update group table
                                    
                                    .. attribute:: update_group
                                    
                                    	A BGP Update group table entry
                                    	**type**\: list of    :py:class:`UpdateGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.update_group = YList()
                                        self.update_group.parent = self
                                        self.update_group.name = 'update_group'


                                    class UpdateGroup(object):
                                        """
                                        A BGP Update group table entry
                                        
                                        .. attribute:: accepts_legacy_pe_rt_route
                                        
                                        	accept\-legacy\-pe\-RT route
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_local_labeled_route_unicast
                                        
                                        	Advertise routes with local\-label via Unicast SAFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_rt_type
                                        
                                        	Advertise RT type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: as_override
                                        
                                        	AS Override option
                                        	**type**\:  bool
                                        
                                        .. attribute:: desync_count
                                        
                                        	Number of times the update has been desynchronized
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: disable_def_vrf_imp_advertisement
                                        
                                        	Disable advertising default VRF  imported routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: disable_native_advertisement
                                        
                                        	Disable advertising native routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: disable_vrf_re_imp_advertisement
                                        
                                        	Disable advertising VRF re\-imported routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation type
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ext_nh_encoding
                                        
                                        	Extended nexthop encoding cap received
                                        	**type**\:  bool
                                        
                                        .. attribute:: filter_group_id
                                        
                                        	Filter group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: gshut_active
                                        
                                        	GSHUT active
                                        	**type**\:  bool
                                        
                                        .. attribute:: gshut_locpref
                                        
                                        	GSHUT local preference
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: gshut_locpref_set
                                        
                                        	GSHUT local preference set
                                        	**type**\:  bool
                                        
                                        .. attribute:: gshut_prepends
                                        
                                        	GSHUT AS prepends
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: has_orf_receive_capability
                                        
                                        	ORF receive capability
                                        	**type**\:  bool
                                        
                                        .. attribute:: is4_byte_as_peer
                                        
                                        	4\-byte AS capable peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_addpath_capable
                                        
                                        	Add\-path capable peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_adv_capable
                                        
                                        	Send tranlsated paths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_adv_perm_net_capable
                                        
                                        	Advertise Permanent\-Net capable peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_adv_reorg_capable
                                        
                                        	Send Re\-orig paths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_aigp_capable
                                        
                                        	AIGP capable peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_aigp_cost_community_capable
                                        
                                        	Send AIGP cost community to peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_aigp_med_capable
                                        
                                        	Send AIGP cost in MED
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_client_reflection_disabled
                                        
                                        	True if client\-to\-client reflection is disabled 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_common_admin_peers
                                        
                                        	Common admin peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_directly_connected_ebgp_v6_peers
                                        
                                        	Directly connected EBGP v6 peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_internal_peers
                                        
                                        	Internal peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_labeled_afi_enabled
                                        
                                        	Update group has labeled AFI enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_llgr_capable
                                        
                                        	Send Long\-lived Stale paths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_orr_root_address_configured
                                        
                                        	ORR Root address configuredfor the neighbor connection
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_route_reflector_client
                                        
                                        	Route\-reflector client
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_send_mcast_attr_enabled
                                        
                                        	Send mcast attribute enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_unlabeled_afi_enabled
                                        
                                        	Update group has unlabeled AFI enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_as
                                        
                                        	Local AS number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_as_replace_as
                                        
                                        	Local AS Replace\-AS option
                                        	**type**\:  bool
                                        
                                        .. attribute:: minimum_advertisement_interval
                                        
                                        	Minimum advertisement interval, secs part
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: minimum_advertisement_interval_msecs
                                        
                                        	Minimum advertisement interval, msecs part
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: neighbor
                                        
                                        	Neighbors in this update group which are not in any sub\-group
                                        	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor>`
                                        
                                        .. attribute:: orr_group_index
                                        
                                        	ORR Group Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: orr_group_name
                                        
                                        	ORR Group Name
                                        	**type**\:  str
                                        
                                        .. attribute:: performance_statistics
                                        
                                        	Performance statistics
                                        	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics>`
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: refresh_subgrp_count
                                        
                                        	Current count of refresh subgroups
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_as
                                        
                                        	Remote AS number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_policy_out
                                        
                                        	Outbound route policy name
                                        	**type**\:  str
                                        
                                        .. attribute:: session_af_name
                                        
                                        	Neighbor session Address family
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: should_remove_private_a_ss
                                        
                                        	Remove private AS numbers
                                        	**type**\:  bool
                                        
                                        .. attribute:: should_remove_private_as_ent_path
                                        
                                        	Remove private AS numbersif the entire path consistsof private ASes
                                        	**type**\:  bool
                                        
                                        .. attribute:: should_send_communities
                                        
                                        	Send communities
                                        	**type**\:  bool
                                        
                                        .. attribute:: should_send_ext_communities
                                        
                                        	Send Extended communities
                                        	**type**\:  bool
                                        
                                        .. attribute:: should_send_gshut_community
                                        
                                        	Send GSHUT community
                                        	**type**\:  bool
                                        
                                        .. attribute:: should_send_stitching_rt
                                        
                                        	Send Stitching RT
                                        	**type**\:  bool
                                        
                                        .. attribute:: soo
                                        
                                        	Site\-of\-origin option
                                        	**type**\:  bool
                                        
                                        .. attribute:: soo_value
                                        
                                        	Site\-of\-origin value
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: split_horizon
                                        
                                        	Split horizon check
                                        	**type**\:  bool
                                        
                                        .. attribute:: subgrp_merge_count
                                        
                                        	Number of times sub\-groups have been merged
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_group_af_name
                                        
                                        	Address family for update group
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: update_group_id
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_sub_group
                                        
                                        	Update sub\-group list
                                        	**type**\: list of    :py:class:`UpdateSubGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup>`
                                        
                                        .. attribute:: updates_formatted
                                        
                                        	Number of updates formatted
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: updates_replicated
                                        
                                        	No. of updates replicated
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: updgrp_cluster_id
                                        
                                        	Cluster ID (populated ifclient\-to\-client reflectionis disabled)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: updgrp_cluster_type
                                        
                                        	Cluster ID type\:undefined/number/Ip address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: use_next_hop_self
                                        
                                        	Next hop self
                                        	**type**\:  bool
                                        
                                        .. attribute:: use_next_hop_unchanged_mpath
                                        
                                        	Next\-hop\-unchanged multipath
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.accepts_legacy_pe_rt_route = None
                                            self.advertise_local_labeled_route_unicast = None
                                            self.advertise_rt_type = None
                                            self.as_override = None
                                            self.desync_count = None
                                            self.disable_def_vrf_imp_advertisement = None
                                            self.disable_native_advertisement = None
                                            self.disable_vrf_re_imp_advertisement = None
                                            self.encapsulation_type = None
                                            self.ext_nh_encoding = None
                                            self.filter_group_id = None
                                            self.gshut_active = None
                                            self.gshut_locpref = None
                                            self.gshut_locpref_set = None
                                            self.gshut_prepends = None
                                            self.has_orf_receive_capability = None
                                            self.is4_byte_as_peer = None
                                            self.is_addpath_capable = None
                                            self.is_adv_capable = None
                                            self.is_adv_perm_net_capable = None
                                            self.is_adv_reorg_capable = None
                                            self.is_aigp_capable = None
                                            self.is_aigp_cost_community_capable = None
                                            self.is_aigp_med_capable = None
                                            self.is_client_reflection_disabled = None
                                            self.is_common_admin_peers = None
                                            self.is_directly_connected_ebgp_v6_peers = None
                                            self.is_internal_peers = None
                                            self.is_labeled_afi_enabled = None
                                            self.is_llgr_capable = None
                                            self.is_orr_root_address_configured = None
                                            self.is_route_reflector_client = None
                                            self.is_send_mcast_attr_enabled = None
                                            self.is_unlabeled_afi_enabled = None
                                            self.local_as = None
                                            self.local_as_replace_as = None
                                            self.minimum_advertisement_interval = None
                                            self.minimum_advertisement_interval_msecs = None
                                            self.neighbor = YList()
                                            self.neighbor.parent = self
                                            self.neighbor.name = 'neighbor'
                                            self.orr_group_index = None
                                            self.orr_group_name = None
                                            self.performance_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics()
                                            self.performance_statistics.parent = self
                                            self.process_instance_id = None
                                            self.refresh_subgrp_count = None
                                            self.remote_as = None
                                            self.route_policy_out = None
                                            self.session_af_name = None
                                            self.should_remove_private_a_ss = None
                                            self.should_remove_private_as_ent_path = None
                                            self.should_send_communities = None
                                            self.should_send_ext_communities = None
                                            self.should_send_gshut_community = None
                                            self.should_send_stitching_rt = None
                                            self.soo = None
                                            self.soo_value = None
                                            self.split_horizon = None
                                            self.subgrp_merge_count = None
                                            self.update_group_af_name = None
                                            self.update_group_id = None
                                            self.update_group_number = None
                                            self.update_sub_group = YList()
                                            self.update_sub_group.parent = self
                                            self.update_sub_group.name = 'update_sub_group'
                                            self.updates_formatted = None
                                            self.updates_replicated = None
                                            self.updgrp_cluster_id = None
                                            self.updgrp_cluster_type = None
                                            self.use_next_hop_self = None
                                            self.use_next_hop_unchanged_mpath = None


                                        class PerformanceStatistics(object):
                                            """
                                            Performance statistics
                                            
                                            .. attribute:: update_generation_be_prefixes_count
                                            
                                            	No. of be prefixes updates generated for
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_calls
                                            
                                            	No. of calls to update generation function
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_messages_count
                                            
                                            	No. of update messages generated
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_prefixes_count
                                            
                                            	No. of prefixes updates generated for
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_time
                                            
                                            	Time spent generating updates (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: updgen_timer_process_time
                                            
                                            	Timestamp when update timer processed for updgrp
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: updgen_timer_start_time
                                            
                                            	Timestamp when update timer started for updgrp
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: updgen_timer_stop_time
                                            
                                            	Timestamp when update timer stopped for updgrp
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.update_generation_be_prefixes_count = None
                                                self.update_generation_calls = None
                                                self.update_generation_messages_count = None
                                                self.update_generation_prefixes_count = None
                                                self.update_generation_time = None
                                                self.updgen_timer_process_time = None
                                                self.updgen_timer_start_time = None
                                                self.updgen_timer_stop_time = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:performance-statistics'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.update_generation_be_prefixes_count is not None:
                                                    return True

                                                if self.update_generation_calls is not None:
                                                    return True

                                                if self.update_generation_messages_count is not None:
                                                    return True

                                                if self.update_generation_prefixes_count is not None:
                                                    return True

                                                if self.update_generation_time is not None:
                                                    return True

                                                if self.updgen_timer_process_time is not None:
                                                    return True

                                                if self.updgen_timer_start_time is not None:
                                                    return True

                                                if self.updgen_timer_stop_time is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics']['meta_info']


                                        class Neighbor(object):
                                            """
                                            Neighbors in this update group which are not in
                                            any sub\-group
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor']['meta_info']


                                        class UpdateSubGroup(object):
                                            """
                                            Update sub\-group list
                                            
                                            .. attribute:: filter_group
                                            
                                            	Update sub\-group fgrp\-num
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: neighbor
                                            
                                            	Neighbors in this subgrp not in any filtergrp
                                            	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor>`
                                            
                                            .. attribute:: update_filter_group
                                            
                                            	Update f\-group list
                                            	**type**\: list of    :py:class:`UpdateFilterGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup>`
                                            
                                            .. attribute:: update_sub_group_number
                                            
                                            	Update sub\-group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: wait_for_eo_rs
                                            
                                            	Wait for  RT Nbr EoRs
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.filter_group = None
                                                self.neighbor = YList()
                                                self.neighbor.parent = self
                                                self.neighbor.name = 'neighbor'
                                                self.update_filter_group = YList()
                                                self.update_filter_group.parent = self
                                                self.update_filter_group.name = 'update_filter_group'
                                                self.update_sub_group_number = None
                                                self.wait_for_eo_rs = None


                                            class UpdateFilterGroup(object):
                                                """
                                                Update f\-group list
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity>`
                                                
                                                .. attribute:: fgroup_advertised_prefixes
                                                
                                                	Number of prefixes advertised to filtergroup in last update walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_created_message_elements
                                                
                                                	Number of message elems created for filtergroup
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_deleted_message_elements
                                                
                                                	Number of message elems deleted
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_flags
                                                
                                                	Flags per filter group
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fgroup_neighbors
                                                
                                                	Nbrs per filter group
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: fgroup_queued_message_elements
                                                
                                                	Number of message elems queued
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_skipped_prefixes
                                                
                                                	Number of prefixes skipped for filtergroup in last update walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_suppressed_prefixes
                                                
                                                	Number of prefixes suppressed for filtergroup in last update walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_total_advertised_prefixes
                                                
                                                	Number of prefixes advertised to filtergroup in all update walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_total_non_optimised_prefixes
                                                
                                                	Number of prefixes  non\-optm from filtergroupin all update walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_total_withdrawn_prefixes
                                                
                                                	Number of prefixes withdrawn f`rom filtergroupin all update walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_withdrawn_prefixes
                                                
                                                	Number of prefixes withdrawn f`rom filtergroupin last update walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_rt_present
                                                
                                                	RT attribute list present
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor
                                                
                                                	Neighbors in this update sub\-group
                                                	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor>`
                                                
                                                .. attribute:: rts
                                                
                                                	RT count per filter group
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: update_filter_group_number
                                                
                                                	Update sub\-group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.fgroup_advertised_prefixes = None
                                                    self.fgroup_created_message_elements = None
                                                    self.fgroup_deleted_message_elements = None
                                                    self.fgroup_flags = None
                                                    self.fgroup_neighbors = None
                                                    self.fgroup_queued_message_elements = None
                                                    self.fgroup_skipped_prefixes = None
                                                    self.fgroup_suppressed_prefixes = None
                                                    self.fgroup_total_advertised_prefixes = None
                                                    self.fgroup_total_non_optimised_prefixes = None
                                                    self.fgroup_total_withdrawn_prefixes = None
                                                    self.fgroup_withdrawn_prefixes = None
                                                    self.is_rt_present = None
                                                    self.neighbor = YList()
                                                    self.neighbor.parent = self
                                                    self.neighbor.name = 'neighbor'
                                                    self.rts = None
                                                    self.update_filter_group_number = None


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity']['meta_info']


                                                class Neighbor(object):
                                                    """
                                                    Neighbors in this update sub\-group
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-filter-group'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.fgroup_advertised_prefixes is not None:
                                                        return True

                                                    if self.fgroup_created_message_elements is not None:
                                                        return True

                                                    if self.fgroup_deleted_message_elements is not None:
                                                        return True

                                                    if self.fgroup_flags is not None:
                                                        return True

                                                    if self.fgroup_neighbors is not None:
                                                        return True

                                                    if self.fgroup_queued_message_elements is not None:
                                                        return True

                                                    if self.fgroup_skipped_prefixes is not None:
                                                        return True

                                                    if self.fgroup_suppressed_prefixes is not None:
                                                        return True

                                                    if self.fgroup_total_advertised_prefixes is not None:
                                                        return True

                                                    if self.fgroup_total_non_optimised_prefixes is not None:
                                                        return True

                                                    if self.fgroup_total_withdrawn_prefixes is not None:
                                                        return True

                                                    if self.fgroup_withdrawn_prefixes is not None:
                                                        return True

                                                    if self.is_rt_present is not None:
                                                        return True

                                                    if self.neighbor is not None:
                                                        for child_ref in self.neighbor:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.rts is not None:
                                                        return True

                                                    if self.update_filter_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup']['meta_info']


                                            class Neighbor(object):
                                                """
                                                Neighbors in this subgrp not in any filtergrp
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-sub-group'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.filter_group is not None:
                                                    return True

                                                if self.neighbor is not None:
                                                    for child_ref in self.neighbor:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.update_filter_group is not None:
                                                    for child_ref in self.update_filter_group:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.update_sub_group_number is not None:
                                                    return True

                                                if self.wait_for_eo_rs is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-group'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.accepts_legacy_pe_rt_route is not None:
                                                return True

                                            if self.advertise_local_labeled_route_unicast is not None:
                                                return True

                                            if self.advertise_rt_type is not None:
                                                return True

                                            if self.as_override is not None:
                                                return True

                                            if self.desync_count is not None:
                                                return True

                                            if self.disable_def_vrf_imp_advertisement is not None:
                                                return True

                                            if self.disable_native_advertisement is not None:
                                                return True

                                            if self.disable_vrf_re_imp_advertisement is not None:
                                                return True

                                            if self.encapsulation_type is not None:
                                                return True

                                            if self.ext_nh_encoding is not None:
                                                return True

                                            if self.filter_group_id is not None:
                                                return True

                                            if self.gshut_active is not None:
                                                return True

                                            if self.gshut_locpref is not None:
                                                return True

                                            if self.gshut_locpref_set is not None:
                                                return True

                                            if self.gshut_prepends is not None:
                                                return True

                                            if self.has_orf_receive_capability is not None:
                                                return True

                                            if self.is4_byte_as_peer is not None:
                                                return True

                                            if self.is_addpath_capable is not None:
                                                return True

                                            if self.is_adv_capable is not None:
                                                return True

                                            if self.is_adv_perm_net_capable is not None:
                                                return True

                                            if self.is_adv_reorg_capable is not None:
                                                return True

                                            if self.is_aigp_capable is not None:
                                                return True

                                            if self.is_aigp_cost_community_capable is not None:
                                                return True

                                            if self.is_aigp_med_capable is not None:
                                                return True

                                            if self.is_client_reflection_disabled is not None:
                                                return True

                                            if self.is_common_admin_peers is not None:
                                                return True

                                            if self.is_directly_connected_ebgp_v6_peers is not None:
                                                return True

                                            if self.is_internal_peers is not None:
                                                return True

                                            if self.is_labeled_afi_enabled is not None:
                                                return True

                                            if self.is_llgr_capable is not None:
                                                return True

                                            if self.is_orr_root_address_configured is not None:
                                                return True

                                            if self.is_route_reflector_client is not None:
                                                return True

                                            if self.is_send_mcast_attr_enabled is not None:
                                                return True

                                            if self.is_unlabeled_afi_enabled is not None:
                                                return True

                                            if self.local_as is not None:
                                                return True

                                            if self.local_as_replace_as is not None:
                                                return True

                                            if self.minimum_advertisement_interval is not None:
                                                return True

                                            if self.minimum_advertisement_interval_msecs is not None:
                                                return True

                                            if self.neighbor is not None:
                                                for child_ref in self.neighbor:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.orr_group_index is not None:
                                                return True

                                            if self.orr_group_name is not None:
                                                return True

                                            if self.performance_statistics is not None and self.performance_statistics._has_data():
                                                return True

                                            if self.process_instance_id is not None:
                                                return True

                                            if self.refresh_subgrp_count is not None:
                                                return True

                                            if self.remote_as is not None:
                                                return True

                                            if self.route_policy_out is not None:
                                                return True

                                            if self.session_af_name is not None:
                                                return True

                                            if self.should_remove_private_a_ss is not None:
                                                return True

                                            if self.should_remove_private_as_ent_path is not None:
                                                return True

                                            if self.should_send_communities is not None:
                                                return True

                                            if self.should_send_ext_communities is not None:
                                                return True

                                            if self.should_send_gshut_community is not None:
                                                return True

                                            if self.should_send_stitching_rt is not None:
                                                return True

                                            if self.soo is not None:
                                                return True

                                            if self.soo_value is not None:
                                                return True

                                            if self.split_horizon is not None:
                                                return True

                                            if self.subgrp_merge_count is not None:
                                                return True

                                            if self.update_group_af_name is not None:
                                                return True

                                            if self.update_group_id is not None:
                                                return True

                                            if self.update_group_number is not None:
                                                return True

                                            if self.update_sub_group is not None:
                                                for child_ref in self.update_sub_group:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.updates_formatted is not None:
                                                return True

                                            if self.updates_replicated is not None:
                                                return True

                                            if self.updgrp_cluster_id is not None:
                                                return True

                                            if self.updgrp_cluster_type is not None:
                                                return True

                                            if self.use_next_hop_self is not None:
                                                return True

                                            if self.use_next_hop_unchanged_mpath is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-groups'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.update_group is not None:
                                            for child_ref in self.update_group:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups']['meta_info']


                                class UpdateGenerationSubGroups(object):
                                    """
                                    Update generation for all sub\-groups
                                    
                                    .. attribute:: update_generation_sub_group
                                    
                                    	Update generation for sub\-group
                                    	**type**\: list of    :py:class:`UpdateGenerationSubGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.update_generation_sub_group = YList()
                                        self.update_generation_sub_group.parent = self
                                        self.update_generation_sub_group.name = 'update_generation_sub_group'


                                    class UpdateGenerationSubGroup(object):
                                        """
                                        Update generation for sub\-group
                                        
                                        .. attribute:: configured_update_limit_sub_group
                                        
                                        	Configured update limit
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: creation_timestamp
                                        
                                        	Creation time
                                        	**type**\:   :py:class:`CreationTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp>`
                                        
                                        .. attribute:: current_update_limit_sub_group
                                        
                                        	Current update limit
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: eo_r_attempted
                                        
                                        	Sending EoR has been attempted
                                        	**type**\:  bool
                                        
                                        .. attribute:: filter_group_count
                                        
                                        	Filter\-group count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: first_update_walk_end_timestamp
                                        
                                        	First update walk end time
                                        	**type**\:   :py:class:`FirstUpdateWalkEndTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp>`
                                        
                                        .. attribute:: first_update_walk_start_timestamp
                                        
                                        	First update walk start time
                                        	**type**\:   :py:class:`FirstUpdateWalkStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp>`
                                        
                                        .. attribute:: io_write_event_pending
                                        
                                        	Is IO write event pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: last_merge_timestamp
                                        
                                        	Last merge time
                                        	**type**\:   :py:class:`LastMergeTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp>`
                                        
                                        .. attribute:: last_merged_sub_group_index
                                        
                                        	Last merged sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_queued_age
                                        
                                        	Time since last update queued event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_queued_timestamp
                                        
                                        	Last update queued time
                                        	**type**\:   :py:class:`LastUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp>`
                                        
                                        .. attribute:: last_update_walk_end_age
                                        
                                        	Time since last update walk end event
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_walk_end_timestamp
                                        
                                        	Last update walk end time
                                        	**type**\:   :py:class:`LastUpdateWalkEndTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp>`
                                        
                                        .. attribute:: last_update_walk_start_timestamp
                                        
                                        	Last update walk start time
                                        	**type**\:   :py:class:`LastUpdateWalkStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp>`
                                        
                                        .. attribute:: merge_count
                                        
                                        	Merge count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_count
                                        
                                        	Neighbor count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: next_resume_version
                                        
                                        	Next resume version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nsr_version
                                        
                                        	NSR version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: parent_sub_group_id
                                        
                                        	Parent Sub\-group identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: parent_sub_group_index
                                        
                                        	Parent Sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pending_target_version
                                        
                                        	Pending target version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_id
                                        
                                        	ProcessID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_sub_group_count
                                        
                                        	Refresh sub\-group count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_id
                                        
                                        	Sub\-group ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: sub_group_id_xr
                                        
                                        	Sub\-group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_index
                                        
                                        	Sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: sub_group_index_xr
                                        
                                        	Sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_default_route_sent
                                        
                                        	Is default route sent
                                        	**type**\:  bool
                                        
                                        .. attribute:: update_group_af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: update_group_index
                                        
                                        	Update\-group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: update_group_index_xr
                                        
                                        	Update\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_main_table_version
                                        
                                        	Main table version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages
                                        
                                        	OutQueue messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size
                                        
                                        	OutQueue size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_refresh_target_version
                                        
                                        	Refresh target version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_statistics
                                        
                                        	Update statistics
                                        	**type**\:   :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics>`
                                        
                                        .. attribute:: update_throttled
                                        
                                        	Is update throttled
                                        	**type**\:  bool
                                        
                                        .. attribute:: update_vrf_name
                                        
                                        	VRF Name
                                        	**type**\:  str
                                        
                                        .. attribute:: update_vrf_table_rib_version
                                        
                                        	VRF Table RIB version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version
                                        
                                        	Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.configured_update_limit_sub_group = None
                                            self.creation_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp()
                                            self.creation_timestamp.parent = self
                                            self.current_update_limit_sub_group = None
                                            self.eo_r_attempted = None
                                            self.filter_group_count = None
                                            self.first_update_walk_end_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp()
                                            self.first_update_walk_end_timestamp.parent = self
                                            self.first_update_walk_start_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp()
                                            self.first_update_walk_start_timestamp.parent = self
                                            self.io_write_event_pending = None
                                            self.last_merge_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp()
                                            self.last_merge_timestamp.parent = self
                                            self.last_merged_sub_group_index = None
                                            self.last_update_queued_age = None
                                            self.last_update_queued_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp()
                                            self.last_update_queued_timestamp.parent = self
                                            self.last_update_walk_end_age = None
                                            self.last_update_walk_end_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp()
                                            self.last_update_walk_end_timestamp.parent = self
                                            self.last_update_walk_start_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp()
                                            self.last_update_walk_start_timestamp.parent = self
                                            self.merge_count = None
                                            self.neighbor_count = None
                                            self.next_resume_version = None
                                            self.nsr_version = None
                                            self.parent_sub_group_id = None
                                            self.parent_sub_group_index = None
                                            self.pending_target_version = None
                                            self.process_id = None
                                            self.refresh_sub_group_count = None
                                            self.sub_group_id = None
                                            self.sub_group_id_xr = None
                                            self.sub_group_index = None
                                            self.sub_group_index_xr = None
                                            self.update_default_route_sent = None
                                            self.update_group_af_name = None
                                            self.update_group_index = None
                                            self.update_group_index_xr = None
                                            self.update_main_table_version = None
                                            self.update_out_queue_messages = None
                                            self.update_out_queue_size = None
                                            self.update_refresh_target_version = None
                                            self.update_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics()
                                            self.update_statistics.parent = self
                                            self.update_throttled = None
                                            self.update_vrf_name = None
                                            self.update_vrf_table_rib_version = None
                                            self.version = None


                                        class CreationTimestamp(object):
                                            """
                                            Creation time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:creation-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp']['meta_info']


                                        class LastMergeTimestamp(object):
                                            """
                                            Last merge time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-merge-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp']['meta_info']


                                        class FirstUpdateWalkStartTimestamp(object):
                                            """
                                            First update walk start time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-update-walk-start-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp']['meta_info']


                                        class FirstUpdateWalkEndTimestamp(object):
                                            """
                                            First update walk end time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-update-walk-end-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp']['meta_info']


                                        class LastUpdateWalkStartTimestamp(object):
                                            """
                                            Last update walk start time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-walk-start-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp']['meta_info']


                                        class LastUpdateWalkEndTimestamp(object):
                                            """
                                            Last update walk end time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-walk-end-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp']['meta_info']


                                        class LastUpdateQueuedTimestamp(object):
                                            """
                                            Last update queued time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-queued-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp']['meta_info']


                                        class UpdateStatistics(object):
                                            """
                                            Update statistics
                                            
                                            .. attribute:: last_update_cleard_age
                                            
                                            	Time since last Clear event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_cleared_timestamp
                                            
                                            	Last Cleared time
                                            	**type**\:   :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp>`
                                            
                                            .. attribute:: last_update_discard_age
                                            
                                            	Time since last Discard event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_discard_timestamp
                                            
                                            	Last Discarded time
                                            	**type**\:   :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                            
                                            .. attribute:: last_update_memory_allocation_fail_age
                                            
                                            	Time since last memory allocation failure event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_memory_allocation_fail_timestamp
                                            
                                            	Memory allocation failure time
                                            	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                            
                                            .. attribute:: last_update_recovery_age
                                            
                                            	Time since last Recovery event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_recovery_timestamp
                                            
                                            	Last Recovery time
                                            	**type**\:   :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                            
                                            .. attribute:: last_update_throttle_age
                                            
                                            	Time since last Throttle event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_throttle_timestamp
                                            
                                            	Last Throttled time
                                            	**type**\:   :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                            
                                            .. attribute:: update_memory_allocation_fail_count
                                            
                                            	Memory allocation failure count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_cleared
                                            
                                            	OutQueue Cleared Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_cumulative
                                            
                                            	OutQueue Cumulative Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_discarded
                                            
                                            	OutQueue Discarded Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_high
                                            
                                            	OutQueue High Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_size_cleared
                                            
                                            	OutQueue Cleared Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_cumulative
                                            
                                            	OutQueue Cumulative Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_discarded
                                            
                                            	OutQueue Discarded Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_high
                                            
                                            	OutQueue Hi Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_recovery_count
                                            
                                            	Recovery Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_throttle_count
                                            
                                            	Throttle Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.last_update_cleard_age = None
                                                self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp()
                                                self.last_update_cleared_timestamp.parent = self
                                                self.last_update_discard_age = None
                                                self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp()
                                                self.last_update_discard_timestamp.parent = self
                                                self.last_update_memory_allocation_fail_age = None
                                                self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                                self.last_update_memory_allocation_fail_timestamp.parent = self
                                                self.last_update_recovery_age = None
                                                self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                                self.last_update_recovery_timestamp.parent = self
                                                self.last_update_throttle_age = None
                                                self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp()
                                                self.last_update_throttle_timestamp.parent = self
                                                self.update_memory_allocation_fail_count = None
                                                self.update_out_queue_messages_cleared = None
                                                self.update_out_queue_messages_cumulative = None
                                                self.update_out_queue_messages_discarded = None
                                                self.update_out_queue_messages_high = None
                                                self.update_out_queue_size_cleared = None
                                                self.update_out_queue_size_cumulative = None
                                                self.update_out_queue_size_discarded = None
                                                self.update_out_queue_size_high = None
                                                self.update_recovery_count = None
                                                self.update_throttle_count = None


                                            class LastUpdateDiscardTimestamp(object):
                                                """
                                                Last Discarded time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-discard-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp']['meta_info']


                                            class LastUpdateClearedTimestamp(object):
                                                """
                                                Last Cleared time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-cleared-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp']['meta_info']


                                            class LastUpdateThrottleTimestamp(object):
                                                """
                                                Last Throttled time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-throttle-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp']['meta_info']


                                            class LastUpdateRecoveryTimestamp(object):
                                                """
                                                Last Recovery time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-recovery-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp']['meta_info']


                                            class LastUpdateMemoryAllocationFailTimestamp(object):
                                                """
                                                Memory allocation failure time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-memory-allocation-fail-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-statistics'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.last_update_cleard_age is not None:
                                                    return True

                                                if self.last_update_cleared_timestamp is not None and self.last_update_cleared_timestamp._has_data():
                                                    return True

                                                if self.last_update_discard_age is not None:
                                                    return True

                                                if self.last_update_discard_timestamp is not None and self.last_update_discard_timestamp._has_data():
                                                    return True

                                                if self.last_update_memory_allocation_fail_age is not None:
                                                    return True

                                                if self.last_update_memory_allocation_fail_timestamp is not None and self.last_update_memory_allocation_fail_timestamp._has_data():
                                                    return True

                                                if self.last_update_recovery_age is not None:
                                                    return True

                                                if self.last_update_recovery_timestamp is not None and self.last_update_recovery_timestamp._has_data():
                                                    return True

                                                if self.last_update_throttle_age is not None:
                                                    return True

                                                if self.last_update_throttle_timestamp is not None and self.last_update_throttle_timestamp._has_data():
                                                    return True

                                                if self.update_memory_allocation_fail_count is not None:
                                                    return True

                                                if self.update_out_queue_messages_cleared is not None:
                                                    return True

                                                if self.update_out_queue_messages_cumulative is not None:
                                                    return True

                                                if self.update_out_queue_messages_discarded is not None:
                                                    return True

                                                if self.update_out_queue_messages_high is not None:
                                                    return True

                                                if self.update_out_queue_size_cleared is not None:
                                                    return True

                                                if self.update_out_queue_size_cumulative is not None:
                                                    return True

                                                if self.update_out_queue_size_discarded is not None:
                                                    return True

                                                if self.update_out_queue_size_high is not None:
                                                    return True

                                                if self.update_recovery_count is not None:
                                                    return True

                                                if self.update_throttle_count is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-sub-group'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.configured_update_limit_sub_group is not None:
                                                return True

                                            if self.creation_timestamp is not None and self.creation_timestamp._has_data():
                                                return True

                                            if self.current_update_limit_sub_group is not None:
                                                return True

                                            if self.eo_r_attempted is not None:
                                                return True

                                            if self.filter_group_count is not None:
                                                return True

                                            if self.first_update_walk_end_timestamp is not None and self.first_update_walk_end_timestamp._has_data():
                                                return True

                                            if self.first_update_walk_start_timestamp is not None and self.first_update_walk_start_timestamp._has_data():
                                                return True

                                            if self.io_write_event_pending is not None:
                                                return True

                                            if self.last_merge_timestamp is not None and self.last_merge_timestamp._has_data():
                                                return True

                                            if self.last_merged_sub_group_index is not None:
                                                return True

                                            if self.last_update_queued_age is not None:
                                                return True

                                            if self.last_update_queued_timestamp is not None and self.last_update_queued_timestamp._has_data():
                                                return True

                                            if self.last_update_walk_end_age is not None:
                                                return True

                                            if self.last_update_walk_end_timestamp is not None and self.last_update_walk_end_timestamp._has_data():
                                                return True

                                            if self.last_update_walk_start_timestamp is not None and self.last_update_walk_start_timestamp._has_data():
                                                return True

                                            if self.merge_count is not None:
                                                return True

                                            if self.neighbor_count is not None:
                                                return True

                                            if self.next_resume_version is not None:
                                                return True

                                            if self.nsr_version is not None:
                                                return True

                                            if self.parent_sub_group_id is not None:
                                                return True

                                            if self.parent_sub_group_index is not None:
                                                return True

                                            if self.pending_target_version is not None:
                                                return True

                                            if self.process_id is not None:
                                                return True

                                            if self.refresh_sub_group_count is not None:
                                                return True

                                            if self.sub_group_id is not None:
                                                return True

                                            if self.sub_group_id_xr is not None:
                                                return True

                                            if self.sub_group_index is not None:
                                                return True

                                            if self.sub_group_index_xr is not None:
                                                return True

                                            if self.update_default_route_sent is not None:
                                                return True

                                            if self.update_group_af_name is not None:
                                                return True

                                            if self.update_group_index is not None:
                                                return True

                                            if self.update_group_index_xr is not None:
                                                return True

                                            if self.update_main_table_version is not None:
                                                return True

                                            if self.update_out_queue_messages is not None:
                                                return True

                                            if self.update_out_queue_size is not None:
                                                return True

                                            if self.update_refresh_target_version is not None:
                                                return True

                                            if self.update_statistics is not None and self.update_statistics._has_data():
                                                return True

                                            if self.update_throttled is not None:
                                                return True

                                            if self.update_vrf_name is not None:
                                                return True

                                            if self.update_vrf_table_rib_version is not None:
                                                return True

                                            if self.version is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-sub-groups'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.update_generation_sub_group is not None:
                                            for child_ref in self.update_generation_sub_group:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups']['meta_info']


                                class NextHopAddressFamilies(object):
                                    """
                                    Address family of nexthop table
                                    
                                    .. attribute:: next_hop_address_family
                                    
                                    	Nexthop Address family
                                    	**type**\: list of    :py:class:`NextHopAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.next_hop_address_family = YList()
                                        self.next_hop_address_family.parent = self
                                        self.next_hop_address_family.name = 'next_hop_address_family'


                                    class NextHopAddressFamily(object):
                                        """
                                        Nexthop Address family
                                        
                                        .. attribute:: next_hop_af_name  <key>
                                        
                                        	Address family
                                        	**type**\:   :py:class:`BgpAddressFamilyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamilyEnum>`
                                        
                                        .. attribute:: next_hop_af_vrf_af
                                        
                                        	A BGP Next\-hop VRF AF table entry
                                        	**type**\:   :py:class:`NextHopAfVrfAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf>`
                                        
                                        .. attribute:: next_hop_afs
                                        
                                        	The BGP Next\-hop table
                                        	**type**\:   :py:class:`NextHopAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.next_hop_af_name = None
                                            self.next_hop_af_vrf_af = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf()
                                            self.next_hop_af_vrf_af.parent = self
                                            self.next_hop_afs = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs()
                                            self.next_hop_afs.parent = self


                                        class NextHopAfVrfAf(object):
                                            """
                                            A BGP Next\-hop VRF AF table entry
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: critical_trigger_delay
                                            
                                            	Trigger delay for critical event processing
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: epe_downloaded_version
                                            
                                            	Version of the EPE table downloaded
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: epe_label_version
                                            
                                            	Version of the EPE label walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: epe_standby_version
                                            
                                            	Version of the EPE table processed by sync thread
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: epe_table_version
                                            
                                            	Version of the EPE table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: gwaf_name
                                            
                                            	GW Address family identifier
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: nh_nexthop_version
                                            
                                            	NH version for gw\_ctx
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_rib_up
                                            
                                            	Whether the VRF is active
                                            	**type**\:  bool
                                            
                                            .. attribute:: nh_rib_version
                                            
                                            	RIB version for gw\_ctx
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_table_id
                                            
                                            	Gateway context table id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: non_critical_trigger_delay
                                            
                                            	Trigger delay for non\-critical event processing
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: performance_statistics
                                            
                                            	Performance statistics
                                            	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics>`
                                            
                                            .. attribute:: table_active
                                            
                                            	Whether the VRF is active
                                            	**type**\:  bool
                                            
                                            .. attribute:: total_nexthops
                                            
                                            	Total number of nexthops
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.af_name = None
                                                self.critical_trigger_delay = None
                                                self.epe_downloaded_version = None
                                                self.epe_label_version = None
                                                self.epe_standby_version = None
                                                self.epe_table_version = None
                                                self.gwaf_name = None
                                                self.nh_nexthop_version = None
                                                self.nh_rib_up = None
                                                self.nh_rib_version = None
                                                self.nh_table_id = None
                                                self.non_critical_trigger_delay = None
                                                self.performance_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics()
                                                self.performance_statistics.parent = self
                                                self.table_active = None
                                                self.total_nexthops = None


                                            class PerformanceStatistics(object):
                                                """
                                                Performance statistics
                                                
                                                .. attribute:: critical_notf_count
                                                
                                                	Number of critical event notifications from RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_notf_bestpath_changes
                                                
                                                	Number of bestpath changes due to last notification
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_notf_bestpath_deletes
                                                
                                                	Number of bestpath deletes due to last notification
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthops_removed_from_rib
                                                
                                                	No. of nexthops withdrawn from RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthops_resent_to_rib
                                                
                                                	No. of nexthops re\-sent to RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthops_sent_to_rib
                                                
                                                	No. of nexthops sent to RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_batch_finish_calls
                                                
                                                	NH batch finish calls
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_flush_timer_calls
                                                
                                                	NH flush timer calls
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_last_a_sync_reg_ts
                                                
                                                	NH Last async Register TS
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_last_a_sync_un_reg_ts
                                                
                                                	NH Last async UnRegister TS
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_last_batch_finish_ts
                                                
                                                	NH Last batch finish TS
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_last_flush_timer_ts
                                                
                                                	NH Last flush timer TS
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_last_sync_reg_ts
                                                
                                                	NH Last sync Register TS
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_peak_registrations
                                                
                                                	NH Registration List Count Peak
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_pending_registrations
                                                
                                                	NH Registration List Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_sync_reg_calls
                                                
                                                	NH sync register calls
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nha_sync_reg_calls
                                                
                                                	NH async register calls
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nha_sync_un_reg_calls
                                                
                                                	NH async unregister calls
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nhrib_update_calls
                                                
                                                	No. of calls to RIB update function
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nhrib_update_time
                                                
                                                	Time spent sending RIB updates (milliseconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: millisecond
                                                
                                                .. attribute:: noncritical_notf_count
                                                
                                                	Number of non\-critical event notifications from RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_sync_registers_failed
                                                
                                                	No. of sync registers with RIB that failed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: riba_sync_registers_failed
                                                
                                                	No. of async registers with RIB that failed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribnh_reg_failed_for_no_rib_conn
                                                
                                                	No. of nh registers failed because of no rib conn
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribnh_reg_failed_for_no_tbl_id
                                                
                                                	No. of nh registers failed because of no tbl\-id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_walk_backup_creates
                                                
                                                	No. of times backup tid created during tunnel walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_walk_gw_not_found
                                                
                                                	No. of times gw was not found during tunnel walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_walk_nh_not_found
                                                
                                                	No. of times nexthop was not found during tunnel walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.critical_notf_count = None
                                                    self.last_notf_bestpath_changes = None
                                                    self.last_notf_bestpath_deletes = None
                                                    self.nexthops_removed_from_rib = None
                                                    self.nexthops_resent_to_rib = None
                                                    self.nexthops_sent_to_rib = None
                                                    self.nh_batch_finish_calls = None
                                                    self.nh_flush_timer_calls = None
                                                    self.nh_last_a_sync_reg_ts = None
                                                    self.nh_last_a_sync_un_reg_ts = None
                                                    self.nh_last_batch_finish_ts = None
                                                    self.nh_last_flush_timer_ts = None
                                                    self.nh_last_sync_reg_ts = None
                                                    self.nh_peak_registrations = None
                                                    self.nh_pending_registrations = None
                                                    self.nh_sync_reg_calls = None
                                                    self.nha_sync_reg_calls = None
                                                    self.nha_sync_un_reg_calls = None
                                                    self.nhrib_update_calls = None
                                                    self.nhrib_update_time = None
                                                    self.noncritical_notf_count = None
                                                    self.rib_sync_registers_failed = None
                                                    self.riba_sync_registers_failed = None
                                                    self.ribnh_reg_failed_for_no_rib_conn = None
                                                    self.ribnh_reg_failed_for_no_tbl_id = None
                                                    self.tunnel_walk_backup_creates = None
                                                    self.tunnel_walk_gw_not_found = None
                                                    self.tunnel_walk_nh_not_found = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:performance-statistics'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.critical_notf_count is not None:
                                                        return True

                                                    if self.last_notf_bestpath_changes is not None:
                                                        return True

                                                    if self.last_notf_bestpath_deletes is not None:
                                                        return True

                                                    if self.nexthops_removed_from_rib is not None:
                                                        return True

                                                    if self.nexthops_resent_to_rib is not None:
                                                        return True

                                                    if self.nexthops_sent_to_rib is not None:
                                                        return True

                                                    if self.nh_batch_finish_calls is not None:
                                                        return True

                                                    if self.nh_flush_timer_calls is not None:
                                                        return True

                                                    if self.nh_last_a_sync_reg_ts is not None:
                                                        return True

                                                    if self.nh_last_a_sync_un_reg_ts is not None:
                                                        return True

                                                    if self.nh_last_batch_finish_ts is not None:
                                                        return True

                                                    if self.nh_last_flush_timer_ts is not None:
                                                        return True

                                                    if self.nh_last_sync_reg_ts is not None:
                                                        return True

                                                    if self.nh_peak_registrations is not None:
                                                        return True

                                                    if self.nh_pending_registrations is not None:
                                                        return True

                                                    if self.nh_sync_reg_calls is not None:
                                                        return True

                                                    if self.nha_sync_reg_calls is not None:
                                                        return True

                                                    if self.nha_sync_un_reg_calls is not None:
                                                        return True

                                                    if self.nhrib_update_calls is not None:
                                                        return True

                                                    if self.nhrib_update_time is not None:
                                                        return True

                                                    if self.noncritical_notf_count is not None:
                                                        return True

                                                    if self.rib_sync_registers_failed is not None:
                                                        return True

                                                    if self.riba_sync_registers_failed is not None:
                                                        return True

                                                    if self.ribnh_reg_failed_for_no_rib_conn is not None:
                                                        return True

                                                    if self.ribnh_reg_failed_for_no_tbl_id is not None:
                                                        return True

                                                    if self.tunnel_walk_backup_creates is not None:
                                                        return True

                                                    if self.tunnel_walk_gw_not_found is not None:
                                                        return True

                                                    if self.tunnel_walk_nh_not_found is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop-af-vrf-af'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.af_name is not None:
                                                    return True

                                                if self.critical_trigger_delay is not None:
                                                    return True

                                                if self.epe_downloaded_version is not None:
                                                    return True

                                                if self.epe_label_version is not None:
                                                    return True

                                                if self.epe_standby_version is not None:
                                                    return True

                                                if self.epe_table_version is not None:
                                                    return True

                                                if self.gwaf_name is not None:
                                                    return True

                                                if self.nh_nexthop_version is not None:
                                                    return True

                                                if self.nh_rib_up is not None:
                                                    return True

                                                if self.nh_rib_version is not None:
                                                    return True

                                                if self.nh_table_id is not None:
                                                    return True

                                                if self.non_critical_trigger_delay is not None:
                                                    return True

                                                if self.performance_statistics is not None and self.performance_statistics._has_data():
                                                    return True

                                                if self.table_active is not None:
                                                    return True

                                                if self.total_nexthops is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf']['meta_info']


                                        class NextHopAfs(object):
                                            """
                                            The BGP Next\-hop table
                                            
                                            .. attribute:: next_hop_af
                                            
                                            	A BGP Next hop entry
                                            	**type**\: list of    :py:class:`NextHopAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.next_hop_af = YList()
                                                self.next_hop_af.parent = self
                                                self.next_hop_af.name = 'next_hop_af'


                                            class NextHopAf(object):
                                                """
                                                A BGP Next hop entry
                                                
                                                .. attribute:: af_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: attribute_set
                                                
                                                	Attribute Set Name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address List
                                                	**type**\: list of    :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress>`
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: nexthop_address
                                                
                                                	Nexthop address
                                                	**type**\:   :py:class:`NexthopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress>`
                                                
                                                .. attribute:: nexthop_aigp_metric
                                                
                                                	AIGP metrice of nexthop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_gateway_info
                                                
                                                	Gateway related info, includingOptimal Route Reflector Gateways
                                                	**type**\: list of    :py:class:`NexthopGatewayInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo>`
                                                
                                                .. attribute:: nexthop_gateway_prefix_connected
                                                
                                                	Is Gateway resolved through Connected route ?
                                                	**type**\:  bool
                                                
                                                .. attribute:: nexthop_gateway_prefix_length
                                                
                                                	Gateway prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_gateway_reachable
                                                
                                                	Is Gateway reachable ?
                                                	**type**\:  bool
                                                
                                                .. attribute:: nexthop_internal_info
                                                
                                                	Internal nexthop info
                                                	**type**\:   :py:class:`NexthopInternalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo>`
                                                
                                                .. attribute:: nexthop_pending_registration
                                                
                                                	Nexthop registration is pending
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nexthop_reference_count
                                                
                                                	Number of neighbors/prefixes referencing this nexthop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_first_hop_if_handle
                                                
                                                	First\-hop interface handle
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: nh_reference_count_total
                                                
                                                	Number of neighbors/prefixes referencing this nexthop (AFs)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nhte_tunnel
                                                
                                                	NH TE tunnel information
                                                	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhteTunnel>`
                                                
                                                .. attribute:: rib_nexthop_id
                                                
                                                	RIB Nexthop Id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.af_name = None
                                                    self.attribute_set = None
                                                    self.neighbor_address = YList()
                                                    self.neighbor_address.parent = self
                                                    self.neighbor_address.name = 'neighbor_address'
                                                    self.next_hop_address = None
                                                    self.nexthop_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress()
                                                    self.nexthop_address.parent = self
                                                    self.nexthop_aigp_metric = None
                                                    self.nexthop_gateway_info = YList()
                                                    self.nexthop_gateway_info.parent = self
                                                    self.nexthop_gateway_info.name = 'nexthop_gateway_info'
                                                    self.nexthop_gateway_prefix_connected = None
                                                    self.nexthop_gateway_prefix_length = None
                                                    self.nexthop_gateway_reachable = None
                                                    self.nexthop_internal_info = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo()
                                                    self.nexthop_internal_info.parent = self
                                                    self.nexthop_pending_registration = None
                                                    self.nexthop_reference_count = None
                                                    self.nh_first_hop_if_handle = None
                                                    self.nh_reference_count_total = None
                                                    self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhteTunnel()
                                                    self.nhte_tunnel.parent = self
                                                    self.rib_nexthop_id = None


                                                class NexthopAddress(object):
                                                    """
                                                    Nexthop address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress']['meta_info']


                                                class NhteTunnel(object):
                                                    """
                                                    NH TE tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_te_tunnel
                                                    
                                                    	NH TE Tunnel info is present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last rib update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	tunnel name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	tunnel type
                                                    	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.binding_label = None
                                                        self.has_te_tunnel = None
                                                        self.is_tunnel_info_stale = None
                                                        self.is_tunnel_registered = None
                                                        self.is_tunnel_up = None
                                                        self.last_tunnel_update = None
                                                        self.tunnel_if_handle = None
                                                        self.tunnel_name = None
                                                        self.tunnel_type = None
                                                        self.tunnel_v6_enabled = None
                                                        self.tunnel_v6_required = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.binding_label is not None:
                                                            return True

                                                        if self.has_te_tunnel is not None:
                                                            return True

                                                        if self.is_tunnel_info_stale is not None:
                                                            return True

                                                        if self.is_tunnel_registered is not None:
                                                            return True

                                                        if self.is_tunnel_up is not None:
                                                            return True

                                                        if self.last_tunnel_update is not None:
                                                            return True

                                                        if self.tunnel_if_handle is not None:
                                                            return True

                                                        if self.tunnel_name is not None:
                                                            return True

                                                        if self.tunnel_type is not None:
                                                            return True

                                                        if self.tunnel_v6_enabled is not None:
                                                            return True

                                                        if self.tunnel_v6_required is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhteTunnel']['meta_info']


                                                class NexthopInternalInfo(object):
                                                    """
                                                    Internal nexthop info
                                                    
                                                    .. attribute:: gateway_flags
                                                    
                                                    	Gateway flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_address
                                                    
                                                    	Nexthop address
                                                    	**type**\:   :py:class:`NexthopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress>`
                                                    
                                                    .. attribute:: nexthop_af_user_bits
                                                    
                                                    	Bitmask indicating the AFs which share the nexthop
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_flags
                                                    
                                                    	Nexthop flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_gateway_internal_info
                                                    
                                                    	Internal nexthop Gateway info
                                                    	**type**\: list of    :py:class:`NexthopGatewayInternalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo>`
                                                    
                                                    .. attribute:: nexthop_id
                                                    
                                                    	Comm librray ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_if_handle
                                                    
                                                    	Nexthop ifhandle
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_label
                                                    
                                                    	Nexthop label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_metrice
                                                    
                                                    	Nexthop metrices
                                                    	**type**\: list of    :py:class:`NexthopMetrice <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice>`
                                                    
                                                    .. attribute:: nexthop_refcount
                                                    
                                                    	Nexthop refcounts
                                                    	**type**\: list of    :py:class:`NexthopRefcount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount>`
                                                    
                                                    .. attribute:: nexthop_version
                                                    
                                                    	Table version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.gateway_flags = None
                                                        self.nexthop_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress()
                                                        self.nexthop_address.parent = self
                                                        self.nexthop_af_user_bits = None
                                                        self.nexthop_flags = None
                                                        self.nexthop_gateway_internal_info = YList()
                                                        self.nexthop_gateway_internal_info.parent = self
                                                        self.nexthop_gateway_internal_info.name = 'nexthop_gateway_internal_info'
                                                        self.nexthop_id = None
                                                        self.nexthop_if_handle = None
                                                        self.nexthop_label = None
                                                        self.nexthop_metrice = YList()
                                                        self.nexthop_metrice.parent = self
                                                        self.nexthop_metrice.name = 'nexthop_metrice'
                                                        self.nexthop_refcount = YList()
                                                        self.nexthop_refcount.parent = self
                                                        self.nexthop_refcount.name = 'nexthop_refcount'
                                                        self.nexthop_version = None


                                                    class NexthopAddress(object):
                                                        """
                                                        Nexthop address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress']['meta_info']


                                                    class NexthopMetrice(object):
                                                        """
                                                        Nexthop metrices
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-metrice'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice']['meta_info']


                                                    class NexthopRefcount(object):
                                                        """
                                                        Nexthop refcounts
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-refcount'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount']['meta_info']


                                                    class NexthopGatewayInternalInfo(object):
                                                        """
                                                        Internal nexthop Gateway info
                                                        
                                                        .. attribute:: gateway_flags
                                                        
                                                        	Gateway flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: registration_since
                                                        
                                                        	Time since registration
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: registration_type
                                                        
                                                        	Nexthop registration type
                                                        	**type**\:   :py:class:`BgpNhValidateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpNhValidateEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.gateway_flags = None
                                                            self.registration_since = None
                                                            self.registration_type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-gateway-internal-info'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.gateway_flags is not None:
                                                                return True

                                                            if self.registration_since is not None:
                                                                return True

                                                            if self.registration_type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-internal-info'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.gateway_flags is not None:
                                                            return True

                                                        if self.nexthop_address is not None and self.nexthop_address._has_data():
                                                            return True

                                                        if self.nexthop_af_user_bits is not None:
                                                            return True

                                                        if self.nexthop_flags is not None:
                                                            return True

                                                        if self.nexthop_gateway_internal_info is not None:
                                                            for child_ref in self.nexthop_gateway_internal_info:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.nexthop_id is not None:
                                                            return True

                                                        if self.nexthop_if_handle is not None:
                                                            return True

                                                        if self.nexthop_label is not None:
                                                            return True

                                                        if self.nexthop_metrice is not None:
                                                            for child_ref in self.nexthop_metrice:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.nexthop_refcount is not None:
                                                            for child_ref in self.nexthop_refcount:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.nexthop_version is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo']['meta_info']


                                                class NexthopGatewayInfo(object):
                                                    """
                                                    Gateway related info, includingOptimal Route
                                                    Reflector Gateways
                                                    
                                                    .. attribute:: critical_events
                                                    
                                                    	Number of critical events received from RIB
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_event_since
                                                    
                                                    	Time since the last event sent to or received from RIB
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_event_type
                                                    
                                                    	Last nexthop event type
                                                    	**type**\:   :py:class:`BgpNhEventEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpNhEventEnum>`
                                                    
                                                    .. attribute:: last_rib_update
                                                    
                                                    	Time since the last rib update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_update_type
                                                    
                                                    	Last nexthop update type
                                                    	**type**\:   :py:class:`BgpNhUpdateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpNhUpdateEnum>`
                                                    
                                                    .. attribute:: nexthop_af_invalid_bits
                                                    
                                                    	Bitmask indicating the AFs which have been invalidated for the nexthop
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: nexthop_metric
                                                    
                                                    	IGP metric for nexthop
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_mpls_enabled
                                                    
                                                    	TRUE if MPLS is configured for IAS/CsC application
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: nexthop_mpls_interfaces
                                                    
                                                    	Number of interfaces on which MPLS is enabled
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_mpls_label
                                                    
                                                    	Local label allocated for IAS/CsC application
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_route
                                                    
                                                    	Route resolving the nethop
                                                    	**type**\:   :py:class:`NexthopRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute>`
                                                    
                                                    .. attribute:: nexthop_route_path
                                                    
                                                    	Nexthops of the resolving route
                                                    	**type**\: list of    :py:class:`NexthopRoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath>`
                                                    
                                                    .. attribute:: nexthop_route_path_count
                                                    
                                                    	Number of paths in the resolving route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_route_prefix_length
                                                    
                                                    	Prefix length of the route resolving the nexthop
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nexthop_route_protocol
                                                    
                                                    	Protocol that resolves the route to the nexthop
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: nexthop_status
                                                    
                                                    	Nexthop status
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nexthop_tableid
                                                    
                                                    	Nexthop Table id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: non_critical_events
                                                    
                                                    	Number of non\-critical events received from RIB
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.critical_events = None
                                                        self.last_event_since = None
                                                        self.last_event_type = None
                                                        self.last_rib_update = None
                                                        self.last_update_type = None
                                                        self.nexthop_af_invalid_bits = None
                                                        self.nexthop_metric = None
                                                        self.nexthop_mpls_enabled = None
                                                        self.nexthop_mpls_interfaces = None
                                                        self.nexthop_mpls_label = None
                                                        self.nexthop_route = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute()
                                                        self.nexthop_route.parent = self
                                                        self.nexthop_route_path = YList()
                                                        self.nexthop_route_path.parent = self
                                                        self.nexthop_route_path.name = 'nexthop_route_path'
                                                        self.nexthop_route_path_count = None
                                                        self.nexthop_route_prefix_length = None
                                                        self.nexthop_route_protocol = None
                                                        self.nexthop_status = None
                                                        self.nexthop_tableid = None
                                                        self.non_critical_events = None


                                                    class NexthopRoute(object):
                                                        """
                                                        Route resolving the nethop
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-route'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute']['meta_info']


                                                    class NexthopRoutePath(object):
                                                        """
                                                        Nexthops of the resolving route
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-route-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-gateway-info'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.critical_events is not None:
                                                            return True

                                                        if self.last_event_since is not None:
                                                            return True

                                                        if self.last_event_type is not None:
                                                            return True

                                                        if self.last_rib_update is not None:
                                                            return True

                                                        if self.last_update_type is not None:
                                                            return True

                                                        if self.nexthop_af_invalid_bits is not None:
                                                            return True

                                                        if self.nexthop_metric is not None:
                                                            return True

                                                        if self.nexthop_mpls_enabled is not None:
                                                            return True

                                                        if self.nexthop_mpls_interfaces is not None:
                                                            return True

                                                        if self.nexthop_mpls_label is not None:
                                                            return True

                                                        if self.nexthop_route is not None and self.nexthop_route._has_data():
                                                            return True

                                                        if self.nexthop_route_path is not None:
                                                            for child_ref in self.nexthop_route_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.nexthop_route_path_count is not None:
                                                            return True

                                                        if self.nexthop_route_prefix_length is not None:
                                                            return True

                                                        if self.nexthop_route_protocol is not None:
                                                            return True

                                                        if self.nexthop_status is not None:
                                                            return True

                                                        if self.nexthop_tableid is not None:
                                                            return True

                                                        if self.non_critical_events is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo']['meta_info']


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address List
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop-af'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.af_name is not None:
                                                        return True

                                                    if self.attribute_set is not None:
                                                        return True

                                                    if self.neighbor_address is not None:
                                                        for child_ref in self.neighbor_address:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.next_hop_address is not None:
                                                        return True

                                                    if self.nexthop_address is not None and self.nexthop_address._has_data():
                                                        return True

                                                    if self.nexthop_aigp_metric is not None:
                                                        return True

                                                    if self.nexthop_gateway_info is not None:
                                                        for child_ref in self.nexthop_gateway_info:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.nexthop_gateway_prefix_connected is not None:
                                                        return True

                                                    if self.nexthop_gateway_prefix_length is not None:
                                                        return True

                                                    if self.nexthop_gateway_reachable is not None:
                                                        return True

                                                    if self.nexthop_internal_info is not None and self.nexthop_internal_info._has_data():
                                                        return True

                                                    if self.nexthop_pending_registration is not None:
                                                        return True

                                                    if self.nexthop_reference_count is not None:
                                                        return True

                                                    if self.nh_first_hop_if_handle is not None:
                                                        return True

                                                    if self.nh_reference_count_total is not None:
                                                        return True

                                                    if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                        return True

                                                    if self.rib_nexthop_id is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop-afs'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.next_hop_af is not None:
                                                    for child_ref in self.next_hop_af:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')
                                            if self.next_hop_af_name is None:
                                                raise YPYModelError('Key property next_hop_af_name is None')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop-address-family[Cisco-IOS-XR-ipv4-bgp-oper:next-hop-af-name = ' + str(self.next_hop_af_name) + ']'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.next_hop_af_name is not None:
                                                return True

                                            if self.next_hop_af_vrf_af is not None and self.next_hop_af_vrf_af._has_data():
                                                return True

                                            if self.next_hop_afs is not None and self.next_hop_afs._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop-address-families'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.next_hop_address_family is not None:
                                            for child_ref in self.next_hop_address_family:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies']['meta_info']


                                class RtSetCounters(object):
                                    """
                                    The RT\-set counter table
                                    
                                    .. attribute:: rt_set_counter
                                    
                                    	One RT\-set counter table entry
                                    	**type**\: list of    :py:class:`RtSetCounter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.rt_set_counter = YList()
                                        self.rt_set_counter.parent = self
                                        self.rt_set_counter.name = 'rt_set_counter'


                                    class RtSetCounter(object):
                                        """
                                        One RT\-set counter table entry
                                        
                                        .. attribute:: rt_set_id  <key>
                                        
                                        	RTSet ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: route_target_set
                                        
                                        	Route Target set
                                        	**type**\:   :py:class:`RouteTargetSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.rt_set_id = None
                                            self.route_target_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet()
                                            self.route_target_set.parent = self


                                        class RouteTargetSet(object):
                                            """
                                            Route Target set
                                            
                                            .. attribute:: rt_set
                                            
                                            	Set of route targets
                                            	**type**\: list of    :py:class:`RtSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet>`
                                            
                                            .. attribute:: rt_set_id
                                            
                                            	Identifier of the rtset
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rt_set_len
                                            
                                            	Length in bytes of set of route targets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rt_set_net_count
                                            
                                            	Count of nets with paths with the rtset
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.rt_set = YList()
                                                self.rt_set.parent = self
                                                self.rt_set.name = 'rt_set'
                                                self.rt_set_id = None
                                                self.rt_set_len = None
                                                self.rt_set_net_count = None


                                            class RtSet(object):
                                                """
                                                Set of route targets
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rt-set'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:route-target-set'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.rt_set is not None:
                                                    for child_ref in self.rt_set:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.rt_set_id is not None:
                                                    return True

                                                if self.rt_set_len is not None:
                                                    return True

                                                if self.rt_set_net_count is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')
                                            if self.rt_set_id is None:
                                                raise YPYModelError('Key property rt_set_id is None')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rt-set-counter[Cisco-IOS-XR-ipv4-bgp-oper:rt-set-id = ' + str(self.rt_set_id) + ']'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.rt_set_id is not None:
                                                return True

                                            if self.route_target_set is not None and self.route_target_set._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rt-set-counters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.rt_set_counter is not None:
                                            for child_ref in self.rt_set_counter:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters']['meta_info']


                                class BmpPaths(object):
                                    """
                                    The paths in BMP Table
                                    
                                    .. attribute:: bmp_path
                                    
                                    	A BMP path table entry
                                    	**type**\: list of    :py:class:`BmpPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bmp_path = YList()
                                        self.bmp_path.parent = self
                                        self.bmp_path.name = 'bmp_path'


                                    class BmpPath(object):
                                        """
                                        A BMP path table entry
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix>`
                                        
                                        .. attribute:: bmp_net_flags
                                        
                                        	Flags associated with net
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_net_version
                                        
                                        	Net's version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_path
                                        
                                        	List of paths under the BMP net
                                        	**type**\: list of    :py:class:`BmpPath_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_>`
                                        
                                        .. attribute:: has_local_label
                                        
                                        	Net has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_local_label
                                        
                                        	Local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: network
                                        
                                        	Network Prefix in Hex format
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: num_of_path
                                        
                                        	Number of path for the net
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: version_age
                                        
                                        	Net Version bump age
                                        	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionAge>`
                                        
                                        .. attribute:: version_timestamp
                                        
                                        	Net Version bump timestamp
                                        	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self.bmp_net_flags = None
                                            self.bmp_net_version = None
                                            self.bmp_path = YList()
                                            self.bmp_path.parent = self
                                            self.bmp_path.name = 'bmp_path'
                                            self.has_local_label = None
                                            self.net_local_label = None
                                            self.network = None
                                            self.num_of_path = None
                                            self.prefix_length = None
                                            self.version_age = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionAge()
                                            self.version_age.parent = self
                                            self.version_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp()
                                            self.version_timestamp.parent = self


                                        class BgpPrefix(object):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self.prefix_length = None


                                            class Prefix(object):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.prefix is not None and self.prefix._has_data():
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix']['meta_info']


                                        class VersionTimestamp(object):
                                            """
                                            Net Version bump timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp']['meta_info']


                                        class VersionAge(object):
                                            """
                                            Net Version bump age
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-age'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionAge']['meta_info']


                                        class BmpPath_(object):
                                            """
                                            List of paths under the BMP net
                                            
                                            .. attribute:: bmp_nbr_bit_map
                                            
                                            	Paths Nbr bmp bit map
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_path_adv_bit_map
                                            
                                            	Path's Adv bit map
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: bmp_path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_path_snd_bit_map
                                            
                                            	Path's pending snd bit map
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: bpath_pointer
                                            
                                            	BGP Path pointer
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: local_path
                                            
                                            	Is path originated locally?
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress>`
                                            
                                            .. attribute:: received_label
                                            
                                            	Label received from peer
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.bmp_nbr_bit_map = None
                                                self.bmp_path_adv_bit_map = None
                                                self.bmp_path_flags = None
                                                self.bmp_path_snd_bit_map = None
                                                self.bpath_pointer = None
                                                self.local_path = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.received_label = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-path'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bmp_nbr_bit_map is not None:
                                                    return True

                                                if self.bmp_path_adv_bit_map is not None:
                                                    return True

                                                if self.bmp_path_flags is not None:
                                                    return True

                                                if self.bmp_path_snd_bit_map is not None:
                                                    return True

                                                if self.bpath_pointer is not None:
                                                    return True

                                                if self.local_path is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.received_label is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-path'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                return True

                                            if self.bmp_net_flags is not None:
                                                return True

                                            if self.bmp_net_version is not None:
                                                return True

                                            if self.bmp_path is not None:
                                                for child_ref in self.bmp_path:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.has_local_label is not None:
                                                return True

                                            if self.net_local_label is not None:
                                                return True

                                            if self.network is not None:
                                                return True

                                            if self.num_of_path is not None:
                                                return True

                                            if self.prefix_length is not None:
                                                return True

                                            if self.version_age is not None and self.version_age._has_data():
                                                return True

                                            if self.version_timestamp is not None and self.version_timestamp._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-paths'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bmp_path is not None:
                                            for child_ref in self.bmp_path:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths']['meta_info']


                                class UpdateGenerationUpdateGroups(object):
                                    """
                                    Update generation for all update\-groups
                                    
                                    .. attribute:: update_generation_update_group
                                    
                                    	Update generation for update\-group
                                    	**type**\: list of    :py:class:`UpdateGenerationUpdateGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.update_generation_update_group = YList()
                                        self.update_generation_update_group.parent = self
                                        self.update_generation_update_group.name = 'update_generation_update_group'


                                    class UpdateGenerationUpdateGroup(object):
                                        """
                                        Update generation for update\-group
                                        
                                        .. attribute:: update_group_index  <key>
                                        
                                        	Update\-group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: filter_group_count
                                        
                                        	Filter\-group count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_permanent
                                        
                                        	Permanent UG check
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_update_timer_running
                                        
                                        	Is update timer running
                                        	**type**\:  bool
                                        
                                        .. attribute:: last_update_timer_delay_value
                                        
                                        	Last update timer delay value
                                        	**type**\:   :py:class:`LastUpdateTimerDelayValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue>`
                                        
                                        .. attribute:: last_update_timer_expiry_age
                                        
                                        	Time since last update timer expiry event
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_timer_expiry_timestamp
                                        
                                        	Last update timer expiry time
                                        	**type**\:   :py:class:`LastUpdateTimerExpiryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp>`
                                        
                                        .. attribute:: last_update_timer_remaining_value
                                        
                                        	Update timer remaining time
                                        	**type**\:   :py:class:`LastUpdateTimerRemainingValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue>`
                                        
                                        .. attribute:: last_update_timer_start_timestamp
                                        
                                        	Last update timer start time
                                        	**type**\:   :py:class:`LastUpdateTimerStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp>`
                                        
                                        .. attribute:: last_update_timer_stop_timestamp
                                        
                                        	Last update timer stop time
                                        	**type**\:   :py:class:`LastUpdateTimerStopTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp>`
                                        
                                        .. attribute:: neighbor_count
                                        
                                        	Neighbor count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_leaving_count
                                        
                                        	Count of neighbors leaving the update\-group
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_session_af_name
                                        
                                        	Neighbor session address family
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: perm_pelem_allowed
                                        
                                        	Count of Perm Pelems allowed by updgen
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: perm_pelem_encountered
                                        
                                        	Count of Perm Pelems seen by updgen
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: perm_pelem_exp_wdr
                                        
                                        	Count of Perm Pelems explicitly wdrn by updgen
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: perm_pelem_not_allowed
                                        
                                        	Count of Perm Pelems not allowed by updgen
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: perm_pelem_spur_wdr
                                        
                                        	Count of Perm Pelems Spurious withdraws by updgen
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_id
                                        
                                        	ProcessID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_sub_group_count
                                        
                                        	Refresh sub\-group count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_sub_group_throttled_count
                                        
                                        	Throttled refresh sub\-group count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_throttled_count
                                        
                                        	Throttled sub\-group count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_recovery_pending
                                        
                                        	Is update generation recovery pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: update_group_af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: update_group_flags2
                                        
                                        	Update\-group internal flags2
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_group_index_xr
                                        
                                        	Update\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages
                                        
                                        	OutQueue Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size
                                        
                                        	OutQueue Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_statistics
                                        
                                        	Update statistics
                                        	**type**\:   :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics>`
                                        
                                        .. attribute:: update_sub_group_count
                                        
                                        	Sub\-group count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_vrf_name
                                        
                                        	VRF Name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.update_group_index = None
                                            self.filter_group_count = None
                                            self.is_permanent = None
                                            self.is_update_timer_running = None
                                            self.last_update_timer_delay_value = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue()
                                            self.last_update_timer_delay_value.parent = self
                                            self.last_update_timer_expiry_age = None
                                            self.last_update_timer_expiry_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp()
                                            self.last_update_timer_expiry_timestamp.parent = self
                                            self.last_update_timer_remaining_value = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue()
                                            self.last_update_timer_remaining_value.parent = self
                                            self.last_update_timer_start_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp()
                                            self.last_update_timer_start_timestamp.parent = self
                                            self.last_update_timer_stop_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp()
                                            self.last_update_timer_stop_timestamp.parent = self
                                            self.neighbor_count = None
                                            self.neighbor_leaving_count = None
                                            self.neighbor_session_af_name = None
                                            self.perm_pelem_allowed = None
                                            self.perm_pelem_encountered = None
                                            self.perm_pelem_exp_wdr = None
                                            self.perm_pelem_not_allowed = None
                                            self.perm_pelem_spur_wdr = None
                                            self.process_id = None
                                            self.refresh_sub_group_count = None
                                            self.refresh_sub_group_throttled_count = None
                                            self.sub_group_throttled_count = None
                                            self.update_generation_recovery_pending = None
                                            self.update_group_af_name = None
                                            self.update_group_flags2 = None
                                            self.update_group_index_xr = None
                                            self.update_out_queue_messages = None
                                            self.update_out_queue_size = None
                                            self.update_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics()
                                            self.update_statistics.parent = self
                                            self.update_sub_group_count = None
                                            self.update_vrf_name = None


                                        class LastUpdateTimerStartTimestamp(object):
                                            """
                                            Last update timer start time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-timer-start-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp']['meta_info']


                                        class LastUpdateTimerStopTimestamp(object):
                                            """
                                            Last update timer stop time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-timer-stop-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp']['meta_info']


                                        class LastUpdateTimerExpiryTimestamp(object):
                                            """
                                            Last update timer expiry time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-timer-expiry-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp']['meta_info']


                                        class LastUpdateTimerRemainingValue(object):
                                            """
                                            Update timer remaining time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-timer-remaining-value'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue']['meta_info']


                                        class LastUpdateTimerDelayValue(object):
                                            """
                                            Last update timer delay value
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-timer-delay-value'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue']['meta_info']


                                        class UpdateStatistics(object):
                                            """
                                            Update statistics
                                            
                                            .. attribute:: last_update_cleard_age
                                            
                                            	Time since last Clear event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_cleared_timestamp
                                            
                                            	Last Cleared time
                                            	**type**\:   :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp>`
                                            
                                            .. attribute:: last_update_discard_age
                                            
                                            	Time since last Discard event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_discard_timestamp
                                            
                                            	Last Discarded time
                                            	**type**\:   :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                            
                                            .. attribute:: last_update_memory_allocation_fail_age
                                            
                                            	Time since last memory allocation failure event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_memory_allocation_fail_timestamp
                                            
                                            	Memory allocation failure time
                                            	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                            
                                            .. attribute:: last_update_recovery_age
                                            
                                            	Time since last Recovery event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_recovery_timestamp
                                            
                                            	Last Recovery time
                                            	**type**\:   :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                            
                                            .. attribute:: last_update_throttle_age
                                            
                                            	Time since last Throttle event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_throttle_timestamp
                                            
                                            	Last Throttled time
                                            	**type**\:   :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                            
                                            .. attribute:: update_memory_allocation_fail_count
                                            
                                            	Memory allocation failure count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_cleared
                                            
                                            	OutQueue Cleared Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_cumulative
                                            
                                            	OutQueue Cumulative Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_discarded
                                            
                                            	OutQueue Discarded Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_high
                                            
                                            	OutQueue High Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_size_cleared
                                            
                                            	OutQueue Cleared Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_cumulative
                                            
                                            	OutQueue Cumulative Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_discarded
                                            
                                            	OutQueue Discarded Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_high
                                            
                                            	OutQueue Hi Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_recovery_count
                                            
                                            	Recovery Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_throttle_count
                                            
                                            	Throttle Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.last_update_cleard_age = None
                                                self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp()
                                                self.last_update_cleared_timestamp.parent = self
                                                self.last_update_discard_age = None
                                                self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp()
                                                self.last_update_discard_timestamp.parent = self
                                                self.last_update_memory_allocation_fail_age = None
                                                self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                                self.last_update_memory_allocation_fail_timestamp.parent = self
                                                self.last_update_recovery_age = None
                                                self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                                self.last_update_recovery_timestamp.parent = self
                                                self.last_update_throttle_age = None
                                                self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp()
                                                self.last_update_throttle_timestamp.parent = self
                                                self.update_memory_allocation_fail_count = None
                                                self.update_out_queue_messages_cleared = None
                                                self.update_out_queue_messages_cumulative = None
                                                self.update_out_queue_messages_discarded = None
                                                self.update_out_queue_messages_high = None
                                                self.update_out_queue_size_cleared = None
                                                self.update_out_queue_size_cumulative = None
                                                self.update_out_queue_size_discarded = None
                                                self.update_out_queue_size_high = None
                                                self.update_recovery_count = None
                                                self.update_throttle_count = None


                                            class LastUpdateDiscardTimestamp(object):
                                                """
                                                Last Discarded time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-discard-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp']['meta_info']


                                            class LastUpdateClearedTimestamp(object):
                                                """
                                                Last Cleared time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-cleared-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp']['meta_info']


                                            class LastUpdateThrottleTimestamp(object):
                                                """
                                                Last Throttled time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-throttle-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp']['meta_info']


                                            class LastUpdateRecoveryTimestamp(object):
                                                """
                                                Last Recovery time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-recovery-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp']['meta_info']


                                            class LastUpdateMemoryAllocationFailTimestamp(object):
                                                """
                                                Memory allocation failure time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-memory-allocation-fail-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-statistics'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.last_update_cleard_age is not None:
                                                    return True

                                                if self.last_update_cleared_timestamp is not None and self.last_update_cleared_timestamp._has_data():
                                                    return True

                                                if self.last_update_discard_age is not None:
                                                    return True

                                                if self.last_update_discard_timestamp is not None and self.last_update_discard_timestamp._has_data():
                                                    return True

                                                if self.last_update_memory_allocation_fail_age is not None:
                                                    return True

                                                if self.last_update_memory_allocation_fail_timestamp is not None and self.last_update_memory_allocation_fail_timestamp._has_data():
                                                    return True

                                                if self.last_update_recovery_age is not None:
                                                    return True

                                                if self.last_update_recovery_timestamp is not None and self.last_update_recovery_timestamp._has_data():
                                                    return True

                                                if self.last_update_throttle_age is not None:
                                                    return True

                                                if self.last_update_throttle_timestamp is not None and self.last_update_throttle_timestamp._has_data():
                                                    return True

                                                if self.update_memory_allocation_fail_count is not None:
                                                    return True

                                                if self.update_out_queue_messages_cleared is not None:
                                                    return True

                                                if self.update_out_queue_messages_cumulative is not None:
                                                    return True

                                                if self.update_out_queue_messages_discarded is not None:
                                                    return True

                                                if self.update_out_queue_messages_high is not None:
                                                    return True

                                                if self.update_out_queue_size_cleared is not None:
                                                    return True

                                                if self.update_out_queue_size_cumulative is not None:
                                                    return True

                                                if self.update_out_queue_size_discarded is not None:
                                                    return True

                                                if self.update_out_queue_size_high is not None:
                                                    return True

                                                if self.update_recovery_count is not None:
                                                    return True

                                                if self.update_throttle_count is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')
                                            if self.update_group_index is None:
                                                raise YPYModelError('Key property update_group_index is None')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-update-group[Cisco-IOS-XR-ipv4-bgp-oper:update-group-index = ' + str(self.update_group_index) + ']'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.update_group_index is not None:
                                                return True

                                            if self.filter_group_count is not None:
                                                return True

                                            if self.is_permanent is not None:
                                                return True

                                            if self.is_update_timer_running is not None:
                                                return True

                                            if self.last_update_timer_delay_value is not None and self.last_update_timer_delay_value._has_data():
                                                return True

                                            if self.last_update_timer_expiry_age is not None:
                                                return True

                                            if self.last_update_timer_expiry_timestamp is not None and self.last_update_timer_expiry_timestamp._has_data():
                                                return True

                                            if self.last_update_timer_remaining_value is not None and self.last_update_timer_remaining_value._has_data():
                                                return True

                                            if self.last_update_timer_start_timestamp is not None and self.last_update_timer_start_timestamp._has_data():
                                                return True

                                            if self.last_update_timer_stop_timestamp is not None and self.last_update_timer_stop_timestamp._has_data():
                                                return True

                                            if self.neighbor_count is not None:
                                                return True

                                            if self.neighbor_leaving_count is not None:
                                                return True

                                            if self.neighbor_session_af_name is not None:
                                                return True

                                            if self.perm_pelem_allowed is not None:
                                                return True

                                            if self.perm_pelem_encountered is not None:
                                                return True

                                            if self.perm_pelem_exp_wdr is not None:
                                                return True

                                            if self.perm_pelem_not_allowed is not None:
                                                return True

                                            if self.perm_pelem_spur_wdr is not None:
                                                return True

                                            if self.process_id is not None:
                                                return True

                                            if self.refresh_sub_group_count is not None:
                                                return True

                                            if self.refresh_sub_group_throttled_count is not None:
                                                return True

                                            if self.sub_group_throttled_count is not None:
                                                return True

                                            if self.update_generation_recovery_pending is not None:
                                                return True

                                            if self.update_group_af_name is not None:
                                                return True

                                            if self.update_group_flags2 is not None:
                                                return True

                                            if self.update_group_index_xr is not None:
                                                return True

                                            if self.update_out_queue_messages is not None:
                                                return True

                                            if self.update_out_queue_size is not None:
                                                return True

                                            if self.update_statistics is not None and self.update_statistics._has_data():
                                                return True

                                            if self.update_sub_group_count is not None:
                                                return True

                                            if self.update_vrf_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-update-groups'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.update_generation_update_group is not None:
                                            for child_ref in self.update_generation_update_group:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups']['meta_info']


                                class UpdateGenerationFilterGroups(object):
                                    """
                                    Update generation for all filter\-groups under
                                    a sub\-group
                                    
                                    .. attribute:: update_generation_filter_group
                                    
                                    	Update generation for filter\-group
                                    	**type**\: list of    :py:class:`UpdateGenerationFilterGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.update_generation_filter_group = YList()
                                        self.update_generation_filter_group.parent = self
                                        self.update_generation_filter_group.name = 'update_generation_filter_group'


                                    class UpdateGenerationFilterGroup(object):
                                        """
                                        Update generation for filter\-group
                                        
                                        .. attribute:: filter_group_index
                                        
                                        	Filter\-group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: neighbor_count
                                        
                                        	Neighbor count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: parent_filter_group_index
                                        
                                        	Parent Filter\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: parent_sub_group_id
                                        
                                        	Parent Sub\-group identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: parent_sub_group_index
                                        
                                        	Parent Sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_id
                                        
                                        	ProcessID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_id
                                        
                                        	Sub\-group ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: sub_group_id_xr
                                        
                                        	Sub\-group identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_index
                                        
                                        	Sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: sub_group_index_xr
                                        
                                        	Sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_filter_group_index
                                        
                                        	Filter\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_group_af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: update_group_index
                                        
                                        	Update\-group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: update_group_index_xr
                                        
                                        	Update\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_vrf_name
                                        
                                        	VRF Name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.filter_group_index = None
                                            self.neighbor_count = None
                                            self.parent_filter_group_index = None
                                            self.parent_sub_group_id = None
                                            self.parent_sub_group_index = None
                                            self.process_id = None
                                            self.sub_group_id = None
                                            self.sub_group_id_xr = None
                                            self.sub_group_index = None
                                            self.sub_group_index_xr = None
                                            self.update_filter_group_index = None
                                            self.update_group_af_name = None
                                            self.update_group_index = None
                                            self.update_group_index_xr = None
                                            self.update_vrf_name = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-filter-group'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.filter_group_index is not None:
                                                return True

                                            if self.neighbor_count is not None:
                                                return True

                                            if self.parent_filter_group_index is not None:
                                                return True

                                            if self.parent_sub_group_id is not None:
                                                return True

                                            if self.parent_sub_group_index is not None:
                                                return True

                                            if self.process_id is not None:
                                                return True

                                            if self.sub_group_id is not None:
                                                return True

                                            if self.sub_group_id_xr is not None:
                                                return True

                                            if self.sub_group_index is not None:
                                                return True

                                            if self.sub_group_index_xr is not None:
                                                return True

                                            if self.update_filter_group_index is not None:
                                                return True

                                            if self.update_group_af_name is not None:
                                                return True

                                            if self.update_group_index is not None:
                                                return True

                                            if self.update_group_index_xr is not None:
                                                return True

                                            if self.update_vrf_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-filter-groups'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.update_generation_filter_group is not None:
                                            for child_ref in self.update_generation_filter_group:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups']['meta_info']


                                class Networks(object):
                                    """
                                    The BGP Network Table
                                    
                                    .. attribute:: network
                                    
                                    	A BGP Network table entry
                                    	**type**\: list of    :py:class:`Network <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.network = YList()
                                        self.network.parent = self
                                        self.network.name = 'network'


                                    class Network(object):
                                        """
                                        A BGP Network table entry
                                        
                                        .. attribute:: active_path_element
                                        
                                        	Path element list received from Active inst
                                        	**type**\: list of    :py:class:`ActivePathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement>`
                                        
                                        .. attribute:: active_process_instance_path
                                        
                                        	Active's paths for this net 
                                        	**type**\: list of    :py:class:`ActiveProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath>`
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield>`
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix>`
                                        
                                        .. attribute:: bit
                                        
                                        	Bit
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: flags
                                        
                                        	Flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: gateway_array
                                        
                                        	Gateway array ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_inconsistent_paths
                                        
                                        	Net has inconsistent paths
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_lbl_retained
                                        
                                        	Net has label retained
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_local_label
                                        
                                        	Net has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_net_aggregation_suppressed
                                        
                                        	Net suppressed due to aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_net_ldp_signaled
                                        
                                        	L2VPN Net LDP signaled  aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_permanent_network
                                        
                                        	Permanent Network
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_path_element
                                        
                                        	Local path element list
                                        	**type**\: list of    :py:class:`LocalPathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement>`
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: local_process_instance_path
                                        
                                        	Local (to process instance) paths for this net 
                                        	**type**\: list of    :py:class:`LocalProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath>`
                                        
                                        .. attribute:: net_backup_available
                                        
                                        	Net has backup path
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_backup_label_rewrite_available
                                        
                                        	Net has label rewrite for backup path
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_eibgp_multipath
                                        
                                        	Net has EIBGP multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_extended_flags
                                        
                                        	Net extended flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: net_flags
                                        
                                        	Flags associated with                            net
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: net_local_label
                                        
                                        	Local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: net_local_label_rewrite
                                        
                                        	Net label has rewrite
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_local_label_srgb
                                        
                                        	Net label allocated fromSegment routing global block
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_multipath
                                        
                                        	Net has multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: network
                                        
                                        	Network in prefix/length format
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        
                                        ----
                                        .. attribute:: num_of_path
                                        
                                        	Number of path for this net
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: resilient_nexthop_set
                                        
                                        	Resilient nexthop set ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_failed
                                        
                                        	RIB install failed
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: table_brib_version
                                        
                                        	Table version # for updates
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: table_version
                                        
                                        	Table version # for net
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version
                                        
                                        	Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version_age
                                        
                                        	Version age
                                        	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.VersionAge>`
                                        
                                        .. attribute:: version_timestamp
                                        
                                        	Version timestamp
                                        	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.VersionTimestamp>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.active_path_element = YList()
                                            self.active_path_element.parent = self
                                            self.active_path_element.name = 'active_path_element'
                                            self.active_process_instance_path = YList()
                                            self.active_process_instance_path.parent = self
                                            self.active_process_instance_path.name = 'active_process_instance_path'
                                            self.add_path_orr_bitfield = YList()
                                            self.add_path_orr_bitfield.parent = self
                                            self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                            self.advertisedto_pe = None
                                            self.af_name = None
                                            self.best_path_orr_bitfield = YList()
                                            self.best_path_orr_bitfield.parent = self
                                            self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self.bit = None
                                            self.flags = None
                                            self.gateway_array = None
                                            self.has_inconsistent_paths = None
                                            self.has_lbl_retained = None
                                            self.has_local_label = None
                                            self.is_net_aggregation_suppressed = None
                                            self.is_net_ldp_signaled = None
                                            self.is_permanent_network = None
                                            self.local_path_element = YList()
                                            self.local_path_element.parent = self
                                            self.local_path_element.name = 'local_path_element'
                                            self.local_peers_advertised_to = YList()
                                            self.local_peers_advertised_to.parent = self
                                            self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                            self.local_process_instance_path = YList()
                                            self.local_process_instance_path.parent = self
                                            self.local_process_instance_path.name = 'local_process_instance_path'
                                            self.net_backup_available = None
                                            self.net_backup_label_rewrite_available = None
                                            self.net_eibgp_multipath = None
                                            self.net_extended_flags = None
                                            self.net_flags = None
                                            self.net_local_label = None
                                            self.net_local_label_rewrite = None
                                            self.net_local_label_srgb = None
                                            self.net_multipath = None
                                            self.network = None
                                            self.num_of_path = None
                                            self.pe_peers_advertised_to = YList()
                                            self.pe_peers_advertised_to.parent = self
                                            self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                            self.process_instance_id = None
                                            self.rd = None
                                            self.resilient_nexthop_set = None
                                            self.rib_failed = None
                                            self.route_distinguisher = None
                                            self.table_brib_version = None
                                            self.table_version = None
                                            self.version = None
                                            self.version_age = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.VersionAge()
                                            self.version_age.parent = self
                                            self.version_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.VersionTimestamp()
                                            self.version_timestamp.parent = self
                                            self.vrf_name = None


                                        class BgpPrefix(object):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self.prefix_length = None


                                            class Prefix(object):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.prefix is not None and self.prefix._has_data():
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix']['meta_info']


                                        class VersionTimestamp(object):
                                            """
                                            Version timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.VersionTimestamp']['meta_info']


                                        class VersionAge(object):
                                            """
                                            Version age
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-age'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.VersionAge']['meta_info']


                                        class LocalPeersAdvertisedTo(object):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo']['meta_info']


                                        class PePeersAdvertisedTo(object):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo']['meta_info']


                                        class BestPathOrrBitfield(object):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield']['meta_info']


                                        class AddPathOrrBitfield(object):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield']['meta_info']


                                        class LocalProcessInstancePath(object):
                                            """
                                            Local (to process instance) paths for this net 
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: attributes_after_policy_in
                                            
                                            	Attributes after inbound policy applied
                                            	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn>`
                                            
                                            .. attribute:: label_fail
                                            
                                            	LSD label allocation failed 
                                            	**type**\:  bool
                                            
                                            .. attribute:: label_o_or_version
                                            
                                            	Label Version when OOR happens
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_oor
                                            
                                            	LSD label space is exhausted
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address_xr
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr>`
                                            
                                            .. attribute:: no_path
                                            
                                            	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                            	**type**\:  bool
                                            
                                            .. attribute:: path_information
                                            
                                            	Path information
                                            	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation>`
                                            
                                            .. attribute:: prefix_version
                                            
                                            	Version of BGP Prefix Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: process_instance_id
                                            
                                            	Process instance ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_route_distinguisher
                                            
                                            	Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_vrf_name
                                            
                                            	Name of the source VRF
                                            	**type**\:  str
                                            
                                            .. attribute:: srcaf_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.af_name = None
                                                self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn()
                                                self.attributes_after_policy_in.parent = self
                                                self.label_fail = None
                                                self.label_o_or_version = None
                                                self.label_oor = None
                                                self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr()
                                                self.neighbor_address_xr.parent = self
                                                self.no_path = None
                                                self.path_information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation()
                                                self.path_information.parent = self
                                                self.prefix_version = None
                                                self.process_instance_id = None
                                                self.route_distinguisher = None
                                                self.source_route_distinguisher = None
                                                self.source_vrf_name = None
                                                self.srcaf_name = None
                                                self.vrf_name = None


                                            class NeighborAddressXr(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr']['meta_info']


                                            class PathInformation(object):
                                                """
                                                Path information
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\:  bool
                                                
                                                .. attribute:: accept_own_self_originated_p_ath
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\:  bool
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\:  bool
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix>`
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\:  bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\:  bool
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr>`
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_esi
                                                
                                                	Path has EVPN ESI
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_rcvd_label
                                                
                                                	Path has received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\:  bool
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebg_ps
                                                
                                                	Not advertised to EBGPs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi>`
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress>`
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop>`
                                                
                                                .. attribute:: nhte_tunnel
                                                
                                                	NH TE tunnel information
                                                	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhteTunnel>`
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\:  bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.accept_own_path = None
                                                    self.accept_own_self_originated_p_ath = None
                                                    self.add_path_orr_bitfield = YList()
                                                    self.add_path_orr_bitfield.parent = self
                                                    self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                    self.advertisedto_pe = None
                                                    self.aigp_metric = None
                                                    self.best_path_comp_stage = None
                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self.best_path_id = None
                                                    self.best_path_id_comp_winner = None
                                                    self.best_path_orr_bitfield = YList()
                                                    self.best_path_orr_bitfield.parent = self
                                                    self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self.dampen_penalty = None
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.fspec_invalid_path = None
                                                    self.graceful_shutdown = None
                                                    self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self.halflife_time = None
                                                    self.has_esi = None
                                                    self.has_gw_addr = None
                                                    self.has_local_net_label = None
                                                    self.has_mdt_group_addr = None
                                                    self.has_mvpn_extcomm = None
                                                    self.has_mvpn_nbr_addr = None
                                                    self.has_mvpn_nexthop_addr = None
                                                    self.has_mvpn_pmsi = None
                                                    self.has_rcvd_label = None
                                                    self.has_second_label = None
                                                    self.ibgp_signaled_validity = None
                                                    self.igp_metric = None
                                                    self.is_aggregation_suppressed = None
                                                    self.is_as_best = None
                                                    self.is_best_path = None
                                                    self.is_import_dampened = None
                                                    self.is_import_suspect = None
                                                    self.is_internal_path = None
                                                    self.is_partial_best = None
                                                    self.is_path_additional_path = None
                                                    self.is_path_advertised_local_as_only = None
                                                    self.is_path_af_install_eligible = None
                                                    self.is_path_backup = None
                                                    self.is_path_backup_protect_multipath = None
                                                    self.is_path_best_external = None
                                                    self.is_path_damped = None
                                                    self.is_path_from_confederation_peer = None
                                                    self.is_path_from_network_command = None
                                                    self.is_path_from_redistribute_command = None
                                                    self.is_path_from_route_reflector = None
                                                    self.is_path_history_held = None
                                                    self.is_path_imp_candidate = None
                                                    self.is_path_imported = None
                                                    self.is_path_local_aggregate = None
                                                    self.is_path_locally_sourced = None
                                                    self.is_path_long_lived_stale = None
                                                    self.is_path_multipath = None
                                                    self.is_path_nexthop_discarded = None
                                                    self.is_path_not_advertised = None
                                                    self.is_path_not_advertised_to_ebg_ps = None
                                                    self.is_path_received_only = None
                                                    self.is_path_reoriginated = None
                                                    self.is_path_reoriginated_stitching = None
                                                    self.is_path_stale = None
                                                    self.is_path_synced_with_igp = None
                                                    self.is_path_valid = None
                                                    self.is_path_vpn_only = None
                                                    self.is_permanent_path = None
                                                    self.is_received_path_not_modified = None
                                                    self.is_spkr_as_best = None
                                                    self.l2vpn_circuit_status_value = YList()
                                                    self.l2vpn_circuit_status_value.parent = self
                                                    self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                    self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi()
                                                    self.l2vpn_evpn_esi.parent = self
                                                    self.l2vpn_size = None
                                                    self.labeled_unicast_safi_path = None
                                                    self.local_label = None
                                                    self.local_nh = None
                                                    self.local_path_id = None
                                                    self.local_peers_advertised_to = YList()
                                                    self.local_peers_advertised_to.parent = self
                                                    self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                    self.maximum_suppress_time = None
                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self.mvpn_path_flags = None
                                                    self.mvpn_pmsi_flags = None
                                                    self.mvpn_pmsi_label = None
                                                    self.mvpn_pmsi_type = None
                                                    self.mvpn_pmsi_value = YList()
                                                    self.mvpn_pmsi_value.parent = self
                                                    self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                    self.mvpn_sfs_path = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.neighbor_router_id = None
                                                    self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop()
                                                    self.next_hop.parent = self
                                                    self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhteTunnel()
                                                    self.nhte_tunnel.parent = self
                                                    self.path_flags = None
                                                    self.path_flap_count = None
                                                    self.path_import_flags = None
                                                    self.path_rt_set_id = None
                                                    self.path_rt_set_route_count = None
                                                    self.path_table_version = None
                                                    self.path_weight = None
                                                    self.pe_peers_advertised_to = YList()
                                                    self.pe_peers_advertised_to.parent = self
                                                    self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                    self.rcvd_label = None
                                                    self.rcvd_path_id = None
                                                    self.reuse_value = None
                                                    self.rib_failed = None
                                                    self.route_type = None
                                                    self.rpki_origin_as_validation_disabled = None
                                                    self.rt_set_limit_enabled = None
                                                    self.second_label = None
                                                    self.seconds_since_first_flap = None
                                                    self.show_rpki_origin_as_validity = None
                                                    self.sn_rpki_origin_as_validity = None
                                                    self.suppress_penalty = None
                                                    self.time_to_unsuppress = None


                                                class BgpPrefix(object):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self.prefix_length = None


                                                    class Prefix(object):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.prefix is not None and self.prefix._has_data():
                                                            return True

                                                        if self.prefix_length is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix']['meta_info']


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress']['meta_info']


                                                class NextHop(object):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop']['meta_info']


                                                class NhteTunnel(object):
                                                    """
                                                    NH TE tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_te_tunnel
                                                    
                                                    	NH TE Tunnel info is present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last rib update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	tunnel name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	tunnel type
                                                    	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.binding_label = None
                                                        self.has_te_tunnel = None
                                                        self.is_tunnel_info_stale = None
                                                        self.is_tunnel_registered = None
                                                        self.is_tunnel_up = None
                                                        self.last_tunnel_update = None
                                                        self.tunnel_if_handle = None
                                                        self.tunnel_name = None
                                                        self.tunnel_type = None
                                                        self.tunnel_v6_enabled = None
                                                        self.tunnel_v6_required = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.binding_label is not None:
                                                            return True

                                                        if self.has_te_tunnel is not None:
                                                            return True

                                                        if self.is_tunnel_info_stale is not None:
                                                            return True

                                                        if self.is_tunnel_registered is not None:
                                                            return True

                                                        if self.is_tunnel_up is not None:
                                                            return True

                                                        if self.last_tunnel_update is not None:
                                                            return True

                                                        if self.tunnel_if_handle is not None:
                                                            return True

                                                        if self.tunnel_name is not None:
                                                            return True

                                                        if self.tunnel_type is not None:
                                                            return True

                                                        if self.tunnel_v6_enabled is not None:
                                                            return True

                                                        if self.tunnel_v6_required is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhteTunnel']['meta_info']


                                                class MdtGroupAddr(object):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr']['meta_info']


                                                class L2VpnEvpnEsi(object):
                                                    """
                                                    L2VPN EVPN ESI
                                                    
                                                    .. attribute:: esi
                                                    
                                                    	esi
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.esi = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.esi is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi']['meta_info']


                                                class GwAddr(object):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.len = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.len is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr']['meta_info']


                                                class BestPathCompWinner(object):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner']['meta_info']


                                                class MvpnNbrAddr(object):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr']['meta_info']


                                                class MvpnNexthopAddr(object):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr']['meta_info']


                                                class L2VpnCircuitStatusValue(object):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                                class MvpnPmsiValue(object):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity']['meta_info']


                                                class LocalPeersAdvertisedTo(object):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                                class PePeersAdvertisedTo(object):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo']['meta_info']


                                                class BestPathOrrBitfield(object):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield']['meta_info']


                                                class AddPathOrrBitfield(object):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.accept_own_path is not None:
                                                        return True

                                                    if self.accept_own_self_originated_p_ath is not None:
                                                        return True

                                                    if self.add_path_orr_bitfield is not None:
                                                        for child_ref in self.add_path_orr_bitfield:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.advertisedto_pe is not None:
                                                        return True

                                                    if self.aigp_metric is not None:
                                                        return True

                                                    if self.best_path_comp_stage is not None:
                                                        return True

                                                    if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                        return True

                                                    if self.best_path_id is not None:
                                                        return True

                                                    if self.best_path_id_comp_winner is not None:
                                                        return True

                                                    if self.best_path_orr_bitfield is not None:
                                                        for child_ref in self.best_path_orr_bitfield:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                        return True

                                                    if self.dampen_penalty is not None:
                                                        return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.fspec_invalid_path is not None:
                                                        return True

                                                    if self.graceful_shutdown is not None:
                                                        return True

                                                    if self.gw_addr is not None and self.gw_addr._has_data():
                                                        return True

                                                    if self.halflife_time is not None:
                                                        return True

                                                    if self.has_esi is not None:
                                                        return True

                                                    if self.has_gw_addr is not None:
                                                        return True

                                                    if self.has_local_net_label is not None:
                                                        return True

                                                    if self.has_mdt_group_addr is not None:
                                                        return True

                                                    if self.has_mvpn_extcomm is not None:
                                                        return True

                                                    if self.has_mvpn_nbr_addr is not None:
                                                        return True

                                                    if self.has_mvpn_nexthop_addr is not None:
                                                        return True

                                                    if self.has_mvpn_pmsi is not None:
                                                        return True

                                                    if self.has_rcvd_label is not None:
                                                        return True

                                                    if self.has_second_label is not None:
                                                        return True

                                                    if self.ibgp_signaled_validity is not None:
                                                        return True

                                                    if self.igp_metric is not None:
                                                        return True

                                                    if self.is_aggregation_suppressed is not None:
                                                        return True

                                                    if self.is_as_best is not None:
                                                        return True

                                                    if self.is_best_path is not None:
                                                        return True

                                                    if self.is_import_dampened is not None:
                                                        return True

                                                    if self.is_import_suspect is not None:
                                                        return True

                                                    if self.is_internal_path is not None:
                                                        return True

                                                    if self.is_partial_best is not None:
                                                        return True

                                                    if self.is_path_additional_path is not None:
                                                        return True

                                                    if self.is_path_advertised_local_as_only is not None:
                                                        return True

                                                    if self.is_path_af_install_eligible is not None:
                                                        return True

                                                    if self.is_path_backup is not None:
                                                        return True

                                                    if self.is_path_backup_protect_multipath is not None:
                                                        return True

                                                    if self.is_path_best_external is not None:
                                                        return True

                                                    if self.is_path_damped is not None:
                                                        return True

                                                    if self.is_path_from_confederation_peer is not None:
                                                        return True

                                                    if self.is_path_from_network_command is not None:
                                                        return True

                                                    if self.is_path_from_redistribute_command is not None:
                                                        return True

                                                    if self.is_path_from_route_reflector is not None:
                                                        return True

                                                    if self.is_path_history_held is not None:
                                                        return True

                                                    if self.is_path_imp_candidate is not None:
                                                        return True

                                                    if self.is_path_imported is not None:
                                                        return True

                                                    if self.is_path_local_aggregate is not None:
                                                        return True

                                                    if self.is_path_locally_sourced is not None:
                                                        return True

                                                    if self.is_path_long_lived_stale is not None:
                                                        return True

                                                    if self.is_path_multipath is not None:
                                                        return True

                                                    if self.is_path_nexthop_discarded is not None:
                                                        return True

                                                    if self.is_path_not_advertised is not None:
                                                        return True

                                                    if self.is_path_not_advertised_to_ebg_ps is not None:
                                                        return True

                                                    if self.is_path_received_only is not None:
                                                        return True

                                                    if self.is_path_reoriginated is not None:
                                                        return True

                                                    if self.is_path_reoriginated_stitching is not None:
                                                        return True

                                                    if self.is_path_stale is not None:
                                                        return True

                                                    if self.is_path_synced_with_igp is not None:
                                                        return True

                                                    if self.is_path_valid is not None:
                                                        return True

                                                    if self.is_path_vpn_only is not None:
                                                        return True

                                                    if self.is_permanent_path is not None:
                                                        return True

                                                    if self.is_received_path_not_modified is not None:
                                                        return True

                                                    if self.is_spkr_as_best is not None:
                                                        return True

                                                    if self.l2vpn_circuit_status_value is not None:
                                                        for child_ref in self.l2vpn_circuit_status_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                        return True

                                                    if self.l2vpn_size is not None:
                                                        return True

                                                    if self.labeled_unicast_safi_path is not None:
                                                        return True

                                                    if self.local_label is not None:
                                                        return True

                                                    if self.local_nh is not None:
                                                        return True

                                                    if self.local_path_id is not None:
                                                        return True

                                                    if self.local_peers_advertised_to is not None:
                                                        for child_ref in self.local_peers_advertised_to:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.maximum_suppress_time is not None:
                                                        return True

                                                    if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                        return True

                                                    if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                        return True

                                                    if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                        return True

                                                    if self.mvpn_path_flags is not None:
                                                        return True

                                                    if self.mvpn_pmsi_flags is not None:
                                                        return True

                                                    if self.mvpn_pmsi_label is not None:
                                                        return True

                                                    if self.mvpn_pmsi_type is not None:
                                                        return True

                                                    if self.mvpn_pmsi_value is not None:
                                                        for child_ref in self.mvpn_pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.mvpn_sfs_path is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.neighbor_router_id is not None:
                                                        return True

                                                    if self.next_hop is not None and self.next_hop._has_data():
                                                        return True

                                                    if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                        return True

                                                    if self.path_flags is not None:
                                                        return True

                                                    if self.path_flap_count is not None:
                                                        return True

                                                    if self.path_import_flags is not None:
                                                        return True

                                                    if self.path_rt_set_id is not None:
                                                        return True

                                                    if self.path_rt_set_route_count is not None:
                                                        return True

                                                    if self.path_table_version is not None:
                                                        return True

                                                    if self.path_weight is not None:
                                                        return True

                                                    if self.pe_peers_advertised_to is not None:
                                                        for child_ref in self.pe_peers_advertised_to:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.rcvd_label is not None:
                                                        return True

                                                    if self.rcvd_path_id is not None:
                                                        return True

                                                    if self.reuse_value is not None:
                                                        return True

                                                    if self.rib_failed is not None:
                                                        return True

                                                    if self.route_type is not None:
                                                        return True

                                                    if self.rpki_origin_as_validation_disabled is not None:
                                                        return True

                                                    if self.rt_set_limit_enabled is not None:
                                                        return True

                                                    if self.second_label is not None:
                                                        return True

                                                    if self.seconds_since_first_flap is not None:
                                                        return True

                                                    if self.show_rpki_origin_as_validity is not None:
                                                        return True

                                                    if self.sn_rpki_origin_as_validity is not None:
                                                        return True

                                                    if self.suppress_penalty is not None:
                                                        return True

                                                    if self.time_to_unsuppress is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation']['meta_info']


                                            class AttributesAfterPolicyIn(object):
                                                """
                                                Attributes after inbound policy applied
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\:  bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\:  bool
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                    self.attr_set.parent = self
                                                    self.attribute_key_number = None
                                                    self.attribute_reuse_id_config = None
                                                    self.attribute_reuse_id_current = None
                                                    self.attribute_reuse_id_keys = None
                                                    self.attribute_reuse_id_max_id = None
                                                    self.attribute_reuse_id_node = None
                                                    self.attribute_reuse_id_recover_sec = None
                                                    self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self.is_application_gateway_present = None
                                                    self.is_as_path2_byte = None
                                                    self.is_attr_set_present = None
                                                    self.is_ribrnh_present = None
                                                    self.is_rnh_present = None
                                                    self.ribrnh_encap = None
                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self.ribrnh_mac = None
                                                    self.ribrnh_table = None
                                                    self.ribrnh_vni = None
                                                    self.ribrnhip_table = None
                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self.rnh_addr_len = None
                                                    self.rnh_len = None
                                                    self.rnh_type = None
                                                    self.set_aigp_inbound_igp = None
                                                    self.set_aigp_inbound_metric = None
                                                    self.vpn_distinguisher = None


                                                class CommonAttributes(object):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_encap_present
                                                    
                                                    	Tunnel Encap attribute present 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_policy_allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_binding_sid
                                                    
                                                    	SR Policy Binding sid
                                                    	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_explicit_path
                                                    
                                                    	SR Policy Explicit paths
                                                    	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                    
                                                    .. attribute:: sr_policy_preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_tunnel_request_state
                                                    
                                                    	SR Tunnel Request State
                                                    	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                    
                                                    .. attribute:: sr_tunnel_state
                                                    
                                                    	SR Tunnel State
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encap Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.aggregator_address = None
                                                        self.aggregator_as = None
                                                        self.aigp_metric_value = None
                                                        self.as_path = None
                                                        self.cluster = YList()
                                                        self.cluster.parent = self
                                                        self.cluster.name = 'cluster'
                                                        self.community = YList()
                                                        self.community.parent = self
                                                        self.community.name = 'community'
                                                        self.connector_type = None
                                                        self.connector_value = YList()
                                                        self.connector_value.parent = self
                                                        self.connector_value.name = 'connector_value'
                                                        self.extended_community = YList()
                                                        self.extended_community.parent = self
                                                        self.extended_community.name = 'extended_community'
                                                        self.extended_community_flags = None
                                                        self.is_aggregator_present = None
                                                        self.is_aigp_present = None
                                                        self.is_as_path_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_community_present = None
                                                        self.is_connector_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_label_index_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_metric_present = None
                                                        self.is_origin_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_ssa_present = None
                                                        self.is_tunnel_encap_present = None
                                                        self.l2tpv3_cookie = YList()
                                                        self.l2tpv3_cookie.parent = self
                                                        self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                        self.l2tpv3_session_id = None
                                                        self.label_index_attr = YList()
                                                        self.label_index_attr.parent = self
                                                        self.label_index_attr.name = 'label_index_attr'
                                                        self.local_preference = None
                                                        self.ls_attr = YList()
                                                        self.ls_attr.parent = self
                                                        self.ls_attr.name = 'ls_attr'
                                                        self.metric = None
                                                        self.neighbor_as = None
                                                        self.origin = None
                                                        self.originator = None
                                                        self.pe_distinguisher_label = YList()
                                                        self.pe_distinguisher_label.parent = self
                                                        self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.pmsi_type = None
                                                        self.pmsi_value = YList()
                                                        self.pmsi_value.parent = self
                                                        self.pmsi_value.name = 'pmsi_value'
                                                        self.ppm_pvalue = None
                                                        self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                        self.sr_policy_allocated_binding_sid.parent = self
                                                        self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                        self.sr_policy_binding_sid.parent = self
                                                        self.sr_policy_explicit_path = YList()
                                                        self.sr_policy_explicit_path.parent = self
                                                        self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                        self.sr_policy_preference = None
                                                        self.sr_tunnel_request_state = None
                                                        self.sr_tunnel_state = None
                                                        self.tunnel_encap_type = None
                                                        self.unknown_attribute = YList()
                                                        self.unknown_attribute.parent = self
                                                        self.unknown_attribute.name = 'unknown_attribute'


                                                    class SrPolicyBindingSid(object):
                                                        """
                                                        SR Policy Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                    class SrPolicyAllocatedBindingSid(object):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                    class Community(object):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                    class ExtendedCommunity(object):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                    class UnknownAttribute(object):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                    class Cluster(object):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                    class L2Tpv3Cookie(object):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                    class ConnectorValue(object):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                    class PmsiValue(object):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                    class LsAttr(object):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                    class LabelIndexAttr(object):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                    class PeDistinguisherLabel(object):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.label = None
                                                            self.pe_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.label is not None:
                                                                return True

                                                            if self.pe_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                    class SrPolicyExplicitPath(object):
                                                        """
                                                        SR Policy Explicit paths
                                                        
                                                        .. attribute:: sid
                                                        
                                                        	Sidlist for explicit path
                                                        	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of explicit path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.sid = YList()
                                                            self.sid.parent = self
                                                            self.sid.name = 'sid'
                                                            self.weight = None


                                                        class Sid(object):
                                                            """
                                                            Sidlist for explicit path
                                                            
                                                            .. attribute:: ipv4
                                                            
                                                            	IP Address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6
                                                            
                                                            	IPv6 address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label sid
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Sid Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4 = None
                                                                self.ipv6 = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4 is not None:
                                                                    return True

                                                                if self.ipv6 is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.sid is not None:
                                                                for child_ref in self.sid:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.weight is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.aggregator_address is not None:
                                                            return True

                                                        if self.aggregator_as is not None:
                                                            return True

                                                        if self.aigp_metric_value is not None:
                                                            return True

                                                        if self.as_path is not None:
                                                            return True

                                                        if self.cluster is not None:
                                                            for child_ref in self.cluster:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.community is not None:
                                                            for child_ref in self.community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.connector_type is not None:
                                                            return True

                                                        if self.connector_value is not None:
                                                            for child_ref in self.connector_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community is not None:
                                                            for child_ref in self.extended_community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community_flags is not None:
                                                            return True

                                                        if self.is_aggregator_present is not None:
                                                            return True

                                                        if self.is_aigp_present is not None:
                                                            return True

                                                        if self.is_as_path_present is not None:
                                                            return True

                                                        if self.is_atomic_aggregate_present is not None:
                                                            return True

                                                        if self.is_community_present is not None:
                                                            return True

                                                        if self.is_connector_present is not None:
                                                            return True

                                                        if self.is_extended_community_present is not None:
                                                            return True

                                                        if self.is_label_index_present is not None:
                                                            return True

                                                        if self.is_local_pref_present is not None:
                                                            return True

                                                        if self.is_ls_attribute_present is not None:
                                                            return True

                                                        if self.is_metric_present is not None:
                                                            return True

                                                        if self.is_origin_present is not None:
                                                            return True

                                                        if self.is_pe_distinguisher_label_present is not None:
                                                            return True

                                                        if self.is_pmsi_present is not None:
                                                            return True

                                                        if self.is_pppmp_present is not None:
                                                            return True

                                                        if self.is_ssa_present is not None:
                                                            return True

                                                        if self.is_tunnel_encap_present is not None:
                                                            return True

                                                        if self.l2tpv3_cookie is not None:
                                                            for child_ref in self.l2tpv3_cookie:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.l2tpv3_session_id is not None:
                                                            return True

                                                        if self.label_index_attr is not None:
                                                            for child_ref in self.label_index_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.local_preference is not None:
                                                            return True

                                                        if self.ls_attr is not None:
                                                            for child_ref in self.ls_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.metric is not None:
                                                            return True

                                                        if self.neighbor_as is not None:
                                                            return True

                                                        if self.origin is not None:
                                                            return True

                                                        if self.originator is not None:
                                                            return True

                                                        if self.pe_distinguisher_label is not None:
                                                            for child_ref in self.pe_distinguisher_label:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.pmsi_flags is not None:
                                                            return True

                                                        if self.pmsi_label is not None:
                                                            return True

                                                        if self.pmsi_type is not None:
                                                            return True

                                                        if self.pmsi_value is not None:
                                                            for child_ref in self.pmsi_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.ppm_pvalue is not None:
                                                            return True

                                                        if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_explicit_path is not None:
                                                            for child_ref in self.sr_policy_explicit_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.sr_policy_preference is not None:
                                                            return True

                                                        if self.sr_tunnel_request_state is not None:
                                                            return True

                                                        if self.sr_tunnel_state is not None:
                                                            return True

                                                        if self.tunnel_encap_type is not None:
                                                            return True

                                                        if self.unknown_attribute is not None:
                                                            for child_ref in self.unknown_attribute:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                                class AttrSet(object):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_encap_present
                                                    
                                                    	Tunnel Encap attribute present 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_policy_allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_binding_sid
                                                    
                                                    	SR Policy Binding sid
                                                    	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_explicit_path
                                                    
                                                    	SR Policy Explicit paths
                                                    	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                    
                                                    .. attribute:: sr_policy_preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_tunnel_request_state
                                                    
                                                    	SR Tunnel Request State
                                                    	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                    
                                                    .. attribute:: sr_tunnel_state
                                                    
                                                    	SR Tunnel State
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encap Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.aggregator_address = None
                                                        self.aggregator_as = None
                                                        self.aigp_metric_value = None
                                                        self.as_path = None
                                                        self.cluster = YList()
                                                        self.cluster.parent = self
                                                        self.cluster.name = 'cluster'
                                                        self.community = YList()
                                                        self.community.parent = self
                                                        self.community.name = 'community'
                                                        self.connector_type = None
                                                        self.connector_value = YList()
                                                        self.connector_value.parent = self
                                                        self.connector_value.name = 'connector_value'
                                                        self.extended_community = YList()
                                                        self.extended_community.parent = self
                                                        self.extended_community.name = 'extended_community'
                                                        self.extended_community_flags = None
                                                        self.is_aggregator_present = None
                                                        self.is_aigp_present = None
                                                        self.is_as_path_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_community_present = None
                                                        self.is_connector_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_label_index_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_metric_present = None
                                                        self.is_origin_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_ssa_present = None
                                                        self.is_tunnel_encap_present = None
                                                        self.l2tpv3_cookie = YList()
                                                        self.l2tpv3_cookie.parent = self
                                                        self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                        self.l2tpv3_session_id = None
                                                        self.label_index_attr = YList()
                                                        self.label_index_attr.parent = self
                                                        self.label_index_attr.name = 'label_index_attr'
                                                        self.local_preference = None
                                                        self.ls_attr = YList()
                                                        self.ls_attr.parent = self
                                                        self.ls_attr.name = 'ls_attr'
                                                        self.metric = None
                                                        self.neighbor_as = None
                                                        self.origin = None
                                                        self.originator = None
                                                        self.pe_distinguisher_label = YList()
                                                        self.pe_distinguisher_label.parent = self
                                                        self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.pmsi_type = None
                                                        self.pmsi_value = YList()
                                                        self.pmsi_value.parent = self
                                                        self.pmsi_value.name = 'pmsi_value'
                                                        self.ppm_pvalue = None
                                                        self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                        self.sr_policy_allocated_binding_sid.parent = self
                                                        self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                        self.sr_policy_binding_sid.parent = self
                                                        self.sr_policy_explicit_path = YList()
                                                        self.sr_policy_explicit_path.parent = self
                                                        self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                        self.sr_policy_preference = None
                                                        self.sr_tunnel_request_state = None
                                                        self.sr_tunnel_state = None
                                                        self.tunnel_encap_type = None
                                                        self.unknown_attribute = YList()
                                                        self.unknown_attribute.parent = self
                                                        self.unknown_attribute.name = 'unknown_attribute'


                                                    class SrPolicyBindingSid(object):
                                                        """
                                                        SR Policy Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                    class SrPolicyAllocatedBindingSid(object):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                    class Community(object):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                    class ExtendedCommunity(object):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                    class UnknownAttribute(object):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                    class Cluster(object):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                    class L2Tpv3Cookie(object):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                    class ConnectorValue(object):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                    class PmsiValue(object):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                    class LsAttr(object):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                    class LabelIndexAttr(object):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                    class PeDistinguisherLabel(object):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.label = None
                                                            self.pe_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.label is not None:
                                                                return True

                                                            if self.pe_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                    class SrPolicyExplicitPath(object):
                                                        """
                                                        SR Policy Explicit paths
                                                        
                                                        .. attribute:: sid
                                                        
                                                        	Sidlist for explicit path
                                                        	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of explicit path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.sid = YList()
                                                            self.sid.parent = self
                                                            self.sid.name = 'sid'
                                                            self.weight = None


                                                        class Sid(object):
                                                            """
                                                            Sidlist for explicit path
                                                            
                                                            .. attribute:: ipv4
                                                            
                                                            	IP Address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6
                                                            
                                                            	IPv6 address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label sid
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Sid Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4 = None
                                                                self.ipv6 = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4 is not None:
                                                                    return True

                                                                if self.ipv6 is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.sid is not None:
                                                                for child_ref in self.sid:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.weight is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.aggregator_address is not None:
                                                            return True

                                                        if self.aggregator_as is not None:
                                                            return True

                                                        if self.aigp_metric_value is not None:
                                                            return True

                                                        if self.as_path is not None:
                                                            return True

                                                        if self.cluster is not None:
                                                            for child_ref in self.cluster:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.community is not None:
                                                            for child_ref in self.community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.connector_type is not None:
                                                            return True

                                                        if self.connector_value is not None:
                                                            for child_ref in self.connector_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community is not None:
                                                            for child_ref in self.extended_community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community_flags is not None:
                                                            return True

                                                        if self.is_aggregator_present is not None:
                                                            return True

                                                        if self.is_aigp_present is not None:
                                                            return True

                                                        if self.is_as_path_present is not None:
                                                            return True

                                                        if self.is_atomic_aggregate_present is not None:
                                                            return True

                                                        if self.is_community_present is not None:
                                                            return True

                                                        if self.is_connector_present is not None:
                                                            return True

                                                        if self.is_extended_community_present is not None:
                                                            return True

                                                        if self.is_label_index_present is not None:
                                                            return True

                                                        if self.is_local_pref_present is not None:
                                                            return True

                                                        if self.is_ls_attribute_present is not None:
                                                            return True

                                                        if self.is_metric_present is not None:
                                                            return True

                                                        if self.is_origin_present is not None:
                                                            return True

                                                        if self.is_pe_distinguisher_label_present is not None:
                                                            return True

                                                        if self.is_pmsi_present is not None:
                                                            return True

                                                        if self.is_pppmp_present is not None:
                                                            return True

                                                        if self.is_ssa_present is not None:
                                                            return True

                                                        if self.is_tunnel_encap_present is not None:
                                                            return True

                                                        if self.l2tpv3_cookie is not None:
                                                            for child_ref in self.l2tpv3_cookie:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.l2tpv3_session_id is not None:
                                                            return True

                                                        if self.label_index_attr is not None:
                                                            for child_ref in self.label_index_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.local_preference is not None:
                                                            return True

                                                        if self.ls_attr is not None:
                                                            for child_ref in self.ls_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.metric is not None:
                                                            return True

                                                        if self.neighbor_as is not None:
                                                            return True

                                                        if self.origin is not None:
                                                            return True

                                                        if self.originator is not None:
                                                            return True

                                                        if self.pe_distinguisher_label is not None:
                                                            for child_ref in self.pe_distinguisher_label:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.pmsi_flags is not None:
                                                            return True

                                                        if self.pmsi_label is not None:
                                                            return True

                                                        if self.pmsi_type is not None:
                                                            return True

                                                        if self.pmsi_value is not None:
                                                            for child_ref in self.pmsi_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.ppm_pvalue is not None:
                                                            return True

                                                        if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_explicit_path is not None:
                                                            for child_ref in self.sr_policy_explicit_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.sr_policy_preference is not None:
                                                            return True

                                                        if self.sr_tunnel_request_state is not None:
                                                            return True

                                                        if self.sr_tunnel_state is not None:
                                                            return True

                                                        if self.tunnel_encap_type is not None:
                                                            return True

                                                        if self.unknown_attribute is not None:
                                                            for child_ref in self.unknown_attribute:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                                class RnhAddr(object):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.len = None
                                                        self.mac_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.len is not None:
                                                            return True

                                                        if self.mac_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                                class RibrnhIp(object):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.attr_set is not None and self.attr_set._has_data():
                                                        return True

                                                    if self.attribute_key_number is not None:
                                                        return True

                                                    if self.attribute_reuse_id_config is not None:
                                                        return True

                                                    if self.attribute_reuse_id_current is not None:
                                                        return True

                                                    if self.attribute_reuse_id_keys is not None:
                                                        return True

                                                    if self.attribute_reuse_id_max_id is not None:
                                                        return True

                                                    if self.attribute_reuse_id_node is not None:
                                                        return True

                                                    if self.attribute_reuse_id_recover_sec is not None:
                                                        return True

                                                    if self.common_attributes is not None and self.common_attributes._has_data():
                                                        return True

                                                    if self.is_application_gateway_present is not None:
                                                        return True

                                                    if self.is_as_path2_byte is not None:
                                                        return True

                                                    if self.is_attr_set_present is not None:
                                                        return True

                                                    if self.is_ribrnh_present is not None:
                                                        return True

                                                    if self.is_rnh_present is not None:
                                                        return True

                                                    if self.ribrnh_encap is not None:
                                                        return True

                                                    if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                        return True

                                                    if self.ribrnh_mac is not None:
                                                        return True

                                                    if self.ribrnh_table is not None:
                                                        return True

                                                    if self.ribrnh_vni is not None:
                                                        return True

                                                    if self.ribrnhip_table is not None:
                                                        return True

                                                    if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                        return True

                                                    if self.rnh_addr_len is not None:
                                                        return True

                                                    if self.rnh_len is not None:
                                                        return True

                                                    if self.rnh_type is not None:
                                                        return True

                                                    if self.set_aigp_inbound_igp is not None:
                                                        return True

                                                    if self.set_aigp_inbound_metric is not None:
                                                        return True

                                                    if self.vpn_distinguisher is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-process-instance-path'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.af_name is not None:
                                                    return True

                                                if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                    return True

                                                if self.label_fail is not None:
                                                    return True

                                                if self.label_o_or_version is not None:
                                                    return True

                                                if self.label_oor is not None:
                                                    return True

                                                if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                    return True

                                                if self.no_path is not None:
                                                    return True

                                                if self.path_information is not None and self.path_information._has_data():
                                                    return True

                                                if self.prefix_version is not None:
                                                    return True

                                                if self.process_instance_id is not None:
                                                    return True

                                                if self.route_distinguisher is not None:
                                                    return True

                                                if self.source_route_distinguisher is not None:
                                                    return True

                                                if self.source_vrf_name is not None:
                                                    return True

                                                if self.srcaf_name is not None:
                                                    return True

                                                if self.vrf_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath']['meta_info']


                                        class ActiveProcessInstancePath(object):
                                            """
                                            Active's paths for this net 
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: attributes_after_policy_in
                                            
                                            	Attributes after inbound policy applied
                                            	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn>`
                                            
                                            .. attribute:: label_fail
                                            
                                            	LSD label allocation failed 
                                            	**type**\:  bool
                                            
                                            .. attribute:: label_o_or_version
                                            
                                            	Label Version when OOR happens
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_oor
                                            
                                            	LSD label space is exhausted
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address_xr
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr>`
                                            
                                            .. attribute:: no_path
                                            
                                            	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                            	**type**\:  bool
                                            
                                            .. attribute:: path_information
                                            
                                            	Path information
                                            	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation>`
                                            
                                            .. attribute:: prefix_version
                                            
                                            	Version of BGP Prefix Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: process_instance_id
                                            
                                            	Process instance ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_route_distinguisher
                                            
                                            	Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_vrf_name
                                            
                                            	Name of the source VRF
                                            	**type**\:  str
                                            
                                            .. attribute:: srcaf_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.af_name = None
                                                self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn()
                                                self.attributes_after_policy_in.parent = self
                                                self.label_fail = None
                                                self.label_o_or_version = None
                                                self.label_oor = None
                                                self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr()
                                                self.neighbor_address_xr.parent = self
                                                self.no_path = None
                                                self.path_information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation()
                                                self.path_information.parent = self
                                                self.prefix_version = None
                                                self.process_instance_id = None
                                                self.route_distinguisher = None
                                                self.source_route_distinguisher = None
                                                self.source_vrf_name = None
                                                self.srcaf_name = None
                                                self.vrf_name = None


                                            class NeighborAddressXr(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr']['meta_info']


                                            class PathInformation(object):
                                                """
                                                Path information
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\:  bool
                                                
                                                .. attribute:: accept_own_self_originated_p_ath
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\:  bool
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\:  bool
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix>`
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\:  bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\:  bool
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr>`
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_esi
                                                
                                                	Path has EVPN ESI
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_rcvd_label
                                                
                                                	Path has received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\:  bool
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebg_ps
                                                
                                                	Not advertised to EBGPs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi>`
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress>`
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop>`
                                                
                                                .. attribute:: nhte_tunnel
                                                
                                                	NH TE tunnel information
                                                	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhteTunnel>`
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\:  bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.accept_own_path = None
                                                    self.accept_own_self_originated_p_ath = None
                                                    self.add_path_orr_bitfield = YList()
                                                    self.add_path_orr_bitfield.parent = self
                                                    self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                    self.advertisedto_pe = None
                                                    self.aigp_metric = None
                                                    self.best_path_comp_stage = None
                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self.best_path_id = None
                                                    self.best_path_id_comp_winner = None
                                                    self.best_path_orr_bitfield = YList()
                                                    self.best_path_orr_bitfield.parent = self
                                                    self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self.dampen_penalty = None
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.fspec_invalid_path = None
                                                    self.graceful_shutdown = None
                                                    self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self.halflife_time = None
                                                    self.has_esi = None
                                                    self.has_gw_addr = None
                                                    self.has_local_net_label = None
                                                    self.has_mdt_group_addr = None
                                                    self.has_mvpn_extcomm = None
                                                    self.has_mvpn_nbr_addr = None
                                                    self.has_mvpn_nexthop_addr = None
                                                    self.has_mvpn_pmsi = None
                                                    self.has_rcvd_label = None
                                                    self.has_second_label = None
                                                    self.ibgp_signaled_validity = None
                                                    self.igp_metric = None
                                                    self.is_aggregation_suppressed = None
                                                    self.is_as_best = None
                                                    self.is_best_path = None
                                                    self.is_import_dampened = None
                                                    self.is_import_suspect = None
                                                    self.is_internal_path = None
                                                    self.is_partial_best = None
                                                    self.is_path_additional_path = None
                                                    self.is_path_advertised_local_as_only = None
                                                    self.is_path_af_install_eligible = None
                                                    self.is_path_backup = None
                                                    self.is_path_backup_protect_multipath = None
                                                    self.is_path_best_external = None
                                                    self.is_path_damped = None
                                                    self.is_path_from_confederation_peer = None
                                                    self.is_path_from_network_command = None
                                                    self.is_path_from_redistribute_command = None
                                                    self.is_path_from_route_reflector = None
                                                    self.is_path_history_held = None
                                                    self.is_path_imp_candidate = None
                                                    self.is_path_imported = None
                                                    self.is_path_local_aggregate = None
                                                    self.is_path_locally_sourced = None
                                                    self.is_path_long_lived_stale = None
                                                    self.is_path_multipath = None
                                                    self.is_path_nexthop_discarded = None
                                                    self.is_path_not_advertised = None
                                                    self.is_path_not_advertised_to_ebg_ps = None
                                                    self.is_path_received_only = None
                                                    self.is_path_reoriginated = None
                                                    self.is_path_reoriginated_stitching = None
                                                    self.is_path_stale = None
                                                    self.is_path_synced_with_igp = None
                                                    self.is_path_valid = None
                                                    self.is_path_vpn_only = None
                                                    self.is_permanent_path = None
                                                    self.is_received_path_not_modified = None
                                                    self.is_spkr_as_best = None
                                                    self.l2vpn_circuit_status_value = YList()
                                                    self.l2vpn_circuit_status_value.parent = self
                                                    self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                    self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi()
                                                    self.l2vpn_evpn_esi.parent = self
                                                    self.l2vpn_size = None
                                                    self.labeled_unicast_safi_path = None
                                                    self.local_label = None
                                                    self.local_nh = None
                                                    self.local_path_id = None
                                                    self.local_peers_advertised_to = YList()
                                                    self.local_peers_advertised_to.parent = self
                                                    self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                    self.maximum_suppress_time = None
                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self.mvpn_path_flags = None
                                                    self.mvpn_pmsi_flags = None
                                                    self.mvpn_pmsi_label = None
                                                    self.mvpn_pmsi_type = None
                                                    self.mvpn_pmsi_value = YList()
                                                    self.mvpn_pmsi_value.parent = self
                                                    self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                    self.mvpn_sfs_path = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.neighbor_router_id = None
                                                    self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop()
                                                    self.next_hop.parent = self
                                                    self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhteTunnel()
                                                    self.nhte_tunnel.parent = self
                                                    self.path_flags = None
                                                    self.path_flap_count = None
                                                    self.path_import_flags = None
                                                    self.path_rt_set_id = None
                                                    self.path_rt_set_route_count = None
                                                    self.path_table_version = None
                                                    self.path_weight = None
                                                    self.pe_peers_advertised_to = YList()
                                                    self.pe_peers_advertised_to.parent = self
                                                    self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                    self.rcvd_label = None
                                                    self.rcvd_path_id = None
                                                    self.reuse_value = None
                                                    self.rib_failed = None
                                                    self.route_type = None
                                                    self.rpki_origin_as_validation_disabled = None
                                                    self.rt_set_limit_enabled = None
                                                    self.second_label = None
                                                    self.seconds_since_first_flap = None
                                                    self.show_rpki_origin_as_validity = None
                                                    self.sn_rpki_origin_as_validity = None
                                                    self.suppress_penalty = None
                                                    self.time_to_unsuppress = None


                                                class BgpPrefix(object):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self.prefix_length = None


                                                    class Prefix(object):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.prefix is not None and self.prefix._has_data():
                                                            return True

                                                        if self.prefix_length is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix']['meta_info']


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress']['meta_info']


                                                class NextHop(object):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop']['meta_info']


                                                class NhteTunnel(object):
                                                    """
                                                    NH TE tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_te_tunnel
                                                    
                                                    	NH TE Tunnel info is present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last rib update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	tunnel name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	tunnel type
                                                    	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.binding_label = None
                                                        self.has_te_tunnel = None
                                                        self.is_tunnel_info_stale = None
                                                        self.is_tunnel_registered = None
                                                        self.is_tunnel_up = None
                                                        self.last_tunnel_update = None
                                                        self.tunnel_if_handle = None
                                                        self.tunnel_name = None
                                                        self.tunnel_type = None
                                                        self.tunnel_v6_enabled = None
                                                        self.tunnel_v6_required = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.binding_label is not None:
                                                            return True

                                                        if self.has_te_tunnel is not None:
                                                            return True

                                                        if self.is_tunnel_info_stale is not None:
                                                            return True

                                                        if self.is_tunnel_registered is not None:
                                                            return True

                                                        if self.is_tunnel_up is not None:
                                                            return True

                                                        if self.last_tunnel_update is not None:
                                                            return True

                                                        if self.tunnel_if_handle is not None:
                                                            return True

                                                        if self.tunnel_name is not None:
                                                            return True

                                                        if self.tunnel_type is not None:
                                                            return True

                                                        if self.tunnel_v6_enabled is not None:
                                                            return True

                                                        if self.tunnel_v6_required is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhteTunnel']['meta_info']


                                                class MdtGroupAddr(object):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr']['meta_info']


                                                class L2VpnEvpnEsi(object):
                                                    """
                                                    L2VPN EVPN ESI
                                                    
                                                    .. attribute:: esi
                                                    
                                                    	esi
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.esi = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.esi is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi']['meta_info']


                                                class GwAddr(object):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.len = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.len is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr']['meta_info']


                                                class BestPathCompWinner(object):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner']['meta_info']


                                                class MvpnNbrAddr(object):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr']['meta_info']


                                                class MvpnNexthopAddr(object):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr']['meta_info']


                                                class L2VpnCircuitStatusValue(object):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                                class MvpnPmsiValue(object):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity']['meta_info']


                                                class LocalPeersAdvertisedTo(object):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                                class PePeersAdvertisedTo(object):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo']['meta_info']


                                                class BestPathOrrBitfield(object):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield']['meta_info']


                                                class AddPathOrrBitfield(object):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.accept_own_path is not None:
                                                        return True

                                                    if self.accept_own_self_originated_p_ath is not None:
                                                        return True

                                                    if self.add_path_orr_bitfield is not None:
                                                        for child_ref in self.add_path_orr_bitfield:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.advertisedto_pe is not None:
                                                        return True

                                                    if self.aigp_metric is not None:
                                                        return True

                                                    if self.best_path_comp_stage is not None:
                                                        return True

                                                    if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                        return True

                                                    if self.best_path_id is not None:
                                                        return True

                                                    if self.best_path_id_comp_winner is not None:
                                                        return True

                                                    if self.best_path_orr_bitfield is not None:
                                                        for child_ref in self.best_path_orr_bitfield:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                        return True

                                                    if self.dampen_penalty is not None:
                                                        return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.fspec_invalid_path is not None:
                                                        return True

                                                    if self.graceful_shutdown is not None:
                                                        return True

                                                    if self.gw_addr is not None and self.gw_addr._has_data():
                                                        return True

                                                    if self.halflife_time is not None:
                                                        return True

                                                    if self.has_esi is not None:
                                                        return True

                                                    if self.has_gw_addr is not None:
                                                        return True

                                                    if self.has_local_net_label is not None:
                                                        return True

                                                    if self.has_mdt_group_addr is not None:
                                                        return True

                                                    if self.has_mvpn_extcomm is not None:
                                                        return True

                                                    if self.has_mvpn_nbr_addr is not None:
                                                        return True

                                                    if self.has_mvpn_nexthop_addr is not None:
                                                        return True

                                                    if self.has_mvpn_pmsi is not None:
                                                        return True

                                                    if self.has_rcvd_label is not None:
                                                        return True

                                                    if self.has_second_label is not None:
                                                        return True

                                                    if self.ibgp_signaled_validity is not None:
                                                        return True

                                                    if self.igp_metric is not None:
                                                        return True

                                                    if self.is_aggregation_suppressed is not None:
                                                        return True

                                                    if self.is_as_best is not None:
                                                        return True

                                                    if self.is_best_path is not None:
                                                        return True

                                                    if self.is_import_dampened is not None:
                                                        return True

                                                    if self.is_import_suspect is not None:
                                                        return True

                                                    if self.is_internal_path is not None:
                                                        return True

                                                    if self.is_partial_best is not None:
                                                        return True

                                                    if self.is_path_additional_path is not None:
                                                        return True

                                                    if self.is_path_advertised_local_as_only is not None:
                                                        return True

                                                    if self.is_path_af_install_eligible is not None:
                                                        return True

                                                    if self.is_path_backup is not None:
                                                        return True

                                                    if self.is_path_backup_protect_multipath is not None:
                                                        return True

                                                    if self.is_path_best_external is not None:
                                                        return True

                                                    if self.is_path_damped is not None:
                                                        return True

                                                    if self.is_path_from_confederation_peer is not None:
                                                        return True

                                                    if self.is_path_from_network_command is not None:
                                                        return True

                                                    if self.is_path_from_redistribute_command is not None:
                                                        return True

                                                    if self.is_path_from_route_reflector is not None:
                                                        return True

                                                    if self.is_path_history_held is not None:
                                                        return True

                                                    if self.is_path_imp_candidate is not None:
                                                        return True

                                                    if self.is_path_imported is not None:
                                                        return True

                                                    if self.is_path_local_aggregate is not None:
                                                        return True

                                                    if self.is_path_locally_sourced is not None:
                                                        return True

                                                    if self.is_path_long_lived_stale is not None:
                                                        return True

                                                    if self.is_path_multipath is not None:
                                                        return True

                                                    if self.is_path_nexthop_discarded is not None:
                                                        return True

                                                    if self.is_path_not_advertised is not None:
                                                        return True

                                                    if self.is_path_not_advertised_to_ebg_ps is not None:
                                                        return True

                                                    if self.is_path_received_only is not None:
                                                        return True

                                                    if self.is_path_reoriginated is not None:
                                                        return True

                                                    if self.is_path_reoriginated_stitching is not None:
                                                        return True

                                                    if self.is_path_stale is not None:
                                                        return True

                                                    if self.is_path_synced_with_igp is not None:
                                                        return True

                                                    if self.is_path_valid is not None:
                                                        return True

                                                    if self.is_path_vpn_only is not None:
                                                        return True

                                                    if self.is_permanent_path is not None:
                                                        return True

                                                    if self.is_received_path_not_modified is not None:
                                                        return True

                                                    if self.is_spkr_as_best is not None:
                                                        return True

                                                    if self.l2vpn_circuit_status_value is not None:
                                                        for child_ref in self.l2vpn_circuit_status_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                        return True

                                                    if self.l2vpn_size is not None:
                                                        return True

                                                    if self.labeled_unicast_safi_path is not None:
                                                        return True

                                                    if self.local_label is not None:
                                                        return True

                                                    if self.local_nh is not None:
                                                        return True

                                                    if self.local_path_id is not None:
                                                        return True

                                                    if self.local_peers_advertised_to is not None:
                                                        for child_ref in self.local_peers_advertised_to:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.maximum_suppress_time is not None:
                                                        return True

                                                    if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                        return True

                                                    if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                        return True

                                                    if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                        return True

                                                    if self.mvpn_path_flags is not None:
                                                        return True

                                                    if self.mvpn_pmsi_flags is not None:
                                                        return True

                                                    if self.mvpn_pmsi_label is not None:
                                                        return True

                                                    if self.mvpn_pmsi_type is not None:
                                                        return True

                                                    if self.mvpn_pmsi_value is not None:
                                                        for child_ref in self.mvpn_pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.mvpn_sfs_path is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.neighbor_router_id is not None:
                                                        return True

                                                    if self.next_hop is not None and self.next_hop._has_data():
                                                        return True

                                                    if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                        return True

                                                    if self.path_flags is not None:
                                                        return True

                                                    if self.path_flap_count is not None:
                                                        return True

                                                    if self.path_import_flags is not None:
                                                        return True

                                                    if self.path_rt_set_id is not None:
                                                        return True

                                                    if self.path_rt_set_route_count is not None:
                                                        return True

                                                    if self.path_table_version is not None:
                                                        return True

                                                    if self.path_weight is not None:
                                                        return True

                                                    if self.pe_peers_advertised_to is not None:
                                                        for child_ref in self.pe_peers_advertised_to:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.rcvd_label is not None:
                                                        return True

                                                    if self.rcvd_path_id is not None:
                                                        return True

                                                    if self.reuse_value is not None:
                                                        return True

                                                    if self.rib_failed is not None:
                                                        return True

                                                    if self.route_type is not None:
                                                        return True

                                                    if self.rpki_origin_as_validation_disabled is not None:
                                                        return True

                                                    if self.rt_set_limit_enabled is not None:
                                                        return True

                                                    if self.second_label is not None:
                                                        return True

                                                    if self.seconds_since_first_flap is not None:
                                                        return True

                                                    if self.show_rpki_origin_as_validity is not None:
                                                        return True

                                                    if self.sn_rpki_origin_as_validity is not None:
                                                        return True

                                                    if self.suppress_penalty is not None:
                                                        return True

                                                    if self.time_to_unsuppress is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation']['meta_info']


                                            class AttributesAfterPolicyIn(object):
                                                """
                                                Attributes after inbound policy applied
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\:  bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\:  bool
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                    self.attr_set.parent = self
                                                    self.attribute_key_number = None
                                                    self.attribute_reuse_id_config = None
                                                    self.attribute_reuse_id_current = None
                                                    self.attribute_reuse_id_keys = None
                                                    self.attribute_reuse_id_max_id = None
                                                    self.attribute_reuse_id_node = None
                                                    self.attribute_reuse_id_recover_sec = None
                                                    self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self.is_application_gateway_present = None
                                                    self.is_as_path2_byte = None
                                                    self.is_attr_set_present = None
                                                    self.is_ribrnh_present = None
                                                    self.is_rnh_present = None
                                                    self.ribrnh_encap = None
                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self.ribrnh_mac = None
                                                    self.ribrnh_table = None
                                                    self.ribrnh_vni = None
                                                    self.ribrnhip_table = None
                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self.rnh_addr_len = None
                                                    self.rnh_len = None
                                                    self.rnh_type = None
                                                    self.set_aigp_inbound_igp = None
                                                    self.set_aigp_inbound_metric = None
                                                    self.vpn_distinguisher = None


                                                class CommonAttributes(object):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_encap_present
                                                    
                                                    	Tunnel Encap attribute present 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_policy_allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_binding_sid
                                                    
                                                    	SR Policy Binding sid
                                                    	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_explicit_path
                                                    
                                                    	SR Policy Explicit paths
                                                    	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                    
                                                    .. attribute:: sr_policy_preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_tunnel_request_state
                                                    
                                                    	SR Tunnel Request State
                                                    	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                    
                                                    .. attribute:: sr_tunnel_state
                                                    
                                                    	SR Tunnel State
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encap Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.aggregator_address = None
                                                        self.aggregator_as = None
                                                        self.aigp_metric_value = None
                                                        self.as_path = None
                                                        self.cluster = YList()
                                                        self.cluster.parent = self
                                                        self.cluster.name = 'cluster'
                                                        self.community = YList()
                                                        self.community.parent = self
                                                        self.community.name = 'community'
                                                        self.connector_type = None
                                                        self.connector_value = YList()
                                                        self.connector_value.parent = self
                                                        self.connector_value.name = 'connector_value'
                                                        self.extended_community = YList()
                                                        self.extended_community.parent = self
                                                        self.extended_community.name = 'extended_community'
                                                        self.extended_community_flags = None
                                                        self.is_aggregator_present = None
                                                        self.is_aigp_present = None
                                                        self.is_as_path_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_community_present = None
                                                        self.is_connector_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_label_index_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_metric_present = None
                                                        self.is_origin_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_ssa_present = None
                                                        self.is_tunnel_encap_present = None
                                                        self.l2tpv3_cookie = YList()
                                                        self.l2tpv3_cookie.parent = self
                                                        self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                        self.l2tpv3_session_id = None
                                                        self.label_index_attr = YList()
                                                        self.label_index_attr.parent = self
                                                        self.label_index_attr.name = 'label_index_attr'
                                                        self.local_preference = None
                                                        self.ls_attr = YList()
                                                        self.ls_attr.parent = self
                                                        self.ls_attr.name = 'ls_attr'
                                                        self.metric = None
                                                        self.neighbor_as = None
                                                        self.origin = None
                                                        self.originator = None
                                                        self.pe_distinguisher_label = YList()
                                                        self.pe_distinguisher_label.parent = self
                                                        self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.pmsi_type = None
                                                        self.pmsi_value = YList()
                                                        self.pmsi_value.parent = self
                                                        self.pmsi_value.name = 'pmsi_value'
                                                        self.ppm_pvalue = None
                                                        self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                        self.sr_policy_allocated_binding_sid.parent = self
                                                        self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                        self.sr_policy_binding_sid.parent = self
                                                        self.sr_policy_explicit_path = YList()
                                                        self.sr_policy_explicit_path.parent = self
                                                        self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                        self.sr_policy_preference = None
                                                        self.sr_tunnel_request_state = None
                                                        self.sr_tunnel_state = None
                                                        self.tunnel_encap_type = None
                                                        self.unknown_attribute = YList()
                                                        self.unknown_attribute.parent = self
                                                        self.unknown_attribute.name = 'unknown_attribute'


                                                    class SrPolicyBindingSid(object):
                                                        """
                                                        SR Policy Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                    class SrPolicyAllocatedBindingSid(object):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                    class Community(object):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                    class ExtendedCommunity(object):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                    class UnknownAttribute(object):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                    class Cluster(object):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                    class L2Tpv3Cookie(object):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                    class ConnectorValue(object):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                    class PmsiValue(object):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                    class LsAttr(object):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                    class LabelIndexAttr(object):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                    class PeDistinguisherLabel(object):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.label = None
                                                            self.pe_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.label is not None:
                                                                return True

                                                            if self.pe_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                    class SrPolicyExplicitPath(object):
                                                        """
                                                        SR Policy Explicit paths
                                                        
                                                        .. attribute:: sid
                                                        
                                                        	Sidlist for explicit path
                                                        	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of explicit path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.sid = YList()
                                                            self.sid.parent = self
                                                            self.sid.name = 'sid'
                                                            self.weight = None


                                                        class Sid(object):
                                                            """
                                                            Sidlist for explicit path
                                                            
                                                            .. attribute:: ipv4
                                                            
                                                            	IP Address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6
                                                            
                                                            	IPv6 address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label sid
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Sid Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4 = None
                                                                self.ipv6 = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4 is not None:
                                                                    return True

                                                                if self.ipv6 is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.sid is not None:
                                                                for child_ref in self.sid:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.weight is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.aggregator_address is not None:
                                                            return True

                                                        if self.aggregator_as is not None:
                                                            return True

                                                        if self.aigp_metric_value is not None:
                                                            return True

                                                        if self.as_path is not None:
                                                            return True

                                                        if self.cluster is not None:
                                                            for child_ref in self.cluster:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.community is not None:
                                                            for child_ref in self.community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.connector_type is not None:
                                                            return True

                                                        if self.connector_value is not None:
                                                            for child_ref in self.connector_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community is not None:
                                                            for child_ref in self.extended_community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community_flags is not None:
                                                            return True

                                                        if self.is_aggregator_present is not None:
                                                            return True

                                                        if self.is_aigp_present is not None:
                                                            return True

                                                        if self.is_as_path_present is not None:
                                                            return True

                                                        if self.is_atomic_aggregate_present is not None:
                                                            return True

                                                        if self.is_community_present is not None:
                                                            return True

                                                        if self.is_connector_present is not None:
                                                            return True

                                                        if self.is_extended_community_present is not None:
                                                            return True

                                                        if self.is_label_index_present is not None:
                                                            return True

                                                        if self.is_local_pref_present is not None:
                                                            return True

                                                        if self.is_ls_attribute_present is not None:
                                                            return True

                                                        if self.is_metric_present is not None:
                                                            return True

                                                        if self.is_origin_present is not None:
                                                            return True

                                                        if self.is_pe_distinguisher_label_present is not None:
                                                            return True

                                                        if self.is_pmsi_present is not None:
                                                            return True

                                                        if self.is_pppmp_present is not None:
                                                            return True

                                                        if self.is_ssa_present is not None:
                                                            return True

                                                        if self.is_tunnel_encap_present is not None:
                                                            return True

                                                        if self.l2tpv3_cookie is not None:
                                                            for child_ref in self.l2tpv3_cookie:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.l2tpv3_session_id is not None:
                                                            return True

                                                        if self.label_index_attr is not None:
                                                            for child_ref in self.label_index_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.local_preference is not None:
                                                            return True

                                                        if self.ls_attr is not None:
                                                            for child_ref in self.ls_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.metric is not None:
                                                            return True

                                                        if self.neighbor_as is not None:
                                                            return True

                                                        if self.origin is not None:
                                                            return True

                                                        if self.originator is not None:
                                                            return True

                                                        if self.pe_distinguisher_label is not None:
                                                            for child_ref in self.pe_distinguisher_label:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.pmsi_flags is not None:
                                                            return True

                                                        if self.pmsi_label is not None:
                                                            return True

                                                        if self.pmsi_type is not None:
                                                            return True

                                                        if self.pmsi_value is not None:
                                                            for child_ref in self.pmsi_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.ppm_pvalue is not None:
                                                            return True

                                                        if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_explicit_path is not None:
                                                            for child_ref in self.sr_policy_explicit_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.sr_policy_preference is not None:
                                                            return True

                                                        if self.sr_tunnel_request_state is not None:
                                                            return True

                                                        if self.sr_tunnel_state is not None:
                                                            return True

                                                        if self.tunnel_encap_type is not None:
                                                            return True

                                                        if self.unknown_attribute is not None:
                                                            for child_ref in self.unknown_attribute:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                                class AttrSet(object):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_encap_present
                                                    
                                                    	Tunnel Encap attribute present 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_policy_allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_binding_sid
                                                    
                                                    	SR Policy Binding sid
                                                    	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_explicit_path
                                                    
                                                    	SR Policy Explicit paths
                                                    	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                    
                                                    .. attribute:: sr_policy_preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_tunnel_request_state
                                                    
                                                    	SR Tunnel Request State
                                                    	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                    
                                                    .. attribute:: sr_tunnel_state
                                                    
                                                    	SR Tunnel State
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encap Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.aggregator_address = None
                                                        self.aggregator_as = None
                                                        self.aigp_metric_value = None
                                                        self.as_path = None
                                                        self.cluster = YList()
                                                        self.cluster.parent = self
                                                        self.cluster.name = 'cluster'
                                                        self.community = YList()
                                                        self.community.parent = self
                                                        self.community.name = 'community'
                                                        self.connector_type = None
                                                        self.connector_value = YList()
                                                        self.connector_value.parent = self
                                                        self.connector_value.name = 'connector_value'
                                                        self.extended_community = YList()
                                                        self.extended_community.parent = self
                                                        self.extended_community.name = 'extended_community'
                                                        self.extended_community_flags = None
                                                        self.is_aggregator_present = None
                                                        self.is_aigp_present = None
                                                        self.is_as_path_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_community_present = None
                                                        self.is_connector_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_label_index_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_metric_present = None
                                                        self.is_origin_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_ssa_present = None
                                                        self.is_tunnel_encap_present = None
                                                        self.l2tpv3_cookie = YList()
                                                        self.l2tpv3_cookie.parent = self
                                                        self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                        self.l2tpv3_session_id = None
                                                        self.label_index_attr = YList()
                                                        self.label_index_attr.parent = self
                                                        self.label_index_attr.name = 'label_index_attr'
                                                        self.local_preference = None
                                                        self.ls_attr = YList()
                                                        self.ls_attr.parent = self
                                                        self.ls_attr.name = 'ls_attr'
                                                        self.metric = None
                                                        self.neighbor_as = None
                                                        self.origin = None
                                                        self.originator = None
                                                        self.pe_distinguisher_label = YList()
                                                        self.pe_distinguisher_label.parent = self
                                                        self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.pmsi_type = None
                                                        self.pmsi_value = YList()
                                                        self.pmsi_value.parent = self
                                                        self.pmsi_value.name = 'pmsi_value'
                                                        self.ppm_pvalue = None
                                                        self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                        self.sr_policy_allocated_binding_sid.parent = self
                                                        self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                        self.sr_policy_binding_sid.parent = self
                                                        self.sr_policy_explicit_path = YList()
                                                        self.sr_policy_explicit_path.parent = self
                                                        self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                        self.sr_policy_preference = None
                                                        self.sr_tunnel_request_state = None
                                                        self.sr_tunnel_state = None
                                                        self.tunnel_encap_type = None
                                                        self.unknown_attribute = YList()
                                                        self.unknown_attribute.parent = self
                                                        self.unknown_attribute.name = 'unknown_attribute'


                                                    class SrPolicyBindingSid(object):
                                                        """
                                                        SR Policy Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                    class SrPolicyAllocatedBindingSid(object):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                    class Community(object):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                    class ExtendedCommunity(object):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                    class UnknownAttribute(object):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                    class Cluster(object):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                    class L2Tpv3Cookie(object):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                    class ConnectorValue(object):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                    class PmsiValue(object):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                    class LsAttr(object):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                    class LabelIndexAttr(object):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                    class PeDistinguisherLabel(object):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.label = None
                                                            self.pe_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.label is not None:
                                                                return True

                                                            if self.pe_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                    class SrPolicyExplicitPath(object):
                                                        """
                                                        SR Policy Explicit paths
                                                        
                                                        .. attribute:: sid
                                                        
                                                        	Sidlist for explicit path
                                                        	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of explicit path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.sid = YList()
                                                            self.sid.parent = self
                                                            self.sid.name = 'sid'
                                                            self.weight = None


                                                        class Sid(object):
                                                            """
                                                            Sidlist for explicit path
                                                            
                                                            .. attribute:: ipv4
                                                            
                                                            	IP Address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6
                                                            
                                                            	IPv6 address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label sid
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Sid Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4 = None
                                                                self.ipv6 = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4 is not None:
                                                                    return True

                                                                if self.ipv6 is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.sid is not None:
                                                                for child_ref in self.sid:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.weight is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.aggregator_address is not None:
                                                            return True

                                                        if self.aggregator_as is not None:
                                                            return True

                                                        if self.aigp_metric_value is not None:
                                                            return True

                                                        if self.as_path is not None:
                                                            return True

                                                        if self.cluster is not None:
                                                            for child_ref in self.cluster:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.community is not None:
                                                            for child_ref in self.community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.connector_type is not None:
                                                            return True

                                                        if self.connector_value is not None:
                                                            for child_ref in self.connector_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community is not None:
                                                            for child_ref in self.extended_community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community_flags is not None:
                                                            return True

                                                        if self.is_aggregator_present is not None:
                                                            return True

                                                        if self.is_aigp_present is not None:
                                                            return True

                                                        if self.is_as_path_present is not None:
                                                            return True

                                                        if self.is_atomic_aggregate_present is not None:
                                                            return True

                                                        if self.is_community_present is not None:
                                                            return True

                                                        if self.is_connector_present is not None:
                                                            return True

                                                        if self.is_extended_community_present is not None:
                                                            return True

                                                        if self.is_label_index_present is not None:
                                                            return True

                                                        if self.is_local_pref_present is not None:
                                                            return True

                                                        if self.is_ls_attribute_present is not None:
                                                            return True

                                                        if self.is_metric_present is not None:
                                                            return True

                                                        if self.is_origin_present is not None:
                                                            return True

                                                        if self.is_pe_distinguisher_label_present is not None:
                                                            return True

                                                        if self.is_pmsi_present is not None:
                                                            return True

                                                        if self.is_pppmp_present is not None:
                                                            return True

                                                        if self.is_ssa_present is not None:
                                                            return True

                                                        if self.is_tunnel_encap_present is not None:
                                                            return True

                                                        if self.l2tpv3_cookie is not None:
                                                            for child_ref in self.l2tpv3_cookie:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.l2tpv3_session_id is not None:
                                                            return True

                                                        if self.label_index_attr is not None:
                                                            for child_ref in self.label_index_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.local_preference is not None:
                                                            return True

                                                        if self.ls_attr is not None:
                                                            for child_ref in self.ls_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.metric is not None:
                                                            return True

                                                        if self.neighbor_as is not None:
                                                            return True

                                                        if self.origin is not None:
                                                            return True

                                                        if self.originator is not None:
                                                            return True

                                                        if self.pe_distinguisher_label is not None:
                                                            for child_ref in self.pe_distinguisher_label:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.pmsi_flags is not None:
                                                            return True

                                                        if self.pmsi_label is not None:
                                                            return True

                                                        if self.pmsi_type is not None:
                                                            return True

                                                        if self.pmsi_value is not None:
                                                            for child_ref in self.pmsi_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.ppm_pvalue is not None:
                                                            return True

                                                        if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_explicit_path is not None:
                                                            for child_ref in self.sr_policy_explicit_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.sr_policy_preference is not None:
                                                            return True

                                                        if self.sr_tunnel_request_state is not None:
                                                            return True

                                                        if self.sr_tunnel_state is not None:
                                                            return True

                                                        if self.tunnel_encap_type is not None:
                                                            return True

                                                        if self.unknown_attribute is not None:
                                                            for child_ref in self.unknown_attribute:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                                class RnhAddr(object):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.len = None
                                                        self.mac_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.len is not None:
                                                            return True

                                                        if self.mac_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                                class RibrnhIp(object):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.attr_set is not None and self.attr_set._has_data():
                                                        return True

                                                    if self.attribute_key_number is not None:
                                                        return True

                                                    if self.attribute_reuse_id_config is not None:
                                                        return True

                                                    if self.attribute_reuse_id_current is not None:
                                                        return True

                                                    if self.attribute_reuse_id_keys is not None:
                                                        return True

                                                    if self.attribute_reuse_id_max_id is not None:
                                                        return True

                                                    if self.attribute_reuse_id_node is not None:
                                                        return True

                                                    if self.attribute_reuse_id_recover_sec is not None:
                                                        return True

                                                    if self.common_attributes is not None and self.common_attributes._has_data():
                                                        return True

                                                    if self.is_application_gateway_present is not None:
                                                        return True

                                                    if self.is_as_path2_byte is not None:
                                                        return True

                                                    if self.is_attr_set_present is not None:
                                                        return True

                                                    if self.is_ribrnh_present is not None:
                                                        return True

                                                    if self.is_rnh_present is not None:
                                                        return True

                                                    if self.ribrnh_encap is not None:
                                                        return True

                                                    if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                        return True

                                                    if self.ribrnh_mac is not None:
                                                        return True

                                                    if self.ribrnh_table is not None:
                                                        return True

                                                    if self.ribrnh_vni is not None:
                                                        return True

                                                    if self.ribrnhip_table is not None:
                                                        return True

                                                    if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                        return True

                                                    if self.rnh_addr_len is not None:
                                                        return True

                                                    if self.rnh_len is not None:
                                                        return True

                                                    if self.rnh_type is not None:
                                                        return True

                                                    if self.set_aigp_inbound_igp is not None:
                                                        return True

                                                    if self.set_aigp_inbound_metric is not None:
                                                        return True

                                                    if self.vpn_distinguisher is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-process-instance-path'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.af_name is not None:
                                                    return True

                                                if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                    return True

                                                if self.label_fail is not None:
                                                    return True

                                                if self.label_o_or_version is not None:
                                                    return True

                                                if self.label_oor is not None:
                                                    return True

                                                if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                    return True

                                                if self.no_path is not None:
                                                    return True

                                                if self.path_information is not None and self.path_information._has_data():
                                                    return True

                                                if self.prefix_version is not None:
                                                    return True

                                                if self.process_instance_id is not None:
                                                    return True

                                                if self.route_distinguisher is not None:
                                                    return True

                                                if self.source_route_distinguisher is not None:
                                                    return True

                                                if self.source_vrf_name is not None:
                                                    return True

                                                if self.srcaf_name is not None:
                                                    return True

                                                if self.vrf_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath']['meta_info']


                                        class LocalPathElement(object):
                                            """
                                            Local path element list
                                            
                                            .. attribute:: is_perm_path_pelem
                                            
                                            	Pelem for permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.NhteTunnel>`
                                            
                                            .. attribute:: pelem_flags
                                            
                                            	Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_gw_metric
                                            
                                            	Gateway metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_addpath_table_attr_version
                                            
                                            	No\-addpath Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_bestpath_table_attr_version
                                            
                                            	No\-bestpath Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_flags
                                            
                                            	Path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pelem_path_id
                                            
                                            	Local Path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_neighbor_addr
                                            
                                            	Path neighbor address
                                            	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr>`
                                            
                                            .. attribute:: pelem_path_nexthop
                                            
                                            	Path nexthop address
                                            	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop>`
                                            
                                            .. attribute:: pelem_path_peer_path_id
                                            
                                            	Path peer path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_table_attr_version
                                            
                                            	Path Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_table_attr_version
                                            
                                            	Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_version
                                            
                                            	Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_perm_path_pelem = None
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.pelem_flags = None
                                                self.pelem_gw_metric = None
                                                self.pelem_no_addpath_table_attr_version = None
                                                self.pelem_no_bestpath_table_attr_version = None
                                                self.pelem_path_flags = None
                                                self.pelem_path_id = None
                                                self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr()
                                                self.pelem_path_neighbor_addr.parent = self
                                                self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop()
                                                self.pelem_path_nexthop.parent = self
                                                self.pelem_path_peer_path_id = None
                                                self.pelem_path_table_attr_version = None
                                                self.pelem_table_attr_version = None
                                                self.pelem_version = None


                                            class PelemPathNexthop(object):
                                                """
                                                Path nexthop address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-nexthop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.NhteTunnel']['meta_info']


                                            class PelemPathNeighborAddr(object):
                                                """
                                                Path neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-neighbor-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-path-element'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_perm_path_pelem is not None:
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.pelem_flags is not None:
                                                    return True

                                                if self.pelem_gw_metric is not None:
                                                    return True

                                                if self.pelem_no_addpath_table_attr_version is not None:
                                                    return True

                                                if self.pelem_no_bestpath_table_attr_version is not None:
                                                    return True

                                                if self.pelem_path_flags is not None:
                                                    return True

                                                if self.pelem_path_id is not None:
                                                    return True

                                                if self.pelem_path_neighbor_addr is not None and self.pelem_path_neighbor_addr._has_data():
                                                    return True

                                                if self.pelem_path_nexthop is not None and self.pelem_path_nexthop._has_data():
                                                    return True

                                                if self.pelem_path_peer_path_id is not None:
                                                    return True

                                                if self.pelem_path_table_attr_version is not None:
                                                    return True

                                                if self.pelem_table_attr_version is not None:
                                                    return True

                                                if self.pelem_version is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement']['meta_info']


                                        class ActivePathElement(object):
                                            """
                                            Path element list received from Active inst
                                            
                                            .. attribute:: is_perm_path_pelem
                                            
                                            	Pelem for permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.NhteTunnel>`
                                            
                                            .. attribute:: pelem_flags
                                            
                                            	Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_gw_metric
                                            
                                            	Gateway metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_addpath_table_attr_version
                                            
                                            	No\-addpath Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_bestpath_table_attr_version
                                            
                                            	No\-bestpath Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_flags
                                            
                                            	Path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pelem_path_id
                                            
                                            	Local Path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_neighbor_addr
                                            
                                            	Path neighbor address
                                            	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr>`
                                            
                                            .. attribute:: pelem_path_nexthop
                                            
                                            	Path nexthop address
                                            	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop>`
                                            
                                            .. attribute:: pelem_path_peer_path_id
                                            
                                            	Path peer path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_table_attr_version
                                            
                                            	Path Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_table_attr_version
                                            
                                            	Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_version
                                            
                                            	Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_perm_path_pelem = None
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.pelem_flags = None
                                                self.pelem_gw_metric = None
                                                self.pelem_no_addpath_table_attr_version = None
                                                self.pelem_no_bestpath_table_attr_version = None
                                                self.pelem_path_flags = None
                                                self.pelem_path_id = None
                                                self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr()
                                                self.pelem_path_neighbor_addr.parent = self
                                                self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop()
                                                self.pelem_path_nexthop.parent = self
                                                self.pelem_path_peer_path_id = None
                                                self.pelem_path_table_attr_version = None
                                                self.pelem_table_attr_version = None
                                                self.pelem_version = None


                                            class PelemPathNexthop(object):
                                                """
                                                Path nexthop address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-nexthop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.NhteTunnel']['meta_info']


                                            class PelemPathNeighborAddr(object):
                                                """
                                                Path neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-neighbor-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-path-element'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_perm_path_pelem is not None:
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.pelem_flags is not None:
                                                    return True

                                                if self.pelem_gw_metric is not None:
                                                    return True

                                                if self.pelem_no_addpath_table_attr_version is not None:
                                                    return True

                                                if self.pelem_no_bestpath_table_attr_version is not None:
                                                    return True

                                                if self.pelem_path_flags is not None:
                                                    return True

                                                if self.pelem_path_id is not None:
                                                    return True

                                                if self.pelem_path_neighbor_addr is not None and self.pelem_path_neighbor_addr._has_data():
                                                    return True

                                                if self.pelem_path_nexthop is not None and self.pelem_path_nexthop._has_data():
                                                    return True

                                                if self.pelem_path_peer_path_id is not None:
                                                    return True

                                                if self.pelem_path_table_attr_version is not None:
                                                    return True

                                                if self.pelem_table_attr_version is not None:
                                                    return True

                                                if self.pelem_version is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.active_path_element is not None:
                                                for child_ref in self.active_path_element:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.active_process_instance_path is not None:
                                                for child_ref in self.active_process_instance_path:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.add_path_orr_bitfield is not None:
                                                for child_ref in self.add_path_orr_bitfield:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.advertisedto_pe is not None:
                                                return True

                                            if self.af_name is not None:
                                                return True

                                            if self.best_path_orr_bitfield is not None:
                                                for child_ref in self.best_path_orr_bitfield:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                return True

                                            if self.bit is not None:
                                                return True

                                            if self.flags is not None:
                                                return True

                                            if self.gateway_array is not None:
                                                return True

                                            if self.has_inconsistent_paths is not None:
                                                return True

                                            if self.has_lbl_retained is not None:
                                                return True

                                            if self.has_local_label is not None:
                                                return True

                                            if self.is_net_aggregation_suppressed is not None:
                                                return True

                                            if self.is_net_ldp_signaled is not None:
                                                return True

                                            if self.is_permanent_network is not None:
                                                return True

                                            if self.local_path_element is not None:
                                                for child_ref in self.local_path_element:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.local_peers_advertised_to is not None:
                                                for child_ref in self.local_peers_advertised_to:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.local_process_instance_path is not None:
                                                for child_ref in self.local_process_instance_path:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.net_backup_available is not None:
                                                return True

                                            if self.net_backup_label_rewrite_available is not None:
                                                return True

                                            if self.net_eibgp_multipath is not None:
                                                return True

                                            if self.net_extended_flags is not None:
                                                return True

                                            if self.net_flags is not None:
                                                return True

                                            if self.net_local_label is not None:
                                                return True

                                            if self.net_local_label_rewrite is not None:
                                                return True

                                            if self.net_local_label_srgb is not None:
                                                return True

                                            if self.net_multipath is not None:
                                                return True

                                            if self.network is not None:
                                                return True

                                            if self.num_of_path is not None:
                                                return True

                                            if self.pe_peers_advertised_to is not None:
                                                for child_ref in self.pe_peers_advertised_to:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.process_instance_id is not None:
                                                return True

                                            if self.rd is not None:
                                                return True

                                            if self.resilient_nexthop_set is not None:
                                                return True

                                            if self.rib_failed is not None:
                                                return True

                                            if self.route_distinguisher is not None:
                                                return True

                                            if self.table_brib_version is not None:
                                                return True

                                            if self.table_version is not None:
                                                return True

                                            if self.version is not None:
                                                return True

                                            if self.version_age is not None and self.version_age._has_data():
                                                return True

                                            if self.version_timestamp is not None and self.version_timestamp._has_data():
                                                return True

                                            if self.vrf_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:networks'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.network is not None:
                                            for child_ref in self.network:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks']['meta_info']


                                class PathTable(object):
                                    """
                                    The BGP Path Table
                                    
                                    .. attribute:: path
                                    
                                    	A BGP path table entry
                                    	**type**\: list of    :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.path = YList()
                                        self.path.parent = self
                                        self.path.name = 'path'


                                    class Path(object):
                                        """
                                        A BGP path table entry
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor adddress
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr>`
                                        
                                        .. attribute:: network
                                        
                                        	Network Prefix in Hex format
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_id
                                        
                                        	Received Path ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type
                                        	**type**\:   :py:class:`BgpRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRouteEnum>`
                                        
                                        .. attribute:: source_rd
                                        
                                        	Source Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self.label_fail = None
                                            self.label_o_or_version = None
                                            self.label_oor = None
                                            self.neighbor_address = None
                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self.network = None
                                            self.no_path = None
                                            self.path_id = None
                                            self.path_information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation()
                                            self.path_information.parent = self
                                            self.prefix_length = None
                                            self.prefix_version = None
                                            self.process_instance_id = None
                                            self.rd = None
                                            self.route_distinguisher = None
                                            self.route_type = None
                                            self.source_rd = None
                                            self.source_route_distinguisher = None
                                            self.source_vrf_name = None
                                            self.srcaf_name = None
                                            self.vrf_name = None


                                        class NeighborAddressXr(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr']['meta_info']


                                        class PathInformation(object):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_esi
                                            
                                            	Path has EVPN ESI
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_rcvd_label
                                            
                                            	Path has received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebg_ps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.L2VpnEvpnEsi>`
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop>`
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhteTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_p_ath = None
                                                self.add_path_orr_bitfield = YList()
                                                self.add_path_orr_bitfield.parent = self
                                                self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                self.advertisedto_pe = None
                                                self.aigp_metric = None
                                                self.best_path_comp_stage = None
                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self.best_path_id = None
                                                self.best_path_id_comp_winner = None
                                                self.best_path_orr_bitfield = YList()
                                                self.best_path_orr_bitfield.parent = self
                                                self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self.dampen_penalty = None
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.fspec_invalid_path = None
                                                self.graceful_shutdown = None
                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self.halflife_time = None
                                                self.has_esi = None
                                                self.has_gw_addr = None
                                                self.has_local_net_label = None
                                                self.has_mdt_group_addr = None
                                                self.has_mvpn_extcomm = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.has_rcvd_label = None
                                                self.has_second_label = None
                                                self.ibgp_signaled_validity = None
                                                self.igp_metric = None
                                                self.is_aggregation_suppressed = None
                                                self.is_as_best = None
                                                self.is_best_path = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_internal_path = None
                                                self.is_partial_best = None
                                                self.is_path_additional_path = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_af_install_eligible = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_damped = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_history_held = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_imported = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_multipath = None
                                                self.is_path_nexthop_discarded = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebg_ps = None
                                                self.is_path_received_only = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_stale = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_valid = None
                                                self.is_path_vpn_only = None
                                                self.is_permanent_path = None
                                                self.is_received_path_not_modified = None
                                                self.is_spkr_as_best = None
                                                self.l2vpn_circuit_status_value = YList()
                                                self.l2vpn_circuit_status_value.parent = self
                                                self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.L2VpnEvpnEsi()
                                                self.l2vpn_evpn_esi.parent = self
                                                self.l2vpn_size = None
                                                self.labeled_unicast_safi_path = None
                                                self.local_label = None
                                                self.local_nh = None
                                                self.local_path_id = None
                                                self.local_peers_advertised_to = YList()
                                                self.local_peers_advertised_to.parent = self
                                                self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                self.maximum_suppress_time = None
                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self.mvpn_path_flags = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_value = YList()
                                                self.mvpn_pmsi_value.parent = self
                                                self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                self.mvpn_sfs_path = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.neighbor_router_id = None
                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.path_flags = None
                                                self.path_flap_count = None
                                                self.path_import_flags = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.path_table_version = None
                                                self.path_weight = None
                                                self.pe_peers_advertised_to = YList()
                                                self.pe_peers_advertised_to.parent = self
                                                self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                self.rcvd_label = None
                                                self.rcvd_path_id = None
                                                self.reuse_value = None
                                                self.rib_failed = None
                                                self.route_type = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.rt_set_limit_enabled = None
                                                self.second_label = None
                                                self.seconds_since_first_flap = None
                                                self.show_rpki_origin_as_validity = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.suppress_penalty = None
                                                self.time_to_unsuppress = None


                                            class BgpPrefix(object):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self.prefix_length = None


                                                class Prefix(object):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.prefix is not None and self.prefix._has_data():
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix']['meta_info']


                                            class NeighborAddress(object):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress']['meta_info']


                                            class NextHop(object):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhteTunnel']['meta_info']


                                            class MdtGroupAddr(object):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr']['meta_info']


                                            class L2VpnEvpnEsi(object):
                                                """
                                                L2VPN EVPN ESI
                                                
                                                .. attribute:: esi
                                                
                                                	esi
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.esi = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.esi is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.L2VpnEvpnEsi']['meta_info']


                                            class GwAddr(object):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.GwAddr']['meta_info']


                                            class BestPathCompWinner(object):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner']['meta_info']


                                            class MvpnNbrAddr(object):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr']['meta_info']


                                            class MvpnNexthopAddr(object):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr']['meta_info']


                                            class L2VpnCircuitStatusValue(object):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                            class MvpnPmsiValue(object):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity']['meta_info']


                                            class LocalPeersAdvertisedTo(object):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                            class PePeersAdvertisedTo(object):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo']['meta_info']


                                            class BestPathOrrBitfield(object):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield']['meta_info']


                                            class AddPathOrrBitfield(object):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.accept_own_path is not None:
                                                    return True

                                                if self.accept_own_self_originated_p_ath is not None:
                                                    return True

                                                if self.add_path_orr_bitfield is not None:
                                                    for child_ref in self.add_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.advertisedto_pe is not None:
                                                    return True

                                                if self.aigp_metric is not None:
                                                    return True

                                                if self.best_path_comp_stage is not None:
                                                    return True

                                                if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                    return True

                                                if self.best_path_id is not None:
                                                    return True

                                                if self.best_path_id_comp_winner is not None:
                                                    return True

                                                if self.best_path_orr_bitfield is not None:
                                                    for child_ref in self.best_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                    return True

                                                if self.dampen_penalty is not None:
                                                    return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.fspec_invalid_path is not None:
                                                    return True

                                                if self.graceful_shutdown is not None:
                                                    return True

                                                if self.gw_addr is not None and self.gw_addr._has_data():
                                                    return True

                                                if self.halflife_time is not None:
                                                    return True

                                                if self.has_esi is not None:
                                                    return True

                                                if self.has_gw_addr is not None:
                                                    return True

                                                if self.has_local_net_label is not None:
                                                    return True

                                                if self.has_mdt_group_addr is not None:
                                                    return True

                                                if self.has_mvpn_extcomm is not None:
                                                    return True

                                                if self.has_mvpn_nbr_addr is not None:
                                                    return True

                                                if self.has_mvpn_nexthop_addr is not None:
                                                    return True

                                                if self.has_mvpn_pmsi is not None:
                                                    return True

                                                if self.has_rcvd_label is not None:
                                                    return True

                                                if self.has_second_label is not None:
                                                    return True

                                                if self.ibgp_signaled_validity is not None:
                                                    return True

                                                if self.igp_metric is not None:
                                                    return True

                                                if self.is_aggregation_suppressed is not None:
                                                    return True

                                                if self.is_as_best is not None:
                                                    return True

                                                if self.is_best_path is not None:
                                                    return True

                                                if self.is_import_dampened is not None:
                                                    return True

                                                if self.is_import_suspect is not None:
                                                    return True

                                                if self.is_internal_path is not None:
                                                    return True

                                                if self.is_partial_best is not None:
                                                    return True

                                                if self.is_path_additional_path is not None:
                                                    return True

                                                if self.is_path_advertised_local_as_only is not None:
                                                    return True

                                                if self.is_path_af_install_eligible is not None:
                                                    return True

                                                if self.is_path_backup is not None:
                                                    return True

                                                if self.is_path_backup_protect_multipath is not None:
                                                    return True

                                                if self.is_path_best_external is not None:
                                                    return True

                                                if self.is_path_damped is not None:
                                                    return True

                                                if self.is_path_from_confederation_peer is not None:
                                                    return True

                                                if self.is_path_from_network_command is not None:
                                                    return True

                                                if self.is_path_from_redistribute_command is not None:
                                                    return True

                                                if self.is_path_from_route_reflector is not None:
                                                    return True

                                                if self.is_path_history_held is not None:
                                                    return True

                                                if self.is_path_imp_candidate is not None:
                                                    return True

                                                if self.is_path_imported is not None:
                                                    return True

                                                if self.is_path_local_aggregate is not None:
                                                    return True

                                                if self.is_path_locally_sourced is not None:
                                                    return True

                                                if self.is_path_long_lived_stale is not None:
                                                    return True

                                                if self.is_path_multipath is not None:
                                                    return True

                                                if self.is_path_nexthop_discarded is not None:
                                                    return True

                                                if self.is_path_not_advertised is not None:
                                                    return True

                                                if self.is_path_not_advertised_to_ebg_ps is not None:
                                                    return True

                                                if self.is_path_received_only is not None:
                                                    return True

                                                if self.is_path_reoriginated is not None:
                                                    return True

                                                if self.is_path_reoriginated_stitching is not None:
                                                    return True

                                                if self.is_path_stale is not None:
                                                    return True

                                                if self.is_path_synced_with_igp is not None:
                                                    return True

                                                if self.is_path_valid is not None:
                                                    return True

                                                if self.is_path_vpn_only is not None:
                                                    return True

                                                if self.is_permanent_path is not None:
                                                    return True

                                                if self.is_received_path_not_modified is not None:
                                                    return True

                                                if self.is_spkr_as_best is not None:
                                                    return True

                                                if self.l2vpn_circuit_status_value is not None:
                                                    for child_ref in self.l2vpn_circuit_status_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                    return True

                                                if self.l2vpn_size is not None:
                                                    return True

                                                if self.labeled_unicast_safi_path is not None:
                                                    return True

                                                if self.local_label is not None:
                                                    return True

                                                if self.local_nh is not None:
                                                    return True

                                                if self.local_path_id is not None:
                                                    return True

                                                if self.local_peers_advertised_to is not None:
                                                    for child_ref in self.local_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.maximum_suppress_time is not None:
                                                    return True

                                                if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                    return True

                                                if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                    return True

                                                if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                    return True

                                                if self.mvpn_path_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_label is not None:
                                                    return True

                                                if self.mvpn_pmsi_type is not None:
                                                    return True

                                                if self.mvpn_pmsi_value is not None:
                                                    for child_ref in self.mvpn_pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.mvpn_sfs_path is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.neighbor_router_id is not None:
                                                    return True

                                                if self.next_hop is not None and self.next_hop._has_data():
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.path_flags is not None:
                                                    return True

                                                if self.path_flap_count is not None:
                                                    return True

                                                if self.path_import_flags is not None:
                                                    return True

                                                if self.path_rt_set_id is not None:
                                                    return True

                                                if self.path_rt_set_route_count is not None:
                                                    return True

                                                if self.path_table_version is not None:
                                                    return True

                                                if self.path_weight is not None:
                                                    return True

                                                if self.pe_peers_advertised_to is not None:
                                                    for child_ref in self.pe_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.rcvd_label is not None:
                                                    return True

                                                if self.rcvd_path_id is not None:
                                                    return True

                                                if self.reuse_value is not None:
                                                    return True

                                                if self.rib_failed is not None:
                                                    return True

                                                if self.route_type is not None:
                                                    return True

                                                if self.rpki_origin_as_validation_disabled is not None:
                                                    return True

                                                if self.rt_set_limit_enabled is not None:
                                                    return True

                                                if self.second_label is not None:
                                                    return True

                                                if self.seconds_since_first_flap is not None:
                                                    return True

                                                if self.show_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.sn_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.suppress_penalty is not None:
                                                    return True

                                                if self.time_to_unsuppress is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation']['meta_info']


                                        class AttributesAfterPolicyIn(object):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self.is_application_gateway_present = None
                                                self.is_as_path2_byte = None
                                                self.is_attr_set_present = None
                                                self.is_ribrnh_present = None
                                                self.is_rnh_present = None
                                                self.ribrnh_encap = None
                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self.ribrnh_mac = None
                                                self.ribrnh_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnhip_table = None
                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self.rnh_addr_len = None
                                                self.rnh_len = None
                                                self.rnh_type = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.vpn_distinguisher = None


                                            class CommonAttributes(object):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                            class AttrSet(object):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                            class RnhAddr(object):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None
                                                    self.mac_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    if self.mac_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                            class RibrnhIp(object):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.attr_set is not None and self.attr_set._has_data():
                                                    return True

                                                if self.attribute_key_number is not None:
                                                    return True

                                                if self.attribute_reuse_id_config is not None:
                                                    return True

                                                if self.attribute_reuse_id_current is not None:
                                                    return True

                                                if self.attribute_reuse_id_keys is not None:
                                                    return True

                                                if self.attribute_reuse_id_max_id is not None:
                                                    return True

                                                if self.attribute_reuse_id_node is not None:
                                                    return True

                                                if self.attribute_reuse_id_recover_sec is not None:
                                                    return True

                                                if self.common_attributes is not None and self.common_attributes._has_data():
                                                    return True

                                                if self.is_application_gateway_present is not None:
                                                    return True

                                                if self.is_as_path2_byte is not None:
                                                    return True

                                                if self.is_attr_set_present is not None:
                                                    return True

                                                if self.is_ribrnh_present is not None:
                                                    return True

                                                if self.is_rnh_present is not None:
                                                    return True

                                                if self.ribrnh_encap is not None:
                                                    return True

                                                if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                    return True

                                                if self.ribrnh_mac is not None:
                                                    return True

                                                if self.ribrnh_table is not None:
                                                    return True

                                                if self.ribrnh_vni is not None:
                                                    return True

                                                if self.ribrnhip_table is not None:
                                                    return True

                                                if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                    return True

                                                if self.rnh_addr_len is not None:
                                                    return True

                                                if self.rnh_len is not None:
                                                    return True

                                                if self.rnh_type is not None:
                                                    return True

                                                if self.set_aigp_inbound_igp is not None:
                                                    return True

                                                if self.set_aigp_inbound_metric is not None:
                                                    return True

                                                if self.vpn_distinguisher is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                return True

                                            if self.label_fail is not None:
                                                return True

                                            if self.label_o_or_version is not None:
                                                return True

                                            if self.label_oor is not None:
                                                return True

                                            if self.neighbor_address is not None:
                                                return True

                                            if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                return True

                                            if self.network is not None:
                                                return True

                                            if self.no_path is not None:
                                                return True

                                            if self.path_id is not None:
                                                return True

                                            if self.path_information is not None and self.path_information._has_data():
                                                return True

                                            if self.prefix_length is not None:
                                                return True

                                            if self.prefix_version is not None:
                                                return True

                                            if self.process_instance_id is not None:
                                                return True

                                            if self.rd is not None:
                                                return True

                                            if self.route_distinguisher is not None:
                                                return True

                                            if self.route_type is not None:
                                                return True

                                            if self.source_rd is not None:
                                                return True

                                            if self.source_route_distinguisher is not None:
                                                return True

                                            if self.source_vrf_name is not None:
                                                return True

                                            if self.srcaf_name is not None:
                                                return True

                                            if self.vrf_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-table'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.path is not None:
                                            for child_ref in self.path:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable']['meta_info']


                                class Epes(object):
                                    """
                                    The BGP Egress Engineering table
                                    
                                    .. attribute:: epe
                                    
                                    	A BGP Egress Engineering table entry
                                    	**type**\: list of    :py:class:`Epe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.epe = YList()
                                        self.epe.parent = self
                                        self.epe.name = 'epe'


                                    class Epe(object):
                                        """
                                        A BGP Egress Engineering table entry
                                        
                                        .. attribute:: epe_flags
                                        
                                        	EPE object's flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: epe_key
                                        
                                        	Key of EPE object
                                        	**type**\: list of    :py:class:`EpeKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeKey>`
                                        
                                        .. attribute:: epe_key_length
                                        
                                        	Epe Key Length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: epe_key_length_xr
                                        
                                        	EPE key length in bits
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: epe_local_address
                                        
                                        	Local address
                                        	**type**\:   :py:class:`EpeLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress>`
                                        
                                        .. attribute:: epe_local_asn
                                        
                                        	Local AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_local_router_id
                                        
                                        	Local router id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_next_hop
                                        
                                        	Nexthop address
                                        	**type**\:   :py:class:`EpeNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop>`
                                        
                                        .. attribute:: epe_remote_asn
                                        
                                        	Remote AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_remote_router_id
                                        
                                        	Remote router id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_set_key
                                        
                                        	Epe Set Key
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: epe_version
                                        
                                        	EPE object's version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: first_hop
                                        
                                        	List of firsthops of EPE
                                        	**type**\: list of    :py:class:`FirstHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop>`
                                        
                                        .. attribute:: ifhandle
                                        
                                        	List of ifhandle of EPE
                                        	**type**\: list of    :py:class:`Ifhandle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.Ifhandle>`
                                        
                                        .. attribute:: label
                                        
                                        	Label assigned to the RPCnext\-hop set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nexthop_id
                                        
                                        	List of nexthop ID of EPE
                                        	**type**\: list of    :py:class:`NexthopId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.NexthopId>`
                                        
                                        .. attribute:: ref_count
                                        
                                        	Refcount
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.epe_flags = None
                                            self.epe_key = YList()
                                            self.epe_key.parent = self
                                            self.epe_key.name = 'epe_key'
                                            self.epe_key_length = None
                                            self.epe_key_length_xr = None
                                            self.epe_local_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress()
                                            self.epe_local_address.parent = self
                                            self.epe_local_asn = None
                                            self.epe_local_router_id = None
                                            self.epe_next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop()
                                            self.epe_next_hop.parent = self
                                            self.epe_remote_asn = None
                                            self.epe_remote_router_id = None
                                            self.epe_set_key = None
                                            self.epe_version = None
                                            self.first_hop = YList()
                                            self.first_hop.parent = self
                                            self.first_hop.name = 'first_hop'
                                            self.ifhandle = YList()
                                            self.ifhandle.parent = self
                                            self.ifhandle.name = 'ifhandle'
                                            self.label = None
                                            self.nexthop_id = YList()
                                            self.nexthop_id.parent = self
                                            self.nexthop_id.name = 'nexthop_id'
                                            self.ref_count = None


                                        class EpeLocalAddress(object):
                                            """
                                            Local address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:epe-local-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress']['meta_info']


                                        class EpeNextHop(object):
                                            """
                                            Nexthop address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:epe-next-hop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop']['meta_info']


                                        class EpeKey(object):
                                            """
                                            Key of EPE object
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:epe-key'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeKey']['meta_info']


                                        class NexthopId(object):
                                            """
                                            List of nexthop ID of EPE
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-id'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.NexthopId']['meta_info']


                                        class Ifhandle(object):
                                            """
                                            List of ifhandle of EPE
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ifhandle'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.Ifhandle']['meta_info']


                                        class FirstHop(object):
                                            """
                                            List of firsthops of EPE
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-hop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:epe'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.epe_flags is not None:
                                                return True

                                            if self.epe_key is not None:
                                                for child_ref in self.epe_key:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.epe_key_length is not None:
                                                return True

                                            if self.epe_key_length_xr is not None:
                                                return True

                                            if self.epe_local_address is not None and self.epe_local_address._has_data():
                                                return True

                                            if self.epe_local_asn is not None:
                                                return True

                                            if self.epe_local_router_id is not None:
                                                return True

                                            if self.epe_next_hop is not None and self.epe_next_hop._has_data():
                                                return True

                                            if self.epe_remote_asn is not None:
                                                return True

                                            if self.epe_remote_router_id is not None:
                                                return True

                                            if self.epe_set_key is not None:
                                                return True

                                            if self.epe_version is not None:
                                                return True

                                            if self.first_hop is not None:
                                                for child_ref in self.first_hop:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.ifhandle is not None:
                                                for child_ref in self.ifhandle:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.label is not None:
                                                return True

                                            if self.nexthop_id is not None:
                                                for child_ref in self.nexthop_id:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.ref_count is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:epes'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.epe is not None:
                                            for child_ref in self.epe:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes']['meta_info']


                                class AdvertisedPathCounts(object):
                                    """
                                    The BGP Advertised paths table (bestpath)
                                    
                                    .. attribute:: advertised_path_count
                                    
                                    	The BGP Advertised path table Count (bestpath)
                                    	**type**\: list of    :py:class:`AdvertisedPathCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.advertised_path_count = YList()
                                        self.advertised_path_count.parent = self
                                        self.advertised_path_count.name = 'advertised_path_count'


                                    class AdvertisedPathCount(object):
                                        """
                                        The BGP Advertised path table Count
                                        (bestpath)
                                        
                                        .. attribute:: neighbor_address  <key>
                                        
                                        	Neighbor address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: max_prefix_advertisedcount
                                        
                                        	Number of prefixes advertsied to neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.neighbor_address = None
                                            self.max_prefix_advertisedcount = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')
                                            if self.neighbor_address is None:
                                                raise YPYModelError('Key property neighbor_address is None')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertised-path-count[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address = ' + str(self.neighbor_address) + ']'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.neighbor_address is not None:
                                                return True

                                            if self.max_prefix_advertisedcount is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertised-path-counts'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.advertised_path_count is not None:
                                            for child_ref in self.advertised_path_count:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts']['meta_info']


                                class PathLabeledTable(object):
                                    """
                                    The BGP Path Labeled Table
                                    
                                    .. attribute:: path
                                    
                                    	A BGP path table entry
                                    	**type**\: list of    :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.path = YList()
                                        self.path.parent = self
                                        self.path.name = 'path'


                                    class Path(object):
                                        """
                                        A BGP path table entry
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor adddress
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr>`
                                        
                                        .. attribute:: network
                                        
                                        	Network Prefix in Hex format
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_id
                                        
                                        	Received Path ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type
                                        	**type**\:   :py:class:`BgpRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRouteEnum>`
                                        
                                        .. attribute:: source_rd
                                        
                                        	Source Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self.label_fail = None
                                            self.label_o_or_version = None
                                            self.label_oor = None
                                            self.neighbor_address = None
                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self.network = None
                                            self.no_path = None
                                            self.path_id = None
                                            self.path_information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation()
                                            self.path_information.parent = self
                                            self.prefix_length = None
                                            self.prefix_version = None
                                            self.process_instance_id = None
                                            self.rd = None
                                            self.route_distinguisher = None
                                            self.route_type = None
                                            self.source_rd = None
                                            self.source_route_distinguisher = None
                                            self.source_vrf_name = None
                                            self.srcaf_name = None
                                            self.vrf_name = None


                                        class NeighborAddressXr(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr']['meta_info']


                                        class PathInformation(object):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_esi
                                            
                                            	Path has EVPN ESI
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_rcvd_label
                                            
                                            	Path has received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebg_ps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2VpnEvpnEsi>`
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop>`
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhteTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_p_ath = None
                                                self.add_path_orr_bitfield = YList()
                                                self.add_path_orr_bitfield.parent = self
                                                self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                self.advertisedto_pe = None
                                                self.aigp_metric = None
                                                self.best_path_comp_stage = None
                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self.best_path_id = None
                                                self.best_path_id_comp_winner = None
                                                self.best_path_orr_bitfield = YList()
                                                self.best_path_orr_bitfield.parent = self
                                                self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self.dampen_penalty = None
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.fspec_invalid_path = None
                                                self.graceful_shutdown = None
                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self.halflife_time = None
                                                self.has_esi = None
                                                self.has_gw_addr = None
                                                self.has_local_net_label = None
                                                self.has_mdt_group_addr = None
                                                self.has_mvpn_extcomm = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.has_rcvd_label = None
                                                self.has_second_label = None
                                                self.ibgp_signaled_validity = None
                                                self.igp_metric = None
                                                self.is_aggregation_suppressed = None
                                                self.is_as_best = None
                                                self.is_best_path = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_internal_path = None
                                                self.is_partial_best = None
                                                self.is_path_additional_path = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_af_install_eligible = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_damped = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_history_held = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_imported = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_multipath = None
                                                self.is_path_nexthop_discarded = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebg_ps = None
                                                self.is_path_received_only = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_stale = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_valid = None
                                                self.is_path_vpn_only = None
                                                self.is_permanent_path = None
                                                self.is_received_path_not_modified = None
                                                self.is_spkr_as_best = None
                                                self.l2vpn_circuit_status_value = YList()
                                                self.l2vpn_circuit_status_value.parent = self
                                                self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2VpnEvpnEsi()
                                                self.l2vpn_evpn_esi.parent = self
                                                self.l2vpn_size = None
                                                self.labeled_unicast_safi_path = None
                                                self.local_label = None
                                                self.local_nh = None
                                                self.local_path_id = None
                                                self.local_peers_advertised_to = YList()
                                                self.local_peers_advertised_to.parent = self
                                                self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                self.maximum_suppress_time = None
                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self.mvpn_path_flags = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_value = YList()
                                                self.mvpn_pmsi_value.parent = self
                                                self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                self.mvpn_sfs_path = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.neighbor_router_id = None
                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.path_flags = None
                                                self.path_flap_count = None
                                                self.path_import_flags = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.path_table_version = None
                                                self.path_weight = None
                                                self.pe_peers_advertised_to = YList()
                                                self.pe_peers_advertised_to.parent = self
                                                self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                self.rcvd_label = None
                                                self.rcvd_path_id = None
                                                self.reuse_value = None
                                                self.rib_failed = None
                                                self.route_type = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.rt_set_limit_enabled = None
                                                self.second_label = None
                                                self.seconds_since_first_flap = None
                                                self.show_rpki_origin_as_validity = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.suppress_penalty = None
                                                self.time_to_unsuppress = None


                                            class BgpPrefix(object):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self.prefix_length = None


                                                class Prefix(object):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.prefix is not None and self.prefix._has_data():
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix']['meta_info']


                                            class NeighborAddress(object):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress']['meta_info']


                                            class NextHop(object):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhteTunnel']['meta_info']


                                            class MdtGroupAddr(object):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr']['meta_info']


                                            class L2VpnEvpnEsi(object):
                                                """
                                                L2VPN EVPN ESI
                                                
                                                .. attribute:: esi
                                                
                                                	esi
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.esi = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.esi is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2VpnEvpnEsi']['meta_info']


                                            class GwAddr(object):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr']['meta_info']


                                            class BestPathCompWinner(object):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner']['meta_info']


                                            class MvpnNbrAddr(object):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr']['meta_info']


                                            class MvpnNexthopAddr(object):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr']['meta_info']


                                            class L2VpnCircuitStatusValue(object):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                            class MvpnPmsiValue(object):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity']['meta_info']


                                            class LocalPeersAdvertisedTo(object):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                            class PePeersAdvertisedTo(object):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo']['meta_info']


                                            class BestPathOrrBitfield(object):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield']['meta_info']


                                            class AddPathOrrBitfield(object):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.accept_own_path is not None:
                                                    return True

                                                if self.accept_own_self_originated_p_ath is not None:
                                                    return True

                                                if self.add_path_orr_bitfield is not None:
                                                    for child_ref in self.add_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.advertisedto_pe is not None:
                                                    return True

                                                if self.aigp_metric is not None:
                                                    return True

                                                if self.best_path_comp_stage is not None:
                                                    return True

                                                if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                    return True

                                                if self.best_path_id is not None:
                                                    return True

                                                if self.best_path_id_comp_winner is not None:
                                                    return True

                                                if self.best_path_orr_bitfield is not None:
                                                    for child_ref in self.best_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                    return True

                                                if self.dampen_penalty is not None:
                                                    return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.fspec_invalid_path is not None:
                                                    return True

                                                if self.graceful_shutdown is not None:
                                                    return True

                                                if self.gw_addr is not None and self.gw_addr._has_data():
                                                    return True

                                                if self.halflife_time is not None:
                                                    return True

                                                if self.has_esi is not None:
                                                    return True

                                                if self.has_gw_addr is not None:
                                                    return True

                                                if self.has_local_net_label is not None:
                                                    return True

                                                if self.has_mdt_group_addr is not None:
                                                    return True

                                                if self.has_mvpn_extcomm is not None:
                                                    return True

                                                if self.has_mvpn_nbr_addr is not None:
                                                    return True

                                                if self.has_mvpn_nexthop_addr is not None:
                                                    return True

                                                if self.has_mvpn_pmsi is not None:
                                                    return True

                                                if self.has_rcvd_label is not None:
                                                    return True

                                                if self.has_second_label is not None:
                                                    return True

                                                if self.ibgp_signaled_validity is not None:
                                                    return True

                                                if self.igp_metric is not None:
                                                    return True

                                                if self.is_aggregation_suppressed is not None:
                                                    return True

                                                if self.is_as_best is not None:
                                                    return True

                                                if self.is_best_path is not None:
                                                    return True

                                                if self.is_import_dampened is not None:
                                                    return True

                                                if self.is_import_suspect is not None:
                                                    return True

                                                if self.is_internal_path is not None:
                                                    return True

                                                if self.is_partial_best is not None:
                                                    return True

                                                if self.is_path_additional_path is not None:
                                                    return True

                                                if self.is_path_advertised_local_as_only is not None:
                                                    return True

                                                if self.is_path_af_install_eligible is not None:
                                                    return True

                                                if self.is_path_backup is not None:
                                                    return True

                                                if self.is_path_backup_protect_multipath is not None:
                                                    return True

                                                if self.is_path_best_external is not None:
                                                    return True

                                                if self.is_path_damped is not None:
                                                    return True

                                                if self.is_path_from_confederation_peer is not None:
                                                    return True

                                                if self.is_path_from_network_command is not None:
                                                    return True

                                                if self.is_path_from_redistribute_command is not None:
                                                    return True

                                                if self.is_path_from_route_reflector is not None:
                                                    return True

                                                if self.is_path_history_held is not None:
                                                    return True

                                                if self.is_path_imp_candidate is not None:
                                                    return True

                                                if self.is_path_imported is not None:
                                                    return True

                                                if self.is_path_local_aggregate is not None:
                                                    return True

                                                if self.is_path_locally_sourced is not None:
                                                    return True

                                                if self.is_path_long_lived_stale is not None:
                                                    return True

                                                if self.is_path_multipath is not None:
                                                    return True

                                                if self.is_path_nexthop_discarded is not None:
                                                    return True

                                                if self.is_path_not_advertised is not None:
                                                    return True

                                                if self.is_path_not_advertised_to_ebg_ps is not None:
                                                    return True

                                                if self.is_path_received_only is not None:
                                                    return True

                                                if self.is_path_reoriginated is not None:
                                                    return True

                                                if self.is_path_reoriginated_stitching is not None:
                                                    return True

                                                if self.is_path_stale is not None:
                                                    return True

                                                if self.is_path_synced_with_igp is not None:
                                                    return True

                                                if self.is_path_valid is not None:
                                                    return True

                                                if self.is_path_vpn_only is not None:
                                                    return True

                                                if self.is_permanent_path is not None:
                                                    return True

                                                if self.is_received_path_not_modified is not None:
                                                    return True

                                                if self.is_spkr_as_best is not None:
                                                    return True

                                                if self.l2vpn_circuit_status_value is not None:
                                                    for child_ref in self.l2vpn_circuit_status_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                    return True

                                                if self.l2vpn_size is not None:
                                                    return True

                                                if self.labeled_unicast_safi_path is not None:
                                                    return True

                                                if self.local_label is not None:
                                                    return True

                                                if self.local_nh is not None:
                                                    return True

                                                if self.local_path_id is not None:
                                                    return True

                                                if self.local_peers_advertised_to is not None:
                                                    for child_ref in self.local_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.maximum_suppress_time is not None:
                                                    return True

                                                if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                    return True

                                                if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                    return True

                                                if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                    return True

                                                if self.mvpn_path_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_label is not None:
                                                    return True

                                                if self.mvpn_pmsi_type is not None:
                                                    return True

                                                if self.mvpn_pmsi_value is not None:
                                                    for child_ref in self.mvpn_pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.mvpn_sfs_path is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.neighbor_router_id is not None:
                                                    return True

                                                if self.next_hop is not None and self.next_hop._has_data():
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.path_flags is not None:
                                                    return True

                                                if self.path_flap_count is not None:
                                                    return True

                                                if self.path_import_flags is not None:
                                                    return True

                                                if self.path_rt_set_id is not None:
                                                    return True

                                                if self.path_rt_set_route_count is not None:
                                                    return True

                                                if self.path_table_version is not None:
                                                    return True

                                                if self.path_weight is not None:
                                                    return True

                                                if self.pe_peers_advertised_to is not None:
                                                    for child_ref in self.pe_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.rcvd_label is not None:
                                                    return True

                                                if self.rcvd_path_id is not None:
                                                    return True

                                                if self.reuse_value is not None:
                                                    return True

                                                if self.rib_failed is not None:
                                                    return True

                                                if self.route_type is not None:
                                                    return True

                                                if self.rpki_origin_as_validation_disabled is not None:
                                                    return True

                                                if self.rt_set_limit_enabled is not None:
                                                    return True

                                                if self.second_label is not None:
                                                    return True

                                                if self.seconds_since_first_flap is not None:
                                                    return True

                                                if self.show_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.sn_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.suppress_penalty is not None:
                                                    return True

                                                if self.time_to_unsuppress is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation']['meta_info']


                                        class AttributesAfterPolicyIn(object):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self.is_application_gateway_present = None
                                                self.is_as_path2_byte = None
                                                self.is_attr_set_present = None
                                                self.is_ribrnh_present = None
                                                self.is_rnh_present = None
                                                self.ribrnh_encap = None
                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self.ribrnh_mac = None
                                                self.ribrnh_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnhip_table = None
                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self.rnh_addr_len = None
                                                self.rnh_len = None
                                                self.rnh_type = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.vpn_distinguisher = None


                                            class CommonAttributes(object):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                            class AttrSet(object):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                            class RnhAddr(object):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None
                                                    self.mac_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    if self.mac_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                            class RibrnhIp(object):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.attr_set is not None and self.attr_set._has_data():
                                                    return True

                                                if self.attribute_key_number is not None:
                                                    return True

                                                if self.attribute_reuse_id_config is not None:
                                                    return True

                                                if self.attribute_reuse_id_current is not None:
                                                    return True

                                                if self.attribute_reuse_id_keys is not None:
                                                    return True

                                                if self.attribute_reuse_id_max_id is not None:
                                                    return True

                                                if self.attribute_reuse_id_node is not None:
                                                    return True

                                                if self.attribute_reuse_id_recover_sec is not None:
                                                    return True

                                                if self.common_attributes is not None and self.common_attributes._has_data():
                                                    return True

                                                if self.is_application_gateway_present is not None:
                                                    return True

                                                if self.is_as_path2_byte is not None:
                                                    return True

                                                if self.is_attr_set_present is not None:
                                                    return True

                                                if self.is_ribrnh_present is not None:
                                                    return True

                                                if self.is_rnh_present is not None:
                                                    return True

                                                if self.ribrnh_encap is not None:
                                                    return True

                                                if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                    return True

                                                if self.ribrnh_mac is not None:
                                                    return True

                                                if self.ribrnh_table is not None:
                                                    return True

                                                if self.ribrnh_vni is not None:
                                                    return True

                                                if self.ribrnhip_table is not None:
                                                    return True

                                                if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                    return True

                                                if self.rnh_addr_len is not None:
                                                    return True

                                                if self.rnh_len is not None:
                                                    return True

                                                if self.rnh_type is not None:
                                                    return True

                                                if self.set_aigp_inbound_igp is not None:
                                                    return True

                                                if self.set_aigp_inbound_metric is not None:
                                                    return True

                                                if self.vpn_distinguisher is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                return True

                                            if self.label_fail is not None:
                                                return True

                                            if self.label_o_or_version is not None:
                                                return True

                                            if self.label_oor is not None:
                                                return True

                                            if self.neighbor_address is not None:
                                                return True

                                            if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                return True

                                            if self.network is not None:
                                                return True

                                            if self.no_path is not None:
                                                return True

                                            if self.path_id is not None:
                                                return True

                                            if self.path_information is not None and self.path_information._has_data():
                                                return True

                                            if self.prefix_length is not None:
                                                return True

                                            if self.prefix_version is not None:
                                                return True

                                            if self.process_instance_id is not None:
                                                return True

                                            if self.rd is not None:
                                                return True

                                            if self.route_distinguisher is not None:
                                                return True

                                            if self.route_type is not None:
                                                return True

                                            if self.source_rd is not None:
                                                return True

                                            if self.source_route_distinguisher is not None:
                                                return True

                                            if self.source_vrf_name is not None:
                                                return True

                                            if self.srcaf_name is not None:
                                                return True

                                            if self.vrf_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-labeled-table'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.path is not None:
                                            for child_ref in self.path:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable']['meta_info']


                                class AdvertisedPaths(object):
                                    """
                                    The BGP Advertised paths table (add\-paths)
                                    
                                    .. attribute:: advertised_path
                                    
                                    	A BGP Advertised paths table entry (add\-paths)
                                    	**type**\: list of    :py:class:`AdvertisedPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.advertised_path = YList()
                                        self.advertised_path.parent = self
                                        self.advertised_path.name = 'advertised_path'


                                    class AdvertisedPath(object):
                                        """
                                        A BGP Advertised paths table entry
                                        (add\-paths)
                                        
                                        .. attribute:: adv_path_info
                                        
                                        	Net Advertized Paths
                                        	**type**\: list of    :py:class:`AdvPathInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo>`
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor 
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: network
                                        
                                        	Network in hex string bytes format
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: paths
                                        
                                        	paths
                                        	**type**\: list of    :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.adv_path_info = YList()
                                            self.adv_path_info.parent = self
                                            self.adv_path_info.name = 'adv_path_info'
                                            self.neighbor_address = None
                                            self.network = None
                                            self.paths = YList()
                                            self.paths.parent = self
                                            self.paths.name = 'paths'
                                            self.prefix_length = None
                                            self.rd = None


                                        class Paths(object):
                                            """
                                            paths
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: attributes_after_policy_in
                                            
                                            	Attributes after inbound policy applied
                                            	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn>`
                                            
                                            .. attribute:: label_fail
                                            
                                            	LSD label allocation failed 
                                            	**type**\:  bool
                                            
                                            .. attribute:: label_o_or_version
                                            
                                            	Label Version when OOR happens
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_oor
                                            
                                            	LSD label space is exhausted
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address_xr
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr>`
                                            
                                            .. attribute:: no_path
                                            
                                            	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                            	**type**\:  bool
                                            
                                            .. attribute:: path_information
                                            
                                            	Path information
                                            	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation>`
                                            
                                            .. attribute:: prefix_version
                                            
                                            	Version of BGP Prefix Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: process_instance_id
                                            
                                            	Process instance ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_route_distinguisher
                                            
                                            	Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_vrf_name
                                            
                                            	Name of the source VRF
                                            	**type**\:  str
                                            
                                            .. attribute:: srcaf_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.af_name = None
                                                self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn()
                                                self.attributes_after_policy_in.parent = self
                                                self.label_fail = None
                                                self.label_o_or_version = None
                                                self.label_oor = None
                                                self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr()
                                                self.neighbor_address_xr.parent = self
                                                self.no_path = None
                                                self.path_information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation()
                                                self.path_information.parent = self
                                                self.prefix_version = None
                                                self.process_instance_id = None
                                                self.route_distinguisher = None
                                                self.source_route_distinguisher = None
                                                self.source_vrf_name = None
                                                self.srcaf_name = None
                                                self.vrf_name = None


                                            class NeighborAddressXr(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr']['meta_info']


                                            class PathInformation(object):
                                                """
                                                Path information
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\:  bool
                                                
                                                .. attribute:: accept_own_self_originated_p_ath
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\:  bool
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield>`
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\:  bool
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner>`
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield>`
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix>`
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity>`
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\:  bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\:  bool
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr>`
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_esi
                                                
                                                	Path has EVPN ESI
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_rcvd_label
                                                
                                                	Path has received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\:  bool
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebg_ps
                                                
                                                	Not advertised to EBGPs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2VpnCircuitStatusValue>`
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2VpnEvpnEsi>`
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr>`
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue>`
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress>`
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop>`
                                                
                                                .. attribute:: nhte_tunnel
                                                
                                                	NH TE tunnel information
                                                	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhteTunnel>`
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\:  bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.accept_own_path = None
                                                    self.accept_own_self_originated_p_ath = None
                                                    self.add_path_orr_bitfield = YList()
                                                    self.add_path_orr_bitfield.parent = self
                                                    self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                    self.advertisedto_pe = None
                                                    self.aigp_metric = None
                                                    self.best_path_comp_stage = None
                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self.best_path_id = None
                                                    self.best_path_id_comp_winner = None
                                                    self.best_path_orr_bitfield = YList()
                                                    self.best_path_orr_bitfield.parent = self
                                                    self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self.dampen_penalty = None
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.fspec_invalid_path = None
                                                    self.graceful_shutdown = None
                                                    self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self.halflife_time = None
                                                    self.has_esi = None
                                                    self.has_gw_addr = None
                                                    self.has_local_net_label = None
                                                    self.has_mdt_group_addr = None
                                                    self.has_mvpn_extcomm = None
                                                    self.has_mvpn_nbr_addr = None
                                                    self.has_mvpn_nexthop_addr = None
                                                    self.has_mvpn_pmsi = None
                                                    self.has_rcvd_label = None
                                                    self.has_second_label = None
                                                    self.ibgp_signaled_validity = None
                                                    self.igp_metric = None
                                                    self.is_aggregation_suppressed = None
                                                    self.is_as_best = None
                                                    self.is_best_path = None
                                                    self.is_import_dampened = None
                                                    self.is_import_suspect = None
                                                    self.is_internal_path = None
                                                    self.is_partial_best = None
                                                    self.is_path_additional_path = None
                                                    self.is_path_advertised_local_as_only = None
                                                    self.is_path_af_install_eligible = None
                                                    self.is_path_backup = None
                                                    self.is_path_backup_protect_multipath = None
                                                    self.is_path_best_external = None
                                                    self.is_path_damped = None
                                                    self.is_path_from_confederation_peer = None
                                                    self.is_path_from_network_command = None
                                                    self.is_path_from_redistribute_command = None
                                                    self.is_path_from_route_reflector = None
                                                    self.is_path_history_held = None
                                                    self.is_path_imp_candidate = None
                                                    self.is_path_imported = None
                                                    self.is_path_local_aggregate = None
                                                    self.is_path_locally_sourced = None
                                                    self.is_path_long_lived_stale = None
                                                    self.is_path_multipath = None
                                                    self.is_path_nexthop_discarded = None
                                                    self.is_path_not_advertised = None
                                                    self.is_path_not_advertised_to_ebg_ps = None
                                                    self.is_path_received_only = None
                                                    self.is_path_reoriginated = None
                                                    self.is_path_reoriginated_stitching = None
                                                    self.is_path_stale = None
                                                    self.is_path_synced_with_igp = None
                                                    self.is_path_valid = None
                                                    self.is_path_vpn_only = None
                                                    self.is_permanent_path = None
                                                    self.is_received_path_not_modified = None
                                                    self.is_spkr_as_best = None
                                                    self.l2vpn_circuit_status_value = YList()
                                                    self.l2vpn_circuit_status_value.parent = self
                                                    self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                    self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2VpnEvpnEsi()
                                                    self.l2vpn_evpn_esi.parent = self
                                                    self.l2vpn_size = None
                                                    self.labeled_unicast_safi_path = None
                                                    self.local_label = None
                                                    self.local_nh = None
                                                    self.local_path_id = None
                                                    self.local_peers_advertised_to = YList()
                                                    self.local_peers_advertised_to.parent = self
                                                    self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                    self.maximum_suppress_time = None
                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self.mvpn_path_flags = None
                                                    self.mvpn_pmsi_flags = None
                                                    self.mvpn_pmsi_label = None
                                                    self.mvpn_pmsi_type = None
                                                    self.mvpn_pmsi_value = YList()
                                                    self.mvpn_pmsi_value.parent = self
                                                    self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                    self.mvpn_sfs_path = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.neighbor_router_id = None
                                                    self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop()
                                                    self.next_hop.parent = self
                                                    self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhteTunnel()
                                                    self.nhte_tunnel.parent = self
                                                    self.path_flags = None
                                                    self.path_flap_count = None
                                                    self.path_import_flags = None
                                                    self.path_rt_set_id = None
                                                    self.path_rt_set_route_count = None
                                                    self.path_table_version = None
                                                    self.path_weight = None
                                                    self.pe_peers_advertised_to = YList()
                                                    self.pe_peers_advertised_to.parent = self
                                                    self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                    self.rcvd_label = None
                                                    self.rcvd_path_id = None
                                                    self.reuse_value = None
                                                    self.rib_failed = None
                                                    self.route_type = None
                                                    self.rpki_origin_as_validation_disabled = None
                                                    self.rt_set_limit_enabled = None
                                                    self.second_label = None
                                                    self.seconds_since_first_flap = None
                                                    self.show_rpki_origin_as_validity = None
                                                    self.sn_rpki_origin_as_validity = None
                                                    self.suppress_penalty = None
                                                    self.time_to_unsuppress = None


                                                class BgpPrefix(object):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self.prefix_length = None


                                                    class Prefix(object):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.prefix is not None and self.prefix._has_data():
                                                            return True

                                                        if self.prefix_length is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix']['meta_info']


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress']['meta_info']


                                                class NextHop(object):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop']['meta_info']


                                                class NhteTunnel(object):
                                                    """
                                                    NH TE tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_te_tunnel
                                                    
                                                    	NH TE Tunnel info is present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last rib update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	tunnel name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	tunnel type
                                                    	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.binding_label = None
                                                        self.has_te_tunnel = None
                                                        self.is_tunnel_info_stale = None
                                                        self.is_tunnel_registered = None
                                                        self.is_tunnel_up = None
                                                        self.last_tunnel_update = None
                                                        self.tunnel_if_handle = None
                                                        self.tunnel_name = None
                                                        self.tunnel_type = None
                                                        self.tunnel_v6_enabled = None
                                                        self.tunnel_v6_required = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.binding_label is not None:
                                                            return True

                                                        if self.has_te_tunnel is not None:
                                                            return True

                                                        if self.is_tunnel_info_stale is not None:
                                                            return True

                                                        if self.is_tunnel_registered is not None:
                                                            return True

                                                        if self.is_tunnel_up is not None:
                                                            return True

                                                        if self.last_tunnel_update is not None:
                                                            return True

                                                        if self.tunnel_if_handle is not None:
                                                            return True

                                                        if self.tunnel_name is not None:
                                                            return True

                                                        if self.tunnel_type is not None:
                                                            return True

                                                        if self.tunnel_v6_enabled is not None:
                                                            return True

                                                        if self.tunnel_v6_required is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhteTunnel']['meta_info']


                                                class MdtGroupAddr(object):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr']['meta_info']


                                                class L2VpnEvpnEsi(object):
                                                    """
                                                    L2VPN EVPN ESI
                                                    
                                                    .. attribute:: esi
                                                    
                                                    	esi
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.esi = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.esi is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2VpnEvpnEsi']['meta_info']


                                                class GwAddr(object):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.len = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.len is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr']['meta_info']


                                                class BestPathCompWinner(object):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner']['meta_info']


                                                class MvpnNbrAddr(object):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr']['meta_info']


                                                class MvpnNexthopAddr(object):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr']['meta_info']


                                                class L2VpnCircuitStatusValue(object):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                                class MvpnPmsiValue(object):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity']['meta_info']


                                                class LocalPeersAdvertisedTo(object):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                                class PePeersAdvertisedTo(object):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo']['meta_info']


                                                class BestPathOrrBitfield(object):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield']['meta_info']


                                                class AddPathOrrBitfield(object):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.accept_own_path is not None:
                                                        return True

                                                    if self.accept_own_self_originated_p_ath is not None:
                                                        return True

                                                    if self.add_path_orr_bitfield is not None:
                                                        for child_ref in self.add_path_orr_bitfield:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.advertisedto_pe is not None:
                                                        return True

                                                    if self.aigp_metric is not None:
                                                        return True

                                                    if self.best_path_comp_stage is not None:
                                                        return True

                                                    if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                        return True

                                                    if self.best_path_id is not None:
                                                        return True

                                                    if self.best_path_id_comp_winner is not None:
                                                        return True

                                                    if self.best_path_orr_bitfield is not None:
                                                        for child_ref in self.best_path_orr_bitfield:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                        return True

                                                    if self.dampen_penalty is not None:
                                                        return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.fspec_invalid_path is not None:
                                                        return True

                                                    if self.graceful_shutdown is not None:
                                                        return True

                                                    if self.gw_addr is not None and self.gw_addr._has_data():
                                                        return True

                                                    if self.halflife_time is not None:
                                                        return True

                                                    if self.has_esi is not None:
                                                        return True

                                                    if self.has_gw_addr is not None:
                                                        return True

                                                    if self.has_local_net_label is not None:
                                                        return True

                                                    if self.has_mdt_group_addr is not None:
                                                        return True

                                                    if self.has_mvpn_extcomm is not None:
                                                        return True

                                                    if self.has_mvpn_nbr_addr is not None:
                                                        return True

                                                    if self.has_mvpn_nexthop_addr is not None:
                                                        return True

                                                    if self.has_mvpn_pmsi is not None:
                                                        return True

                                                    if self.has_rcvd_label is not None:
                                                        return True

                                                    if self.has_second_label is not None:
                                                        return True

                                                    if self.ibgp_signaled_validity is not None:
                                                        return True

                                                    if self.igp_metric is not None:
                                                        return True

                                                    if self.is_aggregation_suppressed is not None:
                                                        return True

                                                    if self.is_as_best is not None:
                                                        return True

                                                    if self.is_best_path is not None:
                                                        return True

                                                    if self.is_import_dampened is not None:
                                                        return True

                                                    if self.is_import_suspect is not None:
                                                        return True

                                                    if self.is_internal_path is not None:
                                                        return True

                                                    if self.is_partial_best is not None:
                                                        return True

                                                    if self.is_path_additional_path is not None:
                                                        return True

                                                    if self.is_path_advertised_local_as_only is not None:
                                                        return True

                                                    if self.is_path_af_install_eligible is not None:
                                                        return True

                                                    if self.is_path_backup is not None:
                                                        return True

                                                    if self.is_path_backup_protect_multipath is not None:
                                                        return True

                                                    if self.is_path_best_external is not None:
                                                        return True

                                                    if self.is_path_damped is not None:
                                                        return True

                                                    if self.is_path_from_confederation_peer is not None:
                                                        return True

                                                    if self.is_path_from_network_command is not None:
                                                        return True

                                                    if self.is_path_from_redistribute_command is not None:
                                                        return True

                                                    if self.is_path_from_route_reflector is not None:
                                                        return True

                                                    if self.is_path_history_held is not None:
                                                        return True

                                                    if self.is_path_imp_candidate is not None:
                                                        return True

                                                    if self.is_path_imported is not None:
                                                        return True

                                                    if self.is_path_local_aggregate is not None:
                                                        return True

                                                    if self.is_path_locally_sourced is not None:
                                                        return True

                                                    if self.is_path_long_lived_stale is not None:
                                                        return True

                                                    if self.is_path_multipath is not None:
                                                        return True

                                                    if self.is_path_nexthop_discarded is not None:
                                                        return True

                                                    if self.is_path_not_advertised is not None:
                                                        return True

                                                    if self.is_path_not_advertised_to_ebg_ps is not None:
                                                        return True

                                                    if self.is_path_received_only is not None:
                                                        return True

                                                    if self.is_path_reoriginated is not None:
                                                        return True

                                                    if self.is_path_reoriginated_stitching is not None:
                                                        return True

                                                    if self.is_path_stale is not None:
                                                        return True

                                                    if self.is_path_synced_with_igp is not None:
                                                        return True

                                                    if self.is_path_valid is not None:
                                                        return True

                                                    if self.is_path_vpn_only is not None:
                                                        return True

                                                    if self.is_permanent_path is not None:
                                                        return True

                                                    if self.is_received_path_not_modified is not None:
                                                        return True

                                                    if self.is_spkr_as_best is not None:
                                                        return True

                                                    if self.l2vpn_circuit_status_value is not None:
                                                        for child_ref in self.l2vpn_circuit_status_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                        return True

                                                    if self.l2vpn_size is not None:
                                                        return True

                                                    if self.labeled_unicast_safi_path is not None:
                                                        return True

                                                    if self.local_label is not None:
                                                        return True

                                                    if self.local_nh is not None:
                                                        return True

                                                    if self.local_path_id is not None:
                                                        return True

                                                    if self.local_peers_advertised_to is not None:
                                                        for child_ref in self.local_peers_advertised_to:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.maximum_suppress_time is not None:
                                                        return True

                                                    if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                        return True

                                                    if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                        return True

                                                    if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                        return True

                                                    if self.mvpn_path_flags is not None:
                                                        return True

                                                    if self.mvpn_pmsi_flags is not None:
                                                        return True

                                                    if self.mvpn_pmsi_label is not None:
                                                        return True

                                                    if self.mvpn_pmsi_type is not None:
                                                        return True

                                                    if self.mvpn_pmsi_value is not None:
                                                        for child_ref in self.mvpn_pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.mvpn_sfs_path is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.neighbor_router_id is not None:
                                                        return True

                                                    if self.next_hop is not None and self.next_hop._has_data():
                                                        return True

                                                    if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                        return True

                                                    if self.path_flags is not None:
                                                        return True

                                                    if self.path_flap_count is not None:
                                                        return True

                                                    if self.path_import_flags is not None:
                                                        return True

                                                    if self.path_rt_set_id is not None:
                                                        return True

                                                    if self.path_rt_set_route_count is not None:
                                                        return True

                                                    if self.path_table_version is not None:
                                                        return True

                                                    if self.path_weight is not None:
                                                        return True

                                                    if self.pe_peers_advertised_to is not None:
                                                        for child_ref in self.pe_peers_advertised_to:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.rcvd_label is not None:
                                                        return True

                                                    if self.rcvd_path_id is not None:
                                                        return True

                                                    if self.reuse_value is not None:
                                                        return True

                                                    if self.rib_failed is not None:
                                                        return True

                                                    if self.route_type is not None:
                                                        return True

                                                    if self.rpki_origin_as_validation_disabled is not None:
                                                        return True

                                                    if self.rt_set_limit_enabled is not None:
                                                        return True

                                                    if self.second_label is not None:
                                                        return True

                                                    if self.seconds_since_first_flap is not None:
                                                        return True

                                                    if self.show_rpki_origin_as_validity is not None:
                                                        return True

                                                    if self.sn_rpki_origin_as_validity is not None:
                                                        return True

                                                    if self.suppress_penalty is not None:
                                                        return True

                                                    if self.time_to_unsuppress is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation']['meta_info']


                                            class AttributesAfterPolicyIn(object):
                                                """
                                                Attributes after inbound policy applied
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet>`
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes>`
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp>`
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr>`
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\:  bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\:  bool
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet()
                                                    self.attr_set.parent = self
                                                    self.attribute_key_number = None
                                                    self.attribute_reuse_id_config = None
                                                    self.attribute_reuse_id_current = None
                                                    self.attribute_reuse_id_keys = None
                                                    self.attribute_reuse_id_max_id = None
                                                    self.attribute_reuse_id_node = None
                                                    self.attribute_reuse_id_recover_sec = None
                                                    self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self.is_application_gateway_present = None
                                                    self.is_as_path2_byte = None
                                                    self.is_attr_set_present = None
                                                    self.is_ribrnh_present = None
                                                    self.is_rnh_present = None
                                                    self.ribrnh_encap = None
                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self.ribrnh_mac = None
                                                    self.ribrnh_table = None
                                                    self.ribrnh_vni = None
                                                    self.ribrnhip_table = None
                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self.rnh_addr_len = None
                                                    self.rnh_len = None
                                                    self.rnh_type = None
                                                    self.set_aigp_inbound_igp = None
                                                    self.set_aigp_inbound_metric = None
                                                    self.vpn_distinguisher = None


                                                class CommonAttributes(object):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_encap_present
                                                    
                                                    	Tunnel Encap attribute present 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_policy_allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_binding_sid
                                                    
                                                    	SR Policy Binding sid
                                                    	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_explicit_path
                                                    
                                                    	SR Policy Explicit paths
                                                    	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                    
                                                    .. attribute:: sr_policy_preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_tunnel_request_state
                                                    
                                                    	SR Tunnel Request State
                                                    	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                    
                                                    .. attribute:: sr_tunnel_state
                                                    
                                                    	SR Tunnel State
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encap Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.aggregator_address = None
                                                        self.aggregator_as = None
                                                        self.aigp_metric_value = None
                                                        self.as_path = None
                                                        self.cluster = YList()
                                                        self.cluster.parent = self
                                                        self.cluster.name = 'cluster'
                                                        self.community = YList()
                                                        self.community.parent = self
                                                        self.community.name = 'community'
                                                        self.connector_type = None
                                                        self.connector_value = YList()
                                                        self.connector_value.parent = self
                                                        self.connector_value.name = 'connector_value'
                                                        self.extended_community = YList()
                                                        self.extended_community.parent = self
                                                        self.extended_community.name = 'extended_community'
                                                        self.extended_community_flags = None
                                                        self.is_aggregator_present = None
                                                        self.is_aigp_present = None
                                                        self.is_as_path_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_community_present = None
                                                        self.is_connector_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_label_index_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_metric_present = None
                                                        self.is_origin_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_ssa_present = None
                                                        self.is_tunnel_encap_present = None
                                                        self.l2tpv3_cookie = YList()
                                                        self.l2tpv3_cookie.parent = self
                                                        self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                        self.l2tpv3_session_id = None
                                                        self.label_index_attr = YList()
                                                        self.label_index_attr.parent = self
                                                        self.label_index_attr.name = 'label_index_attr'
                                                        self.local_preference = None
                                                        self.ls_attr = YList()
                                                        self.ls_attr.parent = self
                                                        self.ls_attr.name = 'ls_attr'
                                                        self.metric = None
                                                        self.neighbor_as = None
                                                        self.origin = None
                                                        self.originator = None
                                                        self.pe_distinguisher_label = YList()
                                                        self.pe_distinguisher_label.parent = self
                                                        self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.pmsi_type = None
                                                        self.pmsi_value = YList()
                                                        self.pmsi_value.parent = self
                                                        self.pmsi_value.name = 'pmsi_value'
                                                        self.ppm_pvalue = None
                                                        self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                        self.sr_policy_allocated_binding_sid.parent = self
                                                        self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                        self.sr_policy_binding_sid.parent = self
                                                        self.sr_policy_explicit_path = YList()
                                                        self.sr_policy_explicit_path.parent = self
                                                        self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                        self.sr_policy_preference = None
                                                        self.sr_tunnel_request_state = None
                                                        self.sr_tunnel_state = None
                                                        self.tunnel_encap_type = None
                                                        self.unknown_attribute = YList()
                                                        self.unknown_attribute.parent = self
                                                        self.unknown_attribute.name = 'unknown_attribute'


                                                    class SrPolicyBindingSid(object):
                                                        """
                                                        SR Policy Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                    class SrPolicyAllocatedBindingSid(object):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                    class Community(object):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                    class ExtendedCommunity(object):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                    class UnknownAttribute(object):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                    class Cluster(object):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                    class L2Tpv3Cookie(object):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                    class ConnectorValue(object):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                    class PmsiValue(object):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                    class LsAttr(object):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                    class LabelIndexAttr(object):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                    class PeDistinguisherLabel(object):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.label = None
                                                            self.pe_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.label is not None:
                                                                return True

                                                            if self.pe_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                    class SrPolicyExplicitPath(object):
                                                        """
                                                        SR Policy Explicit paths
                                                        
                                                        .. attribute:: sid
                                                        
                                                        	Sidlist for explicit path
                                                        	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of explicit path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.sid = YList()
                                                            self.sid.parent = self
                                                            self.sid.name = 'sid'
                                                            self.weight = None


                                                        class Sid(object):
                                                            """
                                                            Sidlist for explicit path
                                                            
                                                            .. attribute:: ipv4
                                                            
                                                            	IP Address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6
                                                            
                                                            	IPv6 address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label sid
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Sid Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4 = None
                                                                self.ipv6 = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4 is not None:
                                                                    return True

                                                                if self.ipv6 is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.sid is not None:
                                                                for child_ref in self.sid:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.weight is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.aggregator_address is not None:
                                                            return True

                                                        if self.aggregator_as is not None:
                                                            return True

                                                        if self.aigp_metric_value is not None:
                                                            return True

                                                        if self.as_path is not None:
                                                            return True

                                                        if self.cluster is not None:
                                                            for child_ref in self.cluster:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.community is not None:
                                                            for child_ref in self.community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.connector_type is not None:
                                                            return True

                                                        if self.connector_value is not None:
                                                            for child_ref in self.connector_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community is not None:
                                                            for child_ref in self.extended_community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community_flags is not None:
                                                            return True

                                                        if self.is_aggregator_present is not None:
                                                            return True

                                                        if self.is_aigp_present is not None:
                                                            return True

                                                        if self.is_as_path_present is not None:
                                                            return True

                                                        if self.is_atomic_aggregate_present is not None:
                                                            return True

                                                        if self.is_community_present is not None:
                                                            return True

                                                        if self.is_connector_present is not None:
                                                            return True

                                                        if self.is_extended_community_present is not None:
                                                            return True

                                                        if self.is_label_index_present is not None:
                                                            return True

                                                        if self.is_local_pref_present is not None:
                                                            return True

                                                        if self.is_ls_attribute_present is not None:
                                                            return True

                                                        if self.is_metric_present is not None:
                                                            return True

                                                        if self.is_origin_present is not None:
                                                            return True

                                                        if self.is_pe_distinguisher_label_present is not None:
                                                            return True

                                                        if self.is_pmsi_present is not None:
                                                            return True

                                                        if self.is_pppmp_present is not None:
                                                            return True

                                                        if self.is_ssa_present is not None:
                                                            return True

                                                        if self.is_tunnel_encap_present is not None:
                                                            return True

                                                        if self.l2tpv3_cookie is not None:
                                                            for child_ref in self.l2tpv3_cookie:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.l2tpv3_session_id is not None:
                                                            return True

                                                        if self.label_index_attr is not None:
                                                            for child_ref in self.label_index_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.local_preference is not None:
                                                            return True

                                                        if self.ls_attr is not None:
                                                            for child_ref in self.ls_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.metric is not None:
                                                            return True

                                                        if self.neighbor_as is not None:
                                                            return True

                                                        if self.origin is not None:
                                                            return True

                                                        if self.originator is not None:
                                                            return True

                                                        if self.pe_distinguisher_label is not None:
                                                            for child_ref in self.pe_distinguisher_label:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.pmsi_flags is not None:
                                                            return True

                                                        if self.pmsi_label is not None:
                                                            return True

                                                        if self.pmsi_type is not None:
                                                            return True

                                                        if self.pmsi_value is not None:
                                                            for child_ref in self.pmsi_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.ppm_pvalue is not None:
                                                            return True

                                                        if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_explicit_path is not None:
                                                            for child_ref in self.sr_policy_explicit_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.sr_policy_preference is not None:
                                                            return True

                                                        if self.sr_tunnel_request_state is not None:
                                                            return True

                                                        if self.sr_tunnel_state is not None:
                                                            return True

                                                        if self.tunnel_encap_type is not None:
                                                            return True

                                                        if self.unknown_attribute is not None:
                                                            for child_ref in self.unknown_attribute:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                                class AttrSet(object):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_encap_present
                                                    
                                                    	Tunnel Encap attribute present 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_policy_allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_binding_sid
                                                    
                                                    	SR Policy Binding sid
                                                    	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_explicit_path
                                                    
                                                    	SR Policy Explicit paths
                                                    	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                    
                                                    .. attribute:: sr_policy_preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_tunnel_request_state
                                                    
                                                    	SR Tunnel Request State
                                                    	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                    
                                                    .. attribute:: sr_tunnel_state
                                                    
                                                    	SR Tunnel State
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encap Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.aggregator_address = None
                                                        self.aggregator_as = None
                                                        self.aigp_metric_value = None
                                                        self.as_path = None
                                                        self.cluster = YList()
                                                        self.cluster.parent = self
                                                        self.cluster.name = 'cluster'
                                                        self.community = YList()
                                                        self.community.parent = self
                                                        self.community.name = 'community'
                                                        self.connector_type = None
                                                        self.connector_value = YList()
                                                        self.connector_value.parent = self
                                                        self.connector_value.name = 'connector_value'
                                                        self.extended_community = YList()
                                                        self.extended_community.parent = self
                                                        self.extended_community.name = 'extended_community'
                                                        self.extended_community_flags = None
                                                        self.is_aggregator_present = None
                                                        self.is_aigp_present = None
                                                        self.is_as_path_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_community_present = None
                                                        self.is_connector_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_label_index_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_metric_present = None
                                                        self.is_origin_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_ssa_present = None
                                                        self.is_tunnel_encap_present = None
                                                        self.l2tpv3_cookie = YList()
                                                        self.l2tpv3_cookie.parent = self
                                                        self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                        self.l2tpv3_session_id = None
                                                        self.label_index_attr = YList()
                                                        self.label_index_attr.parent = self
                                                        self.label_index_attr.name = 'label_index_attr'
                                                        self.local_preference = None
                                                        self.ls_attr = YList()
                                                        self.ls_attr.parent = self
                                                        self.ls_attr.name = 'ls_attr'
                                                        self.metric = None
                                                        self.neighbor_as = None
                                                        self.origin = None
                                                        self.originator = None
                                                        self.pe_distinguisher_label = YList()
                                                        self.pe_distinguisher_label.parent = self
                                                        self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.pmsi_type = None
                                                        self.pmsi_value = YList()
                                                        self.pmsi_value.parent = self
                                                        self.pmsi_value.name = 'pmsi_value'
                                                        self.ppm_pvalue = None
                                                        self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                        self.sr_policy_allocated_binding_sid.parent = self
                                                        self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                        self.sr_policy_binding_sid.parent = self
                                                        self.sr_policy_explicit_path = YList()
                                                        self.sr_policy_explicit_path.parent = self
                                                        self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                        self.sr_policy_preference = None
                                                        self.sr_tunnel_request_state = None
                                                        self.sr_tunnel_state = None
                                                        self.tunnel_encap_type = None
                                                        self.unknown_attribute = YList()
                                                        self.unknown_attribute.parent = self
                                                        self.unknown_attribute.name = 'unknown_attribute'


                                                    class SrPolicyBindingSid(object):
                                                        """
                                                        SR Policy Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                    class SrPolicyAllocatedBindingSid(object):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                    class Community(object):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                    class ExtendedCommunity(object):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                    class UnknownAttribute(object):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                    class Cluster(object):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                    class L2Tpv3Cookie(object):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                    class ConnectorValue(object):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                    class PmsiValue(object):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                    class LsAttr(object):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                    class LabelIndexAttr(object):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                    class PeDistinguisherLabel(object):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.label = None
                                                            self.pe_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.label is not None:
                                                                return True

                                                            if self.pe_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                    class SrPolicyExplicitPath(object):
                                                        """
                                                        SR Policy Explicit paths
                                                        
                                                        .. attribute:: sid
                                                        
                                                        	Sidlist for explicit path
                                                        	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of explicit path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.sid = YList()
                                                            self.sid.parent = self
                                                            self.sid.name = 'sid'
                                                            self.weight = None


                                                        class Sid(object):
                                                            """
                                                            Sidlist for explicit path
                                                            
                                                            .. attribute:: ipv4
                                                            
                                                            	IP Address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6
                                                            
                                                            	IPv6 address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label sid
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Sid Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4 = None
                                                                self.ipv6 = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4 is not None:
                                                                    return True

                                                                if self.ipv6 is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.sid is not None:
                                                                for child_ref in self.sid:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.weight is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.aggregator_address is not None:
                                                            return True

                                                        if self.aggregator_as is not None:
                                                            return True

                                                        if self.aigp_metric_value is not None:
                                                            return True

                                                        if self.as_path is not None:
                                                            return True

                                                        if self.cluster is not None:
                                                            for child_ref in self.cluster:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.community is not None:
                                                            for child_ref in self.community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.connector_type is not None:
                                                            return True

                                                        if self.connector_value is not None:
                                                            for child_ref in self.connector_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community is not None:
                                                            for child_ref in self.extended_community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community_flags is not None:
                                                            return True

                                                        if self.is_aggregator_present is not None:
                                                            return True

                                                        if self.is_aigp_present is not None:
                                                            return True

                                                        if self.is_as_path_present is not None:
                                                            return True

                                                        if self.is_atomic_aggregate_present is not None:
                                                            return True

                                                        if self.is_community_present is not None:
                                                            return True

                                                        if self.is_connector_present is not None:
                                                            return True

                                                        if self.is_extended_community_present is not None:
                                                            return True

                                                        if self.is_label_index_present is not None:
                                                            return True

                                                        if self.is_local_pref_present is not None:
                                                            return True

                                                        if self.is_ls_attribute_present is not None:
                                                            return True

                                                        if self.is_metric_present is not None:
                                                            return True

                                                        if self.is_origin_present is not None:
                                                            return True

                                                        if self.is_pe_distinguisher_label_present is not None:
                                                            return True

                                                        if self.is_pmsi_present is not None:
                                                            return True

                                                        if self.is_pppmp_present is not None:
                                                            return True

                                                        if self.is_ssa_present is not None:
                                                            return True

                                                        if self.is_tunnel_encap_present is not None:
                                                            return True

                                                        if self.l2tpv3_cookie is not None:
                                                            for child_ref in self.l2tpv3_cookie:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.l2tpv3_session_id is not None:
                                                            return True

                                                        if self.label_index_attr is not None:
                                                            for child_ref in self.label_index_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.local_preference is not None:
                                                            return True

                                                        if self.ls_attr is not None:
                                                            for child_ref in self.ls_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.metric is not None:
                                                            return True

                                                        if self.neighbor_as is not None:
                                                            return True

                                                        if self.origin is not None:
                                                            return True

                                                        if self.originator is not None:
                                                            return True

                                                        if self.pe_distinguisher_label is not None:
                                                            for child_ref in self.pe_distinguisher_label:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.pmsi_flags is not None:
                                                            return True

                                                        if self.pmsi_label is not None:
                                                            return True

                                                        if self.pmsi_type is not None:
                                                            return True

                                                        if self.pmsi_value is not None:
                                                            for child_ref in self.pmsi_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.ppm_pvalue is not None:
                                                            return True

                                                        if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_explicit_path is not None:
                                                            for child_ref in self.sr_policy_explicit_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.sr_policy_preference is not None:
                                                            return True

                                                        if self.sr_tunnel_request_state is not None:
                                                            return True

                                                        if self.sr_tunnel_state is not None:
                                                            return True

                                                        if self.tunnel_encap_type is not None:
                                                            return True

                                                        if self.unknown_attribute is not None:
                                                            for child_ref in self.unknown_attribute:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                                class RnhAddr(object):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.len = None
                                                        self.mac_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.len is not None:
                                                            return True

                                                        if self.mac_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                                class RibrnhIp(object):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.attr_set is not None and self.attr_set._has_data():
                                                        return True

                                                    if self.attribute_key_number is not None:
                                                        return True

                                                    if self.attribute_reuse_id_config is not None:
                                                        return True

                                                    if self.attribute_reuse_id_current is not None:
                                                        return True

                                                    if self.attribute_reuse_id_keys is not None:
                                                        return True

                                                    if self.attribute_reuse_id_max_id is not None:
                                                        return True

                                                    if self.attribute_reuse_id_node is not None:
                                                        return True

                                                    if self.attribute_reuse_id_recover_sec is not None:
                                                        return True

                                                    if self.common_attributes is not None and self.common_attributes._has_data():
                                                        return True

                                                    if self.is_application_gateway_present is not None:
                                                        return True

                                                    if self.is_as_path2_byte is not None:
                                                        return True

                                                    if self.is_attr_set_present is not None:
                                                        return True

                                                    if self.is_ribrnh_present is not None:
                                                        return True

                                                    if self.is_rnh_present is not None:
                                                        return True

                                                    if self.ribrnh_encap is not None:
                                                        return True

                                                    if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                        return True

                                                    if self.ribrnh_mac is not None:
                                                        return True

                                                    if self.ribrnh_table is not None:
                                                        return True

                                                    if self.ribrnh_vni is not None:
                                                        return True

                                                    if self.ribrnhip_table is not None:
                                                        return True

                                                    if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                        return True

                                                    if self.rnh_addr_len is not None:
                                                        return True

                                                    if self.rnh_len is not None:
                                                        return True

                                                    if self.rnh_type is not None:
                                                        return True

                                                    if self.set_aigp_inbound_igp is not None:
                                                        return True

                                                    if self.set_aigp_inbound_metric is not None:
                                                        return True

                                                    if self.vpn_distinguisher is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:paths'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.af_name is not None:
                                                    return True

                                                if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                    return True

                                                if self.label_fail is not None:
                                                    return True

                                                if self.label_o_or_version is not None:
                                                    return True

                                                if self.label_oor is not None:
                                                    return True

                                                if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                    return True

                                                if self.no_path is not None:
                                                    return True

                                                if self.path_information is not None and self.path_information._has_data():
                                                    return True

                                                if self.prefix_version is not None:
                                                    return True

                                                if self.process_instance_id is not None:
                                                    return True

                                                if self.route_distinguisher is not None:
                                                    return True

                                                if self.source_route_distinguisher is not None:
                                                    return True

                                                if self.source_vrf_name is not None:
                                                    return True

                                                if self.srcaf_name is not None:
                                                    return True

                                                if self.vrf_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths']['meta_info']


                                        class AdvPathInfo(object):
                                            """
                                            Net Advertized Paths
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: attributes_after_policy_in
                                            
                                            	Attributes after inbound policy
                                            	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn>`
                                            
                                            .. attribute:: attributes_after_policy_out
                                            
                                            	Attributes after outbound policy
                                            	**type**\:   :py:class:`AttributesAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut>`
                                            
                                            .. attribute:: neighbor_address_xr
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr>`
                                            
                                            .. attribute:: no_path
                                            
                                            	No path exists All 'sp\_path\_in' fields except 'sp\_path\_in\->bag\_prefix' are invalid.  All 'sp\_path\_out' fields are invalid
                                            	**type**\:  bool
                                            
                                            .. attribute:: path_info_after_policy_in
                                            
                                            	Path information after inbound policy
                                            	**type**\:   :py:class:`PathInfoAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn>`
                                            
                                            .. attribute:: path_info_after_policy_out
                                            
                                            	Path information after outbound policy
                                            	**type**\:   :py:class:`PathInfoAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut>`
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_route_distinguisher
                                            
                                            	Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.af_name = None
                                                self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn()
                                                self.attributes_after_policy_in.parent = self
                                                self.attributes_after_policy_out = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut()
                                                self.attributes_after_policy_out.parent = self
                                                self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr()
                                                self.neighbor_address_xr.parent = self
                                                self.no_path = None
                                                self.path_info_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn()
                                                self.path_info_after_policy_in.parent = self
                                                self.path_info_after_policy_out = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut()
                                                self.path_info_after_policy_out.parent = self
                                                self.route_distinguisher = None
                                                self.source_route_distinguisher = None
                                                self.vrf_name = None


                                            class NeighborAddressXr(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr']['meta_info']


                                            class PathInfoAfterPolicyIn(object):
                                                """
                                                Path information after inbound policy
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\:  bool
                                                
                                                .. attribute:: accept_own_self_originated_p_ath
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\:  bool
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield>`
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\:  bool
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner>`
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield>`
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix>`
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity>`
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\:  bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\:  bool
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr>`
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_esi
                                                
                                                	Path has EVPN ESI
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_rcvd_label
                                                
                                                	Path has received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\:  bool
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebg_ps
                                                
                                                	Not advertised to EBGPs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue>`
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2VpnEvpnEsi>`
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr>`
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue>`
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress>`
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop>`
                                                
                                                .. attribute:: nhte_tunnel
                                                
                                                	NH TE tunnel information
                                                	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhteTunnel>`
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\:  bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.accept_own_path = None
                                                    self.accept_own_self_originated_p_ath = None
                                                    self.add_path_orr_bitfield = YList()
                                                    self.add_path_orr_bitfield.parent = self
                                                    self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                    self.advertisedto_pe = None
                                                    self.aigp_metric = None
                                                    self.best_path_comp_stage = None
                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self.best_path_id = None
                                                    self.best_path_id_comp_winner = None
                                                    self.best_path_orr_bitfield = YList()
                                                    self.best_path_orr_bitfield.parent = self
                                                    self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self.dampen_penalty = None
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.fspec_invalid_path = None
                                                    self.graceful_shutdown = None
                                                    self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self.halflife_time = None
                                                    self.has_esi = None
                                                    self.has_gw_addr = None
                                                    self.has_local_net_label = None
                                                    self.has_mdt_group_addr = None
                                                    self.has_mvpn_extcomm = None
                                                    self.has_mvpn_nbr_addr = None
                                                    self.has_mvpn_nexthop_addr = None
                                                    self.has_mvpn_pmsi = None
                                                    self.has_rcvd_label = None
                                                    self.has_second_label = None
                                                    self.ibgp_signaled_validity = None
                                                    self.igp_metric = None
                                                    self.is_aggregation_suppressed = None
                                                    self.is_as_best = None
                                                    self.is_best_path = None
                                                    self.is_import_dampened = None
                                                    self.is_import_suspect = None
                                                    self.is_internal_path = None
                                                    self.is_partial_best = None
                                                    self.is_path_additional_path = None
                                                    self.is_path_advertised_local_as_only = None
                                                    self.is_path_af_install_eligible = None
                                                    self.is_path_backup = None
                                                    self.is_path_backup_protect_multipath = None
                                                    self.is_path_best_external = None
                                                    self.is_path_damped = None
                                                    self.is_path_from_confederation_peer = None
                                                    self.is_path_from_network_command = None
                                                    self.is_path_from_redistribute_command = None
                                                    self.is_path_from_route_reflector = None
                                                    self.is_path_history_held = None
                                                    self.is_path_imp_candidate = None
                                                    self.is_path_imported = None
                                                    self.is_path_local_aggregate = None
                                                    self.is_path_locally_sourced = None
                                                    self.is_path_long_lived_stale = None
                                                    self.is_path_multipath = None
                                                    self.is_path_nexthop_discarded = None
                                                    self.is_path_not_advertised = None
                                                    self.is_path_not_advertised_to_ebg_ps = None
                                                    self.is_path_received_only = None
                                                    self.is_path_reoriginated = None
                                                    self.is_path_reoriginated_stitching = None
                                                    self.is_path_stale = None
                                                    self.is_path_synced_with_igp = None
                                                    self.is_path_valid = None
                                                    self.is_path_vpn_only = None
                                                    self.is_permanent_path = None
                                                    self.is_received_path_not_modified = None
                                                    self.is_spkr_as_best = None
                                                    self.l2vpn_circuit_status_value = YList()
                                                    self.l2vpn_circuit_status_value.parent = self
                                                    self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                    self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2VpnEvpnEsi()
                                                    self.l2vpn_evpn_esi.parent = self
                                                    self.l2vpn_size = None
                                                    self.labeled_unicast_safi_path = None
                                                    self.local_label = None
                                                    self.local_nh = None
                                                    self.local_path_id = None
                                                    self.local_peers_advertised_to = YList()
                                                    self.local_peers_advertised_to.parent = self
                                                    self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                    self.maximum_suppress_time = None
                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self.mvpn_path_flags = None
                                                    self.mvpn_pmsi_flags = None
                                                    self.mvpn_pmsi_label = None
                                                    self.mvpn_pmsi_type = None
                                                    self.mvpn_pmsi_value = YList()
                                                    self.mvpn_pmsi_value.parent = self
                                                    self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                    self.mvpn_sfs_path = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.neighbor_router_id = None
                                                    self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop()
                                                    self.next_hop.parent = self
                                                    self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhteTunnel()
                                                    self.nhte_tunnel.parent = self
                                                    self.path_flags = None
                                                    self.path_flap_count = None
                                                    self.path_import_flags = None
                                                    self.path_rt_set_id = None
                                                    self.path_rt_set_route_count = None
                                                    self.path_table_version = None
                                                    self.path_weight = None
                                                    self.pe_peers_advertised_to = YList()
                                                    self.pe_peers_advertised_to.parent = self
                                                    self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                    self.rcvd_label = None
                                                    self.rcvd_path_id = None
                                                    self.reuse_value = None
                                                    self.rib_failed = None
                                                    self.route_type = None
                                                    self.rpki_origin_as_validation_disabled = None
                                                    self.rt_set_limit_enabled = None
                                                    self.second_label = None
                                                    self.seconds_since_first_flap = None
                                                    self.show_rpki_origin_as_validity = None
                                                    self.sn_rpki_origin_as_validity = None
                                                    self.suppress_penalty = None
                                                    self.time_to_unsuppress = None


                                                class BgpPrefix(object):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self.prefix_length = None


                                                    class Prefix(object):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.prefix is not None and self.prefix._has_data():
                                                            return True

                                                        if self.prefix_length is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix']['meta_info']


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress']['meta_info']


                                                class NextHop(object):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop']['meta_info']


                                                class NhteTunnel(object):
                                                    """
                                                    NH TE tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_te_tunnel
                                                    
                                                    	NH TE Tunnel info is present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last rib update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	tunnel name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	tunnel type
                                                    	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.binding_label = None
                                                        self.has_te_tunnel = None
                                                        self.is_tunnel_info_stale = None
                                                        self.is_tunnel_registered = None
                                                        self.is_tunnel_up = None
                                                        self.last_tunnel_update = None
                                                        self.tunnel_if_handle = None
                                                        self.tunnel_name = None
                                                        self.tunnel_type = None
                                                        self.tunnel_v6_enabled = None
                                                        self.tunnel_v6_required = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.binding_label is not None:
                                                            return True

                                                        if self.has_te_tunnel is not None:
                                                            return True

                                                        if self.is_tunnel_info_stale is not None:
                                                            return True

                                                        if self.is_tunnel_registered is not None:
                                                            return True

                                                        if self.is_tunnel_up is not None:
                                                            return True

                                                        if self.last_tunnel_update is not None:
                                                            return True

                                                        if self.tunnel_if_handle is not None:
                                                            return True

                                                        if self.tunnel_name is not None:
                                                            return True

                                                        if self.tunnel_type is not None:
                                                            return True

                                                        if self.tunnel_v6_enabled is not None:
                                                            return True

                                                        if self.tunnel_v6_required is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhteTunnel']['meta_info']


                                                class MdtGroupAddr(object):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr']['meta_info']


                                                class L2VpnEvpnEsi(object):
                                                    """
                                                    L2VPN EVPN ESI
                                                    
                                                    .. attribute:: esi
                                                    
                                                    	esi
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.esi = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.esi is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2VpnEvpnEsi']['meta_info']


                                                class GwAddr(object):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.len = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.len is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr']['meta_info']


                                                class BestPathCompWinner(object):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner']['meta_info']


                                                class MvpnNbrAddr(object):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr']['meta_info']


                                                class MvpnNexthopAddr(object):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr']['meta_info']


                                                class L2VpnCircuitStatusValue(object):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue']['meta_info']


                                                class MvpnPmsiValue(object):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity']['meta_info']


                                                class LocalPeersAdvertisedTo(object):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo']['meta_info']


                                                class PePeersAdvertisedTo(object):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo']['meta_info']


                                                class BestPathOrrBitfield(object):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield']['meta_info']


                                                class AddPathOrrBitfield(object):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-info-after-policy-in'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.accept_own_path is not None:
                                                        return True

                                                    if self.accept_own_self_originated_p_ath is not None:
                                                        return True

                                                    if self.add_path_orr_bitfield is not None:
                                                        for child_ref in self.add_path_orr_bitfield:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.advertisedto_pe is not None:
                                                        return True

                                                    if self.aigp_metric is not None:
                                                        return True

                                                    if self.best_path_comp_stage is not None:
                                                        return True

                                                    if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                        return True

                                                    if self.best_path_id is not None:
                                                        return True

                                                    if self.best_path_id_comp_winner is not None:
                                                        return True

                                                    if self.best_path_orr_bitfield is not None:
                                                        for child_ref in self.best_path_orr_bitfield:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                        return True

                                                    if self.dampen_penalty is not None:
                                                        return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.fspec_invalid_path is not None:
                                                        return True

                                                    if self.graceful_shutdown is not None:
                                                        return True

                                                    if self.gw_addr is not None and self.gw_addr._has_data():
                                                        return True

                                                    if self.halflife_time is not None:
                                                        return True

                                                    if self.has_esi is not None:
                                                        return True

                                                    if self.has_gw_addr is not None:
                                                        return True

                                                    if self.has_local_net_label is not None:
                                                        return True

                                                    if self.has_mdt_group_addr is not None:
                                                        return True

                                                    if self.has_mvpn_extcomm is not None:
                                                        return True

                                                    if self.has_mvpn_nbr_addr is not None:
                                                        return True

                                                    if self.has_mvpn_nexthop_addr is not None:
                                                        return True

                                                    if self.has_mvpn_pmsi is not None:
                                                        return True

                                                    if self.has_rcvd_label is not None:
                                                        return True

                                                    if self.has_second_label is not None:
                                                        return True

                                                    if self.ibgp_signaled_validity is not None:
                                                        return True

                                                    if self.igp_metric is not None:
                                                        return True

                                                    if self.is_aggregation_suppressed is not None:
                                                        return True

                                                    if self.is_as_best is not None:
                                                        return True

                                                    if self.is_best_path is not None:
                                                        return True

                                                    if self.is_import_dampened is not None:
                                                        return True

                                                    if self.is_import_suspect is not None:
                                                        return True

                                                    if self.is_internal_path is not None:
                                                        return True

                                                    if self.is_partial_best is not None:
                                                        return True

                                                    if self.is_path_additional_path is not None:
                                                        return True

                                                    if self.is_path_advertised_local_as_only is not None:
                                                        return True

                                                    if self.is_path_af_install_eligible is not None:
                                                        return True

                                                    if self.is_path_backup is not None:
                                                        return True

                                                    if self.is_path_backup_protect_multipath is not None:
                                                        return True

                                                    if self.is_path_best_external is not None:
                                                        return True

                                                    if self.is_path_damped is not None:
                                                        return True

                                                    if self.is_path_from_confederation_peer is not None:
                                                        return True

                                                    if self.is_path_from_network_command is not None:
                                                        return True

                                                    if self.is_path_from_redistribute_command is not None:
                                                        return True

                                                    if self.is_path_from_route_reflector is not None:
                                                        return True

                                                    if self.is_path_history_held is not None:
                                                        return True

                                                    if self.is_path_imp_candidate is not None:
                                                        return True

                                                    if self.is_path_imported is not None:
                                                        return True

                                                    if self.is_path_local_aggregate is not None:
                                                        return True

                                                    if self.is_path_locally_sourced is not None:
                                                        return True

                                                    if self.is_path_long_lived_stale is not None:
                                                        return True

                                                    if self.is_path_multipath is not None:
                                                        return True

                                                    if self.is_path_nexthop_discarded is not None:
                                                        return True

                                                    if self.is_path_not_advertised is not None:
                                                        return True

                                                    if self.is_path_not_advertised_to_ebg_ps is not None:
                                                        return True

                                                    if self.is_path_received_only is not None:
                                                        return True

                                                    if self.is_path_reoriginated is not None:
                                                        return True

                                                    if self.is_path_reoriginated_stitching is not None:
                                                        return True

                                                    if self.is_path_stale is not None:
                                                        return True

                                                    if self.is_path_synced_with_igp is not None:
                                                        return True

                                                    if self.is_path_valid is not None:
                                                        return True

                                                    if self.is_path_vpn_only is not None:
                                                        return True

                                                    if self.is_permanent_path is not None:
                                                        return True

                                                    if self.is_received_path_not_modified is not None:
                                                        return True

                                                    if self.is_spkr_as_best is not None:
                                                        return True

                                                    if self.l2vpn_circuit_status_value is not None:
                                                        for child_ref in self.l2vpn_circuit_status_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                        return True

                                                    if self.l2vpn_size is not None:
                                                        return True

                                                    if self.labeled_unicast_safi_path is not None:
                                                        return True

                                                    if self.local_label is not None:
                                                        return True

                                                    if self.local_nh is not None:
                                                        return True

                                                    if self.local_path_id is not None:
                                                        return True

                                                    if self.local_peers_advertised_to is not None:
                                                        for child_ref in self.local_peers_advertised_to:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.maximum_suppress_time is not None:
                                                        return True

                                                    if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                        return True

                                                    if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                        return True

                                                    if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                        return True

                                                    if self.mvpn_path_flags is not None:
                                                        return True

                                                    if self.mvpn_pmsi_flags is not None:
                                                        return True

                                                    if self.mvpn_pmsi_label is not None:
                                                        return True

                                                    if self.mvpn_pmsi_type is not None:
                                                        return True

                                                    if self.mvpn_pmsi_value is not None:
                                                        for child_ref in self.mvpn_pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.mvpn_sfs_path is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.neighbor_router_id is not None:
                                                        return True

                                                    if self.next_hop is not None and self.next_hop._has_data():
                                                        return True

                                                    if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                        return True

                                                    if self.path_flags is not None:
                                                        return True

                                                    if self.path_flap_count is not None:
                                                        return True

                                                    if self.path_import_flags is not None:
                                                        return True

                                                    if self.path_rt_set_id is not None:
                                                        return True

                                                    if self.path_rt_set_route_count is not None:
                                                        return True

                                                    if self.path_table_version is not None:
                                                        return True

                                                    if self.path_weight is not None:
                                                        return True

                                                    if self.pe_peers_advertised_to is not None:
                                                        for child_ref in self.pe_peers_advertised_to:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.rcvd_label is not None:
                                                        return True

                                                    if self.rcvd_path_id is not None:
                                                        return True

                                                    if self.reuse_value is not None:
                                                        return True

                                                    if self.rib_failed is not None:
                                                        return True

                                                    if self.route_type is not None:
                                                        return True

                                                    if self.rpki_origin_as_validation_disabled is not None:
                                                        return True

                                                    if self.rt_set_limit_enabled is not None:
                                                        return True

                                                    if self.second_label is not None:
                                                        return True

                                                    if self.seconds_since_first_flap is not None:
                                                        return True

                                                    if self.show_rpki_origin_as_validity is not None:
                                                        return True

                                                    if self.sn_rpki_origin_as_validity is not None:
                                                        return True

                                                    if self.suppress_penalty is not None:
                                                        return True

                                                    if self.time_to_unsuppress is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn']['meta_info']


                                            class PathInfoAfterPolicyOut(object):
                                                """
                                                Path information after outbound policy
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\:  bool
                                                
                                                .. attribute:: accept_own_self_originated_p_ath
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\:  bool
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield>`
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\:  bool
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner>`
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield>`
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix>`
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity>`
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\:  bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\:  bool
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr>`
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_esi
                                                
                                                	Path has EVPN ESI
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_rcvd_label
                                                
                                                	Path has received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\:  bool
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebg_ps
                                                
                                                	Not advertised to EBGPs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue>`
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2VpnEvpnEsi>`
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr>`
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue>`
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress>`
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop>`
                                                
                                                .. attribute:: nhte_tunnel
                                                
                                                	NH TE tunnel information
                                                	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhteTunnel>`
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\:  bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.accept_own_path = None
                                                    self.accept_own_self_originated_p_ath = None
                                                    self.add_path_orr_bitfield = YList()
                                                    self.add_path_orr_bitfield.parent = self
                                                    self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                    self.advertisedto_pe = None
                                                    self.aigp_metric = None
                                                    self.best_path_comp_stage = None
                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self.best_path_id = None
                                                    self.best_path_id_comp_winner = None
                                                    self.best_path_orr_bitfield = YList()
                                                    self.best_path_orr_bitfield.parent = self
                                                    self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self.dampen_penalty = None
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.fspec_invalid_path = None
                                                    self.graceful_shutdown = None
                                                    self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self.halflife_time = None
                                                    self.has_esi = None
                                                    self.has_gw_addr = None
                                                    self.has_local_net_label = None
                                                    self.has_mdt_group_addr = None
                                                    self.has_mvpn_extcomm = None
                                                    self.has_mvpn_nbr_addr = None
                                                    self.has_mvpn_nexthop_addr = None
                                                    self.has_mvpn_pmsi = None
                                                    self.has_rcvd_label = None
                                                    self.has_second_label = None
                                                    self.ibgp_signaled_validity = None
                                                    self.igp_metric = None
                                                    self.is_aggregation_suppressed = None
                                                    self.is_as_best = None
                                                    self.is_best_path = None
                                                    self.is_import_dampened = None
                                                    self.is_import_suspect = None
                                                    self.is_internal_path = None
                                                    self.is_partial_best = None
                                                    self.is_path_additional_path = None
                                                    self.is_path_advertised_local_as_only = None
                                                    self.is_path_af_install_eligible = None
                                                    self.is_path_backup = None
                                                    self.is_path_backup_protect_multipath = None
                                                    self.is_path_best_external = None
                                                    self.is_path_damped = None
                                                    self.is_path_from_confederation_peer = None
                                                    self.is_path_from_network_command = None
                                                    self.is_path_from_redistribute_command = None
                                                    self.is_path_from_route_reflector = None
                                                    self.is_path_history_held = None
                                                    self.is_path_imp_candidate = None
                                                    self.is_path_imported = None
                                                    self.is_path_local_aggregate = None
                                                    self.is_path_locally_sourced = None
                                                    self.is_path_long_lived_stale = None
                                                    self.is_path_multipath = None
                                                    self.is_path_nexthop_discarded = None
                                                    self.is_path_not_advertised = None
                                                    self.is_path_not_advertised_to_ebg_ps = None
                                                    self.is_path_received_only = None
                                                    self.is_path_reoriginated = None
                                                    self.is_path_reoriginated_stitching = None
                                                    self.is_path_stale = None
                                                    self.is_path_synced_with_igp = None
                                                    self.is_path_valid = None
                                                    self.is_path_vpn_only = None
                                                    self.is_permanent_path = None
                                                    self.is_received_path_not_modified = None
                                                    self.is_spkr_as_best = None
                                                    self.l2vpn_circuit_status_value = YList()
                                                    self.l2vpn_circuit_status_value.parent = self
                                                    self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                    self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2VpnEvpnEsi()
                                                    self.l2vpn_evpn_esi.parent = self
                                                    self.l2vpn_size = None
                                                    self.labeled_unicast_safi_path = None
                                                    self.local_label = None
                                                    self.local_nh = None
                                                    self.local_path_id = None
                                                    self.local_peers_advertised_to = YList()
                                                    self.local_peers_advertised_to.parent = self
                                                    self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                    self.maximum_suppress_time = None
                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self.mvpn_path_flags = None
                                                    self.mvpn_pmsi_flags = None
                                                    self.mvpn_pmsi_label = None
                                                    self.mvpn_pmsi_type = None
                                                    self.mvpn_pmsi_value = YList()
                                                    self.mvpn_pmsi_value.parent = self
                                                    self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                    self.mvpn_sfs_path = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.neighbor_router_id = None
                                                    self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop()
                                                    self.next_hop.parent = self
                                                    self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhteTunnel()
                                                    self.nhte_tunnel.parent = self
                                                    self.path_flags = None
                                                    self.path_flap_count = None
                                                    self.path_import_flags = None
                                                    self.path_rt_set_id = None
                                                    self.path_rt_set_route_count = None
                                                    self.path_table_version = None
                                                    self.path_weight = None
                                                    self.pe_peers_advertised_to = YList()
                                                    self.pe_peers_advertised_to.parent = self
                                                    self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                    self.rcvd_label = None
                                                    self.rcvd_path_id = None
                                                    self.reuse_value = None
                                                    self.rib_failed = None
                                                    self.route_type = None
                                                    self.rpki_origin_as_validation_disabled = None
                                                    self.rt_set_limit_enabled = None
                                                    self.second_label = None
                                                    self.seconds_since_first_flap = None
                                                    self.show_rpki_origin_as_validity = None
                                                    self.sn_rpki_origin_as_validity = None
                                                    self.suppress_penalty = None
                                                    self.time_to_unsuppress = None


                                                class BgpPrefix(object):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self.prefix_length = None


                                                    class Prefix(object):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.prefix is not None and self.prefix._has_data():
                                                            return True

                                                        if self.prefix_length is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix']['meta_info']


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress']['meta_info']


                                                class NextHop(object):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop']['meta_info']


                                                class NhteTunnel(object):
                                                    """
                                                    NH TE tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_te_tunnel
                                                    
                                                    	NH TE Tunnel info is present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last rib update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	tunnel name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	tunnel type
                                                    	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.binding_label = None
                                                        self.has_te_tunnel = None
                                                        self.is_tunnel_info_stale = None
                                                        self.is_tunnel_registered = None
                                                        self.is_tunnel_up = None
                                                        self.last_tunnel_update = None
                                                        self.tunnel_if_handle = None
                                                        self.tunnel_name = None
                                                        self.tunnel_type = None
                                                        self.tunnel_v6_enabled = None
                                                        self.tunnel_v6_required = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.binding_label is not None:
                                                            return True

                                                        if self.has_te_tunnel is not None:
                                                            return True

                                                        if self.is_tunnel_info_stale is not None:
                                                            return True

                                                        if self.is_tunnel_registered is not None:
                                                            return True

                                                        if self.is_tunnel_up is not None:
                                                            return True

                                                        if self.last_tunnel_update is not None:
                                                            return True

                                                        if self.tunnel_if_handle is not None:
                                                            return True

                                                        if self.tunnel_name is not None:
                                                            return True

                                                        if self.tunnel_type is not None:
                                                            return True

                                                        if self.tunnel_v6_enabled is not None:
                                                            return True

                                                        if self.tunnel_v6_required is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhteTunnel']['meta_info']


                                                class MdtGroupAddr(object):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr']['meta_info']


                                                class L2VpnEvpnEsi(object):
                                                    """
                                                    L2VPN EVPN ESI
                                                    
                                                    .. attribute:: esi
                                                    
                                                    	esi
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.esi = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.esi is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2VpnEvpnEsi']['meta_info']


                                                class GwAddr(object):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.len = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.len is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr']['meta_info']


                                                class BestPathCompWinner(object):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner']['meta_info']


                                                class MvpnNbrAddr(object):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr']['meta_info']


                                                class MvpnNexthopAddr(object):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr']['meta_info']


                                                class L2VpnCircuitStatusValue(object):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue']['meta_info']


                                                class MvpnPmsiValue(object):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity']['meta_info']


                                                class LocalPeersAdvertisedTo(object):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo']['meta_info']


                                                class PePeersAdvertisedTo(object):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo']['meta_info']


                                                class BestPathOrrBitfield(object):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield']['meta_info']


                                                class AddPathOrrBitfield(object):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-info-after-policy-out'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.accept_own_path is not None:
                                                        return True

                                                    if self.accept_own_self_originated_p_ath is not None:
                                                        return True

                                                    if self.add_path_orr_bitfield is not None:
                                                        for child_ref in self.add_path_orr_bitfield:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.advertisedto_pe is not None:
                                                        return True

                                                    if self.aigp_metric is not None:
                                                        return True

                                                    if self.best_path_comp_stage is not None:
                                                        return True

                                                    if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                        return True

                                                    if self.best_path_id is not None:
                                                        return True

                                                    if self.best_path_id_comp_winner is not None:
                                                        return True

                                                    if self.best_path_orr_bitfield is not None:
                                                        for child_ref in self.best_path_orr_bitfield:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                        return True

                                                    if self.dampen_penalty is not None:
                                                        return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.fspec_invalid_path is not None:
                                                        return True

                                                    if self.graceful_shutdown is not None:
                                                        return True

                                                    if self.gw_addr is not None and self.gw_addr._has_data():
                                                        return True

                                                    if self.halflife_time is not None:
                                                        return True

                                                    if self.has_esi is not None:
                                                        return True

                                                    if self.has_gw_addr is not None:
                                                        return True

                                                    if self.has_local_net_label is not None:
                                                        return True

                                                    if self.has_mdt_group_addr is not None:
                                                        return True

                                                    if self.has_mvpn_extcomm is not None:
                                                        return True

                                                    if self.has_mvpn_nbr_addr is not None:
                                                        return True

                                                    if self.has_mvpn_nexthop_addr is not None:
                                                        return True

                                                    if self.has_mvpn_pmsi is not None:
                                                        return True

                                                    if self.has_rcvd_label is not None:
                                                        return True

                                                    if self.has_second_label is not None:
                                                        return True

                                                    if self.ibgp_signaled_validity is not None:
                                                        return True

                                                    if self.igp_metric is not None:
                                                        return True

                                                    if self.is_aggregation_suppressed is not None:
                                                        return True

                                                    if self.is_as_best is not None:
                                                        return True

                                                    if self.is_best_path is not None:
                                                        return True

                                                    if self.is_import_dampened is not None:
                                                        return True

                                                    if self.is_import_suspect is not None:
                                                        return True

                                                    if self.is_internal_path is not None:
                                                        return True

                                                    if self.is_partial_best is not None:
                                                        return True

                                                    if self.is_path_additional_path is not None:
                                                        return True

                                                    if self.is_path_advertised_local_as_only is not None:
                                                        return True

                                                    if self.is_path_af_install_eligible is not None:
                                                        return True

                                                    if self.is_path_backup is not None:
                                                        return True

                                                    if self.is_path_backup_protect_multipath is not None:
                                                        return True

                                                    if self.is_path_best_external is not None:
                                                        return True

                                                    if self.is_path_damped is not None:
                                                        return True

                                                    if self.is_path_from_confederation_peer is not None:
                                                        return True

                                                    if self.is_path_from_network_command is not None:
                                                        return True

                                                    if self.is_path_from_redistribute_command is not None:
                                                        return True

                                                    if self.is_path_from_route_reflector is not None:
                                                        return True

                                                    if self.is_path_history_held is not None:
                                                        return True

                                                    if self.is_path_imp_candidate is not None:
                                                        return True

                                                    if self.is_path_imported is not None:
                                                        return True

                                                    if self.is_path_local_aggregate is not None:
                                                        return True

                                                    if self.is_path_locally_sourced is not None:
                                                        return True

                                                    if self.is_path_long_lived_stale is not None:
                                                        return True

                                                    if self.is_path_multipath is not None:
                                                        return True

                                                    if self.is_path_nexthop_discarded is not None:
                                                        return True

                                                    if self.is_path_not_advertised is not None:
                                                        return True

                                                    if self.is_path_not_advertised_to_ebg_ps is not None:
                                                        return True

                                                    if self.is_path_received_only is not None:
                                                        return True

                                                    if self.is_path_reoriginated is not None:
                                                        return True

                                                    if self.is_path_reoriginated_stitching is not None:
                                                        return True

                                                    if self.is_path_stale is not None:
                                                        return True

                                                    if self.is_path_synced_with_igp is not None:
                                                        return True

                                                    if self.is_path_valid is not None:
                                                        return True

                                                    if self.is_path_vpn_only is not None:
                                                        return True

                                                    if self.is_permanent_path is not None:
                                                        return True

                                                    if self.is_received_path_not_modified is not None:
                                                        return True

                                                    if self.is_spkr_as_best is not None:
                                                        return True

                                                    if self.l2vpn_circuit_status_value is not None:
                                                        for child_ref in self.l2vpn_circuit_status_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                        return True

                                                    if self.l2vpn_size is not None:
                                                        return True

                                                    if self.labeled_unicast_safi_path is not None:
                                                        return True

                                                    if self.local_label is not None:
                                                        return True

                                                    if self.local_nh is not None:
                                                        return True

                                                    if self.local_path_id is not None:
                                                        return True

                                                    if self.local_peers_advertised_to is not None:
                                                        for child_ref in self.local_peers_advertised_to:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.maximum_suppress_time is not None:
                                                        return True

                                                    if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                        return True

                                                    if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                        return True

                                                    if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                        return True

                                                    if self.mvpn_path_flags is not None:
                                                        return True

                                                    if self.mvpn_pmsi_flags is not None:
                                                        return True

                                                    if self.mvpn_pmsi_label is not None:
                                                        return True

                                                    if self.mvpn_pmsi_type is not None:
                                                        return True

                                                    if self.mvpn_pmsi_value is not None:
                                                        for child_ref in self.mvpn_pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.mvpn_sfs_path is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.neighbor_router_id is not None:
                                                        return True

                                                    if self.next_hop is not None and self.next_hop._has_data():
                                                        return True

                                                    if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                        return True

                                                    if self.path_flags is not None:
                                                        return True

                                                    if self.path_flap_count is not None:
                                                        return True

                                                    if self.path_import_flags is not None:
                                                        return True

                                                    if self.path_rt_set_id is not None:
                                                        return True

                                                    if self.path_rt_set_route_count is not None:
                                                        return True

                                                    if self.path_table_version is not None:
                                                        return True

                                                    if self.path_weight is not None:
                                                        return True

                                                    if self.pe_peers_advertised_to is not None:
                                                        for child_ref in self.pe_peers_advertised_to:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.rcvd_label is not None:
                                                        return True

                                                    if self.rcvd_path_id is not None:
                                                        return True

                                                    if self.reuse_value is not None:
                                                        return True

                                                    if self.rib_failed is not None:
                                                        return True

                                                    if self.route_type is not None:
                                                        return True

                                                    if self.rpki_origin_as_validation_disabled is not None:
                                                        return True

                                                    if self.rt_set_limit_enabled is not None:
                                                        return True

                                                    if self.second_label is not None:
                                                        return True

                                                    if self.seconds_since_first_flap is not None:
                                                        return True

                                                    if self.show_rpki_origin_as_validity is not None:
                                                        return True

                                                    if self.sn_rpki_origin_as_validity is not None:
                                                        return True

                                                    if self.suppress_penalty is not None:
                                                        return True

                                                    if self.time_to_unsuppress is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut']['meta_info']


                                            class AttributesAfterPolicyIn(object):
                                                """
                                                Attributes after inbound policy
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet>`
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes>`
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp>`
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr>`
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\:  bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\:  bool
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet()
                                                    self.attr_set.parent = self
                                                    self.attribute_key_number = None
                                                    self.attribute_reuse_id_config = None
                                                    self.attribute_reuse_id_current = None
                                                    self.attribute_reuse_id_keys = None
                                                    self.attribute_reuse_id_max_id = None
                                                    self.attribute_reuse_id_node = None
                                                    self.attribute_reuse_id_recover_sec = None
                                                    self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self.is_application_gateway_present = None
                                                    self.is_as_path2_byte = None
                                                    self.is_attr_set_present = None
                                                    self.is_ribrnh_present = None
                                                    self.is_rnh_present = None
                                                    self.ribrnh_encap = None
                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self.ribrnh_mac = None
                                                    self.ribrnh_table = None
                                                    self.ribrnh_vni = None
                                                    self.ribrnhip_table = None
                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self.rnh_addr_len = None
                                                    self.rnh_len = None
                                                    self.rnh_type = None
                                                    self.set_aigp_inbound_igp = None
                                                    self.set_aigp_inbound_metric = None
                                                    self.vpn_distinguisher = None


                                                class CommonAttributes(object):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_encap_present
                                                    
                                                    	Tunnel Encap attribute present 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_policy_allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_binding_sid
                                                    
                                                    	SR Policy Binding sid
                                                    	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_explicit_path
                                                    
                                                    	SR Policy Explicit paths
                                                    	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                    
                                                    .. attribute:: sr_policy_preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_tunnel_request_state
                                                    
                                                    	SR Tunnel Request State
                                                    	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                    
                                                    .. attribute:: sr_tunnel_state
                                                    
                                                    	SR Tunnel State
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encap Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.aggregator_address = None
                                                        self.aggregator_as = None
                                                        self.aigp_metric_value = None
                                                        self.as_path = None
                                                        self.cluster = YList()
                                                        self.cluster.parent = self
                                                        self.cluster.name = 'cluster'
                                                        self.community = YList()
                                                        self.community.parent = self
                                                        self.community.name = 'community'
                                                        self.connector_type = None
                                                        self.connector_value = YList()
                                                        self.connector_value.parent = self
                                                        self.connector_value.name = 'connector_value'
                                                        self.extended_community = YList()
                                                        self.extended_community.parent = self
                                                        self.extended_community.name = 'extended_community'
                                                        self.extended_community_flags = None
                                                        self.is_aggregator_present = None
                                                        self.is_aigp_present = None
                                                        self.is_as_path_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_community_present = None
                                                        self.is_connector_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_label_index_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_metric_present = None
                                                        self.is_origin_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_ssa_present = None
                                                        self.is_tunnel_encap_present = None
                                                        self.l2tpv3_cookie = YList()
                                                        self.l2tpv3_cookie.parent = self
                                                        self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                        self.l2tpv3_session_id = None
                                                        self.label_index_attr = YList()
                                                        self.label_index_attr.parent = self
                                                        self.label_index_attr.name = 'label_index_attr'
                                                        self.local_preference = None
                                                        self.ls_attr = YList()
                                                        self.ls_attr.parent = self
                                                        self.ls_attr.name = 'ls_attr'
                                                        self.metric = None
                                                        self.neighbor_as = None
                                                        self.origin = None
                                                        self.originator = None
                                                        self.pe_distinguisher_label = YList()
                                                        self.pe_distinguisher_label.parent = self
                                                        self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.pmsi_type = None
                                                        self.pmsi_value = YList()
                                                        self.pmsi_value.parent = self
                                                        self.pmsi_value.name = 'pmsi_value'
                                                        self.ppm_pvalue = None
                                                        self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                        self.sr_policy_allocated_binding_sid.parent = self
                                                        self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                        self.sr_policy_binding_sid.parent = self
                                                        self.sr_policy_explicit_path = YList()
                                                        self.sr_policy_explicit_path.parent = self
                                                        self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                        self.sr_policy_preference = None
                                                        self.sr_tunnel_request_state = None
                                                        self.sr_tunnel_state = None
                                                        self.tunnel_encap_type = None
                                                        self.unknown_attribute = YList()
                                                        self.unknown_attribute.parent = self
                                                        self.unknown_attribute.name = 'unknown_attribute'


                                                    class SrPolicyBindingSid(object):
                                                        """
                                                        SR Policy Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                    class SrPolicyAllocatedBindingSid(object):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                    class Community(object):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                    class ExtendedCommunity(object):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                    class UnknownAttribute(object):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                    class Cluster(object):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                    class L2Tpv3Cookie(object):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                    class ConnectorValue(object):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                    class PmsiValue(object):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                    class LsAttr(object):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                    class LabelIndexAttr(object):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                    class PeDistinguisherLabel(object):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.label = None
                                                            self.pe_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.label is not None:
                                                                return True

                                                            if self.pe_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                    class SrPolicyExplicitPath(object):
                                                        """
                                                        SR Policy Explicit paths
                                                        
                                                        .. attribute:: sid
                                                        
                                                        	Sidlist for explicit path
                                                        	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of explicit path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.sid = YList()
                                                            self.sid.parent = self
                                                            self.sid.name = 'sid'
                                                            self.weight = None


                                                        class Sid(object):
                                                            """
                                                            Sidlist for explicit path
                                                            
                                                            .. attribute:: ipv4
                                                            
                                                            	IP Address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6
                                                            
                                                            	IPv6 address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label sid
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Sid Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4 = None
                                                                self.ipv6 = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4 is not None:
                                                                    return True

                                                                if self.ipv6 is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.sid is not None:
                                                                for child_ref in self.sid:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.weight is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.aggregator_address is not None:
                                                            return True

                                                        if self.aggregator_as is not None:
                                                            return True

                                                        if self.aigp_metric_value is not None:
                                                            return True

                                                        if self.as_path is not None:
                                                            return True

                                                        if self.cluster is not None:
                                                            for child_ref in self.cluster:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.community is not None:
                                                            for child_ref in self.community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.connector_type is not None:
                                                            return True

                                                        if self.connector_value is not None:
                                                            for child_ref in self.connector_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community is not None:
                                                            for child_ref in self.extended_community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community_flags is not None:
                                                            return True

                                                        if self.is_aggregator_present is not None:
                                                            return True

                                                        if self.is_aigp_present is not None:
                                                            return True

                                                        if self.is_as_path_present is not None:
                                                            return True

                                                        if self.is_atomic_aggregate_present is not None:
                                                            return True

                                                        if self.is_community_present is not None:
                                                            return True

                                                        if self.is_connector_present is not None:
                                                            return True

                                                        if self.is_extended_community_present is not None:
                                                            return True

                                                        if self.is_label_index_present is not None:
                                                            return True

                                                        if self.is_local_pref_present is not None:
                                                            return True

                                                        if self.is_ls_attribute_present is not None:
                                                            return True

                                                        if self.is_metric_present is not None:
                                                            return True

                                                        if self.is_origin_present is not None:
                                                            return True

                                                        if self.is_pe_distinguisher_label_present is not None:
                                                            return True

                                                        if self.is_pmsi_present is not None:
                                                            return True

                                                        if self.is_pppmp_present is not None:
                                                            return True

                                                        if self.is_ssa_present is not None:
                                                            return True

                                                        if self.is_tunnel_encap_present is not None:
                                                            return True

                                                        if self.l2tpv3_cookie is not None:
                                                            for child_ref in self.l2tpv3_cookie:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.l2tpv3_session_id is not None:
                                                            return True

                                                        if self.label_index_attr is not None:
                                                            for child_ref in self.label_index_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.local_preference is not None:
                                                            return True

                                                        if self.ls_attr is not None:
                                                            for child_ref in self.ls_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.metric is not None:
                                                            return True

                                                        if self.neighbor_as is not None:
                                                            return True

                                                        if self.origin is not None:
                                                            return True

                                                        if self.originator is not None:
                                                            return True

                                                        if self.pe_distinguisher_label is not None:
                                                            for child_ref in self.pe_distinguisher_label:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.pmsi_flags is not None:
                                                            return True

                                                        if self.pmsi_label is not None:
                                                            return True

                                                        if self.pmsi_type is not None:
                                                            return True

                                                        if self.pmsi_value is not None:
                                                            for child_ref in self.pmsi_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.ppm_pvalue is not None:
                                                            return True

                                                        if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_explicit_path is not None:
                                                            for child_ref in self.sr_policy_explicit_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.sr_policy_preference is not None:
                                                            return True

                                                        if self.sr_tunnel_request_state is not None:
                                                            return True

                                                        if self.sr_tunnel_state is not None:
                                                            return True

                                                        if self.tunnel_encap_type is not None:
                                                            return True

                                                        if self.unknown_attribute is not None:
                                                            for child_ref in self.unknown_attribute:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                                class AttrSet(object):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_encap_present
                                                    
                                                    	Tunnel Encap attribute present 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_policy_allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_binding_sid
                                                    
                                                    	SR Policy Binding sid
                                                    	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_explicit_path
                                                    
                                                    	SR Policy Explicit paths
                                                    	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                    
                                                    .. attribute:: sr_policy_preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_tunnel_request_state
                                                    
                                                    	SR Tunnel Request State
                                                    	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                    
                                                    .. attribute:: sr_tunnel_state
                                                    
                                                    	SR Tunnel State
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encap Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.aggregator_address = None
                                                        self.aggregator_as = None
                                                        self.aigp_metric_value = None
                                                        self.as_path = None
                                                        self.cluster = YList()
                                                        self.cluster.parent = self
                                                        self.cluster.name = 'cluster'
                                                        self.community = YList()
                                                        self.community.parent = self
                                                        self.community.name = 'community'
                                                        self.connector_type = None
                                                        self.connector_value = YList()
                                                        self.connector_value.parent = self
                                                        self.connector_value.name = 'connector_value'
                                                        self.extended_community = YList()
                                                        self.extended_community.parent = self
                                                        self.extended_community.name = 'extended_community'
                                                        self.extended_community_flags = None
                                                        self.is_aggregator_present = None
                                                        self.is_aigp_present = None
                                                        self.is_as_path_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_community_present = None
                                                        self.is_connector_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_label_index_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_metric_present = None
                                                        self.is_origin_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_ssa_present = None
                                                        self.is_tunnel_encap_present = None
                                                        self.l2tpv3_cookie = YList()
                                                        self.l2tpv3_cookie.parent = self
                                                        self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                        self.l2tpv3_session_id = None
                                                        self.label_index_attr = YList()
                                                        self.label_index_attr.parent = self
                                                        self.label_index_attr.name = 'label_index_attr'
                                                        self.local_preference = None
                                                        self.ls_attr = YList()
                                                        self.ls_attr.parent = self
                                                        self.ls_attr.name = 'ls_attr'
                                                        self.metric = None
                                                        self.neighbor_as = None
                                                        self.origin = None
                                                        self.originator = None
                                                        self.pe_distinguisher_label = YList()
                                                        self.pe_distinguisher_label.parent = self
                                                        self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.pmsi_type = None
                                                        self.pmsi_value = YList()
                                                        self.pmsi_value.parent = self
                                                        self.pmsi_value.name = 'pmsi_value'
                                                        self.ppm_pvalue = None
                                                        self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                        self.sr_policy_allocated_binding_sid.parent = self
                                                        self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                        self.sr_policy_binding_sid.parent = self
                                                        self.sr_policy_explicit_path = YList()
                                                        self.sr_policy_explicit_path.parent = self
                                                        self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                        self.sr_policy_preference = None
                                                        self.sr_tunnel_request_state = None
                                                        self.sr_tunnel_state = None
                                                        self.tunnel_encap_type = None
                                                        self.unknown_attribute = YList()
                                                        self.unknown_attribute.parent = self
                                                        self.unknown_attribute.name = 'unknown_attribute'


                                                    class SrPolicyBindingSid(object):
                                                        """
                                                        SR Policy Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                    class SrPolicyAllocatedBindingSid(object):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                    class Community(object):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                    class ExtendedCommunity(object):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                    class UnknownAttribute(object):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                    class Cluster(object):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                    class L2Tpv3Cookie(object):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                    class ConnectorValue(object):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                    class PmsiValue(object):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                    class LsAttr(object):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                    class LabelIndexAttr(object):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                    class PeDistinguisherLabel(object):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.label = None
                                                            self.pe_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.label is not None:
                                                                return True

                                                            if self.pe_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                    class SrPolicyExplicitPath(object):
                                                        """
                                                        SR Policy Explicit paths
                                                        
                                                        .. attribute:: sid
                                                        
                                                        	Sidlist for explicit path
                                                        	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of explicit path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.sid = YList()
                                                            self.sid.parent = self
                                                            self.sid.name = 'sid'
                                                            self.weight = None


                                                        class Sid(object):
                                                            """
                                                            Sidlist for explicit path
                                                            
                                                            .. attribute:: ipv4
                                                            
                                                            	IP Address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6
                                                            
                                                            	IPv6 address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label sid
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Sid Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4 = None
                                                                self.ipv6 = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4 is not None:
                                                                    return True

                                                                if self.ipv6 is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.sid is not None:
                                                                for child_ref in self.sid:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.weight is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.aggregator_address is not None:
                                                            return True

                                                        if self.aggregator_as is not None:
                                                            return True

                                                        if self.aigp_metric_value is not None:
                                                            return True

                                                        if self.as_path is not None:
                                                            return True

                                                        if self.cluster is not None:
                                                            for child_ref in self.cluster:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.community is not None:
                                                            for child_ref in self.community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.connector_type is not None:
                                                            return True

                                                        if self.connector_value is not None:
                                                            for child_ref in self.connector_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community is not None:
                                                            for child_ref in self.extended_community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community_flags is not None:
                                                            return True

                                                        if self.is_aggregator_present is not None:
                                                            return True

                                                        if self.is_aigp_present is not None:
                                                            return True

                                                        if self.is_as_path_present is not None:
                                                            return True

                                                        if self.is_atomic_aggregate_present is not None:
                                                            return True

                                                        if self.is_community_present is not None:
                                                            return True

                                                        if self.is_connector_present is not None:
                                                            return True

                                                        if self.is_extended_community_present is not None:
                                                            return True

                                                        if self.is_label_index_present is not None:
                                                            return True

                                                        if self.is_local_pref_present is not None:
                                                            return True

                                                        if self.is_ls_attribute_present is not None:
                                                            return True

                                                        if self.is_metric_present is not None:
                                                            return True

                                                        if self.is_origin_present is not None:
                                                            return True

                                                        if self.is_pe_distinguisher_label_present is not None:
                                                            return True

                                                        if self.is_pmsi_present is not None:
                                                            return True

                                                        if self.is_pppmp_present is not None:
                                                            return True

                                                        if self.is_ssa_present is not None:
                                                            return True

                                                        if self.is_tunnel_encap_present is not None:
                                                            return True

                                                        if self.l2tpv3_cookie is not None:
                                                            for child_ref in self.l2tpv3_cookie:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.l2tpv3_session_id is not None:
                                                            return True

                                                        if self.label_index_attr is not None:
                                                            for child_ref in self.label_index_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.local_preference is not None:
                                                            return True

                                                        if self.ls_attr is not None:
                                                            for child_ref in self.ls_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.metric is not None:
                                                            return True

                                                        if self.neighbor_as is not None:
                                                            return True

                                                        if self.origin is not None:
                                                            return True

                                                        if self.originator is not None:
                                                            return True

                                                        if self.pe_distinguisher_label is not None:
                                                            for child_ref in self.pe_distinguisher_label:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.pmsi_flags is not None:
                                                            return True

                                                        if self.pmsi_label is not None:
                                                            return True

                                                        if self.pmsi_type is not None:
                                                            return True

                                                        if self.pmsi_value is not None:
                                                            for child_ref in self.pmsi_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.ppm_pvalue is not None:
                                                            return True

                                                        if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_explicit_path is not None:
                                                            for child_ref in self.sr_policy_explicit_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.sr_policy_preference is not None:
                                                            return True

                                                        if self.sr_tunnel_request_state is not None:
                                                            return True

                                                        if self.sr_tunnel_state is not None:
                                                            return True

                                                        if self.tunnel_encap_type is not None:
                                                            return True

                                                        if self.unknown_attribute is not None:
                                                            for child_ref in self.unknown_attribute:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                                class RnhAddr(object):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.len = None
                                                        self.mac_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.len is not None:
                                                            return True

                                                        if self.mac_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                                class RibrnhIp(object):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.attr_set is not None and self.attr_set._has_data():
                                                        return True

                                                    if self.attribute_key_number is not None:
                                                        return True

                                                    if self.attribute_reuse_id_config is not None:
                                                        return True

                                                    if self.attribute_reuse_id_current is not None:
                                                        return True

                                                    if self.attribute_reuse_id_keys is not None:
                                                        return True

                                                    if self.attribute_reuse_id_max_id is not None:
                                                        return True

                                                    if self.attribute_reuse_id_node is not None:
                                                        return True

                                                    if self.attribute_reuse_id_recover_sec is not None:
                                                        return True

                                                    if self.common_attributes is not None and self.common_attributes._has_data():
                                                        return True

                                                    if self.is_application_gateway_present is not None:
                                                        return True

                                                    if self.is_as_path2_byte is not None:
                                                        return True

                                                    if self.is_attr_set_present is not None:
                                                        return True

                                                    if self.is_ribrnh_present is not None:
                                                        return True

                                                    if self.is_rnh_present is not None:
                                                        return True

                                                    if self.ribrnh_encap is not None:
                                                        return True

                                                    if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                        return True

                                                    if self.ribrnh_mac is not None:
                                                        return True

                                                    if self.ribrnh_table is not None:
                                                        return True

                                                    if self.ribrnh_vni is not None:
                                                        return True

                                                    if self.ribrnhip_table is not None:
                                                        return True

                                                    if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                        return True

                                                    if self.rnh_addr_len is not None:
                                                        return True

                                                    if self.rnh_len is not None:
                                                        return True

                                                    if self.rnh_type is not None:
                                                        return True

                                                    if self.set_aigp_inbound_igp is not None:
                                                        return True

                                                    if self.set_aigp_inbound_metric is not None:
                                                        return True

                                                    if self.vpn_distinguisher is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn']['meta_info']


                                            class AttributesAfterPolicyOut(object):
                                                """
                                                Attributes after outbound policy
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet>`
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes>`
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp>`
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr>`
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\:  bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\:  bool
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet()
                                                    self.attr_set.parent = self
                                                    self.attribute_key_number = None
                                                    self.attribute_reuse_id_config = None
                                                    self.attribute_reuse_id_current = None
                                                    self.attribute_reuse_id_keys = None
                                                    self.attribute_reuse_id_max_id = None
                                                    self.attribute_reuse_id_node = None
                                                    self.attribute_reuse_id_recover_sec = None
                                                    self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self.is_application_gateway_present = None
                                                    self.is_as_path2_byte = None
                                                    self.is_attr_set_present = None
                                                    self.is_ribrnh_present = None
                                                    self.is_rnh_present = None
                                                    self.ribrnh_encap = None
                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self.ribrnh_mac = None
                                                    self.ribrnh_table = None
                                                    self.ribrnh_vni = None
                                                    self.ribrnhip_table = None
                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self.rnh_addr_len = None
                                                    self.rnh_len = None
                                                    self.rnh_type = None
                                                    self.set_aigp_inbound_igp = None
                                                    self.set_aigp_inbound_metric = None
                                                    self.vpn_distinguisher = None


                                                class CommonAttributes(object):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_encap_present
                                                    
                                                    	Tunnel Encap attribute present 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_policy_allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_binding_sid
                                                    
                                                    	SR Policy Binding sid
                                                    	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_explicit_path
                                                    
                                                    	SR Policy Explicit paths
                                                    	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyExplicitPath>`
                                                    
                                                    .. attribute:: sr_policy_preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_tunnel_request_state
                                                    
                                                    	SR Tunnel Request State
                                                    	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                    
                                                    .. attribute:: sr_tunnel_state
                                                    
                                                    	SR Tunnel State
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encap Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.aggregator_address = None
                                                        self.aggregator_as = None
                                                        self.aigp_metric_value = None
                                                        self.as_path = None
                                                        self.cluster = YList()
                                                        self.cluster.parent = self
                                                        self.cluster.name = 'cluster'
                                                        self.community = YList()
                                                        self.community.parent = self
                                                        self.community.name = 'community'
                                                        self.connector_type = None
                                                        self.connector_value = YList()
                                                        self.connector_value.parent = self
                                                        self.connector_value.name = 'connector_value'
                                                        self.extended_community = YList()
                                                        self.extended_community.parent = self
                                                        self.extended_community.name = 'extended_community'
                                                        self.extended_community_flags = None
                                                        self.is_aggregator_present = None
                                                        self.is_aigp_present = None
                                                        self.is_as_path_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_community_present = None
                                                        self.is_connector_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_label_index_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_metric_present = None
                                                        self.is_origin_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_ssa_present = None
                                                        self.is_tunnel_encap_present = None
                                                        self.l2tpv3_cookie = YList()
                                                        self.l2tpv3_cookie.parent = self
                                                        self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                        self.l2tpv3_session_id = None
                                                        self.label_index_attr = YList()
                                                        self.label_index_attr.parent = self
                                                        self.label_index_attr.name = 'label_index_attr'
                                                        self.local_preference = None
                                                        self.ls_attr = YList()
                                                        self.ls_attr.parent = self
                                                        self.ls_attr.name = 'ls_attr'
                                                        self.metric = None
                                                        self.neighbor_as = None
                                                        self.origin = None
                                                        self.originator = None
                                                        self.pe_distinguisher_label = YList()
                                                        self.pe_distinguisher_label.parent = self
                                                        self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.pmsi_type = None
                                                        self.pmsi_value = YList()
                                                        self.pmsi_value.parent = self
                                                        self.pmsi_value.name = 'pmsi_value'
                                                        self.ppm_pvalue = None
                                                        self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                        self.sr_policy_allocated_binding_sid.parent = self
                                                        self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyBindingSid()
                                                        self.sr_policy_binding_sid.parent = self
                                                        self.sr_policy_explicit_path = YList()
                                                        self.sr_policy_explicit_path.parent = self
                                                        self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                        self.sr_policy_preference = None
                                                        self.sr_tunnel_request_state = None
                                                        self.sr_tunnel_state = None
                                                        self.tunnel_encap_type = None
                                                        self.unknown_attribute = YList()
                                                        self.unknown_attribute.parent = self
                                                        self.unknown_attribute.name = 'unknown_attribute'


                                                    class SrPolicyBindingSid(object):
                                                        """
                                                        SR Policy Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                    class SrPolicyAllocatedBindingSid(object):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                    class Community(object):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community']['meta_info']


                                                    class ExtendedCommunity(object):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity']['meta_info']


                                                    class UnknownAttribute(object):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute']['meta_info']


                                                    class Cluster(object):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster']['meta_info']


                                                    class L2Tpv3Cookie(object):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                    class ConnectorValue(object):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue']['meta_info']


                                                    class PmsiValue(object):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue']['meta_info']


                                                    class LsAttr(object):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr']['meta_info']


                                                    class LabelIndexAttr(object):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr']['meta_info']


                                                    class PeDistinguisherLabel(object):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.label = None
                                                            self.pe_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.label is not None:
                                                                return True

                                                            if self.pe_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                    class SrPolicyExplicitPath(object):
                                                        """
                                                        SR Policy Explicit paths
                                                        
                                                        .. attribute:: sid
                                                        
                                                        	Sidlist for explicit path
                                                        	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of explicit path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.sid = YList()
                                                            self.sid.parent = self
                                                            self.sid.name = 'sid'
                                                            self.weight = None


                                                        class Sid(object):
                                                            """
                                                            Sidlist for explicit path
                                                            
                                                            .. attribute:: ipv4
                                                            
                                                            	IP Address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6
                                                            
                                                            	IPv6 address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label sid
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Sid Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4 = None
                                                                self.ipv6 = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4 is not None:
                                                                    return True

                                                                if self.ipv6 is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.sid is not None:
                                                                for child_ref in self.sid:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.weight is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.aggregator_address is not None:
                                                            return True

                                                        if self.aggregator_as is not None:
                                                            return True

                                                        if self.aigp_metric_value is not None:
                                                            return True

                                                        if self.as_path is not None:
                                                            return True

                                                        if self.cluster is not None:
                                                            for child_ref in self.cluster:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.community is not None:
                                                            for child_ref in self.community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.connector_type is not None:
                                                            return True

                                                        if self.connector_value is not None:
                                                            for child_ref in self.connector_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community is not None:
                                                            for child_ref in self.extended_community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community_flags is not None:
                                                            return True

                                                        if self.is_aggregator_present is not None:
                                                            return True

                                                        if self.is_aigp_present is not None:
                                                            return True

                                                        if self.is_as_path_present is not None:
                                                            return True

                                                        if self.is_atomic_aggregate_present is not None:
                                                            return True

                                                        if self.is_community_present is not None:
                                                            return True

                                                        if self.is_connector_present is not None:
                                                            return True

                                                        if self.is_extended_community_present is not None:
                                                            return True

                                                        if self.is_label_index_present is not None:
                                                            return True

                                                        if self.is_local_pref_present is not None:
                                                            return True

                                                        if self.is_ls_attribute_present is not None:
                                                            return True

                                                        if self.is_metric_present is not None:
                                                            return True

                                                        if self.is_origin_present is not None:
                                                            return True

                                                        if self.is_pe_distinguisher_label_present is not None:
                                                            return True

                                                        if self.is_pmsi_present is not None:
                                                            return True

                                                        if self.is_pppmp_present is not None:
                                                            return True

                                                        if self.is_ssa_present is not None:
                                                            return True

                                                        if self.is_tunnel_encap_present is not None:
                                                            return True

                                                        if self.l2tpv3_cookie is not None:
                                                            for child_ref in self.l2tpv3_cookie:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.l2tpv3_session_id is not None:
                                                            return True

                                                        if self.label_index_attr is not None:
                                                            for child_ref in self.label_index_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.local_preference is not None:
                                                            return True

                                                        if self.ls_attr is not None:
                                                            for child_ref in self.ls_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.metric is not None:
                                                            return True

                                                        if self.neighbor_as is not None:
                                                            return True

                                                        if self.origin is not None:
                                                            return True

                                                        if self.originator is not None:
                                                            return True

                                                        if self.pe_distinguisher_label is not None:
                                                            for child_ref in self.pe_distinguisher_label:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.pmsi_flags is not None:
                                                            return True

                                                        if self.pmsi_label is not None:
                                                            return True

                                                        if self.pmsi_type is not None:
                                                            return True

                                                        if self.pmsi_value is not None:
                                                            for child_ref in self.pmsi_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.ppm_pvalue is not None:
                                                            return True

                                                        if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_explicit_path is not None:
                                                            for child_ref in self.sr_policy_explicit_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.sr_policy_preference is not None:
                                                            return True

                                                        if self.sr_tunnel_request_state is not None:
                                                            return True

                                                        if self.sr_tunnel_state is not None:
                                                            return True

                                                        if self.tunnel_encap_type is not None:
                                                            return True

                                                        if self.unknown_attribute is not None:
                                                            for child_ref in self.unknown_attribute:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes']['meta_info']


                                                class AttrSet(object):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_encap_present
                                                    
                                                    	Tunnel Encap attribute present 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_policy_allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyAllocatedBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_binding_sid
                                                    
                                                    	SR Policy Binding sid
                                                    	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_explicit_path
                                                    
                                                    	SR Policy Explicit paths
                                                    	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyExplicitPath>`
                                                    
                                                    .. attribute:: sr_policy_preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_tunnel_request_state
                                                    
                                                    	SR Tunnel Request State
                                                    	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                    
                                                    .. attribute:: sr_tunnel_state
                                                    
                                                    	SR Tunnel State
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encap Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.aggregator_address = None
                                                        self.aggregator_as = None
                                                        self.aigp_metric_value = None
                                                        self.as_path = None
                                                        self.cluster = YList()
                                                        self.cluster.parent = self
                                                        self.cluster.name = 'cluster'
                                                        self.community = YList()
                                                        self.community.parent = self
                                                        self.community.name = 'community'
                                                        self.connector_type = None
                                                        self.connector_value = YList()
                                                        self.connector_value.parent = self
                                                        self.connector_value.name = 'connector_value'
                                                        self.extended_community = YList()
                                                        self.extended_community.parent = self
                                                        self.extended_community.name = 'extended_community'
                                                        self.extended_community_flags = None
                                                        self.is_aggregator_present = None
                                                        self.is_aigp_present = None
                                                        self.is_as_path_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_community_present = None
                                                        self.is_connector_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_label_index_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_metric_present = None
                                                        self.is_origin_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_ssa_present = None
                                                        self.is_tunnel_encap_present = None
                                                        self.l2tpv3_cookie = YList()
                                                        self.l2tpv3_cookie.parent = self
                                                        self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                        self.l2tpv3_session_id = None
                                                        self.label_index_attr = YList()
                                                        self.label_index_attr.parent = self
                                                        self.label_index_attr.name = 'label_index_attr'
                                                        self.local_preference = None
                                                        self.ls_attr = YList()
                                                        self.ls_attr.parent = self
                                                        self.ls_attr.name = 'ls_attr'
                                                        self.metric = None
                                                        self.neighbor_as = None
                                                        self.origin = None
                                                        self.originator = None
                                                        self.pe_distinguisher_label = YList()
                                                        self.pe_distinguisher_label.parent = self
                                                        self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.pmsi_type = None
                                                        self.pmsi_value = YList()
                                                        self.pmsi_value.parent = self
                                                        self.pmsi_value.name = 'pmsi_value'
                                                        self.ppm_pvalue = None
                                                        self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyAllocatedBindingSid()
                                                        self.sr_policy_allocated_binding_sid.parent = self
                                                        self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyBindingSid()
                                                        self.sr_policy_binding_sid.parent = self
                                                        self.sr_policy_explicit_path = YList()
                                                        self.sr_policy_explicit_path.parent = self
                                                        self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                        self.sr_policy_preference = None
                                                        self.sr_tunnel_request_state = None
                                                        self.sr_tunnel_state = None
                                                        self.tunnel_encap_type = None
                                                        self.unknown_attribute = YList()
                                                        self.unknown_attribute.parent = self
                                                        self.unknown_attribute.name = 'unknown_attribute'


                                                    class SrPolicyBindingSid(object):
                                                        """
                                                        SR Policy Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyBindingSid']['meta_info']


                                                    class SrPolicyAllocatedBindingSid(object):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                    class Community(object):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community']['meta_info']


                                                    class ExtendedCommunity(object):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity']['meta_info']


                                                    class UnknownAttribute(object):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute']['meta_info']


                                                    class Cluster(object):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster']['meta_info']


                                                    class L2Tpv3Cookie(object):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie']['meta_info']


                                                    class ConnectorValue(object):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue']['meta_info']


                                                    class PmsiValue(object):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue']['meta_info']


                                                    class LsAttr(object):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr']['meta_info']


                                                    class LabelIndexAttr(object):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr']['meta_info']


                                                    class PeDistinguisherLabel(object):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.label = None
                                                            self.pe_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.label is not None:
                                                                return True

                                                            if self.pe_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel']['meta_info']


                                                    class SrPolicyExplicitPath(object):
                                                        """
                                                        SR Policy Explicit paths
                                                        
                                                        .. attribute:: sid
                                                        
                                                        	Sidlist for explicit path
                                                        	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyExplicitPath.Sid>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of explicit path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.sid = YList()
                                                            self.sid.parent = self
                                                            self.sid.name = 'sid'
                                                            self.weight = None


                                                        class Sid(object):
                                                            """
                                                            Sidlist for explicit path
                                                            
                                                            .. attribute:: ipv4
                                                            
                                                            	IP Address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6
                                                            
                                                            	IPv6 address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label sid
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Sid Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4 = None
                                                                self.ipv6 = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4 is not None:
                                                                    return True

                                                                if self.ipv6 is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.sid is not None:
                                                                for child_ref in self.sid:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.weight is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.aggregator_address is not None:
                                                            return True

                                                        if self.aggregator_as is not None:
                                                            return True

                                                        if self.aigp_metric_value is not None:
                                                            return True

                                                        if self.as_path is not None:
                                                            return True

                                                        if self.cluster is not None:
                                                            for child_ref in self.cluster:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.community is not None:
                                                            for child_ref in self.community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.connector_type is not None:
                                                            return True

                                                        if self.connector_value is not None:
                                                            for child_ref in self.connector_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community is not None:
                                                            for child_ref in self.extended_community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community_flags is not None:
                                                            return True

                                                        if self.is_aggregator_present is not None:
                                                            return True

                                                        if self.is_aigp_present is not None:
                                                            return True

                                                        if self.is_as_path_present is not None:
                                                            return True

                                                        if self.is_atomic_aggregate_present is not None:
                                                            return True

                                                        if self.is_community_present is not None:
                                                            return True

                                                        if self.is_connector_present is not None:
                                                            return True

                                                        if self.is_extended_community_present is not None:
                                                            return True

                                                        if self.is_label_index_present is not None:
                                                            return True

                                                        if self.is_local_pref_present is not None:
                                                            return True

                                                        if self.is_ls_attribute_present is not None:
                                                            return True

                                                        if self.is_metric_present is not None:
                                                            return True

                                                        if self.is_origin_present is not None:
                                                            return True

                                                        if self.is_pe_distinguisher_label_present is not None:
                                                            return True

                                                        if self.is_pmsi_present is not None:
                                                            return True

                                                        if self.is_pppmp_present is not None:
                                                            return True

                                                        if self.is_ssa_present is not None:
                                                            return True

                                                        if self.is_tunnel_encap_present is not None:
                                                            return True

                                                        if self.l2tpv3_cookie is not None:
                                                            for child_ref in self.l2tpv3_cookie:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.l2tpv3_session_id is not None:
                                                            return True

                                                        if self.label_index_attr is not None:
                                                            for child_ref in self.label_index_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.local_preference is not None:
                                                            return True

                                                        if self.ls_attr is not None:
                                                            for child_ref in self.ls_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.metric is not None:
                                                            return True

                                                        if self.neighbor_as is not None:
                                                            return True

                                                        if self.origin is not None:
                                                            return True

                                                        if self.originator is not None:
                                                            return True

                                                        if self.pe_distinguisher_label is not None:
                                                            for child_ref in self.pe_distinguisher_label:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.pmsi_flags is not None:
                                                            return True

                                                        if self.pmsi_label is not None:
                                                            return True

                                                        if self.pmsi_type is not None:
                                                            return True

                                                        if self.pmsi_value is not None:
                                                            for child_ref in self.pmsi_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.ppm_pvalue is not None:
                                                            return True

                                                        if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_explicit_path is not None:
                                                            for child_ref in self.sr_policy_explicit_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.sr_policy_preference is not None:
                                                            return True

                                                        if self.sr_tunnel_request_state is not None:
                                                            return True

                                                        if self.sr_tunnel_state is not None:
                                                            return True

                                                        if self.tunnel_encap_type is not None:
                                                            return True

                                                        if self.unknown_attribute is not None:
                                                            for child_ref in self.unknown_attribute:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet']['meta_info']


                                                class RnhAddr(object):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.len = None
                                                        self.mac_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.len is not None:
                                                            return True

                                                        if self.mac_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr']['meta_info']


                                                class RibrnhIp(object):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-out'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.attr_set is not None and self.attr_set._has_data():
                                                        return True

                                                    if self.attribute_key_number is not None:
                                                        return True

                                                    if self.attribute_reuse_id_config is not None:
                                                        return True

                                                    if self.attribute_reuse_id_current is not None:
                                                        return True

                                                    if self.attribute_reuse_id_keys is not None:
                                                        return True

                                                    if self.attribute_reuse_id_max_id is not None:
                                                        return True

                                                    if self.attribute_reuse_id_node is not None:
                                                        return True

                                                    if self.attribute_reuse_id_recover_sec is not None:
                                                        return True

                                                    if self.common_attributes is not None and self.common_attributes._has_data():
                                                        return True

                                                    if self.is_application_gateway_present is not None:
                                                        return True

                                                    if self.is_as_path2_byte is not None:
                                                        return True

                                                    if self.is_attr_set_present is not None:
                                                        return True

                                                    if self.is_ribrnh_present is not None:
                                                        return True

                                                    if self.is_rnh_present is not None:
                                                        return True

                                                    if self.ribrnh_encap is not None:
                                                        return True

                                                    if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                        return True

                                                    if self.ribrnh_mac is not None:
                                                        return True

                                                    if self.ribrnh_table is not None:
                                                        return True

                                                    if self.ribrnh_vni is not None:
                                                        return True

                                                    if self.ribrnhip_table is not None:
                                                        return True

                                                    if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                        return True

                                                    if self.rnh_addr_len is not None:
                                                        return True

                                                    if self.rnh_len is not None:
                                                        return True

                                                    if self.rnh_type is not None:
                                                        return True

                                                    if self.set_aigp_inbound_igp is not None:
                                                        return True

                                                    if self.set_aigp_inbound_metric is not None:
                                                        return True

                                                    if self.vpn_distinguisher is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:adv-path-info'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.af_name is not None:
                                                    return True

                                                if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                    return True

                                                if self.attributes_after_policy_out is not None and self.attributes_after_policy_out._has_data():
                                                    return True

                                                if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                    return True

                                                if self.no_path is not None:
                                                    return True

                                                if self.path_info_after_policy_in is not None and self.path_info_after_policy_in._has_data():
                                                    return True

                                                if self.path_info_after_policy_out is not None and self.path_info_after_policy_out._has_data():
                                                    return True

                                                if self.route_distinguisher is not None:
                                                    return True

                                                if self.source_route_distinguisher is not None:
                                                    return True

                                                if self.vrf_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertised-path'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.adv_path_info is not None:
                                                for child_ref in self.adv_path_info:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.neighbor_address is not None:
                                                return True

                                            if self.network is not None:
                                                return True

                                            if self.paths is not None:
                                                for child_ref in self.paths:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.prefix_length is not None:
                                                return True

                                            if self.rd is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertised-paths'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.advertised_path is not None:
                                            for child_ref in self.advertised_path:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths']['meta_info']


                                class NeighborAfTable(object):
                                    """
                                    The BGP Neighbor AF table
                                    
                                    .. attribute:: neighbor
                                    
                                    	A BGP Neighbor table entry
                                    	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.neighbor = YList()
                                        self.neighbor.parent = self
                                        self.neighbor.name = 'neighbor'


                                    class Neighbor(object):
                                        """
                                        A BGP Neighbor table entry
                                        
                                        .. attribute:: neighbor_address  <key>
                                        
                                        	Neighbor address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: active_bmp_servers
                                        
                                        	BMP Servers to which the neighbor sends logs
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: actual_last_write_bytes
                                        
                                        	Actual size of last write
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: actual_last_write_reset_bytes
                                        
                                        	Actual size of last write before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: actual_second_last_write_bytes
                                        
                                        	Actual size of second last write
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: actual_second_last_write_reset_bytes
                                        
                                        	Actual size of second last write before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: af_data
                                        
                                        	Address family specific neighbor data
                                        	**type**\: list of    :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData>`
                                        
                                        .. attribute:: attempted_last_write_bytes
                                        
                                        	Attempted size of last write
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attempted_last_write_reset_bytes
                                        
                                        	Attempted size of last write before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attempted_second_last_write_bytes
                                        
                                        	Attempted size of second last write
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attempted_second_last_write_reset_bytes
                                        
                                        	Attempted size of second last write before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bfd_minintervalval
                                        
                                        	BFD Mininterval for this peer
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bfd_multiplierval
                                        
                                        	BFD Multiplier for this peer
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bfd_session_created_state
                                        
                                        	BFD state for this peer
                                        	**type**\:   :py:class:`BgpBfdStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdStateEnum>`
                                        
                                        .. attribute:: bfd_session_enable_mode
                                        
                                        	BFD enable mode for this peer
                                        	**type**\:   :py:class:`BgpBfdEnableModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdEnableModeEnum>`
                                        
                                        .. attribute:: bfd_session_state
                                        
                                        	BFD state for this peer
                                        	**type**\:   :py:class:`BgpBfdStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdStateEnum>`
                                        
                                        .. attribute:: bfd_state_ts
                                        
                                        	Timestamp since when nbr is in this bfd state
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bytes_read
                                        
                                        	Total bytes read
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bytes_written
                                        
                                        	Total bytes written by write thread
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: configured_hold_time
                                        
                                        	Hold time (in secs) configured for this connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: configured_keepalive
                                        
                                        	Keepalive time (in secs) configured for this connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: configured_min_acc_hold_time
                                        
                                        	Minimum acceptable hold time from neighbor (in secs) configured for this connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: connect_retry_interval
                                        
                                        	Time (in secs) for connect retry timer
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: connection_admin_status
                                        
                                        	Administrative status of connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: connection_down_count
                                        
                                        	Number of times connection was dropped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: connection_established_time
                                        
                                        	Time (in secs) that the connection has been established
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: connection_local_address
                                        
                                        	Local address for the connection
                                        	**type**\:   :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress>`
                                        
                                        .. attribute:: connection_local_port
                                        
                                        	Local port for the connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: connection_remote_address
                                        
                                        	Remote address for the connection
                                        	**type**\:   :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress>`
                                        
                                        .. attribute:: connection_remote_port
                                        
                                        	Remote port for the connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: connection_state
                                        
                                        	State of connection
                                        	**type**\:   :py:class:`BgpConnStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnStateEnum>`
                                        
                                        .. attribute:: connection_up_count
                                        
                                        	Number of times the connection was established
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: count_last_write
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: description
                                        
                                        	Description
                                        	**type**\:  str
                                        
                                        .. attribute:: discard_as4_path
                                        
                                        	Discard AS4\_PATH in case there is a discrepancy in merging AS\_PATH and AS4\_PATH,retain ASPATH
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: discard_data_bytes
                                        
                                        	Remaining discard data (bytes) on Standby
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: dmz_link_bandwidth
                                        
                                        	Bandwidth of link to single\-hop eBGP peer
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: dynamic_neighbor
                                        
                                        	Dynamic neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: ebgp_recv_dmz
                                        
                                        	Receive Bandwidth of link to single\-hop eBGP peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: ebgp_send_dmz_mode
                                        
                                        	Ebgp send dmz link bw mode
                                        	**type**\:   :py:class:`BgpEbgpSendDmzEnableModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableModeEnum>`
                                        
                                        .. attribute:: ebgp_time_to_live
                                        
                                        	Maximum number of hops for external BGP neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: egress_peer_engineering_enabled
                                        
                                        	Indicates if Egress Peer Engineering is enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: error_notifies_received
                                        
                                        	Number of error notifications received on the connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: error_notifies_sent
                                        
                                        	Number of error notifications sent on the connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fpbsn_offset
                                        
                                        	First standby PDU boundary SeqNo offset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fssn_offset
                                        
                                        	First standby SeqNo offset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: gr_restart_time
                                        
                                        	Neighbor restart time (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: gr_stale_path_time
                                        
                                        	Neighbor stale\-path time (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: graceful_maintenance
                                        
                                        	Graceful Maintenance
                                        	**type**\:   :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance>`
                                        
                                        .. attribute:: graceful_restart_enabled_nbr
                                        
                                        	Neighbor supports graceful\-restart
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_internal_link
                                        
                                        	Internal link to neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: hold_time
                                        
                                        	Hold time (in secs) negotiated for this connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: ignore_connected
                                        
                                        	If true, the VPN client isan IBGP CE peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: internal_vpn_client
                                        
                                        	If true, don't do NHconnected check for nbr
                                        	**type**\:  bool
                                        
                                        .. attribute:: io_armed
                                        
                                        	If true, socket has beenauto\-armed for io control
                                        	**type**\:  bool
                                        
                                        .. attribute:: is4_byte_as_capability_received
                                        
                                        	4\-byte AScapability received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is4_byte_as_capability_sent
                                        
                                        	4\-byte AScapability Snt
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_administratively_shut_down
                                        
                                        	Neighbor is administratively shut down
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_capability_negotiation_performed
                                        
                                        	Capability negotiation performed
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_capability_negotiation_suppressed
                                        
                                        	Capability negotiation suppressed
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ebgp_multihop_bgpmpls_forwarding_disabled
                                        
                                        	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ebgp_peer_as_league
                                        
                                        	EBGP peer belongs to AS League
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ebgp_peer_common_admin
                                        
                                        	EBGP peer with common administation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_external_neighbor_not_directly_connected
                                        
                                        	External neighbor not directly connected
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_gr_aware
                                        
                                        	GR awareness received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_local_address_configured
                                        
                                        	Local address configured for the neighbor connection
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_max_prefix_shutdown
                                        
                                        	Neighbor shut down because it exceeded max prfx count
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_out_of_memory_forced_up
                                        
                                        	Neighbor forced up during a low memory condition
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_out_of_memory_shutdown
                                        
                                        	Neighbor shut down during a SEVERE low memory condition
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_passive_close
                                        
                                        	If true, active socket canbe closed if passive openis received for a GRcapable neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_read_disabled
                                        
                                        	If true, socket read isdisabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_route_refresh_capability_received
                                        
                                        	Route refresh capability received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_route_refresh_old_capability_received
                                        
                                        	Route refresh old capability received
                                        	**type**\:  bool
                                        
                                        .. attribute:: keep_alive_time
                                        
                                        	Keepalive time (in secs) negotiated for this connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_ackd_seq_no
                                        
                                        	SeqNo of the last Ackd byte
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_k_aerror_reset
                                        
                                        	Duration (in secs) since last time that an error was encountered after KA expiry
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_k_aexpiry_reset
                                        
                                        	Time (in secs) since last KA timer expiry before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_k_anotsent_reset
                                        
                                        	Duration (in secs) since last time that KA was not sent before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_k_astart_reset
                                        
                                        	Time (in secs) since the last KA timer start before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_notify_error_code
                                        
                                        	Code for the last error notification seen on the connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: last_notify_error_subcode
                                        
                                        	Error subcode of the last error notification seen on the connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: last_write_event
                                        
                                        	Time (in secs) since last write thread event
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: local_as
                                        
                                        	Local AS number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_as_dual_as
                                        
                                        	Local AS Dual\-AS option
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_as_dual_as_mode_native
                                        
                                        	Applies only if Local AS Dual\-AS option is enabled. Indicates if Dual\-AS mode is native
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_as_no_prepend
                                        
                                        	Option to not prepend the Local AS to announcements
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_as_replace_as
                                        
                                        	Local AS Replace\-AS option
                                        	**type**\:  bool
                                        
                                        .. attribute:: message_statistics
                                        
                                        	Message statistics
                                        	**type**\:   :py:class:`MessageStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics>`
                                        
                                        .. attribute:: messages_queued_in
                                        
                                        	No. of msgs on receive queue
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: messages_queued_out
                                        
                                        	No. of messages on send queue
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: messages_received
                                        
                                        	Number of messages received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: messages_sent
                                        
                                        	Number of messages sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: min_advertise_interval
                                        
                                        	Minimum advertisement interval, secs part
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: min_advertise_interval_msecs
                                        
                                        	Minimum advertisement interval, msecs part
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: min_origination_interval
                                        
                                        	Minimum origination interval (in secs)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: msg_log_in
                                        
                                        	Message in log count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: msg_log_out
                                        
                                        	Message out log count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multi_protocol_capability_received
                                        
                                        	Multi\-protocol capability has been received
                                        	**type**\:  bool
                                        
                                        .. attribute:: nbr_cluster_id
                                        
                                        	Cluster id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nbr_enforce_first_as
                                        
                                        	Neighbor enforce first AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: nbr_in_cluster
                                        
                                        	Type of cluster\_id\:undefined/number/Ip address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: negotiated_protocol_version
                                        
                                        	Negotiated protocol version
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: neighbor_interface_handle
                                        
                                        	Interface Handle of Neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_local_as
                                        
                                        	Local AS configured on the neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nsr_enabled
                                        
                                        	Neighbor supports NSR
                                        	**type**\:  bool
                                        
                                        .. attribute:: nsr_state
                                        
                                        	NSR state
                                        	**type**\:   :py:class:`BgpSyncNbrNsrStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrStateEnum>`
                                        
                                        .. attribute:: open_check_error_code
                                        
                                        	Open check error code
                                        	**type**\:   :py:class:`BgpOpenCheckErrEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpOpenCheckErrEnum>`
                                        
                                        .. attribute:: peer_error_code
                                        
                                        	If peer closed, error received from transport
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: peer_reset_reason
                                        
                                        	Reason for last peer close event
                                        	**type**\:   :py:class:`BgpPeerResetReasonIndexEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPeerResetReasonIndexEnum>`
                                        
                                        .. attribute:: performance_statistics
                                        
                                        	Performance statistics
                                        	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics>`
                                        
                                        .. attribute:: previous_connection_state
                                        
                                        	Previous state of connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: read_armed
                                        
                                        	If true, socket has beenauto\-armed for read
                                        	**type**\:  bool
                                        
                                        .. attribute:: received_notification_info
                                        
                                        	Information on the last notification received
                                        	**type**\:   :py:class:`ReceivedNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo>`
                                        
                                        .. attribute:: remote_as
                                        
                                        	Remote AS number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_as_number
                                        
                                        	Remote AS number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reset_notification_sent
                                        
                                        	Notification was sent during last reset
                                        	**type**\:  bool
                                        
                                        .. attribute:: reset_reason
                                        
                                        	Reason for last connection reset
                                        	**type**\:   :py:class:`BgpResetReasonIndexEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndexEnum>`
                                        
                                        .. attribute:: router_id
                                        
                                        	Router ID for the neighbor
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rpki_allow_invalid
                                        
                                        	Prefix v. allow invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: rpki_disable
                                        
                                        	Prefix validation disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: rpki_signal_ibgp
                                        
                                        	Prefix v. signal ibgp
                                        	**type**\:  bool
                                        
                                        .. attribute:: rpki_use_validity
                                        
                                        	Prefix v. use validity
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_last_k_aexpiry_reset
                                        
                                        	Time (in secs) since second last KA timer expiry before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: second_last_k_astart_reset
                                        
                                        	Time (in secs) since the second last KA timer start before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: second_last_write_event
                                        
                                        	Time (in secs) since second last write thread event
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: send_notification_info
                                        
                                        	Information on the last notification sent
                                        	**type**\:   :py:class:`SendNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo>`
                                        
                                        .. attribute:: socket_read_bytes
                                        
                                        	Total read bytes value insocket\-lib
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: speaker_id
                                        
                                        	Speaker this neighbor is allocated to
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: standby_rp
                                        
                                        	Standby RP socket inited for Active Open
                                        	**type**\:  bool
                                        
                                        .. attribute:: suppress4_byte_as
                                        
                                        	Suppress 4byteas capability
                                        	**type**\:  bool
                                        
                                        .. attribute:: tcp_init_sync_done_time_spec
                                        
                                        	Time when neighbor entered TCP Init Sync Done
                                        	**type**\:   :py:class:`TcpInitSyncDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec>`
                                        
                                        .. attribute:: tcp_init_sync_phase_two_time_spec
                                        
                                        	Time when neighbor entered TCP Init Sync Phase Two
                                        	**type**\:   :py:class:`TcpInitSyncPhaseTwoTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec>`
                                        
                                        .. attribute:: tcp_init_sync_time_spec
                                        
                                        	Time When neighbor entered TCP Init Sync
                                        	**type**\:   :py:class:`TcpInitSyncTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec>`
                                        
                                        .. attribute:: tcp_session_open_mode
                                        
                                        	The TCP mode to be used to set up BGP session with the neighbor
                                        	**type**\:   :py:class:`BgpTcpModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpModeEnum>`
                                        
                                        .. attribute:: tcpmss
                                        
                                        	Neighbor TCP Maximum Segment                     size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_last_cb
                                        
                                        	CB
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: time_last_cb_reset
                                        
                                        	Last CB before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_last_fb
                                        
                                        	FB
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: time_since_connection_last_dropped
                                        
                                        	Time since the connection last went down (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_since_last_read
                                        
                                        	Time (in secs) since last read
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_since_last_read_reset
                                        
                                        	Time (in secs) since last read before last reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_since_last_update
                                        
                                        	Time (in secs) since last update message was received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_since_last_write
                                        
                                        	Time (in secs) since last write
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_since_last_write_reset
                                        
                                        	Time (in secs) since last write before last reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_since_second_last_write
                                        
                                        	Time (in secs) since second  last write
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_since_second_last_write_reset
                                        
                                        	Time (in secs) since last write before last reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: tos_type
                                        
                                        	Precedence or DSCP type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: tos_value
                                        
                                        	Precedence or DSCP value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ttl_security_enabled
                                        
                                        	TTL Security enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: update_bytes_read
                                        
                                        	Total update bytes read
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: update_messages_in
                                        
                                        	No. of update msgs received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_messages_out
                                        
                                        	No. of update messages sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: write_armed
                                        
                                        	If true, socket has beenauto\-armed for write
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.neighbor_address = None
                                            self.active_bmp_servers = None
                                            self.actual_last_write_bytes = None
                                            self.actual_last_write_reset_bytes = None
                                            self.actual_second_last_write_bytes = None
                                            self.actual_second_last_write_reset_bytes = None
                                            self.af_data = YList()
                                            self.af_data.parent = self
                                            self.af_data.name = 'af_data'
                                            self.attempted_last_write_bytes = None
                                            self.attempted_last_write_reset_bytes = None
                                            self.attempted_second_last_write_bytes = None
                                            self.attempted_second_last_write_reset_bytes = None
                                            self.bfd_minintervalval = None
                                            self.bfd_multiplierval = None
                                            self.bfd_session_created_state = None
                                            self.bfd_session_enable_mode = None
                                            self.bfd_session_state = None
                                            self.bfd_state_ts = None
                                            self.bytes_read = None
                                            self.bytes_written = None
                                            self.configured_hold_time = None
                                            self.configured_keepalive = None
                                            self.configured_min_acc_hold_time = None
                                            self.connect_retry_interval = None
                                            self.connection_admin_status = None
                                            self.connection_down_count = None
                                            self.connection_established_time = None
                                            self.connection_local_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress()
                                            self.connection_local_address.parent = self
                                            self.connection_local_port = None
                                            self.connection_remote_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress()
                                            self.connection_remote_address.parent = self
                                            self.connection_remote_port = None
                                            self.connection_state = None
                                            self.connection_up_count = None
                                            self.count_last_write = None
                                            self.description = None
                                            self.discard_as4_path = None
                                            self.discard_data_bytes = None
                                            self.dmz_link_bandwidth = None
                                            self.dynamic_neighbor = None
                                            self.ebgp_recv_dmz = None
                                            self.ebgp_send_dmz_mode = None
                                            self.ebgp_time_to_live = None
                                            self.egress_peer_engineering_enabled = None
                                            self.error_notifies_received = None
                                            self.error_notifies_sent = None
                                            self.fpbsn_offset = None
                                            self.fssn_offset = None
                                            self.gr_restart_time = None
                                            self.gr_stale_path_time = None
                                            self.graceful_maintenance = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance()
                                            self.graceful_maintenance.parent = self
                                            self.graceful_restart_enabled_nbr = None
                                            self.has_internal_link = None
                                            self.hold_time = None
                                            self.ignore_connected = None
                                            self.internal_vpn_client = None
                                            self.io_armed = None
                                            self.is4_byte_as_capability_received = None
                                            self.is4_byte_as_capability_sent = None
                                            self.is_administratively_shut_down = None
                                            self.is_capability_negotiation_performed = None
                                            self.is_capability_negotiation_suppressed = None
                                            self.is_ebgp_multihop_bgpmpls_forwarding_disabled = None
                                            self.is_ebgp_peer_as_league = None
                                            self.is_ebgp_peer_common_admin = None
                                            self.is_external_neighbor_not_directly_connected = None
                                            self.is_gr_aware = None
                                            self.is_local_address_configured = None
                                            self.is_neighbor_max_prefix_shutdown = None
                                            self.is_out_of_memory_forced_up = None
                                            self.is_out_of_memory_shutdown = None
                                            self.is_passive_close = None
                                            self.is_read_disabled = None
                                            self.is_route_refresh_capability_received = None
                                            self.is_route_refresh_old_capability_received = None
                                            self.keep_alive_time = None
                                            self.last_ackd_seq_no = None
                                            self.last_k_aerror_reset = None
                                            self.last_k_aexpiry_reset = None
                                            self.last_k_anotsent_reset = None
                                            self.last_k_astart_reset = None
                                            self.last_notify_error_code = None
                                            self.last_notify_error_subcode = None
                                            self.last_write_event = None
                                            self.local_as = None
                                            self.local_as_dual_as = None
                                            self.local_as_dual_as_mode_native = None
                                            self.local_as_no_prepend = None
                                            self.local_as_replace_as = None
                                            self.message_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics()
                                            self.message_statistics.parent = self
                                            self.messages_queued_in = None
                                            self.messages_queued_out = None
                                            self.messages_received = None
                                            self.messages_sent = None
                                            self.min_advertise_interval = None
                                            self.min_advertise_interval_msecs = None
                                            self.min_origination_interval = None
                                            self.msg_log_in = None
                                            self.msg_log_out = None
                                            self.multi_protocol_capability_received = None
                                            self.nbr_cluster_id = None
                                            self.nbr_enforce_first_as = None
                                            self.nbr_in_cluster = None
                                            self.negotiated_protocol_version = None
                                            self.neighbor_interface_handle = None
                                            self.neighbor_local_as = None
                                            self.nsr_enabled = None
                                            self.nsr_state = None
                                            self.open_check_error_code = None
                                            self.peer_error_code = None
                                            self.peer_reset_reason = None
                                            self.performance_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics()
                                            self.performance_statistics.parent = self
                                            self.previous_connection_state = None
                                            self.read_armed = None
                                            self.received_notification_info = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo()
                                            self.received_notification_info.parent = self
                                            self.remote_as = None
                                            self.remote_as_number = None
                                            self.reset_notification_sent = None
                                            self.reset_reason = None
                                            self.router_id = None
                                            self.rpki_allow_invalid = None
                                            self.rpki_disable = None
                                            self.rpki_signal_ibgp = None
                                            self.rpki_use_validity = None
                                            self.second_last_k_aexpiry_reset = None
                                            self.second_last_k_astart_reset = None
                                            self.second_last_write_event = None
                                            self.send_notification_info = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo()
                                            self.send_notification_info.parent = self
                                            self.socket_read_bytes = None
                                            self.speaker_id = None
                                            self.standby_rp = None
                                            self.suppress4_byte_as = None
                                            self.tcp_init_sync_done_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec()
                                            self.tcp_init_sync_done_time_spec.parent = self
                                            self.tcp_init_sync_phase_two_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec()
                                            self.tcp_init_sync_phase_two_time_spec.parent = self
                                            self.tcp_init_sync_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec()
                                            self.tcp_init_sync_time_spec.parent = self
                                            self.tcp_session_open_mode = None
                                            self.tcpmss = None
                                            self.time_last_cb = None
                                            self.time_last_cb_reset = None
                                            self.time_last_fb = None
                                            self.time_since_connection_last_dropped = None
                                            self.time_since_last_read = None
                                            self.time_since_last_read_reset = None
                                            self.time_since_last_update = None
                                            self.time_since_last_write = None
                                            self.time_since_last_write_reset = None
                                            self.time_since_second_last_write = None
                                            self.time_since_second_last_write_reset = None
                                            self.tos_type = None
                                            self.tos_value = None
                                            self.ttl_security_enabled = None
                                            self.update_bytes_read = None
                                            self.update_messages_in = None
                                            self.update_messages_out = None
                                            self.vrf_name = None
                                            self.write_armed = None


                                        class ConnectionLocalAddress(object):
                                            """
                                            Local address for the connection
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connection-local-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress']['meta_info']


                                        class ConnectionRemoteAddress(object):
                                            """
                                            Remote address for the connection
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connection-remote-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress']['meta_info']


                                        class SendNotificationInfo(object):
                                            """
                                            Information on the last notification sent
                                            
                                            .. attribute:: last_notification_data
                                            
                                            	Message data in last notification
                                            	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData>`
                                            
                                            .. attribute:: notification_error_code
                                            
                                            	Error code in last notification
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: notification_error_subcode
                                            
                                            	Error subcode in last notification
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: time_since_last_notification
                                            
                                            	Time since the last notification was sent or received (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.last_notification_data = YList()
                                                self.last_notification_data.parent = self
                                                self.last_notification_data.name = 'last_notification_data'
                                                self.notification_error_code = None
                                                self.notification_error_subcode = None
                                                self.time_since_last_notification = None


                                            class LastNotificationData(object):
                                                """
                                                Message data in last notification
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-notification-data'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:send-notification-info'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.last_notification_data is not None:
                                                    for child_ref in self.last_notification_data:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.notification_error_code is not None:
                                                    return True

                                                if self.notification_error_subcode is not None:
                                                    return True

                                                if self.time_since_last_notification is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo']['meta_info']


                                        class ReceivedNotificationInfo(object):
                                            """
                                            Information on the last notification received
                                            
                                            .. attribute:: last_notification_data
                                            
                                            	Message data in last notification
                                            	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData>`
                                            
                                            .. attribute:: notification_error_code
                                            
                                            	Error code in last notification
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: notification_error_subcode
                                            
                                            	Error subcode in last notification
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: time_since_last_notification
                                            
                                            	Time since the last notification was sent or received (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.last_notification_data = YList()
                                                self.last_notification_data.parent = self
                                                self.last_notification_data.name = 'last_notification_data'
                                                self.notification_error_code = None
                                                self.notification_error_subcode = None
                                                self.time_since_last_notification = None


                                            class LastNotificationData(object):
                                                """
                                                Message data in last notification
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-notification-data'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:received-notification-info'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.last_notification_data is not None:
                                                    for child_ref in self.last_notification_data:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.notification_error_code is not None:
                                                    return True

                                                if self.notification_error_subcode is not None:
                                                    return True

                                                if self.time_since_last_notification is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo']['meta_info']


                                        class PerformanceStatistics(object):
                                            """
                                            Performance statistics
                                            
                                            .. attribute:: active_collision
                                            
                                            	Number of Closed Active connections for this neighbor due to collision 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: actives
                                            
                                            	Number of retried Active opens for this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: control_to_read_thread_trigger
                                            
                                            	Number of times io\-control thread trigger read thread
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: control_to_write_thread_trigger
                                            
                                            	Number of times io\-control thread trigger write thread
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: data_bytes_read
                                            
                                            	No. of bytes of data read
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: data_bytes_written
                                            
                                            	No. of data bytes written
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: failed_post_actives
                                            
                                            	Number of Active Opens that failed in the Post Active State for this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: high_throttled_read
                                            
                                            	Num of socket reads after nbr crossed high threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: inbound_update_messages
                                            
                                            	Number of inbound update messages processed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: inbound_update_messages_time
                                            
                                            	Time spent processing inbound update messages (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: io_read_time
                                            
                                            	Time spent reading inbound data (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: io_write_time
                                            
                                            	Time spent writing outbound data (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: last_nsr_scoped_sync
                                            
                                            	Last time NSR scoped syncwas done for the neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_sent_seq_no
                                            
                                            	Seq No of the last sent byte
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: low_throttled_read
                                            
                                            	Num socket reads after nbrs crossed low threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_read_size
                                            
                                            	Size of largest socket (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: nbr_fd
                                            
                                            	Primary FD, per nbr
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: nbr_flags
                                            
                                            	Nbr flags, per thread
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: network_status
                                            
                                            	Socket status, TRUE if socket closed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nsr_oper_down_count
                                            
                                            	Number of times NSR scoped sync has been done
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: passive_collision
                                            
                                            	Number of Closed Remote opens for this neighborneighbor due to collision 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: passives
                                            
                                            	Number of retried Passive opens for this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: read_calls_count
                                            
                                            	No. of calls to function to read inbound data
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: read_messages_count
                                            
                                            	Number of BGP messages read
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: read_throttles
                                            
                                            	Number of partial read throttles
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rejected_passives
                                            
                                            	Number of rejected Passive opens for this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reset_flags
                                            
                                            	Reset flags, per thread
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reset_retries
                                            
                                            	Reset Retries, per nbr
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: subgroup_list_time
                                            
                                            	Time spent processing sub\-group message list  (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: sync_flags
                                            
                                            	Sync flags, per nbr
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_since_last_throttled_read
                                            
                                            	Time (in secs) since last read after being throttled
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: write_calls_count
                                            
                                            	No. of calls to function to write outbound data
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: write_queue_calls_count
                                            
                                            	No. of calls to function to process write queue
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: write_queue_messages_count
                                            
                                            	Number of write queue messages processed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: write_queue_time
                                            
                                            	Time spent processing write queue (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: write_subgroup_calls_count
                                            
                                            	No. of calls to function to process sub\-group message list
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: write_subgroup_messages_count
                                            
                                            	Number of sub\-group msgs processed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.active_collision = None
                                                self.actives = None
                                                self.control_to_read_thread_trigger = None
                                                self.control_to_write_thread_trigger = None
                                                self.data_bytes_read = None
                                                self.data_bytes_written = None
                                                self.failed_post_actives = None
                                                self.high_throttled_read = None
                                                self.inbound_update_messages = None
                                                self.inbound_update_messages_time = None
                                                self.io_read_time = None
                                                self.io_write_time = None
                                                self.last_nsr_scoped_sync = None
                                                self.last_sent_seq_no = None
                                                self.low_throttled_read = None
                                                self.maximum_read_size = None
                                                self.nbr_fd = None
                                                self.nbr_flags = None
                                                self.network_status = None
                                                self.nsr_oper_down_count = None
                                                self.passive_collision = None
                                                self.passives = None
                                                self.read_calls_count = None
                                                self.read_messages_count = None
                                                self.read_throttles = None
                                                self.rejected_passives = None
                                                self.reset_flags = None
                                                self.reset_retries = None
                                                self.subgroup_list_time = None
                                                self.sync_flags = None
                                                self.time_since_last_throttled_read = None
                                                self.write_calls_count = None
                                                self.write_queue_calls_count = None
                                                self.write_queue_messages_count = None
                                                self.write_queue_time = None
                                                self.write_subgroup_calls_count = None
                                                self.write_subgroup_messages_count = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:performance-statistics'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.active_collision is not None:
                                                    return True

                                                if self.actives is not None:
                                                    return True

                                                if self.control_to_read_thread_trigger is not None:
                                                    return True

                                                if self.control_to_write_thread_trigger is not None:
                                                    return True

                                                if self.data_bytes_read is not None:
                                                    return True

                                                if self.data_bytes_written is not None:
                                                    return True

                                                if self.failed_post_actives is not None:
                                                    return True

                                                if self.high_throttled_read is not None:
                                                    return True

                                                if self.inbound_update_messages is not None:
                                                    return True

                                                if self.inbound_update_messages_time is not None:
                                                    return True

                                                if self.io_read_time is not None:
                                                    return True

                                                if self.io_write_time is not None:
                                                    return True

                                                if self.last_nsr_scoped_sync is not None:
                                                    return True

                                                if self.last_sent_seq_no is not None:
                                                    return True

                                                if self.low_throttled_read is not None:
                                                    return True

                                                if self.maximum_read_size is not None:
                                                    return True

                                                if self.nbr_fd is not None:
                                                    return True

                                                if self.nbr_flags is not None:
                                                    return True

                                                if self.network_status is not None:
                                                    return True

                                                if self.nsr_oper_down_count is not None:
                                                    return True

                                                if self.passive_collision is not None:
                                                    return True

                                                if self.passives is not None:
                                                    return True

                                                if self.read_calls_count is not None:
                                                    return True

                                                if self.read_messages_count is not None:
                                                    return True

                                                if self.read_throttles is not None:
                                                    return True

                                                if self.rejected_passives is not None:
                                                    return True

                                                if self.reset_flags is not None:
                                                    return True

                                                if self.reset_retries is not None:
                                                    return True

                                                if self.subgroup_list_time is not None:
                                                    return True

                                                if self.sync_flags is not None:
                                                    return True

                                                if self.time_since_last_throttled_read is not None:
                                                    return True

                                                if self.write_calls_count is not None:
                                                    return True

                                                if self.write_queue_calls_count is not None:
                                                    return True

                                                if self.write_queue_messages_count is not None:
                                                    return True

                                                if self.write_queue_time is not None:
                                                    return True

                                                if self.write_subgroup_calls_count is not None:
                                                    return True

                                                if self.write_subgroup_messages_count is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics']['meta_info']


                                        class MessageStatistics(object):
                                            """
                                            Message statistics
                                            
                                            .. attribute:: keepalive
                                            
                                            	Keepalive
                                            	**type**\:   :py:class:`Keepalive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive>`
                                            
                                            .. attribute:: notification
                                            
                                            	Notification
                                            	**type**\:   :py:class:`Notification <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification>`
                                            
                                            .. attribute:: open
                                            
                                            	Open
                                            	**type**\:   :py:class:`Open <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open>`
                                            
                                            .. attribute:: route_refresh
                                            
                                            	Route refresh
                                            	**type**\:   :py:class:`RouteRefresh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh>`
                                            
                                            .. attribute:: total
                                            
                                            	Total
                                            	**type**\:   :py:class:`Total <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total>`
                                            
                                            .. attribute:: update
                                            
                                            	Update
                                            	**type**\:   :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.keepalive = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive()
                                                self.keepalive.parent = self
                                                self.notification = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification()
                                                self.notification.parent = self
                                                self.open = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open()
                                                self.open.parent = self
                                                self.route_refresh = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh()
                                                self.route_refresh.parent = self
                                                self.total = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total()
                                                self.total.parent = self
                                                self.update = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update()
                                                self.update.parent = self


                                            class Open(object):
                                                """
                                                Open
                                                
                                                .. attribute:: rx
                                                
                                                	Receive
                                                	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx>`
                                                
                                                .. attribute:: tx
                                                
                                                	Transmit
                                                	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.rx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx()
                                                    self.rx.parent = self
                                                    self.tx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx()
                                                    self.tx.parent = self


                                                class Tx(object):
                                                    """
                                                    Transmit
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.count = None
                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec()
                                                        self.last_time_spec.parent = self


                                                    class LastTimeSpec(object):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.nanoseconds = None
                                                            self.seconds = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.nanoseconds is not None:
                                                                return True

                                                            if self.seconds is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.count is not None:
                                                            return True

                                                        if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx']['meta_info']


                                                class Rx(object):
                                                    """
                                                    Receive
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.count = None
                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec()
                                                        self.last_time_spec.parent = self


                                                    class LastTimeSpec(object):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.nanoseconds = None
                                                            self.seconds = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.nanoseconds is not None:
                                                                return True

                                                            if self.seconds is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.count is not None:
                                                            return True

                                                        if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:open'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.rx is not None and self.rx._has_data():
                                                        return True

                                                    if self.tx is not None and self.tx._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open']['meta_info']


                                            class Notification(object):
                                                """
                                                Notification
                                                
                                                .. attribute:: rx
                                                
                                                	Receive
                                                	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx>`
                                                
                                                .. attribute:: tx
                                                
                                                	Transmit
                                                	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.rx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx()
                                                    self.rx.parent = self
                                                    self.tx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx()
                                                    self.tx.parent = self


                                                class Tx(object):
                                                    """
                                                    Transmit
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.count = None
                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec()
                                                        self.last_time_spec.parent = self


                                                    class LastTimeSpec(object):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.nanoseconds = None
                                                            self.seconds = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.nanoseconds is not None:
                                                                return True

                                                            if self.seconds is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.count is not None:
                                                            return True

                                                        if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx']['meta_info']


                                                class Rx(object):
                                                    """
                                                    Receive
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.count = None
                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec()
                                                        self.last_time_spec.parent = self


                                                    class LastTimeSpec(object):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.nanoseconds = None
                                                            self.seconds = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.nanoseconds is not None:
                                                                return True

                                                            if self.seconds is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.count is not None:
                                                            return True

                                                        if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:notification'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.rx is not None and self.rx._has_data():
                                                        return True

                                                    if self.tx is not None and self.tx._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification']['meta_info']


                                            class Update(object):
                                                """
                                                Update
                                                
                                                .. attribute:: rx
                                                
                                                	Receive
                                                	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx>`
                                                
                                                .. attribute:: tx
                                                
                                                	Transmit
                                                	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.rx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx()
                                                    self.rx.parent = self
                                                    self.tx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx()
                                                    self.tx.parent = self


                                                class Tx(object):
                                                    """
                                                    Transmit
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.count = None
                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec()
                                                        self.last_time_spec.parent = self


                                                    class LastTimeSpec(object):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.nanoseconds = None
                                                            self.seconds = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.nanoseconds is not None:
                                                                return True

                                                            if self.seconds is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.count is not None:
                                                            return True

                                                        if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx']['meta_info']


                                                class Rx(object):
                                                    """
                                                    Receive
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.count = None
                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec()
                                                        self.last_time_spec.parent = self


                                                    class LastTimeSpec(object):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.nanoseconds = None
                                                            self.seconds = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.nanoseconds is not None:
                                                                return True

                                                            if self.seconds is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.count is not None:
                                                            return True

                                                        if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.rx is not None and self.rx._has_data():
                                                        return True

                                                    if self.tx is not None and self.tx._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update']['meta_info']


                                            class Keepalive(object):
                                                """
                                                Keepalive
                                                
                                                .. attribute:: rx
                                                
                                                	Receive
                                                	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx>`
                                                
                                                .. attribute:: tx
                                                
                                                	Transmit
                                                	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.rx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx()
                                                    self.rx.parent = self
                                                    self.tx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx()
                                                    self.tx.parent = self


                                                class Tx(object):
                                                    """
                                                    Transmit
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.count = None
                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec()
                                                        self.last_time_spec.parent = self


                                                    class LastTimeSpec(object):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.nanoseconds = None
                                                            self.seconds = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.nanoseconds is not None:
                                                                return True

                                                            if self.seconds is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.count is not None:
                                                            return True

                                                        if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx']['meta_info']


                                                class Rx(object):
                                                    """
                                                    Receive
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.count = None
                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec()
                                                        self.last_time_spec.parent = self


                                                    class LastTimeSpec(object):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.nanoseconds = None
                                                            self.seconds = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.nanoseconds is not None:
                                                                return True

                                                            if self.seconds is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.count is not None:
                                                            return True

                                                        if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:keepalive'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.rx is not None and self.rx._has_data():
                                                        return True

                                                    if self.tx is not None and self.tx._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive']['meta_info']


                                            class RouteRefresh(object):
                                                """
                                                Route refresh
                                                
                                                .. attribute:: rx
                                                
                                                	Receive
                                                	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx>`
                                                
                                                .. attribute:: tx
                                                
                                                	Transmit
                                                	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.rx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx()
                                                    self.rx.parent = self
                                                    self.tx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx()
                                                    self.tx.parent = self


                                                class Tx(object):
                                                    """
                                                    Transmit
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.count = None
                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec()
                                                        self.last_time_spec.parent = self


                                                    class LastTimeSpec(object):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.nanoseconds = None
                                                            self.seconds = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.nanoseconds is not None:
                                                                return True

                                                            if self.seconds is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.count is not None:
                                                            return True

                                                        if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx']['meta_info']


                                                class Rx(object):
                                                    """
                                                    Receive
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.count = None
                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec()
                                                        self.last_time_spec.parent = self


                                                    class LastTimeSpec(object):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.nanoseconds = None
                                                            self.seconds = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.nanoseconds is not None:
                                                                return True

                                                            if self.seconds is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.count is not None:
                                                            return True

                                                        if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:route-refresh'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.rx is not None and self.rx._has_data():
                                                        return True

                                                    if self.tx is not None and self.tx._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh']['meta_info']


                                            class Total(object):
                                                """
                                                Total
                                                
                                                .. attribute:: rx
                                                
                                                	Receive
                                                	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx>`
                                                
                                                .. attribute:: tx
                                                
                                                	Transmit
                                                	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.rx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx()
                                                    self.rx.parent = self
                                                    self.tx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx()
                                                    self.tx.parent = self


                                                class Tx(object):
                                                    """
                                                    Transmit
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.count = None
                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec()
                                                        self.last_time_spec.parent = self


                                                    class LastTimeSpec(object):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.nanoseconds = None
                                                            self.seconds = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.nanoseconds is not None:
                                                                return True

                                                            if self.seconds is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.count is not None:
                                                            return True

                                                        if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx']['meta_info']


                                                class Rx(object):
                                                    """
                                                    Receive
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.count = None
                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec()
                                                        self.last_time_spec.parent = self


                                                    class LastTimeSpec(object):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.nanoseconds = None
                                                            self.seconds = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.nanoseconds is not None:
                                                                return True

                                                            if self.seconds is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.count is not None:
                                                            return True

                                                        if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:total'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.rx is not None and self.rx._has_data():
                                                        return True

                                                    if self.tx is not None and self.tx._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:message-statistics'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.keepalive is not None and self.keepalive._has_data():
                                                    return True

                                                if self.notification is not None and self.notification._has_data():
                                                    return True

                                                if self.open is not None and self.open._has_data():
                                                    return True

                                                if self.route_refresh is not None and self.route_refresh._has_data():
                                                    return True

                                                if self.total is not None and self.total._has_data():
                                                    return True

                                                if self.update is not None and self.update._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics']['meta_info']


                                        class TcpInitSyncTimeSpec(object):
                                            """
                                            Time When neighbor entered TCP Init Sync
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tcp-init-sync-time-spec'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec']['meta_info']


                                        class TcpInitSyncPhaseTwoTimeSpec(object):
                                            """
                                            Time when neighbor entered TCP Init Sync Phase
                                            Two
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tcp-init-sync-phase-two-time-spec'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec']['meta_info']


                                        class TcpInitSyncDoneTimeSpec(object):
                                            """
                                            Time when neighbor entered TCP Init Sync Done
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tcp-init-sync-done-time-spec'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec']['meta_info']


                                        class GracefulMaintenance(object):
                                            """
                                            Graceful Maintenance
                                            
                                            .. attribute:: gshut_active
                                            
                                            	Graceful Maintenance activated
                                            	**type**\:  bool
                                            
                                            .. attribute:: gshut_exists
                                            
                                            	Graceful Maintenance enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: gshut_local_active
                                            
                                            	Graceful Maintenance locally activated
                                            	**type**\:  bool
                                            
                                            .. attribute:: gshut_locpref
                                            
                                            	Graceful Maintenance Local Preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: gshut_locpref_set
                                            
                                            	Graceful Maintenance Local Preference set
                                            	**type**\:  bool
                                            
                                            .. attribute:: gshut_prepends
                                            
                                            	Graceful Maintenance number of AS prepends
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.gshut_active = None
                                                self.gshut_exists = None
                                                self.gshut_local_active = None
                                                self.gshut_locpref = None
                                                self.gshut_locpref_set = None
                                                self.gshut_prepends = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:graceful-maintenance'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.gshut_active is not None:
                                                    return True

                                                if self.gshut_exists is not None:
                                                    return True

                                                if self.gshut_local_active is not None:
                                                    return True

                                                if self.gshut_locpref is not None:
                                                    return True

                                                if self.gshut_locpref_set is not None:
                                                    return True

                                                if self.gshut_prepends is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance']['meta_info']


                                        class AfData(object):
                                            """
                                            Address family specific neighbor data
                                            
                                            .. attribute:: accept_own_enabled
                                            
                                            	Accept\-Own enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: acked_version
                                            
                                            	Version mapped from acked seqNo
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: address_family_long_lived_time
                                            
                                            	AF specific Long\-lived\-time config
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertise_afi
                                            
                                            	Encode in Advertise AFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_afi_def_vrf_imp_disable
                                            
                                            	Advertise of default VRF import disable
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_afi_disable
                                            
                                            	Encode in Advertise AFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_afi_eo_r_ready
                                            
                                            	EoR Can be sent for Advertise AFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_afi_reorg
                                            
                                            	Encode in Advertise AFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_afi_vrf_re_imp_disable
                                            
                                            	Advertise of VRF re\-import disable
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_evp_nv4afi_def_vrf_imp_disable
                                            
                                            	Advertise of v4 default VRF import disable
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_evp_nv4afi_vrf_re_imp_disable
                                            
                                            	Advertise of v4 VRF re\-import disable
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_evp_nv6afi_def_vrf_imp_disable
                                            
                                            	Advertise of v6 default VRF import disable
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_evp_nv6afi_vrf_re_imp_disable
                                            
                                            	Advertise of v6 VRF re\-import disable
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_local_labeled_route_unicast
                                            
                                            	Advertise routes with local\-label via Unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_rt_type
                                            
                                            	Advertise RT type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: advertise_v4_flags
                                            
                                            	Advertise options for VPNV4
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertise_v6_flags
                                            
                                            	Advertise options for VPNV6
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: afrpki_allow_invalid
                                            
                                            	Prefix v. allow invalid
                                            	**type**\:  bool
                                            
                                            .. attribute:: afrpki_disable
                                            
                                            	Prefix validation disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: afrpki_signal_ibgp
                                            
                                            	Prefix v. signal ibgp
                                            	**type**\:  bool
                                            
                                            .. attribute:: afrpki_use_validity
                                            
                                            	Prefix v. use validity
                                            	**type**\:  bool
                                            
                                            .. attribute:: allow_as_in_count
                                            
                                            	Allowas\-in count config
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: always_use_next_hop_local
                                            
                                            	Local router always used for next\-hop
                                            	**type**\:  bool
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation type
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: eo_r_received_in_read_only
                                            
                                            	An EoR was received while in read\-only mode
                                            	**type**\:  bool
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_standby
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunityStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby>`
                                            
                                            .. attribute:: filter_group_index
                                            
                                            	Filter group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: flowspec_redirect_validation_d_isable
                                            
                                            	Flowspec Redirect Validation Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: flowspec_validation_d_isable
                                            
                                            	Flowspec Validation Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: import_reoriginate
                                            
                                            	Import Reoriginate enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: import_reoriginate_stitching
                                            
                                            	Import Reoriginate Stitching enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: import_stitching
                                            
                                            	Import Stitching enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_add_path_receive_capability_advertised
                                            
                                            	Addpath Receive capability advertised
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_add_path_receive_capability_received
                                            
                                            	Addpath Receive capability received
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_add_path_send_capability_advertised
                                            
                                            	Addpath Send capability advertised
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_add_path_send_capability_received
                                            
                                            	Addpath Send capability received
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_addpath_receive_operational
                                            
                                            	Addpath is operational on receive\-side
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_addpath_send_operational
                                            
                                            	Addpath is operational on send\-side
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertise_permanent_network
                                            
                                            	Advertise Permanent Network
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertised_graceful_restart
                                            
                                            	Graceful Restart Capability advertised
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertised_orf_receive
                                            
                                            	Prefix based ORF receive mode capability advertised
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertised_orf_send
                                            
                                            	Prefix based ORF send mode capability advertised
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_set
                                            
                                            	AIGP set 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_allow_as_in_set
                                            
                                            	Allowas\-in set 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_override_set
                                            
                                            	As override set 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_default_originate_sent
                                            
                                            	Default origination update sent
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ext_nh_encoding_capability_received
                                            
                                            	Extended nexthop encoding capability received
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ext_nh_encoding_capability_sent
                                            
                                            	Extended nexhop encoding capability Sent
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_state_flag
                                            
                                            	Restart state flag enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_legacy_pe_rt
                                            
                                            	Nbr accepts route from legacy PE for RT\-Constraint AF 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_af_capable
                                            
                                            	Address family capability received from neighbor
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_ebgp_without_inbound_policy
                                            
                                            	eBGP neighbor with no configured inbound policy
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_ebgp_without_outbound_policy
                                            
                                            	eBGP neighbor with no configured outbound policy
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_route_reflector_client
                                            
                                            	Nbr is a route reflector client
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orf_send_scheduled
                                            
                                            	Scheduled to send prefix based ORF
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orf_sent
                                            
                                            	Outbound route filter sent to neighbor
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orr_root_address_configured
                                            
                                            	ORR Root address configuredfor the neighbor connection
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_peer_orf_capable
                                            
                                            	Peer has outbound route filter capability
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_prefix_orf_present
                                            
                                            	Outbound route filter prefix ORF present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_graceful_restart_capable
                                            
                                            	Graceful Restart Capability received
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_orf_receive_capable
                                            
                                            	Prefix based ORF receive mode capability received
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_orf_send_capable
                                            
                                            	Prefix based ORF send mode capability received
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rt_present
                                            
                                            	RT attribute list present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rt_present_standby
                                            
                                            	RT attribute list present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_send_mcast_attr
                                            
                                            	Send Mcast Attr
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_soft_reconfiguration_inbound_allowed
                                            
                                            	Inbound soft reconfiguration allowed
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_update_deferred
                                            
                                            	Update deferred until ORF/route refresh received
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_update_leaving
                                            
                                            	Nbr leaving update\-groupto another
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_update_throttled
                                            
                                            	Updates Throttled becausewrite limit is reached
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_use_soft_reconfiguration_always_on
                                            
                                            	Soft reconf overrides route refresh
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_restart_time
                                            
                                            	Local Restart time (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: long_lived_graceful_restart_capability_received
                                            
                                            	Long\-lived graceful\-restart capability received from the neighbor
                                            	**type**\:  bool
                                            
                                            .. attribute:: long_lived_graceful_restart_stale_time_accept
                                            
                                            	Maximum long\-lived graceful\-restart stale time acceptable from the neighbor (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: long_lived_graceful_restart_stale_time_configured
                                            
                                            	Long\-lived graceful\-restart stale time is configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: long_lived_graceful_restart_stale_time_received
                                            
                                            	Long\-lived graceful\-restart stale time received from the neighbor (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: long_lived_graceful_restart_stale_time_sent
                                            
                                            	Stale time sent in long\-lived graceful\-restart capability (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: max_prefix_discard_extra_paths
                                            
                                            	Discard extra paths when prefix limit reached
                                            	**type**\:  bool
                                            
                                            .. attribute:: max_prefix_exceed_discard_paths
                                            
                                            	Did we discard extra paths when prefix limit reached
                                            	**type**\:  bool
                                            
                                            .. attribute:: max_prefix_limit
                                            
                                            	Max limit for # of prefixes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: max_prefix_restart_time
                                            
                                            	Time interval (in minutes) after which peering session will be reestablished
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: minute
                                            
                                            .. attribute:: max_prefix_threshold_percent
                                            
                                            	Percentage of maximum no. of prefixes at which to generate warning
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: percentage
                                            
                                            .. attribute:: neighbor_af_performance_statistics
                                            
                                            	Neighbor AF statistics
                                            	**type**\:   :py:class:`NeighborAfPerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics>`
                                            
                                            .. attribute:: neighbor_default_originate
                                            
                                            	Neighbor originates default
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_long_lived_graceful_restart_capable
                                            
                                            	Treat neighbor as long\-lived graceful\-restart capable
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_long_lived_graceful_restart_time_remaining
                                            
                                            	Remaining long\-lived graceful\-restart time
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_preserved_forwarding_state
                                            
                                            	Neighbor preserved forwarding state
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_preserved_long_lived_forwarding_state
                                            
                                            	Neighbor preserved long\-lived forwarding state
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_version
                                            
                                            	Neighbor version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: number_of_best_externalpaths
                                            
                                            	No. of best\-external paths from this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: number_of_bestpaths
                                            
                                            	No. of bestpaths from this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: orf_entries_received
                                            
                                            	Number of outbound route filter entries received
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: orr_group_index
                                            
                                            	ORR Group Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: orr_group_name
                                            
                                            	ORR Group Name
                                            	**type**\:  str
                                            
                                            .. attribute:: outstanding_version
                                            
                                            	Version mapped from acked seqNo that was synced last
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: outstanding_version_max
                                            
                                            	Version mapped from acked seqNo that was synced last
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_accepted
                                            
                                            	No. of prefixes accepted
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_advertised
                                            
                                            	No. of prefixes advertised
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_be_advertised
                                            
                                            	No BE prefixes advertised
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_denied
                                            
                                            	No. of prefixes denied
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_denied_no_policy
                                            
                                            	No. of prefixes denied because there was no inbound policy
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_denied_non_cumulative
                                            
                                            	No. of prefixes exactly denied (non cumulative)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_denied_orf_policy
                                            
                                            	No. of prefixes denied by prefix based ORF policy
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_denied_policy
                                            
                                            	No. of prefixes denied by inbound policy
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_denied_rt_permit
                                            
                                            	No. of prefixes denied because RT extended community is not imported
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_suppressed
                                            
                                            	No. of prefixes suppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_synced
                                            
                                            	Number of prefixes synced to standby
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_withdrawn
                                            
                                            	No. of prefixes withdrawn
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_withdrawn_not_found
                                            
                                            	No. of prefixes withdrawn but not found
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: refresh_acked_version
                                            
                                            	Version acked by the peer for refresh updates sent
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: refresh_target_version
                                            
                                            	Target version for refresh update generation
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: refresh_version
                                            
                                            	Version till which refresh updates have been generated
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remove_private_as_entire_aspath_from_inbound_updates
                                            
                                            	Private AS numbers removed from updates from this nbr only if the aspath has only private ASes
                                            	**type**\:  bool
                                            
                                            .. attribute:: remove_private_as_entire_aspath_from_updates
                                            
                                            	Private AS numbers removed from updates to thisnbr only if the aspath hasonly private ASes
                                            	**type**\:  bool
                                            
                                            .. attribute:: remove_private_as_from_inbound_updates
                                            
                                            	Private AS numbers removed from updates from this nbr
                                            	**type**\:  bool
                                            
                                            .. attribute:: remove_private_as_from_updates
                                            
                                            	Private AS numbers removed from updates to this nbr
                                            	**type**\:  bool
                                            
                                            .. attribute:: restart_time
                                            
                                            	Restart time advertised (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: rib_purge_timeout_value
                                            
                                            	RIB purge timeout time (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: route_policy_default_originate
                                            
                                            	Default\-originate route policy name
                                            	**type**\:  str
                                            
                                            .. attribute:: route_policy_in
                                            
                                            	Incoming route policy name
                                            	**type**\:  str
                                            
                                            .. attribute:: route_policy_out
                                            
                                            	Outgoing route policy name
                                            	**type**\:  str
                                            
                                            .. attribute:: route_policy_prefix_orf
                                            
                                            	Prefix based ORF for incoming updates
                                            	**type**\:  str
                                            
                                            .. attribute:: route_refreshes_received
                                            
                                            	Number of route refresh requests received
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_refreshes_sent
                                            
                                            	Number of route refresh requests sent
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: selective_multipath_eligible
                                            
                                            	Selective multipath eligible
                                            	**type**\:  bool
                                            
                                            .. attribute:: sent_community_to_neighbor
                                            
                                            	Community attribute sent to neighbor
                                            	**type**\:  bool
                                            
                                            .. attribute:: sent_extended_community_to_neighbor
                                            
                                            	Extended community attribute sent to neighbor
                                            	**type**\:  bool
                                            
                                            .. attribute:: sent_gshut_community_to_neighbor
                                            
                                            	GSHUT Community attribute sent to neighbor
                                            	**type**\:  bool
                                            
                                            .. attribute:: stale_path_timeout
                                            
                                            	Stale path timeout time (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: synced_acked_version
                                            
                                            	Version mapped from acked seqNo that was synced last
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: use_max_prefix_warning_only
                                            
                                            	Warning only when maximum prefix limit reached
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_update_gen_enabled
                                            
                                            	RT Nbr enabled for updategento another
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_update_gen_trigger_enabled
                                            
                                            	RT Nbr enabled for updategento another
                                            	**type**\:  bool
                                            
                                            .. attribute:: weight
                                            
                                            	Weight for this AF
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.accept_own_enabled = None
                                                self.acked_version = None
                                                self.address_family_long_lived_time = None
                                                self.advertise_afi = None
                                                self.advertise_afi_def_vrf_imp_disable = None
                                                self.advertise_afi_disable = None
                                                self.advertise_afi_eo_r_ready = None
                                                self.advertise_afi_reorg = None
                                                self.advertise_afi_vrf_re_imp_disable = None
                                                self.advertise_evp_nv4afi_def_vrf_imp_disable = None
                                                self.advertise_evp_nv4afi_vrf_re_imp_disable = None
                                                self.advertise_evp_nv6afi_def_vrf_imp_disable = None
                                                self.advertise_evp_nv6afi_vrf_re_imp_disable = None
                                                self.advertise_local_labeled_route_unicast = None
                                                self.advertise_rt_type = None
                                                self.advertise_v4_flags = None
                                                self.advertise_v6_flags = None
                                                self.af_name = None
                                                self.afrpki_allow_invalid = None
                                                self.afrpki_disable = None
                                                self.afrpki_signal_ibgp = None
                                                self.afrpki_use_validity = None
                                                self.allow_as_in_count = None
                                                self.always_use_next_hop_local = None
                                                self.encapsulation_type = None
                                                self.eo_r_received_in_read_only = None
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.extended_community_standby = YList()
                                                self.extended_community_standby.parent = self
                                                self.extended_community_standby.name = 'extended_community_standby'
                                                self.filter_group_index = None
                                                self.flowspec_redirect_validation_d_isable = None
                                                self.flowspec_validation_d_isable = None
                                                self.import_reoriginate = None
                                                self.import_reoriginate_stitching = None
                                                self.import_stitching = None
                                                self.is_add_path_receive_capability_advertised = None
                                                self.is_add_path_receive_capability_received = None
                                                self.is_add_path_send_capability_advertised = None
                                                self.is_add_path_send_capability_received = None
                                                self.is_addpath_receive_operational = None
                                                self.is_addpath_send_operational = None
                                                self.is_advertise_permanent_network = None
                                                self.is_advertised_graceful_restart = None
                                                self.is_advertised_orf_receive = None
                                                self.is_advertised_orf_send = None
                                                self.is_aigp_set = None
                                                self.is_allow_as_in_set = None
                                                self.is_as_override_set = None
                                                self.is_default_originate_sent = None
                                                self.is_ext_nh_encoding_capability_received = None
                                                self.is_ext_nh_encoding_capability_sent = None
                                                self.is_graceful_restart_state_flag = None
                                                self.is_legacy_pe_rt = None
                                                self.is_neighbor_af_capable = None
                                                self.is_neighbor_ebgp_without_inbound_policy = None
                                                self.is_neighbor_ebgp_without_outbound_policy = None
                                                self.is_neighbor_route_reflector_client = None
                                                self.is_orf_send_scheduled = None
                                                self.is_orf_sent = None
                                                self.is_orr_root_address_configured = None
                                                self.is_peer_orf_capable = None
                                                self.is_prefix_orf_present = None
                                                self.is_received_graceful_restart_capable = None
                                                self.is_received_orf_receive_capable = None
                                                self.is_received_orf_send_capable = None
                                                self.is_rt_present = None
                                                self.is_rt_present_standby = None
                                                self.is_send_mcast_attr = None
                                                self.is_soft_reconfiguration_inbound_allowed = None
                                                self.is_update_deferred = None
                                                self.is_update_leaving = None
                                                self.is_update_throttled = None
                                                self.is_use_soft_reconfiguration_always_on = None
                                                self.local_restart_time = None
                                                self.long_lived_graceful_restart_capability_received = None
                                                self.long_lived_graceful_restart_stale_time_accept = None
                                                self.long_lived_graceful_restart_stale_time_configured = None
                                                self.long_lived_graceful_restart_stale_time_received = None
                                                self.long_lived_graceful_restart_stale_time_sent = None
                                                self.max_prefix_discard_extra_paths = None
                                                self.max_prefix_exceed_discard_paths = None
                                                self.max_prefix_limit = None
                                                self.max_prefix_restart_time = None
                                                self.max_prefix_threshold_percent = None
                                                self.neighbor_af_performance_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics()
                                                self.neighbor_af_performance_statistics.parent = self
                                                self.neighbor_default_originate = None
                                                self.neighbor_long_lived_graceful_restart_capable = None
                                                self.neighbor_long_lived_graceful_restart_time_remaining = None
                                                self.neighbor_preserved_forwarding_state = None
                                                self.neighbor_preserved_long_lived_forwarding_state = None
                                                self.neighbor_version = None
                                                self.number_of_best_externalpaths = None
                                                self.number_of_bestpaths = None
                                                self.orf_entries_received = None
                                                self.orr_group_index = None
                                                self.orr_group_name = None
                                                self.outstanding_version = None
                                                self.outstanding_version_max = None
                                                self.prefixes_accepted = None
                                                self.prefixes_advertised = None
                                                self.prefixes_be_advertised = None
                                                self.prefixes_denied = None
                                                self.prefixes_denied_no_policy = None
                                                self.prefixes_denied_non_cumulative = None
                                                self.prefixes_denied_orf_policy = None
                                                self.prefixes_denied_policy = None
                                                self.prefixes_denied_rt_permit = None
                                                self.prefixes_suppressed = None
                                                self.prefixes_synced = None
                                                self.prefixes_withdrawn = None
                                                self.prefixes_withdrawn_not_found = None
                                                self.refresh_acked_version = None
                                                self.refresh_target_version = None
                                                self.refresh_version = None
                                                self.remove_private_as_entire_aspath_from_inbound_updates = None
                                                self.remove_private_as_entire_aspath_from_updates = None
                                                self.remove_private_as_from_inbound_updates = None
                                                self.remove_private_as_from_updates = None
                                                self.restart_time = None
                                                self.rib_purge_timeout_value = None
                                                self.route_policy_default_originate = None
                                                self.route_policy_in = None
                                                self.route_policy_out = None
                                                self.route_policy_prefix_orf = None
                                                self.route_refreshes_received = None
                                                self.route_refreshes_sent = None
                                                self.selective_multipath_eligible = None
                                                self.sent_community_to_neighbor = None
                                                self.sent_extended_community_to_neighbor = None
                                                self.sent_gshut_community_to_neighbor = None
                                                self.stale_path_timeout = None
                                                self.synced_acked_version = None
                                                self.update_group_number = None
                                                self.use_max_prefix_warning_only = None
                                                self.vpn_update_gen_enabled = None
                                                self.vpn_update_gen_trigger_enabled = None
                                                self.weight = None


                                            class NeighborAfPerformanceStatistics(object):
                                                """
                                                Neighbor AF statistics
                                                
                                                .. attribute:: processed_messages
                                                
                                                	Number of messages processed from the neighbor's write queue
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sent_messages
                                                
                                                	Number of messages sent from the neighbor's write queue
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: split_horizon_update_blocked
                                                
                                                	No. of update messages with split\-horizon flag that were blocked
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: split_horizon_update_transmit
                                                
                                                	No. of update messages with split\-horizon flag that were sent out
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: split_horizon_withdraw_blocked
                                                
                                                	No. of withdraw messages with split\-horizon flag that were blocked
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: split_horizon_withdraw_transmit
                                                
                                                	No. of withdraw messages with split\-horizon flag that were sent out
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sub_group_pending_message_count
                                                
                                                	No. of sub\-group messages waiting to be sent out on this neighbor \-\- DEPRECATED \-\- 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.processed_messages = None
                                                    self.sent_messages = None
                                                    self.split_horizon_update_blocked = None
                                                    self.split_horizon_update_transmit = None
                                                    self.split_horizon_withdraw_blocked = None
                                                    self.split_horizon_withdraw_transmit = None
                                                    self.sub_group_pending_message_count = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-af-performance-statistics'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.processed_messages is not None:
                                                        return True

                                                    if self.sent_messages is not None:
                                                        return True

                                                    if self.split_horizon_update_blocked is not None:
                                                        return True

                                                    if self.split_horizon_update_transmit is not None:
                                                        return True

                                                    if self.split_horizon_withdraw_blocked is not None:
                                                        return True

                                                    if self.split_horizon_withdraw_transmit is not None:
                                                        return True

                                                    if self.sub_group_pending_message_count is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity']['meta_info']


                                            class ExtendedCommunityStandby(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community-standby'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af-data'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.accept_own_enabled is not None:
                                                    return True

                                                if self.acked_version is not None:
                                                    return True

                                                if self.address_family_long_lived_time is not None:
                                                    return True

                                                if self.advertise_afi is not None:
                                                    return True

                                                if self.advertise_afi_def_vrf_imp_disable is not None:
                                                    return True

                                                if self.advertise_afi_disable is not None:
                                                    return True

                                                if self.advertise_afi_eo_r_ready is not None:
                                                    return True

                                                if self.advertise_afi_reorg is not None:
                                                    return True

                                                if self.advertise_afi_vrf_re_imp_disable is not None:
                                                    return True

                                                if self.advertise_evp_nv4afi_def_vrf_imp_disable is not None:
                                                    return True

                                                if self.advertise_evp_nv4afi_vrf_re_imp_disable is not None:
                                                    return True

                                                if self.advertise_evp_nv6afi_def_vrf_imp_disable is not None:
                                                    return True

                                                if self.advertise_evp_nv6afi_vrf_re_imp_disable is not None:
                                                    return True

                                                if self.advertise_local_labeled_route_unicast is not None:
                                                    return True

                                                if self.advertise_rt_type is not None:
                                                    return True

                                                if self.advertise_v4_flags is not None:
                                                    return True

                                                if self.advertise_v6_flags is not None:
                                                    return True

                                                if self.af_name is not None:
                                                    return True

                                                if self.afrpki_allow_invalid is not None:
                                                    return True

                                                if self.afrpki_disable is not None:
                                                    return True

                                                if self.afrpki_signal_ibgp is not None:
                                                    return True

                                                if self.afrpki_use_validity is not None:
                                                    return True

                                                if self.allow_as_in_count is not None:
                                                    return True

                                                if self.always_use_next_hop_local is not None:
                                                    return True

                                                if self.encapsulation_type is not None:
                                                    return True

                                                if self.eo_r_received_in_read_only is not None:
                                                    return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community_standby is not None:
                                                    for child_ref in self.extended_community_standby:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.filter_group_index is not None:
                                                    return True

                                                if self.flowspec_redirect_validation_d_isable is not None:
                                                    return True

                                                if self.flowspec_validation_d_isable is not None:
                                                    return True

                                                if self.import_reoriginate is not None:
                                                    return True

                                                if self.import_reoriginate_stitching is not None:
                                                    return True

                                                if self.import_stitching is not None:
                                                    return True

                                                if self.is_add_path_receive_capability_advertised is not None:
                                                    return True

                                                if self.is_add_path_receive_capability_received is not None:
                                                    return True

                                                if self.is_add_path_send_capability_advertised is not None:
                                                    return True

                                                if self.is_add_path_send_capability_received is not None:
                                                    return True

                                                if self.is_addpath_receive_operational is not None:
                                                    return True

                                                if self.is_addpath_send_operational is not None:
                                                    return True

                                                if self.is_advertise_permanent_network is not None:
                                                    return True

                                                if self.is_advertised_graceful_restart is not None:
                                                    return True

                                                if self.is_advertised_orf_receive is not None:
                                                    return True

                                                if self.is_advertised_orf_send is not None:
                                                    return True

                                                if self.is_aigp_set is not None:
                                                    return True

                                                if self.is_allow_as_in_set is not None:
                                                    return True

                                                if self.is_as_override_set is not None:
                                                    return True

                                                if self.is_default_originate_sent is not None:
                                                    return True

                                                if self.is_ext_nh_encoding_capability_received is not None:
                                                    return True

                                                if self.is_ext_nh_encoding_capability_sent is not None:
                                                    return True

                                                if self.is_graceful_restart_state_flag is not None:
                                                    return True

                                                if self.is_legacy_pe_rt is not None:
                                                    return True

                                                if self.is_neighbor_af_capable is not None:
                                                    return True

                                                if self.is_neighbor_ebgp_without_inbound_policy is not None:
                                                    return True

                                                if self.is_neighbor_ebgp_without_outbound_policy is not None:
                                                    return True

                                                if self.is_neighbor_route_reflector_client is not None:
                                                    return True

                                                if self.is_orf_send_scheduled is not None:
                                                    return True

                                                if self.is_orf_sent is not None:
                                                    return True

                                                if self.is_orr_root_address_configured is not None:
                                                    return True

                                                if self.is_peer_orf_capable is not None:
                                                    return True

                                                if self.is_prefix_orf_present is not None:
                                                    return True

                                                if self.is_received_graceful_restart_capable is not None:
                                                    return True

                                                if self.is_received_orf_receive_capable is not None:
                                                    return True

                                                if self.is_received_orf_send_capable is not None:
                                                    return True

                                                if self.is_rt_present is not None:
                                                    return True

                                                if self.is_rt_present_standby is not None:
                                                    return True

                                                if self.is_send_mcast_attr is not None:
                                                    return True

                                                if self.is_soft_reconfiguration_inbound_allowed is not None:
                                                    return True

                                                if self.is_update_deferred is not None:
                                                    return True

                                                if self.is_update_leaving is not None:
                                                    return True

                                                if self.is_update_throttled is not None:
                                                    return True

                                                if self.is_use_soft_reconfiguration_always_on is not None:
                                                    return True

                                                if self.local_restart_time is not None:
                                                    return True

                                                if self.long_lived_graceful_restart_capability_received is not None:
                                                    return True

                                                if self.long_lived_graceful_restart_stale_time_accept is not None:
                                                    return True

                                                if self.long_lived_graceful_restart_stale_time_configured is not None:
                                                    return True

                                                if self.long_lived_graceful_restart_stale_time_received is not None:
                                                    return True

                                                if self.long_lived_graceful_restart_stale_time_sent is not None:
                                                    return True

                                                if self.max_prefix_discard_extra_paths is not None:
                                                    return True

                                                if self.max_prefix_exceed_discard_paths is not None:
                                                    return True

                                                if self.max_prefix_limit is not None:
                                                    return True

                                                if self.max_prefix_restart_time is not None:
                                                    return True

                                                if self.max_prefix_threshold_percent is not None:
                                                    return True

                                                if self.neighbor_af_performance_statistics is not None and self.neighbor_af_performance_statistics._has_data():
                                                    return True

                                                if self.neighbor_default_originate is not None:
                                                    return True

                                                if self.neighbor_long_lived_graceful_restart_capable is not None:
                                                    return True

                                                if self.neighbor_long_lived_graceful_restart_time_remaining is not None:
                                                    return True

                                                if self.neighbor_preserved_forwarding_state is not None:
                                                    return True

                                                if self.neighbor_preserved_long_lived_forwarding_state is not None:
                                                    return True

                                                if self.neighbor_version is not None:
                                                    return True

                                                if self.number_of_best_externalpaths is not None:
                                                    return True

                                                if self.number_of_bestpaths is not None:
                                                    return True

                                                if self.orf_entries_received is not None:
                                                    return True

                                                if self.orr_group_index is not None:
                                                    return True

                                                if self.orr_group_name is not None:
                                                    return True

                                                if self.outstanding_version is not None:
                                                    return True

                                                if self.outstanding_version_max is not None:
                                                    return True

                                                if self.prefixes_accepted is not None:
                                                    return True

                                                if self.prefixes_advertised is not None:
                                                    return True

                                                if self.prefixes_be_advertised is not None:
                                                    return True

                                                if self.prefixes_denied is not None:
                                                    return True

                                                if self.prefixes_denied_no_policy is not None:
                                                    return True

                                                if self.prefixes_denied_non_cumulative is not None:
                                                    return True

                                                if self.prefixes_denied_orf_policy is not None:
                                                    return True

                                                if self.prefixes_denied_policy is not None:
                                                    return True

                                                if self.prefixes_denied_rt_permit is not None:
                                                    return True

                                                if self.prefixes_suppressed is not None:
                                                    return True

                                                if self.prefixes_synced is not None:
                                                    return True

                                                if self.prefixes_withdrawn is not None:
                                                    return True

                                                if self.prefixes_withdrawn_not_found is not None:
                                                    return True

                                                if self.refresh_acked_version is not None:
                                                    return True

                                                if self.refresh_target_version is not None:
                                                    return True

                                                if self.refresh_version is not None:
                                                    return True

                                                if self.remove_private_as_entire_aspath_from_inbound_updates is not None:
                                                    return True

                                                if self.remove_private_as_entire_aspath_from_updates is not None:
                                                    return True

                                                if self.remove_private_as_from_inbound_updates is not None:
                                                    return True

                                                if self.remove_private_as_from_updates is not None:
                                                    return True

                                                if self.restart_time is not None:
                                                    return True

                                                if self.rib_purge_timeout_value is not None:
                                                    return True

                                                if self.route_policy_default_originate is not None:
                                                    return True

                                                if self.route_policy_in is not None:
                                                    return True

                                                if self.route_policy_out is not None:
                                                    return True

                                                if self.route_policy_prefix_orf is not None:
                                                    return True

                                                if self.route_refreshes_received is not None:
                                                    return True

                                                if self.route_refreshes_sent is not None:
                                                    return True

                                                if self.selective_multipath_eligible is not None:
                                                    return True

                                                if self.sent_community_to_neighbor is not None:
                                                    return True

                                                if self.sent_extended_community_to_neighbor is not None:
                                                    return True

                                                if self.sent_gshut_community_to_neighbor is not None:
                                                    return True

                                                if self.stale_path_timeout is not None:
                                                    return True

                                                if self.synced_acked_version is not None:
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                if self.use_max_prefix_warning_only is not None:
                                                    return True

                                                if self.vpn_update_gen_enabled is not None:
                                                    return True

                                                if self.vpn_update_gen_trigger_enabled is not None:
                                                    return True

                                                if self.weight is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')
                                            if self.neighbor_address is None:
                                                raise YPYModelError('Key property neighbor_address is None')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address = ' + str(self.neighbor_address) + ']'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.neighbor_address is not None:
                                                return True

                                            if self.active_bmp_servers is not None:
                                                return True

                                            if self.actual_last_write_bytes is not None:
                                                return True

                                            if self.actual_last_write_reset_bytes is not None:
                                                return True

                                            if self.actual_second_last_write_bytes is not None:
                                                return True

                                            if self.actual_second_last_write_reset_bytes is not None:
                                                return True

                                            if self.af_data is not None:
                                                for child_ref in self.af_data:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.attempted_last_write_bytes is not None:
                                                return True

                                            if self.attempted_last_write_reset_bytes is not None:
                                                return True

                                            if self.attempted_second_last_write_bytes is not None:
                                                return True

                                            if self.attempted_second_last_write_reset_bytes is not None:
                                                return True

                                            if self.bfd_minintervalval is not None:
                                                return True

                                            if self.bfd_multiplierval is not None:
                                                return True

                                            if self.bfd_session_created_state is not None:
                                                return True

                                            if self.bfd_session_enable_mode is not None:
                                                return True

                                            if self.bfd_session_state is not None:
                                                return True

                                            if self.bfd_state_ts is not None:
                                                return True

                                            if self.bytes_read is not None:
                                                return True

                                            if self.bytes_written is not None:
                                                return True

                                            if self.configured_hold_time is not None:
                                                return True

                                            if self.configured_keepalive is not None:
                                                return True

                                            if self.configured_min_acc_hold_time is not None:
                                                return True

                                            if self.connect_retry_interval is not None:
                                                return True

                                            if self.connection_admin_status is not None:
                                                return True

                                            if self.connection_down_count is not None:
                                                return True

                                            if self.connection_established_time is not None:
                                                return True

                                            if self.connection_local_address is not None and self.connection_local_address._has_data():
                                                return True

                                            if self.connection_local_port is not None:
                                                return True

                                            if self.connection_remote_address is not None and self.connection_remote_address._has_data():
                                                return True

                                            if self.connection_remote_port is not None:
                                                return True

                                            if self.connection_state is not None:
                                                return True

                                            if self.connection_up_count is not None:
                                                return True

                                            if self.count_last_write is not None:
                                                return True

                                            if self.description is not None:
                                                return True

                                            if self.discard_as4_path is not None:
                                                return True

                                            if self.discard_data_bytes is not None:
                                                return True

                                            if self.dmz_link_bandwidth is not None:
                                                return True

                                            if self.dynamic_neighbor is not None:
                                                return True

                                            if self.ebgp_recv_dmz is not None:
                                                return True

                                            if self.ebgp_send_dmz_mode is not None:
                                                return True

                                            if self.ebgp_time_to_live is not None:
                                                return True

                                            if self.egress_peer_engineering_enabled is not None:
                                                return True

                                            if self.error_notifies_received is not None:
                                                return True

                                            if self.error_notifies_sent is not None:
                                                return True

                                            if self.fpbsn_offset is not None:
                                                return True

                                            if self.fssn_offset is not None:
                                                return True

                                            if self.gr_restart_time is not None:
                                                return True

                                            if self.gr_stale_path_time is not None:
                                                return True

                                            if self.graceful_maintenance is not None and self.graceful_maintenance._has_data():
                                                return True

                                            if self.graceful_restart_enabled_nbr is not None:
                                                return True

                                            if self.has_internal_link is not None:
                                                return True

                                            if self.hold_time is not None:
                                                return True

                                            if self.ignore_connected is not None:
                                                return True

                                            if self.internal_vpn_client is not None:
                                                return True

                                            if self.io_armed is not None:
                                                return True

                                            if self.is4_byte_as_capability_received is not None:
                                                return True

                                            if self.is4_byte_as_capability_sent is not None:
                                                return True

                                            if self.is_administratively_shut_down is not None:
                                                return True

                                            if self.is_capability_negotiation_performed is not None:
                                                return True

                                            if self.is_capability_negotiation_suppressed is not None:
                                                return True

                                            if self.is_ebgp_multihop_bgpmpls_forwarding_disabled is not None:
                                                return True

                                            if self.is_ebgp_peer_as_league is not None:
                                                return True

                                            if self.is_ebgp_peer_common_admin is not None:
                                                return True

                                            if self.is_external_neighbor_not_directly_connected is not None:
                                                return True

                                            if self.is_gr_aware is not None:
                                                return True

                                            if self.is_local_address_configured is not None:
                                                return True

                                            if self.is_neighbor_max_prefix_shutdown is not None:
                                                return True

                                            if self.is_out_of_memory_forced_up is not None:
                                                return True

                                            if self.is_out_of_memory_shutdown is not None:
                                                return True

                                            if self.is_passive_close is not None:
                                                return True

                                            if self.is_read_disabled is not None:
                                                return True

                                            if self.is_route_refresh_capability_received is not None:
                                                return True

                                            if self.is_route_refresh_old_capability_received is not None:
                                                return True

                                            if self.keep_alive_time is not None:
                                                return True

                                            if self.last_ackd_seq_no is not None:
                                                return True

                                            if self.last_k_aerror_reset is not None:
                                                return True

                                            if self.last_k_aexpiry_reset is not None:
                                                return True

                                            if self.last_k_anotsent_reset is not None:
                                                return True

                                            if self.last_k_astart_reset is not None:
                                                return True

                                            if self.last_notify_error_code is not None:
                                                return True

                                            if self.last_notify_error_subcode is not None:
                                                return True

                                            if self.last_write_event is not None:
                                                return True

                                            if self.local_as is not None:
                                                return True

                                            if self.local_as_dual_as is not None:
                                                return True

                                            if self.local_as_dual_as_mode_native is not None:
                                                return True

                                            if self.local_as_no_prepend is not None:
                                                return True

                                            if self.local_as_replace_as is not None:
                                                return True

                                            if self.message_statistics is not None and self.message_statistics._has_data():
                                                return True

                                            if self.messages_queued_in is not None:
                                                return True

                                            if self.messages_queued_out is not None:
                                                return True

                                            if self.messages_received is not None:
                                                return True

                                            if self.messages_sent is not None:
                                                return True

                                            if self.min_advertise_interval is not None:
                                                return True

                                            if self.min_advertise_interval_msecs is not None:
                                                return True

                                            if self.min_origination_interval is not None:
                                                return True

                                            if self.msg_log_in is not None:
                                                return True

                                            if self.msg_log_out is not None:
                                                return True

                                            if self.multi_protocol_capability_received is not None:
                                                return True

                                            if self.nbr_cluster_id is not None:
                                                return True

                                            if self.nbr_enforce_first_as is not None:
                                                return True

                                            if self.nbr_in_cluster is not None:
                                                return True

                                            if self.negotiated_protocol_version is not None:
                                                return True

                                            if self.neighbor_interface_handle is not None:
                                                return True

                                            if self.neighbor_local_as is not None:
                                                return True

                                            if self.nsr_enabled is not None:
                                                return True

                                            if self.nsr_state is not None:
                                                return True

                                            if self.open_check_error_code is not None:
                                                return True

                                            if self.peer_error_code is not None:
                                                return True

                                            if self.peer_reset_reason is not None:
                                                return True

                                            if self.performance_statistics is not None and self.performance_statistics._has_data():
                                                return True

                                            if self.previous_connection_state is not None:
                                                return True

                                            if self.read_armed is not None:
                                                return True

                                            if self.received_notification_info is not None and self.received_notification_info._has_data():
                                                return True

                                            if self.remote_as is not None:
                                                return True

                                            if self.remote_as_number is not None:
                                                return True

                                            if self.reset_notification_sent is not None:
                                                return True

                                            if self.reset_reason is not None:
                                                return True

                                            if self.router_id is not None:
                                                return True

                                            if self.rpki_allow_invalid is not None:
                                                return True

                                            if self.rpki_disable is not None:
                                                return True

                                            if self.rpki_signal_ibgp is not None:
                                                return True

                                            if self.rpki_use_validity is not None:
                                                return True

                                            if self.second_last_k_aexpiry_reset is not None:
                                                return True

                                            if self.second_last_k_astart_reset is not None:
                                                return True

                                            if self.second_last_write_event is not None:
                                                return True

                                            if self.send_notification_info is not None and self.send_notification_info._has_data():
                                                return True

                                            if self.socket_read_bytes is not None:
                                                return True

                                            if self.speaker_id is not None:
                                                return True

                                            if self.standby_rp is not None:
                                                return True

                                            if self.suppress4_byte_as is not None:
                                                return True

                                            if self.tcp_init_sync_done_time_spec is not None and self.tcp_init_sync_done_time_spec._has_data():
                                                return True

                                            if self.tcp_init_sync_phase_two_time_spec is not None and self.tcp_init_sync_phase_two_time_spec._has_data():
                                                return True

                                            if self.tcp_init_sync_time_spec is not None and self.tcp_init_sync_time_spec._has_data():
                                                return True

                                            if self.tcp_session_open_mode is not None:
                                                return True

                                            if self.tcpmss is not None:
                                                return True

                                            if self.time_last_cb is not None:
                                                return True

                                            if self.time_last_cb_reset is not None:
                                                return True

                                            if self.time_last_fb is not None:
                                                return True

                                            if self.time_since_connection_last_dropped is not None:
                                                return True

                                            if self.time_since_last_read is not None:
                                                return True

                                            if self.time_since_last_read_reset is not None:
                                                return True

                                            if self.time_since_last_update is not None:
                                                return True

                                            if self.time_since_last_write is not None:
                                                return True

                                            if self.time_since_last_write_reset is not None:
                                                return True

                                            if self.time_since_second_last_write is not None:
                                                return True

                                            if self.time_since_second_last_write_reset is not None:
                                                return True

                                            if self.tos_type is not None:
                                                return True

                                            if self.tos_value is not None:
                                                return True

                                            if self.ttl_security_enabled is not None:
                                                return True

                                            if self.update_bytes_read is not None:
                                                return True

                                            if self.update_messages_in is not None:
                                                return True

                                            if self.update_messages_out is not None:
                                                return True

                                            if self.vrf_name is not None:
                                                return True

                                            if self.write_armed is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-af-table'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.neighbor is not None:
                                            for child_ref in self.neighbor:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable']['meta_info']


                                class NetworkAllRds(object):
                                    """
                                    The BGP Network Lookup Table
                                    
                                    .. attribute:: network_all_rd
                                    
                                    	The BGP Network Lookup table
                                    	**type**\: list of    :py:class:`NetworkAllRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.network_all_rd = YList()
                                        self.network_all_rd.parent = self
                                        self.network_all_rd.name = 'network_all_rd'


                                    class NetworkAllRd(object):
                                        """
                                        The BGP Network Lookup table
                                        
                                        .. attribute:: network_addr  <key>
                                        
                                        	Network in prefix/length format (address part)
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: network_prefix  <key>
                                        
                                        	Network in prefix/length format (prefix part)
                                        	**type**\:  int
                                        
                                        	**range:** 0..128
                                        
                                        .. attribute:: network_rds
                                        
                                        	The BGP Network Lookup table
                                        	**type**\:   :py:class:`NetworkRds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.network_addr = None
                                            self.network_prefix = None
                                            self.network_rds = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds()
                                            self.network_rds.parent = self


                                        class NetworkRds(object):
                                            """
                                            The BGP Network Lookup table
                                            
                                            .. attribute:: network_rd
                                            
                                            	A BGP Network table entry
                                            	**type**\: list of    :py:class:`NetworkRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.network_rd = YList()
                                                self.network_rd.parent = self
                                                self.network_rd.name = 'network_rd'


                                            class NetworkRd(object):
                                                """
                                                A BGP Network table entry
                                                
                                                .. attribute:: rd  <key>
                                                
                                                	Route Distinguisher value
                                                	**type**\:  str
                                                
                                                .. attribute:: active_path_element
                                                
                                                	Path element list received from Active inst
                                                	**type**\: list of    :py:class:`ActivePathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement>`
                                                
                                                .. attribute:: active_process_instance_path
                                                
                                                	Active's paths for this net 
                                                	**type**\: list of    :py:class:`ActiveProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath>`
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield>`
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\:  bool
                                                
                                                .. attribute:: af_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield>`
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix>`
                                                
                                                .. attribute:: bit
                                                
                                                	Bit
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: flags
                                                
                                                	Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: gateway_array
                                                
                                                	Gateway array ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_inconsistent_paths
                                                
                                                	Net has inconsistent paths
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_lbl_retained
                                                
                                                	Net has label retained
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_local_label
                                                
                                                	Net has local label
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_net_aggregation_suppressed
                                                
                                                	Net suppressed due to aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_net_ldp_signaled
                                                
                                                	L2VPN Net LDP signaled  aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_permanent_network
                                                
                                                	Permanent Network
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_path_element
                                                
                                                	Local path element list
                                                	**type**\: list of    :py:class:`LocalPathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement>`
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: local_process_instance_path
                                                
                                                	Local (to process instance) paths for this net 
                                                	**type**\: list of    :py:class:`LocalProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath>`
                                                
                                                .. attribute:: net_backup_available
                                                
                                                	Net has backup path
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_backup_label_rewrite_available
                                                
                                                	Net has label rewrite for backup path
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_eibgp_multipath
                                                
                                                	Net has EIBGP multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_extended_flags
                                                
                                                	Net extended flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: net_flags
                                                
                                                	Flags associated with                            net
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: net_local_label
                                                
                                                	Local label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: net_local_label_rewrite
                                                
                                                	Net label has rewrite
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_local_label_srgb
                                                
                                                	Net label allocated fromSegment routing global block
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_multipath
                                                
                                                	Net has multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: num_of_path
                                                
                                                	Number of path for this net
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: process_instance_id
                                                
                                                	Process instance ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: resilient_nexthop_set
                                                
                                                	Resilient nexthop set ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_failed
                                                
                                                	RIB install failed
                                                	**type**\:  bool
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: table_brib_version
                                                
                                                	Table version # for updates
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: table_version
                                                
                                                	Table version # for net
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: version
                                                
                                                	Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: version_age
                                                
                                                	Version age
                                                	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionAge>`
                                                
                                                .. attribute:: version_timestamp
                                                
                                                	Version timestamp
                                                	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionTimestamp>`
                                                
                                                .. attribute:: vrf_name
                                                
                                                	Name of the VRF
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.rd = None
                                                    self.active_path_element = YList()
                                                    self.active_path_element.parent = self
                                                    self.active_path_element.name = 'active_path_element'
                                                    self.active_process_instance_path = YList()
                                                    self.active_process_instance_path.parent = self
                                                    self.active_process_instance_path.name = 'active_process_instance_path'
                                                    self.add_path_orr_bitfield = YList()
                                                    self.add_path_orr_bitfield.parent = self
                                                    self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                    self.advertisedto_pe = None
                                                    self.af_name = None
                                                    self.best_path_orr_bitfield = YList()
                                                    self.best_path_orr_bitfield.parent = self
                                                    self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self.bit = None
                                                    self.flags = None
                                                    self.gateway_array = None
                                                    self.has_inconsistent_paths = None
                                                    self.has_lbl_retained = None
                                                    self.has_local_label = None
                                                    self.is_net_aggregation_suppressed = None
                                                    self.is_net_ldp_signaled = None
                                                    self.is_permanent_network = None
                                                    self.local_path_element = YList()
                                                    self.local_path_element.parent = self
                                                    self.local_path_element.name = 'local_path_element'
                                                    self.local_peers_advertised_to = YList()
                                                    self.local_peers_advertised_to.parent = self
                                                    self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                    self.local_process_instance_path = YList()
                                                    self.local_process_instance_path.parent = self
                                                    self.local_process_instance_path.name = 'local_process_instance_path'
                                                    self.net_backup_available = None
                                                    self.net_backup_label_rewrite_available = None
                                                    self.net_eibgp_multipath = None
                                                    self.net_extended_flags = None
                                                    self.net_flags = None
                                                    self.net_local_label = None
                                                    self.net_local_label_rewrite = None
                                                    self.net_local_label_srgb = None
                                                    self.net_multipath = None
                                                    self.num_of_path = None
                                                    self.pe_peers_advertised_to = YList()
                                                    self.pe_peers_advertised_to.parent = self
                                                    self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                    self.process_instance_id = None
                                                    self.resilient_nexthop_set = None
                                                    self.rib_failed = None
                                                    self.route_distinguisher = None
                                                    self.table_brib_version = None
                                                    self.table_version = None
                                                    self.version = None
                                                    self.version_age = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionAge()
                                                    self.version_age.parent = self
                                                    self.version_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionTimestamp()
                                                    self.version_timestamp.parent = self
                                                    self.vrf_name = None


                                                class BgpPrefix(object):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self.prefix_length = None


                                                    class Prefix(object):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.prefix is not None and self.prefix._has_data():
                                                            return True

                                                        if self.prefix_length is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix']['meta_info']


                                                class VersionTimestamp(object):
                                                    """
                                                    Version timestamp
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-timestamp'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionTimestamp']['meta_info']


                                                class VersionAge(object):
                                                    """
                                                    Version age
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-age'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionAge']['meta_info']


                                                class LocalPeersAdvertisedTo(object):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo']['meta_info']


                                                class PePeersAdvertisedTo(object):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo']['meta_info']


                                                class BestPathOrrBitfield(object):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield']['meta_info']


                                                class AddPathOrrBitfield(object):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield']['meta_info']


                                                class LocalProcessInstancePath(object):
                                                    """
                                                    Local (to process instance) paths for this net 
                                                    
                                                    .. attribute:: af_name
                                                    
                                                    	Address family identifier
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: attributes_after_policy_in
                                                    
                                                    	Attributes after inbound policy applied
                                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn>`
                                                    
                                                    .. attribute:: label_fail
                                                    
                                                    	LSD label allocation failed 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: label_o_or_version
                                                    
                                                    	Label Version when OOR happens
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_oor
                                                    
                                                    	LSD label space is exhausted
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address_xr
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr>`
                                                    
                                                    .. attribute:: no_path
                                                    
                                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: path_information
                                                    
                                                    	Path information
                                                    	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation>`
                                                    
                                                    .. attribute:: prefix_version
                                                    
                                                    	Version of BGP Prefix Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: process_instance_id
                                                    
                                                    	Process instance ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: route_distinguisher
                                                    
                                                    	Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: source_route_distinguisher
                                                    
                                                    	Source Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: source_vrf_name
                                                    
                                                    	Name of the source VRF
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: srcaf_name
                                                    
                                                    	Address family identifier
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: vrf_name
                                                    
                                                    	Name of the VRF
                                                    	**type**\:  str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.af_name = None
                                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn()
                                                        self.attributes_after_policy_in.parent = self
                                                        self.label_fail = None
                                                        self.label_o_or_version = None
                                                        self.label_oor = None
                                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr()
                                                        self.neighbor_address_xr.parent = self
                                                        self.no_path = None
                                                        self.path_information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation()
                                                        self.path_information.parent = self
                                                        self.prefix_version = None
                                                        self.process_instance_id = None
                                                        self.route_distinguisher = None
                                                        self.source_route_distinguisher = None
                                                        self.source_vrf_name = None
                                                        self.srcaf_name = None
                                                        self.vrf_name = None


                                                    class NeighborAddressXr(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr']['meta_info']


                                                    class PathInformation(object):
                                                        """
                                                        Path information
                                                        
                                                        .. attribute:: accept_own_path
                                                        
                                                        	Accept Own
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: accept_own_self_originated_p_ath
                                                        
                                                        	Accept\-Own self\-originated
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: add_path_orr_bitfield
                                                        
                                                        	ORR Add path Bitfields
                                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                        
                                                        .. attribute:: advertisedto_pe
                                                        
                                                        	Net could be advertised                          to PE peers
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: aigp_metric
                                                        
                                                        	Total AIGP metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: best_path_comp_stage
                                                        
                                                        	Stage where the path lost to the best path or group best
                                                        	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                                        
                                                        .. attribute:: best_path_comp_winner
                                                        
                                                        	Neighbor address of the path which won best path comparison
                                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                        
                                                        .. attribute:: best_path_id
                                                        
                                                        	Best path ID; DEPRECATED BYLocalPathId
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: best_path_id_comp_winner
                                                        
                                                        	Path ID of the path which won best path comparison
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: best_path_orr_bitfield
                                                        
                                                        	ORR Best path Bitfields
                                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                        
                                                        .. attribute:: bgp_prefix
                                                        
                                                        	BGP prefix
                                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix>`
                                                        
                                                        .. attribute:: dampen_penalty
                                                        
                                                        	Dampening penalty
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Mvpn Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                        
                                                        .. attribute:: fspec_invalid_path
                                                        
                                                        	Is Fspec invalid path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: graceful_shutdown
                                                        
                                                        	Marked for graceful shutdown
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: gw_addr
                                                        
                                                        	Path GW Address
                                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.GwAddr>`
                                                        
                                                        .. attribute:: halflife_time
                                                        
                                                        	Half\-life time for the penalty
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_esi
                                                        
                                                        	Path has EVPN ESI
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_gw_addr
                                                        
                                                        	Path has GW Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_local_net_label
                                                        
                                                        	Path has local label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mdt_group_addr
                                                        
                                                        	Path has MDT Group Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_extcomm
                                                        
                                                        	Path has MVPN EXTCOMM feedback
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_nbr_addr
                                                        
                                                        	Path has Mvpn nbr Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_nexthop_addr
                                                        
                                                        	Path has MVPN nexthop Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_pmsi
                                                        
                                                        	Path has MVPN PMSI feedback
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_rcvd_label
                                                        
                                                        	Path has received label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_second_label
                                                        
                                                        	Path has second received label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: ibgp_signaled_validity
                                                        
                                                        	IBGP signalled validation
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: igp_metric
                                                        
                                                        	IGP metric to the gateway
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: is_aggregation_suppressed
                                                        
                                                        	Path suppressed due to aggregation
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_best
                                                        
                                                        	Best available path within AS
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_best_path
                                                        
                                                        	Best available path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_import_dampened
                                                        
                                                        	net import dampened
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_import_suspect
                                                        
                                                        	net import suspect
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_internal_path
                                                        
                                                        	Received over an internal link
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_partial_best
                                                        
                                                        	Partial best path within distributed speaker
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_additional_path
                                                        
                                                        	Path is an additional\-path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_advertised_local_as_only
                                                        
                                                        	Not advertised outside local AS
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_af_install_eligible
                                                        
                                                        	Path can be installed in AF RIB
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_backup
                                                        
                                                        	Path is a backup path 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_backup_protect_multipath
                                                        
                                                        	Path is a backup path to protect multipaths
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_best_external
                                                        
                                                        	Path is a best external path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_damped
                                                        
                                                        	Path suppressed due to dampening
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_confederation_peer
                                                        
                                                        	Path received from confederation peer
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_network_command
                                                        
                                                        	Path sourced by network command
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_redistribute_command
                                                        
                                                        	Path sourced by redistribute command
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_route_reflector
                                                        
                                                        	Path received from route reflector
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_history_held
                                                        
                                                        	Path entry held to remember history
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_imp_candidate
                                                        
                                                        	Path is a candidate for multipath import
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_imported
                                                        
                                                        	Path is imported
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_local_aggregate
                                                        
                                                        	Path is a locally created aggregate
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_locally_sourced
                                                        
                                                        	Path sourced locally
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_long_lived_stale
                                                        
                                                        	Long lived stale routes learnt before neighbor restarts
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_multipath
                                                        
                                                        	Path is one of multipath best routes
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_nexthop_discarded
                                                        
                                                        	Path is redirected to Null0
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_not_advertised
                                                        
                                                        	Not advertised to any peer
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_not_advertised_to_ebg_ps
                                                        
                                                        	Not advertised to EBGPs
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_received_only
                                                        
                                                        	Path is received only
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_reoriginated
                                                        
                                                        	Path is reoriginated
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_reoriginated_stitching
                                                        
                                                        	Path is reoriginated with stitching RTs
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_stale
                                                        
                                                        	Stale routes learnt before neighbor restarts
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_synced_with_igp
                                                        
                                                        	Path synchronized with IGP
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_valid
                                                        
                                                        	Path attributes are usable
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_vpn_only
                                                        
                                                        	Path is not in the vrf
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_permanent_path
                                                        
                                                        	Path is of type Permanent path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_received_path_not_modified
                                                        
                                                        	Received path used without modification
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_spkr_as_best
                                                        
                                                        	Best available path within AS in speaker
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2vpn_circuit_status_value
                                                        
                                                        	L2VPN Circuit Status Value
                                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                        
                                                        .. attribute:: l2vpn_evpn_esi
                                                        
                                                        	L2VPN EVPN ESI
                                                        	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi>`
                                                        
                                                        .. attribute:: l2vpn_size
                                                        
                                                        	Path block size
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: labeled_unicast_safi_path
                                                        
                                                        	Path was learnt by labeled\-unicast SAFI
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: local_label
                                                        
                                                        	Path local label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_nh
                                                        
                                                        	Path has local nexthop
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: local_path_id
                                                        
                                                        	Local path ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_peers_advertised_to
                                                        
                                                        	Local peers that this prefix has been advertised to
                                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                        
                                                        .. attribute:: maximum_suppress_time
                                                        
                                                        	Maximum duration to suppress a stable route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mdt_group_addr
                                                        
                                                        	IPv4 MDT Group Address for the path
                                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                        
                                                        .. attribute:: mvpn_nbr_addr
                                                        
                                                        	Mvpn nbr Address for the path
                                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                        
                                                        .. attribute:: mvpn_nexthop_addr
                                                        
                                                        	Mvpn nexthop Address for the path
                                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                        
                                                        .. attribute:: mvpn_path_flags
                                                        
                                                        	Mvpn path flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: mvpn_pmsi_flags
                                                        
                                                        	Mvpn PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: mvpn_pmsi_label
                                                        
                                                        	Mvpn PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mvpn_pmsi_type
                                                        
                                                        	Mvpn PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: mvpn_pmsi_value
                                                        
                                                        	Mvpn PMSI Value
                                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                        
                                                        .. attribute:: mvpn_sfs_path
                                                        
                                                        	Is MVPN single forwarder PE path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress>`
                                                        
                                                        .. attribute:: neighbor_router_id
                                                        
                                                        	Router ID of the neighbor for the path
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: next_hop
                                                        
                                                        	Next hop
                                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop>`
                                                        
                                                        .. attribute:: nhte_tunnel
                                                        
                                                        	NH TE tunnel information
                                                        	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhteTunnel>`
                                                        
                                                        .. attribute:: path_flags
                                                        
                                                        	Flags associated with path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: path_flap_count
                                                        
                                                        	Number of times this route has flapped
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_import_flags
                                                        
                                                        	Path import flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_rt_set_id
                                                        
                                                        	RT\-set id of the path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_rt_set_route_count
                                                        
                                                        	Count in RT\-set
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_table_version
                                                        
                                                        	Table version # for pelem
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_weight
                                                        
                                                        	Weight for the path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pe_peers_advertised_to
                                                        
                                                        	PE peers that this prefix has been advertised to
                                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                        
                                                        .. attribute:: rcvd_label
                                                        
                                                        	Path received label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rcvd_path_id
                                                        
                                                        	Received path ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: reuse_value
                                                        
                                                        	Value to start reusing a route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rib_failed
                                                        
                                                        	Is net failed installed                          in RIB
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route Type of path
                                                        	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                                        
                                                        .. attribute:: rpki_origin_as_validation_disabled
                                                        
                                                        	RPKI originAS V. Disabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: rt_set_limit_enabled
                                                        
                                                        	Path subject to RT\-set net limit
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: second_label
                                                        
                                                        	Path second received label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: seconds_since_first_flap
                                                        
                                                        	Seconds since route first flapped
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: show_rpki_origin_as_validity
                                                        
                                                        	Display validity state ?
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: sn_rpki_origin_as_validity
                                                        
                                                        	RPKI origin validation state
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: suppress_penalty
                                                        
                                                        	Value to start suppressing a route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: time_to_unsuppress
                                                        
                                                        	Seconds until route is unsuppressed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.accept_own_path = None
                                                            self.accept_own_self_originated_p_ath = None
                                                            self.add_path_orr_bitfield = YList()
                                                            self.add_path_orr_bitfield.parent = self
                                                            self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                            self.advertisedto_pe = None
                                                            self.aigp_metric = None
                                                            self.best_path_comp_stage = None
                                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner()
                                                            self.best_path_comp_winner.parent = self
                                                            self.best_path_id = None
                                                            self.best_path_id_comp_winner = None
                                                            self.best_path_orr_bitfield = YList()
                                                            self.best_path_orr_bitfield.parent = self
                                                            self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix()
                                                            self.bgp_prefix.parent = self
                                                            self.dampen_penalty = None
                                                            self.extended_community = YList()
                                                            self.extended_community.parent = self
                                                            self.extended_community.name = 'extended_community'
                                                            self.fspec_invalid_path = None
                                                            self.graceful_shutdown = None
                                                            self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.GwAddr()
                                                            self.gw_addr.parent = self
                                                            self.halflife_time = None
                                                            self.has_esi = None
                                                            self.has_gw_addr = None
                                                            self.has_local_net_label = None
                                                            self.has_mdt_group_addr = None
                                                            self.has_mvpn_extcomm = None
                                                            self.has_mvpn_nbr_addr = None
                                                            self.has_mvpn_nexthop_addr = None
                                                            self.has_mvpn_pmsi = None
                                                            self.has_rcvd_label = None
                                                            self.has_second_label = None
                                                            self.ibgp_signaled_validity = None
                                                            self.igp_metric = None
                                                            self.is_aggregation_suppressed = None
                                                            self.is_as_best = None
                                                            self.is_best_path = None
                                                            self.is_import_dampened = None
                                                            self.is_import_suspect = None
                                                            self.is_internal_path = None
                                                            self.is_partial_best = None
                                                            self.is_path_additional_path = None
                                                            self.is_path_advertised_local_as_only = None
                                                            self.is_path_af_install_eligible = None
                                                            self.is_path_backup = None
                                                            self.is_path_backup_protect_multipath = None
                                                            self.is_path_best_external = None
                                                            self.is_path_damped = None
                                                            self.is_path_from_confederation_peer = None
                                                            self.is_path_from_network_command = None
                                                            self.is_path_from_redistribute_command = None
                                                            self.is_path_from_route_reflector = None
                                                            self.is_path_history_held = None
                                                            self.is_path_imp_candidate = None
                                                            self.is_path_imported = None
                                                            self.is_path_local_aggregate = None
                                                            self.is_path_locally_sourced = None
                                                            self.is_path_long_lived_stale = None
                                                            self.is_path_multipath = None
                                                            self.is_path_nexthop_discarded = None
                                                            self.is_path_not_advertised = None
                                                            self.is_path_not_advertised_to_ebg_ps = None
                                                            self.is_path_received_only = None
                                                            self.is_path_reoriginated = None
                                                            self.is_path_reoriginated_stitching = None
                                                            self.is_path_stale = None
                                                            self.is_path_synced_with_igp = None
                                                            self.is_path_valid = None
                                                            self.is_path_vpn_only = None
                                                            self.is_permanent_path = None
                                                            self.is_received_path_not_modified = None
                                                            self.is_spkr_as_best = None
                                                            self.l2vpn_circuit_status_value = YList()
                                                            self.l2vpn_circuit_status_value.parent = self
                                                            self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                            self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi()
                                                            self.l2vpn_evpn_esi.parent = self
                                                            self.l2vpn_size = None
                                                            self.labeled_unicast_safi_path = None
                                                            self.local_label = None
                                                            self.local_nh = None
                                                            self.local_path_id = None
                                                            self.local_peers_advertised_to = YList()
                                                            self.local_peers_advertised_to.parent = self
                                                            self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                            self.maximum_suppress_time = None
                                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr()
                                                            self.mdt_group_addr.parent = self
                                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                            self.mvpn_nbr_addr.parent = self
                                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                            self.mvpn_nexthop_addr.parent = self
                                                            self.mvpn_path_flags = None
                                                            self.mvpn_pmsi_flags = None
                                                            self.mvpn_pmsi_label = None
                                                            self.mvpn_pmsi_type = None
                                                            self.mvpn_pmsi_value = YList()
                                                            self.mvpn_pmsi_value.parent = self
                                                            self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                            self.mvpn_sfs_path = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.neighbor_router_id = None
                                                            self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop()
                                                            self.next_hop.parent = self
                                                            self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhteTunnel()
                                                            self.nhte_tunnel.parent = self
                                                            self.path_flags = None
                                                            self.path_flap_count = None
                                                            self.path_import_flags = None
                                                            self.path_rt_set_id = None
                                                            self.path_rt_set_route_count = None
                                                            self.path_table_version = None
                                                            self.path_weight = None
                                                            self.pe_peers_advertised_to = YList()
                                                            self.pe_peers_advertised_to.parent = self
                                                            self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                            self.rcvd_label = None
                                                            self.rcvd_path_id = None
                                                            self.reuse_value = None
                                                            self.rib_failed = None
                                                            self.route_type = None
                                                            self.rpki_origin_as_validation_disabled = None
                                                            self.rt_set_limit_enabled = None
                                                            self.second_label = None
                                                            self.seconds_since_first_flap = None
                                                            self.show_rpki_origin_as_validity = None
                                                            self.sn_rpki_origin_as_validity = None
                                                            self.suppress_penalty = None
                                                            self.time_to_unsuppress = None


                                                        class BgpPrefix(object):
                                                            """
                                                            BGP prefix
                                                            
                                                            .. attribute:: prefix
                                                            
                                                            	Prefix
                                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                            
                                                            .. attribute:: prefix_length
                                                            
                                                            	Prefix length
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                                self.prefix.parent = self
                                                                self.prefix_length = None


                                                            class Prefix(object):
                                                                """
                                                                Prefix
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.prefix is not None and self.prefix._has_data():
                                                                    return True

                                                                if self.prefix_length is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix']['meta_info']


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress']['meta_info']


                                                        class NextHop(object):
                                                            """
                                                            Next hop
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop']['meta_info']


                                                        class NhteTunnel(object):
                                                            """
                                                            NH TE tunnel information
                                                            
                                                            .. attribute:: binding_label
                                                            
                                                            	Binding label for the tunnel
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: has_te_tunnel
                                                            
                                                            	NH TE Tunnel info is present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_info_stale
                                                            
                                                            	Tunnel is stale
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_registered
                                                            
                                                            	Tunnel registered flag
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_up
                                                            
                                                            	Tunnel Up flag
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: last_tunnel_update
                                                            
                                                            	Time since the last rib update happened
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_if_handle
                                                            
                                                            	Interface handle for the tunnel
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_name
                                                            
                                                            	tunnel name
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            .. attribute:: tunnel_type
                                                            
                                                            	tunnel type
                                                            	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                            
                                                            .. attribute:: tunnel_v6_enabled
                                                            
                                                            	IPv6 enabled
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_v6_required
                                                            
                                                            	Tunnel need IPv6
                                                            	**type**\:  bool
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.binding_label = None
                                                                self.has_te_tunnel = None
                                                                self.is_tunnel_info_stale = None
                                                                self.is_tunnel_registered = None
                                                                self.is_tunnel_up = None
                                                                self.last_tunnel_update = None
                                                                self.tunnel_if_handle = None
                                                                self.tunnel_name = None
                                                                self.tunnel_type = None
                                                                self.tunnel_v6_enabled = None
                                                                self.tunnel_v6_required = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.binding_label is not None:
                                                                    return True

                                                                if self.has_te_tunnel is not None:
                                                                    return True

                                                                if self.is_tunnel_info_stale is not None:
                                                                    return True

                                                                if self.is_tunnel_registered is not None:
                                                                    return True

                                                                if self.is_tunnel_up is not None:
                                                                    return True

                                                                if self.last_tunnel_update is not None:
                                                                    return True

                                                                if self.tunnel_if_handle is not None:
                                                                    return True

                                                                if self.tunnel_name is not None:
                                                                    return True

                                                                if self.tunnel_type is not None:
                                                                    return True

                                                                if self.tunnel_v6_enabled is not None:
                                                                    return True

                                                                if self.tunnel_v6_required is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhteTunnel']['meta_info']


                                                        class MdtGroupAddr(object):
                                                            """
                                                            IPv4 MDT Group Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr']['meta_info']


                                                        class L2VpnEvpnEsi(object):
                                                            """
                                                            L2VPN EVPN ESI
                                                            
                                                            .. attribute:: esi
                                                            
                                                            	esi
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.esi = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.esi is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi']['meta_info']


                                                        class GwAddr(object):
                                                            """
                                                            Path GW Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self.len = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.len is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.GwAddr']['meta_info']


                                                        class BestPathCompWinner(object):
                                                            """
                                                            Neighbor address of the path which won best path
                                                            comparison
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner']['meta_info']


                                                        class MvpnNbrAddr(object):
                                                            """
                                                            Mvpn nbr Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr']['meta_info']


                                                        class MvpnNexthopAddr(object):
                                                            """
                                                            Mvpn nexthop Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr']['meta_info']


                                                        class L2VpnCircuitStatusValue(object):
                                                            """
                                                            L2VPN Circuit Status Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                                        class MvpnPmsiValue(object):
                                                            """
                                                            Mvpn PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue']['meta_info']


                                                        class ExtendedCommunity(object):
                                                            """
                                                            Mvpn Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity']['meta_info']


                                                        class LocalPeersAdvertisedTo(object):
                                                            """
                                                            Local peers that this prefix has been advertised
                                                            to
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.is_neighbor = None
                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self.update_group_number = None


                                                            class NeighborAddress(object):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.is_neighbor is not None:
                                                                    return True

                                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                    return True

                                                                if self.update_group_number is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                                        class PePeersAdvertisedTo(object):
                                                            """
                                                            PE peers that this prefix has been advertised to
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.is_neighbor = None
                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self.update_group_number = None


                                                            class NeighborAddress(object):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.is_neighbor is not None:
                                                                    return True

                                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                    return True

                                                                if self.update_group_number is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo']['meta_info']


                                                        class BestPathOrrBitfield(object):
                                                            """
                                                            ORR Best path Bitfields
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.is_neighbor = None
                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self.update_group_number = None


                                                            class NeighborAddress(object):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.is_neighbor is not None:
                                                                    return True

                                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                    return True

                                                                if self.update_group_number is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield']['meta_info']


                                                        class AddPathOrrBitfield(object):
                                                            """
                                                            ORR Add path Bitfields
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.is_neighbor = None
                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self.update_group_number = None


                                                            class NeighborAddress(object):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.is_neighbor is not None:
                                                                    return True

                                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                    return True

                                                                if self.update_group_number is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.accept_own_path is not None:
                                                                return True

                                                            if self.accept_own_self_originated_p_ath is not None:
                                                                return True

                                                            if self.add_path_orr_bitfield is not None:
                                                                for child_ref in self.add_path_orr_bitfield:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.advertisedto_pe is not None:
                                                                return True

                                                            if self.aigp_metric is not None:
                                                                return True

                                                            if self.best_path_comp_stage is not None:
                                                                return True

                                                            if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                                return True

                                                            if self.best_path_id is not None:
                                                                return True

                                                            if self.best_path_id_comp_winner is not None:
                                                                return True

                                                            if self.best_path_orr_bitfield is not None:
                                                                for child_ref in self.best_path_orr_bitfield:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                                return True

                                                            if self.dampen_penalty is not None:
                                                                return True

                                                            if self.extended_community is not None:
                                                                for child_ref in self.extended_community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.fspec_invalid_path is not None:
                                                                return True

                                                            if self.graceful_shutdown is not None:
                                                                return True

                                                            if self.gw_addr is not None and self.gw_addr._has_data():
                                                                return True

                                                            if self.halflife_time is not None:
                                                                return True

                                                            if self.has_esi is not None:
                                                                return True

                                                            if self.has_gw_addr is not None:
                                                                return True

                                                            if self.has_local_net_label is not None:
                                                                return True

                                                            if self.has_mdt_group_addr is not None:
                                                                return True

                                                            if self.has_mvpn_extcomm is not None:
                                                                return True

                                                            if self.has_mvpn_nbr_addr is not None:
                                                                return True

                                                            if self.has_mvpn_nexthop_addr is not None:
                                                                return True

                                                            if self.has_mvpn_pmsi is not None:
                                                                return True

                                                            if self.has_rcvd_label is not None:
                                                                return True

                                                            if self.has_second_label is not None:
                                                                return True

                                                            if self.ibgp_signaled_validity is not None:
                                                                return True

                                                            if self.igp_metric is not None:
                                                                return True

                                                            if self.is_aggregation_suppressed is not None:
                                                                return True

                                                            if self.is_as_best is not None:
                                                                return True

                                                            if self.is_best_path is not None:
                                                                return True

                                                            if self.is_import_dampened is not None:
                                                                return True

                                                            if self.is_import_suspect is not None:
                                                                return True

                                                            if self.is_internal_path is not None:
                                                                return True

                                                            if self.is_partial_best is not None:
                                                                return True

                                                            if self.is_path_additional_path is not None:
                                                                return True

                                                            if self.is_path_advertised_local_as_only is not None:
                                                                return True

                                                            if self.is_path_af_install_eligible is not None:
                                                                return True

                                                            if self.is_path_backup is not None:
                                                                return True

                                                            if self.is_path_backup_protect_multipath is not None:
                                                                return True

                                                            if self.is_path_best_external is not None:
                                                                return True

                                                            if self.is_path_damped is not None:
                                                                return True

                                                            if self.is_path_from_confederation_peer is not None:
                                                                return True

                                                            if self.is_path_from_network_command is not None:
                                                                return True

                                                            if self.is_path_from_redistribute_command is not None:
                                                                return True

                                                            if self.is_path_from_route_reflector is not None:
                                                                return True

                                                            if self.is_path_history_held is not None:
                                                                return True

                                                            if self.is_path_imp_candidate is not None:
                                                                return True

                                                            if self.is_path_imported is not None:
                                                                return True

                                                            if self.is_path_local_aggregate is not None:
                                                                return True

                                                            if self.is_path_locally_sourced is not None:
                                                                return True

                                                            if self.is_path_long_lived_stale is not None:
                                                                return True

                                                            if self.is_path_multipath is not None:
                                                                return True

                                                            if self.is_path_nexthop_discarded is not None:
                                                                return True

                                                            if self.is_path_not_advertised is not None:
                                                                return True

                                                            if self.is_path_not_advertised_to_ebg_ps is not None:
                                                                return True

                                                            if self.is_path_received_only is not None:
                                                                return True

                                                            if self.is_path_reoriginated is not None:
                                                                return True

                                                            if self.is_path_reoriginated_stitching is not None:
                                                                return True

                                                            if self.is_path_stale is not None:
                                                                return True

                                                            if self.is_path_synced_with_igp is not None:
                                                                return True

                                                            if self.is_path_valid is not None:
                                                                return True

                                                            if self.is_path_vpn_only is not None:
                                                                return True

                                                            if self.is_permanent_path is not None:
                                                                return True

                                                            if self.is_received_path_not_modified is not None:
                                                                return True

                                                            if self.is_spkr_as_best is not None:
                                                                return True

                                                            if self.l2vpn_circuit_status_value is not None:
                                                                for child_ref in self.l2vpn_circuit_status_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                                return True

                                                            if self.l2vpn_size is not None:
                                                                return True

                                                            if self.labeled_unicast_safi_path is not None:
                                                                return True

                                                            if self.local_label is not None:
                                                                return True

                                                            if self.local_nh is not None:
                                                                return True

                                                            if self.local_path_id is not None:
                                                                return True

                                                            if self.local_peers_advertised_to is not None:
                                                                for child_ref in self.local_peers_advertised_to:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.maximum_suppress_time is not None:
                                                                return True

                                                            if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                                return True

                                                            if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                                return True

                                                            if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                                return True

                                                            if self.mvpn_path_flags is not None:
                                                                return True

                                                            if self.mvpn_pmsi_flags is not None:
                                                                return True

                                                            if self.mvpn_pmsi_label is not None:
                                                                return True

                                                            if self.mvpn_pmsi_type is not None:
                                                                return True

                                                            if self.mvpn_pmsi_value is not None:
                                                                for child_ref in self.mvpn_pmsi_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.mvpn_sfs_path is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.neighbor_router_id is not None:
                                                                return True

                                                            if self.next_hop is not None and self.next_hop._has_data():
                                                                return True

                                                            if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                                return True

                                                            if self.path_flags is not None:
                                                                return True

                                                            if self.path_flap_count is not None:
                                                                return True

                                                            if self.path_import_flags is not None:
                                                                return True

                                                            if self.path_rt_set_id is not None:
                                                                return True

                                                            if self.path_rt_set_route_count is not None:
                                                                return True

                                                            if self.path_table_version is not None:
                                                                return True

                                                            if self.path_weight is not None:
                                                                return True

                                                            if self.pe_peers_advertised_to is not None:
                                                                for child_ref in self.pe_peers_advertised_to:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.rcvd_label is not None:
                                                                return True

                                                            if self.rcvd_path_id is not None:
                                                                return True

                                                            if self.reuse_value is not None:
                                                                return True

                                                            if self.rib_failed is not None:
                                                                return True

                                                            if self.route_type is not None:
                                                                return True

                                                            if self.rpki_origin_as_validation_disabled is not None:
                                                                return True

                                                            if self.rt_set_limit_enabled is not None:
                                                                return True

                                                            if self.second_label is not None:
                                                                return True

                                                            if self.seconds_since_first_flap is not None:
                                                                return True

                                                            if self.show_rpki_origin_as_validity is not None:
                                                                return True

                                                            if self.sn_rpki_origin_as_validity is not None:
                                                                return True

                                                            if self.suppress_penalty is not None:
                                                                return True

                                                            if self.time_to_unsuppress is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation']['meta_info']


                                                    class AttributesAfterPolicyIn(object):
                                                        """
                                                        Attributes after inbound policy applied
                                                        
                                                        .. attribute:: attr_set
                                                        
                                                        	ATTR\_SET attribute
                                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                        
                                                        .. attribute:: attribute_key_number
                                                        
                                                        	Attribute key number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_config
                                                        
                                                        	Attribute reuse ID Configured
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: attribute_reuse_id_current
                                                        
                                                        	Attribute reuse ID current ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_keys
                                                        
                                                        	Attribute reuse ID allocated keys
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_max_id
                                                        
                                                        	Attribute reuse ID maximum ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_node
                                                        
                                                        	Attribute reuse ID nodes
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_recover_sec
                                                        
                                                        	Attribute reuse ID timer in seconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: common_attributes
                                                        
                                                        	Common attributes
                                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                        
                                                        .. attribute:: is_application_gateway_present
                                                        
                                                        	Application gateway present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path2_byte
                                                        
                                                        	AS path encoded as 2\-byte
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_attr_set_present
                                                        
                                                        	BGP ATTR\_SET attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ribrnh_present
                                                        
                                                        	RIB RNH Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_rnh_present
                                                        
                                                        	RNH Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: ribrnh_encap
                                                        
                                                        	RIB RNH Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ribrnh_ip
                                                        
                                                        	RIB RNH IP Address
                                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                        
                                                        .. attribute:: ribrnh_mac
                                                        
                                                        	RIB RNH MAC Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                        
                                                        .. attribute:: ribrnh_table
                                                        
                                                        	RIB RNH Table
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ribrnh_vni
                                                        
                                                        	RIB RNH Vni
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ribrnhip_table
                                                        
                                                        	RIB RNH IP Table
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rnh_addr
                                                        
                                                        	RNH Address
                                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                        
                                                        .. attribute:: rnh_addr_len
                                                        
                                                        	RNH Address Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rnh_len
                                                        
                                                        	RNH Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: rnh_type
                                                        
                                                        	RNH Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: set_aigp_inbound_igp
                                                        
                                                        	AIGP set by policy inbound IGP 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: set_aigp_inbound_metric
                                                        
                                                        	AIGP set by policy inbound metric
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: vpn_distinguisher
                                                        
                                                        	VPN Distinguisher
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                            self.attr_set.parent = self
                                                            self.attribute_key_number = None
                                                            self.attribute_reuse_id_config = None
                                                            self.attribute_reuse_id_current = None
                                                            self.attribute_reuse_id_keys = None
                                                            self.attribute_reuse_id_max_id = None
                                                            self.attribute_reuse_id_node = None
                                                            self.attribute_reuse_id_recover_sec = None
                                                            self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                            self.common_attributes.parent = self
                                                            self.is_application_gateway_present = None
                                                            self.is_as_path2_byte = None
                                                            self.is_attr_set_present = None
                                                            self.is_ribrnh_present = None
                                                            self.is_rnh_present = None
                                                            self.ribrnh_encap = None
                                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                            self.ribrnh_ip.parent = self
                                                            self.ribrnh_mac = None
                                                            self.ribrnh_table = None
                                                            self.ribrnh_vni = None
                                                            self.ribrnhip_table = None
                                                            self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                            self.rnh_addr.parent = self
                                                            self.rnh_addr_len = None
                                                            self.rnh_len = None
                                                            self.rnh_type = None
                                                            self.set_aigp_inbound_igp = None
                                                            self.set_aigp_inbound_metric = None
                                                            self.vpn_distinguisher = None


                                                        class CommonAttributes(object):
                                                            """
                                                            Common attributes
                                                            
                                                            .. attribute:: aggregator_address
                                                            
                                                            	Address where aggregation was performed
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: aggregator_as
                                                            
                                                            	AS where aggregation was last performed
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: aigp_metric_value
                                                            
                                                            	AIGP metric value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..18446744073709551615
                                                            
                                                            .. attribute:: as_path
                                                            
                                                            	AS path attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: cluster
                                                            
                                                            	Cluster list attribute
                                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                            
                                                            .. attribute:: community
                                                            
                                                            	Community attribute
                                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                            
                                                            .. attribute:: connector_type
                                                            
                                                            	Connector Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: connector_value
                                                            
                                                            	Connector Value
                                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                            
                                                            .. attribute:: extended_community
                                                            
                                                            	Extended community attribute
                                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                            
                                                            .. attribute:: extended_community_flags
                                                            
                                                            	Extended community Flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: is_aggregator_present
                                                            
                                                            	Aggregator attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_aigp_present
                                                            
                                                            	AIGP Present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_as_path_present
                                                            
                                                            	AS path attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_atomic_aggregate_present
                                                            
                                                            	Atomic aggregate attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_community_present
                                                            
                                                            	Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_connector_present
                                                            
                                                            	Connector present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_extended_community_present
                                                            
                                                            	Extended community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_label_index_present
                                                            
                                                            	Label Index attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_local_pref_present
                                                            
                                                            	Local Preference attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ls_attribute_present
                                                            
                                                            	BGP LS attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_metric_present
                                                            
                                                            	Metric attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_origin_present
                                                            
                                                            	Origin attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pe_distinguisher_label_present
                                                            
                                                            	PE distinguisher label  attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pmsi_present
                                                            
                                                            	PMSI Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pppmp_present
                                                            
                                                            	PPMP Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ssa_present
                                                            
                                                            	SSA attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_encap_present
                                                            
                                                            	Tunnel Encap attribute present 
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: l2tpv3_cookie
                                                            
                                                            	L2TPv3 Cookie
                                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                            
                                                            .. attribute:: l2tpv3_session_id
                                                            
                                                            	L2TPv3 session id
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: label_index_attr
                                                            
                                                            	Label Index attribute
                                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                            
                                                            .. attribute:: local_preference
                                                            
                                                            	Local preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ls_attr
                                                            
                                                            	BGP LS attribute
                                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	Metric
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: neighbor_as
                                                            
                                                            	Neighbor AS number
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: origin
                                                            
                                                            	Origin
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: originator
                                                            
                                                            	Originator attribute
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: pe_distinguisher_label
                                                            
                                                            	PE distinguisher label attribute
                                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                            
                                                            .. attribute:: pmsi_flags
                                                            
                                                            	PMSI Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pmsi_label
                                                            
                                                            	PMSI label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pmsi_type
                                                            
                                                            	PMSI Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: pmsi_value
                                                            
                                                            	PMSI Value
                                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                            
                                                            .. attribute:: ppm_pvalue
                                                            
                                                            	PPMP Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: sr_policy_allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                            
                                                            .. attribute:: sr_policy_binding_sid
                                                            
                                                            	SR Policy Binding sid
                                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                            
                                                            .. attribute:: sr_policy_explicit_path
                                                            
                                                            	SR Policy Explicit paths
                                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                            
                                                            .. attribute:: sr_policy_preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: sr_tunnel_request_state
                                                            
                                                            	SR Tunnel Request State
                                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                            
                                                            .. attribute:: sr_tunnel_state
                                                            
                                                            	SR Tunnel State
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encap Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: unknown_attribute
                                                            
                                                            	Unknown attributes
                                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.aggregator_address = None
                                                                self.aggregator_as = None
                                                                self.aigp_metric_value = None
                                                                self.as_path = None
                                                                self.cluster = YList()
                                                                self.cluster.parent = self
                                                                self.cluster.name = 'cluster'
                                                                self.community = YList()
                                                                self.community.parent = self
                                                                self.community.name = 'community'
                                                                self.connector_type = None
                                                                self.connector_value = YList()
                                                                self.connector_value.parent = self
                                                                self.connector_value.name = 'connector_value'
                                                                self.extended_community = YList()
                                                                self.extended_community.parent = self
                                                                self.extended_community.name = 'extended_community'
                                                                self.extended_community_flags = None
                                                                self.is_aggregator_present = None
                                                                self.is_aigp_present = None
                                                                self.is_as_path_present = None
                                                                self.is_atomic_aggregate_present = None
                                                                self.is_community_present = None
                                                                self.is_connector_present = None
                                                                self.is_extended_community_present = None
                                                                self.is_label_index_present = None
                                                                self.is_local_pref_present = None
                                                                self.is_ls_attribute_present = None
                                                                self.is_metric_present = None
                                                                self.is_origin_present = None
                                                                self.is_pe_distinguisher_label_present = None
                                                                self.is_pmsi_present = None
                                                                self.is_pppmp_present = None
                                                                self.is_ssa_present = None
                                                                self.is_tunnel_encap_present = None
                                                                self.l2tpv3_cookie = YList()
                                                                self.l2tpv3_cookie.parent = self
                                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                                self.l2tpv3_session_id = None
                                                                self.label_index_attr = YList()
                                                                self.label_index_attr.parent = self
                                                                self.label_index_attr.name = 'label_index_attr'
                                                                self.local_preference = None
                                                                self.ls_attr = YList()
                                                                self.ls_attr.parent = self
                                                                self.ls_attr.name = 'ls_attr'
                                                                self.metric = None
                                                                self.neighbor_as = None
                                                                self.origin = None
                                                                self.originator = None
                                                                self.pe_distinguisher_label = YList()
                                                                self.pe_distinguisher_label.parent = self
                                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                                self.pmsi_flags = None
                                                                self.pmsi_label = None
                                                                self.pmsi_type = None
                                                                self.pmsi_value = YList()
                                                                self.pmsi_value.parent = self
                                                                self.pmsi_value.name = 'pmsi_value'
                                                                self.ppm_pvalue = None
                                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                                self.sr_policy_allocated_binding_sid.parent = self
                                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                                self.sr_policy_binding_sid.parent = self
                                                                self.sr_policy_explicit_path = YList()
                                                                self.sr_policy_explicit_path.parent = self
                                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                                self.sr_policy_preference = None
                                                                self.sr_tunnel_request_state = None
                                                                self.sr_tunnel_state = None
                                                                self.tunnel_encap_type = None
                                                                self.unknown_attribute = YList()
                                                                self.unknown_attribute.parent = self
                                                                self.unknown_attribute.name = 'unknown_attribute'


                                                            class SrPolicyBindingSid(object):
                                                                """
                                                                SR Policy Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_address = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                            class SrPolicyAllocatedBindingSid(object):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_address = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                            class Community(object):
                                                                """
                                                                Community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                            class ExtendedCommunity(object):
                                                                """
                                                                Extended community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                            class UnknownAttribute(object):
                                                                """
                                                                Unknown attributes
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                            class Cluster(object):
                                                                """
                                                                Cluster list attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                            class L2Tpv3Cookie(object):
                                                                """
                                                                L2TPv3 Cookie
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                            class ConnectorValue(object):
                                                                """
                                                                Connector Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                            class PmsiValue(object):
                                                                """
                                                                PMSI Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                            class LsAttr(object):
                                                                """
                                                                BGP LS attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                            class LabelIndexAttr(object):
                                                                """
                                                                Label Index attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                            class PeDistinguisherLabel(object):
                                                                """
                                                                PE distinguisher label attribute
                                                                
                                                                .. attribute:: label
                                                                
                                                                	Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pe_address
                                                                
                                                                	 PE address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.label = None
                                                                    self.pe_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.pe_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                            class SrPolicyExplicitPath(object):
                                                                """
                                                                SR Policy Explicit paths
                                                                
                                                                .. attribute:: sid
                                                                
                                                                	Sidlist for explicit path
                                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of explicit path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.sid = YList()
                                                                    self.sid.parent = self
                                                                    self.sid.name = 'sid'
                                                                    self.weight = None


                                                                class Sid(object):
                                                                    """
                                                                    Sidlist for explicit path
                                                                    
                                                                    .. attribute:: ipv4
                                                                    
                                                                    	IP Address sid
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6
                                                                    
                                                                    	IPv6 address sid
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label sid
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Sid Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4 = None
                                                                        self.ipv6 = None
                                                                        self.label = None
                                                                        self.type = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4 is not None:
                                                                            return True

                                                                        if self.ipv6 is not None:
                                                                            return True

                                                                        if self.label is not None:
                                                                            return True

                                                                        if self.type is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.sid is not None:
                                                                        for child_ref in self.sid:
                                                                            if child_ref._has_data():
                                                                                return True

                                                                    if self.weight is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.aggregator_address is not None:
                                                                    return True

                                                                if self.aggregator_as is not None:
                                                                    return True

                                                                if self.aigp_metric_value is not None:
                                                                    return True

                                                                if self.as_path is not None:
                                                                    return True

                                                                if self.cluster is not None:
                                                                    for child_ref in self.cluster:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.community is not None:
                                                                    for child_ref in self.community:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.connector_type is not None:
                                                                    return True

                                                                if self.connector_value is not None:
                                                                    for child_ref in self.connector_value:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.extended_community is not None:
                                                                    for child_ref in self.extended_community:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.extended_community_flags is not None:
                                                                    return True

                                                                if self.is_aggregator_present is not None:
                                                                    return True

                                                                if self.is_aigp_present is not None:
                                                                    return True

                                                                if self.is_as_path_present is not None:
                                                                    return True

                                                                if self.is_atomic_aggregate_present is not None:
                                                                    return True

                                                                if self.is_community_present is not None:
                                                                    return True

                                                                if self.is_connector_present is not None:
                                                                    return True

                                                                if self.is_extended_community_present is not None:
                                                                    return True

                                                                if self.is_label_index_present is not None:
                                                                    return True

                                                                if self.is_local_pref_present is not None:
                                                                    return True

                                                                if self.is_ls_attribute_present is not None:
                                                                    return True

                                                                if self.is_metric_present is not None:
                                                                    return True

                                                                if self.is_origin_present is not None:
                                                                    return True

                                                                if self.is_pe_distinguisher_label_present is not None:
                                                                    return True

                                                                if self.is_pmsi_present is not None:
                                                                    return True

                                                                if self.is_pppmp_present is not None:
                                                                    return True

                                                                if self.is_ssa_present is not None:
                                                                    return True

                                                                if self.is_tunnel_encap_present is not None:
                                                                    return True

                                                                if self.l2tpv3_cookie is not None:
                                                                    for child_ref in self.l2tpv3_cookie:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.l2tpv3_session_id is not None:
                                                                    return True

                                                                if self.label_index_attr is not None:
                                                                    for child_ref in self.label_index_attr:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.local_preference is not None:
                                                                    return True

                                                                if self.ls_attr is not None:
                                                                    for child_ref in self.ls_attr:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.metric is not None:
                                                                    return True

                                                                if self.neighbor_as is not None:
                                                                    return True

                                                                if self.origin is not None:
                                                                    return True

                                                                if self.originator is not None:
                                                                    return True

                                                                if self.pe_distinguisher_label is not None:
                                                                    for child_ref in self.pe_distinguisher_label:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.pmsi_flags is not None:
                                                                    return True

                                                                if self.pmsi_label is not None:
                                                                    return True

                                                                if self.pmsi_type is not None:
                                                                    return True

                                                                if self.pmsi_value is not None:
                                                                    for child_ref in self.pmsi_value:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.ppm_pvalue is not None:
                                                                    return True

                                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                                    return True

                                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                                    return True

                                                                if self.sr_policy_explicit_path is not None:
                                                                    for child_ref in self.sr_policy_explicit_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.sr_policy_preference is not None:
                                                                    return True

                                                                if self.sr_tunnel_request_state is not None:
                                                                    return True

                                                                if self.sr_tunnel_state is not None:
                                                                    return True

                                                                if self.tunnel_encap_type is not None:
                                                                    return True

                                                                if self.unknown_attribute is not None:
                                                                    for child_ref in self.unknown_attribute:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                                        class AttrSet(object):
                                                            """
                                                            ATTR\_SET attribute
                                                            
                                                            .. attribute:: aggregator_address
                                                            
                                                            	Address where aggregation was performed
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: aggregator_as
                                                            
                                                            	AS where aggregation was last performed
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: aigp_metric_value
                                                            
                                                            	AIGP metric value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..18446744073709551615
                                                            
                                                            .. attribute:: as_path
                                                            
                                                            	AS path attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: cluster
                                                            
                                                            	Cluster list attribute
                                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                            
                                                            .. attribute:: community
                                                            
                                                            	Community attribute
                                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                            
                                                            .. attribute:: connector_type
                                                            
                                                            	Connector Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: connector_value
                                                            
                                                            	Connector Value
                                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                            
                                                            .. attribute:: extended_community
                                                            
                                                            	Extended community attribute
                                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                            
                                                            .. attribute:: extended_community_flags
                                                            
                                                            	Extended community Flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: is_aggregator_present
                                                            
                                                            	Aggregator attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_aigp_present
                                                            
                                                            	AIGP Present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_as_path_present
                                                            
                                                            	AS path attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_atomic_aggregate_present
                                                            
                                                            	Atomic aggregate attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_community_present
                                                            
                                                            	Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_connector_present
                                                            
                                                            	Connector present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_extended_community_present
                                                            
                                                            	Extended community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_label_index_present
                                                            
                                                            	Label Index attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_local_pref_present
                                                            
                                                            	Local Preference attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ls_attribute_present
                                                            
                                                            	BGP LS attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_metric_present
                                                            
                                                            	Metric attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_origin_present
                                                            
                                                            	Origin attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pe_distinguisher_label_present
                                                            
                                                            	PE distinguisher label  attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pmsi_present
                                                            
                                                            	PMSI Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pppmp_present
                                                            
                                                            	PPMP Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ssa_present
                                                            
                                                            	SSA attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_encap_present
                                                            
                                                            	Tunnel Encap attribute present 
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: l2tpv3_cookie
                                                            
                                                            	L2TPv3 Cookie
                                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                            
                                                            .. attribute:: l2tpv3_session_id
                                                            
                                                            	L2TPv3 session id
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: label_index_attr
                                                            
                                                            	Label Index attribute
                                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                            
                                                            .. attribute:: local_preference
                                                            
                                                            	Local preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ls_attr
                                                            
                                                            	BGP LS attribute
                                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	Metric
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: neighbor_as
                                                            
                                                            	Neighbor AS number
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: origin
                                                            
                                                            	Origin
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: originator
                                                            
                                                            	Originator attribute
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: pe_distinguisher_label
                                                            
                                                            	PE distinguisher label attribute
                                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                            
                                                            .. attribute:: pmsi_flags
                                                            
                                                            	PMSI Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pmsi_label
                                                            
                                                            	PMSI label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pmsi_type
                                                            
                                                            	PMSI Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: pmsi_value
                                                            
                                                            	PMSI Value
                                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                            
                                                            .. attribute:: ppm_pvalue
                                                            
                                                            	PPMP Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: sr_policy_allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                            
                                                            .. attribute:: sr_policy_binding_sid
                                                            
                                                            	SR Policy Binding sid
                                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                            
                                                            .. attribute:: sr_policy_explicit_path
                                                            
                                                            	SR Policy Explicit paths
                                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                            
                                                            .. attribute:: sr_policy_preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: sr_tunnel_request_state
                                                            
                                                            	SR Tunnel Request State
                                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                            
                                                            .. attribute:: sr_tunnel_state
                                                            
                                                            	SR Tunnel State
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encap Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: unknown_attribute
                                                            
                                                            	Unknown attributes
                                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.aggregator_address = None
                                                                self.aggregator_as = None
                                                                self.aigp_metric_value = None
                                                                self.as_path = None
                                                                self.cluster = YList()
                                                                self.cluster.parent = self
                                                                self.cluster.name = 'cluster'
                                                                self.community = YList()
                                                                self.community.parent = self
                                                                self.community.name = 'community'
                                                                self.connector_type = None
                                                                self.connector_value = YList()
                                                                self.connector_value.parent = self
                                                                self.connector_value.name = 'connector_value'
                                                                self.extended_community = YList()
                                                                self.extended_community.parent = self
                                                                self.extended_community.name = 'extended_community'
                                                                self.extended_community_flags = None
                                                                self.is_aggregator_present = None
                                                                self.is_aigp_present = None
                                                                self.is_as_path_present = None
                                                                self.is_atomic_aggregate_present = None
                                                                self.is_community_present = None
                                                                self.is_connector_present = None
                                                                self.is_extended_community_present = None
                                                                self.is_label_index_present = None
                                                                self.is_local_pref_present = None
                                                                self.is_ls_attribute_present = None
                                                                self.is_metric_present = None
                                                                self.is_origin_present = None
                                                                self.is_pe_distinguisher_label_present = None
                                                                self.is_pmsi_present = None
                                                                self.is_pppmp_present = None
                                                                self.is_ssa_present = None
                                                                self.is_tunnel_encap_present = None
                                                                self.l2tpv3_cookie = YList()
                                                                self.l2tpv3_cookie.parent = self
                                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                                self.l2tpv3_session_id = None
                                                                self.label_index_attr = YList()
                                                                self.label_index_attr.parent = self
                                                                self.label_index_attr.name = 'label_index_attr'
                                                                self.local_preference = None
                                                                self.ls_attr = YList()
                                                                self.ls_attr.parent = self
                                                                self.ls_attr.name = 'ls_attr'
                                                                self.metric = None
                                                                self.neighbor_as = None
                                                                self.origin = None
                                                                self.originator = None
                                                                self.pe_distinguisher_label = YList()
                                                                self.pe_distinguisher_label.parent = self
                                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                                self.pmsi_flags = None
                                                                self.pmsi_label = None
                                                                self.pmsi_type = None
                                                                self.pmsi_value = YList()
                                                                self.pmsi_value.parent = self
                                                                self.pmsi_value.name = 'pmsi_value'
                                                                self.ppm_pvalue = None
                                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                                self.sr_policy_allocated_binding_sid.parent = self
                                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                                self.sr_policy_binding_sid.parent = self
                                                                self.sr_policy_explicit_path = YList()
                                                                self.sr_policy_explicit_path.parent = self
                                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                                self.sr_policy_preference = None
                                                                self.sr_tunnel_request_state = None
                                                                self.sr_tunnel_state = None
                                                                self.tunnel_encap_type = None
                                                                self.unknown_attribute = YList()
                                                                self.unknown_attribute.parent = self
                                                                self.unknown_attribute.name = 'unknown_attribute'


                                                            class SrPolicyBindingSid(object):
                                                                """
                                                                SR Policy Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_address = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                            class SrPolicyAllocatedBindingSid(object):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_address = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                            class Community(object):
                                                                """
                                                                Community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                            class ExtendedCommunity(object):
                                                                """
                                                                Extended community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                            class UnknownAttribute(object):
                                                                """
                                                                Unknown attributes
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                            class Cluster(object):
                                                                """
                                                                Cluster list attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                            class L2Tpv3Cookie(object):
                                                                """
                                                                L2TPv3 Cookie
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                            class ConnectorValue(object):
                                                                """
                                                                Connector Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                            class PmsiValue(object):
                                                                """
                                                                PMSI Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                            class LsAttr(object):
                                                                """
                                                                BGP LS attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                            class LabelIndexAttr(object):
                                                                """
                                                                Label Index attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                            class PeDistinguisherLabel(object):
                                                                """
                                                                PE distinguisher label attribute
                                                                
                                                                .. attribute:: label
                                                                
                                                                	Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pe_address
                                                                
                                                                	 PE address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.label = None
                                                                    self.pe_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.pe_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                            class SrPolicyExplicitPath(object):
                                                                """
                                                                SR Policy Explicit paths
                                                                
                                                                .. attribute:: sid
                                                                
                                                                	Sidlist for explicit path
                                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of explicit path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.sid = YList()
                                                                    self.sid.parent = self
                                                                    self.sid.name = 'sid'
                                                                    self.weight = None


                                                                class Sid(object):
                                                                    """
                                                                    Sidlist for explicit path
                                                                    
                                                                    .. attribute:: ipv4
                                                                    
                                                                    	IP Address sid
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6
                                                                    
                                                                    	IPv6 address sid
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label sid
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Sid Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4 = None
                                                                        self.ipv6 = None
                                                                        self.label = None
                                                                        self.type = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4 is not None:
                                                                            return True

                                                                        if self.ipv6 is not None:
                                                                            return True

                                                                        if self.label is not None:
                                                                            return True

                                                                        if self.type is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.sid is not None:
                                                                        for child_ref in self.sid:
                                                                            if child_ref._has_data():
                                                                                return True

                                                                    if self.weight is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.aggregator_address is not None:
                                                                    return True

                                                                if self.aggregator_as is not None:
                                                                    return True

                                                                if self.aigp_metric_value is not None:
                                                                    return True

                                                                if self.as_path is not None:
                                                                    return True

                                                                if self.cluster is not None:
                                                                    for child_ref in self.cluster:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.community is not None:
                                                                    for child_ref in self.community:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.connector_type is not None:
                                                                    return True

                                                                if self.connector_value is not None:
                                                                    for child_ref in self.connector_value:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.extended_community is not None:
                                                                    for child_ref in self.extended_community:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.extended_community_flags is not None:
                                                                    return True

                                                                if self.is_aggregator_present is not None:
                                                                    return True

                                                                if self.is_aigp_present is not None:
                                                                    return True

                                                                if self.is_as_path_present is not None:
                                                                    return True

                                                                if self.is_atomic_aggregate_present is not None:
                                                                    return True

                                                                if self.is_community_present is not None:
                                                                    return True

                                                                if self.is_connector_present is not None:
                                                                    return True

                                                                if self.is_extended_community_present is not None:
                                                                    return True

                                                                if self.is_label_index_present is not None:
                                                                    return True

                                                                if self.is_local_pref_present is not None:
                                                                    return True

                                                                if self.is_ls_attribute_present is not None:
                                                                    return True

                                                                if self.is_metric_present is not None:
                                                                    return True

                                                                if self.is_origin_present is not None:
                                                                    return True

                                                                if self.is_pe_distinguisher_label_present is not None:
                                                                    return True

                                                                if self.is_pmsi_present is not None:
                                                                    return True

                                                                if self.is_pppmp_present is not None:
                                                                    return True

                                                                if self.is_ssa_present is not None:
                                                                    return True

                                                                if self.is_tunnel_encap_present is not None:
                                                                    return True

                                                                if self.l2tpv3_cookie is not None:
                                                                    for child_ref in self.l2tpv3_cookie:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.l2tpv3_session_id is not None:
                                                                    return True

                                                                if self.label_index_attr is not None:
                                                                    for child_ref in self.label_index_attr:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.local_preference is not None:
                                                                    return True

                                                                if self.ls_attr is not None:
                                                                    for child_ref in self.ls_attr:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.metric is not None:
                                                                    return True

                                                                if self.neighbor_as is not None:
                                                                    return True

                                                                if self.origin is not None:
                                                                    return True

                                                                if self.originator is not None:
                                                                    return True

                                                                if self.pe_distinguisher_label is not None:
                                                                    for child_ref in self.pe_distinguisher_label:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.pmsi_flags is not None:
                                                                    return True

                                                                if self.pmsi_label is not None:
                                                                    return True

                                                                if self.pmsi_type is not None:
                                                                    return True

                                                                if self.pmsi_value is not None:
                                                                    for child_ref in self.pmsi_value:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.ppm_pvalue is not None:
                                                                    return True

                                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                                    return True

                                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                                    return True

                                                                if self.sr_policy_explicit_path is not None:
                                                                    for child_ref in self.sr_policy_explicit_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.sr_policy_preference is not None:
                                                                    return True

                                                                if self.sr_tunnel_request_state is not None:
                                                                    return True

                                                                if self.sr_tunnel_state is not None:
                                                                    return True

                                                                if self.tunnel_encap_type is not None:
                                                                    return True

                                                                if self.unknown_attribute is not None:
                                                                    for child_ref in self.unknown_attribute:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                                        class RnhAddr(object):
                                                            """
                                                            RNH Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                            
                                                            .. attribute:: mac_address
                                                            
                                                            	MAC Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self.len = None
                                                                self.mac_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.len is not None:
                                                                    return True

                                                                if self.mac_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                                        class RibrnhIp(object):
                                                            """
                                                            RIB RNH IP Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.attr_set is not None and self.attr_set._has_data():
                                                                return True

                                                            if self.attribute_key_number is not None:
                                                                return True

                                                            if self.attribute_reuse_id_config is not None:
                                                                return True

                                                            if self.attribute_reuse_id_current is not None:
                                                                return True

                                                            if self.attribute_reuse_id_keys is not None:
                                                                return True

                                                            if self.attribute_reuse_id_max_id is not None:
                                                                return True

                                                            if self.attribute_reuse_id_node is not None:
                                                                return True

                                                            if self.attribute_reuse_id_recover_sec is not None:
                                                                return True

                                                            if self.common_attributes is not None and self.common_attributes._has_data():
                                                                return True

                                                            if self.is_application_gateway_present is not None:
                                                                return True

                                                            if self.is_as_path2_byte is not None:
                                                                return True

                                                            if self.is_attr_set_present is not None:
                                                                return True

                                                            if self.is_ribrnh_present is not None:
                                                                return True

                                                            if self.is_rnh_present is not None:
                                                                return True

                                                            if self.ribrnh_encap is not None:
                                                                return True

                                                            if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                                return True

                                                            if self.ribrnh_mac is not None:
                                                                return True

                                                            if self.ribrnh_table is not None:
                                                                return True

                                                            if self.ribrnh_vni is not None:
                                                                return True

                                                            if self.ribrnhip_table is not None:
                                                                return True

                                                            if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                                return True

                                                            if self.rnh_addr_len is not None:
                                                                return True

                                                            if self.rnh_len is not None:
                                                                return True

                                                            if self.rnh_type is not None:
                                                                return True

                                                            if self.set_aigp_inbound_igp is not None:
                                                                return True

                                                            if self.set_aigp_inbound_metric is not None:
                                                                return True

                                                            if self.vpn_distinguisher is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-process-instance-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.af_name is not None:
                                                            return True

                                                        if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                            return True

                                                        if self.label_fail is not None:
                                                            return True

                                                        if self.label_o_or_version is not None:
                                                            return True

                                                        if self.label_oor is not None:
                                                            return True

                                                        if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                            return True

                                                        if self.no_path is not None:
                                                            return True

                                                        if self.path_information is not None and self.path_information._has_data():
                                                            return True

                                                        if self.prefix_version is not None:
                                                            return True

                                                        if self.process_instance_id is not None:
                                                            return True

                                                        if self.route_distinguisher is not None:
                                                            return True

                                                        if self.source_route_distinguisher is not None:
                                                            return True

                                                        if self.source_vrf_name is not None:
                                                            return True

                                                        if self.srcaf_name is not None:
                                                            return True

                                                        if self.vrf_name is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath']['meta_info']


                                                class ActiveProcessInstancePath(object):
                                                    """
                                                    Active's paths for this net 
                                                    
                                                    .. attribute:: af_name
                                                    
                                                    	Address family identifier
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: attributes_after_policy_in
                                                    
                                                    	Attributes after inbound policy applied
                                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn>`
                                                    
                                                    .. attribute:: label_fail
                                                    
                                                    	LSD label allocation failed 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: label_o_or_version
                                                    
                                                    	Label Version when OOR happens
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_oor
                                                    
                                                    	LSD label space is exhausted
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address_xr
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr>`
                                                    
                                                    .. attribute:: no_path
                                                    
                                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: path_information
                                                    
                                                    	Path information
                                                    	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation>`
                                                    
                                                    .. attribute:: prefix_version
                                                    
                                                    	Version of BGP Prefix Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: process_instance_id
                                                    
                                                    	Process instance ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: route_distinguisher
                                                    
                                                    	Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: source_route_distinguisher
                                                    
                                                    	Source Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: source_vrf_name
                                                    
                                                    	Name of the source VRF
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: srcaf_name
                                                    
                                                    	Address family identifier
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: vrf_name
                                                    
                                                    	Name of the VRF
                                                    	**type**\:  str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.af_name = None
                                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn()
                                                        self.attributes_after_policy_in.parent = self
                                                        self.label_fail = None
                                                        self.label_o_or_version = None
                                                        self.label_oor = None
                                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr()
                                                        self.neighbor_address_xr.parent = self
                                                        self.no_path = None
                                                        self.path_information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation()
                                                        self.path_information.parent = self
                                                        self.prefix_version = None
                                                        self.process_instance_id = None
                                                        self.route_distinguisher = None
                                                        self.source_route_distinguisher = None
                                                        self.source_vrf_name = None
                                                        self.srcaf_name = None
                                                        self.vrf_name = None


                                                    class NeighborAddressXr(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr']['meta_info']


                                                    class PathInformation(object):
                                                        """
                                                        Path information
                                                        
                                                        .. attribute:: accept_own_path
                                                        
                                                        	Accept Own
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: accept_own_self_originated_p_ath
                                                        
                                                        	Accept\-Own self\-originated
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: add_path_orr_bitfield
                                                        
                                                        	ORR Add path Bitfields
                                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                        
                                                        .. attribute:: advertisedto_pe
                                                        
                                                        	Net could be advertised                          to PE peers
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: aigp_metric
                                                        
                                                        	Total AIGP metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: best_path_comp_stage
                                                        
                                                        	Stage where the path lost to the best path or group best
                                                        	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                                        
                                                        .. attribute:: best_path_comp_winner
                                                        
                                                        	Neighbor address of the path which won best path comparison
                                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                        
                                                        .. attribute:: best_path_id
                                                        
                                                        	Best path ID; DEPRECATED BYLocalPathId
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: best_path_id_comp_winner
                                                        
                                                        	Path ID of the path which won best path comparison
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: best_path_orr_bitfield
                                                        
                                                        	ORR Best path Bitfields
                                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                        
                                                        .. attribute:: bgp_prefix
                                                        
                                                        	BGP prefix
                                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix>`
                                                        
                                                        .. attribute:: dampen_penalty
                                                        
                                                        	Dampening penalty
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Mvpn Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                        
                                                        .. attribute:: fspec_invalid_path
                                                        
                                                        	Is Fspec invalid path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: graceful_shutdown
                                                        
                                                        	Marked for graceful shutdown
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: gw_addr
                                                        
                                                        	Path GW Address
                                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.GwAddr>`
                                                        
                                                        .. attribute:: halflife_time
                                                        
                                                        	Half\-life time for the penalty
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_esi
                                                        
                                                        	Path has EVPN ESI
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_gw_addr
                                                        
                                                        	Path has GW Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_local_net_label
                                                        
                                                        	Path has local label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mdt_group_addr
                                                        
                                                        	Path has MDT Group Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_extcomm
                                                        
                                                        	Path has MVPN EXTCOMM feedback
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_nbr_addr
                                                        
                                                        	Path has Mvpn nbr Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_nexthop_addr
                                                        
                                                        	Path has MVPN nexthop Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_pmsi
                                                        
                                                        	Path has MVPN PMSI feedback
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_rcvd_label
                                                        
                                                        	Path has received label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_second_label
                                                        
                                                        	Path has second received label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: ibgp_signaled_validity
                                                        
                                                        	IBGP signalled validation
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: igp_metric
                                                        
                                                        	IGP metric to the gateway
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: is_aggregation_suppressed
                                                        
                                                        	Path suppressed due to aggregation
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_best
                                                        
                                                        	Best available path within AS
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_best_path
                                                        
                                                        	Best available path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_import_dampened
                                                        
                                                        	net import dampened
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_import_suspect
                                                        
                                                        	net import suspect
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_internal_path
                                                        
                                                        	Received over an internal link
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_partial_best
                                                        
                                                        	Partial best path within distributed speaker
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_additional_path
                                                        
                                                        	Path is an additional\-path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_advertised_local_as_only
                                                        
                                                        	Not advertised outside local AS
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_af_install_eligible
                                                        
                                                        	Path can be installed in AF RIB
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_backup
                                                        
                                                        	Path is a backup path 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_backup_protect_multipath
                                                        
                                                        	Path is a backup path to protect multipaths
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_best_external
                                                        
                                                        	Path is a best external path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_damped
                                                        
                                                        	Path suppressed due to dampening
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_confederation_peer
                                                        
                                                        	Path received from confederation peer
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_network_command
                                                        
                                                        	Path sourced by network command
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_redistribute_command
                                                        
                                                        	Path sourced by redistribute command
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_route_reflector
                                                        
                                                        	Path received from route reflector
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_history_held
                                                        
                                                        	Path entry held to remember history
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_imp_candidate
                                                        
                                                        	Path is a candidate for multipath import
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_imported
                                                        
                                                        	Path is imported
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_local_aggregate
                                                        
                                                        	Path is a locally created aggregate
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_locally_sourced
                                                        
                                                        	Path sourced locally
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_long_lived_stale
                                                        
                                                        	Long lived stale routes learnt before neighbor restarts
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_multipath
                                                        
                                                        	Path is one of multipath best routes
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_nexthop_discarded
                                                        
                                                        	Path is redirected to Null0
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_not_advertised
                                                        
                                                        	Not advertised to any peer
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_not_advertised_to_ebg_ps
                                                        
                                                        	Not advertised to EBGPs
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_received_only
                                                        
                                                        	Path is received only
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_reoriginated
                                                        
                                                        	Path is reoriginated
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_reoriginated_stitching
                                                        
                                                        	Path is reoriginated with stitching RTs
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_stale
                                                        
                                                        	Stale routes learnt before neighbor restarts
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_synced_with_igp
                                                        
                                                        	Path synchronized with IGP
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_valid
                                                        
                                                        	Path attributes are usable
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_vpn_only
                                                        
                                                        	Path is not in the vrf
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_permanent_path
                                                        
                                                        	Path is of type Permanent path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_received_path_not_modified
                                                        
                                                        	Received path used without modification
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_spkr_as_best
                                                        
                                                        	Best available path within AS in speaker
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2vpn_circuit_status_value
                                                        
                                                        	L2VPN Circuit Status Value
                                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                        
                                                        .. attribute:: l2vpn_evpn_esi
                                                        
                                                        	L2VPN EVPN ESI
                                                        	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi>`
                                                        
                                                        .. attribute:: l2vpn_size
                                                        
                                                        	Path block size
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: labeled_unicast_safi_path
                                                        
                                                        	Path was learnt by labeled\-unicast SAFI
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: local_label
                                                        
                                                        	Path local label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_nh
                                                        
                                                        	Path has local nexthop
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: local_path_id
                                                        
                                                        	Local path ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_peers_advertised_to
                                                        
                                                        	Local peers that this prefix has been advertised to
                                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                        
                                                        .. attribute:: maximum_suppress_time
                                                        
                                                        	Maximum duration to suppress a stable route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mdt_group_addr
                                                        
                                                        	IPv4 MDT Group Address for the path
                                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                        
                                                        .. attribute:: mvpn_nbr_addr
                                                        
                                                        	Mvpn nbr Address for the path
                                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                        
                                                        .. attribute:: mvpn_nexthop_addr
                                                        
                                                        	Mvpn nexthop Address for the path
                                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                        
                                                        .. attribute:: mvpn_path_flags
                                                        
                                                        	Mvpn path flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: mvpn_pmsi_flags
                                                        
                                                        	Mvpn PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: mvpn_pmsi_label
                                                        
                                                        	Mvpn PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mvpn_pmsi_type
                                                        
                                                        	Mvpn PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: mvpn_pmsi_value
                                                        
                                                        	Mvpn PMSI Value
                                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                        
                                                        .. attribute:: mvpn_sfs_path
                                                        
                                                        	Is MVPN single forwarder PE path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress>`
                                                        
                                                        .. attribute:: neighbor_router_id
                                                        
                                                        	Router ID of the neighbor for the path
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: next_hop
                                                        
                                                        	Next hop
                                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop>`
                                                        
                                                        .. attribute:: nhte_tunnel
                                                        
                                                        	NH TE tunnel information
                                                        	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhteTunnel>`
                                                        
                                                        .. attribute:: path_flags
                                                        
                                                        	Flags associated with path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: path_flap_count
                                                        
                                                        	Number of times this route has flapped
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_import_flags
                                                        
                                                        	Path import flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_rt_set_id
                                                        
                                                        	RT\-set id of the path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_rt_set_route_count
                                                        
                                                        	Count in RT\-set
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_table_version
                                                        
                                                        	Table version # for pelem
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_weight
                                                        
                                                        	Weight for the path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pe_peers_advertised_to
                                                        
                                                        	PE peers that this prefix has been advertised to
                                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                        
                                                        .. attribute:: rcvd_label
                                                        
                                                        	Path received label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rcvd_path_id
                                                        
                                                        	Received path ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: reuse_value
                                                        
                                                        	Value to start reusing a route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rib_failed
                                                        
                                                        	Is net failed installed                          in RIB
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route Type of path
                                                        	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                                        
                                                        .. attribute:: rpki_origin_as_validation_disabled
                                                        
                                                        	RPKI originAS V. Disabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: rt_set_limit_enabled
                                                        
                                                        	Path subject to RT\-set net limit
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: second_label
                                                        
                                                        	Path second received label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: seconds_since_first_flap
                                                        
                                                        	Seconds since route first flapped
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: show_rpki_origin_as_validity
                                                        
                                                        	Display validity state ?
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: sn_rpki_origin_as_validity
                                                        
                                                        	RPKI origin validation state
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: suppress_penalty
                                                        
                                                        	Value to start suppressing a route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: time_to_unsuppress
                                                        
                                                        	Seconds until route is unsuppressed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.accept_own_path = None
                                                            self.accept_own_self_originated_p_ath = None
                                                            self.add_path_orr_bitfield = YList()
                                                            self.add_path_orr_bitfield.parent = self
                                                            self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                            self.advertisedto_pe = None
                                                            self.aigp_metric = None
                                                            self.best_path_comp_stage = None
                                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner()
                                                            self.best_path_comp_winner.parent = self
                                                            self.best_path_id = None
                                                            self.best_path_id_comp_winner = None
                                                            self.best_path_orr_bitfield = YList()
                                                            self.best_path_orr_bitfield.parent = self
                                                            self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix()
                                                            self.bgp_prefix.parent = self
                                                            self.dampen_penalty = None
                                                            self.extended_community = YList()
                                                            self.extended_community.parent = self
                                                            self.extended_community.name = 'extended_community'
                                                            self.fspec_invalid_path = None
                                                            self.graceful_shutdown = None
                                                            self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.GwAddr()
                                                            self.gw_addr.parent = self
                                                            self.halflife_time = None
                                                            self.has_esi = None
                                                            self.has_gw_addr = None
                                                            self.has_local_net_label = None
                                                            self.has_mdt_group_addr = None
                                                            self.has_mvpn_extcomm = None
                                                            self.has_mvpn_nbr_addr = None
                                                            self.has_mvpn_nexthop_addr = None
                                                            self.has_mvpn_pmsi = None
                                                            self.has_rcvd_label = None
                                                            self.has_second_label = None
                                                            self.ibgp_signaled_validity = None
                                                            self.igp_metric = None
                                                            self.is_aggregation_suppressed = None
                                                            self.is_as_best = None
                                                            self.is_best_path = None
                                                            self.is_import_dampened = None
                                                            self.is_import_suspect = None
                                                            self.is_internal_path = None
                                                            self.is_partial_best = None
                                                            self.is_path_additional_path = None
                                                            self.is_path_advertised_local_as_only = None
                                                            self.is_path_af_install_eligible = None
                                                            self.is_path_backup = None
                                                            self.is_path_backup_protect_multipath = None
                                                            self.is_path_best_external = None
                                                            self.is_path_damped = None
                                                            self.is_path_from_confederation_peer = None
                                                            self.is_path_from_network_command = None
                                                            self.is_path_from_redistribute_command = None
                                                            self.is_path_from_route_reflector = None
                                                            self.is_path_history_held = None
                                                            self.is_path_imp_candidate = None
                                                            self.is_path_imported = None
                                                            self.is_path_local_aggregate = None
                                                            self.is_path_locally_sourced = None
                                                            self.is_path_long_lived_stale = None
                                                            self.is_path_multipath = None
                                                            self.is_path_nexthop_discarded = None
                                                            self.is_path_not_advertised = None
                                                            self.is_path_not_advertised_to_ebg_ps = None
                                                            self.is_path_received_only = None
                                                            self.is_path_reoriginated = None
                                                            self.is_path_reoriginated_stitching = None
                                                            self.is_path_stale = None
                                                            self.is_path_synced_with_igp = None
                                                            self.is_path_valid = None
                                                            self.is_path_vpn_only = None
                                                            self.is_permanent_path = None
                                                            self.is_received_path_not_modified = None
                                                            self.is_spkr_as_best = None
                                                            self.l2vpn_circuit_status_value = YList()
                                                            self.l2vpn_circuit_status_value.parent = self
                                                            self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                            self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi()
                                                            self.l2vpn_evpn_esi.parent = self
                                                            self.l2vpn_size = None
                                                            self.labeled_unicast_safi_path = None
                                                            self.local_label = None
                                                            self.local_nh = None
                                                            self.local_path_id = None
                                                            self.local_peers_advertised_to = YList()
                                                            self.local_peers_advertised_to.parent = self
                                                            self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                            self.maximum_suppress_time = None
                                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr()
                                                            self.mdt_group_addr.parent = self
                                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                            self.mvpn_nbr_addr.parent = self
                                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                            self.mvpn_nexthop_addr.parent = self
                                                            self.mvpn_path_flags = None
                                                            self.mvpn_pmsi_flags = None
                                                            self.mvpn_pmsi_label = None
                                                            self.mvpn_pmsi_type = None
                                                            self.mvpn_pmsi_value = YList()
                                                            self.mvpn_pmsi_value.parent = self
                                                            self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                            self.mvpn_sfs_path = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.neighbor_router_id = None
                                                            self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop()
                                                            self.next_hop.parent = self
                                                            self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhteTunnel()
                                                            self.nhte_tunnel.parent = self
                                                            self.path_flags = None
                                                            self.path_flap_count = None
                                                            self.path_import_flags = None
                                                            self.path_rt_set_id = None
                                                            self.path_rt_set_route_count = None
                                                            self.path_table_version = None
                                                            self.path_weight = None
                                                            self.pe_peers_advertised_to = YList()
                                                            self.pe_peers_advertised_to.parent = self
                                                            self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                            self.rcvd_label = None
                                                            self.rcvd_path_id = None
                                                            self.reuse_value = None
                                                            self.rib_failed = None
                                                            self.route_type = None
                                                            self.rpki_origin_as_validation_disabled = None
                                                            self.rt_set_limit_enabled = None
                                                            self.second_label = None
                                                            self.seconds_since_first_flap = None
                                                            self.show_rpki_origin_as_validity = None
                                                            self.sn_rpki_origin_as_validity = None
                                                            self.suppress_penalty = None
                                                            self.time_to_unsuppress = None


                                                        class BgpPrefix(object):
                                                            """
                                                            BGP prefix
                                                            
                                                            .. attribute:: prefix
                                                            
                                                            	Prefix
                                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                            
                                                            .. attribute:: prefix_length
                                                            
                                                            	Prefix length
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                                self.prefix.parent = self
                                                                self.prefix_length = None


                                                            class Prefix(object):
                                                                """
                                                                Prefix
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.prefix is not None and self.prefix._has_data():
                                                                    return True

                                                                if self.prefix_length is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix']['meta_info']


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress']['meta_info']


                                                        class NextHop(object):
                                                            """
                                                            Next hop
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop']['meta_info']


                                                        class NhteTunnel(object):
                                                            """
                                                            NH TE tunnel information
                                                            
                                                            .. attribute:: binding_label
                                                            
                                                            	Binding label for the tunnel
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: has_te_tunnel
                                                            
                                                            	NH TE Tunnel info is present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_info_stale
                                                            
                                                            	Tunnel is stale
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_registered
                                                            
                                                            	Tunnel registered flag
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_up
                                                            
                                                            	Tunnel Up flag
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: last_tunnel_update
                                                            
                                                            	Time since the last rib update happened
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_if_handle
                                                            
                                                            	Interface handle for the tunnel
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_name
                                                            
                                                            	tunnel name
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            .. attribute:: tunnel_type
                                                            
                                                            	tunnel type
                                                            	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                            
                                                            .. attribute:: tunnel_v6_enabled
                                                            
                                                            	IPv6 enabled
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_v6_required
                                                            
                                                            	Tunnel need IPv6
                                                            	**type**\:  bool
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.binding_label = None
                                                                self.has_te_tunnel = None
                                                                self.is_tunnel_info_stale = None
                                                                self.is_tunnel_registered = None
                                                                self.is_tunnel_up = None
                                                                self.last_tunnel_update = None
                                                                self.tunnel_if_handle = None
                                                                self.tunnel_name = None
                                                                self.tunnel_type = None
                                                                self.tunnel_v6_enabled = None
                                                                self.tunnel_v6_required = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.binding_label is not None:
                                                                    return True

                                                                if self.has_te_tunnel is not None:
                                                                    return True

                                                                if self.is_tunnel_info_stale is not None:
                                                                    return True

                                                                if self.is_tunnel_registered is not None:
                                                                    return True

                                                                if self.is_tunnel_up is not None:
                                                                    return True

                                                                if self.last_tunnel_update is not None:
                                                                    return True

                                                                if self.tunnel_if_handle is not None:
                                                                    return True

                                                                if self.tunnel_name is not None:
                                                                    return True

                                                                if self.tunnel_type is not None:
                                                                    return True

                                                                if self.tunnel_v6_enabled is not None:
                                                                    return True

                                                                if self.tunnel_v6_required is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhteTunnel']['meta_info']


                                                        class MdtGroupAddr(object):
                                                            """
                                                            IPv4 MDT Group Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr']['meta_info']


                                                        class L2VpnEvpnEsi(object):
                                                            """
                                                            L2VPN EVPN ESI
                                                            
                                                            .. attribute:: esi
                                                            
                                                            	esi
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.esi = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.esi is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi']['meta_info']


                                                        class GwAddr(object):
                                                            """
                                                            Path GW Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self.len = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.len is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.GwAddr']['meta_info']


                                                        class BestPathCompWinner(object):
                                                            """
                                                            Neighbor address of the path which won best path
                                                            comparison
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner']['meta_info']


                                                        class MvpnNbrAddr(object):
                                                            """
                                                            Mvpn nbr Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr']['meta_info']


                                                        class MvpnNexthopAddr(object):
                                                            """
                                                            Mvpn nexthop Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr']['meta_info']


                                                        class L2VpnCircuitStatusValue(object):
                                                            """
                                                            L2VPN Circuit Status Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                                        class MvpnPmsiValue(object):
                                                            """
                                                            Mvpn PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue']['meta_info']


                                                        class ExtendedCommunity(object):
                                                            """
                                                            Mvpn Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity']['meta_info']


                                                        class LocalPeersAdvertisedTo(object):
                                                            """
                                                            Local peers that this prefix has been advertised
                                                            to
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.is_neighbor = None
                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self.update_group_number = None


                                                            class NeighborAddress(object):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.is_neighbor is not None:
                                                                    return True

                                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                    return True

                                                                if self.update_group_number is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                                        class PePeersAdvertisedTo(object):
                                                            """
                                                            PE peers that this prefix has been advertised to
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.is_neighbor = None
                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self.update_group_number = None


                                                            class NeighborAddress(object):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.is_neighbor is not None:
                                                                    return True

                                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                    return True

                                                                if self.update_group_number is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo']['meta_info']


                                                        class BestPathOrrBitfield(object):
                                                            """
                                                            ORR Best path Bitfields
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.is_neighbor = None
                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self.update_group_number = None


                                                            class NeighborAddress(object):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.is_neighbor is not None:
                                                                    return True

                                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                    return True

                                                                if self.update_group_number is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield']['meta_info']


                                                        class AddPathOrrBitfield(object):
                                                            """
                                                            ORR Add path Bitfields
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.is_neighbor = None
                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self.update_group_number = None


                                                            class NeighborAddress(object):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.is_neighbor is not None:
                                                                    return True

                                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                    return True

                                                                if self.update_group_number is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.accept_own_path is not None:
                                                                return True

                                                            if self.accept_own_self_originated_p_ath is not None:
                                                                return True

                                                            if self.add_path_orr_bitfield is not None:
                                                                for child_ref in self.add_path_orr_bitfield:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.advertisedto_pe is not None:
                                                                return True

                                                            if self.aigp_metric is not None:
                                                                return True

                                                            if self.best_path_comp_stage is not None:
                                                                return True

                                                            if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                                return True

                                                            if self.best_path_id is not None:
                                                                return True

                                                            if self.best_path_id_comp_winner is not None:
                                                                return True

                                                            if self.best_path_orr_bitfield is not None:
                                                                for child_ref in self.best_path_orr_bitfield:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                                return True

                                                            if self.dampen_penalty is not None:
                                                                return True

                                                            if self.extended_community is not None:
                                                                for child_ref in self.extended_community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.fspec_invalid_path is not None:
                                                                return True

                                                            if self.graceful_shutdown is not None:
                                                                return True

                                                            if self.gw_addr is not None and self.gw_addr._has_data():
                                                                return True

                                                            if self.halflife_time is not None:
                                                                return True

                                                            if self.has_esi is not None:
                                                                return True

                                                            if self.has_gw_addr is not None:
                                                                return True

                                                            if self.has_local_net_label is not None:
                                                                return True

                                                            if self.has_mdt_group_addr is not None:
                                                                return True

                                                            if self.has_mvpn_extcomm is not None:
                                                                return True

                                                            if self.has_mvpn_nbr_addr is not None:
                                                                return True

                                                            if self.has_mvpn_nexthop_addr is not None:
                                                                return True

                                                            if self.has_mvpn_pmsi is not None:
                                                                return True

                                                            if self.has_rcvd_label is not None:
                                                                return True

                                                            if self.has_second_label is not None:
                                                                return True

                                                            if self.ibgp_signaled_validity is not None:
                                                                return True

                                                            if self.igp_metric is not None:
                                                                return True

                                                            if self.is_aggregation_suppressed is not None:
                                                                return True

                                                            if self.is_as_best is not None:
                                                                return True

                                                            if self.is_best_path is not None:
                                                                return True

                                                            if self.is_import_dampened is not None:
                                                                return True

                                                            if self.is_import_suspect is not None:
                                                                return True

                                                            if self.is_internal_path is not None:
                                                                return True

                                                            if self.is_partial_best is not None:
                                                                return True

                                                            if self.is_path_additional_path is not None:
                                                                return True

                                                            if self.is_path_advertised_local_as_only is not None:
                                                                return True

                                                            if self.is_path_af_install_eligible is not None:
                                                                return True

                                                            if self.is_path_backup is not None:
                                                                return True

                                                            if self.is_path_backup_protect_multipath is not None:
                                                                return True

                                                            if self.is_path_best_external is not None:
                                                                return True

                                                            if self.is_path_damped is not None:
                                                                return True

                                                            if self.is_path_from_confederation_peer is not None:
                                                                return True

                                                            if self.is_path_from_network_command is not None:
                                                                return True

                                                            if self.is_path_from_redistribute_command is not None:
                                                                return True

                                                            if self.is_path_from_route_reflector is not None:
                                                                return True

                                                            if self.is_path_history_held is not None:
                                                                return True

                                                            if self.is_path_imp_candidate is not None:
                                                                return True

                                                            if self.is_path_imported is not None:
                                                                return True

                                                            if self.is_path_local_aggregate is not None:
                                                                return True

                                                            if self.is_path_locally_sourced is not None:
                                                                return True

                                                            if self.is_path_long_lived_stale is not None:
                                                                return True

                                                            if self.is_path_multipath is not None:
                                                                return True

                                                            if self.is_path_nexthop_discarded is not None:
                                                                return True

                                                            if self.is_path_not_advertised is not None:
                                                                return True

                                                            if self.is_path_not_advertised_to_ebg_ps is not None:
                                                                return True

                                                            if self.is_path_received_only is not None:
                                                                return True

                                                            if self.is_path_reoriginated is not None:
                                                                return True

                                                            if self.is_path_reoriginated_stitching is not None:
                                                                return True

                                                            if self.is_path_stale is not None:
                                                                return True

                                                            if self.is_path_synced_with_igp is not None:
                                                                return True

                                                            if self.is_path_valid is not None:
                                                                return True

                                                            if self.is_path_vpn_only is not None:
                                                                return True

                                                            if self.is_permanent_path is not None:
                                                                return True

                                                            if self.is_received_path_not_modified is not None:
                                                                return True

                                                            if self.is_spkr_as_best is not None:
                                                                return True

                                                            if self.l2vpn_circuit_status_value is not None:
                                                                for child_ref in self.l2vpn_circuit_status_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                                return True

                                                            if self.l2vpn_size is not None:
                                                                return True

                                                            if self.labeled_unicast_safi_path is not None:
                                                                return True

                                                            if self.local_label is not None:
                                                                return True

                                                            if self.local_nh is not None:
                                                                return True

                                                            if self.local_path_id is not None:
                                                                return True

                                                            if self.local_peers_advertised_to is not None:
                                                                for child_ref in self.local_peers_advertised_to:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.maximum_suppress_time is not None:
                                                                return True

                                                            if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                                return True

                                                            if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                                return True

                                                            if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                                return True

                                                            if self.mvpn_path_flags is not None:
                                                                return True

                                                            if self.mvpn_pmsi_flags is not None:
                                                                return True

                                                            if self.mvpn_pmsi_label is not None:
                                                                return True

                                                            if self.mvpn_pmsi_type is not None:
                                                                return True

                                                            if self.mvpn_pmsi_value is not None:
                                                                for child_ref in self.mvpn_pmsi_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.mvpn_sfs_path is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.neighbor_router_id is not None:
                                                                return True

                                                            if self.next_hop is not None and self.next_hop._has_data():
                                                                return True

                                                            if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                                return True

                                                            if self.path_flags is not None:
                                                                return True

                                                            if self.path_flap_count is not None:
                                                                return True

                                                            if self.path_import_flags is not None:
                                                                return True

                                                            if self.path_rt_set_id is not None:
                                                                return True

                                                            if self.path_rt_set_route_count is not None:
                                                                return True

                                                            if self.path_table_version is not None:
                                                                return True

                                                            if self.path_weight is not None:
                                                                return True

                                                            if self.pe_peers_advertised_to is not None:
                                                                for child_ref in self.pe_peers_advertised_to:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.rcvd_label is not None:
                                                                return True

                                                            if self.rcvd_path_id is not None:
                                                                return True

                                                            if self.reuse_value is not None:
                                                                return True

                                                            if self.rib_failed is not None:
                                                                return True

                                                            if self.route_type is not None:
                                                                return True

                                                            if self.rpki_origin_as_validation_disabled is not None:
                                                                return True

                                                            if self.rt_set_limit_enabled is not None:
                                                                return True

                                                            if self.second_label is not None:
                                                                return True

                                                            if self.seconds_since_first_flap is not None:
                                                                return True

                                                            if self.show_rpki_origin_as_validity is not None:
                                                                return True

                                                            if self.sn_rpki_origin_as_validity is not None:
                                                                return True

                                                            if self.suppress_penalty is not None:
                                                                return True

                                                            if self.time_to_unsuppress is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation']['meta_info']


                                                    class AttributesAfterPolicyIn(object):
                                                        """
                                                        Attributes after inbound policy applied
                                                        
                                                        .. attribute:: attr_set
                                                        
                                                        	ATTR\_SET attribute
                                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                        
                                                        .. attribute:: attribute_key_number
                                                        
                                                        	Attribute key number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_config
                                                        
                                                        	Attribute reuse ID Configured
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: attribute_reuse_id_current
                                                        
                                                        	Attribute reuse ID current ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_keys
                                                        
                                                        	Attribute reuse ID allocated keys
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_max_id
                                                        
                                                        	Attribute reuse ID maximum ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_node
                                                        
                                                        	Attribute reuse ID nodes
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_recover_sec
                                                        
                                                        	Attribute reuse ID timer in seconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: common_attributes
                                                        
                                                        	Common attributes
                                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                        
                                                        .. attribute:: is_application_gateway_present
                                                        
                                                        	Application gateway present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path2_byte
                                                        
                                                        	AS path encoded as 2\-byte
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_attr_set_present
                                                        
                                                        	BGP ATTR\_SET attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ribrnh_present
                                                        
                                                        	RIB RNH Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_rnh_present
                                                        
                                                        	RNH Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: ribrnh_encap
                                                        
                                                        	RIB RNH Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ribrnh_ip
                                                        
                                                        	RIB RNH IP Address
                                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                        
                                                        .. attribute:: ribrnh_mac
                                                        
                                                        	RIB RNH MAC Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                        
                                                        .. attribute:: ribrnh_table
                                                        
                                                        	RIB RNH Table
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ribrnh_vni
                                                        
                                                        	RIB RNH Vni
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ribrnhip_table
                                                        
                                                        	RIB RNH IP Table
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rnh_addr
                                                        
                                                        	RNH Address
                                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                        
                                                        .. attribute:: rnh_addr_len
                                                        
                                                        	RNH Address Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rnh_len
                                                        
                                                        	RNH Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: rnh_type
                                                        
                                                        	RNH Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: set_aigp_inbound_igp
                                                        
                                                        	AIGP set by policy inbound IGP 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: set_aigp_inbound_metric
                                                        
                                                        	AIGP set by policy inbound metric
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: vpn_distinguisher
                                                        
                                                        	VPN Distinguisher
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                            self.attr_set.parent = self
                                                            self.attribute_key_number = None
                                                            self.attribute_reuse_id_config = None
                                                            self.attribute_reuse_id_current = None
                                                            self.attribute_reuse_id_keys = None
                                                            self.attribute_reuse_id_max_id = None
                                                            self.attribute_reuse_id_node = None
                                                            self.attribute_reuse_id_recover_sec = None
                                                            self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                            self.common_attributes.parent = self
                                                            self.is_application_gateway_present = None
                                                            self.is_as_path2_byte = None
                                                            self.is_attr_set_present = None
                                                            self.is_ribrnh_present = None
                                                            self.is_rnh_present = None
                                                            self.ribrnh_encap = None
                                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                            self.ribrnh_ip.parent = self
                                                            self.ribrnh_mac = None
                                                            self.ribrnh_table = None
                                                            self.ribrnh_vni = None
                                                            self.ribrnhip_table = None
                                                            self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                            self.rnh_addr.parent = self
                                                            self.rnh_addr_len = None
                                                            self.rnh_len = None
                                                            self.rnh_type = None
                                                            self.set_aigp_inbound_igp = None
                                                            self.set_aigp_inbound_metric = None
                                                            self.vpn_distinguisher = None


                                                        class CommonAttributes(object):
                                                            """
                                                            Common attributes
                                                            
                                                            .. attribute:: aggregator_address
                                                            
                                                            	Address where aggregation was performed
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: aggregator_as
                                                            
                                                            	AS where aggregation was last performed
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: aigp_metric_value
                                                            
                                                            	AIGP metric value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..18446744073709551615
                                                            
                                                            .. attribute:: as_path
                                                            
                                                            	AS path attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: cluster
                                                            
                                                            	Cluster list attribute
                                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                            
                                                            .. attribute:: community
                                                            
                                                            	Community attribute
                                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                            
                                                            .. attribute:: connector_type
                                                            
                                                            	Connector Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: connector_value
                                                            
                                                            	Connector Value
                                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                            
                                                            .. attribute:: extended_community
                                                            
                                                            	Extended community attribute
                                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                            
                                                            .. attribute:: extended_community_flags
                                                            
                                                            	Extended community Flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: is_aggregator_present
                                                            
                                                            	Aggregator attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_aigp_present
                                                            
                                                            	AIGP Present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_as_path_present
                                                            
                                                            	AS path attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_atomic_aggregate_present
                                                            
                                                            	Atomic aggregate attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_community_present
                                                            
                                                            	Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_connector_present
                                                            
                                                            	Connector present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_extended_community_present
                                                            
                                                            	Extended community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_label_index_present
                                                            
                                                            	Label Index attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_local_pref_present
                                                            
                                                            	Local Preference attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ls_attribute_present
                                                            
                                                            	BGP LS attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_metric_present
                                                            
                                                            	Metric attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_origin_present
                                                            
                                                            	Origin attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pe_distinguisher_label_present
                                                            
                                                            	PE distinguisher label  attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pmsi_present
                                                            
                                                            	PMSI Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pppmp_present
                                                            
                                                            	PPMP Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ssa_present
                                                            
                                                            	SSA attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_encap_present
                                                            
                                                            	Tunnel Encap attribute present 
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: l2tpv3_cookie
                                                            
                                                            	L2TPv3 Cookie
                                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                            
                                                            .. attribute:: l2tpv3_session_id
                                                            
                                                            	L2TPv3 session id
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: label_index_attr
                                                            
                                                            	Label Index attribute
                                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                            
                                                            .. attribute:: local_preference
                                                            
                                                            	Local preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ls_attr
                                                            
                                                            	BGP LS attribute
                                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	Metric
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: neighbor_as
                                                            
                                                            	Neighbor AS number
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: origin
                                                            
                                                            	Origin
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: originator
                                                            
                                                            	Originator attribute
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: pe_distinguisher_label
                                                            
                                                            	PE distinguisher label attribute
                                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                            
                                                            .. attribute:: pmsi_flags
                                                            
                                                            	PMSI Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pmsi_label
                                                            
                                                            	PMSI label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pmsi_type
                                                            
                                                            	PMSI Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: pmsi_value
                                                            
                                                            	PMSI Value
                                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                            
                                                            .. attribute:: ppm_pvalue
                                                            
                                                            	PPMP Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: sr_policy_allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                            
                                                            .. attribute:: sr_policy_binding_sid
                                                            
                                                            	SR Policy Binding sid
                                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                            
                                                            .. attribute:: sr_policy_explicit_path
                                                            
                                                            	SR Policy Explicit paths
                                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                            
                                                            .. attribute:: sr_policy_preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: sr_tunnel_request_state
                                                            
                                                            	SR Tunnel Request State
                                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                            
                                                            .. attribute:: sr_tunnel_state
                                                            
                                                            	SR Tunnel State
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encap Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: unknown_attribute
                                                            
                                                            	Unknown attributes
                                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.aggregator_address = None
                                                                self.aggregator_as = None
                                                                self.aigp_metric_value = None
                                                                self.as_path = None
                                                                self.cluster = YList()
                                                                self.cluster.parent = self
                                                                self.cluster.name = 'cluster'
                                                                self.community = YList()
                                                                self.community.parent = self
                                                                self.community.name = 'community'
                                                                self.connector_type = None
                                                                self.connector_value = YList()
                                                                self.connector_value.parent = self
                                                                self.connector_value.name = 'connector_value'
                                                                self.extended_community = YList()
                                                                self.extended_community.parent = self
                                                                self.extended_community.name = 'extended_community'
                                                                self.extended_community_flags = None
                                                                self.is_aggregator_present = None
                                                                self.is_aigp_present = None
                                                                self.is_as_path_present = None
                                                                self.is_atomic_aggregate_present = None
                                                                self.is_community_present = None
                                                                self.is_connector_present = None
                                                                self.is_extended_community_present = None
                                                                self.is_label_index_present = None
                                                                self.is_local_pref_present = None
                                                                self.is_ls_attribute_present = None
                                                                self.is_metric_present = None
                                                                self.is_origin_present = None
                                                                self.is_pe_distinguisher_label_present = None
                                                                self.is_pmsi_present = None
                                                                self.is_pppmp_present = None
                                                                self.is_ssa_present = None
                                                                self.is_tunnel_encap_present = None
                                                                self.l2tpv3_cookie = YList()
                                                                self.l2tpv3_cookie.parent = self
                                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                                self.l2tpv3_session_id = None
                                                                self.label_index_attr = YList()
                                                                self.label_index_attr.parent = self
                                                                self.label_index_attr.name = 'label_index_attr'
                                                                self.local_preference = None
                                                                self.ls_attr = YList()
                                                                self.ls_attr.parent = self
                                                                self.ls_attr.name = 'ls_attr'
                                                                self.metric = None
                                                                self.neighbor_as = None
                                                                self.origin = None
                                                                self.originator = None
                                                                self.pe_distinguisher_label = YList()
                                                                self.pe_distinguisher_label.parent = self
                                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                                self.pmsi_flags = None
                                                                self.pmsi_label = None
                                                                self.pmsi_type = None
                                                                self.pmsi_value = YList()
                                                                self.pmsi_value.parent = self
                                                                self.pmsi_value.name = 'pmsi_value'
                                                                self.ppm_pvalue = None
                                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                                self.sr_policy_allocated_binding_sid.parent = self
                                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                                self.sr_policy_binding_sid.parent = self
                                                                self.sr_policy_explicit_path = YList()
                                                                self.sr_policy_explicit_path.parent = self
                                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                                self.sr_policy_preference = None
                                                                self.sr_tunnel_request_state = None
                                                                self.sr_tunnel_state = None
                                                                self.tunnel_encap_type = None
                                                                self.unknown_attribute = YList()
                                                                self.unknown_attribute.parent = self
                                                                self.unknown_attribute.name = 'unknown_attribute'


                                                            class SrPolicyBindingSid(object):
                                                                """
                                                                SR Policy Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_address = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                            class SrPolicyAllocatedBindingSid(object):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_address = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                            class Community(object):
                                                                """
                                                                Community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                            class ExtendedCommunity(object):
                                                                """
                                                                Extended community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                            class UnknownAttribute(object):
                                                                """
                                                                Unknown attributes
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                            class Cluster(object):
                                                                """
                                                                Cluster list attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                            class L2Tpv3Cookie(object):
                                                                """
                                                                L2TPv3 Cookie
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                            class ConnectorValue(object):
                                                                """
                                                                Connector Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                            class PmsiValue(object):
                                                                """
                                                                PMSI Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                            class LsAttr(object):
                                                                """
                                                                BGP LS attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                            class LabelIndexAttr(object):
                                                                """
                                                                Label Index attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                            class PeDistinguisherLabel(object):
                                                                """
                                                                PE distinguisher label attribute
                                                                
                                                                .. attribute:: label
                                                                
                                                                	Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pe_address
                                                                
                                                                	 PE address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.label = None
                                                                    self.pe_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.pe_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                            class SrPolicyExplicitPath(object):
                                                                """
                                                                SR Policy Explicit paths
                                                                
                                                                .. attribute:: sid
                                                                
                                                                	Sidlist for explicit path
                                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of explicit path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.sid = YList()
                                                                    self.sid.parent = self
                                                                    self.sid.name = 'sid'
                                                                    self.weight = None


                                                                class Sid(object):
                                                                    """
                                                                    Sidlist for explicit path
                                                                    
                                                                    .. attribute:: ipv4
                                                                    
                                                                    	IP Address sid
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6
                                                                    
                                                                    	IPv6 address sid
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label sid
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Sid Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4 = None
                                                                        self.ipv6 = None
                                                                        self.label = None
                                                                        self.type = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4 is not None:
                                                                            return True

                                                                        if self.ipv6 is not None:
                                                                            return True

                                                                        if self.label is not None:
                                                                            return True

                                                                        if self.type is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.sid is not None:
                                                                        for child_ref in self.sid:
                                                                            if child_ref._has_data():
                                                                                return True

                                                                    if self.weight is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.aggregator_address is not None:
                                                                    return True

                                                                if self.aggregator_as is not None:
                                                                    return True

                                                                if self.aigp_metric_value is not None:
                                                                    return True

                                                                if self.as_path is not None:
                                                                    return True

                                                                if self.cluster is not None:
                                                                    for child_ref in self.cluster:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.community is not None:
                                                                    for child_ref in self.community:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.connector_type is not None:
                                                                    return True

                                                                if self.connector_value is not None:
                                                                    for child_ref in self.connector_value:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.extended_community is not None:
                                                                    for child_ref in self.extended_community:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.extended_community_flags is not None:
                                                                    return True

                                                                if self.is_aggregator_present is not None:
                                                                    return True

                                                                if self.is_aigp_present is not None:
                                                                    return True

                                                                if self.is_as_path_present is not None:
                                                                    return True

                                                                if self.is_atomic_aggregate_present is not None:
                                                                    return True

                                                                if self.is_community_present is not None:
                                                                    return True

                                                                if self.is_connector_present is not None:
                                                                    return True

                                                                if self.is_extended_community_present is not None:
                                                                    return True

                                                                if self.is_label_index_present is not None:
                                                                    return True

                                                                if self.is_local_pref_present is not None:
                                                                    return True

                                                                if self.is_ls_attribute_present is not None:
                                                                    return True

                                                                if self.is_metric_present is not None:
                                                                    return True

                                                                if self.is_origin_present is not None:
                                                                    return True

                                                                if self.is_pe_distinguisher_label_present is not None:
                                                                    return True

                                                                if self.is_pmsi_present is not None:
                                                                    return True

                                                                if self.is_pppmp_present is not None:
                                                                    return True

                                                                if self.is_ssa_present is not None:
                                                                    return True

                                                                if self.is_tunnel_encap_present is not None:
                                                                    return True

                                                                if self.l2tpv3_cookie is not None:
                                                                    for child_ref in self.l2tpv3_cookie:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.l2tpv3_session_id is not None:
                                                                    return True

                                                                if self.label_index_attr is not None:
                                                                    for child_ref in self.label_index_attr:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.local_preference is not None:
                                                                    return True

                                                                if self.ls_attr is not None:
                                                                    for child_ref in self.ls_attr:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.metric is not None:
                                                                    return True

                                                                if self.neighbor_as is not None:
                                                                    return True

                                                                if self.origin is not None:
                                                                    return True

                                                                if self.originator is not None:
                                                                    return True

                                                                if self.pe_distinguisher_label is not None:
                                                                    for child_ref in self.pe_distinguisher_label:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.pmsi_flags is not None:
                                                                    return True

                                                                if self.pmsi_label is not None:
                                                                    return True

                                                                if self.pmsi_type is not None:
                                                                    return True

                                                                if self.pmsi_value is not None:
                                                                    for child_ref in self.pmsi_value:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.ppm_pvalue is not None:
                                                                    return True

                                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                                    return True

                                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                                    return True

                                                                if self.sr_policy_explicit_path is not None:
                                                                    for child_ref in self.sr_policy_explicit_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.sr_policy_preference is not None:
                                                                    return True

                                                                if self.sr_tunnel_request_state is not None:
                                                                    return True

                                                                if self.sr_tunnel_state is not None:
                                                                    return True

                                                                if self.tunnel_encap_type is not None:
                                                                    return True

                                                                if self.unknown_attribute is not None:
                                                                    for child_ref in self.unknown_attribute:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                                        class AttrSet(object):
                                                            """
                                                            ATTR\_SET attribute
                                                            
                                                            .. attribute:: aggregator_address
                                                            
                                                            	Address where aggregation was performed
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: aggregator_as
                                                            
                                                            	AS where aggregation was last performed
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: aigp_metric_value
                                                            
                                                            	AIGP metric value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..18446744073709551615
                                                            
                                                            .. attribute:: as_path
                                                            
                                                            	AS path attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: cluster
                                                            
                                                            	Cluster list attribute
                                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                            
                                                            .. attribute:: community
                                                            
                                                            	Community attribute
                                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                            
                                                            .. attribute:: connector_type
                                                            
                                                            	Connector Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: connector_value
                                                            
                                                            	Connector Value
                                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                            
                                                            .. attribute:: extended_community
                                                            
                                                            	Extended community attribute
                                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                            
                                                            .. attribute:: extended_community_flags
                                                            
                                                            	Extended community Flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: is_aggregator_present
                                                            
                                                            	Aggregator attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_aigp_present
                                                            
                                                            	AIGP Present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_as_path_present
                                                            
                                                            	AS path attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_atomic_aggregate_present
                                                            
                                                            	Atomic aggregate attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_community_present
                                                            
                                                            	Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_connector_present
                                                            
                                                            	Connector present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_extended_community_present
                                                            
                                                            	Extended community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_label_index_present
                                                            
                                                            	Label Index attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_local_pref_present
                                                            
                                                            	Local Preference attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ls_attribute_present
                                                            
                                                            	BGP LS attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_metric_present
                                                            
                                                            	Metric attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_origin_present
                                                            
                                                            	Origin attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pe_distinguisher_label_present
                                                            
                                                            	PE distinguisher label  attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pmsi_present
                                                            
                                                            	PMSI Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pppmp_present
                                                            
                                                            	PPMP Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ssa_present
                                                            
                                                            	SSA attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_encap_present
                                                            
                                                            	Tunnel Encap attribute present 
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: l2tpv3_cookie
                                                            
                                                            	L2TPv3 Cookie
                                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                            
                                                            .. attribute:: l2tpv3_session_id
                                                            
                                                            	L2TPv3 session id
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: label_index_attr
                                                            
                                                            	Label Index attribute
                                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                            
                                                            .. attribute:: local_preference
                                                            
                                                            	Local preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ls_attr
                                                            
                                                            	BGP LS attribute
                                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	Metric
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: neighbor_as
                                                            
                                                            	Neighbor AS number
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: origin
                                                            
                                                            	Origin
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: originator
                                                            
                                                            	Originator attribute
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: pe_distinguisher_label
                                                            
                                                            	PE distinguisher label attribute
                                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                            
                                                            .. attribute:: pmsi_flags
                                                            
                                                            	PMSI Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pmsi_label
                                                            
                                                            	PMSI label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pmsi_type
                                                            
                                                            	PMSI Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: pmsi_value
                                                            
                                                            	PMSI Value
                                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                            
                                                            .. attribute:: ppm_pvalue
                                                            
                                                            	PPMP Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: sr_policy_allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                            
                                                            .. attribute:: sr_policy_binding_sid
                                                            
                                                            	SR Policy Binding sid
                                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                            
                                                            .. attribute:: sr_policy_explicit_path
                                                            
                                                            	SR Policy Explicit paths
                                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                            
                                                            .. attribute:: sr_policy_preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: sr_tunnel_request_state
                                                            
                                                            	SR Tunnel Request State
                                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                            
                                                            .. attribute:: sr_tunnel_state
                                                            
                                                            	SR Tunnel State
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encap Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: unknown_attribute
                                                            
                                                            	Unknown attributes
                                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.aggregator_address = None
                                                                self.aggregator_as = None
                                                                self.aigp_metric_value = None
                                                                self.as_path = None
                                                                self.cluster = YList()
                                                                self.cluster.parent = self
                                                                self.cluster.name = 'cluster'
                                                                self.community = YList()
                                                                self.community.parent = self
                                                                self.community.name = 'community'
                                                                self.connector_type = None
                                                                self.connector_value = YList()
                                                                self.connector_value.parent = self
                                                                self.connector_value.name = 'connector_value'
                                                                self.extended_community = YList()
                                                                self.extended_community.parent = self
                                                                self.extended_community.name = 'extended_community'
                                                                self.extended_community_flags = None
                                                                self.is_aggregator_present = None
                                                                self.is_aigp_present = None
                                                                self.is_as_path_present = None
                                                                self.is_atomic_aggregate_present = None
                                                                self.is_community_present = None
                                                                self.is_connector_present = None
                                                                self.is_extended_community_present = None
                                                                self.is_label_index_present = None
                                                                self.is_local_pref_present = None
                                                                self.is_ls_attribute_present = None
                                                                self.is_metric_present = None
                                                                self.is_origin_present = None
                                                                self.is_pe_distinguisher_label_present = None
                                                                self.is_pmsi_present = None
                                                                self.is_pppmp_present = None
                                                                self.is_ssa_present = None
                                                                self.is_tunnel_encap_present = None
                                                                self.l2tpv3_cookie = YList()
                                                                self.l2tpv3_cookie.parent = self
                                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                                self.l2tpv3_session_id = None
                                                                self.label_index_attr = YList()
                                                                self.label_index_attr.parent = self
                                                                self.label_index_attr.name = 'label_index_attr'
                                                                self.local_preference = None
                                                                self.ls_attr = YList()
                                                                self.ls_attr.parent = self
                                                                self.ls_attr.name = 'ls_attr'
                                                                self.metric = None
                                                                self.neighbor_as = None
                                                                self.origin = None
                                                                self.originator = None
                                                                self.pe_distinguisher_label = YList()
                                                                self.pe_distinguisher_label.parent = self
                                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                                self.pmsi_flags = None
                                                                self.pmsi_label = None
                                                                self.pmsi_type = None
                                                                self.pmsi_value = YList()
                                                                self.pmsi_value.parent = self
                                                                self.pmsi_value.name = 'pmsi_value'
                                                                self.ppm_pvalue = None
                                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                                self.sr_policy_allocated_binding_sid.parent = self
                                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                                self.sr_policy_binding_sid.parent = self
                                                                self.sr_policy_explicit_path = YList()
                                                                self.sr_policy_explicit_path.parent = self
                                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                                self.sr_policy_preference = None
                                                                self.sr_tunnel_request_state = None
                                                                self.sr_tunnel_state = None
                                                                self.tunnel_encap_type = None
                                                                self.unknown_attribute = YList()
                                                                self.unknown_attribute.parent = self
                                                                self.unknown_attribute.name = 'unknown_attribute'


                                                            class SrPolicyBindingSid(object):
                                                                """
                                                                SR Policy Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_address = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                            class SrPolicyAllocatedBindingSid(object):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_address = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                            class Community(object):
                                                                """
                                                                Community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                            class ExtendedCommunity(object):
                                                                """
                                                                Extended community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                            class UnknownAttribute(object):
                                                                """
                                                                Unknown attributes
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                            class Cluster(object):
                                                                """
                                                                Cluster list attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                            class L2Tpv3Cookie(object):
                                                                """
                                                                L2TPv3 Cookie
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                            class ConnectorValue(object):
                                                                """
                                                                Connector Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                            class PmsiValue(object):
                                                                """
                                                                PMSI Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                            class LsAttr(object):
                                                                """
                                                                BGP LS attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                            class LabelIndexAttr(object):
                                                                """
                                                                Label Index attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                            class PeDistinguisherLabel(object):
                                                                """
                                                                PE distinguisher label attribute
                                                                
                                                                .. attribute:: label
                                                                
                                                                	Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pe_address
                                                                
                                                                	 PE address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.label = None
                                                                    self.pe_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.pe_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                            class SrPolicyExplicitPath(object):
                                                                """
                                                                SR Policy Explicit paths
                                                                
                                                                .. attribute:: sid
                                                                
                                                                	Sidlist for explicit path
                                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of explicit path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.sid = YList()
                                                                    self.sid.parent = self
                                                                    self.sid.name = 'sid'
                                                                    self.weight = None


                                                                class Sid(object):
                                                                    """
                                                                    Sidlist for explicit path
                                                                    
                                                                    .. attribute:: ipv4
                                                                    
                                                                    	IP Address sid
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6
                                                                    
                                                                    	IPv6 address sid
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label sid
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Sid Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4 = None
                                                                        self.ipv6 = None
                                                                        self.label = None
                                                                        self.type = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4 is not None:
                                                                            return True

                                                                        if self.ipv6 is not None:
                                                                            return True

                                                                        if self.label is not None:
                                                                            return True

                                                                        if self.type is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.sid is not None:
                                                                        for child_ref in self.sid:
                                                                            if child_ref._has_data():
                                                                                return True

                                                                    if self.weight is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.aggregator_address is not None:
                                                                    return True

                                                                if self.aggregator_as is not None:
                                                                    return True

                                                                if self.aigp_metric_value is not None:
                                                                    return True

                                                                if self.as_path is not None:
                                                                    return True

                                                                if self.cluster is not None:
                                                                    for child_ref in self.cluster:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.community is not None:
                                                                    for child_ref in self.community:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.connector_type is not None:
                                                                    return True

                                                                if self.connector_value is not None:
                                                                    for child_ref in self.connector_value:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.extended_community is not None:
                                                                    for child_ref in self.extended_community:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.extended_community_flags is not None:
                                                                    return True

                                                                if self.is_aggregator_present is not None:
                                                                    return True

                                                                if self.is_aigp_present is not None:
                                                                    return True

                                                                if self.is_as_path_present is not None:
                                                                    return True

                                                                if self.is_atomic_aggregate_present is not None:
                                                                    return True

                                                                if self.is_community_present is not None:
                                                                    return True

                                                                if self.is_connector_present is not None:
                                                                    return True

                                                                if self.is_extended_community_present is not None:
                                                                    return True

                                                                if self.is_label_index_present is not None:
                                                                    return True

                                                                if self.is_local_pref_present is not None:
                                                                    return True

                                                                if self.is_ls_attribute_present is not None:
                                                                    return True

                                                                if self.is_metric_present is not None:
                                                                    return True

                                                                if self.is_origin_present is not None:
                                                                    return True

                                                                if self.is_pe_distinguisher_label_present is not None:
                                                                    return True

                                                                if self.is_pmsi_present is not None:
                                                                    return True

                                                                if self.is_pppmp_present is not None:
                                                                    return True

                                                                if self.is_ssa_present is not None:
                                                                    return True

                                                                if self.is_tunnel_encap_present is not None:
                                                                    return True

                                                                if self.l2tpv3_cookie is not None:
                                                                    for child_ref in self.l2tpv3_cookie:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.l2tpv3_session_id is not None:
                                                                    return True

                                                                if self.label_index_attr is not None:
                                                                    for child_ref in self.label_index_attr:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.local_preference is not None:
                                                                    return True

                                                                if self.ls_attr is not None:
                                                                    for child_ref in self.ls_attr:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.metric is not None:
                                                                    return True

                                                                if self.neighbor_as is not None:
                                                                    return True

                                                                if self.origin is not None:
                                                                    return True

                                                                if self.originator is not None:
                                                                    return True

                                                                if self.pe_distinguisher_label is not None:
                                                                    for child_ref in self.pe_distinguisher_label:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.pmsi_flags is not None:
                                                                    return True

                                                                if self.pmsi_label is not None:
                                                                    return True

                                                                if self.pmsi_type is not None:
                                                                    return True

                                                                if self.pmsi_value is not None:
                                                                    for child_ref in self.pmsi_value:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.ppm_pvalue is not None:
                                                                    return True

                                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                                    return True

                                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                                    return True

                                                                if self.sr_policy_explicit_path is not None:
                                                                    for child_ref in self.sr_policy_explicit_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.sr_policy_preference is not None:
                                                                    return True

                                                                if self.sr_tunnel_request_state is not None:
                                                                    return True

                                                                if self.sr_tunnel_state is not None:
                                                                    return True

                                                                if self.tunnel_encap_type is not None:
                                                                    return True

                                                                if self.unknown_attribute is not None:
                                                                    for child_ref in self.unknown_attribute:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                                        class RnhAddr(object):
                                                            """
                                                            RNH Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                            
                                                            .. attribute:: mac_address
                                                            
                                                            	MAC Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self.len = None
                                                                self.mac_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.len is not None:
                                                                    return True

                                                                if self.mac_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                                        class RibrnhIp(object):
                                                            """
                                                            RIB RNH IP Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.attr_set is not None and self.attr_set._has_data():
                                                                return True

                                                            if self.attribute_key_number is not None:
                                                                return True

                                                            if self.attribute_reuse_id_config is not None:
                                                                return True

                                                            if self.attribute_reuse_id_current is not None:
                                                                return True

                                                            if self.attribute_reuse_id_keys is not None:
                                                                return True

                                                            if self.attribute_reuse_id_max_id is not None:
                                                                return True

                                                            if self.attribute_reuse_id_node is not None:
                                                                return True

                                                            if self.attribute_reuse_id_recover_sec is not None:
                                                                return True

                                                            if self.common_attributes is not None and self.common_attributes._has_data():
                                                                return True

                                                            if self.is_application_gateway_present is not None:
                                                                return True

                                                            if self.is_as_path2_byte is not None:
                                                                return True

                                                            if self.is_attr_set_present is not None:
                                                                return True

                                                            if self.is_ribrnh_present is not None:
                                                                return True

                                                            if self.is_rnh_present is not None:
                                                                return True

                                                            if self.ribrnh_encap is not None:
                                                                return True

                                                            if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                                return True

                                                            if self.ribrnh_mac is not None:
                                                                return True

                                                            if self.ribrnh_table is not None:
                                                                return True

                                                            if self.ribrnh_vni is not None:
                                                                return True

                                                            if self.ribrnhip_table is not None:
                                                                return True

                                                            if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                                return True

                                                            if self.rnh_addr_len is not None:
                                                                return True

                                                            if self.rnh_len is not None:
                                                                return True

                                                            if self.rnh_type is not None:
                                                                return True

                                                            if self.set_aigp_inbound_igp is not None:
                                                                return True

                                                            if self.set_aigp_inbound_metric is not None:
                                                                return True

                                                            if self.vpn_distinguisher is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-process-instance-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.af_name is not None:
                                                            return True

                                                        if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                            return True

                                                        if self.label_fail is not None:
                                                            return True

                                                        if self.label_o_or_version is not None:
                                                            return True

                                                        if self.label_oor is not None:
                                                            return True

                                                        if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                            return True

                                                        if self.no_path is not None:
                                                            return True

                                                        if self.path_information is not None and self.path_information._has_data():
                                                            return True

                                                        if self.prefix_version is not None:
                                                            return True

                                                        if self.process_instance_id is not None:
                                                            return True

                                                        if self.route_distinguisher is not None:
                                                            return True

                                                        if self.source_route_distinguisher is not None:
                                                            return True

                                                        if self.source_vrf_name is not None:
                                                            return True

                                                        if self.srcaf_name is not None:
                                                            return True

                                                        if self.vrf_name is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath']['meta_info']


                                                class LocalPathElement(object):
                                                    """
                                                    Local path element list
                                                    
                                                    .. attribute:: is_perm_path_pelem
                                                    
                                                    	Pelem for permanent path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: nhte_tunnel
                                                    
                                                    	NH TE tunnel information
                                                    	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.NhteTunnel>`
                                                    
                                                    .. attribute:: pelem_flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_gw_metric
                                                    
                                                    	Gateway metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_no_addpath_table_attr_version
                                                    
                                                    	No\-addpath Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_no_bestpath_table_attr_version
                                                    
                                                    	No\-bestpath Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_flags
                                                    
                                                    	Path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: pelem_path_id
                                                    
                                                    	Local Path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_neighbor_addr
                                                    
                                                    	Path neighbor address
                                                    	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr>`
                                                    
                                                    .. attribute:: pelem_path_nexthop
                                                    
                                                    	Path nexthop address
                                                    	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop>`
                                                    
                                                    .. attribute:: pelem_path_peer_path_id
                                                    
                                                    	Path peer path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_table_attr_version
                                                    
                                                    	Path Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_table_attr_version
                                                    
                                                    	Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_version
                                                    
                                                    	Version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_perm_path_pelem = None
                                                        self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.NhteTunnel()
                                                        self.nhte_tunnel.parent = self
                                                        self.pelem_flags = None
                                                        self.pelem_gw_metric = None
                                                        self.pelem_no_addpath_table_attr_version = None
                                                        self.pelem_no_bestpath_table_attr_version = None
                                                        self.pelem_path_flags = None
                                                        self.pelem_path_id = None
                                                        self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr()
                                                        self.pelem_path_neighbor_addr.parent = self
                                                        self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop()
                                                        self.pelem_path_nexthop.parent = self
                                                        self.pelem_path_peer_path_id = None
                                                        self.pelem_path_table_attr_version = None
                                                        self.pelem_table_attr_version = None
                                                        self.pelem_version = None


                                                    class PelemPathNexthop(object):
                                                        """
                                                        Path nexthop address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-nexthop'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop']['meta_info']


                                                    class NhteTunnel(object):
                                                        """
                                                        NH TE tunnel information
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	Binding label for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_te_tunnel
                                                        
                                                        	NH TE Tunnel info is present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_info_stale
                                                        
                                                        	Tunnel is stale
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_registered
                                                        
                                                        	Tunnel registered flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_up
                                                        
                                                        	Tunnel Up flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: last_tunnel_update
                                                        
                                                        	Time since the last rib update happened
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_if_handle
                                                        
                                                        	Interface handle for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_name
                                                        
                                                        	tunnel name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        .. attribute:: tunnel_type
                                                        
                                                        	tunnel type
                                                        	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                        
                                                        .. attribute:: tunnel_v6_enabled
                                                        
                                                        	IPv6 enabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_v6_required
                                                        
                                                        	Tunnel need IPv6
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.binding_label = None
                                                            self.has_te_tunnel = None
                                                            self.is_tunnel_info_stale = None
                                                            self.is_tunnel_registered = None
                                                            self.is_tunnel_up = None
                                                            self.last_tunnel_update = None
                                                            self.tunnel_if_handle = None
                                                            self.tunnel_name = None
                                                            self.tunnel_type = None
                                                            self.tunnel_v6_enabled = None
                                                            self.tunnel_v6_required = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.binding_label is not None:
                                                                return True

                                                            if self.has_te_tunnel is not None:
                                                                return True

                                                            if self.is_tunnel_info_stale is not None:
                                                                return True

                                                            if self.is_tunnel_registered is not None:
                                                                return True

                                                            if self.is_tunnel_up is not None:
                                                                return True

                                                            if self.last_tunnel_update is not None:
                                                                return True

                                                            if self.tunnel_if_handle is not None:
                                                                return True

                                                            if self.tunnel_name is not None:
                                                                return True

                                                            if self.tunnel_type is not None:
                                                                return True

                                                            if self.tunnel_v6_enabled is not None:
                                                                return True

                                                            if self.tunnel_v6_required is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.NhteTunnel']['meta_info']


                                                    class PelemPathNeighborAddr(object):
                                                        """
                                                        Path neighbor address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-neighbor-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-path-element'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_perm_path_pelem is not None:
                                                            return True

                                                        if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                            return True

                                                        if self.pelem_flags is not None:
                                                            return True

                                                        if self.pelem_gw_metric is not None:
                                                            return True

                                                        if self.pelem_no_addpath_table_attr_version is not None:
                                                            return True

                                                        if self.pelem_no_bestpath_table_attr_version is not None:
                                                            return True

                                                        if self.pelem_path_flags is not None:
                                                            return True

                                                        if self.pelem_path_id is not None:
                                                            return True

                                                        if self.pelem_path_neighbor_addr is not None and self.pelem_path_neighbor_addr._has_data():
                                                            return True

                                                        if self.pelem_path_nexthop is not None and self.pelem_path_nexthop._has_data():
                                                            return True

                                                        if self.pelem_path_peer_path_id is not None:
                                                            return True

                                                        if self.pelem_path_table_attr_version is not None:
                                                            return True

                                                        if self.pelem_table_attr_version is not None:
                                                            return True

                                                        if self.pelem_version is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement']['meta_info']


                                                class ActivePathElement(object):
                                                    """
                                                    Path element list received from Active inst
                                                    
                                                    .. attribute:: is_perm_path_pelem
                                                    
                                                    	Pelem for permanent path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: nhte_tunnel
                                                    
                                                    	NH TE tunnel information
                                                    	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.NhteTunnel>`
                                                    
                                                    .. attribute:: pelem_flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_gw_metric
                                                    
                                                    	Gateway metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_no_addpath_table_attr_version
                                                    
                                                    	No\-addpath Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_no_bestpath_table_attr_version
                                                    
                                                    	No\-bestpath Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_flags
                                                    
                                                    	Path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: pelem_path_id
                                                    
                                                    	Local Path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_neighbor_addr
                                                    
                                                    	Path neighbor address
                                                    	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr>`
                                                    
                                                    .. attribute:: pelem_path_nexthop
                                                    
                                                    	Path nexthop address
                                                    	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop>`
                                                    
                                                    .. attribute:: pelem_path_peer_path_id
                                                    
                                                    	Path peer path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_table_attr_version
                                                    
                                                    	Path Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_table_attr_version
                                                    
                                                    	Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_version
                                                    
                                                    	Version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_perm_path_pelem = None
                                                        self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.NhteTunnel()
                                                        self.nhte_tunnel.parent = self
                                                        self.pelem_flags = None
                                                        self.pelem_gw_metric = None
                                                        self.pelem_no_addpath_table_attr_version = None
                                                        self.pelem_no_bestpath_table_attr_version = None
                                                        self.pelem_path_flags = None
                                                        self.pelem_path_id = None
                                                        self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr()
                                                        self.pelem_path_neighbor_addr.parent = self
                                                        self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop()
                                                        self.pelem_path_nexthop.parent = self
                                                        self.pelem_path_peer_path_id = None
                                                        self.pelem_path_table_attr_version = None
                                                        self.pelem_table_attr_version = None
                                                        self.pelem_version = None


                                                    class PelemPathNexthop(object):
                                                        """
                                                        Path nexthop address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-nexthop'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop']['meta_info']


                                                    class NhteTunnel(object):
                                                        """
                                                        NH TE tunnel information
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	Binding label for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_te_tunnel
                                                        
                                                        	NH TE Tunnel info is present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_info_stale
                                                        
                                                        	Tunnel is stale
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_registered
                                                        
                                                        	Tunnel registered flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_up
                                                        
                                                        	Tunnel Up flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: last_tunnel_update
                                                        
                                                        	Time since the last rib update happened
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_if_handle
                                                        
                                                        	Interface handle for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_name
                                                        
                                                        	tunnel name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        .. attribute:: tunnel_type
                                                        
                                                        	tunnel type
                                                        	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                        
                                                        .. attribute:: tunnel_v6_enabled
                                                        
                                                        	IPv6 enabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_v6_required
                                                        
                                                        	Tunnel need IPv6
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.binding_label = None
                                                            self.has_te_tunnel = None
                                                            self.is_tunnel_info_stale = None
                                                            self.is_tunnel_registered = None
                                                            self.is_tunnel_up = None
                                                            self.last_tunnel_update = None
                                                            self.tunnel_if_handle = None
                                                            self.tunnel_name = None
                                                            self.tunnel_type = None
                                                            self.tunnel_v6_enabled = None
                                                            self.tunnel_v6_required = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.binding_label is not None:
                                                                return True

                                                            if self.has_te_tunnel is not None:
                                                                return True

                                                            if self.is_tunnel_info_stale is not None:
                                                                return True

                                                            if self.is_tunnel_registered is not None:
                                                                return True

                                                            if self.is_tunnel_up is not None:
                                                                return True

                                                            if self.last_tunnel_update is not None:
                                                                return True

                                                            if self.tunnel_if_handle is not None:
                                                                return True

                                                            if self.tunnel_name is not None:
                                                                return True

                                                            if self.tunnel_type is not None:
                                                                return True

                                                            if self.tunnel_v6_enabled is not None:
                                                                return True

                                                            if self.tunnel_v6_required is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.NhteTunnel']['meta_info']


                                                    class PelemPathNeighborAddr(object):
                                                        """
                                                        Path neighbor address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-neighbor-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-path-element'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_perm_path_pelem is not None:
                                                            return True

                                                        if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                            return True

                                                        if self.pelem_flags is not None:
                                                            return True

                                                        if self.pelem_gw_metric is not None:
                                                            return True

                                                        if self.pelem_no_addpath_table_attr_version is not None:
                                                            return True

                                                        if self.pelem_no_bestpath_table_attr_version is not None:
                                                            return True

                                                        if self.pelem_path_flags is not None:
                                                            return True

                                                        if self.pelem_path_id is not None:
                                                            return True

                                                        if self.pelem_path_neighbor_addr is not None and self.pelem_path_neighbor_addr._has_data():
                                                            return True

                                                        if self.pelem_path_nexthop is not None and self.pelem_path_nexthop._has_data():
                                                            return True

                                                        if self.pelem_path_peer_path_id is not None:
                                                            return True

                                                        if self.pelem_path_table_attr_version is not None:
                                                            return True

                                                        if self.pelem_table_attr_version is not None:
                                                            return True

                                                        if self.pelem_version is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                                    if self.rd is None:
                                                        raise YPYModelError('Key property rd is None')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-rd[Cisco-IOS-XR-ipv4-bgp-oper:rd = ' + str(self.rd) + ']'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.rd is not None:
                                                        return True

                                                    if self.active_path_element is not None:
                                                        for child_ref in self.active_path_element:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.active_process_instance_path is not None:
                                                        for child_ref in self.active_process_instance_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.add_path_orr_bitfield is not None:
                                                        for child_ref in self.add_path_orr_bitfield:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.advertisedto_pe is not None:
                                                        return True

                                                    if self.af_name is not None:
                                                        return True

                                                    if self.best_path_orr_bitfield is not None:
                                                        for child_ref in self.best_path_orr_bitfield:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                        return True

                                                    if self.bit is not None:
                                                        return True

                                                    if self.flags is not None:
                                                        return True

                                                    if self.gateway_array is not None:
                                                        return True

                                                    if self.has_inconsistent_paths is not None:
                                                        return True

                                                    if self.has_lbl_retained is not None:
                                                        return True

                                                    if self.has_local_label is not None:
                                                        return True

                                                    if self.is_net_aggregation_suppressed is not None:
                                                        return True

                                                    if self.is_net_ldp_signaled is not None:
                                                        return True

                                                    if self.is_permanent_network is not None:
                                                        return True

                                                    if self.local_path_element is not None:
                                                        for child_ref in self.local_path_element:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_peers_advertised_to is not None:
                                                        for child_ref in self.local_peers_advertised_to:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_process_instance_path is not None:
                                                        for child_ref in self.local_process_instance_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.net_backup_available is not None:
                                                        return True

                                                    if self.net_backup_label_rewrite_available is not None:
                                                        return True

                                                    if self.net_eibgp_multipath is not None:
                                                        return True

                                                    if self.net_extended_flags is not None:
                                                        return True

                                                    if self.net_flags is not None:
                                                        return True

                                                    if self.net_local_label is not None:
                                                        return True

                                                    if self.net_local_label_rewrite is not None:
                                                        return True

                                                    if self.net_local_label_srgb is not None:
                                                        return True

                                                    if self.net_multipath is not None:
                                                        return True

                                                    if self.num_of_path is not None:
                                                        return True

                                                    if self.pe_peers_advertised_to is not None:
                                                        for child_ref in self.pe_peers_advertised_to:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.process_instance_id is not None:
                                                        return True

                                                    if self.resilient_nexthop_set is not None:
                                                        return True

                                                    if self.rib_failed is not None:
                                                        return True

                                                    if self.route_distinguisher is not None:
                                                        return True

                                                    if self.table_brib_version is not None:
                                                        return True

                                                    if self.table_version is not None:
                                                        return True

                                                    if self.version is not None:
                                                        return True

                                                    if self.version_age is not None and self.version_age._has_data():
                                                        return True

                                                    if self.version_timestamp is not None and self.version_timestamp._has_data():
                                                        return True

                                                    if self.vrf_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-rds'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.network_rd is not None:
                                                    for child_ref in self.network_rd:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')
                                            if self.network_addr is None:
                                                raise YPYModelError('Key property network_addr is None')
                                            if self.network_prefix is None:
                                                raise YPYModelError('Key property network_prefix is None')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-all-rd[Cisco-IOS-XR-ipv4-bgp-oper:network-addr = ' + str(self.network_addr) + '][Cisco-IOS-XR-ipv4-bgp-oper:network-prefix = ' + str(self.network_prefix) + ']'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.network_addr is not None:
                                                return True

                                            if self.network_prefix is not None:
                                                return True

                                            if self.network_rds is not None and self.network_rds._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-all-rds'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.network_all_rd is not None:
                                            for child_ref in self.network_all_rd:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NetworkAllRds']['meta_info']


                                class UpdateGenerationNeighbors(object):
                                    """
                                    Update generation for all neighbors
                                    
                                    .. attribute:: update_generation_neighbor
                                    
                                    	Update generation for neighbor
                                    	**type**\: list of    :py:class:`UpdateGenerationNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.update_generation_neighbor = YList()
                                        self.update_generation_neighbor.parent = self
                                        self.update_generation_neighbor.name = 'update_generation_neighbor'


                                    class UpdateGenerationNeighbor(object):
                                        """
                                        Update generation for neighbor
                                        
                                        .. attribute:: ack_version
                                        
                                        	Ack version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: current_update_group_af_name
                                        
                                        	Current Update\-group address\-family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: default_originate_internal_context
                                        
                                        	Default\-origination context
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: default_originate_state
                                        
                                        	Default\-origination state
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: filter_group_index
                                        
                                        	Filter\-group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: first_default_originate_timestamp
                                        
                                        	First default\-origination time
                                        	**type**\:   :py:class:`FirstDefaultOriginateTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp>`
                                        
                                        .. attribute:: first_update_queued_timestamp
                                        
                                        	First update queued time
                                        	**type**\:   :py:class:`FirstUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp>`
                                        
                                        .. attribute:: first_update_write_timestamp
                                        
                                        	First update write time
                                        	**type**\:   :py:class:`FirstUpdateWriteTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp>`
                                        
                                        .. attribute:: inbound_refresh_count
                                        
                                        	Refresh Inbound count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_eor_outstanding
                                        
                                        	Number of EORs outstanding
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_update_group_timer_running
                                        
                                        	Is update\-group timer running
                                        	**type**\:  bool
                                        
                                        .. attribute:: last_default_originate_age
                                        
                                        	Time since last default\-origination event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_default_originate_timestamp
                                        
                                        	Last default\-origination time
                                        	**type**\:   :py:class:`LastDefaultOriginateTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp>`
                                        
                                        .. attribute:: last_filter_group_add_timestamp
                                        
                                        	Last added time
                                        	**type**\:   :py:class:`LastFilterGroupAddTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp>`
                                        
                                        .. attribute:: last_filter_group_remove_timestamp
                                        
                                        	Last removed time
                                        	**type**\:   :py:class:`LastFilterGroupRemoveTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp>`
                                        
                                        .. attribute:: last_refresh_update_queued_age
                                        
                                        	Time since last refresh update queued event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_refresh_update_queued_timestamp
                                        
                                        	Last refresh update queued time
                                        	**type**\:   :py:class:`LastRefreshUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp>`
                                        
                                        .. attribute:: last_refresh_update_write_age
                                        
                                        	Time since last refresh update write event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_refresh_update_write_timestamp
                                        
                                        	Last refresh update write time
                                        	**type**\:   :py:class:`LastRefreshUpdateWriteTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp>`
                                        
                                        .. attribute:: last_sub_group_add_timestamp
                                        
                                        	Last added time
                                        	**type**\:   :py:class:`LastSubGroupAddTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp>`
                                        
                                        .. attribute:: last_sub_group_remove_timestamp
                                        
                                        	Last removed time
                                        	**type**\:   :py:class:`LastSubGroupRemoveTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp>`
                                        
                                        .. attribute:: last_update_group_af_name
                                        
                                        	Last Update\-group address\-family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: last_update_group_expiry_timestamp
                                        
                                        	Last update\-group timer expiry
                                        	**type**\:   :py:class:`LastUpdateGroupExpiryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp>`
                                        
                                        .. attribute:: last_update_group_start_timestamp
                                        
                                        	Last update\-group timer start
                                        	**type**\:   :py:class:`LastUpdateGroupStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp>`
                                        
                                        .. attribute:: last_update_queued_age
                                        
                                        	Time since last update queued event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_queued_timestamp
                                        
                                        	Last update queued time
                                        	**type**\:   :py:class:`LastUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp>`
                                        
                                        .. attribute:: last_update_write_age
                                        
                                        	Time since last update write event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_write_timestamp
                                        
                                        	Last update write time
                                        	**type**\:   :py:class:`LastUpdateWriteTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp>`
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: next_resume_version
                                        
                                        	Resume version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: outbound_refresh_count
                                        
                                        	Refresh Outbound count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: outstanding_version_count
                                        
                                        	Outstanding version count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pending_target_version
                                        
                                        	Pending target version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_id
                                        
                                        	ProcessID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_ack_version
                                        
                                        	Refresh Ack version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_filter_group_index
                                        
                                        	Refresh Filter\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_next_resume_version
                                        
                                        	Refresh resume version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_pending_target_version
                                        
                                        	Pending refresh target version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_requested_target_version
                                        
                                        	Requested refresh target version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_sub_group_id
                                        
                                        	Refresh sub\-group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_sub_group_index
                                        
                                        	Refresh Sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_update_out_queue_messages
                                        
                                        	Refresh OutQueue messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_update_out_queue_size
                                        
                                        	Refresh OutQueue size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_id
                                        
                                        	Sub\-group ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: sub_group_index
                                        
                                        	Sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: sub_group_index_xr
                                        
                                        	Sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: synced_ack_version
                                        
                                        	Synced ack version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_filter_group_index
                                        
                                        	Filter\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_filter_group_messages
                                        
                                        	Filter\-group messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_group_af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: update_group_index
                                        
                                        	Update\-group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: update_group_index_xr
                                        
                                        	Update\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_main_table_version
                                        
                                        	Main table version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:   :py:class:`UpdateNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress>`
                                        
                                        .. attribute:: update_out_queue_messages
                                        
                                        	OutQueue messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size
                                        
                                        	OutQueue size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_refresh_target_version
                                        
                                        	Refresh target version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_refresh_version
                                        
                                        	Refresh version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_statistics
                                        
                                        	Update statistics
                                        	**type**\:   :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics>`
                                        
                                        .. attribute:: update_vrf_name
                                        
                                        	VRF Name
                                        	**type**\:  str
                                        
                                        .. attribute:: update_vrf_table_rib_version
                                        
                                        	VRF Table RIB version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version
                                        
                                        	Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ack_version = None
                                            self.current_update_group_af_name = None
                                            self.default_originate_internal_context = None
                                            self.default_originate_state = None
                                            self.filter_group_index = None
                                            self.first_default_originate_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp()
                                            self.first_default_originate_timestamp.parent = self
                                            self.first_update_queued_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp()
                                            self.first_update_queued_timestamp.parent = self
                                            self.first_update_write_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp()
                                            self.first_update_write_timestamp.parent = self
                                            self.inbound_refresh_count = None
                                            self.is_eor_outstanding = None
                                            self.is_update_group_timer_running = None
                                            self.last_default_originate_age = None
                                            self.last_default_originate_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp()
                                            self.last_default_originate_timestamp.parent = self
                                            self.last_filter_group_add_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp()
                                            self.last_filter_group_add_timestamp.parent = self
                                            self.last_filter_group_remove_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp()
                                            self.last_filter_group_remove_timestamp.parent = self
                                            self.last_refresh_update_queued_age = None
                                            self.last_refresh_update_queued_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp()
                                            self.last_refresh_update_queued_timestamp.parent = self
                                            self.last_refresh_update_write_age = None
                                            self.last_refresh_update_write_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp()
                                            self.last_refresh_update_write_timestamp.parent = self
                                            self.last_sub_group_add_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp()
                                            self.last_sub_group_add_timestamp.parent = self
                                            self.last_sub_group_remove_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp()
                                            self.last_sub_group_remove_timestamp.parent = self
                                            self.last_update_group_af_name = None
                                            self.last_update_group_expiry_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp()
                                            self.last_update_group_expiry_timestamp.parent = self
                                            self.last_update_group_start_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp()
                                            self.last_update_group_start_timestamp.parent = self
                                            self.last_update_queued_age = None
                                            self.last_update_queued_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp()
                                            self.last_update_queued_timestamp.parent = self
                                            self.last_update_write_age = None
                                            self.last_update_write_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp()
                                            self.last_update_write_timestamp.parent = self
                                            self.neighbor_address = None
                                            self.next_resume_version = None
                                            self.outbound_refresh_count = None
                                            self.outstanding_version_count = None
                                            self.pending_target_version = None
                                            self.process_id = None
                                            self.refresh_ack_version = None
                                            self.refresh_filter_group_index = None
                                            self.refresh_next_resume_version = None
                                            self.refresh_pending_target_version = None
                                            self.refresh_requested_target_version = None
                                            self.refresh_sub_group_id = None
                                            self.refresh_sub_group_index = None
                                            self.refresh_update_out_queue_messages = None
                                            self.refresh_update_out_queue_size = None
                                            self.sub_group_id = None
                                            self.sub_group_index = None
                                            self.sub_group_index_xr = None
                                            self.synced_ack_version = None
                                            self.update_filter_group_index = None
                                            self.update_filter_group_messages = None
                                            self.update_group_af_name = None
                                            self.update_group_index = None
                                            self.update_group_index_xr = None
                                            self.update_main_table_version = None
                                            self.update_neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress()
                                            self.update_neighbor_address.parent = self
                                            self.update_out_queue_messages = None
                                            self.update_out_queue_size = None
                                            self.update_refresh_target_version = None
                                            self.update_refresh_version = None
                                            self.update_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics()
                                            self.update_statistics.parent = self
                                            self.update_vrf_name = None
                                            self.update_vrf_table_rib_version = None
                                            self.version = None


                                        class UpdateNeighborAddress(object):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress']['meta_info']


                                        class LastSubGroupAddTimestamp(object):
                                            """
                                            Last added time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-sub-group-add-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp']['meta_info']


                                        class LastSubGroupRemoveTimestamp(object):
                                            """
                                            Last removed time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-sub-group-remove-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp']['meta_info']


                                        class LastFilterGroupAddTimestamp(object):
                                            """
                                            Last added time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-filter-group-add-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp']['meta_info']


                                        class LastFilterGroupRemoveTimestamp(object):
                                            """
                                            Last removed time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-filter-group-remove-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp']['meta_info']


                                        class FirstDefaultOriginateTimestamp(object):
                                            """
                                            First default\-origination time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-default-originate-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp']['meta_info']


                                        class LastDefaultOriginateTimestamp(object):
                                            """
                                            Last default\-origination time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-default-originate-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp']['meta_info']


                                        class LastUpdateGroupStartTimestamp(object):
                                            """
                                            Last update\-group timer start
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-group-start-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp']['meta_info']


                                        class LastUpdateGroupExpiryTimestamp(object):
                                            """
                                            Last update\-group timer expiry
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-group-expiry-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp']['meta_info']


                                        class FirstUpdateQueuedTimestamp(object):
                                            """
                                            First update queued time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-update-queued-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp']['meta_info']


                                        class LastUpdateQueuedTimestamp(object):
                                            """
                                            Last update queued time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-queued-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp']['meta_info']


                                        class LastRefreshUpdateQueuedTimestamp(object):
                                            """
                                            Last refresh update queued time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-refresh-update-queued-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp']['meta_info']


                                        class FirstUpdateWriteTimestamp(object):
                                            """
                                            First update write time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-update-write-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp']['meta_info']


                                        class LastUpdateWriteTimestamp(object):
                                            """
                                            Last update write time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-write-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp']['meta_info']


                                        class LastRefreshUpdateWriteTimestamp(object):
                                            """
                                            Last refresh update write time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-refresh-update-write-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp']['meta_info']


                                        class UpdateStatistics(object):
                                            """
                                            Update statistics
                                            
                                            .. attribute:: last_update_cleard_age
                                            
                                            	Time since last Clear event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_cleared_timestamp
                                            
                                            	Last Cleared time
                                            	**type**\:   :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp>`
                                            
                                            .. attribute:: last_update_discard_age
                                            
                                            	Time since last Discard event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_discard_timestamp
                                            
                                            	Last Discarded time
                                            	**type**\:   :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                            
                                            .. attribute:: last_update_memory_allocation_fail_age
                                            
                                            	Time since last memory allocation failure event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_memory_allocation_fail_timestamp
                                            
                                            	Memory allocation failure time
                                            	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                            
                                            .. attribute:: last_update_recovery_age
                                            
                                            	Time since last Recovery event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_recovery_timestamp
                                            
                                            	Last Recovery time
                                            	**type**\:   :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                            
                                            .. attribute:: last_update_throttle_age
                                            
                                            	Time since last Throttle event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_throttle_timestamp
                                            
                                            	Last Throttled time
                                            	**type**\:   :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                            
                                            .. attribute:: update_memory_allocation_fail_count
                                            
                                            	Memory allocation failure count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_cleared
                                            
                                            	OutQueue Cleared Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_cumulative
                                            
                                            	OutQueue Cumulative Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_discarded
                                            
                                            	OutQueue Discarded Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_high
                                            
                                            	OutQueue High Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_size_cleared
                                            
                                            	OutQueue Cleared Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_cumulative
                                            
                                            	OutQueue Cumulative Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_discarded
                                            
                                            	OutQueue Discarded Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_high
                                            
                                            	OutQueue Hi Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_recovery_count
                                            
                                            	Recovery Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_throttle_count
                                            
                                            	Throttle Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.last_update_cleard_age = None
                                                self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp()
                                                self.last_update_cleared_timestamp.parent = self
                                                self.last_update_discard_age = None
                                                self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp()
                                                self.last_update_discard_timestamp.parent = self
                                                self.last_update_memory_allocation_fail_age = None
                                                self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                                self.last_update_memory_allocation_fail_timestamp.parent = self
                                                self.last_update_recovery_age = None
                                                self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                                self.last_update_recovery_timestamp.parent = self
                                                self.last_update_throttle_age = None
                                                self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp()
                                                self.last_update_throttle_timestamp.parent = self
                                                self.update_memory_allocation_fail_count = None
                                                self.update_out_queue_messages_cleared = None
                                                self.update_out_queue_messages_cumulative = None
                                                self.update_out_queue_messages_discarded = None
                                                self.update_out_queue_messages_high = None
                                                self.update_out_queue_size_cleared = None
                                                self.update_out_queue_size_cumulative = None
                                                self.update_out_queue_size_discarded = None
                                                self.update_out_queue_size_high = None
                                                self.update_recovery_count = None
                                                self.update_throttle_count = None


                                            class LastUpdateDiscardTimestamp(object):
                                                """
                                                Last Discarded time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-discard-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp']['meta_info']


                                            class LastUpdateClearedTimestamp(object):
                                                """
                                                Last Cleared time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-cleared-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp']['meta_info']


                                            class LastUpdateThrottleTimestamp(object):
                                                """
                                                Last Throttled time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-throttle-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp']['meta_info']


                                            class LastUpdateRecoveryTimestamp(object):
                                                """
                                                Last Recovery time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-recovery-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp']['meta_info']


                                            class LastUpdateMemoryAllocationFailTimestamp(object):
                                                """
                                                Memory allocation failure time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-memory-allocation-fail-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-statistics'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.last_update_cleard_age is not None:
                                                    return True

                                                if self.last_update_cleared_timestamp is not None and self.last_update_cleared_timestamp._has_data():
                                                    return True

                                                if self.last_update_discard_age is not None:
                                                    return True

                                                if self.last_update_discard_timestamp is not None and self.last_update_discard_timestamp._has_data():
                                                    return True

                                                if self.last_update_memory_allocation_fail_age is not None:
                                                    return True

                                                if self.last_update_memory_allocation_fail_timestamp is not None and self.last_update_memory_allocation_fail_timestamp._has_data():
                                                    return True

                                                if self.last_update_recovery_age is not None:
                                                    return True

                                                if self.last_update_recovery_timestamp is not None and self.last_update_recovery_timestamp._has_data():
                                                    return True

                                                if self.last_update_throttle_age is not None:
                                                    return True

                                                if self.last_update_throttle_timestamp is not None and self.last_update_throttle_timestamp._has_data():
                                                    return True

                                                if self.update_memory_allocation_fail_count is not None:
                                                    return True

                                                if self.update_out_queue_messages_cleared is not None:
                                                    return True

                                                if self.update_out_queue_messages_cumulative is not None:
                                                    return True

                                                if self.update_out_queue_messages_discarded is not None:
                                                    return True

                                                if self.update_out_queue_messages_high is not None:
                                                    return True

                                                if self.update_out_queue_size_cleared is not None:
                                                    return True

                                                if self.update_out_queue_size_cumulative is not None:
                                                    return True

                                                if self.update_out_queue_size_discarded is not None:
                                                    return True

                                                if self.update_out_queue_size_high is not None:
                                                    return True

                                                if self.update_recovery_count is not None:
                                                    return True

                                                if self.update_throttle_count is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-neighbor'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ack_version is not None:
                                                return True

                                            if self.current_update_group_af_name is not None:
                                                return True

                                            if self.default_originate_internal_context is not None:
                                                return True

                                            if self.default_originate_state is not None:
                                                return True

                                            if self.filter_group_index is not None:
                                                return True

                                            if self.first_default_originate_timestamp is not None and self.first_default_originate_timestamp._has_data():
                                                return True

                                            if self.first_update_queued_timestamp is not None and self.first_update_queued_timestamp._has_data():
                                                return True

                                            if self.first_update_write_timestamp is not None and self.first_update_write_timestamp._has_data():
                                                return True

                                            if self.inbound_refresh_count is not None:
                                                return True

                                            if self.is_eor_outstanding is not None:
                                                return True

                                            if self.is_update_group_timer_running is not None:
                                                return True

                                            if self.last_default_originate_age is not None:
                                                return True

                                            if self.last_default_originate_timestamp is not None and self.last_default_originate_timestamp._has_data():
                                                return True

                                            if self.last_filter_group_add_timestamp is not None and self.last_filter_group_add_timestamp._has_data():
                                                return True

                                            if self.last_filter_group_remove_timestamp is not None and self.last_filter_group_remove_timestamp._has_data():
                                                return True

                                            if self.last_refresh_update_queued_age is not None:
                                                return True

                                            if self.last_refresh_update_queued_timestamp is not None and self.last_refresh_update_queued_timestamp._has_data():
                                                return True

                                            if self.last_refresh_update_write_age is not None:
                                                return True

                                            if self.last_refresh_update_write_timestamp is not None and self.last_refresh_update_write_timestamp._has_data():
                                                return True

                                            if self.last_sub_group_add_timestamp is not None and self.last_sub_group_add_timestamp._has_data():
                                                return True

                                            if self.last_sub_group_remove_timestamp is not None and self.last_sub_group_remove_timestamp._has_data():
                                                return True

                                            if self.last_update_group_af_name is not None:
                                                return True

                                            if self.last_update_group_expiry_timestamp is not None and self.last_update_group_expiry_timestamp._has_data():
                                                return True

                                            if self.last_update_group_start_timestamp is not None and self.last_update_group_start_timestamp._has_data():
                                                return True

                                            if self.last_update_queued_age is not None:
                                                return True

                                            if self.last_update_queued_timestamp is not None and self.last_update_queued_timestamp._has_data():
                                                return True

                                            if self.last_update_write_age is not None:
                                                return True

                                            if self.last_update_write_timestamp is not None and self.last_update_write_timestamp._has_data():
                                                return True

                                            if self.neighbor_address is not None:
                                                return True

                                            if self.next_resume_version is not None:
                                                return True

                                            if self.outbound_refresh_count is not None:
                                                return True

                                            if self.outstanding_version_count is not None:
                                                return True

                                            if self.pending_target_version is not None:
                                                return True

                                            if self.process_id is not None:
                                                return True

                                            if self.refresh_ack_version is not None:
                                                return True

                                            if self.refresh_filter_group_index is not None:
                                                return True

                                            if self.refresh_next_resume_version is not None:
                                                return True

                                            if self.refresh_pending_target_version is not None:
                                                return True

                                            if self.refresh_requested_target_version is not None:
                                                return True

                                            if self.refresh_sub_group_id is not None:
                                                return True

                                            if self.refresh_sub_group_index is not None:
                                                return True

                                            if self.refresh_update_out_queue_messages is not None:
                                                return True

                                            if self.refresh_update_out_queue_size is not None:
                                                return True

                                            if self.sub_group_id is not None:
                                                return True

                                            if self.sub_group_index is not None:
                                                return True

                                            if self.sub_group_index_xr is not None:
                                                return True

                                            if self.synced_ack_version is not None:
                                                return True

                                            if self.update_filter_group_index is not None:
                                                return True

                                            if self.update_filter_group_messages is not None:
                                                return True

                                            if self.update_group_af_name is not None:
                                                return True

                                            if self.update_group_index is not None:
                                                return True

                                            if self.update_group_index_xr is not None:
                                                return True

                                            if self.update_main_table_version is not None:
                                                return True

                                            if self.update_neighbor_address is not None and self.update_neighbor_address._has_data():
                                                return True

                                            if self.update_out_queue_messages is not None:
                                                return True

                                            if self.update_out_queue_size is not None:
                                                return True

                                            if self.update_refresh_target_version is not None:
                                                return True

                                            if self.update_refresh_version is not None:
                                                return True

                                            if self.update_statistics is not None and self.update_statistics._has_data():
                                                return True

                                            if self.update_vrf_name is not None:
                                                return True

                                            if self.update_vrf_table_rib_version is not None:
                                                return True

                                            if self.version is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-neighbors'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.update_generation_neighbor is not None:
                                            for child_ref in self.update_generation_neighbor:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors']['meta_info']


                                class UpdateGenerationAddressFamily(object):
                                    """
                                    Update generation for address\-family
                                    
                                    .. attribute:: configured_update_limit_af
                                    
                                    	Configured AF update limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: configured_update_limit_sub_group_ibgp
                                    
                                    	Configured IBGP sub\-group update limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: configured_update_limit_subgrp_ebgp
                                    
                                    	Configured EBGP sub\-group update limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: current_update_limit_af
                                    
                                    	Current AF update limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: current_update_limit_sub_group_ibgp
                                    
                                    	Current IBGP sub\-group update limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: current_update_limit_subgrp_ebgp
                                    
                                    	Current EBGP sub\-group update limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: filter_group_count
                                    
                                    	Filter\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_count
                                    
                                    	Neighbor count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_count
                                    
                                    	Refresh sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_throttled_count
                                    
                                    	Throttled refresh sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_throttled_count
                                    
                                    	Throttled sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_neighbor_count
                                    
                                    	VRF Table neighbor count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_refresh_sub_group_count
                                    
                                    	VRF Table refresh sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_refresh_sub_group_throttled_count
                                    
                                    	VRF Table throttled refresh sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_sub_group_throttled_count
                                    
                                    	VRF Table throttled sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_update_group_count
                                    
                                    	VRF Table update\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_group_af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: update_main_table_version
                                    
                                    	Main table version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_min_neighbor_version
                                    
                                    	Minimum Neighbor version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages
                                    
                                    	OutQueue messsages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_size
                                    
                                    	OutQueue size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_rib_version
                                    
                                    	RIB version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_statistics
                                    
                                    	Upate statistics
                                    	**type**\:   :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics>`
                                    
                                    .. attribute:: update_sub_group_count
                                    
                                    	Sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_table_filter_group_count
                                    
                                    	VRF Table filter\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_table_sub_group_count
                                    
                                    	VRF Table sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_table_vrf_name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    .. attribute:: update_throttled
                                    
                                    	Is Update throttled
                                    	**type**\:  bool
                                    
                                    .. attribute:: update_update_group_count
                                    
                                    	Update\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_vrf_rd_version
                                    
                                    	RD Version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_vrf_table_rib_version
                                    
                                    	VRF Table RIB version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_vrfaf_name
                                    
                                    	Address family identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.configured_update_limit_af = None
                                        self.configured_update_limit_sub_group_ibgp = None
                                        self.configured_update_limit_subgrp_ebgp = None
                                        self.current_update_limit_af = None
                                        self.current_update_limit_sub_group_ibgp = None
                                        self.current_update_limit_subgrp_ebgp = None
                                        self.filter_group_count = None
                                        self.neighbor_count = None
                                        self.refresh_sub_group_count = None
                                        self.refresh_sub_group_throttled_count = None
                                        self.sub_group_throttled_count = None
                                        self.table_neighbor_count = None
                                        self.table_refresh_sub_group_count = None
                                        self.table_refresh_sub_group_throttled_count = None
                                        self.table_sub_group_throttled_count = None
                                        self.table_update_group_count = None
                                        self.update_group_af_name = None
                                        self.update_main_table_version = None
                                        self.update_min_neighbor_version = None
                                        self.update_out_queue_messages = None
                                        self.update_out_queue_size = None
                                        self.update_rib_version = None
                                        self.update_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics()
                                        self.update_statistics.parent = self
                                        self.update_sub_group_count = None
                                        self.update_table_filter_group_count = None
                                        self.update_table_sub_group_count = None
                                        self.update_table_vrf_name = None
                                        self.update_throttled = None
                                        self.update_update_group_count = None
                                        self.update_vrf_rd_version = None
                                        self.update_vrf_table_rib_version = None
                                        self.update_vrfaf_name = None


                                    class UpdateStatistics(object):
                                        """
                                        Upate statistics
                                        
                                        .. attribute:: last_update_cleard_age
                                        
                                        	Time since last Clear event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_cleared_timestamp
                                        
                                        	Last Cleared time
                                        	**type**\:   :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp>`
                                        
                                        .. attribute:: last_update_discard_age
                                        
                                        	Time since last Discard event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_discard_timestamp
                                        
                                        	Last Discarded time
                                        	**type**\:   :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                        
                                        .. attribute:: last_update_memory_allocation_fail_age
                                        
                                        	Time since last memory allocation failure event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_memory_allocation_fail_timestamp
                                        
                                        	Memory allocation failure time
                                        	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                        
                                        .. attribute:: last_update_recovery_age
                                        
                                        	Time since last Recovery event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_recovery_timestamp
                                        
                                        	Last Recovery time
                                        	**type**\:   :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                        
                                        .. attribute:: last_update_throttle_age
                                        
                                        	Time since last Throttle event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_throttle_timestamp
                                        
                                        	Last Throttled time
                                        	**type**\:   :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                        
                                        .. attribute:: update_memory_allocation_fail_count
                                        
                                        	Memory allocation failure count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cleared
                                        
                                        	OutQueue Cleared Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cumulative
                                        
                                        	OutQueue Cumulative Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_discarded
                                        
                                        	OutQueue Discarded Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_high
                                        
                                        	OutQueue High Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size_cleared
                                        
                                        	OutQueue Cleared Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_cumulative
                                        
                                        	OutQueue Cumulative Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_discarded
                                        
                                        	OutQueue Discarded Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_high
                                        
                                        	OutQueue Hi Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_recovery_count
                                        
                                        	Recovery Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_throttle_count
                                        
                                        	Throttle Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.last_update_cleard_age = None
                                            self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp()
                                            self.last_update_cleared_timestamp.parent = self
                                            self.last_update_discard_age = None
                                            self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp()
                                            self.last_update_discard_timestamp.parent = self
                                            self.last_update_memory_allocation_fail_age = None
                                            self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                            self.last_update_memory_allocation_fail_timestamp.parent = self
                                            self.last_update_recovery_age = None
                                            self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                            self.last_update_recovery_timestamp.parent = self
                                            self.last_update_throttle_age = None
                                            self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp()
                                            self.last_update_throttle_timestamp.parent = self
                                            self.update_memory_allocation_fail_count = None
                                            self.update_out_queue_messages_cleared = None
                                            self.update_out_queue_messages_cumulative = None
                                            self.update_out_queue_messages_discarded = None
                                            self.update_out_queue_messages_high = None
                                            self.update_out_queue_size_cleared = None
                                            self.update_out_queue_size_cumulative = None
                                            self.update_out_queue_size_discarded = None
                                            self.update_out_queue_size_high = None
                                            self.update_recovery_count = None
                                            self.update_throttle_count = None


                                        class LastUpdateDiscardTimestamp(object):
                                            """
                                            Last Discarded time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-discard-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp']['meta_info']


                                        class LastUpdateClearedTimestamp(object):
                                            """
                                            Last Cleared time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-cleared-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp']['meta_info']


                                        class LastUpdateThrottleTimestamp(object):
                                            """
                                            Last Throttled time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-throttle-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp']['meta_info']


                                        class LastUpdateRecoveryTimestamp(object):
                                            """
                                            Last Recovery time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-recovery-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp']['meta_info']


                                        class LastUpdateMemoryAllocationFailTimestamp(object):
                                            """
                                            Memory allocation failure time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-memory-allocation-fail-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-statistics'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.last_update_cleard_age is not None:
                                                return True

                                            if self.last_update_cleared_timestamp is not None and self.last_update_cleared_timestamp._has_data():
                                                return True

                                            if self.last_update_discard_age is not None:
                                                return True

                                            if self.last_update_discard_timestamp is not None and self.last_update_discard_timestamp._has_data():
                                                return True

                                            if self.last_update_memory_allocation_fail_age is not None:
                                                return True

                                            if self.last_update_memory_allocation_fail_timestamp is not None and self.last_update_memory_allocation_fail_timestamp._has_data():
                                                return True

                                            if self.last_update_recovery_age is not None:
                                                return True

                                            if self.last_update_recovery_timestamp is not None and self.last_update_recovery_timestamp._has_data():
                                                return True

                                            if self.last_update_throttle_age is not None:
                                                return True

                                            if self.last_update_throttle_timestamp is not None and self.last_update_throttle_timestamp._has_data():
                                                return True

                                            if self.update_memory_allocation_fail_count is not None:
                                                return True

                                            if self.update_out_queue_messages_cleared is not None:
                                                return True

                                            if self.update_out_queue_messages_cumulative is not None:
                                                return True

                                            if self.update_out_queue_messages_discarded is not None:
                                                return True

                                            if self.update_out_queue_messages_high is not None:
                                                return True

                                            if self.update_out_queue_size_cleared is not None:
                                                return True

                                            if self.update_out_queue_size_cumulative is not None:
                                                return True

                                            if self.update_out_queue_size_discarded is not None:
                                                return True

                                            if self.update_out_queue_size_high is not None:
                                                return True

                                            if self.update_recovery_count is not None:
                                                return True

                                            if self.update_throttle_count is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-address-family'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.configured_update_limit_af is not None:
                                            return True

                                        if self.configured_update_limit_sub_group_ibgp is not None:
                                            return True

                                        if self.configured_update_limit_subgrp_ebgp is not None:
                                            return True

                                        if self.current_update_limit_af is not None:
                                            return True

                                        if self.current_update_limit_sub_group_ibgp is not None:
                                            return True

                                        if self.current_update_limit_subgrp_ebgp is not None:
                                            return True

                                        if self.filter_group_count is not None:
                                            return True

                                        if self.neighbor_count is not None:
                                            return True

                                        if self.refresh_sub_group_count is not None:
                                            return True

                                        if self.refresh_sub_group_throttled_count is not None:
                                            return True

                                        if self.sub_group_throttled_count is not None:
                                            return True

                                        if self.table_neighbor_count is not None:
                                            return True

                                        if self.table_refresh_sub_group_count is not None:
                                            return True

                                        if self.table_refresh_sub_group_throttled_count is not None:
                                            return True

                                        if self.table_sub_group_throttled_count is not None:
                                            return True

                                        if self.table_update_group_count is not None:
                                            return True

                                        if self.update_group_af_name is not None:
                                            return True

                                        if self.update_main_table_version is not None:
                                            return True

                                        if self.update_min_neighbor_version is not None:
                                            return True

                                        if self.update_out_queue_messages is not None:
                                            return True

                                        if self.update_out_queue_size is not None:
                                            return True

                                        if self.update_rib_version is not None:
                                            return True

                                        if self.update_statistics is not None and self.update_statistics._has_data():
                                            return True

                                        if self.update_sub_group_count is not None:
                                            return True

                                        if self.update_table_filter_group_count is not None:
                                            return True

                                        if self.update_table_sub_group_count is not None:
                                            return True

                                        if self.update_table_vrf_name is not None:
                                            return True

                                        if self.update_throttled is not None:
                                            return True

                                        if self.update_update_group_count is not None:
                                            return True

                                        if self.update_vrf_rd_version is not None:
                                            return True

                                        if self.update_vrf_table_rib_version is not None:
                                            return True

                                        if self.update_vrfaf_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily']['meta_info']


                                class Dampenings(object):
                                    """
                                    The BGP Dampening table
                                    
                                    .. attribute:: dampening
                                    
                                    	A BGP Dampening table entry
                                    	**type**\: list of    :py:class:`Dampening <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.dampening = YList()
                                        self.dampening.parent = self
                                        self.dampening.name = 'dampening'


                                    class Dampening(object):
                                        """
                                        A BGP Dampening table entry
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr>`
                                        
                                        .. attribute:: network
                                        
                                        	Network in prefix/length format
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        
                                        ----
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_id
                                        
                                        	Received Path ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation>`
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: reuse
                                        
                                        	Reuse array index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_rd
                                        
                                        	Source Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: version
                                        
                                        	Version number
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self.label_fail = None
                                            self.label_o_or_version = None
                                            self.label_oor = None
                                            self.neighbor_address = None
                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self.network = None
                                            self.no_path = None
                                            self.path_id = None
                                            self.path_information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation()
                                            self.path_information.parent = self
                                            self.prefix_version = None
                                            self.process_instance_id = None
                                            self.rd = None
                                            self.reuse = None
                                            self.route_distinguisher = None
                                            self.source_rd = None
                                            self.source_route_distinguisher = None
                                            self.source_vrf_name = None
                                            self.srcaf_name = None
                                            self.version = None
                                            self.vrf_name = None


                                        class NeighborAddressXr(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr']['meta_info']


                                        class PathInformation(object):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_esi
                                            
                                            	Path has EVPN ESI
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_rcvd_label
                                            
                                            	Path has received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebg_ps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.L2VpnEvpnEsi>`
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop>`
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhteTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_p_ath = None
                                                self.add_path_orr_bitfield = YList()
                                                self.add_path_orr_bitfield.parent = self
                                                self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                self.advertisedto_pe = None
                                                self.aigp_metric = None
                                                self.best_path_comp_stage = None
                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self.best_path_id = None
                                                self.best_path_id_comp_winner = None
                                                self.best_path_orr_bitfield = YList()
                                                self.best_path_orr_bitfield.parent = self
                                                self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self.dampen_penalty = None
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.fspec_invalid_path = None
                                                self.graceful_shutdown = None
                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self.halflife_time = None
                                                self.has_esi = None
                                                self.has_gw_addr = None
                                                self.has_local_net_label = None
                                                self.has_mdt_group_addr = None
                                                self.has_mvpn_extcomm = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.has_rcvd_label = None
                                                self.has_second_label = None
                                                self.ibgp_signaled_validity = None
                                                self.igp_metric = None
                                                self.is_aggregation_suppressed = None
                                                self.is_as_best = None
                                                self.is_best_path = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_internal_path = None
                                                self.is_partial_best = None
                                                self.is_path_additional_path = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_af_install_eligible = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_damped = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_history_held = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_imported = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_multipath = None
                                                self.is_path_nexthop_discarded = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebg_ps = None
                                                self.is_path_received_only = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_stale = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_valid = None
                                                self.is_path_vpn_only = None
                                                self.is_permanent_path = None
                                                self.is_received_path_not_modified = None
                                                self.is_spkr_as_best = None
                                                self.l2vpn_circuit_status_value = YList()
                                                self.l2vpn_circuit_status_value.parent = self
                                                self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.L2VpnEvpnEsi()
                                                self.l2vpn_evpn_esi.parent = self
                                                self.l2vpn_size = None
                                                self.labeled_unicast_safi_path = None
                                                self.local_label = None
                                                self.local_nh = None
                                                self.local_path_id = None
                                                self.local_peers_advertised_to = YList()
                                                self.local_peers_advertised_to.parent = self
                                                self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                self.maximum_suppress_time = None
                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self.mvpn_path_flags = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_value = YList()
                                                self.mvpn_pmsi_value.parent = self
                                                self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                self.mvpn_sfs_path = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.neighbor_router_id = None
                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.path_flags = None
                                                self.path_flap_count = None
                                                self.path_import_flags = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.path_table_version = None
                                                self.path_weight = None
                                                self.pe_peers_advertised_to = YList()
                                                self.pe_peers_advertised_to.parent = self
                                                self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                self.rcvd_label = None
                                                self.rcvd_path_id = None
                                                self.reuse_value = None
                                                self.rib_failed = None
                                                self.route_type = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.rt_set_limit_enabled = None
                                                self.second_label = None
                                                self.seconds_since_first_flap = None
                                                self.show_rpki_origin_as_validity = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.suppress_penalty = None
                                                self.time_to_unsuppress = None


                                            class BgpPrefix(object):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self.prefix_length = None


                                                class Prefix(object):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.prefix is not None and self.prefix._has_data():
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix']['meta_info']


                                            class NeighborAddress(object):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress']['meta_info']


                                            class NextHop(object):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhteTunnel']['meta_info']


                                            class MdtGroupAddr(object):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr']['meta_info']


                                            class L2VpnEvpnEsi(object):
                                                """
                                                L2VPN EVPN ESI
                                                
                                                .. attribute:: esi
                                                
                                                	esi
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.esi = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.esi is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.L2VpnEvpnEsi']['meta_info']


                                            class GwAddr(object):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr']['meta_info']


                                            class BestPathCompWinner(object):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner']['meta_info']


                                            class MvpnNbrAddr(object):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr']['meta_info']


                                            class MvpnNexthopAddr(object):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr']['meta_info']


                                            class L2VpnCircuitStatusValue(object):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                            class MvpnPmsiValue(object):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity']['meta_info']


                                            class LocalPeersAdvertisedTo(object):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                            class PePeersAdvertisedTo(object):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo']['meta_info']


                                            class BestPathOrrBitfield(object):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield']['meta_info']


                                            class AddPathOrrBitfield(object):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.accept_own_path is not None:
                                                    return True

                                                if self.accept_own_self_originated_p_ath is not None:
                                                    return True

                                                if self.add_path_orr_bitfield is not None:
                                                    for child_ref in self.add_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.advertisedto_pe is not None:
                                                    return True

                                                if self.aigp_metric is not None:
                                                    return True

                                                if self.best_path_comp_stage is not None:
                                                    return True

                                                if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                    return True

                                                if self.best_path_id is not None:
                                                    return True

                                                if self.best_path_id_comp_winner is not None:
                                                    return True

                                                if self.best_path_orr_bitfield is not None:
                                                    for child_ref in self.best_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                    return True

                                                if self.dampen_penalty is not None:
                                                    return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.fspec_invalid_path is not None:
                                                    return True

                                                if self.graceful_shutdown is not None:
                                                    return True

                                                if self.gw_addr is not None and self.gw_addr._has_data():
                                                    return True

                                                if self.halflife_time is not None:
                                                    return True

                                                if self.has_esi is not None:
                                                    return True

                                                if self.has_gw_addr is not None:
                                                    return True

                                                if self.has_local_net_label is not None:
                                                    return True

                                                if self.has_mdt_group_addr is not None:
                                                    return True

                                                if self.has_mvpn_extcomm is not None:
                                                    return True

                                                if self.has_mvpn_nbr_addr is not None:
                                                    return True

                                                if self.has_mvpn_nexthop_addr is not None:
                                                    return True

                                                if self.has_mvpn_pmsi is not None:
                                                    return True

                                                if self.has_rcvd_label is not None:
                                                    return True

                                                if self.has_second_label is not None:
                                                    return True

                                                if self.ibgp_signaled_validity is not None:
                                                    return True

                                                if self.igp_metric is not None:
                                                    return True

                                                if self.is_aggregation_suppressed is not None:
                                                    return True

                                                if self.is_as_best is not None:
                                                    return True

                                                if self.is_best_path is not None:
                                                    return True

                                                if self.is_import_dampened is not None:
                                                    return True

                                                if self.is_import_suspect is not None:
                                                    return True

                                                if self.is_internal_path is not None:
                                                    return True

                                                if self.is_partial_best is not None:
                                                    return True

                                                if self.is_path_additional_path is not None:
                                                    return True

                                                if self.is_path_advertised_local_as_only is not None:
                                                    return True

                                                if self.is_path_af_install_eligible is not None:
                                                    return True

                                                if self.is_path_backup is not None:
                                                    return True

                                                if self.is_path_backup_protect_multipath is not None:
                                                    return True

                                                if self.is_path_best_external is not None:
                                                    return True

                                                if self.is_path_damped is not None:
                                                    return True

                                                if self.is_path_from_confederation_peer is not None:
                                                    return True

                                                if self.is_path_from_network_command is not None:
                                                    return True

                                                if self.is_path_from_redistribute_command is not None:
                                                    return True

                                                if self.is_path_from_route_reflector is not None:
                                                    return True

                                                if self.is_path_history_held is not None:
                                                    return True

                                                if self.is_path_imp_candidate is not None:
                                                    return True

                                                if self.is_path_imported is not None:
                                                    return True

                                                if self.is_path_local_aggregate is not None:
                                                    return True

                                                if self.is_path_locally_sourced is not None:
                                                    return True

                                                if self.is_path_long_lived_stale is not None:
                                                    return True

                                                if self.is_path_multipath is not None:
                                                    return True

                                                if self.is_path_nexthop_discarded is not None:
                                                    return True

                                                if self.is_path_not_advertised is not None:
                                                    return True

                                                if self.is_path_not_advertised_to_ebg_ps is not None:
                                                    return True

                                                if self.is_path_received_only is not None:
                                                    return True

                                                if self.is_path_reoriginated is not None:
                                                    return True

                                                if self.is_path_reoriginated_stitching is not None:
                                                    return True

                                                if self.is_path_stale is not None:
                                                    return True

                                                if self.is_path_synced_with_igp is not None:
                                                    return True

                                                if self.is_path_valid is not None:
                                                    return True

                                                if self.is_path_vpn_only is not None:
                                                    return True

                                                if self.is_permanent_path is not None:
                                                    return True

                                                if self.is_received_path_not_modified is not None:
                                                    return True

                                                if self.is_spkr_as_best is not None:
                                                    return True

                                                if self.l2vpn_circuit_status_value is not None:
                                                    for child_ref in self.l2vpn_circuit_status_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                    return True

                                                if self.l2vpn_size is not None:
                                                    return True

                                                if self.labeled_unicast_safi_path is not None:
                                                    return True

                                                if self.local_label is not None:
                                                    return True

                                                if self.local_nh is not None:
                                                    return True

                                                if self.local_path_id is not None:
                                                    return True

                                                if self.local_peers_advertised_to is not None:
                                                    for child_ref in self.local_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.maximum_suppress_time is not None:
                                                    return True

                                                if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                    return True

                                                if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                    return True

                                                if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                    return True

                                                if self.mvpn_path_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_label is not None:
                                                    return True

                                                if self.mvpn_pmsi_type is not None:
                                                    return True

                                                if self.mvpn_pmsi_value is not None:
                                                    for child_ref in self.mvpn_pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.mvpn_sfs_path is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.neighbor_router_id is not None:
                                                    return True

                                                if self.next_hop is not None and self.next_hop._has_data():
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.path_flags is not None:
                                                    return True

                                                if self.path_flap_count is not None:
                                                    return True

                                                if self.path_import_flags is not None:
                                                    return True

                                                if self.path_rt_set_id is not None:
                                                    return True

                                                if self.path_rt_set_route_count is not None:
                                                    return True

                                                if self.path_table_version is not None:
                                                    return True

                                                if self.path_weight is not None:
                                                    return True

                                                if self.pe_peers_advertised_to is not None:
                                                    for child_ref in self.pe_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.rcvd_label is not None:
                                                    return True

                                                if self.rcvd_path_id is not None:
                                                    return True

                                                if self.reuse_value is not None:
                                                    return True

                                                if self.rib_failed is not None:
                                                    return True

                                                if self.route_type is not None:
                                                    return True

                                                if self.rpki_origin_as_validation_disabled is not None:
                                                    return True

                                                if self.rt_set_limit_enabled is not None:
                                                    return True

                                                if self.second_label is not None:
                                                    return True

                                                if self.seconds_since_first_flap is not None:
                                                    return True

                                                if self.show_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.sn_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.suppress_penalty is not None:
                                                    return True

                                                if self.time_to_unsuppress is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation']['meta_info']


                                        class AttributesAfterPolicyIn(object):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self.is_application_gateway_present = None
                                                self.is_as_path2_byte = None
                                                self.is_attr_set_present = None
                                                self.is_ribrnh_present = None
                                                self.is_rnh_present = None
                                                self.ribrnh_encap = None
                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self.ribrnh_mac = None
                                                self.ribrnh_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnhip_table = None
                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self.rnh_addr_len = None
                                                self.rnh_len = None
                                                self.rnh_type = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.vpn_distinguisher = None


                                            class CommonAttributes(object):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                            class AttrSet(object):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                            class RnhAddr(object):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None
                                                    self.mac_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    if self.mac_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                            class RibrnhIp(object):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.attr_set is not None and self.attr_set._has_data():
                                                    return True

                                                if self.attribute_key_number is not None:
                                                    return True

                                                if self.attribute_reuse_id_config is not None:
                                                    return True

                                                if self.attribute_reuse_id_current is not None:
                                                    return True

                                                if self.attribute_reuse_id_keys is not None:
                                                    return True

                                                if self.attribute_reuse_id_max_id is not None:
                                                    return True

                                                if self.attribute_reuse_id_node is not None:
                                                    return True

                                                if self.attribute_reuse_id_recover_sec is not None:
                                                    return True

                                                if self.common_attributes is not None and self.common_attributes._has_data():
                                                    return True

                                                if self.is_application_gateway_present is not None:
                                                    return True

                                                if self.is_as_path2_byte is not None:
                                                    return True

                                                if self.is_attr_set_present is not None:
                                                    return True

                                                if self.is_ribrnh_present is not None:
                                                    return True

                                                if self.is_rnh_present is not None:
                                                    return True

                                                if self.ribrnh_encap is not None:
                                                    return True

                                                if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                    return True

                                                if self.ribrnh_mac is not None:
                                                    return True

                                                if self.ribrnh_table is not None:
                                                    return True

                                                if self.ribrnh_vni is not None:
                                                    return True

                                                if self.ribrnhip_table is not None:
                                                    return True

                                                if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                    return True

                                                if self.rnh_addr_len is not None:
                                                    return True

                                                if self.rnh_len is not None:
                                                    return True

                                                if self.rnh_type is not None:
                                                    return True

                                                if self.set_aigp_inbound_igp is not None:
                                                    return True

                                                if self.set_aigp_inbound_metric is not None:
                                                    return True

                                                if self.vpn_distinguisher is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:dampening'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                return True

                                            if self.label_fail is not None:
                                                return True

                                            if self.label_o_or_version is not None:
                                                return True

                                            if self.label_oor is not None:
                                                return True

                                            if self.neighbor_address is not None:
                                                return True

                                            if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                return True

                                            if self.network is not None:
                                                return True

                                            if self.no_path is not None:
                                                return True

                                            if self.path_id is not None:
                                                return True

                                            if self.path_information is not None and self.path_information._has_data():
                                                return True

                                            if self.prefix_version is not None:
                                                return True

                                            if self.process_instance_id is not None:
                                                return True

                                            if self.rd is not None:
                                                return True

                                            if self.reuse is not None:
                                                return True

                                            if self.route_distinguisher is not None:
                                                return True

                                            if self.source_rd is not None:
                                                return True

                                            if self.source_route_distinguisher is not None:
                                                return True

                                            if self.source_vrf_name is not None:
                                                return True

                                            if self.srcaf_name is not None:
                                                return True

                                            if self.version is not None:
                                                return True

                                            if self.vrf_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:dampenings'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dampening is not None:
                                            for child_ref in self.dampening:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings']['meta_info']


                                class PrefixFilters(object):
                                    """
                                    The BGP Prefix Filter table
                                    
                                    .. attribute:: prefix_filter
                                    
                                    	A BGP prefix filter table entry
                                    	**type**\: list of    :py:class:`PrefixFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.prefix_filter = YList()
                                        self.prefix_filter.parent = self
                                        self.prefix_filter.name = 'prefix_filter'


                                    class PrefixFilter(object):
                                        """
                                        A BGP prefix filter table entry
                                        
                                        .. attribute:: neighbor_address  <key>
                                        
                                        	Neighbor address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: af_name
                                        
                                        	Address family identfier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr>`
                                        
                                        .. attribute:: prefix_list_info
                                        
                                        	Prefix list
                                        	**type**\:   :py:class:`PrefixListInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.neighbor_address = None
                                            self.af_name = None
                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self.prefix_list_info = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo()
                                            self.prefix_list_info.parent = self


                                        class NeighborAddressXr(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr']['meta_info']


                                        class PrefixListInfo(object):
                                            """
                                            Prefix list
                                            
                                            .. attribute:: bgp_pfxlst
                                            
                                            	bgp pfxlst
                                            	**type**\: list of    :py:class:`BgpPfxlst <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.bgp_pfxlst = YList()
                                                self.bgp_pfxlst.parent = self
                                                self.bgp_pfxlst.name = 'bgp_pfxlst'


                                            class BgpPfxlst(object):
                                                """
                                                bgp pfxlst
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix>`
                                                
                                                .. attribute:: is_prefix_grant
                                                
                                                	TRUE = permit, FALSE = deny
                                                	**type**\:  bool
                                                
                                                .. attribute:: max_prefix_length
                                                
                                                	Maximum prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: min_prefix_length
                                                
                                                	Minimum prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self.is_prefix_grant = None
                                                    self.max_prefix_length = None
                                                    self.min_prefix_length = None
                                                    self.sequence_number = None


                                                class BgpPrefix(object):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self.prefix_length = None


                                                    class Prefix(object):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.prefix is not None and self.prefix._has_data():
                                                            return True

                                                        if self.prefix_length is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-pfxlst'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                        return True

                                                    if self.is_prefix_grant is not None:
                                                        return True

                                                    if self.max_prefix_length is not None:
                                                        return True

                                                    if self.min_prefix_length is not None:
                                                        return True

                                                    if self.sequence_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix-list-info'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bgp_pfxlst is not None:
                                                    for child_ref in self.bgp_pfxlst:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')
                                            if self.neighbor_address is None:
                                                raise YPYModelError('Key property neighbor_address is None')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix-filter[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address = ' + str(self.neighbor_address) + ']'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.neighbor_address is not None:
                                                return True

                                            if self.af_name is not None:
                                                return True

                                            if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                return True

                                            if self.prefix_list_info is not None and self.prefix_list_info._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix-filters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.prefix_filter is not None:
                                            for child_ref in self.prefix_filter:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters']['meta_info']


                                class Attributes(object):
                                    """
                                    The BGP Attribute table
                                    
                                    .. attribute:: attribute
                                    
                                    	A BGP Attribute table entry
                                    	**type**\: list of    :py:class:`Attribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.attribute = YList()
                                        self.attribute.parent = self
                                        self.attribute.name = 'attribute'


                                    class Attribute(object):
                                        """
                                        A BGP Attribute table entry
                                        
                                        .. attribute:: attribute_cache_bucket
                                        
                                        	Attribute cache bucket
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: attribute_cache_id
                                        
                                        	Attribute cache ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: attribute_iid
                                        
                                        	Attribute IID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: attribute_info
                                        
                                        	Attributes
                                        	**type**\:   :py:class:`AttributeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo>`
                                        
                                        .. attribute:: attribute_instance_id
                                        
                                        	Attribute Instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: attribute_structure_hash_value
                                        
                                        	Hash value for attribute structure
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_structure_id
                                        
                                        	ID of attribute structure
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: reference_count
                                        
                                        	Number of paths which use this attribute structure
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.attribute_cache_bucket = None
                                            self.attribute_cache_id = None
                                            self.attribute_iid = None
                                            self.attribute_info = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo()
                                            self.attribute_info.parent = self
                                            self.attribute_instance_id = None
                                            self.attribute_structure_hash_value = None
                                            self.attribute_structure_id = None
                                            self.process_instance_id = None
                                            self.reference_count = None


                                        class AttributeInfo(object):
                                            """
                                            Attributes
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet()
                                                self.attr_set.parent = self
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self.is_application_gateway_present = None
                                                self.is_as_path2_byte = None
                                                self.is_attr_set_present = None
                                                self.is_ribrnh_present = None
                                                self.is_rnh_present = None
                                                self.ribrnh_encap = None
                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self.ribrnh_mac = None
                                                self.ribrnh_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnhip_table = None
                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self.rnh_addr_len = None
                                                self.rnh_len = None
                                                self.rnh_type = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.vpn_distinguisher = None


                                            class CommonAttributes(object):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes']['meta_info']


                                            class AttrSet(object):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet']['meta_info']


                                            class RnhAddr(object):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None
                                                    self.mac_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    if self.mac_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr']['meta_info']


                                            class RibrnhIp(object):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attribute-info'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.attr_set is not None and self.attr_set._has_data():
                                                    return True

                                                if self.attribute_key_number is not None:
                                                    return True

                                                if self.attribute_reuse_id_config is not None:
                                                    return True

                                                if self.attribute_reuse_id_current is not None:
                                                    return True

                                                if self.attribute_reuse_id_keys is not None:
                                                    return True

                                                if self.attribute_reuse_id_max_id is not None:
                                                    return True

                                                if self.attribute_reuse_id_node is not None:
                                                    return True

                                                if self.attribute_reuse_id_recover_sec is not None:
                                                    return True

                                                if self.common_attributes is not None and self.common_attributes._has_data():
                                                    return True

                                                if self.is_application_gateway_present is not None:
                                                    return True

                                                if self.is_as_path2_byte is not None:
                                                    return True

                                                if self.is_attr_set_present is not None:
                                                    return True

                                                if self.is_ribrnh_present is not None:
                                                    return True

                                                if self.is_rnh_present is not None:
                                                    return True

                                                if self.ribrnh_encap is not None:
                                                    return True

                                                if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                    return True

                                                if self.ribrnh_mac is not None:
                                                    return True

                                                if self.ribrnh_table is not None:
                                                    return True

                                                if self.ribrnh_vni is not None:
                                                    return True

                                                if self.ribrnhip_table is not None:
                                                    return True

                                                if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                    return True

                                                if self.rnh_addr_len is not None:
                                                    return True

                                                if self.rnh_len is not None:
                                                    return True

                                                if self.rnh_type is not None:
                                                    return True

                                                if self.set_aigp_inbound_igp is not None:
                                                    return True

                                                if self.set_aigp_inbound_metric is not None:
                                                    return True

                                                if self.vpn_distinguisher is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attribute'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.attribute_cache_bucket is not None:
                                                return True

                                            if self.attribute_cache_id is not None:
                                                return True

                                            if self.attribute_iid is not None:
                                                return True

                                            if self.attribute_info is not None and self.attribute_info._has_data():
                                                return True

                                            if self.attribute_instance_id is not None:
                                                return True

                                            if self.attribute_structure_hash_value is not None:
                                                return True

                                            if self.attribute_structure_id is not None:
                                                return True

                                            if self.process_instance_id is not None:
                                                return True

                                            if self.reference_count is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.attribute is not None:
                                            for child_ref in self.attribute:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.af_name is None:
                                        raise YPYModelError('Key property af_name is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af[Cisco-IOS-XR-ipv4-bgp-oper:af-name = ' + str(self.af_name) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.advertised_path_counts is not None and self.advertised_path_counts._has_data():
                                        return True

                                    if self.advertised_path_xr is not None and self.advertised_path_xr._has_data():
                                        return True

                                    if self.advertised_paths is not None and self.advertised_paths._has_data():
                                        return True

                                    if self.af_process_info is not None and self.af_process_info._has_data():
                                        return True

                                    if self.attributes is not None and self.attributes._has_data():
                                        return True

                                    if self.bmp_paths is not None and self.bmp_paths._has_data():
                                        return True

                                    if self.convergence is not None and self.convergence._has_data():
                                        return True

                                    if self.dampenings is not None and self.dampenings._has_data():
                                        return True

                                    if self.epes is not None and self.epes._has_data():
                                        return True

                                    if self.global_af_process_info is not None and self.global_af_process_info._has_data():
                                        return True

                                    if self.neighbor_af_table is not None and self.neighbor_af_table._has_data():
                                        return True

                                    if self.network_all_rds is not None and self.network_all_rds._has_data():
                                        return True

                                    if self.network_lookup_all_rds is not None and self.network_lookup_all_rds._has_data():
                                        return True

                                    if self.network_prefixes is not None and self.network_prefixes._has_data():
                                        return True

                                    if self.networks is not None and self.networks._has_data():
                                        return True

                                    if self.next_hop_address_families is not None and self.next_hop_address_families._has_data():
                                        return True

                                    if self.path_labeled_table is not None and self.path_labeled_table._has_data():
                                        return True

                                    if self.path_table is not None and self.path_table._has_data():
                                        return True

                                    if self.path_used_table is not None and self.path_used_table._has_data():
                                        return True

                                    if self.policies is not None and self.policies._has_data():
                                        return True

                                    if self.prefix_filters is not None and self.prefix_filters._has_data():
                                        return True

                                    if self.rpc_sets is not None and self.rpc_sets._has_data():
                                        return True

                                    if self.rt_set_counters is not None and self.rt_set_counters._has_data():
                                        return True

                                    if self.sourced_networks is not None and self.sourced_networks._has_data():
                                        return True

                                    if self.update_generation_address_family is not None and self.update_generation_address_family._has_data():
                                        return True

                                    if self.update_generation_filter_groups is not None and self.update_generation_filter_groups._has_data():
                                        return True

                                    if self.update_generation_neighbors is not None and self.update_generation_neighbors._has_data():
                                        return True

                                    if self.update_generation_sub_groups is not None and self.update_generation_sub_groups._has_data():
                                        return True

                                    if self.update_generation_update_groups is not None and self.update_generation_update_groups._has_data():
                                        return True

                                    if self.update_groups is not None and self.update_groups._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:afs'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af is not None:
                                    for child_ref in self.af:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs']['meta_info']


                        class Information(object):
                            """
                            Meta data for VRF
                            
                            .. attribute:: route_distinguisher
                            
                            	Route Distinguisher
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{16}
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.route_distinguisher = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.route_distinguisher is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Information']['meta_info']


                        class UpdateInboundFilterVrf(object):
                            """
                            Update inbound filtering information for the VRF
                            
                            .. attribute:: last_update_filtered_age
                            
                            	Time since last filtered messages received event (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_update_filtered_timestamp
                            
                            	Last Filtered messages received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`LastUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp>`
                            
                            .. attribute:: update_filtered_message_count
                            
                            	Filtered messages count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_filtered_neighbor_count
                            
                            	Count of neighbors that received filtered messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_vrf_name
                            
                            	VRF Name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.last_update_filtered_age = None
                                self.last_update_filtered_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp()
                                self.last_update_filtered_timestamp.parent = self
                                self.update_filtered_message_count = None
                                self.update_filtered_neighbor_count = None
                                self.update_vrf_name = None


                            class LastUpdateFilteredTimestamp(object):
                                """
                                Last Filtered messages received time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.nanoseconds = None
                                    self.seconds = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-filtered-timestamp'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.nanoseconds is not None:
                                        return True

                                    if self.seconds is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-inbound-filter-vrf'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.last_update_filtered_age is not None:
                                    return True

                                if self.last_update_filtered_timestamp is not None and self.last_update_filtered_timestamp._has_data():
                                    return True

                                if self.update_filtered_message_count is not None:
                                    return True

                                if self.update_filtered_neighbor_count is not None:
                                    return True

                                if self.update_vrf_name is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterVrf']['meta_info']


                        class Postits(object):
                            """
                            The BGP Neighbor table
                            
                            .. attribute:: postit
                            
                            	A BGP Postit table entry
                            	**type**\: list of    :py:class:`Postit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.postit = YList()
                                self.postit.parent = self
                                self.postit.name = 'postit'


                            class Postit(object):
                                """
                                A BGP Postit table entry
                                
                                .. attribute:: neighbor_address  <key>
                                
                                	Neighbor address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: connect_state
                                
                                	State
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_af
                                
                                	Neighbor Afi
                                	**type**\: list of    :py:class:`NeighborAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborAf>`
                                
                                .. attribute:: neighbors_address
                                
                                	Neighbor Addr
                                	**type**\:   :py:class:`NeighborsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress>`
                                
                                .. attribute:: nsr_state
                                
                                	NSR state
                                	**type**\:   :py:class:`BgpSyncNbrNsrStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrStateEnum>`
                                
                                .. attribute:: postit_info
                                
                                	Postit Info
                                	**type**\: list of    :py:class:`PostitInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.PostitInfo>`
                                
                                .. attribute:: start_time
                                
                                	StartTime
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vrf_name
                                
                                	VRF Name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.neighbor_address = None
                                    self.connect_state = None
                                    self.neighbor_af = YList()
                                    self.neighbor_af.parent = self
                                    self.neighbor_af.name = 'neighbor_af'
                                    self.neighbors_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress()
                                    self.neighbors_address.parent = self
                                    self.nsr_state = None
                                    self.postit_info = YList()
                                    self.postit_info.parent = self
                                    self.postit_info.name = 'postit_info'
                                    self.start_time = None
                                    self.vrf_name = None


                                class NeighborsAddress(object):
                                    """
                                    Neighbor Addr
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpnvpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2VpnvplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4mdt_address = None
                                        self.ipv4mvpn_address = None
                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress()
                                        self.ipv4sr_policy_address.parent = self
                                        self.ipv4vpn_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress()
                                        self.ipv6sr_policy_address.parent = self
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_flowspec_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.l2vpn_evpn_address = None
                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2VpnvplsAddress()
                                        self.l2vpnvpls_address.parent = self
                                        self.ls_ls_address = None
                                        self.rt_constraint_address = None


                                    class L2VpnvplsAddress(object):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2VpnvplsAddress']['meta_info']


                                    class L2VpnMspwAddress(object):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2VpnMspwAddress']['meta_info']


                                    class Ipv4SrPolicyAddress(object):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress']['meta_info']


                                    class Ipv6SrPolicyAddress(object):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv6_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv6_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbors-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.afi is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv4_flowspec_address is not None:
                                            return True

                                        if self.ipv4_label_address is not None:
                                            return True

                                        if self.ipv4_mcast_address is not None:
                                            return True

                                        if self.ipv4_tunnel_address is not None:
                                            return True

                                        if self.ipv4mdt_address is not None:
                                            return True

                                        if self.ipv4mvpn_address is not None:
                                            return True

                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                            return True

                                        if self.ipv4vpn_address is not None:
                                            return True

                                        if self.ipv4vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv4vpna_mcastddress is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        if self.ipv6_flowspec_address is not None:
                                            return True

                                        if self.ipv6_label_address is not None:
                                            return True

                                        if self.ipv6_mcast_address is not None:
                                            return True

                                        if self.ipv6mvpn_address is not None:
                                            return True

                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                            return True

                                        if self.ipv6vpn_address is not None:
                                            return True

                                        if self.ipv6vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv6vpn_mcast_address is not None:
                                            return True

                                        if self.l2vpn_evpn_address is not None:
                                            return True

                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                            return True

                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                            return True

                                        if self.ls_ls_address is not None:
                                            return True

                                        if self.rt_constraint_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress']['meta_info']


                                class NeighborAf(object):
                                    """
                                    Neighbor Afi
                                    
                                    .. attribute:: entry
                                    
                                    	Array entry
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-af'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborAf']['meta_info']


                                class PostitInfo(object):
                                    """
                                    Postit Info
                                    
                                    .. attribute:: peer_id
                                    
                                    	Peer ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: postit_af_name
                                    
                                    	Postit Afi
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: postit_direction
                                    
                                    	Postit Direction
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: postit_flags
                                    
                                    	Postit Flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: postit_id
                                    
                                    	Postit ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: postit_notification
                                    
                                    	Postit notification
                                    	**type**\:   :py:class:`PostitNotification <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification>`
                                    
                                    .. attribute:: postit_policy
                                    
                                    	Policy
                                    	**type**\:  str
                                    
                                    .. attribute:: postit_reset
                                    
                                    	Reset
                                    	**type**\:   :py:class:`BgpResetReasonIndexEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndexEnum>`
                                    
                                    .. attribute:: postit_subtype
                                    
                                    	Postit Subtype
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: postit_ts
                                    
                                    	Postit TS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: postit_type
                                    
                                    	Postit Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.peer_id = None
                                        self.postit_af_name = None
                                        self.postit_direction = None
                                        self.postit_flags = None
                                        self.postit_id = None
                                        self.postit_notification = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification()
                                        self.postit_notification.parent = self
                                        self.postit_policy = None
                                        self.postit_reset = None
                                        self.postit_subtype = None
                                        self.postit_ts = None
                                        self.postit_type = None


                                    class PostitNotification(object):
                                        """
                                        Postit notification
                                        
                                        .. attribute:: last_notification_data
                                        
                                        	Message data in last notification
                                        	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData>`
                                        
                                        .. attribute:: notification_error_code
                                        
                                        	Error code in last notification
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: notification_error_subcode
                                        
                                        	Error subcode in last notification
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: time_since_last_notification
                                        
                                        	Time since the last notification was sent or received (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.last_notification_data = YList()
                                            self.last_notification_data.parent = self
                                            self.last_notification_data.name = 'last_notification_data'
                                            self.notification_error_code = None
                                            self.notification_error_subcode = None
                                            self.time_since_last_notification = None


                                        class LastNotificationData(object):
                                            """
                                            Message data in last notification
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-notification-data'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:postit-notification'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.last_notification_data is not None:
                                                for child_ref in self.last_notification_data:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.notification_error_code is not None:
                                                return True

                                            if self.notification_error_subcode is not None:
                                                return True

                                            if self.time_since_last_notification is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:postit-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.peer_id is not None:
                                            return True

                                        if self.postit_af_name is not None:
                                            return True

                                        if self.postit_direction is not None:
                                            return True

                                        if self.postit_flags is not None:
                                            return True

                                        if self.postit_id is not None:
                                            return True

                                        if self.postit_notification is not None and self.postit_notification._has_data():
                                            return True

                                        if self.postit_policy is not None:
                                            return True

                                        if self.postit_reset is not None:
                                            return True

                                        if self.postit_subtype is not None:
                                            return True

                                        if self.postit_ts is not None:
                                            return True

                                        if self.postit_type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.PostitInfo']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.neighbor_address is None:
                                        raise YPYModelError('Key property neighbor_address is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:postit[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address = ' + str(self.neighbor_address) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.neighbor_address is not None:
                                        return True

                                    if self.connect_state is not None:
                                        return True

                                    if self.neighbor_af is not None:
                                        for child_ref in self.neighbor_af:
                                            if child_ref._has_data():
                                                return True

                                    if self.neighbors_address is not None and self.neighbors_address._has_data():
                                        return True

                                    if self.nsr_state is not None:
                                        return True

                                    if self.postit_info is not None:
                                        for child_ref in self.postit_info:
                                            if child_ref._has_data():
                                                return True

                                    if self.start_time is not None:
                                        return True

                                    if self.vrf_name is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:postits'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.postit is not None:
                                    for child_ref in self.postit:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits']['meta_info']


                        class GlobalProcessInfo(object):
                            """
                            The Global Process information table
                            
                            .. attribute:: global_
                            
                            	Global information
                            	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Global_>`
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:   :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Vrf_>`
                            
                            .. attribute:: vrf_name
                            
                            	Name of the VRF
                            	**type**\:  str
                            
                            .. attribute:: vrfid
                            
                            	VRF ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.global_ = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Global_()
                                self.global_.parent = self
                                self.vrf = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Vrf_()
                                self.vrf.parent = self
                                self.vrf_name = None
                                self.vrfid = None


                            class Global_(object):
                                """
                                Global information
                                
                                .. attribute:: asn_format
                                
                                	BGP AS Number Format
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_current_buffer_size
                                
                                	Current value for BMP buffer 
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmp_default_buffer_size
                                
                                	Default value for BMP buffer limit when a value is not configured
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmp_maximum_buffer_size
                                
                                	Maximum limit user can configure for max\-buffer\-size command under bmp\-server
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: cluster_id
                                
                                	Cluster ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: cluster_id_entry
                                
                                	All configured Cluster IDs
                                	**type**\: list of    :py:class:`ClusterIdEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Global_.ClusterIdEntry>`
                                
                                .. attribute:: confederation_id
                                
                                	Confederation ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: configured_cluster_id
                                
                                	Configured cluster ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: generic_scan_period
                                
                                	Period (in seconds) of generic scanner runs
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: graceful_maint_all_nbrs
                                
                                	Graceful Maintenance also for neighbors without GM configuration
                                	**type**\:  bool
                                
                                .. attribute:: graceful_maint_retain_routes
                                
                                	Retaining routes in RIB when BGP process stops while in Graceful Maintenance
                                	**type**\:  bool
                                
                                .. attribute:: graceful_maintenance
                                
                                	Graceful Maintenance
                                	**type**\:  bool
                                
                                .. attribute:: in_standalone_mode
                                
                                	Standalone or Distributed mode
                                	**type**\:  bool
                                
                                .. attribute:: instance_name
                                
                                	Name of BGP instance
                                	**type**\:  str
                                
                                .. attribute:: is_cluster_id_specified_as_ip
                                
                                	Cluster ID specified as an IP address
                                	**type**\:  bool
                                
                                .. attribute:: local_as
                                
                                	Local autonomous system number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: process_rlimit
                                
                                	Platform RLIMIT max for the process
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: restart_count
                                
                                	No of times BGP has started
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: srgb_end
                                
                                	In use Segment\-routing Global Block end value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: srgb_end_configured
                                
                                	Configured segment\-routing Global Block end value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: srgb_start
                                
                                	In use segment\-routing Global Block start value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: srgb_start_configured
                                
                                	Configured segment\-routing Global Block start value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_delay
                                
                                	Update delay timeout time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.asn_format = None
                                    self.bmp_current_buffer_size = None
                                    self.bmp_default_buffer_size = None
                                    self.bmp_maximum_buffer_size = None
                                    self.cluster_id = None
                                    self.cluster_id_entry = YList()
                                    self.cluster_id_entry.parent = self
                                    self.cluster_id_entry.name = 'cluster_id_entry'
                                    self.confederation_id = None
                                    self.configured_cluster_id = None
                                    self.generic_scan_period = None
                                    self.graceful_maint_all_nbrs = None
                                    self.graceful_maint_retain_routes = None
                                    self.graceful_maintenance = None
                                    self.in_standalone_mode = None
                                    self.instance_name = None
                                    self.is_cluster_id_specified_as_ip = None
                                    self.local_as = None
                                    self.process_rlimit = None
                                    self.restart_count = None
                                    self.srgb_end = None
                                    self.srgb_end_configured = None
                                    self.srgb_start = None
                                    self.srgb_start_configured = None
                                    self.update_delay = None


                                class ClusterIdEntry(object):
                                    """
                                    All configured Cluster IDs
                                    
                                    .. attribute:: cluster_id_type
                                    
                                    	Cluster ID type\: number or IPv4 address
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: cluster_id_val
                                    
                                    	Cluster ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.cluster_id_type = None
                                        self.cluster_id_val = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster-id-entry'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.cluster_id_type is not None:
                                            return True

                                        if self.cluster_id_val is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Global_.ClusterIdEntry']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:global'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.asn_format is not None:
                                        return True

                                    if self.bmp_current_buffer_size is not None:
                                        return True

                                    if self.bmp_default_buffer_size is not None:
                                        return True

                                    if self.bmp_maximum_buffer_size is not None:
                                        return True

                                    if self.cluster_id is not None:
                                        return True

                                    if self.cluster_id_entry is not None:
                                        for child_ref in self.cluster_id_entry:
                                            if child_ref._has_data():
                                                return True

                                    if self.confederation_id is not None:
                                        return True

                                    if self.configured_cluster_id is not None:
                                        return True

                                    if self.generic_scan_period is not None:
                                        return True

                                    if self.graceful_maint_all_nbrs is not None:
                                        return True

                                    if self.graceful_maint_retain_routes is not None:
                                        return True

                                    if self.graceful_maintenance is not None:
                                        return True

                                    if self.in_standalone_mode is not None:
                                        return True

                                    if self.instance_name is not None:
                                        return True

                                    if self.is_cluster_id_specified_as_ip is not None:
                                        return True

                                    if self.local_as is not None:
                                        return True

                                    if self.process_rlimit is not None:
                                        return True

                                    if self.restart_count is not None:
                                        return True

                                    if self.srgb_end is not None:
                                        return True

                                    if self.srgb_end_configured is not None:
                                        return True

                                    if self.srgb_start is not None:
                                        return True

                                    if self.srgb_start_configured is not None:
                                        return True

                                    if self.update_delay is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Global_']['meta_info']


                            class Vrf_(object):
                                """
                                VRF information
                                
                                .. attribute:: configured_router_id
                                
                                	Configured router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: default_local_preference
                                
                                	Default local preference
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: default_metric
                                
                                	Default metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: hold_time
                                
                                	Default hold timer (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: is_bestpath_aigp_ignore_enabled
                                
                                	Bestpath\: Ignore AIGP unless both paths have AIGP attribute
                                	**type**\:  bool
                                
                                .. attribute:: is_bestpath_always_compare_med_enabled
                                
                                	Bestpath\: Always compare MED
                                	**type**\:  bool
                                
                                .. attribute:: is_bestpath_as_path_mpath_relax_enabled
                                
                                	Bestpath\: Relax AS path for mpath
                                	**type**\:  bool
                                
                                .. attribute:: is_bestpath_compare_med_from_confed_peer_enabled
                                
                                	Bestpath\: Compare MED from confed peer
                                	**type**\:  bool
                                
                                .. attribute:: is_bestpath_compare_router_id_for_ebgp_peers_enabled
                                
                                	Bestpath\: Compare routerID for eBGP peers
                                	**type**\:  bool
                                
                                .. attribute:: is_bestpath_ignore_as_path_enabled
                                
                                	Bestpath\: Ignore AS path
                                	**type**\:  bool
                                
                                .. attribute:: is_bestpath_missing_med_is_worst_enabled
                                
                                	Bestpath\: Treat missing MED as worst
                                	**type**\:  bool
                                
                                .. attribute:: is_default_metric_configured
                                
                                	Default metric configured
                                	**type**\:  bool
                                
                                .. attribute:: is_default_originate_configured
                                
                                	Default route originate configured
                                	**type**\:  bool
                                
                                .. attribute:: is_enforce_first_as_enabled
                                
                                	Enforce first AS
                                	**type**\:  bool
                                
                                .. attribute:: is_fast_external_fallover_enabled
                                
                                	Fast external fallover enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_graceful_restart
                                
                                	Graceful restart enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_multipath_as_path_ignore_onwards_enabled
                                
                                	Multipath\: Ignore everything AS path onwards for mpath
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_logging
                                
                                	Neighbor logging enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_nsr
                                
                                	Non\-stop routing enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_redistribute_ibgp_to_ig_ps_enabled
                                
                                	Redistribute iBGP into IGPs enabled
                                	**type**\:  bool
                                
                                .. attribute:: keep_alive_time
                                
                                	Default keepalive timer (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: min_acceptable_hold_time
                                
                                	Default min acceptable hold time from neighbor(seconds)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: restart_time
                                
                                	Restart time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: rib_purge_timeout
                                
                                	RIB purge timeout time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: route_distinguisher
                                
                                	Route Distinguisher
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: router_id
                                
                                	Router ID for the VRF
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: stale_path_time
                                
                                	Stale path timeout time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: vrf_is_active
                                
                                	VRF state
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.configured_router_id = None
                                    self.default_local_preference = None
                                    self.default_metric = None
                                    self.hold_time = None
                                    self.is_bestpath_aigp_ignore_enabled = None
                                    self.is_bestpath_always_compare_med_enabled = None
                                    self.is_bestpath_as_path_mpath_relax_enabled = None
                                    self.is_bestpath_compare_med_from_confed_peer_enabled = None
                                    self.is_bestpath_compare_router_id_for_ebgp_peers_enabled = None
                                    self.is_bestpath_ignore_as_path_enabled = None
                                    self.is_bestpath_missing_med_is_worst_enabled = None
                                    self.is_default_metric_configured = None
                                    self.is_default_originate_configured = None
                                    self.is_enforce_first_as_enabled = None
                                    self.is_fast_external_fallover_enabled = None
                                    self.is_graceful_restart = None
                                    self.is_multipath_as_path_ignore_onwards_enabled = None
                                    self.is_neighbor_logging = None
                                    self.is_nsr = None
                                    self.is_redistribute_ibgp_to_ig_ps_enabled = None
                                    self.keep_alive_time = None
                                    self.min_acceptable_hold_time = None
                                    self.restart_time = None
                                    self.rib_purge_timeout = None
                                    self.route_distinguisher = None
                                    self.router_id = None
                                    self.stale_path_time = None
                                    self.vrf_is_active = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:vrf'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.configured_router_id is not None:
                                        return True

                                    if self.default_local_preference is not None:
                                        return True

                                    if self.default_metric is not None:
                                        return True

                                    if self.hold_time is not None:
                                        return True

                                    if self.is_bestpath_aigp_ignore_enabled is not None:
                                        return True

                                    if self.is_bestpath_always_compare_med_enabled is not None:
                                        return True

                                    if self.is_bestpath_as_path_mpath_relax_enabled is not None:
                                        return True

                                    if self.is_bestpath_compare_med_from_confed_peer_enabled is not None:
                                        return True

                                    if self.is_bestpath_compare_router_id_for_ebgp_peers_enabled is not None:
                                        return True

                                    if self.is_bestpath_ignore_as_path_enabled is not None:
                                        return True

                                    if self.is_bestpath_missing_med_is_worst_enabled is not None:
                                        return True

                                    if self.is_default_metric_configured is not None:
                                        return True

                                    if self.is_default_originate_configured is not None:
                                        return True

                                    if self.is_enforce_first_as_enabled is not None:
                                        return True

                                    if self.is_fast_external_fallover_enabled is not None:
                                        return True

                                    if self.is_graceful_restart is not None:
                                        return True

                                    if self.is_multipath_as_path_ignore_onwards_enabled is not None:
                                        return True

                                    if self.is_neighbor_logging is not None:
                                        return True

                                    if self.is_nsr is not None:
                                        return True

                                    if self.is_redistribute_ibgp_to_ig_ps_enabled is not None:
                                        return True

                                    if self.keep_alive_time is not None:
                                        return True

                                    if self.min_acceptable_hold_time is not None:
                                        return True

                                    if self.restart_time is not None:
                                        return True

                                    if self.rib_purge_timeout is not None:
                                        return True

                                    if self.route_distinguisher is not None:
                                        return True

                                    if self.router_id is not None:
                                        return True

                                    if self.stale_path_time is not None:
                                        return True

                                    if self.vrf_is_active is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Vrf_']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:global-process-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.global_ is not None and self.global_._has_data():
                                    return True

                                if self.vrf is not None and self.vrf._has_data():
                                    return True

                                if self.vrf_name is not None:
                                    return True

                                if self.vrfid is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo']['meta_info']


                        class UpdateInboundErrorNeighbors(object):
                            """
                            Update inbound error information for all
                            neighbors
                            
                            .. attribute:: update_inbound_error_neighbor
                            
                            	Update inbound error information for neighbor
                            	**type**\: list of    :py:class:`UpdateInboundErrorNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.update_inbound_error_neighbor = YList()
                                self.update_inbound_error_neighbor.parent = self
                                self.update_inbound_error_neighbor.name = 'update_inbound_error_neighbor'


                            class UpdateInboundErrorNeighbor(object):
                                """
                                Update inbound error information for neighbor
                                
                                .. attribute:: neighbor_address  <key>
                                
                                	Neighbor address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: establishment_action_count
                                
                                	Number of occurence of each action type since  session establishment
                                	**type**\: list of    :py:class:`EstablishmentActionCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount>`
                                
                                .. attribute:: establishment_total_update_message_count
                                
                                	Total update messages count since session establishment
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: first_update_error_handling_reset_timestamp
                                
                                	First error\-handling reset time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`FirstUpdateErrorHandlingResetTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp>`
                                
                                .. attribute:: first_update_malformed_timestamp
                                
                                	First malformed message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`FirstUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp>`
                                
                                .. attribute:: first_update_memory_allocation_fail_timestamp
                                
                                	First memory allocation failure time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`FirstUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp>`
                                
                                .. attribute:: last_error_handling_reset_age
                                
                                	Time since last error\-handling reset event (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_error_handling_reset_timestamp
                                
                                	Last error\-handling reset time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`LastErrorHandlingResetTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp>`
                                
                                .. attribute:: last_update_malformed_age
                                
                                	Time since last malformed message received event (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_update_malformed_timestamp
                                
                                	Last malformed message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`LastUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp>`
                                
                                .. attribute:: last_update_memory_allocation_fail_age
                                
                                	Time since last memory allocation failure event (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_update_memory_allocation_fail_timestamp
                                
                                	Last memory allocation failure time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp>`
                                
                                .. attribute:: total_update_message_count
                                
                                	Total update messages count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_attribute_discard_count
                                
                                	Discarded attribute count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_error_handling_avoid_reset
                                
                                	Configure error\-handling to avoid resets
                                	**type**\:  bool
                                
                                .. attribute:: update_error_handling_reset_count
                                
                                	Error\-handling reset count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_error_message
                                
                                	List of malformed messages
                                	**type**\: list of    :py:class:`UpdateErrorMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage>`
                                
                                .. attribute:: update_error_message_list_count
                                
                                	Malformed messages list count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_malformed_message_count
                                
                                	Malformed messages count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_memory_allocation_fail_count
                                
                                	Memory allocation failure count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_neighbor_address
                                
                                	Neighbor address
                                	**type**\:   :py:class:`UpdateNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress>`
                                
                                .. attribute:: update_vrf_name
                                
                                	VRF Name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.neighbor_address = None
                                    self.establishment_action_count = YList()
                                    self.establishment_action_count.parent = self
                                    self.establishment_action_count.name = 'establishment_action_count'
                                    self.establishment_total_update_message_count = None
                                    self.first_update_error_handling_reset_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp()
                                    self.first_update_error_handling_reset_timestamp.parent = self
                                    self.first_update_malformed_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp()
                                    self.first_update_malformed_timestamp.parent = self
                                    self.first_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp()
                                    self.first_update_memory_allocation_fail_timestamp.parent = self
                                    self.last_error_handling_reset_age = None
                                    self.last_error_handling_reset_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp()
                                    self.last_error_handling_reset_timestamp.parent = self
                                    self.last_update_malformed_age = None
                                    self.last_update_malformed_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp()
                                    self.last_update_malformed_timestamp.parent = self
                                    self.last_update_memory_allocation_fail_age = None
                                    self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp()
                                    self.last_update_memory_allocation_fail_timestamp.parent = self
                                    self.total_update_message_count = None
                                    self.update_attribute_discard_count = None
                                    self.update_error_handling_avoid_reset = None
                                    self.update_error_handling_reset_count = None
                                    self.update_error_message = YList()
                                    self.update_error_message.parent = self
                                    self.update_error_message.name = 'update_error_message'
                                    self.update_error_message_list_count = None
                                    self.update_malformed_message_count = None
                                    self.update_memory_allocation_fail_count = None
                                    self.update_neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress()
                                    self.update_neighbor_address.parent = self
                                    self.update_vrf_name = None


                                class UpdateNeighborAddress(object):
                                    """
                                    Neighbor address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpnvpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnvplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4mdt_address = None
                                        self.ipv4mvpn_address = None
                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress()
                                        self.ipv4sr_policy_address.parent = self
                                        self.ipv4vpn_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress()
                                        self.ipv6sr_policy_address.parent = self
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_flowspec_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.l2vpn_evpn_address = None
                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnvplsAddress()
                                        self.l2vpnvpls_address.parent = self
                                        self.ls_ls_address = None
                                        self.rt_constraint_address = None


                                    class L2VpnvplsAddress(object):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnvplsAddress']['meta_info']


                                    class L2VpnMspwAddress(object):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnMspwAddress']['meta_info']


                                    class Ipv4SrPolicyAddress(object):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                    class Ipv6SrPolicyAddress(object):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv6_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv6_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-neighbor-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.afi is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv4_flowspec_address is not None:
                                            return True

                                        if self.ipv4_label_address is not None:
                                            return True

                                        if self.ipv4_mcast_address is not None:
                                            return True

                                        if self.ipv4_tunnel_address is not None:
                                            return True

                                        if self.ipv4mdt_address is not None:
                                            return True

                                        if self.ipv4mvpn_address is not None:
                                            return True

                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                            return True

                                        if self.ipv4vpn_address is not None:
                                            return True

                                        if self.ipv4vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv4vpna_mcastddress is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        if self.ipv6_flowspec_address is not None:
                                            return True

                                        if self.ipv6_label_address is not None:
                                            return True

                                        if self.ipv6_mcast_address is not None:
                                            return True

                                        if self.ipv6mvpn_address is not None:
                                            return True

                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                            return True

                                        if self.ipv6vpn_address is not None:
                                            return True

                                        if self.ipv6vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv6vpn_mcast_address is not None:
                                            return True

                                        if self.l2vpn_evpn_address is not None:
                                            return True

                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                            return True

                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                            return True

                                        if self.ls_ls_address is not None:
                                            return True

                                        if self.rt_constraint_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress']['meta_info']


                                class FirstUpdateMalformedTimestamp(object):
                                    """
                                    First malformed message received time\: time
                                    elapsed since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-update-malformed-timestamp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp']['meta_info']


                                class LastUpdateMalformedTimestamp(object):
                                    """
                                    Last malformed message received time\: time
                                    elapsed since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-malformed-timestamp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp']['meta_info']


                                class FirstUpdateMemoryAllocationFailTimestamp(object):
                                    """
                                    First memory allocation failure time\: time
                                    elapsed since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-update-memory-allocation-fail-timestamp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp']['meta_info']


                                class LastUpdateMemoryAllocationFailTimestamp(object):
                                    """
                                    Last memory allocation failure time\: time
                                    elapsed since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-memory-allocation-fail-timestamp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp']['meta_info']


                                class FirstUpdateErrorHandlingResetTimestamp(object):
                                    """
                                    First error\-handling reset time\: time elapsed
                                    since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-update-error-handling-reset-timestamp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp']['meta_info']


                                class LastErrorHandlingResetTimestamp(object):
                                    """
                                    Last error\-handling reset time\: time elapsed
                                    since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-error-handling-reset-timestamp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp']['meta_info']


                                class EstablishmentActionCount(object):
                                    """
                                    Number of occurence of each action type since
                                    
                                    session establishment
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:establishment-action-count'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount']['meta_info']


                                class UpdateErrorMessage(object):
                                    """
                                    List of malformed messages
                                    
                                    .. attribute:: update_attribute_discard_count
                                    
                                    	Discarded attribute count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_error_element
                                    
                                    	Error element list
                                    	**type**\: list of    :py:class:`UpdateErrorElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement>`
                                    
                                    .. attribute:: update_error_final_action
                                    
                                    	Error final action
                                    	**type**\:   :py:class:`BgpBagUpdErrActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdErrActionEnum>`
                                    
                                    .. attribute:: update_error_nlri_address_family
                                    
                                    	NLRI address\-family
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: update_error_nlri_string
                                    
                                    	List of NLRIs in string format
                                    	**type**\:  str
                                    
                                    .. attribute:: update_error_nlri_string_truncated
                                    
                                    	Indicates whether NLRI string was truncated due to lack of space
                                    	**type**\:  bool
                                    
                                    .. attribute:: update_message_data
                                    
                                    	Raw Message data in binary format
                                    	**type**\: list of    :py:class:`UpdateMessageData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData>`
                                    
                                    .. attribute:: update_message_reset_data
                                    
                                    	Reset data
                                    	**type**\:   :py:class:`UpdateMessageResetData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData>`
                                    
                                    .. attribute:: update_message_timestamp
                                    
                                    	Message timestamp\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                    	**type**\:   :py:class:`UpdateMessageTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.update_attribute_discard_count = None
                                        self.update_error_element = YList()
                                        self.update_error_element.parent = self
                                        self.update_error_element.name = 'update_error_element'
                                        self.update_error_final_action = None
                                        self.update_error_nlri_address_family = None
                                        self.update_error_nlri_string = None
                                        self.update_error_nlri_string_truncated = None
                                        self.update_message_data = YList()
                                        self.update_message_data.parent = self
                                        self.update_message_data.name = 'update_message_data'
                                        self.update_message_reset_data = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData()
                                        self.update_message_reset_data.parent = self
                                        self.update_message_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp()
                                        self.update_message_timestamp.parent = self


                                    class UpdateMessageTimestamp(object):
                                        """
                                        Message timestamp\: time elapsed since 00\:00\:00
                                        UTC, January 1, 1970
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-message-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp']['meta_info']


                                    class UpdateMessageResetData(object):
                                        """
                                        Reset data
                                        
                                        .. attribute:: update_error_reset_notification_code
                                        
                                        	Notification code
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_error_reset_notification_data
                                        
                                        	Notification data
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: update_error_reset_notification_data_length
                                        
                                        	Notification data length
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: update_error_reset_notification_sub_code
                                        
                                        	Notification sub code
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: update_error_reset_reason
                                        
                                        	Reset Reason
                                        	**type**\:   :py:class:`BgpResetReasonIndexEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndexEnum>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.update_error_reset_notification_code = None
                                            self.update_error_reset_notification_data = None
                                            self.update_error_reset_notification_data_length = None
                                            self.update_error_reset_notification_sub_code = None
                                            self.update_error_reset_reason = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-message-reset-data'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.update_error_reset_notification_code is not None:
                                                return True

                                            if self.update_error_reset_notification_data is not None:
                                                return True

                                            if self.update_error_reset_notification_data_length is not None:
                                                return True

                                            if self.update_error_reset_notification_sub_code is not None:
                                                return True

                                            if self.update_error_reset_reason is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData']['meta_info']


                                    class UpdateMessageData(object):
                                        """
                                        Raw Message data in binary format
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.entry = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-message-data'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.entry is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData']['meta_info']


                                    class UpdateErrorElement(object):
                                        """
                                        Error element list
                                        
                                        .. attribute:: update_attribute_code
                                        
                                        	Attribute code [RFC4271\: BGP4]
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_attribute_flags
                                        
                                        	Attribute Flags [RFC4271\: BGP4]
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_attribute_length
                                        
                                        	Attribute Length [RFC4271\: BGP4]
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: update_error_action
                                        
                                        	Error action
                                        	**type**\:   :py:class:`BgpBagUpdErrActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdErrActionEnum>`
                                        
                                        .. attribute:: update_error_data
                                        
                                        	Error data
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: update_error_data_length
                                        
                                        	Error data length
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.update_attribute_code = None
                                            self.update_attribute_flags = None
                                            self.update_attribute_length = None
                                            self.update_error_action = None
                                            self.update_error_data = None
                                            self.update_error_data_length = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-error-element'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.update_attribute_code is not None:
                                                return True

                                            if self.update_attribute_flags is not None:
                                                return True

                                            if self.update_attribute_length is not None:
                                                return True

                                            if self.update_error_action is not None:
                                                return True

                                            if self.update_error_data is not None:
                                                return True

                                            if self.update_error_data_length is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-error-message'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.update_attribute_discard_count is not None:
                                            return True

                                        if self.update_error_element is not None:
                                            for child_ref in self.update_error_element:
                                                if child_ref._has_data():
                                                    return True

                                        if self.update_error_final_action is not None:
                                            return True

                                        if self.update_error_nlri_address_family is not None:
                                            return True

                                        if self.update_error_nlri_string is not None:
                                            return True

                                        if self.update_error_nlri_string_truncated is not None:
                                            return True

                                        if self.update_message_data is not None:
                                            for child_ref in self.update_message_data:
                                                if child_ref._has_data():
                                                    return True

                                        if self.update_message_reset_data is not None and self.update_message_reset_data._has_data():
                                            return True

                                        if self.update_message_timestamp is not None and self.update_message_timestamp._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.neighbor_address is None:
                                        raise YPYModelError('Key property neighbor_address is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-inbound-error-neighbor[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address = ' + str(self.neighbor_address) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.neighbor_address is not None:
                                        return True

                                    if self.establishment_action_count is not None:
                                        for child_ref in self.establishment_action_count:
                                            if child_ref._has_data():
                                                return True

                                    if self.establishment_total_update_message_count is not None:
                                        return True

                                    if self.first_update_error_handling_reset_timestamp is not None and self.first_update_error_handling_reset_timestamp._has_data():
                                        return True

                                    if self.first_update_malformed_timestamp is not None and self.first_update_malformed_timestamp._has_data():
                                        return True

                                    if self.first_update_memory_allocation_fail_timestamp is not None and self.first_update_memory_allocation_fail_timestamp._has_data():
                                        return True

                                    if self.last_error_handling_reset_age is not None:
                                        return True

                                    if self.last_error_handling_reset_timestamp is not None and self.last_error_handling_reset_timestamp._has_data():
                                        return True

                                    if self.last_update_malformed_age is not None:
                                        return True

                                    if self.last_update_malformed_timestamp is not None and self.last_update_malformed_timestamp._has_data():
                                        return True

                                    if self.last_update_memory_allocation_fail_age is not None:
                                        return True

                                    if self.last_update_memory_allocation_fail_timestamp is not None and self.last_update_memory_allocation_fail_timestamp._has_data():
                                        return True

                                    if self.total_update_message_count is not None:
                                        return True

                                    if self.update_attribute_discard_count is not None:
                                        return True

                                    if self.update_error_handling_avoid_reset is not None:
                                        return True

                                    if self.update_error_handling_reset_count is not None:
                                        return True

                                    if self.update_error_message is not None:
                                        for child_ref in self.update_error_message:
                                            if child_ref._has_data():
                                                return True

                                    if self.update_error_message_list_count is not None:
                                        return True

                                    if self.update_malformed_message_count is not None:
                                        return True

                                    if self.update_memory_allocation_fail_count is not None:
                                        return True

                                    if self.update_neighbor_address is not None and self.update_neighbor_address._has_data():
                                        return True

                                    if self.update_vrf_name is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-inbound-error-neighbors'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.update_inbound_error_neighbor is not None:
                                    for child_ref in self.update_inbound_error_neighbor:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors']['meta_info']


                        class UpdateInboundFilterNeighbors(object):
                            """
                            Update inbound filtering information for all
                            neighbors
                            
                            .. attribute:: update_inbound_filter_neighbor
                            
                            	Update inbound filtering information for neighbor
                            	**type**\: list of    :py:class:`UpdateInboundFilterNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.update_inbound_filter_neighbor = YList()
                                self.update_inbound_filter_neighbor.parent = self
                                self.update_inbound_filter_neighbor.name = 'update_inbound_filter_neighbor'


                            class UpdateInboundFilterNeighbor(object):
                                """
                                Update inbound filtering information for
                                neighbor
                                
                                .. attribute:: neighbor_address  <key>
                                
                                	Neighbor address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: configured_update_filter_message_buffer_count
                                
                                	Configured Filtered message buffer count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: establishment_total_filter_update_message_count
                                
                                	Total update messages count since session establishment
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: establishment_update_filtered_message_count
                                
                                	Filtered messages count since session establishment
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: first_update_filtered_timestamp
                                
                                	First filtered message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`FirstUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp>`
                                
                                .. attribute:: last_update_filtered_age
                                
                                	Time since last filtered message received event (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_update_filtered_timestamp
                                
                                	Last filtered message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`LastUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp>`
                                
                                .. attribute:: message_update_attribute_filtering_enabled
                                
                                	Attribute filtering is enabled for the current message being parsed
                                	**type**\:  bool
                                
                                .. attribute:: operational_update_attribute_filtering_enabled
                                
                                	Attribute filtering is enabled
                                	**type**\:  bool
                                
                                .. attribute:: operational_update_filter_message_buffer_count
                                
                                	Operational Filtered messages buffer count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_filter_update_message_count
                                
                                	Total update messages count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_attribute_filter_attributes
                                
                                	List of attributes that can be filtered
                                	**type**\: list of    :py:class:`UpdateAttributeFilterAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes>`
                                
                                .. attribute:: update_attribute_filter_group_name
                                
                                	Update attribute\-filter group name
                                	**type**\:  str
                                
                                .. attribute:: update_filter_logging_enabled
                                
                                	Logging is enabled
                                	**type**\:  bool
                                
                                .. attribute:: update_filter_message
                                
                                	List of filtered messages
                                	**type**\: list of    :py:class:`UpdateFilterMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage>`
                                
                                .. attribute:: update_filter_message_buffer_circular
                                
                                	Indicates if the message buffers are circular
                                	**type**\:  bool
                                
                                .. attribute:: update_filter_message_list_count
                                
                                	Filtered messages list count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_filtered_message_count
                                
                                	Filtered messages count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_neighbor_address
                                
                                	Neighbor address
                                	**type**\:   :py:class:`UpdateNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress>`
                                
                                .. attribute:: update_vrf_name
                                
                                	VRF Name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.neighbor_address = None
                                    self.configured_update_filter_message_buffer_count = None
                                    self.establishment_total_filter_update_message_count = None
                                    self.establishment_update_filtered_message_count = None
                                    self.first_update_filtered_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp()
                                    self.first_update_filtered_timestamp.parent = self
                                    self.last_update_filtered_age = None
                                    self.last_update_filtered_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp()
                                    self.last_update_filtered_timestamp.parent = self
                                    self.message_update_attribute_filtering_enabled = None
                                    self.operational_update_attribute_filtering_enabled = None
                                    self.operational_update_filter_message_buffer_count = None
                                    self.total_filter_update_message_count = None
                                    self.update_attribute_filter_attributes = YList()
                                    self.update_attribute_filter_attributes.parent = self
                                    self.update_attribute_filter_attributes.name = 'update_attribute_filter_attributes'
                                    self.update_attribute_filter_group_name = None
                                    self.update_filter_logging_enabled = None
                                    self.update_filter_message = YList()
                                    self.update_filter_message.parent = self
                                    self.update_filter_message.name = 'update_filter_message'
                                    self.update_filter_message_buffer_circular = None
                                    self.update_filter_message_list_count = None
                                    self.update_filtered_message_count = None
                                    self.update_neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress()
                                    self.update_neighbor_address.parent = self
                                    self.update_vrf_name = None


                                class UpdateNeighborAddress(object):
                                    """
                                    Neighbor address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpnvpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnvplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4mdt_address = None
                                        self.ipv4mvpn_address = None
                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress()
                                        self.ipv4sr_policy_address.parent = self
                                        self.ipv4vpn_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress()
                                        self.ipv6sr_policy_address.parent = self
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_flowspec_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.l2vpn_evpn_address = None
                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnvplsAddress()
                                        self.l2vpnvpls_address.parent = self
                                        self.ls_ls_address = None
                                        self.rt_constraint_address = None


                                    class L2VpnvplsAddress(object):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnvplsAddress']['meta_info']


                                    class L2VpnMspwAddress(object):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnMspwAddress']['meta_info']


                                    class Ipv4SrPolicyAddress(object):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                    class Ipv6SrPolicyAddress(object):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv6_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv6_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-neighbor-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.afi is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv4_flowspec_address is not None:
                                            return True

                                        if self.ipv4_label_address is not None:
                                            return True

                                        if self.ipv4_mcast_address is not None:
                                            return True

                                        if self.ipv4_tunnel_address is not None:
                                            return True

                                        if self.ipv4mdt_address is not None:
                                            return True

                                        if self.ipv4mvpn_address is not None:
                                            return True

                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                            return True

                                        if self.ipv4vpn_address is not None:
                                            return True

                                        if self.ipv4vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv4vpna_mcastddress is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        if self.ipv6_flowspec_address is not None:
                                            return True

                                        if self.ipv6_label_address is not None:
                                            return True

                                        if self.ipv6_mcast_address is not None:
                                            return True

                                        if self.ipv6mvpn_address is not None:
                                            return True

                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                            return True

                                        if self.ipv6vpn_address is not None:
                                            return True

                                        if self.ipv6vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv6vpn_mcast_address is not None:
                                            return True

                                        if self.l2vpn_evpn_address is not None:
                                            return True

                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                            return True

                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                            return True

                                        if self.ls_ls_address is not None:
                                            return True

                                        if self.rt_constraint_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress']['meta_info']


                                class FirstUpdateFilteredTimestamp(object):
                                    """
                                    First filtered message received time\: time
                                    elapsed since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-update-filtered-timestamp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp']['meta_info']


                                class LastUpdateFilteredTimestamp(object):
                                    """
                                    Last filtered message received time\: time
                                    elapsed since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-filtered-timestamp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp']['meta_info']


                                class UpdateAttributeFilterAttributes(object):
                                    """
                                    List of attributes that can be filtered
                                    
                                    .. attribute:: establishment_update_filter_match_count
                                    
                                    	Filter match counter since last session establishment
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_update_filter_match_age
                                    
                                    	Time since this attribute was last filtered (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_filter_match_timestamp
                                    
                                    	Last attribute filtered time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                    	**type**\:   :py:class:`LastUpdateFilterMatchTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp>`
                                    
                                    .. attribute:: update_filter_action
                                    
                                    	Filtering action
                                    	**type**\:   :py:class:`BgpBagUpdFilterActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterActionEnum>`
                                    
                                    .. attribute:: update_filter_match_count
                                    
                                    	Filter match counter
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_internal_attribute_code
                                    
                                    	Internal attribute code [RFC4271\: BGP4]
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.establishment_update_filter_match_count = None
                                        self.last_update_filter_match_age = None
                                        self.last_update_filter_match_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp()
                                        self.last_update_filter_match_timestamp.parent = self
                                        self.update_filter_action = None
                                        self.update_filter_match_count = None
                                        self.update_internal_attribute_code = None


                                    class LastUpdateFilterMatchTimestamp(object):
                                        """
                                        Last attribute filtered time\: time elapsed since
                                        00\:00\:00 UTC, January 1, 1970
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-filter-match-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-attribute-filter-attributes'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.establishment_update_filter_match_count is not None:
                                            return True

                                        if self.last_update_filter_match_age is not None:
                                            return True

                                        if self.last_update_filter_match_timestamp is not None and self.last_update_filter_match_timestamp._has_data():
                                            return True

                                        if self.update_filter_action is not None:
                                            return True

                                        if self.update_filter_match_count is not None:
                                            return True

                                        if self.update_internal_attribute_code is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes']['meta_info']


                                class UpdateFilterMessage(object):
                                    """
                                    List of filtered messages
                                    
                                    .. attribute:: update_filter_element
                                    
                                    	Filtering element list
                                    	**type**\: list of    :py:class:`UpdateFilterElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement>`
                                    
                                    .. attribute:: update_filter_final_action
                                    
                                    	Filtering final action
                                    	**type**\:   :py:class:`BgpBagUpdFilterActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterActionEnum>`
                                    
                                    .. attribute:: update_filter_message_data
                                    
                                    	Raw Message data in binary format
                                    	**type**\: list of    :py:class:`UpdateFilterMessageData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData>`
                                    
                                    .. attribute:: update_filter_message_timestamp
                                    
                                    	Message timestamp\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                    	**type**\:   :py:class:`UpdateFilterMessageTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp>`
                                    
                                    .. attribute:: update_filter_nlri_address_family
                                    
                                    	NLRI address\-family
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: update_filter_nlri_string
                                    
                                    	List of NLRIs in string format
                                    	**type**\:  str
                                    
                                    .. attribute:: update_filter_nlri_string_truncated
                                    
                                    	Indicates whether NLRI string was truncated due to lack of space
                                    	**type**\:  bool
                                    
                                    .. attribute:: update_filtered_attribute_count
                                    
                                    	Filtered attributes count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.update_filter_element = YList()
                                        self.update_filter_element.parent = self
                                        self.update_filter_element.name = 'update_filter_element'
                                        self.update_filter_final_action = None
                                        self.update_filter_message_data = YList()
                                        self.update_filter_message_data.parent = self
                                        self.update_filter_message_data.name = 'update_filter_message_data'
                                        self.update_filter_message_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp()
                                        self.update_filter_message_timestamp.parent = self
                                        self.update_filter_nlri_address_family = None
                                        self.update_filter_nlri_string = None
                                        self.update_filter_nlri_string_truncated = None
                                        self.update_filtered_attribute_count = None


                                    class UpdateFilterMessageTimestamp(object):
                                        """
                                        Message timestamp\: time elapsed since 00\:00\:00
                                        UTC, January 1, 1970
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-filter-message-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp']['meta_info']


                                    class UpdateFilterMessageData(object):
                                        """
                                        Raw Message data in binary format
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.entry = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-filter-message-data'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.entry is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData']['meta_info']


                                    class UpdateFilterElement(object):
                                        """
                                        Filtering element list
                                        
                                        .. attribute:: update_attribute_code
                                        
                                        	Attribute code [RFC4271\: BGP4]
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_attribute_flags
                                        
                                        	Attribute Flags [RFC4271\: BGP4]
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_filter_action
                                        
                                        	Filtering action
                                        	**type**\:   :py:class:`BgpBagUpdFilterActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterActionEnum>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.update_attribute_code = None
                                            self.update_attribute_flags = None
                                            self.update_filter_action = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-filter-element'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.update_attribute_code is not None:
                                                return True

                                            if self.update_attribute_flags is not None:
                                                return True

                                            if self.update_filter_action is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-filter-message'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.update_filter_element is not None:
                                            for child_ref in self.update_filter_element:
                                                if child_ref._has_data():
                                                    return True

                                        if self.update_filter_final_action is not None:
                                            return True

                                        if self.update_filter_message_data is not None:
                                            for child_ref in self.update_filter_message_data:
                                                if child_ref._has_data():
                                                    return True

                                        if self.update_filter_message_timestamp is not None and self.update_filter_message_timestamp._has_data():
                                            return True

                                        if self.update_filter_nlri_address_family is not None:
                                            return True

                                        if self.update_filter_nlri_string is not None:
                                            return True

                                        if self.update_filter_nlri_string_truncated is not None:
                                            return True

                                        if self.update_filtered_attribute_count is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.neighbor_address is None:
                                        raise YPYModelError('Key property neighbor_address is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-inbound-filter-neighbor[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address = ' + str(self.neighbor_address) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.neighbor_address is not None:
                                        return True

                                    if self.configured_update_filter_message_buffer_count is not None:
                                        return True

                                    if self.establishment_total_filter_update_message_count is not None:
                                        return True

                                    if self.establishment_update_filtered_message_count is not None:
                                        return True

                                    if self.first_update_filtered_timestamp is not None and self.first_update_filtered_timestamp._has_data():
                                        return True

                                    if self.last_update_filtered_age is not None:
                                        return True

                                    if self.last_update_filtered_timestamp is not None and self.last_update_filtered_timestamp._has_data():
                                        return True

                                    if self.message_update_attribute_filtering_enabled is not None:
                                        return True

                                    if self.operational_update_attribute_filtering_enabled is not None:
                                        return True

                                    if self.operational_update_filter_message_buffer_count is not None:
                                        return True

                                    if self.total_filter_update_message_count is not None:
                                        return True

                                    if self.update_attribute_filter_attributes is not None:
                                        for child_ref in self.update_attribute_filter_attributes:
                                            if child_ref._has_data():
                                                return True

                                    if self.update_attribute_filter_group_name is not None:
                                        return True

                                    if self.update_filter_logging_enabled is not None:
                                        return True

                                    if self.update_filter_message is not None:
                                        for child_ref in self.update_filter_message:
                                            if child_ref._has_data():
                                                return True

                                    if self.update_filter_message_buffer_circular is not None:
                                        return True

                                    if self.update_filter_message_list_count is not None:
                                        return True

                                    if self.update_filtered_message_count is not None:
                                        return True

                                    if self.update_neighbor_address is not None and self.update_neighbor_address._has_data():
                                        return True

                                    if self.update_vrf_name is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-inbound-filter-neighbors'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.update_inbound_filter_neighbor is not None:
                                    for child_ref in self.update_inbound_filter_neighbor:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors']['meta_info']


                        class Bmp(object):
                            """
                            BMP related Operational Data
                            
                            .. attribute:: server_neighbors
                            
                            	Table of Neighbors for a BMP Server
                            	**type**\:   :py:class:`ServerNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors>`
                            
                            .. attribute:: server_summaries
                            
                            	Table of BMP Servers
                            	**type**\:   :py:class:`ServerSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.server_neighbors = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors()
                                self.server_neighbors.parent = self
                                self.server_summaries = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries()
                                self.server_summaries.parent = self


                            class ServerSummaries(object):
                                """
                                Table of BMP Servers
                                
                                .. attribute:: server_summary
                                
                                	Summary Information about BMP server
                                	**type**\: list of    :py:class:`ServerSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.server_summary = YList()
                                    self.server_summary.parent = self
                                    self.server_summary.name = 'server_summary'


                                class ServerSummary(object):
                                    """
                                    Summary Information about BMP server
                                    
                                    .. attribute:: server_id  <key>
                                    
                                    	BMP Server ID
                                    	**type**\:  int
                                    
                                    	**range:** 1..8
                                    
                                    .. attribute:: bmp_bytes_written_tcp
                                    
                                    	Total bytes sent to TCP
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: bmp_init_msg_count
                                    
                                    	Number of Initiation Msgs sent by this BMP Server
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_messages_wdraw_discarded
                                    
                                    	Total bmpQ wdraw msgs discarded because of peer down
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_peer_msg_drop_count
                                    
                                    	Total number of messages dropped
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_peer_msg_pending_count
                                    
                                    	Total number of bmpQ msgs pending
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_peer_msg_pending_count_hwts
                                    
                                    	Total bmpQ msgs pending max time
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmp_peer_msg_pending_count_max
                                    
                                    	Total bmpQ msgs pending max
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_per_peer_msg_count
                                    
                                    	Total number of per peer messages sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_per_peer_msg_route_mon_count
                                    
                                    	Total number of per peer route mon messages sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_pfx_wdraw_discarded
                                    
                                    	Total bmpQ wdraw pfxes discarded because of peer down
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_send_version
                                    
                                    	Table Version that this BMP server has caught  upto
                                    	**type**\: list of    :py:class:`BmpSendVersion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpSendVersion>`
                                    
                                    .. attribute:: bmp_server_host_name
                                    
                                    	BMP Server Hostname
                                    	**type**\:  str
                                    
                                    .. attribute:: bmp_server_id
                                    
                                    	BMP Server ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: bmp_server_is_flapping
                                    
                                    	Connection to the BMP server Flapping
                                    	**type**\:  bool
                                    
                                    .. attribute:: bmp_server_last_discon_time
                                    
                                    	Timespec of Last Disconnect event received from BMP server
                                    	**type**\:   :py:class:`BmpServerLastDisconTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime>`
                                    
                                    .. attribute:: bmp_server_nbr_count
                                    
                                    	Neighbor count for the BMP Server
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_server_port
                                    
                                    	BMP Server Port Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_server_state
                                    
                                    	Connection state of the BMP server
                                    	**type**\:   :py:class:`BgpBmpStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBmpStateEnum>`
                                    
                                    .. attribute:: bmp_server_state_age
                                    
                                    	Age of current state of BMP Server
                                    	**type**\:   :py:class:`BmpServerStateAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge>`
                                    
                                    .. attribute:: bmp_server_state_time_spec
                                    
                                    	Timespec of current state of BMP Server
                                    	**type**\:   :py:class:`BmpServerStateTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec>`
                                    
                                    .. attribute:: bmp_status_report_count
                                    
                                    	Number of Status ReportMessages sent by this BMP Server
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_termination_msg_count
                                    
                                    	Number of Termination Messages sent by this BMP Server
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_update_mode
                                    
                                    	Update sending mode configured for this BMP server
                                    	**type**\:   :py:class:`BgpBmpUpdModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBmpUpdModeEnum>`
                                    
                                    .. attribute:: bmp_vrf_id
                                    
                                    	VRF ID for the vrf name configured
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_vrf_name
                                    
                                    	VRF Name configured
                                    	**type**\:  str
                                    
                                    .. attribute:: bmpq_last_all_write_pulse_sent_time
                                    
                                    	Last BMPQ write pulse Sent for all BMP servers 
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmpq_last_write_pulse_cb_time
                                    
                                    	Last BMPQ write pulse callback time
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmpq_last_write_pulse_sent_time
                                    
                                    	Last BMPQ write pulse Sent time
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmpr_mon_upd_messages
                                    
                                    	Total bmpQ update msgs 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmpr_mon_update_gen_time
                                    
                                    	Time spent in update generation(milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: bmpr_mon_wdraw_messages
                                    
                                    	Total bmpQ withdraw msgs 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_update_count
                                    
                                    	Number of path update sent 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_update_drop
                                    
                                    	Number of path update drop 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_withdraw_count
                                    
                                    	Number of path wdraw sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_withdraw_drop
                                    
                                    	Number of path wdraw drop 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_keep_alive_interval
                                    
                                    	TCP Keep alive interval configured
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_last_write_cb_time
                                    
                                    	Last TCP Write CB time
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tcp_last_write_result
                                    
                                    	Last TCP Socket write status
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_last_write_time
                                    
                                    	Last TCP Write time
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tcp_maximum_segment_size
                                    
                                    	TCP Maximum Segments size configured
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_write_cb_pending
                                    
                                    	Are we waiting for TCP write callback ?
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_write_time
                                    
                                    	Time spent processing sending msg to TCP(milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: tos_type
                                    
                                    	Precedence (0) or DSCP (1) type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_value
                                    
                                    	Precedence or DSCP value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_source_address
                                    
                                    	Address of Interface configured as Update Source
                                    	**type**\:   :py:class:`UpdateSourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress>`
                                    
                                    .. attribute:: update_source_interface_name
                                    
                                    	Interface configured as Update Source
                                    	**type**\:  str
                                    
                                    .. attribute:: update_source_vrf_id
                                    
                                    	VRF ID of interface configured as Update Source
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.server_id = None
                                        self.bmp_bytes_written_tcp = None
                                        self.bmp_init_msg_count = None
                                        self.bmp_messages_wdraw_discarded = None
                                        self.bmp_peer_msg_drop_count = None
                                        self.bmp_peer_msg_pending_count = None
                                        self.bmp_peer_msg_pending_count_hwts = None
                                        self.bmp_peer_msg_pending_count_max = None
                                        self.bmp_per_peer_msg_count = None
                                        self.bmp_per_peer_msg_route_mon_count = None
                                        self.bmp_pfx_wdraw_discarded = None
                                        self.bmp_send_version = YList()
                                        self.bmp_send_version.parent = self
                                        self.bmp_send_version.name = 'bmp_send_version'
                                        self.bmp_server_host_name = None
                                        self.bmp_server_id = None
                                        self.bmp_server_is_flapping = None
                                        self.bmp_server_last_discon_time = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime()
                                        self.bmp_server_last_discon_time.parent = self
                                        self.bmp_server_nbr_count = None
                                        self.bmp_server_port = None
                                        self.bmp_server_state = None
                                        self.bmp_server_state_age = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge()
                                        self.bmp_server_state_age.parent = self
                                        self.bmp_server_state_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec()
                                        self.bmp_server_state_time_spec.parent = self
                                        self.bmp_status_report_count = None
                                        self.bmp_termination_msg_count = None
                                        self.bmp_update_mode = None
                                        self.bmp_vrf_id = None
                                        self.bmp_vrf_name = None
                                        self.bmpq_last_all_write_pulse_sent_time = None
                                        self.bmpq_last_write_pulse_cb_time = None
                                        self.bmpq_last_write_pulse_sent_time = None
                                        self.bmpr_mon_upd_messages = None
                                        self.bmpr_mon_update_gen_time = None
                                        self.bmpr_mon_wdraw_messages = None
                                        self.path_update_count = None
                                        self.path_update_drop = None
                                        self.path_withdraw_count = None
                                        self.path_withdraw_drop = None
                                        self.tcp_keep_alive_interval = None
                                        self.tcp_last_write_cb_time = None
                                        self.tcp_last_write_result = None
                                        self.tcp_last_write_time = None
                                        self.tcp_maximum_segment_size = None
                                        self.tcp_write_cb_pending = None
                                        self.tcp_write_time = None
                                        self.tos_type = None
                                        self.tos_value = None
                                        self.update_source_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress()
                                        self.update_source_address.parent = self
                                        self.update_source_interface_name = None
                                        self.update_source_vrf_id = None


                                    class BmpServerStateAge(object):
                                        """
                                        Age of current state of BMP Server
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-server-state-age'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge']['meta_info']


                                    class BmpServerStateTimeSpec(object):
                                        """
                                        Timespec of current state of BMP Server
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-server-state-time-spec'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec']['meta_info']


                                    class BmpServerLastDisconTime(object):
                                        """
                                        Timespec of Last Disconnect event received from
                                        BMP server
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-server-last-discon-time'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime']['meta_info']


                                    class UpdateSourceAddress(object):
                                        """
                                        Address of Interface configured as Update Source
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-source-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress']['meta_info']


                                    class BmpSendVersion(object):
                                        """
                                        Table Version that this BMP server has caught
                                        
                                        upto
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.entry = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-send-version'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.entry is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpSendVersion']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.server_id is None:
                                            raise YPYModelError('Key property server_id is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:server-summary[Cisco-IOS-XR-ipv4-bgp-oper:server-id = ' + str(self.server_id) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.server_id is not None:
                                            return True

                                        if self.bmp_bytes_written_tcp is not None:
                                            return True

                                        if self.bmp_init_msg_count is not None:
                                            return True

                                        if self.bmp_messages_wdraw_discarded is not None:
                                            return True

                                        if self.bmp_peer_msg_drop_count is not None:
                                            return True

                                        if self.bmp_peer_msg_pending_count is not None:
                                            return True

                                        if self.bmp_peer_msg_pending_count_hwts is not None:
                                            return True

                                        if self.bmp_peer_msg_pending_count_max is not None:
                                            return True

                                        if self.bmp_per_peer_msg_count is not None:
                                            return True

                                        if self.bmp_per_peer_msg_route_mon_count is not None:
                                            return True

                                        if self.bmp_pfx_wdraw_discarded is not None:
                                            return True

                                        if self.bmp_send_version is not None:
                                            for child_ref in self.bmp_send_version:
                                                if child_ref._has_data():
                                                    return True

                                        if self.bmp_server_host_name is not None:
                                            return True

                                        if self.bmp_server_id is not None:
                                            return True

                                        if self.bmp_server_is_flapping is not None:
                                            return True

                                        if self.bmp_server_last_discon_time is not None and self.bmp_server_last_discon_time._has_data():
                                            return True

                                        if self.bmp_server_nbr_count is not None:
                                            return True

                                        if self.bmp_server_port is not None:
                                            return True

                                        if self.bmp_server_state is not None:
                                            return True

                                        if self.bmp_server_state_age is not None and self.bmp_server_state_age._has_data():
                                            return True

                                        if self.bmp_server_state_time_spec is not None and self.bmp_server_state_time_spec._has_data():
                                            return True

                                        if self.bmp_status_report_count is not None:
                                            return True

                                        if self.bmp_termination_msg_count is not None:
                                            return True

                                        if self.bmp_update_mode is not None:
                                            return True

                                        if self.bmp_vrf_id is not None:
                                            return True

                                        if self.bmp_vrf_name is not None:
                                            return True

                                        if self.bmpq_last_all_write_pulse_sent_time is not None:
                                            return True

                                        if self.bmpq_last_write_pulse_cb_time is not None:
                                            return True

                                        if self.bmpq_last_write_pulse_sent_time is not None:
                                            return True

                                        if self.bmpr_mon_upd_messages is not None:
                                            return True

                                        if self.bmpr_mon_update_gen_time is not None:
                                            return True

                                        if self.bmpr_mon_wdraw_messages is not None:
                                            return True

                                        if self.path_update_count is not None:
                                            return True

                                        if self.path_update_drop is not None:
                                            return True

                                        if self.path_withdraw_count is not None:
                                            return True

                                        if self.path_withdraw_drop is not None:
                                            return True

                                        if self.tcp_keep_alive_interval is not None:
                                            return True

                                        if self.tcp_last_write_cb_time is not None:
                                            return True

                                        if self.tcp_last_write_result is not None:
                                            return True

                                        if self.tcp_last_write_time is not None:
                                            return True

                                        if self.tcp_maximum_segment_size is not None:
                                            return True

                                        if self.tcp_write_cb_pending is not None:
                                            return True

                                        if self.tcp_write_time is not None:
                                            return True

                                        if self.tos_type is not None:
                                            return True

                                        if self.tos_value is not None:
                                            return True

                                        if self.update_source_address is not None and self.update_source_address._has_data():
                                            return True

                                        if self.update_source_interface_name is not None:
                                            return True

                                        if self.update_source_vrf_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:server-summaries'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.server_summary is not None:
                                        for child_ref in self.server_summary:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries']['meta_info']


                            class ServerNeighbors(object):
                                """
                                Table of Neighbors for a BMP Server
                                
                                .. attribute:: server_neighbor
                                
                                	BMP Server under which neighbor info are needed
                                	**type**\: list of    :py:class:`ServerNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.server_neighbor = YList()
                                    self.server_neighbor.parent = self
                                    self.server_neighbor.name = 'server_neighbor'


                                class ServerNeighbor(object):
                                    """
                                    BMP Server under which neighbor info are
                                    needed
                                    
                                    .. attribute:: server_id  <key>
                                    
                                    	BMP Server ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: monitored_neighbors
                                    
                                    	List of Neighbors under which BMP Server is confgiured
                                    	**type**\:   :py:class:`MonitoredNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.server_id = None
                                        self.monitored_neighbors = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors()
                                        self.monitored_neighbors.parent = self


                                    class MonitoredNeighbors(object):
                                        """
                                        List of Neighbors under which BMP Server is
                                        confgiured
                                        
                                        .. attribute:: monitored_neighbor
                                        
                                        	Information about a neighbor monitored by BMP server
                                        	**type**\: list of    :py:class:`MonitoredNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.monitored_neighbor = YList()
                                            self.monitored_neighbor.parent = self
                                            self.monitored_neighbor.name = 'monitored_neighbor'


                                        class MonitoredNeighbor(object):
                                            """
                                            Information about a neighbor monitored by
                                            BMP server
                                            
                                            .. attribute:: neighbor_address  <key>
                                            
                                            	Neighbor address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bmp_neighbor_address
                                            
                                            	Address of Nbr that logs to BMP server
                                            	**type**\:   :py:class:`BmpNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress>`
                                            
                                            .. attribute:: bmp_neighbor_msg_dropped
                                            
                                            	Number of messages dropped sent from this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_msg_pending
                                            
                                            	Number of messages pending to be sent to BMP Server from this Neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_path_update_drop
                                            
                                            	Number of path update drop 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_path_update_sent
                                            
                                            	Number of Path UpdateMessages sent
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_path_withdraw_drop
                                            
                                            	Number of path wdraw drop 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_path_withdraw_sent
                                            
                                            	Number of Path WithdrawMessages sent
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_peer_down_sent
                                            
                                            	Number of Peer DOWN Messages sent from this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_peer_up_sent
                                            
                                            	Number of Peer UP Messages sent from this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_route_monitor_sent
                                            
                                            	Number of Route Monitor Messages sent
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_upd_msg_sent
                                            
                                            	Number of update message sent
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_wdraw_msg_sent
                                            
                                            	Number of withdraw message sent
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.neighbor_address = None
                                                self.bmp_neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress()
                                                self.bmp_neighbor_address.parent = self
                                                self.bmp_neighbor_msg_dropped = None
                                                self.bmp_neighbor_msg_pending = None
                                                self.bmp_neighbor_path_update_drop = None
                                                self.bmp_neighbor_path_update_sent = None
                                                self.bmp_neighbor_path_withdraw_drop = None
                                                self.bmp_neighbor_path_withdraw_sent = None
                                                self.bmp_neighbor_peer_down_sent = None
                                                self.bmp_neighbor_peer_up_sent = None
                                                self.bmp_neighbor_route_monitor_sent = None
                                                self.bmp_neighbor_upd_msg_sent = None
                                                self.bmp_neighbor_wdraw_msg_sent = None


                                            class BmpNeighborAddress(object):
                                                """
                                                Address of Nbr that logs to BMP server
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.neighbor_address is None:
                                                    raise YPYModelError('Key property neighbor_address is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:monitored-neighbor[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address = ' + str(self.neighbor_address) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.neighbor_address is not None:
                                                    return True

                                                if self.bmp_neighbor_address is not None and self.bmp_neighbor_address._has_data():
                                                    return True

                                                if self.bmp_neighbor_msg_dropped is not None:
                                                    return True

                                                if self.bmp_neighbor_msg_pending is not None:
                                                    return True

                                                if self.bmp_neighbor_path_update_drop is not None:
                                                    return True

                                                if self.bmp_neighbor_path_update_sent is not None:
                                                    return True

                                                if self.bmp_neighbor_path_withdraw_drop is not None:
                                                    return True

                                                if self.bmp_neighbor_path_withdraw_sent is not None:
                                                    return True

                                                if self.bmp_neighbor_peer_down_sent is not None:
                                                    return True

                                                if self.bmp_neighbor_peer_up_sent is not None:
                                                    return True

                                                if self.bmp_neighbor_route_monitor_sent is not None:
                                                    return True

                                                if self.bmp_neighbor_upd_msg_sent is not None:
                                                    return True

                                                if self.bmp_neighbor_wdraw_msg_sent is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:monitored-neighbors'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.monitored_neighbor is not None:
                                                for child_ref in self.monitored_neighbor:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.server_id is None:
                                            raise YPYModelError('Key property server_id is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:server-neighbor[Cisco-IOS-XR-ipv4-bgp-oper:server-id = ' + str(self.server_id) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.server_id is not None:
                                            return True

                                        if self.monitored_neighbors is not None and self.monitored_neighbors._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:server-neighbors'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.server_neighbor is not None:
                                        for child_ref in self.server_neighbor:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.server_neighbors is not None and self.server_neighbors._has_data():
                                    return True

                                if self.server_summaries is not None and self.server_summaries._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp']['meta_info']


                        class ProcessInfo(object):
                            """
                            A Process instance table entry
                            
                            .. attribute:: global_
                            
                            	Global information
                            	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_>`
                            
                            .. attribute:: performance_statistics
                            
                            	Performance statistics
                            	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics>`
                            
                            .. attribute:: process_instance
                            
                            	ID for the BGP process instance
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:   :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Vrf_>`
                            
                            .. attribute:: vrf_name
                            
                            	Name of the VRF
                            	**type**\:  str
                            
                            .. attribute:: vrf_totals
                            
                            	per VRF counts aggregated across all VRFs
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.global_ = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_()
                                self.global_.parent = self
                                self.performance_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics()
                                self.performance_statistics.parent = self
                                self.process_instance = None
                                self.vrf = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Vrf_()
                                self.vrf.parent = self
                                self.vrf_name = None
                                self.vrf_totals = None


                            class Global_(object):
                                """
                                Global information
                                
                                .. attribute:: as_path_entries_memory
                                
                                	Memory (in bytes) used by AS\-path entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: as_path_entry_count
                                
                                	Number of AS\-path entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: attr_set_entry_count
                                
                                	Number of ATTRSET entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: attr_set_memory
                                
                                	Memory (in bytes) used by ATTRSET entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: bmp_pool_alloc_count
                                
                                	bmp pool alloc count
                                	**type**\: list of    :py:class:`BmpPoolAllocCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.BmpPoolAllocCount>`
                                
                                .. attribute:: bmp_pool_free_count
                                
                                	bmp pool free count
                                	**type**\: list of    :py:class:`BmpPoolFreeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.BmpPoolFreeCount>`
                                
                                .. attribute:: bmp_pool_size
                                
                                	bmp pool size
                                	**type**\: list of    :py:class:`BmpPoolSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.BmpPoolSize>`
                                
                                .. attribute:: community_entry_count
                                
                                	Number of community entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: community_memory
                                
                                	Memory (in bytes) used by community entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: established_neighbors_count_total
                                
                                	Total umber of established neighbors
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: extended_community_entry_count
                                
                                	Number of extended community entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: extended_community_memory
                                
                                	Memory (in bytes) used by extended community entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: lindex_entry_count
                                
                                	Number of LINDEX entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lindex_memory
                                
                                	Memory (in bytes) used by LINDEX entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: local_as
                                
                                	Local autonomous system number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsattr_entry_count
                                
                                	Number of LASATTR entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsattr_memory
                                
                                	Memory (in bytes) used by LSATTR entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: msg_log_pool_alloc_count
                                
                                	msg log pool alloc count
                                	**type**\: list of    :py:class:`MsgLogPoolAllocCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.MsgLogPoolAllocCount>`
                                
                                .. attribute:: msg_log_pool_free_count
                                
                                	msg log pool free count
                                	**type**\: list of    :py:class:`MsgLogPoolFreeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.MsgLogPoolFreeCount>`
                                
                                .. attribute:: msg_log_pool_size
                                
                                	msg log pool size
                                	**type**\: list of    :py:class:`MsgLogPoolSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.MsgLogPoolSize>`
                                
                                .. attribute:: neighbors_count_total
                                
                                	Total number of neighbors
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nexthop_count
                                
                                	Number of nexthop attribute info entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nexthop_memory
                                
                                	Memory (in bytes) used by nexthop attribute info entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: path_attribute_memory
                                
                                	Memory (bytes) used by path attribute entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: path_attributes_entry_count
                                
                                	No. of path attribute entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pe_distinguisher_label_entry_count
                                
                                	Number of PE distinguisher label entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pe_distinguisher_label_memory
                                
                                	Memory (in bytes) used by PE distinguisher labels entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: pool_alloc_count
                                
                                	pool alloc count
                                	**type**\: list of    :py:class:`PoolAllocCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.PoolAllocCount>`
                                
                                .. attribute:: pool_free_count
                                
                                	pool free count
                                	**type**\: list of    :py:class:`PoolFreeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.PoolFreeCount>`
                                
                                .. attribute:: pool_size
                                
                                	pool size
                                	**type**\: list of    :py:class:`PoolSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.PoolSize>`
                                
                                .. attribute:: ppmp_entry_count
                                
                                	Number of PPMP entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ppmp_memory
                                
                                	Memory (in bytes) used by PPMP entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: process_instance_node
                                
                                	Node the process instance is on
                                	**type**\:  str
                                
                                .. attribute:: pta_entry_count
                                
                                	Number of PTA entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pta_memory
                                
                                	Memory (in bytes) used by PTA entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: restart_count
                                
                                	No. of times BGP has started
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ribrnh_entry_count
                                
                                	Number of RIBRNH entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ribrnh_memory
                                
                                	Memory (in bytes) used by RIBRNH entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: route_reflector_memory
                                
                                	Memory (in bytes) used by route reflector info entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: route_reflectors
                                
                                	Number of route reflector info entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sn_num_non_dflt_vrf_nbrs
                                
                                	sn num non dflt vrf nbrs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sn_num_non_dflt_vrf_nbrs_estab
                                
                                	sn num non dflt vrf nbrs estab
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_vrf_count
                                
                                	total vrf count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tunnel_encap_entry_count
                                
                                	Number of Tunnel encap entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tunnel_encap_memory
                                
                                	Memory (in bytes) used by tunnel encap entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.as_path_entries_memory = None
                                    self.as_path_entry_count = None
                                    self.attr_set_entry_count = None
                                    self.attr_set_memory = None
                                    self.bmp_pool_alloc_count = YList()
                                    self.bmp_pool_alloc_count.parent = self
                                    self.bmp_pool_alloc_count.name = 'bmp_pool_alloc_count'
                                    self.bmp_pool_free_count = YList()
                                    self.bmp_pool_free_count.parent = self
                                    self.bmp_pool_free_count.name = 'bmp_pool_free_count'
                                    self.bmp_pool_size = YList()
                                    self.bmp_pool_size.parent = self
                                    self.bmp_pool_size.name = 'bmp_pool_size'
                                    self.community_entry_count = None
                                    self.community_memory = None
                                    self.established_neighbors_count_total = None
                                    self.extended_community_entry_count = None
                                    self.extended_community_memory = None
                                    self.lindex_entry_count = None
                                    self.lindex_memory = None
                                    self.local_as = None
                                    self.lsattr_entry_count = None
                                    self.lsattr_memory = None
                                    self.msg_log_pool_alloc_count = YList()
                                    self.msg_log_pool_alloc_count.parent = self
                                    self.msg_log_pool_alloc_count.name = 'msg_log_pool_alloc_count'
                                    self.msg_log_pool_free_count = YList()
                                    self.msg_log_pool_free_count.parent = self
                                    self.msg_log_pool_free_count.name = 'msg_log_pool_free_count'
                                    self.msg_log_pool_size = YList()
                                    self.msg_log_pool_size.parent = self
                                    self.msg_log_pool_size.name = 'msg_log_pool_size'
                                    self.neighbors_count_total = None
                                    self.nexthop_count = None
                                    self.nexthop_memory = None
                                    self.path_attribute_memory = None
                                    self.path_attributes_entry_count = None
                                    self.pe_distinguisher_label_entry_count = None
                                    self.pe_distinguisher_label_memory = None
                                    self.pool_alloc_count = YList()
                                    self.pool_alloc_count.parent = self
                                    self.pool_alloc_count.name = 'pool_alloc_count'
                                    self.pool_free_count = YList()
                                    self.pool_free_count.parent = self
                                    self.pool_free_count.name = 'pool_free_count'
                                    self.pool_size = YList()
                                    self.pool_size.parent = self
                                    self.pool_size.name = 'pool_size'
                                    self.ppmp_entry_count = None
                                    self.ppmp_memory = None
                                    self.process_instance_node = None
                                    self.pta_entry_count = None
                                    self.pta_memory = None
                                    self.restart_count = None
                                    self.ribrnh_entry_count = None
                                    self.ribrnh_memory = None
                                    self.route_reflector_memory = None
                                    self.route_reflectors = None
                                    self.sn_num_non_dflt_vrf_nbrs = None
                                    self.sn_num_non_dflt_vrf_nbrs_estab = None
                                    self.total_vrf_count = None
                                    self.tunnel_encap_entry_count = None
                                    self.tunnel_encap_memory = None


                                class PoolSize(object):
                                    """
                                    pool size
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pool-size'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.PoolSize']['meta_info']


                                class PoolAllocCount(object):
                                    """
                                    pool alloc count
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pool-alloc-count'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.PoolAllocCount']['meta_info']


                                class PoolFreeCount(object):
                                    """
                                    pool free count
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pool-free-count'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.PoolFreeCount']['meta_info']


                                class MsgLogPoolSize(object):
                                    """
                                    msg log pool size
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:msg-log-pool-size'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.MsgLogPoolSize']['meta_info']


                                class MsgLogPoolAllocCount(object):
                                    """
                                    msg log pool alloc count
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:msg-log-pool-alloc-count'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.MsgLogPoolAllocCount']['meta_info']


                                class MsgLogPoolFreeCount(object):
                                    """
                                    msg log pool free count
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:msg-log-pool-free-count'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.MsgLogPoolFreeCount']['meta_info']


                                class BmpPoolSize(object):
                                    """
                                    bmp pool size
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-pool-size'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.BmpPoolSize']['meta_info']


                                class BmpPoolAllocCount(object):
                                    """
                                    bmp pool alloc count
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-pool-alloc-count'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.BmpPoolAllocCount']['meta_info']


                                class BmpPoolFreeCount(object):
                                    """
                                    bmp pool free count
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-pool-free-count'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_.BmpPoolFreeCount']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:global'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.as_path_entries_memory is not None:
                                        return True

                                    if self.as_path_entry_count is not None:
                                        return True

                                    if self.attr_set_entry_count is not None:
                                        return True

                                    if self.attr_set_memory is not None:
                                        return True

                                    if self.bmp_pool_alloc_count is not None:
                                        for child_ref in self.bmp_pool_alloc_count:
                                            if child_ref._has_data():
                                                return True

                                    if self.bmp_pool_free_count is not None:
                                        for child_ref in self.bmp_pool_free_count:
                                            if child_ref._has_data():
                                                return True

                                    if self.bmp_pool_size is not None:
                                        for child_ref in self.bmp_pool_size:
                                            if child_ref._has_data():
                                                return True

                                    if self.community_entry_count is not None:
                                        return True

                                    if self.community_memory is not None:
                                        return True

                                    if self.established_neighbors_count_total is not None:
                                        return True

                                    if self.extended_community_entry_count is not None:
                                        return True

                                    if self.extended_community_memory is not None:
                                        return True

                                    if self.lindex_entry_count is not None:
                                        return True

                                    if self.lindex_memory is not None:
                                        return True

                                    if self.local_as is not None:
                                        return True

                                    if self.lsattr_entry_count is not None:
                                        return True

                                    if self.lsattr_memory is not None:
                                        return True

                                    if self.msg_log_pool_alloc_count is not None:
                                        for child_ref in self.msg_log_pool_alloc_count:
                                            if child_ref._has_data():
                                                return True

                                    if self.msg_log_pool_free_count is not None:
                                        for child_ref in self.msg_log_pool_free_count:
                                            if child_ref._has_data():
                                                return True

                                    if self.msg_log_pool_size is not None:
                                        for child_ref in self.msg_log_pool_size:
                                            if child_ref._has_data():
                                                return True

                                    if self.neighbors_count_total is not None:
                                        return True

                                    if self.nexthop_count is not None:
                                        return True

                                    if self.nexthop_memory is not None:
                                        return True

                                    if self.path_attribute_memory is not None:
                                        return True

                                    if self.path_attributes_entry_count is not None:
                                        return True

                                    if self.pe_distinguisher_label_entry_count is not None:
                                        return True

                                    if self.pe_distinguisher_label_memory is not None:
                                        return True

                                    if self.pool_alloc_count is not None:
                                        for child_ref in self.pool_alloc_count:
                                            if child_ref._has_data():
                                                return True

                                    if self.pool_free_count is not None:
                                        for child_ref in self.pool_free_count:
                                            if child_ref._has_data():
                                                return True

                                    if self.pool_size is not None:
                                        for child_ref in self.pool_size:
                                            if child_ref._has_data():
                                                return True

                                    if self.ppmp_entry_count is not None:
                                        return True

                                    if self.ppmp_memory is not None:
                                        return True

                                    if self.process_instance_node is not None:
                                        return True

                                    if self.pta_entry_count is not None:
                                        return True

                                    if self.pta_memory is not None:
                                        return True

                                    if self.restart_count is not None:
                                        return True

                                    if self.ribrnh_entry_count is not None:
                                        return True

                                    if self.ribrnh_memory is not None:
                                        return True

                                    if self.route_reflector_memory is not None:
                                        return True

                                    if self.route_reflectors is not None:
                                        return True

                                    if self.sn_num_non_dflt_vrf_nbrs is not None:
                                        return True

                                    if self.sn_num_non_dflt_vrf_nbrs_estab is not None:
                                        return True

                                    if self.total_vrf_count is not None:
                                        return True

                                    if self.tunnel_encap_entry_count is not None:
                                        return True

                                    if self.tunnel_encap_memory is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global_']['meta_info']


                            class Vrf_(object):
                                """
                                VRF information
                                
                                .. attribute:: established_neighbors_count
                                
                                	Number of established neighbors
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbors_count
                                
                                	Number of neighbors
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: network_count
                                
                                	Number of networks
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: notifications_received
                                
                                	No. of notifications received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: notifications_sent
                                
                                	No. of notifications sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_count
                                
                                	Number of paths
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_messages_received
                                
                                	Number of update messages received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_messages_sent
                                
                                	No. of update messages sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.established_neighbors_count = None
                                    self.neighbors_count = None
                                    self.network_count = None
                                    self.notifications_received = None
                                    self.notifications_sent = None
                                    self.path_count = None
                                    self.update_messages_received = None
                                    self.update_messages_sent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:vrf'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.established_neighbors_count is not None:
                                        return True

                                    if self.neighbors_count is not None:
                                        return True

                                    if self.network_count is not None:
                                        return True

                                    if self.notifications_received is not None:
                                        return True

                                    if self.notifications_sent is not None:
                                        return True

                                    if self.path_count is not None:
                                        return True

                                    if self.update_messages_received is not None:
                                        return True

                                    if self.update_messages_sent is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Vrf_']['meta_info']


                            class PerformanceStatistics(object):
                                """
                                Performance statistics
                                
                                .. attribute:: global_
                                
                                	Global information
                                	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_>`
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:   :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Vrf_>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.global_ = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_()
                                    self.global_.parent = self
                                    self.vrf = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Vrf_()
                                    self.vrf.parent = self


                                class Global_(object):
                                    """
                                    Global information
                                    
                                    .. attribute:: active_nsr_mode_enter_time
                                    
                                    	Time that each mode was entered (seconds since  Jan 1 1970)
                                    	**type**\: list of    :py:class:`ActiveNsrModeEnterTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrModeEnterTime>`
                                    
                                    .. attribute:: active_nsr_state
                                    
                                    	Current Active BGP nsrstate
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: active_nsrfo_time
                                    
                                    	Time that each thread isdone with its  go\-activeprocessing (seconds since Jan 1 1970)
                                    	**type**\: list of    :py:class:`ActiveNsrfoTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrfoTime>`
                                    
                                    .. attribute:: active_nsrtcp_phase_two_enter_time
                                    
                                    	Time that NSR TCP Init Sync Phase Two entered on active (seconds since Jan 1 1970)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: bgp_te_infra_tunnel_type
                                    
                                    	BGP TE infra tunnel type
                                    	**type**\:   :py:class:`BgpTeInfraTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTeInfraTunnelEnum>`
                                    
                                    .. attribute:: brib_api_input_bytes
                                    
                                    	bRIB API input bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: brib_api_input_messages
                                    
                                    	bRIB API input messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_input_prefixes_received
                                    
                                    	bRIB API input advertised prefixes received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_input_processing_time
                                    
                                    	Time spent processing input from bRIB API (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: brib_api_input_withdrawn_prefixes
                                    
                                    	bRIB API input withdrawn prefixes received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_output_bytes_generated
                                    
                                    	bRIB API output bytes generated
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: brib_api_output_bytes_sent
                                    
                                    	bRIB API output bytes sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: brib_api_output_calls
                                    
                                    	bRIB API calls to generate output
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_output_generation_time
                                    
                                    	Time spent generating output for bRIB API (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: brib_api_output_messages_sent
                                    
                                    	bRIB API output messages sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_output_prefixes_advertised
                                    
                                    	bRIB API output prefixes advertised
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_output_prefixes_withdrawn
                                    
                                    	bRIB API output prefixes withdrawn
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_output_sending_time
                                    
                                    	Time spent sending output to bRIB API (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: configuration_items_processed
                                    
                                    	Number of config items processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: configuration_processing_time
                                    
                                    	Time spent processing config (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: current_clock_time
                                    
                                    	Current time
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: ds_npl
                                    
                                    	NSR related DS and NPL information
                                    	**type**\:   :py:class:`DsNpl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl>`
                                    
                                    .. attribute:: edm_processing_time
                                    
                                    	Time spent processing EDM requests (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: edm_requests_count
                                    
                                    	Number of EDM requests processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: in_event_attach_calls
                                    
                                    	event\_file\_attach  calls for input
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: in_out_event_attach_calls
                                    
                                    	event\_file\_attach calls for input
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: initial_sync_sessions_added
                                    
                                    	If true, BGP has at least one established session when NSR initial synchronization is started
                                    	**type**\:  bool
                                    
                                    .. attribute:: instance_node_role
                                    
                                    	Node role \- active/passive
                                    	**type**\:  bool
                                    
                                    .. attribute:: io_handler_tm
                                    
                                    	Timestamp when IO timer handler got called
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: io_timer_id
                                    
                                    	IO master timer ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: io_tree_timer_expiry
                                    
                                    	Time as per tree\->mtexptime
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: io_tree_timer_left
                                    
                                    	Time left before the QNX timer would expire
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: ipv4rib_server
                                    
                                    	IPv4 RIB server global info
                                    	**type**\:   :py:class:`Ipv4RibServer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer>`
                                    
                                    .. attribute:: ipv6rib_server
                                    
                                    	IPv6 RIB server global info
                                    	**type**\:   :py:class:`Ipv6RibServer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer>`
                                    
                                    .. attribute:: issu_milestone
                                    
                                    	ISSU Milestones
                                    	**type**\: list of    :py:class:`IssuMilestone <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.IssuMilestone>`
                                    
                                    .. attribute:: issu_milestone_packed
                                    
                                    	Flag to indicate ISSU Milestones packed
                                    	**type**\:  bool
                                    
                                    .. attribute:: lsd_connection
                                    
                                    	MPLS LSD server connection info
                                    	**type**\:   :py:class:`LsdConnection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection>`
                                    
                                    .. attribute:: nsr_last_reset_reason
                                    
                                    	Reason for last nsr state  machine reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: out_event_attach_calls
                                    
                                    	event\_file\_attach  calls for output
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: postit_count_info
                                    
                                    	List of neighbors and their postit counts
                                    	**type**\: list of    :py:class:`PostitCountInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo>`
                                    
                                    .. attribute:: proc_scoped_sync_state
                                    
                                    	BGP scoped sync state
                                    	**type**\:   :py:class:`BgpScopedSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpScopedSyncStateEnum>`
                                    
                                    .. attribute:: qad_ac_ks_failure
                                    
                                    	Ack failure on QAD 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_ac_ks_received
                                    
                                    	Acks received on QAD 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_init_drops
                                    
                                    	Packets dropped on standby during initialization
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_messages_received
                                    
                                    	Messages received on QAD 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_messages_sent
                                    
                                    	Messages sent on QAD 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_processed
                                    
                                    	Messages processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_recv_drops
                                    
                                    	Received packet dropped due to null peer 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_resumes
                                    
                                    	QAD send resume 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_send_drops
                                    
                                    	Send packets dropped due to null peer 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_send_failure
                                    
                                    	Send failure on QAD 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_suspends
                                    
                                    	QAD send suspend
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_timeout_received
                                    
                                    	Timeouts received on QAD 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_timeout_recvd
                                    
                                    	Number of packet send timeouts 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qadack_sent
                                    
                                    	Acks sent on QAD 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qadoos_drops
                                    
                                    	Packets dropped due to  out of sequence packetreceived
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: redcon_nsr_ready
                                    
                                    	NSR state conveyed to Redcon  by bgp \- nsr ready/unready
                                    	**type**\:  bool
                                    
                                    .. attribute:: redcon_state_time
                                    
                                    	Time when nsr state wasconveyed to Redcon last
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sec_active_nsr_state
                                    
                                    	Current Sec Active BGP nsrstate
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sec_active_nsrtcp_phase_two_enter_time
                                    
                                    	Time that NSR TCP Init Sync Phase Two entered on active (seconds since Jan 1 1970)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: standby_nsr_mode_enter_time
                                    
                                    	Time that each mode was entered (seconds since  Jan 1 1970)
                                    	**type**\: list of    :py:class:`StandbyNsrModeEnterTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.StandbyNsrModeEnterTime>`
                                    
                                    .. attribute:: te_connection
                                    
                                    	MPLS TE server connection info
                                    	**type**\:   :py:class:`TeConnection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection>`
                                    
                                    .. attribute:: tep2p_auto_tunnel_enabled
                                    
                                    	TE support for P2P auto tunnel
                                    	**type**\:  bool
                                    
                                    .. attribute:: total_neighbors_with_pending_postits
                                    
                                    	Total nbrs with pending postits
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_outstanding_postits
                                    
                                    	Total outstanding postits across all neighbors
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: updgen_handler_tm
                                    
                                    	Timestamp when updgen timer handler got called
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: updgen_timer_id
                                    
                                    	Updgen master timer ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: updgen_tree_timer_expiry
                                    
                                    	Time as per tree\->mtexptime
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: updgen_tree_timer_left
                                    
                                    	Time left before the QNX timer would expire
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.active_nsr_mode_enter_time = YList()
                                        self.active_nsr_mode_enter_time.parent = self
                                        self.active_nsr_mode_enter_time.name = 'active_nsr_mode_enter_time'
                                        self.active_nsr_state = None
                                        self.active_nsrfo_time = YList()
                                        self.active_nsrfo_time.parent = self
                                        self.active_nsrfo_time.name = 'active_nsrfo_time'
                                        self.active_nsrtcp_phase_two_enter_time = None
                                        self.bgp_te_infra_tunnel_type = None
                                        self.brib_api_input_bytes = None
                                        self.brib_api_input_messages = None
                                        self.brib_api_input_prefixes_received = None
                                        self.brib_api_input_processing_time = None
                                        self.brib_api_input_withdrawn_prefixes = None
                                        self.brib_api_output_bytes_generated = None
                                        self.brib_api_output_bytes_sent = None
                                        self.brib_api_output_calls = None
                                        self.brib_api_output_generation_time = None
                                        self.brib_api_output_messages_sent = None
                                        self.brib_api_output_prefixes_advertised = None
                                        self.brib_api_output_prefixes_withdrawn = None
                                        self.brib_api_output_sending_time = None
                                        self.configuration_items_processed = None
                                        self.configuration_processing_time = None
                                        self.current_clock_time = None
                                        self.ds_npl = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl()
                                        self.ds_npl.parent = self
                                        self.edm_processing_time = None
                                        self.edm_requests_count = None
                                        self.in_event_attach_calls = None
                                        self.in_out_event_attach_calls = None
                                        self.initial_sync_sessions_added = None
                                        self.instance_node_role = None
                                        self.io_handler_tm = None
                                        self.io_timer_id = None
                                        self.io_tree_timer_expiry = None
                                        self.io_tree_timer_left = None
                                        self.ipv4rib_server = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer()
                                        self.ipv4rib_server.parent = self
                                        self.ipv6rib_server = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer()
                                        self.ipv6rib_server.parent = self
                                        self.issu_milestone = YList()
                                        self.issu_milestone.parent = self
                                        self.issu_milestone.name = 'issu_milestone'
                                        self.issu_milestone_packed = None
                                        self.lsd_connection = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection()
                                        self.lsd_connection.parent = self
                                        self.nsr_last_reset_reason = None
                                        self.out_event_attach_calls = None
                                        self.postit_count_info = YList()
                                        self.postit_count_info.parent = self
                                        self.postit_count_info.name = 'postit_count_info'
                                        self.proc_scoped_sync_state = None
                                        self.qad_ac_ks_failure = None
                                        self.qad_ac_ks_received = None
                                        self.qad_init_drops = None
                                        self.qad_messages_received = None
                                        self.qad_messages_sent = None
                                        self.qad_processed = None
                                        self.qad_recv_drops = None
                                        self.qad_resumes = None
                                        self.qad_send_drops = None
                                        self.qad_send_failure = None
                                        self.qad_suspends = None
                                        self.qad_timeout_received = None
                                        self.qad_timeout_recvd = None
                                        self.qadack_sent = None
                                        self.qadoos_drops = None
                                        self.redcon_nsr_ready = None
                                        self.redcon_state_time = None
                                        self.sec_active_nsr_state = None
                                        self.sec_active_nsrtcp_phase_two_enter_time = None
                                        self.standby_nsr_mode_enter_time = YList()
                                        self.standby_nsr_mode_enter_time.parent = self
                                        self.standby_nsr_mode_enter_time.name = 'standby_nsr_mode_enter_time'
                                        self.te_connection = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection()
                                        self.te_connection.parent = self
                                        self.tep2p_auto_tunnel_enabled = None
                                        self.total_neighbors_with_pending_postits = None
                                        self.total_outstanding_postits = None
                                        self.updgen_handler_tm = None
                                        self.updgen_timer_id = None
                                        self.updgen_tree_timer_expiry = None
                                        self.updgen_tree_timer_left = None


                                    class Ipv4RibServer(object):
                                        """
                                        IPv4 RIB server global info
                                        
                                        .. attribute:: first_rib_connection_down_timestamp
                                        
                                        	First RIB connection Down event timestamp
                                        	**type**\:   :py:class:`FirstRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionDownTimestamp>`
                                        
                                        .. attribute:: first_rib_connection_up_timestamp
                                        
                                        	First RIB connection Up event timestamp
                                        	**type**\:   :py:class:`FirstRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionUpTimestamp>`
                                        
                                        .. attribute:: is_rib_connection_up
                                        
                                        	Is RIB Connection Up?
                                        	**type**\:  bool
                                        
                                        .. attribute:: last_rib_connection_down_age
                                        
                                        	Time since last RIB connection Down event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_rib_connection_down_timestamp
                                        
                                        	Last RIB connection Down event timestamp
                                        	**type**\:   :py:class:`LastRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionDownTimestamp>`
                                        
                                        .. attribute:: last_rib_connection_up_age
                                        
                                        	Time since last RIB connection Up event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_rib_connection_up_timestamp
                                        
                                        	Last RIB connection Up event timestamp
                                        	**type**\:   :py:class:`LastRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionUpTimestamp>`
                                        
                                        .. attribute:: rib_connection_down_count
                                        
                                        	Number of RIB connection Down events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_connection_up_count
                                        
                                        	Number of RIB connection Up events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.first_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionDownTimestamp()
                                            self.first_rib_connection_down_timestamp.parent = self
                                            self.first_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionUpTimestamp()
                                            self.first_rib_connection_up_timestamp.parent = self
                                            self.is_rib_connection_up = None
                                            self.last_rib_connection_down_age = None
                                            self.last_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionDownTimestamp()
                                            self.last_rib_connection_down_timestamp.parent = self
                                            self.last_rib_connection_up_age = None
                                            self.last_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionUpTimestamp()
                                            self.last_rib_connection_up_timestamp.parent = self
                                            self.rib_connection_down_count = None
                                            self.rib_connection_up_count = None


                                        class FirstRibConnectionUpTimestamp(object):
                                            """
                                            First RIB connection Up event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-rib-connection-up-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionUpTimestamp']['meta_info']


                                        class LastRibConnectionUpTimestamp(object):
                                            """
                                            Last RIB connection Up event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-rib-connection-up-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionUpTimestamp']['meta_info']


                                        class FirstRibConnectionDownTimestamp(object):
                                            """
                                            First RIB connection Down event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-rib-connection-down-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionDownTimestamp']['meta_info']


                                        class LastRibConnectionDownTimestamp(object):
                                            """
                                            Last RIB connection Down event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-rib-connection-down-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionDownTimestamp']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4rib-server'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.first_rib_connection_down_timestamp is not None and self.first_rib_connection_down_timestamp._has_data():
                                                return True

                                            if self.first_rib_connection_up_timestamp is not None and self.first_rib_connection_up_timestamp._has_data():
                                                return True

                                            if self.is_rib_connection_up is not None:
                                                return True

                                            if self.last_rib_connection_down_age is not None:
                                                return True

                                            if self.last_rib_connection_down_timestamp is not None and self.last_rib_connection_down_timestamp._has_data():
                                                return True

                                            if self.last_rib_connection_up_age is not None:
                                                return True

                                            if self.last_rib_connection_up_timestamp is not None and self.last_rib_connection_up_timestamp._has_data():
                                                return True

                                            if self.rib_connection_down_count is not None:
                                                return True

                                            if self.rib_connection_up_count is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer']['meta_info']


                                    class Ipv6RibServer(object):
                                        """
                                        IPv6 RIB server global info
                                        
                                        .. attribute:: first_rib_connection_down_timestamp
                                        
                                        	First RIB connection Down event timestamp
                                        	**type**\:   :py:class:`FirstRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionDownTimestamp>`
                                        
                                        .. attribute:: first_rib_connection_up_timestamp
                                        
                                        	First RIB connection Up event timestamp
                                        	**type**\:   :py:class:`FirstRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionUpTimestamp>`
                                        
                                        .. attribute:: is_rib_connection_up
                                        
                                        	Is RIB Connection Up?
                                        	**type**\:  bool
                                        
                                        .. attribute:: last_rib_connection_down_age
                                        
                                        	Time since last RIB connection Down event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_rib_connection_down_timestamp
                                        
                                        	Last RIB connection Down event timestamp
                                        	**type**\:   :py:class:`LastRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionDownTimestamp>`
                                        
                                        .. attribute:: last_rib_connection_up_age
                                        
                                        	Time since last RIB connection Up event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_rib_connection_up_timestamp
                                        
                                        	Last RIB connection Up event timestamp
                                        	**type**\:   :py:class:`LastRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionUpTimestamp>`
                                        
                                        .. attribute:: rib_connection_down_count
                                        
                                        	Number of RIB connection Down events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_connection_up_count
                                        
                                        	Number of RIB connection Up events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.first_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionDownTimestamp()
                                            self.first_rib_connection_down_timestamp.parent = self
                                            self.first_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionUpTimestamp()
                                            self.first_rib_connection_up_timestamp.parent = self
                                            self.is_rib_connection_up = None
                                            self.last_rib_connection_down_age = None
                                            self.last_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionDownTimestamp()
                                            self.last_rib_connection_down_timestamp.parent = self
                                            self.last_rib_connection_up_age = None
                                            self.last_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionUpTimestamp()
                                            self.last_rib_connection_up_timestamp.parent = self
                                            self.rib_connection_down_count = None
                                            self.rib_connection_up_count = None


                                        class FirstRibConnectionUpTimestamp(object):
                                            """
                                            First RIB connection Up event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-rib-connection-up-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionUpTimestamp']['meta_info']


                                        class LastRibConnectionUpTimestamp(object):
                                            """
                                            Last RIB connection Up event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-rib-connection-up-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionUpTimestamp']['meta_info']


                                        class FirstRibConnectionDownTimestamp(object):
                                            """
                                            First RIB connection Down event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-rib-connection-down-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionDownTimestamp']['meta_info']


                                        class LastRibConnectionDownTimestamp(object):
                                            """
                                            Last RIB connection Down event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-rib-connection-down-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionDownTimestamp']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6rib-server'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.first_rib_connection_down_timestamp is not None and self.first_rib_connection_down_timestamp._has_data():
                                                return True

                                            if self.first_rib_connection_up_timestamp is not None and self.first_rib_connection_up_timestamp._has_data():
                                                return True

                                            if self.is_rib_connection_up is not None:
                                                return True

                                            if self.last_rib_connection_down_age is not None:
                                                return True

                                            if self.last_rib_connection_down_timestamp is not None and self.last_rib_connection_down_timestamp._has_data():
                                                return True

                                            if self.last_rib_connection_up_age is not None:
                                                return True

                                            if self.last_rib_connection_up_timestamp is not None and self.last_rib_connection_up_timestamp._has_data():
                                                return True

                                            if self.rib_connection_down_count is not None:
                                                return True

                                            if self.rib_connection_up_count is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer']['meta_info']


                                    class TeConnection(object):
                                        """
                                        MPLS TE server connection info
                                        
                                        .. attribute:: connection_down_count
                                        
                                        	Number of connection down events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: connection_up_count
                                        
                                        	Number of connection Up events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: first_connection_down_timestamp
                                        
                                        	First connection Down event timestamp
                                        	**type**\:   :py:class:`FirstConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionDownTimestamp>`
                                        
                                        .. attribute:: first_connection_up_timestamp
                                        
                                        	First connection Up event timestamp
                                        	**type**\:   :py:class:`FirstConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionUpTimestamp>`
                                        
                                        .. attribute:: is_connection_up
                                        
                                        	Is Connection Up?
                                        	**type**\:  bool
                                        
                                        .. attribute:: last_connection_down_age
                                        
                                        	Time since last connection Down event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_connection_down_timestamp
                                        
                                        	Last connection Down event timestamp
                                        	**type**\:   :py:class:`LastConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionDownTimestamp>`
                                        
                                        .. attribute:: last_connection_up_age
                                        
                                        	Time since last connection Up event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_connection_up_timestamp
                                        
                                        	Last connection Up event timestamp
                                        	**type**\:   :py:class:`LastConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionUpTimestamp>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.connection_down_count = None
                                            self.connection_up_count = None
                                            self.first_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionDownTimestamp()
                                            self.first_connection_down_timestamp.parent = self
                                            self.first_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionUpTimestamp()
                                            self.first_connection_up_timestamp.parent = self
                                            self.is_connection_up = None
                                            self.last_connection_down_age = None
                                            self.last_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionDownTimestamp()
                                            self.last_connection_down_timestamp.parent = self
                                            self.last_connection_up_age = None
                                            self.last_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionUpTimestamp()
                                            self.last_connection_up_timestamp.parent = self


                                        class FirstConnectionUpTimestamp(object):
                                            """
                                            First connection Up event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-connection-up-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionUpTimestamp']['meta_info']


                                        class LastConnectionUpTimestamp(object):
                                            """
                                            Last connection Up event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-connection-up-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionUpTimestamp']['meta_info']


                                        class FirstConnectionDownTimestamp(object):
                                            """
                                            First connection Down event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-connection-down-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionDownTimestamp']['meta_info']


                                        class LastConnectionDownTimestamp(object):
                                            """
                                            Last connection Down event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-connection-down-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionDownTimestamp']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:te-connection'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.connection_down_count is not None:
                                                return True

                                            if self.connection_up_count is not None:
                                                return True

                                            if self.first_connection_down_timestamp is not None and self.first_connection_down_timestamp._has_data():
                                                return True

                                            if self.first_connection_up_timestamp is not None and self.first_connection_up_timestamp._has_data():
                                                return True

                                            if self.is_connection_up is not None:
                                                return True

                                            if self.last_connection_down_age is not None:
                                                return True

                                            if self.last_connection_down_timestamp is not None and self.last_connection_down_timestamp._has_data():
                                                return True

                                            if self.last_connection_up_age is not None:
                                                return True

                                            if self.last_connection_up_timestamp is not None and self.last_connection_up_timestamp._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection']['meta_info']


                                    class LsdConnection(object):
                                        """
                                        MPLS LSD server connection info
                                        
                                        .. attribute:: connection_down_count
                                        
                                        	Number of connection down events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: connection_up_count
                                        
                                        	Number of connection Up events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: first_connection_down_timestamp
                                        
                                        	First connection Down event timestamp
                                        	**type**\:   :py:class:`FirstConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionDownTimestamp>`
                                        
                                        .. attribute:: first_connection_up_timestamp
                                        
                                        	First connection Up event timestamp
                                        	**type**\:   :py:class:`FirstConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionUpTimestamp>`
                                        
                                        .. attribute:: is_connection_up
                                        
                                        	Is Connection Up?
                                        	**type**\:  bool
                                        
                                        .. attribute:: last_connection_down_age
                                        
                                        	Time since last connection Down event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_connection_down_timestamp
                                        
                                        	Last connection Down event timestamp
                                        	**type**\:   :py:class:`LastConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionDownTimestamp>`
                                        
                                        .. attribute:: last_connection_up_age
                                        
                                        	Time since last connection Up event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_connection_up_timestamp
                                        
                                        	Last connection Up event timestamp
                                        	**type**\:   :py:class:`LastConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionUpTimestamp>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.connection_down_count = None
                                            self.connection_up_count = None
                                            self.first_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionDownTimestamp()
                                            self.first_connection_down_timestamp.parent = self
                                            self.first_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionUpTimestamp()
                                            self.first_connection_up_timestamp.parent = self
                                            self.is_connection_up = None
                                            self.last_connection_down_age = None
                                            self.last_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionDownTimestamp()
                                            self.last_connection_down_timestamp.parent = self
                                            self.last_connection_up_age = None
                                            self.last_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionUpTimestamp()
                                            self.last_connection_up_timestamp.parent = self


                                        class FirstConnectionUpTimestamp(object):
                                            """
                                            First connection Up event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-connection-up-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionUpTimestamp']['meta_info']


                                        class LastConnectionUpTimestamp(object):
                                            """
                                            Last connection Up event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-connection-up-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionUpTimestamp']['meta_info']


                                        class FirstConnectionDownTimestamp(object):
                                            """
                                            First connection Down event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-connection-down-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionDownTimestamp']['meta_info']


                                        class LastConnectionDownTimestamp(object):
                                            """
                                            Last connection Down event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-connection-down-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionDownTimestamp']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:lsd-connection'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.connection_down_count is not None:
                                                return True

                                            if self.connection_up_count is not None:
                                                return True

                                            if self.first_connection_down_timestamp is not None and self.first_connection_down_timestamp._has_data():
                                                return True

                                            if self.first_connection_up_timestamp is not None and self.first_connection_up_timestamp._has_data():
                                                return True

                                            if self.is_connection_up is not None:
                                                return True

                                            if self.last_connection_down_age is not None:
                                                return True

                                            if self.last_connection_down_timestamp is not None and self.last_connection_down_timestamp._has_data():
                                                return True

                                            if self.last_connection_up_age is not None:
                                                return True

                                            if self.last_connection_up_timestamp is not None and self.last_connection_up_timestamp._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection']['meta_info']


                                    class DsNpl(object):
                                        """
                                        NSR related DS and NPL information
                                        
                                        .. attribute:: dir_service_conn_state
                                        
                                        	Current Directory Service connectionstate
                                        	**type**\:   :py:class:`BgpDsConnStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpDsConnStateEnum>`
                                        
                                        .. attribute:: dsissu_status_flag
                                        
                                        	DS ISSU status flag
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: issu_mgr_conn_state
                                        
                                        	Current ISSU Mgr connection state
                                        	**type**\:   :py:class:`BgpIsmConnStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpIsmConnStateEnum>`
                                        
                                        .. attribute:: issu_phase
                                        
                                        	Current ISSU Phase
                                        	**type**\:  str
                                        
                                        .. attribute:: issu_type_ng
                                        
                                        	ISSU type is Next Gen
                                        	**type**\:  bool
                                        
                                        .. attribute:: issuha_option
                                        
                                        	Current ISSU HA option
                                        	**type**\:  str
                                        
                                        .. attribute:: local_ds_handle
                                        
                                        	Local Directory Service handle
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: npl_endpoint
                                        
                                        	NPL endpoint information
                                        	**type**\: list of    :py:class:`NplEndpoint <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint>`
                                        
                                        .. attribute:: npl_priority_statistic
                                        
                                        	NPL priority statistics
                                        	**type**\: list of    :py:class:`NplPriorityStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic>`
                                        
                                        .. attribute:: service_name
                                        
                                        	Local DS service name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.dir_service_conn_state = None
                                            self.dsissu_status_flag = None
                                            self.issu_mgr_conn_state = None
                                            self.issu_phase = None
                                            self.issu_type_ng = None
                                            self.issuha_option = None
                                            self.local_ds_handle = None
                                            self.npl_endpoint = YList()
                                            self.npl_endpoint.parent = self
                                            self.npl_endpoint.name = 'npl_endpoint'
                                            self.npl_priority_statistic = YList()
                                            self.npl_priority_statistic.parent = self
                                            self.npl_priority_statistic.name = 'npl_priority_statistic'
                                            self.service_name = None


                                        class NplPriorityStatistic(object):
                                            """
                                            NPL priority statistics
                                            
                                            .. attribute:: num_recv
                                            
                                            	Total recvd
                                            	**type**\: list of    :py:class:`NumRecv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecv>`
                                            
                                            .. attribute:: num_recv_drop
                                            
                                            	Recv Errors/drops
                                            	**type**\: list of    :py:class:`NumRecvDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop>`
                                            
                                            .. attribute:: num_sent
                                            
                                            	Total sent
                                            	**type**\: list of    :py:class:`NumSent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSent>`
                                            
                                            .. attribute:: num_sent_drop
                                            
                                            	Sent Error/drops
                                            	**type**\: list of    :py:class:`NumSentDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.num_recv = YList()
                                                self.num_recv.parent = self
                                                self.num_recv.name = 'num_recv'
                                                self.num_recv_drop = YList()
                                                self.num_recv_drop.parent = self
                                                self.num_recv_drop.name = 'num_recv_drop'
                                                self.num_sent = YList()
                                                self.num_sent.parent = self
                                                self.num_sent.name = 'num_sent'
                                                self.num_sent_drop = YList()
                                                self.num_sent_drop.parent = self
                                                self.num_sent_drop.name = 'num_sent_drop'


                                            class NumSent(object):
                                                """
                                                Total sent
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:num-sent'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSent']['meta_info']


                                            class NumRecv(object):
                                                """
                                                Total recvd
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:num-recv'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecv']['meta_info']


                                            class NumSentDrop(object):
                                                """
                                                Sent Error/drops
                                                
                                                .. attribute:: nsr_pl_send_drop_array
                                                
                                                	nsr pl send drop array
                                                	**type**\: list of    :py:class:`NsrPlSendDropArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nsr_pl_send_drop_array = YList()
                                                    self.nsr_pl_send_drop_array.parent = self
                                                    self.nsr_pl_send_drop_array.name = 'nsr_pl_send_drop_array'


                                                class NsrPlSendDropArray(object):
                                                    """
                                                    nsr pl send drop array
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nsr-pl-send-drop-array'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:num-sent-drop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nsr_pl_send_drop_array is not None:
                                                        for child_ref in self.nsr_pl_send_drop_array:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop']['meta_info']


                                            class NumRecvDrop(object):
                                                """
                                                Recv Errors/drops
                                                
                                                .. attribute:: nsr_pl_recv_drop_array
                                                
                                                	nsr pl recv drop array
                                                	**type**\: list of    :py:class:`NsrPlRecvDropArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nsr_pl_recv_drop_array = YList()
                                                    self.nsr_pl_recv_drop_array.parent = self
                                                    self.nsr_pl_recv_drop_array.name = 'nsr_pl_recv_drop_array'


                                                class NsrPlRecvDropArray(object):
                                                    """
                                                    nsr pl recv drop array
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nsr-pl-recv-drop-array'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:num-recv-drop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nsr_pl_recv_drop_array is not None:
                                                        for child_ref in self.nsr_pl_recv_drop_array:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:npl-priority-statistic'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.num_recv is not None:
                                                    for child_ref in self.num_recv:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.num_recv_drop is not None:
                                                    for child_ref in self.num_recv_drop:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.num_sent is not None:
                                                    for child_ref in self.num_sent:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.num_sent_drop is not None:
                                                    for child_ref in self.num_sent_drop:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic']['meta_info']


                                        class NplEndpoint(object):
                                            """
                                            NPL endpoint information
                                            
                                            .. attribute:: endpoint
                                            
                                            	NCD endpoint bytestream
                                            	**type**\: list of    :py:class:`Endpoint <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint.Endpoint>`
                                            
                                            .. attribute:: endpoint_active_flag
                                            
                                            	Endpoint active flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: endpoint_handle
                                            
                                            	NCD endpoint handle
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: endpoint_issu_role
                                            
                                            	Endpoint's ISSU Role. Values are 'Primary', 'Secondary' and 'Tertiary'
                                            	**type**\:  str
                                            
                                            .. attribute:: endpoint_name
                                            
                                            	Endpoint name
                                            	**type**\:  str
                                            
                                            .. attribute:: endpoint_stale_flag
                                            
                                            	Endpoint stale flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: expected_sequence_num
                                            
                                            	Expected sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: msg_size
                                            
                                            	Message size for this entity
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: node_id
                                            
                                            	Node ID
                                            	**type**\:  str
                                            
                                            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                                            
                                            .. attribute:: sync_group_name
                                            
                                            	Syncgroup associated with this endpoint
                                            	**type**\:  str
                                            
                                            .. attribute:: wheel_id
                                            
                                            	Wheel ID for this endpoint
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.endpoint = YList()
                                                self.endpoint.parent = self
                                                self.endpoint.name = 'endpoint'
                                                self.endpoint_active_flag = None
                                                self.endpoint_handle = None
                                                self.endpoint_issu_role = None
                                                self.endpoint_name = None
                                                self.endpoint_stale_flag = None
                                                self.expected_sequence_num = None
                                                self.msg_size = None
                                                self.node_id = None
                                                self.sync_group_name = None
                                                self.wheel_id = None


                                            class Endpoint(object):
                                                """
                                                NCD endpoint bytestream
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:endpoint'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint.Endpoint']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:npl-endpoint'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.endpoint is not None:
                                                    for child_ref in self.endpoint:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.endpoint_active_flag is not None:
                                                    return True

                                                if self.endpoint_handle is not None:
                                                    return True

                                                if self.endpoint_issu_role is not None:
                                                    return True

                                                if self.endpoint_name is not None:
                                                    return True

                                                if self.endpoint_stale_flag is not None:
                                                    return True

                                                if self.expected_sequence_num is not None:
                                                    return True

                                                if self.msg_size is not None:
                                                    return True

                                                if self.node_id is not None:
                                                    return True

                                                if self.sync_group_name is not None:
                                                    return True

                                                if self.wheel_id is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ds-npl'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dir_service_conn_state is not None:
                                                return True

                                            if self.dsissu_status_flag is not None:
                                                return True

                                            if self.issu_mgr_conn_state is not None:
                                                return True

                                            if self.issu_phase is not None:
                                                return True

                                            if self.issu_type_ng is not None:
                                                return True

                                            if self.issuha_option is not None:
                                                return True

                                            if self.local_ds_handle is not None:
                                                return True

                                            if self.npl_endpoint is not None:
                                                for child_ref in self.npl_endpoint:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.npl_priority_statistic is not None:
                                                for child_ref in self.npl_priority_statistic:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.service_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl']['meta_info']


                                    class ActiveNsrModeEnterTime(object):
                                        """
                                        Time that each mode was entered (seconds since
                                        
                                        Jan 1 1970)
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.entry = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-nsr-mode-enter-time'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.entry is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrModeEnterTime']['meta_info']


                                    class StandbyNsrModeEnterTime(object):
                                        """
                                        Time that each mode was entered (seconds since
                                        
                                        Jan 1 1970)
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.entry = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:standby-nsr-mode-enter-time'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.entry is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.StandbyNsrModeEnterTime']['meta_info']


                                    class ActiveNsrfoTime(object):
                                        """
                                        Time that each thread isdone with its
                                        
                                        go\-activeprocessing (seconds since Jan 1 1970)
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.entry = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-nsrfo-time'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.entry is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrfoTime']['meta_info']


                                    class PostitCountInfo(object):
                                        """
                                        List of neighbors and their postit counts
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress>`
                                        
                                        .. attribute:: postit_count
                                        
                                        	Count of the number of postits for this nbr
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self.postit_count = None
                                            self.vrf_name = None


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:postit-count-info'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            if self.postit_count is not None:
                                                return True

                                            if self.vrf_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo']['meta_info']


                                    class IssuMilestone(object):
                                        """
                                        ISSU Milestones
                                        
                                        .. attribute:: milestone_met_timestamp
                                        
                                        	Milestone met timestamp
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: milestone_name
                                        
                                        	Milestone name
                                        	**type**\:  str
                                        
                                        	**length:** 0..64
                                        
                                        .. attribute:: milestone_start_timestamp
                                        
                                        	Milestone start timestamp
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.milestone_met_timestamp = None
                                            self.milestone_name = None
                                            self.milestone_start_timestamp = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:issu-milestone'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.milestone_met_timestamp is not None:
                                                return True

                                            if self.milestone_name is not None:
                                                return True

                                            if self.milestone_start_timestamp is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.IssuMilestone']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:global'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.active_nsr_mode_enter_time is not None:
                                            for child_ref in self.active_nsr_mode_enter_time:
                                                if child_ref._has_data():
                                                    return True

                                        if self.active_nsr_state is not None:
                                            return True

                                        if self.active_nsrfo_time is not None:
                                            for child_ref in self.active_nsrfo_time:
                                                if child_ref._has_data():
                                                    return True

                                        if self.active_nsrtcp_phase_two_enter_time is not None:
                                            return True

                                        if self.bgp_te_infra_tunnel_type is not None:
                                            return True

                                        if self.brib_api_input_bytes is not None:
                                            return True

                                        if self.brib_api_input_messages is not None:
                                            return True

                                        if self.brib_api_input_prefixes_received is not None:
                                            return True

                                        if self.brib_api_input_processing_time is not None:
                                            return True

                                        if self.brib_api_input_withdrawn_prefixes is not None:
                                            return True

                                        if self.brib_api_output_bytes_generated is not None:
                                            return True

                                        if self.brib_api_output_bytes_sent is not None:
                                            return True

                                        if self.brib_api_output_calls is not None:
                                            return True

                                        if self.brib_api_output_generation_time is not None:
                                            return True

                                        if self.brib_api_output_messages_sent is not None:
                                            return True

                                        if self.brib_api_output_prefixes_advertised is not None:
                                            return True

                                        if self.brib_api_output_prefixes_withdrawn is not None:
                                            return True

                                        if self.brib_api_output_sending_time is not None:
                                            return True

                                        if self.configuration_items_processed is not None:
                                            return True

                                        if self.configuration_processing_time is not None:
                                            return True

                                        if self.current_clock_time is not None:
                                            return True

                                        if self.ds_npl is not None and self.ds_npl._has_data():
                                            return True

                                        if self.edm_processing_time is not None:
                                            return True

                                        if self.edm_requests_count is not None:
                                            return True

                                        if self.in_event_attach_calls is not None:
                                            return True

                                        if self.in_out_event_attach_calls is not None:
                                            return True

                                        if self.initial_sync_sessions_added is not None:
                                            return True

                                        if self.instance_node_role is not None:
                                            return True

                                        if self.io_handler_tm is not None:
                                            return True

                                        if self.io_timer_id is not None:
                                            return True

                                        if self.io_tree_timer_expiry is not None:
                                            return True

                                        if self.io_tree_timer_left is not None:
                                            return True

                                        if self.ipv4rib_server is not None and self.ipv4rib_server._has_data():
                                            return True

                                        if self.ipv6rib_server is not None and self.ipv6rib_server._has_data():
                                            return True

                                        if self.issu_milestone is not None:
                                            for child_ref in self.issu_milestone:
                                                if child_ref._has_data():
                                                    return True

                                        if self.issu_milestone_packed is not None:
                                            return True

                                        if self.lsd_connection is not None and self.lsd_connection._has_data():
                                            return True

                                        if self.nsr_last_reset_reason is not None:
                                            return True

                                        if self.out_event_attach_calls is not None:
                                            return True

                                        if self.postit_count_info is not None:
                                            for child_ref in self.postit_count_info:
                                                if child_ref._has_data():
                                                    return True

                                        if self.proc_scoped_sync_state is not None:
                                            return True

                                        if self.qad_ac_ks_failure is not None:
                                            return True

                                        if self.qad_ac_ks_received is not None:
                                            return True

                                        if self.qad_init_drops is not None:
                                            return True

                                        if self.qad_messages_received is not None:
                                            return True

                                        if self.qad_messages_sent is not None:
                                            return True

                                        if self.qad_processed is not None:
                                            return True

                                        if self.qad_recv_drops is not None:
                                            return True

                                        if self.qad_resumes is not None:
                                            return True

                                        if self.qad_send_drops is not None:
                                            return True

                                        if self.qad_send_failure is not None:
                                            return True

                                        if self.qad_suspends is not None:
                                            return True

                                        if self.qad_timeout_received is not None:
                                            return True

                                        if self.qad_timeout_recvd is not None:
                                            return True

                                        if self.qadack_sent is not None:
                                            return True

                                        if self.qadoos_drops is not None:
                                            return True

                                        if self.redcon_nsr_ready is not None:
                                            return True

                                        if self.redcon_state_time is not None:
                                            return True

                                        if self.sec_active_nsr_state is not None:
                                            return True

                                        if self.sec_active_nsrtcp_phase_two_enter_time is not None:
                                            return True

                                        if self.standby_nsr_mode_enter_time is not None:
                                            for child_ref in self.standby_nsr_mode_enter_time:
                                                if child_ref._has_data():
                                                    return True

                                        if self.te_connection is not None and self.te_connection._has_data():
                                            return True

                                        if self.tep2p_auto_tunnel_enabled is not None:
                                            return True

                                        if self.total_neighbors_with_pending_postits is not None:
                                            return True

                                        if self.total_outstanding_postits is not None:
                                            return True

                                        if self.updgen_handler_tm is not None:
                                            return True

                                        if self.updgen_timer_id is not None:
                                            return True

                                        if self.updgen_tree_timer_expiry is not None:
                                            return True

                                        if self.updgen_tree_timer_left is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_']['meta_info']


                                class Vrf_(object):
                                    """
                                    VRF information
                                    
                                    .. attribute:: data_bytes_read
                                    
                                    	No. of bytes of data read
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: data_bytes_written
                                    
                                    	Number of bytes of data written
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: high_throttled_read_count
                                    
                                    	Number of socket reads for nbrs above high threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inbound_update_messages
                                    
                                    	Number of inbound update messages processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inbound_update_messages_time
                                    
                                    	Time spent processing imbound update messages (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: io_read_time
                                    
                                    	Time spent reading inbound data (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: io_write_time
                                    
                                    	Time spent writing outbound data (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: low_throttled_read_count
                                    
                                    	Number of socket reads for nbrs above low threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lpts_calls
                                    
                                    	Number of times LPTS socket opt set up
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lpts_set_up_time
                                    
                                    	Time spent setting up LPTS socket opt (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: read_calls_count
                                    
                                    	No. of calls to function to read inbound data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: read_messages_count
                                    
                                    	Number of BGP messages read
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: read_throttles_count
                                    
                                    	Number of partial read throttles
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subgroup_list_time
                                    
                                    	Time spent processing sub\-group message list (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: write_calls_count
                                    
                                    	No. of calls to function to write outbound data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_queue_calls_count
                                    
                                    	No. of Calls to function to process write queue
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_queue_messages_count
                                    
                                    	Number of write queue messages processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_queue_time
                                    
                                    	Time spent processing write queue (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_subgroup_calls_count
                                    
                                    	No. of calls to to funvction to process sub\-group message list
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_subgroup_messages_count
                                    
                                    	Number of sub\-group messages processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.data_bytes_read = None
                                        self.data_bytes_written = None
                                        self.high_throttled_read_count = None
                                        self.inbound_update_messages = None
                                        self.inbound_update_messages_time = None
                                        self.io_read_time = None
                                        self.io_write_time = None
                                        self.low_throttled_read_count = None
                                        self.lpts_calls = None
                                        self.lpts_set_up_time = None
                                        self.read_calls_count = None
                                        self.read_messages_count = None
                                        self.read_throttles_count = None
                                        self.subgroup_list_time = None
                                        self.write_calls_count = None
                                        self.write_queue_calls_count = None
                                        self.write_queue_messages_count = None
                                        self.write_queue_time = None
                                        self.write_subgroup_calls_count = None
                                        self.write_subgroup_messages_count = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:vrf'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data_bytes_read is not None:
                                            return True

                                        if self.data_bytes_written is not None:
                                            return True

                                        if self.high_throttled_read_count is not None:
                                            return True

                                        if self.inbound_update_messages is not None:
                                            return True

                                        if self.inbound_update_messages_time is not None:
                                            return True

                                        if self.io_read_time is not None:
                                            return True

                                        if self.io_write_time is not None:
                                            return True

                                        if self.low_throttled_read_count is not None:
                                            return True

                                        if self.lpts_calls is not None:
                                            return True

                                        if self.lpts_set_up_time is not None:
                                            return True

                                        if self.read_calls_count is not None:
                                            return True

                                        if self.read_messages_count is not None:
                                            return True

                                        if self.read_throttles_count is not None:
                                            return True

                                        if self.subgroup_list_time is not None:
                                            return True

                                        if self.write_calls_count is not None:
                                            return True

                                        if self.write_queue_calls_count is not None:
                                            return True

                                        if self.write_queue_messages_count is not None:
                                            return True

                                        if self.write_queue_time is not None:
                                            return True

                                        if self.write_subgroup_calls_count is not None:
                                            return True

                                        if self.write_subgroup_messages_count is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Vrf_']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:performance-statistics'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.global_ is not None and self.global_._has_data():
                                        return True

                                    if self.vrf is not None and self.vrf._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:process-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.global_ is not None and self.global_._has_data():
                                    return True

                                if self.performance_statistics is not None and self.performance_statistics._has_data():
                                    return True

                                if self.process_instance is not None:
                                    return True

                                if self.vrf is not None and self.vrf._has_data():
                                    return True

                                if self.vrf_name is not None:
                                    return True

                                if self.vrf_totals is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo']['meta_info']


                        class Sessions(object):
                            """
                            The BGP session table
                            
                            .. attribute:: session
                            
                            	A BGP session table entry
                            	**type**\: list of    :py:class:`Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.session = YList()
                                self.session.parent = self
                                self.session.name = 'session'


                            class Session(object):
                                """
                                A BGP session table entry
                                
                                .. attribute:: neighbor_address  <key>
                                
                                	Neighbor address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: connection_local_address
                                
                                	Local address for the connection
                                	**type**\:   :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress>`
                                
                                .. attribute:: connection_remote_address
                                
                                	Remote address for the connection
                                	**type**\:   :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress>`
                                
                                .. attribute:: connection_state
                                
                                	State of connection
                                	**type**\:   :py:class:`BgpConnStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnStateEnum>`
                                
                                .. attribute:: description
                                
                                	Description
                                	**type**\:  str
                                
                                .. attribute:: is_local_address_configured
                                
                                	Local address configured for the neighbor connection
                                	**type**\:  bool
                                
                                .. attribute:: local_as
                                
                                	Local AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: messages_queued_in
                                
                                	No. of msgs on receive queue
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: messages_queued_out
                                
                                	No. of messages on send queue
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_enabled
                                
                                	Neighbor supports NSR
                                	**type**\:  bool
                                
                                .. attribute:: nsr_state
                                
                                	NSR state
                                	**type**\:   :py:class:`BgpSyncNbrNsrStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrStateEnum>`
                                
                                .. attribute:: postit_pending
                                
                                	Nbr has postits pending
                                	**type**\:  bool
                                
                                .. attribute:: remote_as
                                
                                	Remote AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: speaker_id
                                
                                	Speaker this neighbor is allocated to
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vrf_name
                                
                                	Name of the VRF
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.neighbor_address = None
                                    self.connection_local_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress()
                                    self.connection_local_address.parent = self
                                    self.connection_remote_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress()
                                    self.connection_remote_address.parent = self
                                    self.connection_state = None
                                    self.description = None
                                    self.is_local_address_configured = None
                                    self.local_as = None
                                    self.messages_queued_in = None
                                    self.messages_queued_out = None
                                    self.nsr_enabled = None
                                    self.nsr_state = None
                                    self.postit_pending = None
                                    self.remote_as = None
                                    self.speaker_id = None
                                    self.vrf_name = None


                                class ConnectionLocalAddress(object):
                                    """
                                    Local address for the connection
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpnvpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2VpnvplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4mdt_address = None
                                        self.ipv4mvpn_address = None
                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                        self.ipv4sr_policy_address.parent = self
                                        self.ipv4vpn_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                        self.ipv6sr_policy_address.parent = self
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_flowspec_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.l2vpn_evpn_address = None
                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2VpnvplsAddress()
                                        self.l2vpnvpls_address.parent = self
                                        self.ls_ls_address = None
                                        self.rt_constraint_address = None


                                    class L2VpnvplsAddress(object):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2VpnvplsAddress']['meta_info']


                                    class L2VpnMspwAddress(object):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2VpnMspwAddress']['meta_info']


                                    class Ipv4SrPolicyAddress(object):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress']['meta_info']


                                    class Ipv6SrPolicyAddress(object):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv6_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv6_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connection-local-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.afi is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv4_flowspec_address is not None:
                                            return True

                                        if self.ipv4_label_address is not None:
                                            return True

                                        if self.ipv4_mcast_address is not None:
                                            return True

                                        if self.ipv4_tunnel_address is not None:
                                            return True

                                        if self.ipv4mdt_address is not None:
                                            return True

                                        if self.ipv4mvpn_address is not None:
                                            return True

                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                            return True

                                        if self.ipv4vpn_address is not None:
                                            return True

                                        if self.ipv4vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv4vpna_mcastddress is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        if self.ipv6_flowspec_address is not None:
                                            return True

                                        if self.ipv6_label_address is not None:
                                            return True

                                        if self.ipv6_mcast_address is not None:
                                            return True

                                        if self.ipv6mvpn_address is not None:
                                            return True

                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                            return True

                                        if self.ipv6vpn_address is not None:
                                            return True

                                        if self.ipv6vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv6vpn_mcast_address is not None:
                                            return True

                                        if self.l2vpn_evpn_address is not None:
                                            return True

                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                            return True

                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                            return True

                                        if self.ls_ls_address is not None:
                                            return True

                                        if self.rt_constraint_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress']['meta_info']


                                class ConnectionRemoteAddress(object):
                                    """
                                    Remote address for the connection
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpnvpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2VpnvplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4mdt_address = None
                                        self.ipv4mvpn_address = None
                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                        self.ipv4sr_policy_address.parent = self
                                        self.ipv4vpn_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                        self.ipv6sr_policy_address.parent = self
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_flowspec_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.l2vpn_evpn_address = None
                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2VpnvplsAddress()
                                        self.l2vpnvpls_address.parent = self
                                        self.ls_ls_address = None
                                        self.rt_constraint_address = None


                                    class L2VpnvplsAddress(object):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2VpnvplsAddress']['meta_info']


                                    class L2VpnMspwAddress(object):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2VpnMspwAddress']['meta_info']


                                    class Ipv4SrPolicyAddress(object):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress']['meta_info']


                                    class Ipv6SrPolicyAddress(object):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv6_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv6_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connection-remote-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.afi is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv4_flowspec_address is not None:
                                            return True

                                        if self.ipv4_label_address is not None:
                                            return True

                                        if self.ipv4_mcast_address is not None:
                                            return True

                                        if self.ipv4_tunnel_address is not None:
                                            return True

                                        if self.ipv4mdt_address is not None:
                                            return True

                                        if self.ipv4mvpn_address is not None:
                                            return True

                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                            return True

                                        if self.ipv4vpn_address is not None:
                                            return True

                                        if self.ipv4vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv4vpna_mcastddress is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        if self.ipv6_flowspec_address is not None:
                                            return True

                                        if self.ipv6_label_address is not None:
                                            return True

                                        if self.ipv6_mcast_address is not None:
                                            return True

                                        if self.ipv6mvpn_address is not None:
                                            return True

                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                            return True

                                        if self.ipv6vpn_address is not None:
                                            return True

                                        if self.ipv6vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv6vpn_mcast_address is not None:
                                            return True

                                        if self.l2vpn_evpn_address is not None:
                                            return True

                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                            return True

                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                            return True

                                        if self.ls_ls_address is not None:
                                            return True

                                        if self.rt_constraint_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.neighbor_address is None:
                                        raise YPYModelError('Key property neighbor_address is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:session[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address = ' + str(self.neighbor_address) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.neighbor_address is not None:
                                        return True

                                    if self.connection_local_address is not None and self.connection_local_address._has_data():
                                        return True

                                    if self.connection_remote_address is not None and self.connection_remote_address._has_data():
                                        return True

                                    if self.connection_state is not None:
                                        return True

                                    if self.description is not None:
                                        return True

                                    if self.is_local_address_configured is not None:
                                        return True

                                    if self.local_as is not None:
                                        return True

                                    if self.messages_queued_in is not None:
                                        return True

                                    if self.messages_queued_out is not None:
                                        return True

                                    if self.nsr_enabled is not None:
                                        return True

                                    if self.nsr_state is not None:
                                        return True

                                    if self.postit_pending is not None:
                                        return True

                                    if self.remote_as is not None:
                                        return True

                                    if self.speaker_id is not None:
                                        return True

                                    if self.vrf_name is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sessions'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.session is not None:
                                    for child_ref in self.session:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions']['meta_info']


                        class Neighbors(object):
                            """
                            The BGP Neighbor table
                            
                            .. attribute:: neighbor
                            
                            	A BGP Neighbor table entry
                            	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.neighbor = YList()
                                self.neighbor.parent = self
                                self.neighbor.name = 'neighbor'


                            class Neighbor(object):
                                """
                                A BGP Neighbor table entry
                                
                                .. attribute:: neighbor_address  <key>
                                
                                	Neighbor address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: active_bmp_servers
                                
                                	BMP Servers to which the neighbor sends logs
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: actual_last_write_bytes
                                
                                	Actual size of last write
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: actual_last_write_reset_bytes
                                
                                	Actual size of last write before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: actual_second_last_write_bytes
                                
                                	Actual size of second last write
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: actual_second_last_write_reset_bytes
                                
                                	Actual size of second last write before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: af_data
                                
                                	Address family specific neighbor data
                                	**type**\: list of    :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData>`
                                
                                .. attribute:: attempted_last_write_bytes
                                
                                	Attempted size of last write
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: attempted_last_write_reset_bytes
                                
                                	Attempted size of last write before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: attempted_second_last_write_bytes
                                
                                	Attempted size of second last write
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: attempted_second_last_write_reset_bytes
                                
                                	Attempted size of second last write before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_minintervalval
                                
                                	BFD Mininterval for this peer
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_multiplierval
                                
                                	BFD Multiplier for this peer
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_session_created_state
                                
                                	BFD state for this peer
                                	**type**\:   :py:class:`BgpBfdStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdStateEnum>`
                                
                                .. attribute:: bfd_session_enable_mode
                                
                                	BFD enable mode for this peer
                                	**type**\:   :py:class:`BgpBfdEnableModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdEnableModeEnum>`
                                
                                .. attribute:: bfd_session_state
                                
                                	BFD state for this peer
                                	**type**\:   :py:class:`BgpBfdStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdStateEnum>`
                                
                                .. attribute:: bfd_state_ts
                                
                                	Timestamp since when nbr is in this bfd state
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bytes_read
                                
                                	Total bytes read
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: bytes_written
                                
                                	Total bytes written by write thread
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: configured_hold_time
                                
                                	Hold time (in secs) configured for this connection
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: configured_keepalive
                                
                                	Keepalive time (in secs) configured for this connection
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: configured_min_acc_hold_time
                                
                                	Minimum acceptable hold time from neighbor (in secs) configured for this connection
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: connect_retry_interval
                                
                                	Time (in secs) for connect retry timer
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: connection_admin_status
                                
                                	Administrative status of connection
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: connection_down_count
                                
                                	Number of times connection was dropped
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: connection_established_time
                                
                                	Time (in secs) that the connection has been established
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: connection_local_address
                                
                                	Local address for the connection
                                	**type**\:   :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress>`
                                
                                .. attribute:: connection_local_port
                                
                                	Local port for the connection
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: connection_remote_address
                                
                                	Remote address for the connection
                                	**type**\:   :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress>`
                                
                                .. attribute:: connection_remote_port
                                
                                	Remote port for the connection
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: connection_state
                                
                                	State of connection
                                	**type**\:   :py:class:`BgpConnStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnStateEnum>`
                                
                                .. attribute:: connection_up_count
                                
                                	Number of times the connection was established
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: count_last_write
                                
                                	Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: description
                                
                                	Description
                                	**type**\:  str
                                
                                .. attribute:: discard_as4_path
                                
                                	Discard AS4\_PATH in case there is a discrepancy in merging AS\_PATH and AS4\_PATH,retain ASPATH
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: discard_data_bytes
                                
                                	Remaining discard data (bytes) on Standby
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: dmz_link_bandwidth
                                
                                	Bandwidth of link to single\-hop eBGP peer
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: dynamic_neighbor
                                
                                	Dynamic neighbor
                                	**type**\:  bool
                                
                                .. attribute:: ebgp_recv_dmz
                                
                                	Receive Bandwidth of link to single\-hop eBGP peer
                                	**type**\:  bool
                                
                                .. attribute:: ebgp_send_dmz_mode
                                
                                	Ebgp send dmz link bw mode
                                	**type**\:   :py:class:`BgpEbgpSendDmzEnableModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableModeEnum>`
                                
                                .. attribute:: ebgp_time_to_live
                                
                                	Maximum number of hops for external BGP neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: egress_peer_engineering_enabled
                                
                                	Indicates if Egress Peer Engineering is enabled
                                	**type**\:  bool
                                
                                .. attribute:: error_notifies_received
                                
                                	Number of error notifications received on the connection
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: error_notifies_sent
                                
                                	Number of error notifications sent on the connection
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fpbsn_offset
                                
                                	First standby PDU boundary SeqNo offset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fssn_offset
                                
                                	First standby SeqNo offset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: gr_restart_time
                                
                                	Neighbor restart time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: gr_stale_path_time
                                
                                	Neighbor stale\-path time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: graceful_maintenance
                                
                                	Graceful Maintenance
                                	**type**\:   :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.GracefulMaintenance>`
                                
                                .. attribute:: graceful_restart_enabled_nbr
                                
                                	Neighbor supports graceful\-restart
                                	**type**\:  bool
                                
                                .. attribute:: has_internal_link
                                
                                	Internal link to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: hold_time
                                
                                	Hold time (in secs) negotiated for this connection
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: ignore_connected
                                
                                	If true, the VPN client isan IBGP CE peer
                                	**type**\:  bool
                                
                                .. attribute:: internal_vpn_client
                                
                                	If true, don't do NHconnected check for nbr
                                	**type**\:  bool
                                
                                .. attribute:: io_armed
                                
                                	If true, socket has beenauto\-armed for io control
                                	**type**\:  bool
                                
                                .. attribute:: is4_byte_as_capability_received
                                
                                	4\-byte AScapability received
                                	**type**\:  bool
                                
                                .. attribute:: is4_byte_as_capability_sent
                                
                                	4\-byte AScapability Snt
                                	**type**\:  bool
                                
                                .. attribute:: is_administratively_shut_down
                                
                                	Neighbor is administratively shut down
                                	**type**\:  bool
                                
                                .. attribute:: is_capability_negotiation_performed
                                
                                	Capability negotiation performed
                                	**type**\:  bool
                                
                                .. attribute:: is_capability_negotiation_suppressed
                                
                                	Capability negotiation suppressed
                                	**type**\:  bool
                                
                                .. attribute:: is_ebgp_multihop_bgpmpls_forwarding_disabled
                                
                                	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ebgp_peer_as_league
                                
                                	EBGP peer belongs to AS League
                                	**type**\:  bool
                                
                                .. attribute:: is_ebgp_peer_common_admin
                                
                                	EBGP peer with common administation
                                	**type**\:  bool
                                
                                .. attribute:: is_external_neighbor_not_directly_connected
                                
                                	External neighbor not directly connected
                                	**type**\:  bool
                                
                                .. attribute:: is_gr_aware
                                
                                	GR awareness received
                                	**type**\:  bool
                                
                                .. attribute:: is_local_address_configured
                                
                                	Local address configured for the neighbor connection
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_max_prefix_shutdown
                                
                                	Neighbor shut down because it exceeded max prfx count
                                	**type**\:  bool
                                
                                .. attribute:: is_out_of_memory_forced_up
                                
                                	Neighbor forced up during a low memory condition
                                	**type**\:  bool
                                
                                .. attribute:: is_out_of_memory_shutdown
                                
                                	Neighbor shut down during a SEVERE low memory condition
                                	**type**\:  bool
                                
                                .. attribute:: is_passive_close
                                
                                	If true, active socket canbe closed if passive openis received for a GRcapable neighbor
                                	**type**\:  bool
                                
                                .. attribute:: is_read_disabled
                                
                                	If true, socket read isdisabled
                                	**type**\:  bool
                                
                                .. attribute:: is_route_refresh_capability_received
                                
                                	Route refresh capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_route_refresh_old_capability_received
                                
                                	Route refresh old capability received
                                	**type**\:  bool
                                
                                .. attribute:: keep_alive_time
                                
                                	Keepalive time (in secs) negotiated for this connection
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: last_ackd_seq_no
                                
                                	SeqNo of the last Ackd byte
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_k_aerror_reset
                                
                                	Duration (in secs) since last time that an error was encountered after KA expiry
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_k_aexpiry_reset
                                
                                	Time (in secs) since last KA timer expiry before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_k_anotsent_reset
                                
                                	Duration (in secs) since last time that KA was not sent before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_k_astart_reset
                                
                                	Time (in secs) since the last KA timer start before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_notify_error_code
                                
                                	Code for the last error notification seen on the connection
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: last_notify_error_subcode
                                
                                	Error subcode of the last error notification seen on the connection
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: last_write_event
                                
                                	Time (in secs) since last write thread event
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: local_as
                                
                                	Local AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_as_dual_as
                                
                                	Local AS Dual\-AS option
                                	**type**\:  bool
                                
                                .. attribute:: local_as_dual_as_mode_native
                                
                                	Applies only if Local AS Dual\-AS option is enabled. Indicates if Dual\-AS mode is native
                                	**type**\:  bool
                                
                                .. attribute:: local_as_no_prepend
                                
                                	Option to not prepend the Local AS to announcements
                                	**type**\:  bool
                                
                                .. attribute:: local_as_replace_as
                                
                                	Local AS Replace\-AS option
                                	**type**\:  bool
                                
                                .. attribute:: message_statistics
                                
                                	Message statistics
                                	**type**\:   :py:class:`MessageStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics>`
                                
                                .. attribute:: messages_queued_in
                                
                                	No. of msgs on receive queue
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: messages_queued_out
                                
                                	No. of messages on send queue
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: messages_received
                                
                                	Number of messages received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: messages_sent
                                
                                	Number of messages sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: min_advertise_interval
                                
                                	Minimum advertisement interval, secs part
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: min_advertise_interval_msecs
                                
                                	Minimum advertisement interval, msecs part
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: min_origination_interval
                                
                                	Minimum origination interval (in secs)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: msg_log_in
                                
                                	Message in log count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: msg_log_out
                                
                                	Message out log count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: multi_protocol_capability_received
                                
                                	Multi\-protocol capability has been received
                                	**type**\:  bool
                                
                                .. attribute:: nbr_cluster_id
                                
                                	Cluster id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nbr_enforce_first_as
                                
                                	Neighbor enforce first AS
                                	**type**\:  bool
                                
                                .. attribute:: nbr_in_cluster
                                
                                	Type of cluster\_id\:undefined/number/Ip address
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: negotiated_protocol_version
                                
                                	Negotiated protocol version
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: neighbor_interface_handle
                                
                                	Interface Handle of Neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_local_as
                                
                                	Local AS configured on the neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_enabled
                                
                                	Neighbor supports NSR
                                	**type**\:  bool
                                
                                .. attribute:: nsr_state
                                
                                	NSR state
                                	**type**\:   :py:class:`BgpSyncNbrNsrStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrStateEnum>`
                                
                                .. attribute:: open_check_error_code
                                
                                	Open check error code
                                	**type**\:   :py:class:`BgpOpenCheckErrEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpOpenCheckErrEnum>`
                                
                                .. attribute:: peer_error_code
                                
                                	If peer closed, error received from transport
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: peer_reset_reason
                                
                                	Reason for last peer close event
                                	**type**\:   :py:class:`BgpPeerResetReasonIndexEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPeerResetReasonIndexEnum>`
                                
                                .. attribute:: performance_statistics
                                
                                	Performance statistics
                                	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.PerformanceStatistics>`
                                
                                .. attribute:: previous_connection_state
                                
                                	Previous state of connection
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: read_armed
                                
                                	If true, socket has beenauto\-armed for read
                                	**type**\:  bool
                                
                                .. attribute:: received_notification_info
                                
                                	Information on the last notification received
                                	**type**\:   :py:class:`ReceivedNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo>`
                                
                                .. attribute:: remote_as
                                
                                	Remote AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_as_number
                                
                                	Remote AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reset_notification_sent
                                
                                	Notification was sent during last reset
                                	**type**\:  bool
                                
                                .. attribute:: reset_reason
                                
                                	Reason for last connection reset
                                	**type**\:   :py:class:`BgpResetReasonIndexEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndexEnum>`
                                
                                .. attribute:: router_id
                                
                                	Router ID for the neighbor
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rpki_allow_invalid
                                
                                	Prefix v. allow invalid
                                	**type**\:  bool
                                
                                .. attribute:: rpki_disable
                                
                                	Prefix validation disabled
                                	**type**\:  bool
                                
                                .. attribute:: rpki_signal_ibgp
                                
                                	Prefix v. signal ibgp
                                	**type**\:  bool
                                
                                .. attribute:: rpki_use_validity
                                
                                	Prefix v. use validity
                                	**type**\:  bool
                                
                                .. attribute:: second_last_k_aexpiry_reset
                                
                                	Time (in secs) since second last KA timer expiry before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: second_last_k_astart_reset
                                
                                	Time (in secs) since the second last KA timer start before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: second_last_write_event
                                
                                	Time (in secs) since second last write thread event
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: send_notification_info
                                
                                	Information on the last notification sent
                                	**type**\:   :py:class:`SendNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo>`
                                
                                .. attribute:: socket_read_bytes
                                
                                	Total read bytes value insocket\-lib
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: speaker_id
                                
                                	Speaker this neighbor is allocated to
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: standby_rp
                                
                                	Standby RP socket inited for Active Open
                                	**type**\:  bool
                                
                                .. attribute:: suppress4_byte_as
                                
                                	Suppress 4byteas capability
                                	**type**\:  bool
                                
                                .. attribute:: tcp_init_sync_done_time_spec
                                
                                	Time when neighbor entered TCP Init Sync Done
                                	**type**\:   :py:class:`TcpInitSyncDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec>`
                                
                                .. attribute:: tcp_init_sync_phase_two_time_spec
                                
                                	Time when neighbor entered TCP Init Sync Phase Two
                                	**type**\:   :py:class:`TcpInitSyncPhaseTwoTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec>`
                                
                                .. attribute:: tcp_init_sync_time_spec
                                
                                	Time When neighbor entered TCP Init Sync
                                	**type**\:   :py:class:`TcpInitSyncTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncTimeSpec>`
                                
                                .. attribute:: tcp_session_open_mode
                                
                                	The TCP mode to be used to set up BGP session with the neighbor
                                	**type**\:   :py:class:`BgpTcpModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpModeEnum>`
                                
                                .. attribute:: tcpmss
                                
                                	Neighbor TCP Maximum Segment                     size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_last_cb
                                
                                	CB
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: time_last_cb_reset
                                
                                	Last CB before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_last_fb
                                
                                	FB
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: time_since_connection_last_dropped
                                
                                	Time since the connection last went down (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: time_since_last_read
                                
                                	Time (in secs) since last read
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: time_since_last_read_reset
                                
                                	Time (in secs) since last read before last reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: time_since_last_update
                                
                                	Time (in secs) since last update message was received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: time_since_last_write
                                
                                	Time (in secs) since last write
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: time_since_last_write_reset
                                
                                	Time (in secs) since last write before last reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: time_since_second_last_write
                                
                                	Time (in secs) since second  last write
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: time_since_second_last_write_reset
                                
                                	Time (in secs) since last write before last reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: tos_type
                                
                                	Precedence or DSCP type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_value
                                
                                	Precedence or DSCP value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ttl_security_enabled
                                
                                	TTL Security enabled
                                	**type**\:  bool
                                
                                .. attribute:: update_bytes_read
                                
                                	Total update bytes read
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: update_messages_in
                                
                                	No. of update msgs received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_messages_out
                                
                                	No. of update messages sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vrf_name
                                
                                	Name of the VRF
                                	**type**\:  str
                                
                                .. attribute:: write_armed
                                
                                	If true, socket has beenauto\-armed for write
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.neighbor_address = None
                                    self.active_bmp_servers = None
                                    self.actual_last_write_bytes = None
                                    self.actual_last_write_reset_bytes = None
                                    self.actual_second_last_write_bytes = None
                                    self.actual_second_last_write_reset_bytes = None
                                    self.af_data = YList()
                                    self.af_data.parent = self
                                    self.af_data.name = 'af_data'
                                    self.attempted_last_write_bytes = None
                                    self.attempted_last_write_reset_bytes = None
                                    self.attempted_second_last_write_bytes = None
                                    self.attempted_second_last_write_reset_bytes = None
                                    self.bfd_minintervalval = None
                                    self.bfd_multiplierval = None
                                    self.bfd_session_created_state = None
                                    self.bfd_session_enable_mode = None
                                    self.bfd_session_state = None
                                    self.bfd_state_ts = None
                                    self.bytes_read = None
                                    self.bytes_written = None
                                    self.configured_hold_time = None
                                    self.configured_keepalive = None
                                    self.configured_min_acc_hold_time = None
                                    self.connect_retry_interval = None
                                    self.connection_admin_status = None
                                    self.connection_down_count = None
                                    self.connection_established_time = None
                                    self.connection_local_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress()
                                    self.connection_local_address.parent = self
                                    self.connection_local_port = None
                                    self.connection_remote_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress()
                                    self.connection_remote_address.parent = self
                                    self.connection_remote_port = None
                                    self.connection_state = None
                                    self.connection_up_count = None
                                    self.count_last_write = None
                                    self.description = None
                                    self.discard_as4_path = None
                                    self.discard_data_bytes = None
                                    self.dmz_link_bandwidth = None
                                    self.dynamic_neighbor = None
                                    self.ebgp_recv_dmz = None
                                    self.ebgp_send_dmz_mode = None
                                    self.ebgp_time_to_live = None
                                    self.egress_peer_engineering_enabled = None
                                    self.error_notifies_received = None
                                    self.error_notifies_sent = None
                                    self.fpbsn_offset = None
                                    self.fssn_offset = None
                                    self.gr_restart_time = None
                                    self.gr_stale_path_time = None
                                    self.graceful_maintenance = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.GracefulMaintenance()
                                    self.graceful_maintenance.parent = self
                                    self.graceful_restart_enabled_nbr = None
                                    self.has_internal_link = None
                                    self.hold_time = None
                                    self.ignore_connected = None
                                    self.internal_vpn_client = None
                                    self.io_armed = None
                                    self.is4_byte_as_capability_received = None
                                    self.is4_byte_as_capability_sent = None
                                    self.is_administratively_shut_down = None
                                    self.is_capability_negotiation_performed = None
                                    self.is_capability_negotiation_suppressed = None
                                    self.is_ebgp_multihop_bgpmpls_forwarding_disabled = None
                                    self.is_ebgp_peer_as_league = None
                                    self.is_ebgp_peer_common_admin = None
                                    self.is_external_neighbor_not_directly_connected = None
                                    self.is_gr_aware = None
                                    self.is_local_address_configured = None
                                    self.is_neighbor_max_prefix_shutdown = None
                                    self.is_out_of_memory_forced_up = None
                                    self.is_out_of_memory_shutdown = None
                                    self.is_passive_close = None
                                    self.is_read_disabled = None
                                    self.is_route_refresh_capability_received = None
                                    self.is_route_refresh_old_capability_received = None
                                    self.keep_alive_time = None
                                    self.last_ackd_seq_no = None
                                    self.last_k_aerror_reset = None
                                    self.last_k_aexpiry_reset = None
                                    self.last_k_anotsent_reset = None
                                    self.last_k_astart_reset = None
                                    self.last_notify_error_code = None
                                    self.last_notify_error_subcode = None
                                    self.last_write_event = None
                                    self.local_as = None
                                    self.local_as_dual_as = None
                                    self.local_as_dual_as_mode_native = None
                                    self.local_as_no_prepend = None
                                    self.local_as_replace_as = None
                                    self.message_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics()
                                    self.message_statistics.parent = self
                                    self.messages_queued_in = None
                                    self.messages_queued_out = None
                                    self.messages_received = None
                                    self.messages_sent = None
                                    self.min_advertise_interval = None
                                    self.min_advertise_interval_msecs = None
                                    self.min_origination_interval = None
                                    self.msg_log_in = None
                                    self.msg_log_out = None
                                    self.multi_protocol_capability_received = None
                                    self.nbr_cluster_id = None
                                    self.nbr_enforce_first_as = None
                                    self.nbr_in_cluster = None
                                    self.negotiated_protocol_version = None
                                    self.neighbor_interface_handle = None
                                    self.neighbor_local_as = None
                                    self.nsr_enabled = None
                                    self.nsr_state = None
                                    self.open_check_error_code = None
                                    self.peer_error_code = None
                                    self.peer_reset_reason = None
                                    self.performance_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.PerformanceStatistics()
                                    self.performance_statistics.parent = self
                                    self.previous_connection_state = None
                                    self.read_armed = None
                                    self.received_notification_info = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo()
                                    self.received_notification_info.parent = self
                                    self.remote_as = None
                                    self.remote_as_number = None
                                    self.reset_notification_sent = None
                                    self.reset_reason = None
                                    self.router_id = None
                                    self.rpki_allow_invalid = None
                                    self.rpki_disable = None
                                    self.rpki_signal_ibgp = None
                                    self.rpki_use_validity = None
                                    self.second_last_k_aexpiry_reset = None
                                    self.second_last_k_astart_reset = None
                                    self.second_last_write_event = None
                                    self.send_notification_info = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo()
                                    self.send_notification_info.parent = self
                                    self.socket_read_bytes = None
                                    self.speaker_id = None
                                    self.standby_rp = None
                                    self.suppress4_byte_as = None
                                    self.tcp_init_sync_done_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec()
                                    self.tcp_init_sync_done_time_spec.parent = self
                                    self.tcp_init_sync_phase_two_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec()
                                    self.tcp_init_sync_phase_two_time_spec.parent = self
                                    self.tcp_init_sync_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncTimeSpec()
                                    self.tcp_init_sync_time_spec.parent = self
                                    self.tcp_session_open_mode = None
                                    self.tcpmss = None
                                    self.time_last_cb = None
                                    self.time_last_cb_reset = None
                                    self.time_last_fb = None
                                    self.time_since_connection_last_dropped = None
                                    self.time_since_last_read = None
                                    self.time_since_last_read_reset = None
                                    self.time_since_last_update = None
                                    self.time_since_last_write = None
                                    self.time_since_last_write_reset = None
                                    self.time_since_second_last_write = None
                                    self.time_since_second_last_write_reset = None
                                    self.tos_type = None
                                    self.tos_value = None
                                    self.ttl_security_enabled = None
                                    self.update_bytes_read = None
                                    self.update_messages_in = None
                                    self.update_messages_out = None
                                    self.vrf_name = None
                                    self.write_armed = None


                                class ConnectionLocalAddress(object):
                                    """
                                    Local address for the connection
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpnvpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnvplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4mdt_address = None
                                        self.ipv4mvpn_address = None
                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                        self.ipv4sr_policy_address.parent = self
                                        self.ipv4vpn_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                        self.ipv6sr_policy_address.parent = self
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_flowspec_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.l2vpn_evpn_address = None
                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnvplsAddress()
                                        self.l2vpnvpls_address.parent = self
                                        self.ls_ls_address = None
                                        self.rt_constraint_address = None


                                    class L2VpnvplsAddress(object):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnvplsAddress']['meta_info']


                                    class L2VpnMspwAddress(object):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress']['meta_info']


                                    class Ipv4SrPolicyAddress(object):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress']['meta_info']


                                    class Ipv6SrPolicyAddress(object):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv6_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv6_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connection-local-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.afi is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv4_flowspec_address is not None:
                                            return True

                                        if self.ipv4_label_address is not None:
                                            return True

                                        if self.ipv4_mcast_address is not None:
                                            return True

                                        if self.ipv4_tunnel_address is not None:
                                            return True

                                        if self.ipv4mdt_address is not None:
                                            return True

                                        if self.ipv4mvpn_address is not None:
                                            return True

                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                            return True

                                        if self.ipv4vpn_address is not None:
                                            return True

                                        if self.ipv4vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv4vpna_mcastddress is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        if self.ipv6_flowspec_address is not None:
                                            return True

                                        if self.ipv6_label_address is not None:
                                            return True

                                        if self.ipv6_mcast_address is not None:
                                            return True

                                        if self.ipv6mvpn_address is not None:
                                            return True

                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                            return True

                                        if self.ipv6vpn_address is not None:
                                            return True

                                        if self.ipv6vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv6vpn_mcast_address is not None:
                                            return True

                                        if self.l2vpn_evpn_address is not None:
                                            return True

                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                            return True

                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                            return True

                                        if self.ls_ls_address is not None:
                                            return True

                                        if self.rt_constraint_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress']['meta_info']


                                class ConnectionRemoteAddress(object):
                                    """
                                    Remote address for the connection
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpnvpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnvplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4mdt_address = None
                                        self.ipv4mvpn_address = None
                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                        self.ipv4sr_policy_address.parent = self
                                        self.ipv4vpn_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                        self.ipv6sr_policy_address.parent = self
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_flowspec_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.l2vpn_evpn_address = None
                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnvplsAddress()
                                        self.l2vpnvpls_address.parent = self
                                        self.ls_ls_address = None
                                        self.rt_constraint_address = None


                                    class L2VpnvplsAddress(object):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnvplsAddress']['meta_info']


                                    class L2VpnMspwAddress(object):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress']['meta_info']


                                    class Ipv4SrPolicyAddress(object):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress']['meta_info']


                                    class Ipv6SrPolicyAddress(object):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv6_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv6_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connection-remote-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.afi is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv4_flowspec_address is not None:
                                            return True

                                        if self.ipv4_label_address is not None:
                                            return True

                                        if self.ipv4_mcast_address is not None:
                                            return True

                                        if self.ipv4_tunnel_address is not None:
                                            return True

                                        if self.ipv4mdt_address is not None:
                                            return True

                                        if self.ipv4mvpn_address is not None:
                                            return True

                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                            return True

                                        if self.ipv4vpn_address is not None:
                                            return True

                                        if self.ipv4vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv4vpna_mcastddress is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        if self.ipv6_flowspec_address is not None:
                                            return True

                                        if self.ipv6_label_address is not None:
                                            return True

                                        if self.ipv6_mcast_address is not None:
                                            return True

                                        if self.ipv6mvpn_address is not None:
                                            return True

                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                            return True

                                        if self.ipv6vpn_address is not None:
                                            return True

                                        if self.ipv6vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv6vpn_mcast_address is not None:
                                            return True

                                        if self.l2vpn_evpn_address is not None:
                                            return True

                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                            return True

                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                            return True

                                        if self.ls_ls_address is not None:
                                            return True

                                        if self.rt_constraint_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress']['meta_info']


                                class SendNotificationInfo(object):
                                    """
                                    Information on the last notification sent
                                    
                                    .. attribute:: last_notification_data
                                    
                                    	Message data in last notification
                                    	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData>`
                                    
                                    .. attribute:: notification_error_code
                                    
                                    	Error code in last notification
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: notification_error_subcode
                                    
                                    	Error subcode in last notification
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: time_since_last_notification
                                    
                                    	Time since the last notification was sent or received (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.last_notification_data = YList()
                                        self.last_notification_data.parent = self
                                        self.last_notification_data.name = 'last_notification_data'
                                        self.notification_error_code = None
                                        self.notification_error_subcode = None
                                        self.time_since_last_notification = None


                                    class LastNotificationData(object):
                                        """
                                        Message data in last notification
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.entry = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-notification-data'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.entry is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:send-notification-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.last_notification_data is not None:
                                            for child_ref in self.last_notification_data:
                                                if child_ref._has_data():
                                                    return True

                                        if self.notification_error_code is not None:
                                            return True

                                        if self.notification_error_subcode is not None:
                                            return True

                                        if self.time_since_last_notification is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo']['meta_info']


                                class ReceivedNotificationInfo(object):
                                    """
                                    Information on the last notification received
                                    
                                    .. attribute:: last_notification_data
                                    
                                    	Message data in last notification
                                    	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData>`
                                    
                                    .. attribute:: notification_error_code
                                    
                                    	Error code in last notification
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: notification_error_subcode
                                    
                                    	Error subcode in last notification
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: time_since_last_notification
                                    
                                    	Time since the last notification was sent or received (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.last_notification_data = YList()
                                        self.last_notification_data.parent = self
                                        self.last_notification_data.name = 'last_notification_data'
                                        self.notification_error_code = None
                                        self.notification_error_subcode = None
                                        self.time_since_last_notification = None


                                    class LastNotificationData(object):
                                        """
                                        Message data in last notification
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.entry = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-notification-data'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.entry is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:received-notification-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.last_notification_data is not None:
                                            for child_ref in self.last_notification_data:
                                                if child_ref._has_data():
                                                    return True

                                        if self.notification_error_code is not None:
                                            return True

                                        if self.notification_error_subcode is not None:
                                            return True

                                        if self.time_since_last_notification is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo']['meta_info']


                                class PerformanceStatistics(object):
                                    """
                                    Performance statistics
                                    
                                    .. attribute:: active_collision
                                    
                                    	Number of Closed Active connections for this neighbor due to collision 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: actives
                                    
                                    	Number of retried Active opens for this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: control_to_read_thread_trigger
                                    
                                    	Number of times io\-control thread trigger read thread
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: control_to_write_thread_trigger
                                    
                                    	Number of times io\-control thread trigger write thread
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: data_bytes_read
                                    
                                    	No. of bytes of data read
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: data_bytes_written
                                    
                                    	No. of data bytes written
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: failed_post_actives
                                    
                                    	Number of Active Opens that failed in the Post Active State for this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: high_throttled_read
                                    
                                    	Num of socket reads after nbr crossed high threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inbound_update_messages
                                    
                                    	Number of inbound update messages processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inbound_update_messages_time
                                    
                                    	Time spent processing inbound update messages (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: io_read_time
                                    
                                    	Time spent reading inbound data (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: io_write_time
                                    
                                    	Time spent writing outbound data (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: last_nsr_scoped_sync
                                    
                                    	Last time NSR scoped syncwas done for the neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_sent_seq_no
                                    
                                    	Seq No of the last sent byte
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: low_throttled_read
                                    
                                    	Num socket reads after nbrs crossed low threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_read_size
                                    
                                    	Size of largest socket (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: nbr_fd
                                    
                                    	Primary FD, per nbr
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: nbr_flags
                                    
                                    	Nbr flags, per thread
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: network_status
                                    
                                    	Socket status, TRUE if socket closed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_oper_down_count
                                    
                                    	Number of times NSR scoped sync has been done
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: passive_collision
                                    
                                    	Number of Closed Remote opens for this neighborneighbor due to collision 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: passives
                                    
                                    	Number of retried Passive opens for this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: read_calls_count
                                    
                                    	No. of calls to function to read inbound data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: read_messages_count
                                    
                                    	Number of BGP messages read
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: read_throttles
                                    
                                    	Number of partial read throttles
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rejected_passives
                                    
                                    	Number of rejected Passive opens for this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reset_flags
                                    
                                    	Reset flags, per thread
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reset_retries
                                    
                                    	Reset Retries, per nbr
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: subgroup_list_time
                                    
                                    	Time spent processing sub\-group message list  (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: sync_flags
                                    
                                    	Sync flags, per nbr
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: time_since_last_throttled_read
                                    
                                    	Time (in secs) since last read after being throttled
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: write_calls_count
                                    
                                    	No. of calls to function to write outbound data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_queue_calls_count
                                    
                                    	No. of calls to function to process write queue
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_queue_messages_count
                                    
                                    	Number of write queue messages processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_queue_time
                                    
                                    	Time spent processing write queue (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: write_subgroup_calls_count
                                    
                                    	No. of calls to function to process sub\-group message list
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_subgroup_messages_count
                                    
                                    	Number of sub\-group msgs processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.active_collision = None
                                        self.actives = None
                                        self.control_to_read_thread_trigger = None
                                        self.control_to_write_thread_trigger = None
                                        self.data_bytes_read = None
                                        self.data_bytes_written = None
                                        self.failed_post_actives = None
                                        self.high_throttled_read = None
                                        self.inbound_update_messages = None
                                        self.inbound_update_messages_time = None
                                        self.io_read_time = None
                                        self.io_write_time = None
                                        self.last_nsr_scoped_sync = None
                                        self.last_sent_seq_no = None
                                        self.low_throttled_read = None
                                        self.maximum_read_size = None
                                        self.nbr_fd = None
                                        self.nbr_flags = None
                                        self.network_status = None
                                        self.nsr_oper_down_count = None
                                        self.passive_collision = None
                                        self.passives = None
                                        self.read_calls_count = None
                                        self.read_messages_count = None
                                        self.read_throttles = None
                                        self.rejected_passives = None
                                        self.reset_flags = None
                                        self.reset_retries = None
                                        self.subgroup_list_time = None
                                        self.sync_flags = None
                                        self.time_since_last_throttled_read = None
                                        self.write_calls_count = None
                                        self.write_queue_calls_count = None
                                        self.write_queue_messages_count = None
                                        self.write_queue_time = None
                                        self.write_subgroup_calls_count = None
                                        self.write_subgroup_messages_count = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:performance-statistics'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.active_collision is not None:
                                            return True

                                        if self.actives is not None:
                                            return True

                                        if self.control_to_read_thread_trigger is not None:
                                            return True

                                        if self.control_to_write_thread_trigger is not None:
                                            return True

                                        if self.data_bytes_read is not None:
                                            return True

                                        if self.data_bytes_written is not None:
                                            return True

                                        if self.failed_post_actives is not None:
                                            return True

                                        if self.high_throttled_read is not None:
                                            return True

                                        if self.inbound_update_messages is not None:
                                            return True

                                        if self.inbound_update_messages_time is not None:
                                            return True

                                        if self.io_read_time is not None:
                                            return True

                                        if self.io_write_time is not None:
                                            return True

                                        if self.last_nsr_scoped_sync is not None:
                                            return True

                                        if self.last_sent_seq_no is not None:
                                            return True

                                        if self.low_throttled_read is not None:
                                            return True

                                        if self.maximum_read_size is not None:
                                            return True

                                        if self.nbr_fd is not None:
                                            return True

                                        if self.nbr_flags is not None:
                                            return True

                                        if self.network_status is not None:
                                            return True

                                        if self.nsr_oper_down_count is not None:
                                            return True

                                        if self.passive_collision is not None:
                                            return True

                                        if self.passives is not None:
                                            return True

                                        if self.read_calls_count is not None:
                                            return True

                                        if self.read_messages_count is not None:
                                            return True

                                        if self.read_throttles is not None:
                                            return True

                                        if self.rejected_passives is not None:
                                            return True

                                        if self.reset_flags is not None:
                                            return True

                                        if self.reset_retries is not None:
                                            return True

                                        if self.subgroup_list_time is not None:
                                            return True

                                        if self.sync_flags is not None:
                                            return True

                                        if self.time_since_last_throttled_read is not None:
                                            return True

                                        if self.write_calls_count is not None:
                                            return True

                                        if self.write_queue_calls_count is not None:
                                            return True

                                        if self.write_queue_messages_count is not None:
                                            return True

                                        if self.write_queue_time is not None:
                                            return True

                                        if self.write_subgroup_calls_count is not None:
                                            return True

                                        if self.write_subgroup_messages_count is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.PerformanceStatistics']['meta_info']


                                class MessageStatistics(object):
                                    """
                                    Message statistics
                                    
                                    .. attribute:: keepalive
                                    
                                    	Keepalive
                                    	**type**\:   :py:class:`Keepalive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive>`
                                    
                                    .. attribute:: notification
                                    
                                    	Notification
                                    	**type**\:   :py:class:`Notification <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification>`
                                    
                                    .. attribute:: open
                                    
                                    	Open
                                    	**type**\:   :py:class:`Open <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open>`
                                    
                                    .. attribute:: route_refresh
                                    
                                    	Route refresh
                                    	**type**\:   :py:class:`RouteRefresh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh>`
                                    
                                    .. attribute:: total
                                    
                                    	Total
                                    	**type**\:   :py:class:`Total <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total>`
                                    
                                    .. attribute:: update
                                    
                                    	Update
                                    	**type**\:   :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.keepalive = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive()
                                        self.keepalive.parent = self
                                        self.notification = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification()
                                        self.notification.parent = self
                                        self.open = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open()
                                        self.open.parent = self
                                        self.route_refresh = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh()
                                        self.route_refresh.parent = self
                                        self.total = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total()
                                        self.total.parent = self
                                        self.update = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update()
                                        self.update.parent = self


                                    class Open(object):
                                        """
                                        Open
                                        
                                        .. attribute:: rx
                                        
                                        	Receive
                                        	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx>`
                                        
                                        .. attribute:: tx
                                        
                                        	Transmit
                                        	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.rx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx()
                                            self.rx.parent = self
                                            self.tx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx()
                                            self.tx.parent = self


                                        class Tx(object):
                                            """
                                            Transmit
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.count = None
                                                self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec()
                                                self.last_time_spec.parent = self


                                            class LastTimeSpec(object):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.count is not None:
                                                    return True

                                                if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx']['meta_info']


                                        class Rx(object):
                                            """
                                            Receive
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.count = None
                                                self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec()
                                                self.last_time_spec.parent = self


                                            class LastTimeSpec(object):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.count is not None:
                                                    return True

                                                if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:open'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.rx is not None and self.rx._has_data():
                                                return True

                                            if self.tx is not None and self.tx._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open']['meta_info']


                                    class Notification(object):
                                        """
                                        Notification
                                        
                                        .. attribute:: rx
                                        
                                        	Receive
                                        	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx>`
                                        
                                        .. attribute:: tx
                                        
                                        	Transmit
                                        	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.rx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx()
                                            self.rx.parent = self
                                            self.tx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx()
                                            self.tx.parent = self


                                        class Tx(object):
                                            """
                                            Transmit
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.count = None
                                                self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec()
                                                self.last_time_spec.parent = self


                                            class LastTimeSpec(object):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.count is not None:
                                                    return True

                                                if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx']['meta_info']


                                        class Rx(object):
                                            """
                                            Receive
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.count = None
                                                self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec()
                                                self.last_time_spec.parent = self


                                            class LastTimeSpec(object):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.count is not None:
                                                    return True

                                                if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:notification'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.rx is not None and self.rx._has_data():
                                                return True

                                            if self.tx is not None and self.tx._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification']['meta_info']


                                    class Update(object):
                                        """
                                        Update
                                        
                                        .. attribute:: rx
                                        
                                        	Receive
                                        	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx>`
                                        
                                        .. attribute:: tx
                                        
                                        	Transmit
                                        	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.rx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx()
                                            self.rx.parent = self
                                            self.tx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx()
                                            self.tx.parent = self


                                        class Tx(object):
                                            """
                                            Transmit
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.count = None
                                                self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec()
                                                self.last_time_spec.parent = self


                                            class LastTimeSpec(object):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.count is not None:
                                                    return True

                                                if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx']['meta_info']


                                        class Rx(object):
                                            """
                                            Receive
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.count = None
                                                self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec()
                                                self.last_time_spec.parent = self


                                            class LastTimeSpec(object):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.count is not None:
                                                    return True

                                                if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.rx is not None and self.rx._has_data():
                                                return True

                                            if self.tx is not None and self.tx._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update']['meta_info']


                                    class Keepalive(object):
                                        """
                                        Keepalive
                                        
                                        .. attribute:: rx
                                        
                                        	Receive
                                        	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx>`
                                        
                                        .. attribute:: tx
                                        
                                        	Transmit
                                        	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.rx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx()
                                            self.rx.parent = self
                                            self.tx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx()
                                            self.tx.parent = self


                                        class Tx(object):
                                            """
                                            Transmit
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.count = None
                                                self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec()
                                                self.last_time_spec.parent = self


                                            class LastTimeSpec(object):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.count is not None:
                                                    return True

                                                if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx']['meta_info']


                                        class Rx(object):
                                            """
                                            Receive
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.count = None
                                                self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec()
                                                self.last_time_spec.parent = self


                                            class LastTimeSpec(object):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.count is not None:
                                                    return True

                                                if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:keepalive'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.rx is not None and self.rx._has_data():
                                                return True

                                            if self.tx is not None and self.tx._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive']['meta_info']


                                    class RouteRefresh(object):
                                        """
                                        Route refresh
                                        
                                        .. attribute:: rx
                                        
                                        	Receive
                                        	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx>`
                                        
                                        .. attribute:: tx
                                        
                                        	Transmit
                                        	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.rx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx()
                                            self.rx.parent = self
                                            self.tx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx()
                                            self.tx.parent = self


                                        class Tx(object):
                                            """
                                            Transmit
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.count = None
                                                self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec()
                                                self.last_time_spec.parent = self


                                            class LastTimeSpec(object):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.count is not None:
                                                    return True

                                                if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx']['meta_info']


                                        class Rx(object):
                                            """
                                            Receive
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.count = None
                                                self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec()
                                                self.last_time_spec.parent = self


                                            class LastTimeSpec(object):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.count is not None:
                                                    return True

                                                if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:route-refresh'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.rx is not None and self.rx._has_data():
                                                return True

                                            if self.tx is not None and self.tx._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh']['meta_info']


                                    class Total(object):
                                        """
                                        Total
                                        
                                        .. attribute:: rx
                                        
                                        	Receive
                                        	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx>`
                                        
                                        .. attribute:: tx
                                        
                                        	Transmit
                                        	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.rx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx()
                                            self.rx.parent = self
                                            self.tx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx()
                                            self.tx.parent = self


                                        class Tx(object):
                                            """
                                            Transmit
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.count = None
                                                self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec()
                                                self.last_time_spec.parent = self


                                            class LastTimeSpec(object):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.count is not None:
                                                    return True

                                                if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx']['meta_info']


                                        class Rx(object):
                                            """
                                            Receive
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.count = None
                                                self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec()
                                                self.last_time_spec.parent = self


                                            class LastTimeSpec(object):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.count is not None:
                                                    return True

                                                if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:total'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.rx is not None and self.rx._has_data():
                                                return True

                                            if self.tx is not None and self.tx._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:message-statistics'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.keepalive is not None and self.keepalive._has_data():
                                            return True

                                        if self.notification is not None and self.notification._has_data():
                                            return True

                                        if self.open is not None and self.open._has_data():
                                            return True

                                        if self.route_refresh is not None and self.route_refresh._has_data():
                                            return True

                                        if self.total is not None and self.total._has_data():
                                            return True

                                        if self.update is not None and self.update._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics']['meta_info']


                                class TcpInitSyncTimeSpec(object):
                                    """
                                    Time When neighbor entered TCP Init Sync
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tcp-init-sync-time-spec'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncTimeSpec']['meta_info']


                                class TcpInitSyncPhaseTwoTimeSpec(object):
                                    """
                                    Time when neighbor entered TCP Init Sync Phase
                                    Two
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tcp-init-sync-phase-two-time-spec'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec']['meta_info']


                                class TcpInitSyncDoneTimeSpec(object):
                                    """
                                    Time when neighbor entered TCP Init Sync Done
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tcp-init-sync-done-time-spec'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec']['meta_info']


                                class GracefulMaintenance(object):
                                    """
                                    Graceful Maintenance
                                    
                                    .. attribute:: gshut_active
                                    
                                    	Graceful Maintenance activated
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_exists
                                    
                                    	Graceful Maintenance enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_local_active
                                    
                                    	Graceful Maintenance locally activated
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_locpref
                                    
                                    	Graceful Maintenance Local Preference
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: gshut_locpref_set
                                    
                                    	Graceful Maintenance Local Preference set
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_prepends
                                    
                                    	Graceful Maintenance number of AS prepends
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.gshut_active = None
                                        self.gshut_exists = None
                                        self.gshut_local_active = None
                                        self.gshut_locpref = None
                                        self.gshut_locpref_set = None
                                        self.gshut_prepends = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:graceful-maintenance'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.gshut_active is not None:
                                            return True

                                        if self.gshut_exists is not None:
                                            return True

                                        if self.gshut_local_active is not None:
                                            return True

                                        if self.gshut_locpref is not None:
                                            return True

                                        if self.gshut_locpref_set is not None:
                                            return True

                                        if self.gshut_prepends is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.GracefulMaintenance']['meta_info']


                                class AfData(object):
                                    """
                                    Address family specific neighbor data
                                    
                                    .. attribute:: accept_own_enabled
                                    
                                    	Accept\-Own enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: acked_version
                                    
                                    	Version mapped from acked seqNo
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: address_family_long_lived_time
                                    
                                    	AF specific Long\-lived\-time config
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: advertise_afi
                                    
                                    	Encode in Advertise AFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_afi_def_vrf_imp_disable
                                    
                                    	Advertise of default VRF import disable
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_afi_disable
                                    
                                    	Encode in Advertise AFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_afi_eo_r_ready
                                    
                                    	EoR Can be sent for Advertise AFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_afi_reorg
                                    
                                    	Encode in Advertise AFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_afi_vrf_re_imp_disable
                                    
                                    	Advertise of VRF re\-import disable
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_evp_nv4afi_def_vrf_imp_disable
                                    
                                    	Advertise of v4 default VRF import disable
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_evp_nv4afi_vrf_re_imp_disable
                                    
                                    	Advertise of v4 VRF re\-import disable
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_evp_nv6afi_def_vrf_imp_disable
                                    
                                    	Advertise of v6 default VRF import disable
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_evp_nv6afi_vrf_re_imp_disable
                                    
                                    	Advertise of v6 VRF re\-import disable
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_local_labeled_route_unicast
                                    
                                    	Advertise routes with local\-label via Unicast SAFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_rt_type
                                    
                                    	Advertise RT type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: advertise_v4_flags
                                    
                                    	Advertise options for VPNV4
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: advertise_v6_flags
                                    
                                    	Advertise options for VPNV6
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: afrpki_allow_invalid
                                    
                                    	Prefix v. allow invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: afrpki_disable
                                    
                                    	Prefix validation disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: afrpki_signal_ibgp
                                    
                                    	Prefix v. signal ibgp
                                    	**type**\:  bool
                                    
                                    .. attribute:: afrpki_use_validity
                                    
                                    	Prefix v. use validity
                                    	**type**\:  bool
                                    
                                    .. attribute:: allow_as_in_count
                                    
                                    	Allowas\-in count config
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: always_use_next_hop_local
                                    
                                    	Local router always used for next\-hop
                                    	**type**\:  bool
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation type
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: eo_r_received_in_read_only
                                    
                                    	An EoR was received while in read\-only mode
                                    	**type**\:  bool
                                    
                                    .. attribute:: extended_community
                                    
                                    	Extended community attribute
                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunity>`
                                    
                                    .. attribute:: extended_community_standby
                                    
                                    	Extended community attribute
                                    	**type**\: list of    :py:class:`ExtendedCommunityStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby>`
                                    
                                    .. attribute:: filter_group_index
                                    
                                    	Filter group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: flowspec_redirect_validation_d_isable
                                    
                                    	Flowspec Redirect Validation Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flowspec_validation_d_isable
                                    
                                    	Flowspec Validation Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: import_reoriginate
                                    
                                    	Import Reoriginate enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: import_reoriginate_stitching
                                    
                                    	Import Reoriginate Stitching enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: import_stitching
                                    
                                    	Import Stitching enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_add_path_receive_capability_advertised
                                    
                                    	Addpath Receive capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_add_path_receive_capability_received
                                    
                                    	Addpath Receive capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_add_path_send_capability_advertised
                                    
                                    	Addpath Send capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_add_path_send_capability_received
                                    
                                    	Addpath Send capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_addpath_receive_operational
                                    
                                    	Addpath is operational on receive\-side
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_addpath_send_operational
                                    
                                    	Addpath is operational on send\-side
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_advertise_permanent_network
                                    
                                    	Advertise Permanent Network
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_advertised_graceful_restart
                                    
                                    	Graceful Restart Capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_advertised_orf_receive
                                    
                                    	Prefix based ORF receive mode capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_advertised_orf_send
                                    
                                    	Prefix based ORF send mode capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_aigp_set
                                    
                                    	AIGP set 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_allow_as_in_set
                                    
                                    	Allowas\-in set 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_as_override_set
                                    
                                    	As override set 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_default_originate_sent
                                    
                                    	Default origination update sent
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ext_nh_encoding_capability_received
                                    
                                    	Extended nexthop encoding capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ext_nh_encoding_capability_sent
                                    
                                    	Extended nexhop encoding capability Sent
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_graceful_restart_state_flag
                                    
                                    	Restart state flag enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_legacy_pe_rt
                                    
                                    	Nbr accepts route from legacy PE for RT\-Constraint AF 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_af_capable
                                    
                                    	Address family capability received from neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_ebgp_without_inbound_policy
                                    
                                    	eBGP neighbor with no configured inbound policy
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_ebgp_without_outbound_policy
                                    
                                    	eBGP neighbor with no configured outbound policy
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_route_reflector_client
                                    
                                    	Nbr is a route reflector client
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_orf_send_scheduled
                                    
                                    	Scheduled to send prefix based ORF
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_orf_sent
                                    
                                    	Outbound route filter sent to neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_orr_root_address_configured
                                    
                                    	ORR Root address configuredfor the neighbor connection
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_peer_orf_capable
                                    
                                    	Peer has outbound route filter capability
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_prefix_orf_present
                                    
                                    	Outbound route filter prefix ORF present
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_received_graceful_restart_capable
                                    
                                    	Graceful Restart Capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_received_orf_receive_capable
                                    
                                    	Prefix based ORF receive mode capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_received_orf_send_capable
                                    
                                    	Prefix based ORF send mode capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_rt_present
                                    
                                    	RT attribute list present
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_rt_present_standby
                                    
                                    	RT attribute list present
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_send_mcast_attr
                                    
                                    	Send Mcast Attr
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_soft_reconfiguration_inbound_allowed
                                    
                                    	Inbound soft reconfiguration allowed
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_update_deferred
                                    
                                    	Update deferred until ORF/route refresh received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_update_leaving
                                    
                                    	Nbr leaving update\-groupto another
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_update_throttled
                                    
                                    	Updates Throttled becausewrite limit is reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_use_soft_reconfiguration_always_on
                                    
                                    	Soft reconf overrides route refresh
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_restart_time
                                    
                                    	Local Restart time (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: long_lived_graceful_restart_capability_received
                                    
                                    	Long\-lived graceful\-restart capability received from the neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_accept
                                    
                                    	Maximum long\-lived graceful\-restart stale time acceptable from the neighbor (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_configured
                                    
                                    	Long\-lived graceful\-restart stale time is configured
                                    	**type**\:  bool
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_received
                                    
                                    	Long\-lived graceful\-restart stale time received from the neighbor (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_sent
                                    
                                    	Stale time sent in long\-lived graceful\-restart capability (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: max_prefix_discard_extra_paths
                                    
                                    	Discard extra paths when prefix limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: max_prefix_exceed_discard_paths
                                    
                                    	Did we discard extra paths when prefix limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: max_prefix_limit
                                    
                                    	Max limit for # of prefixes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: max_prefix_restart_time
                                    
                                    	Time interval (in minutes) after which peering session will be reestablished
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: minute
                                    
                                    .. attribute:: max_prefix_threshold_percent
                                    
                                    	Percentage of maximum no. of prefixes at which to generate warning
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: percentage
                                    
                                    .. attribute:: neighbor_af_performance_statistics
                                    
                                    	Neighbor AF statistics
                                    	**type**\:   :py:class:`NeighborAfPerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics>`
                                    
                                    .. attribute:: neighbor_default_originate
                                    
                                    	Neighbor originates default
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_long_lived_graceful_restart_capable
                                    
                                    	Treat neighbor as long\-lived graceful\-restart capable
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_long_lived_graceful_restart_time_remaining
                                    
                                    	Remaining long\-lived graceful\-restart time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_preserved_forwarding_state
                                    
                                    	Neighbor preserved forwarding state
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_preserved_long_lived_forwarding_state
                                    
                                    	Neighbor preserved long\-lived forwarding state
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_version
                                    
                                    	Neighbor version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: number_of_best_externalpaths
                                    
                                    	No. of best\-external paths from this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: number_of_bestpaths
                                    
                                    	No. of bestpaths from this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: orf_entries_received
                                    
                                    	Number of outbound route filter entries received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: orr_group_index
                                    
                                    	ORR Group Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: orr_group_name
                                    
                                    	ORR Group Name
                                    	**type**\:  str
                                    
                                    .. attribute:: outstanding_version
                                    
                                    	Version mapped from acked seqNo that was synced last
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: outstanding_version_max
                                    
                                    	Version mapped from acked seqNo that was synced last
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_accepted
                                    
                                    	No. of prefixes accepted
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_advertised
                                    
                                    	No. of prefixes advertised
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_be_advertised
                                    
                                    	No BE prefixes advertised
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_denied
                                    
                                    	No. of prefixes denied
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_denied_no_policy
                                    
                                    	No. of prefixes denied because there was no inbound policy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_denied_non_cumulative
                                    
                                    	No. of prefixes exactly denied (non cumulative)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_denied_orf_policy
                                    
                                    	No. of prefixes denied by prefix based ORF policy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_denied_policy
                                    
                                    	No. of prefixes denied by inbound policy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_denied_rt_permit
                                    
                                    	No. of prefixes denied because RT extended community is not imported
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_suppressed
                                    
                                    	No. of prefixes suppressed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_synced
                                    
                                    	Number of prefixes synced to standby
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_withdrawn
                                    
                                    	No. of prefixes withdrawn
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_withdrawn_not_found
                                    
                                    	No. of prefixes withdrawn but not found
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_acked_version
                                    
                                    	Version acked by the peer for refresh updates sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_target_version
                                    
                                    	Target version for refresh update generation
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_version
                                    
                                    	Version till which refresh updates have been generated
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remove_private_as_entire_aspath_from_inbound_updates
                                    
                                    	Private AS numbers removed from updates from this nbr only if the aspath has only private ASes
                                    	**type**\:  bool
                                    
                                    .. attribute:: remove_private_as_entire_aspath_from_updates
                                    
                                    	Private AS numbers removed from updates to thisnbr only if the aspath hasonly private ASes
                                    	**type**\:  bool
                                    
                                    .. attribute:: remove_private_as_from_inbound_updates
                                    
                                    	Private AS numbers removed from updates from this nbr
                                    	**type**\:  bool
                                    
                                    .. attribute:: remove_private_as_from_updates
                                    
                                    	Private AS numbers removed from updates to this nbr
                                    	**type**\:  bool
                                    
                                    .. attribute:: restart_time
                                    
                                    	Restart time advertised (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: rib_purge_timeout_value
                                    
                                    	RIB purge timeout time (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: route_policy_default_originate
                                    
                                    	Default\-originate route policy name
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_in
                                    
                                    	Incoming route policy name
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_out
                                    
                                    	Outgoing route policy name
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_prefix_orf
                                    
                                    	Prefix based ORF for incoming updates
                                    	**type**\:  str
                                    
                                    .. attribute:: route_refreshes_received
                                    
                                    	Number of route refresh requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_refreshes_sent
                                    
                                    	Number of route refresh requests sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: selective_multipath_eligible
                                    
                                    	Selective multipath eligible
                                    	**type**\:  bool
                                    
                                    .. attribute:: sent_community_to_neighbor
                                    
                                    	Community attribute sent to neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: sent_extended_community_to_neighbor
                                    
                                    	Extended community attribute sent to neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: sent_gshut_community_to_neighbor
                                    
                                    	GSHUT Community attribute sent to neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: stale_path_timeout
                                    
                                    	Stale path timeout time (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: synced_acked_version
                                    
                                    	Version mapped from acked seqNo that was synced last
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_group_number
                                    
                                    	Update group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: use_max_prefix_warning_only
                                    
                                    	Warning only when maximum prefix limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: vpn_update_gen_enabled
                                    
                                    	RT Nbr enabled for updategento another
                                    	**type**\:  bool
                                    
                                    .. attribute:: vpn_update_gen_trigger_enabled
                                    
                                    	RT Nbr enabled for updategento another
                                    	**type**\:  bool
                                    
                                    .. attribute:: weight
                                    
                                    	Weight for this AF
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.accept_own_enabled = None
                                        self.acked_version = None
                                        self.address_family_long_lived_time = None
                                        self.advertise_afi = None
                                        self.advertise_afi_def_vrf_imp_disable = None
                                        self.advertise_afi_disable = None
                                        self.advertise_afi_eo_r_ready = None
                                        self.advertise_afi_reorg = None
                                        self.advertise_afi_vrf_re_imp_disable = None
                                        self.advertise_evp_nv4afi_def_vrf_imp_disable = None
                                        self.advertise_evp_nv4afi_vrf_re_imp_disable = None
                                        self.advertise_evp_nv6afi_def_vrf_imp_disable = None
                                        self.advertise_evp_nv6afi_vrf_re_imp_disable = None
                                        self.advertise_local_labeled_route_unicast = None
                                        self.advertise_rt_type = None
                                        self.advertise_v4_flags = None
                                        self.advertise_v6_flags = None
                                        self.af_name = None
                                        self.afrpki_allow_invalid = None
                                        self.afrpki_disable = None
                                        self.afrpki_signal_ibgp = None
                                        self.afrpki_use_validity = None
                                        self.allow_as_in_count = None
                                        self.always_use_next_hop_local = None
                                        self.encapsulation_type = None
                                        self.eo_r_received_in_read_only = None
                                        self.extended_community = YList()
                                        self.extended_community.parent = self
                                        self.extended_community.name = 'extended_community'
                                        self.extended_community_standby = YList()
                                        self.extended_community_standby.parent = self
                                        self.extended_community_standby.name = 'extended_community_standby'
                                        self.filter_group_index = None
                                        self.flowspec_redirect_validation_d_isable = None
                                        self.flowspec_validation_d_isable = None
                                        self.import_reoriginate = None
                                        self.import_reoriginate_stitching = None
                                        self.import_stitching = None
                                        self.is_add_path_receive_capability_advertised = None
                                        self.is_add_path_receive_capability_received = None
                                        self.is_add_path_send_capability_advertised = None
                                        self.is_add_path_send_capability_received = None
                                        self.is_addpath_receive_operational = None
                                        self.is_addpath_send_operational = None
                                        self.is_advertise_permanent_network = None
                                        self.is_advertised_graceful_restart = None
                                        self.is_advertised_orf_receive = None
                                        self.is_advertised_orf_send = None
                                        self.is_aigp_set = None
                                        self.is_allow_as_in_set = None
                                        self.is_as_override_set = None
                                        self.is_default_originate_sent = None
                                        self.is_ext_nh_encoding_capability_received = None
                                        self.is_ext_nh_encoding_capability_sent = None
                                        self.is_graceful_restart_state_flag = None
                                        self.is_legacy_pe_rt = None
                                        self.is_neighbor_af_capable = None
                                        self.is_neighbor_ebgp_without_inbound_policy = None
                                        self.is_neighbor_ebgp_without_outbound_policy = None
                                        self.is_neighbor_route_reflector_client = None
                                        self.is_orf_send_scheduled = None
                                        self.is_orf_sent = None
                                        self.is_orr_root_address_configured = None
                                        self.is_peer_orf_capable = None
                                        self.is_prefix_orf_present = None
                                        self.is_received_graceful_restart_capable = None
                                        self.is_received_orf_receive_capable = None
                                        self.is_received_orf_send_capable = None
                                        self.is_rt_present = None
                                        self.is_rt_present_standby = None
                                        self.is_send_mcast_attr = None
                                        self.is_soft_reconfiguration_inbound_allowed = None
                                        self.is_update_deferred = None
                                        self.is_update_leaving = None
                                        self.is_update_throttled = None
                                        self.is_use_soft_reconfiguration_always_on = None
                                        self.local_restart_time = None
                                        self.long_lived_graceful_restart_capability_received = None
                                        self.long_lived_graceful_restart_stale_time_accept = None
                                        self.long_lived_graceful_restart_stale_time_configured = None
                                        self.long_lived_graceful_restart_stale_time_received = None
                                        self.long_lived_graceful_restart_stale_time_sent = None
                                        self.max_prefix_discard_extra_paths = None
                                        self.max_prefix_exceed_discard_paths = None
                                        self.max_prefix_limit = None
                                        self.max_prefix_restart_time = None
                                        self.max_prefix_threshold_percent = None
                                        self.neighbor_af_performance_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics()
                                        self.neighbor_af_performance_statistics.parent = self
                                        self.neighbor_default_originate = None
                                        self.neighbor_long_lived_graceful_restart_capable = None
                                        self.neighbor_long_lived_graceful_restart_time_remaining = None
                                        self.neighbor_preserved_forwarding_state = None
                                        self.neighbor_preserved_long_lived_forwarding_state = None
                                        self.neighbor_version = None
                                        self.number_of_best_externalpaths = None
                                        self.number_of_bestpaths = None
                                        self.orf_entries_received = None
                                        self.orr_group_index = None
                                        self.orr_group_name = None
                                        self.outstanding_version = None
                                        self.outstanding_version_max = None
                                        self.prefixes_accepted = None
                                        self.prefixes_advertised = None
                                        self.prefixes_be_advertised = None
                                        self.prefixes_denied = None
                                        self.prefixes_denied_no_policy = None
                                        self.prefixes_denied_non_cumulative = None
                                        self.prefixes_denied_orf_policy = None
                                        self.prefixes_denied_policy = None
                                        self.prefixes_denied_rt_permit = None
                                        self.prefixes_suppressed = None
                                        self.prefixes_synced = None
                                        self.prefixes_withdrawn = None
                                        self.prefixes_withdrawn_not_found = None
                                        self.refresh_acked_version = None
                                        self.refresh_target_version = None
                                        self.refresh_version = None
                                        self.remove_private_as_entire_aspath_from_inbound_updates = None
                                        self.remove_private_as_entire_aspath_from_updates = None
                                        self.remove_private_as_from_inbound_updates = None
                                        self.remove_private_as_from_updates = None
                                        self.restart_time = None
                                        self.rib_purge_timeout_value = None
                                        self.route_policy_default_originate = None
                                        self.route_policy_in = None
                                        self.route_policy_out = None
                                        self.route_policy_prefix_orf = None
                                        self.route_refreshes_received = None
                                        self.route_refreshes_sent = None
                                        self.selective_multipath_eligible = None
                                        self.sent_community_to_neighbor = None
                                        self.sent_extended_community_to_neighbor = None
                                        self.sent_gshut_community_to_neighbor = None
                                        self.stale_path_timeout = None
                                        self.synced_acked_version = None
                                        self.update_group_number = None
                                        self.use_max_prefix_warning_only = None
                                        self.vpn_update_gen_enabled = None
                                        self.vpn_update_gen_trigger_enabled = None
                                        self.weight = None


                                    class NeighborAfPerformanceStatistics(object):
                                        """
                                        Neighbor AF statistics
                                        
                                        .. attribute:: processed_messages
                                        
                                        	Number of messages processed from the neighbor's write queue
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sent_messages
                                        
                                        	Number of messages sent from the neighbor's write queue
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: split_horizon_update_blocked
                                        
                                        	No. of update messages with split\-horizon flag that were blocked
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: split_horizon_update_transmit
                                        
                                        	No. of update messages with split\-horizon flag that were sent out
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: split_horizon_withdraw_blocked
                                        
                                        	No. of withdraw messages with split\-horizon flag that were blocked
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: split_horizon_withdraw_transmit
                                        
                                        	No. of withdraw messages with split\-horizon flag that were sent out
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_pending_message_count
                                        
                                        	No. of sub\-group messages waiting to be sent out on this neighbor \-\- DEPRECATED \-\- 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.processed_messages = None
                                            self.sent_messages = None
                                            self.split_horizon_update_blocked = None
                                            self.split_horizon_update_transmit = None
                                            self.split_horizon_withdraw_blocked = None
                                            self.split_horizon_withdraw_transmit = None
                                            self.sub_group_pending_message_count = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-af-performance-statistics'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.processed_messages is not None:
                                                return True

                                            if self.sent_messages is not None:
                                                return True

                                            if self.split_horizon_update_blocked is not None:
                                                return True

                                            if self.split_horizon_update_transmit is not None:
                                                return True

                                            if self.split_horizon_withdraw_blocked is not None:
                                                return True

                                            if self.split_horizon_withdraw_transmit is not None:
                                                return True

                                            if self.sub_group_pending_message_count is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics']['meta_info']


                                    class ExtendedCommunity(object):
                                        """
                                        Extended community attribute
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.entry = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.entry is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunity']['meta_info']


                                    class ExtendedCommunityStandby(object):
                                        """
                                        Extended community attribute
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.entry = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community-standby'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.entry is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af-data'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.accept_own_enabled is not None:
                                            return True

                                        if self.acked_version is not None:
                                            return True

                                        if self.address_family_long_lived_time is not None:
                                            return True

                                        if self.advertise_afi is not None:
                                            return True

                                        if self.advertise_afi_def_vrf_imp_disable is not None:
                                            return True

                                        if self.advertise_afi_disable is not None:
                                            return True

                                        if self.advertise_afi_eo_r_ready is not None:
                                            return True

                                        if self.advertise_afi_reorg is not None:
                                            return True

                                        if self.advertise_afi_vrf_re_imp_disable is not None:
                                            return True

                                        if self.advertise_evp_nv4afi_def_vrf_imp_disable is not None:
                                            return True

                                        if self.advertise_evp_nv4afi_vrf_re_imp_disable is not None:
                                            return True

                                        if self.advertise_evp_nv6afi_def_vrf_imp_disable is not None:
                                            return True

                                        if self.advertise_evp_nv6afi_vrf_re_imp_disable is not None:
                                            return True

                                        if self.advertise_local_labeled_route_unicast is not None:
                                            return True

                                        if self.advertise_rt_type is not None:
                                            return True

                                        if self.advertise_v4_flags is not None:
                                            return True

                                        if self.advertise_v6_flags is not None:
                                            return True

                                        if self.af_name is not None:
                                            return True

                                        if self.afrpki_allow_invalid is not None:
                                            return True

                                        if self.afrpki_disable is not None:
                                            return True

                                        if self.afrpki_signal_ibgp is not None:
                                            return True

                                        if self.afrpki_use_validity is not None:
                                            return True

                                        if self.allow_as_in_count is not None:
                                            return True

                                        if self.always_use_next_hop_local is not None:
                                            return True

                                        if self.encapsulation_type is not None:
                                            return True

                                        if self.eo_r_received_in_read_only is not None:
                                            return True

                                        if self.extended_community is not None:
                                            for child_ref in self.extended_community:
                                                if child_ref._has_data():
                                                    return True

                                        if self.extended_community_standby is not None:
                                            for child_ref in self.extended_community_standby:
                                                if child_ref._has_data():
                                                    return True

                                        if self.filter_group_index is not None:
                                            return True

                                        if self.flowspec_redirect_validation_d_isable is not None:
                                            return True

                                        if self.flowspec_validation_d_isable is not None:
                                            return True

                                        if self.import_reoriginate is not None:
                                            return True

                                        if self.import_reoriginate_stitching is not None:
                                            return True

                                        if self.import_stitching is not None:
                                            return True

                                        if self.is_add_path_receive_capability_advertised is not None:
                                            return True

                                        if self.is_add_path_receive_capability_received is not None:
                                            return True

                                        if self.is_add_path_send_capability_advertised is not None:
                                            return True

                                        if self.is_add_path_send_capability_received is not None:
                                            return True

                                        if self.is_addpath_receive_operational is not None:
                                            return True

                                        if self.is_addpath_send_operational is not None:
                                            return True

                                        if self.is_advertise_permanent_network is not None:
                                            return True

                                        if self.is_advertised_graceful_restart is not None:
                                            return True

                                        if self.is_advertised_orf_receive is not None:
                                            return True

                                        if self.is_advertised_orf_send is not None:
                                            return True

                                        if self.is_aigp_set is not None:
                                            return True

                                        if self.is_allow_as_in_set is not None:
                                            return True

                                        if self.is_as_override_set is not None:
                                            return True

                                        if self.is_default_originate_sent is not None:
                                            return True

                                        if self.is_ext_nh_encoding_capability_received is not None:
                                            return True

                                        if self.is_ext_nh_encoding_capability_sent is not None:
                                            return True

                                        if self.is_graceful_restart_state_flag is not None:
                                            return True

                                        if self.is_legacy_pe_rt is not None:
                                            return True

                                        if self.is_neighbor_af_capable is not None:
                                            return True

                                        if self.is_neighbor_ebgp_without_inbound_policy is not None:
                                            return True

                                        if self.is_neighbor_ebgp_without_outbound_policy is not None:
                                            return True

                                        if self.is_neighbor_route_reflector_client is not None:
                                            return True

                                        if self.is_orf_send_scheduled is not None:
                                            return True

                                        if self.is_orf_sent is not None:
                                            return True

                                        if self.is_orr_root_address_configured is not None:
                                            return True

                                        if self.is_peer_orf_capable is not None:
                                            return True

                                        if self.is_prefix_orf_present is not None:
                                            return True

                                        if self.is_received_graceful_restart_capable is not None:
                                            return True

                                        if self.is_received_orf_receive_capable is not None:
                                            return True

                                        if self.is_received_orf_send_capable is not None:
                                            return True

                                        if self.is_rt_present is not None:
                                            return True

                                        if self.is_rt_present_standby is not None:
                                            return True

                                        if self.is_send_mcast_attr is not None:
                                            return True

                                        if self.is_soft_reconfiguration_inbound_allowed is not None:
                                            return True

                                        if self.is_update_deferred is not None:
                                            return True

                                        if self.is_update_leaving is not None:
                                            return True

                                        if self.is_update_throttled is not None:
                                            return True

                                        if self.is_use_soft_reconfiguration_always_on is not None:
                                            return True

                                        if self.local_restart_time is not None:
                                            return True

                                        if self.long_lived_graceful_restart_capability_received is not None:
                                            return True

                                        if self.long_lived_graceful_restart_stale_time_accept is not None:
                                            return True

                                        if self.long_lived_graceful_restart_stale_time_configured is not None:
                                            return True

                                        if self.long_lived_graceful_restart_stale_time_received is not None:
                                            return True

                                        if self.long_lived_graceful_restart_stale_time_sent is not None:
                                            return True

                                        if self.max_prefix_discard_extra_paths is not None:
                                            return True

                                        if self.max_prefix_exceed_discard_paths is not None:
                                            return True

                                        if self.max_prefix_limit is not None:
                                            return True

                                        if self.max_prefix_restart_time is not None:
                                            return True

                                        if self.max_prefix_threshold_percent is not None:
                                            return True

                                        if self.neighbor_af_performance_statistics is not None and self.neighbor_af_performance_statistics._has_data():
                                            return True

                                        if self.neighbor_default_originate is not None:
                                            return True

                                        if self.neighbor_long_lived_graceful_restart_capable is not None:
                                            return True

                                        if self.neighbor_long_lived_graceful_restart_time_remaining is not None:
                                            return True

                                        if self.neighbor_preserved_forwarding_state is not None:
                                            return True

                                        if self.neighbor_preserved_long_lived_forwarding_state is not None:
                                            return True

                                        if self.neighbor_version is not None:
                                            return True

                                        if self.number_of_best_externalpaths is not None:
                                            return True

                                        if self.number_of_bestpaths is not None:
                                            return True

                                        if self.orf_entries_received is not None:
                                            return True

                                        if self.orr_group_index is not None:
                                            return True

                                        if self.orr_group_name is not None:
                                            return True

                                        if self.outstanding_version is not None:
                                            return True

                                        if self.outstanding_version_max is not None:
                                            return True

                                        if self.prefixes_accepted is not None:
                                            return True

                                        if self.prefixes_advertised is not None:
                                            return True

                                        if self.prefixes_be_advertised is not None:
                                            return True

                                        if self.prefixes_denied is not None:
                                            return True

                                        if self.prefixes_denied_no_policy is not None:
                                            return True

                                        if self.prefixes_denied_non_cumulative is not None:
                                            return True

                                        if self.prefixes_denied_orf_policy is not None:
                                            return True

                                        if self.prefixes_denied_policy is not None:
                                            return True

                                        if self.prefixes_denied_rt_permit is not None:
                                            return True

                                        if self.prefixes_suppressed is not None:
                                            return True

                                        if self.prefixes_synced is not None:
                                            return True

                                        if self.prefixes_withdrawn is not None:
                                            return True

                                        if self.prefixes_withdrawn_not_found is not None:
                                            return True

                                        if self.refresh_acked_version is not None:
                                            return True

                                        if self.refresh_target_version is not None:
                                            return True

                                        if self.refresh_version is not None:
                                            return True

                                        if self.remove_private_as_entire_aspath_from_inbound_updates is not None:
                                            return True

                                        if self.remove_private_as_entire_aspath_from_updates is not None:
                                            return True

                                        if self.remove_private_as_from_inbound_updates is not None:
                                            return True

                                        if self.remove_private_as_from_updates is not None:
                                            return True

                                        if self.restart_time is not None:
                                            return True

                                        if self.rib_purge_timeout_value is not None:
                                            return True

                                        if self.route_policy_default_originate is not None:
                                            return True

                                        if self.route_policy_in is not None:
                                            return True

                                        if self.route_policy_out is not None:
                                            return True

                                        if self.route_policy_prefix_orf is not None:
                                            return True

                                        if self.route_refreshes_received is not None:
                                            return True

                                        if self.route_refreshes_sent is not None:
                                            return True

                                        if self.selective_multipath_eligible is not None:
                                            return True

                                        if self.sent_community_to_neighbor is not None:
                                            return True

                                        if self.sent_extended_community_to_neighbor is not None:
                                            return True

                                        if self.sent_gshut_community_to_neighbor is not None:
                                            return True

                                        if self.stale_path_timeout is not None:
                                            return True

                                        if self.synced_acked_version is not None:
                                            return True

                                        if self.update_group_number is not None:
                                            return True

                                        if self.use_max_prefix_warning_only is not None:
                                            return True

                                        if self.vpn_update_gen_enabled is not None:
                                            return True

                                        if self.vpn_update_gen_trigger_enabled is not None:
                                            return True

                                        if self.weight is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.neighbor_address is None:
                                        raise YPYModelError('Key property neighbor_address is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address = ' + str(self.neighbor_address) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.neighbor_address is not None:
                                        return True

                                    if self.active_bmp_servers is not None:
                                        return True

                                    if self.actual_last_write_bytes is not None:
                                        return True

                                    if self.actual_last_write_reset_bytes is not None:
                                        return True

                                    if self.actual_second_last_write_bytes is not None:
                                        return True

                                    if self.actual_second_last_write_reset_bytes is not None:
                                        return True

                                    if self.af_data is not None:
                                        for child_ref in self.af_data:
                                            if child_ref._has_data():
                                                return True

                                    if self.attempted_last_write_bytes is not None:
                                        return True

                                    if self.attempted_last_write_reset_bytes is not None:
                                        return True

                                    if self.attempted_second_last_write_bytes is not None:
                                        return True

                                    if self.attempted_second_last_write_reset_bytes is not None:
                                        return True

                                    if self.bfd_minintervalval is not None:
                                        return True

                                    if self.bfd_multiplierval is not None:
                                        return True

                                    if self.bfd_session_created_state is not None:
                                        return True

                                    if self.bfd_session_enable_mode is not None:
                                        return True

                                    if self.bfd_session_state is not None:
                                        return True

                                    if self.bfd_state_ts is not None:
                                        return True

                                    if self.bytes_read is not None:
                                        return True

                                    if self.bytes_written is not None:
                                        return True

                                    if self.configured_hold_time is not None:
                                        return True

                                    if self.configured_keepalive is not None:
                                        return True

                                    if self.configured_min_acc_hold_time is not None:
                                        return True

                                    if self.connect_retry_interval is not None:
                                        return True

                                    if self.connection_admin_status is not None:
                                        return True

                                    if self.connection_down_count is not None:
                                        return True

                                    if self.connection_established_time is not None:
                                        return True

                                    if self.connection_local_address is not None and self.connection_local_address._has_data():
                                        return True

                                    if self.connection_local_port is not None:
                                        return True

                                    if self.connection_remote_address is not None and self.connection_remote_address._has_data():
                                        return True

                                    if self.connection_remote_port is not None:
                                        return True

                                    if self.connection_state is not None:
                                        return True

                                    if self.connection_up_count is not None:
                                        return True

                                    if self.count_last_write is not None:
                                        return True

                                    if self.description is not None:
                                        return True

                                    if self.discard_as4_path is not None:
                                        return True

                                    if self.discard_data_bytes is not None:
                                        return True

                                    if self.dmz_link_bandwidth is not None:
                                        return True

                                    if self.dynamic_neighbor is not None:
                                        return True

                                    if self.ebgp_recv_dmz is not None:
                                        return True

                                    if self.ebgp_send_dmz_mode is not None:
                                        return True

                                    if self.ebgp_time_to_live is not None:
                                        return True

                                    if self.egress_peer_engineering_enabled is not None:
                                        return True

                                    if self.error_notifies_received is not None:
                                        return True

                                    if self.error_notifies_sent is not None:
                                        return True

                                    if self.fpbsn_offset is not None:
                                        return True

                                    if self.fssn_offset is not None:
                                        return True

                                    if self.gr_restart_time is not None:
                                        return True

                                    if self.gr_stale_path_time is not None:
                                        return True

                                    if self.graceful_maintenance is not None and self.graceful_maintenance._has_data():
                                        return True

                                    if self.graceful_restart_enabled_nbr is not None:
                                        return True

                                    if self.has_internal_link is not None:
                                        return True

                                    if self.hold_time is not None:
                                        return True

                                    if self.ignore_connected is not None:
                                        return True

                                    if self.internal_vpn_client is not None:
                                        return True

                                    if self.io_armed is not None:
                                        return True

                                    if self.is4_byte_as_capability_received is not None:
                                        return True

                                    if self.is4_byte_as_capability_sent is not None:
                                        return True

                                    if self.is_administratively_shut_down is not None:
                                        return True

                                    if self.is_capability_negotiation_performed is not None:
                                        return True

                                    if self.is_capability_negotiation_suppressed is not None:
                                        return True

                                    if self.is_ebgp_multihop_bgpmpls_forwarding_disabled is not None:
                                        return True

                                    if self.is_ebgp_peer_as_league is not None:
                                        return True

                                    if self.is_ebgp_peer_common_admin is not None:
                                        return True

                                    if self.is_external_neighbor_not_directly_connected is not None:
                                        return True

                                    if self.is_gr_aware is not None:
                                        return True

                                    if self.is_local_address_configured is not None:
                                        return True

                                    if self.is_neighbor_max_prefix_shutdown is not None:
                                        return True

                                    if self.is_out_of_memory_forced_up is not None:
                                        return True

                                    if self.is_out_of_memory_shutdown is not None:
                                        return True

                                    if self.is_passive_close is not None:
                                        return True

                                    if self.is_read_disabled is not None:
                                        return True

                                    if self.is_route_refresh_capability_received is not None:
                                        return True

                                    if self.is_route_refresh_old_capability_received is not None:
                                        return True

                                    if self.keep_alive_time is not None:
                                        return True

                                    if self.last_ackd_seq_no is not None:
                                        return True

                                    if self.last_k_aerror_reset is not None:
                                        return True

                                    if self.last_k_aexpiry_reset is not None:
                                        return True

                                    if self.last_k_anotsent_reset is not None:
                                        return True

                                    if self.last_k_astart_reset is not None:
                                        return True

                                    if self.last_notify_error_code is not None:
                                        return True

                                    if self.last_notify_error_subcode is not None:
                                        return True

                                    if self.last_write_event is not None:
                                        return True

                                    if self.local_as is not None:
                                        return True

                                    if self.local_as_dual_as is not None:
                                        return True

                                    if self.local_as_dual_as_mode_native is not None:
                                        return True

                                    if self.local_as_no_prepend is not None:
                                        return True

                                    if self.local_as_replace_as is not None:
                                        return True

                                    if self.message_statistics is not None and self.message_statistics._has_data():
                                        return True

                                    if self.messages_queued_in is not None:
                                        return True

                                    if self.messages_queued_out is not None:
                                        return True

                                    if self.messages_received is not None:
                                        return True

                                    if self.messages_sent is not None:
                                        return True

                                    if self.min_advertise_interval is not None:
                                        return True

                                    if self.min_advertise_interval_msecs is not None:
                                        return True

                                    if self.min_origination_interval is not None:
                                        return True

                                    if self.msg_log_in is not None:
                                        return True

                                    if self.msg_log_out is not None:
                                        return True

                                    if self.multi_protocol_capability_received is not None:
                                        return True

                                    if self.nbr_cluster_id is not None:
                                        return True

                                    if self.nbr_enforce_first_as is not None:
                                        return True

                                    if self.nbr_in_cluster is not None:
                                        return True

                                    if self.negotiated_protocol_version is not None:
                                        return True

                                    if self.neighbor_interface_handle is not None:
                                        return True

                                    if self.neighbor_local_as is not None:
                                        return True

                                    if self.nsr_enabled is not None:
                                        return True

                                    if self.nsr_state is not None:
                                        return True

                                    if self.open_check_error_code is not None:
                                        return True

                                    if self.peer_error_code is not None:
                                        return True

                                    if self.peer_reset_reason is not None:
                                        return True

                                    if self.performance_statistics is not None and self.performance_statistics._has_data():
                                        return True

                                    if self.previous_connection_state is not None:
                                        return True

                                    if self.read_armed is not None:
                                        return True

                                    if self.received_notification_info is not None and self.received_notification_info._has_data():
                                        return True

                                    if self.remote_as is not None:
                                        return True

                                    if self.remote_as_number is not None:
                                        return True

                                    if self.reset_notification_sent is not None:
                                        return True

                                    if self.reset_reason is not None:
                                        return True

                                    if self.router_id is not None:
                                        return True

                                    if self.rpki_allow_invalid is not None:
                                        return True

                                    if self.rpki_disable is not None:
                                        return True

                                    if self.rpki_signal_ibgp is not None:
                                        return True

                                    if self.rpki_use_validity is not None:
                                        return True

                                    if self.second_last_k_aexpiry_reset is not None:
                                        return True

                                    if self.second_last_k_astart_reset is not None:
                                        return True

                                    if self.second_last_write_event is not None:
                                        return True

                                    if self.send_notification_info is not None and self.send_notification_info._has_data():
                                        return True

                                    if self.socket_read_bytes is not None:
                                        return True

                                    if self.speaker_id is not None:
                                        return True

                                    if self.standby_rp is not None:
                                        return True

                                    if self.suppress4_byte_as is not None:
                                        return True

                                    if self.tcp_init_sync_done_time_spec is not None and self.tcp_init_sync_done_time_spec._has_data():
                                        return True

                                    if self.tcp_init_sync_phase_two_time_spec is not None and self.tcp_init_sync_phase_two_time_spec._has_data():
                                        return True

                                    if self.tcp_init_sync_time_spec is not None and self.tcp_init_sync_time_spec._has_data():
                                        return True

                                    if self.tcp_session_open_mode is not None:
                                        return True

                                    if self.tcpmss is not None:
                                        return True

                                    if self.time_last_cb is not None:
                                        return True

                                    if self.time_last_cb_reset is not None:
                                        return True

                                    if self.time_last_fb is not None:
                                        return True

                                    if self.time_since_connection_last_dropped is not None:
                                        return True

                                    if self.time_since_last_read is not None:
                                        return True

                                    if self.time_since_last_read_reset is not None:
                                        return True

                                    if self.time_since_last_update is not None:
                                        return True

                                    if self.time_since_last_write is not None:
                                        return True

                                    if self.time_since_last_write_reset is not None:
                                        return True

                                    if self.time_since_second_last_write is not None:
                                        return True

                                    if self.time_since_second_last_write_reset is not None:
                                        return True

                                    if self.tos_type is not None:
                                        return True

                                    if self.tos_value is not None:
                                        return True

                                    if self.ttl_security_enabled is not None:
                                        return True

                                    if self.update_bytes_read is not None:
                                        return True

                                    if self.update_messages_in is not None:
                                        return True

                                    if self.update_messages_out is not None:
                                        return True

                                    if self.vrf_name is not None:
                                        return True

                                    if self.write_armed is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbors'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.neighbor is not None:
                                    for child_ref in self.neighbor:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors']['meta_info']


                        class NextHopVrf(object):
                            """
                            A BGP Next\-hop VRF table entry
                            
                            .. attribute:: last_notification_processing_time
                            
                            	Processing time for the last notification
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_notificationication_time
                            
                            	Time since the last notification was received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_notification_bestpath_changes
                            
                            	Number of bestpath changes caused by notification which resulted in maximum processing
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_notification_bestpath_deletes
                            
                            	Number of bestpath deletes caused by notification which resulted in maximum processing
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_proc_notification_time
                            
                            	How long since the maximum processing time notifcation was received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_processing_time
                            
                            	Maximum time spent procesing a single batch notification
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total_processing_time
                            
                            	Total time spent in processing
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.last_notification_processing_time = None
                                self.last_notificationication_time = None
                                self.max_notification_bestpath_changes = None
                                self.max_notification_bestpath_deletes = None
                                self.max_proc_notification_time = None
                                self.maximum_processing_time = None
                                self.total_processing_time = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop-vrf'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.last_notification_processing_time is not None:
                                    return True

                                if self.last_notificationication_time is not None:
                                    return True

                                if self.max_notification_bestpath_changes is not None:
                                    return True

                                if self.max_notification_bestpath_deletes is not None:
                                    return True

                                if self.max_proc_notification_time is not None:
                                    return True

                                if self.maximum_processing_time is not None:
                                    return True

                                if self.total_processing_time is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NextHopVrf']['meta_info']


                        class NeighborRanges(object):
                            """
                            The BGP Dynamic Neighbor Range table
                            
                            .. attribute:: neighbor_range
                            
                            	A BGP Neighbor Range table entry
                            	**type**\: list of    :py:class:`NeighborRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.neighbor_range = YList()
                                self.neighbor_range.parent = self
                                self.neighbor_range.name = 'neighbor_range'


                            class NeighborRange(object):
                                """
                                A BGP Neighbor Range table entry
                                
                                .. attribute:: neighbor_range_address  <key>
                                
                                	Neighbor Range prefix
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                
                                ----
                                .. attribute:: active_bmp_servers
                                
                                	BMP Servers to which the neighbor sends logs
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: addpath_receive_disable
                                
                                	Addpath Receive Disabled
                                	**type**\:  bool
                                
                                .. attribute:: addpath_receive_enable
                                
                                	Addpath Receive enable
                                	**type**\:  bool
                                
                                .. attribute:: addpath_send_disable
                                
                                	Addpath Send Disabled
                                	**type**\:  bool
                                
                                .. attribute:: addpath_send_enable
                                
                                	Addpath Send enabled
                                	**type**\:  bool
                                
                                .. attribute:: af_data
                                
                                	Address family specific neighbor data
                                	**type**\: list of    :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData>`
                                
                                .. attribute:: attrf_group_name
                                
                                	Attrf Group Name
                                	**type**\:  str
                                
                                .. attribute:: bfd_minintervalval
                                
                                	BFD Mininterval for this peer
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_multiplierval
                                
                                	BFD Multiplier for this peer
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_session_enable_mode
                                
                                	BFD enable mode for this peer
                                	**type**\:   :py:class:`BgpBfdEnableModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdEnableModeEnum>`
                                
                                .. attribute:: cfg_local_address
                                
                                	Configured local address
                                	**type**\:   :py:class:`CfgLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress>`
                                
                                .. attribute:: configured_hold_time
                                
                                	Hold time (in secs) configured for this connection
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: configured_keepalive
                                
                                	Keepalive time (in secs) configured for this connection
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: configured_min_acc_hold_time
                                
                                	Minimum acceptable hold time from neighbor (in secs) configured for this connection
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: connection_local_address
                                
                                	Local address for the connection
                                	**type**\:   :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress>`
                                
                                .. attribute:: connection_remote_address
                                
                                	Remote address for the connection
                                	**type**\:   :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress>`
                                
                                .. attribute:: current_peers
                                
                                	Current Dynamic nbrs in range
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: description
                                
                                	Description
                                	**type**\:  str
                                
                                .. attribute:: discard_as4_path
                                
                                	Discard AS4\_PATH in case there is a discrepancy in merging AS\_PATH and AS4\_PATH,retain ASPATH
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: dmz_link_bandwidth
                                
                                	Bandwidth of link to single\-hop eBGP peer
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ebgp_recv_dmz
                                
                                	Receive Bandwidth of link to single\-hop eBGP peer
                                	**type**\:  bool
                                
                                .. attribute:: ebgp_send_dmz_mode
                                
                                	Ebgp send dmz link bw mode
                                	**type**\:   :py:class:`BgpEbgpSendDmzEnableModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableModeEnum>`
                                
                                .. attribute:: ebgp_time_to_live
                                
                                	Maximum number of hops for external BGP neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: egress_peer_engineering_enabled
                                
                                	Indicates if Egress Peer Engineering is enabled
                                	**type**\:  bool
                                
                                .. attribute:: gr_restart_time
                                
                                	Neighbor restart time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: gr_stale_path_time
                                
                                	Neighbor stale\-path time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: graceful_maintenance
                                
                                	Graceful Maintenance
                                	**type**\:   :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.GracefulMaintenance>`
                                
                                .. attribute:: graceful_restart_enabled_nbr
                                
                                	Neighbor supports graceful\-restart
                                	**type**\:  bool
                                
                                .. attribute:: has_internal_link
                                
                                	Internal link to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: idle_watch_time
                                
                                	Dynamic Neighbor idle\-watch time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: ignore_connected
                                
                                	If true, the VPN client isan IBGP CE peer
                                	**type**\:  bool
                                
                                .. attribute:: instance
                                
                                	Dynamic Neighbor Instance List
                                	**type**\: list of    :py:class:`Instance_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_>`
                                
                                .. attribute:: internal_vpn_client
                                
                                	If true, don't do NHconnected check for nbr
                                	**type**\:  bool
                                
                                .. attribute:: is_administratively_shut_down
                                
                                	Neighbor is administratively shut down
                                	**type**\:  bool
                                
                                .. attribute:: is_capability_negotiation_performed
                                
                                	Capability negotiation performed
                                	**type**\:  bool
                                
                                .. attribute:: is_ebgp_multihop_bgpmpls_forwarding_disabled
                                
                                	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_local_address_configured
                                
                                	Local address configured for the neighbor connection
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_max_prefix_shutdown
                                
                                	Neighbor shut down because it exceeded max prfx count
                                	**type**\:  bool
                                
                                .. attribute:: is_out_of_memory_forced_up
                                
                                	Neighbor forced up during a low memory condition
                                	**type**\:  bool
                                
                                .. attribute:: is_passive_close
                                
                                	If true, active socket canbe closed if passive openis received for a GRcapable neighbor
                                	**type**\:  bool
                                
                                .. attribute:: islocal_address_cfg
                                
                                	Local address configured
                                	**type**\:  bool
                                
                                .. attribute:: local_as
                                
                                	Local AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_as_dual_as
                                
                                	Local AS Dual\-AS option
                                	**type**\:  bool
                                
                                .. attribute:: local_as_dual_as_mode_native
                                
                                	Applies only if Local AS Dual\-AS option is enabled. Indicates if Dual\-AS mode is native
                                	**type**\:  bool
                                
                                .. attribute:: local_as_no_prepend
                                
                                	Option to not prepend the Local AS to announcements
                                	**type**\:  bool
                                
                                .. attribute:: local_as_replace_as
                                
                                	Local AS Replace\-AS option
                                	**type**\:  bool
                                
                                .. attribute:: max_peers
                                
                                	Max Dynamic nbrs in range
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: min_advertise_interval
                                
                                	Minimum advertisement interval, secs part
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: min_advertise_interval_msecs
                                
                                	Minimum advertisement interval, msecs part
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: min_origination_interval
                                
                                	Minimum origination interval (in secs)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: msg_buf_count
                                
                                	Message Buf Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: msg_bug_circular
                                
                                	Message Buf Circular
                                	**type**\:  bool
                                
                                .. attribute:: msg_log_in
                                
                                	Message in log count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: msg_log_out
                                
                                	Message out log count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nbr_cluster_id
                                
                                	Cluster id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nbr_enforce_first_as
                                
                                	Neighbor enforce first AS
                                	**type**\:  bool
                                
                                .. attribute:: nbr_in_cluster
                                
                                	Type of cluster\_id\:undefined/number/Ip address
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: nbr_rcv_size
                                
                                	Nbr Receive Size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nbr_send_size
                                
                                	Nbr Send Size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_local_as
                                
                                	Local AS configured on the neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_range_prefix_length
                                
                                	Neighbor Range Prefix Length
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: nsr_enabled
                                
                                	Neighbor supports NSR
                                	**type**\:  bool
                                
                                .. attribute:: oper_attrf_enable
                                
                                	Oper attrf Enable
                                	**type**\:  bool
                                
                                .. attribute:: range_inst_error
                                
                                	Error during instance creation
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: range_max_drop
                                
                                	open drop due to max peers
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: range_open_accepted
                                
                                	open accepted
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: range_open_match
                                
                                	Passive open matching range
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_as
                                
                                	Remote AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_as_list_name
                                
                                	Remote AS List Name
                                	**type**\:  str
                                
                                .. attribute:: remote_as_number
                                
                                	Remote AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rpki_allow_invalid
                                
                                	Prefix v. allow invalid
                                	**type**\:  bool
                                
                                .. attribute:: rpki_disable
                                
                                	Prefix validation disabled
                                	**type**\:  bool
                                
                                .. attribute:: rpki_signal_ibgp
                                
                                	Prefix v. signal ibgp
                                	**type**\:  bool
                                
                                .. attribute:: rpki_use_validity
                                
                                	Prefix v. use validity
                                	**type**\:  bool
                                
                                .. attribute:: speaker_id
                                
                                	Speaker this neighbor is allocated to
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: standby_rp
                                
                                	Standby RP socket inited for Active Open
                                	**type**\:  bool
                                
                                .. attribute:: suppress4_byte_as
                                
                                	Suppress 4byteas capability
                                	**type**\:  bool
                                
                                .. attribute:: syslog_enable
                                
                                	syslog enable
                                	**type**\:  bool
                                
                                .. attribute:: tcp_session_open_mode
                                
                                	The TCP mode to be used to set up BGP session with the neighbor
                                	**type**\:   :py:class:`BgpTcpModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpModeEnum>`
                                
                                .. attribute:: tcpmss
                                
                                	Neighbor TCP Maximum Segment                     size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tos_type
                                
                                	Precedence or DSCP type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_value
                                
                                	Precedence or DSCP value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ttl_security_enabled
                                
                                	TTL Security enabled
                                	**type**\:  bool
                                
                                .. attribute:: upd_errh_noreset
                                
                                	Update errh noreset
                                	**type**\:  bool
                                
                                .. attribute:: update_source
                                
                                	Update Source
                                	**type**\:  str
                                
                                .. attribute:: vrf_name
                                
                                	Name of the VRF
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.neighbor_range_address = None
                                    self.active_bmp_servers = None
                                    self.addpath_receive_disable = None
                                    self.addpath_receive_enable = None
                                    self.addpath_send_disable = None
                                    self.addpath_send_enable = None
                                    self.af_data = YList()
                                    self.af_data.parent = self
                                    self.af_data.name = 'af_data'
                                    self.attrf_group_name = None
                                    self.bfd_minintervalval = None
                                    self.bfd_multiplierval = None
                                    self.bfd_session_enable_mode = None
                                    self.cfg_local_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress()
                                    self.cfg_local_address.parent = self
                                    self.configured_hold_time = None
                                    self.configured_keepalive = None
                                    self.configured_min_acc_hold_time = None
                                    self.connection_local_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress()
                                    self.connection_local_address.parent = self
                                    self.connection_remote_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress()
                                    self.connection_remote_address.parent = self
                                    self.current_peers = None
                                    self.description = None
                                    self.discard_as4_path = None
                                    self.dmz_link_bandwidth = None
                                    self.ebgp_recv_dmz = None
                                    self.ebgp_send_dmz_mode = None
                                    self.ebgp_time_to_live = None
                                    self.egress_peer_engineering_enabled = None
                                    self.gr_restart_time = None
                                    self.gr_stale_path_time = None
                                    self.graceful_maintenance = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.GracefulMaintenance()
                                    self.graceful_maintenance.parent = self
                                    self.graceful_restart_enabled_nbr = None
                                    self.has_internal_link = None
                                    self.idle_watch_time = None
                                    self.ignore_connected = None
                                    self.instance = YList()
                                    self.instance.parent = self
                                    self.instance.name = 'instance'
                                    self.internal_vpn_client = None
                                    self.is_administratively_shut_down = None
                                    self.is_capability_negotiation_performed = None
                                    self.is_ebgp_multihop_bgpmpls_forwarding_disabled = None
                                    self.is_local_address_configured = None
                                    self.is_neighbor_max_prefix_shutdown = None
                                    self.is_out_of_memory_forced_up = None
                                    self.is_passive_close = None
                                    self.islocal_address_cfg = None
                                    self.local_as = None
                                    self.local_as_dual_as = None
                                    self.local_as_dual_as_mode_native = None
                                    self.local_as_no_prepend = None
                                    self.local_as_replace_as = None
                                    self.max_peers = None
                                    self.min_advertise_interval = None
                                    self.min_advertise_interval_msecs = None
                                    self.min_origination_interval = None
                                    self.msg_buf_count = None
                                    self.msg_bug_circular = None
                                    self.msg_log_in = None
                                    self.msg_log_out = None
                                    self.nbr_cluster_id = None
                                    self.nbr_enforce_first_as = None
                                    self.nbr_in_cluster = None
                                    self.nbr_rcv_size = None
                                    self.nbr_send_size = None
                                    self.neighbor_local_as = None
                                    self.neighbor_range_prefix_length = None
                                    self.nsr_enabled = None
                                    self.oper_attrf_enable = None
                                    self.range_inst_error = None
                                    self.range_max_drop = None
                                    self.range_open_accepted = None
                                    self.range_open_match = None
                                    self.remote_as = None
                                    self.remote_as_list_name = None
                                    self.remote_as_number = None
                                    self.rpki_allow_invalid = None
                                    self.rpki_disable = None
                                    self.rpki_signal_ibgp = None
                                    self.rpki_use_validity = None
                                    self.speaker_id = None
                                    self.standby_rp = None
                                    self.suppress4_byte_as = None
                                    self.syslog_enable = None
                                    self.tcp_session_open_mode = None
                                    self.tcpmss = None
                                    self.tos_type = None
                                    self.tos_value = None
                                    self.ttl_security_enabled = None
                                    self.upd_errh_noreset = None
                                    self.update_source = None
                                    self.vrf_name = None


                                class ConnectionLocalAddress(object):
                                    """
                                    Local address for the connection
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpnvpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnvplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4mdt_address = None
                                        self.ipv4mvpn_address = None
                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                        self.ipv4sr_policy_address.parent = self
                                        self.ipv4vpn_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                        self.ipv6sr_policy_address.parent = self
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_flowspec_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.l2vpn_evpn_address = None
                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnvplsAddress()
                                        self.l2vpnvpls_address.parent = self
                                        self.ls_ls_address = None
                                        self.rt_constraint_address = None


                                    class L2VpnvplsAddress(object):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnvplsAddress']['meta_info']


                                    class L2VpnMspwAddress(object):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnMspwAddress']['meta_info']


                                    class Ipv4SrPolicyAddress(object):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress']['meta_info']


                                    class Ipv6SrPolicyAddress(object):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv6_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv6_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connection-local-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.afi is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv4_flowspec_address is not None:
                                            return True

                                        if self.ipv4_label_address is not None:
                                            return True

                                        if self.ipv4_mcast_address is not None:
                                            return True

                                        if self.ipv4_tunnel_address is not None:
                                            return True

                                        if self.ipv4mdt_address is not None:
                                            return True

                                        if self.ipv4mvpn_address is not None:
                                            return True

                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                            return True

                                        if self.ipv4vpn_address is not None:
                                            return True

                                        if self.ipv4vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv4vpna_mcastddress is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        if self.ipv6_flowspec_address is not None:
                                            return True

                                        if self.ipv6_label_address is not None:
                                            return True

                                        if self.ipv6_mcast_address is not None:
                                            return True

                                        if self.ipv6mvpn_address is not None:
                                            return True

                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                            return True

                                        if self.ipv6vpn_address is not None:
                                            return True

                                        if self.ipv6vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv6vpn_mcast_address is not None:
                                            return True

                                        if self.l2vpn_evpn_address is not None:
                                            return True

                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                            return True

                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                            return True

                                        if self.ls_ls_address is not None:
                                            return True

                                        if self.rt_constraint_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress']['meta_info']


                                class ConnectionRemoteAddress(object):
                                    """
                                    Remote address for the connection
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpnvpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnvplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4mdt_address = None
                                        self.ipv4mvpn_address = None
                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                        self.ipv4sr_policy_address.parent = self
                                        self.ipv4vpn_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                        self.ipv6sr_policy_address.parent = self
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_flowspec_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.l2vpn_evpn_address = None
                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnvplsAddress()
                                        self.l2vpnvpls_address.parent = self
                                        self.ls_ls_address = None
                                        self.rt_constraint_address = None


                                    class L2VpnvplsAddress(object):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnvplsAddress']['meta_info']


                                    class L2VpnMspwAddress(object):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnMspwAddress']['meta_info']


                                    class Ipv4SrPolicyAddress(object):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress']['meta_info']


                                    class Ipv6SrPolicyAddress(object):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv6_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv6_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connection-remote-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.afi is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv4_flowspec_address is not None:
                                            return True

                                        if self.ipv4_label_address is not None:
                                            return True

                                        if self.ipv4_mcast_address is not None:
                                            return True

                                        if self.ipv4_tunnel_address is not None:
                                            return True

                                        if self.ipv4mdt_address is not None:
                                            return True

                                        if self.ipv4mvpn_address is not None:
                                            return True

                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                            return True

                                        if self.ipv4vpn_address is not None:
                                            return True

                                        if self.ipv4vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv4vpna_mcastddress is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        if self.ipv6_flowspec_address is not None:
                                            return True

                                        if self.ipv6_label_address is not None:
                                            return True

                                        if self.ipv6_mcast_address is not None:
                                            return True

                                        if self.ipv6mvpn_address is not None:
                                            return True

                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                            return True

                                        if self.ipv6vpn_address is not None:
                                            return True

                                        if self.ipv6vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv6vpn_mcast_address is not None:
                                            return True

                                        if self.l2vpn_evpn_address is not None:
                                            return True

                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                            return True

                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                            return True

                                        if self.ls_ls_address is not None:
                                            return True

                                        if self.rt_constraint_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress']['meta_info']


                                class GracefulMaintenance(object):
                                    """
                                    Graceful Maintenance
                                    
                                    .. attribute:: gshut_active
                                    
                                    	Graceful Maintenance activated
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_exists
                                    
                                    	Graceful Maintenance enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_local_active
                                    
                                    	Graceful Maintenance locally activated
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_locpref
                                    
                                    	Graceful Maintenance Local Preference
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: gshut_locpref_set
                                    
                                    	Graceful Maintenance Local Preference set
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_prepends
                                    
                                    	Graceful Maintenance number of AS prepends
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.gshut_active = None
                                        self.gshut_exists = None
                                        self.gshut_local_active = None
                                        self.gshut_locpref = None
                                        self.gshut_locpref_set = None
                                        self.gshut_prepends = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:graceful-maintenance'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.gshut_active is not None:
                                            return True

                                        if self.gshut_exists is not None:
                                            return True

                                        if self.gshut_local_active is not None:
                                            return True

                                        if self.gshut_locpref is not None:
                                            return True

                                        if self.gshut_locpref_set is not None:
                                            return True

                                        if self.gshut_prepends is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.GracefulMaintenance']['meta_info']


                                class CfgLocalAddress(object):
                                    """
                                    Configured local address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpnvpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnvplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4mdt_address = None
                                        self.ipv4mvpn_address = None
                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress()
                                        self.ipv4sr_policy_address.parent = self
                                        self.ipv4vpn_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress()
                                        self.ipv6sr_policy_address.parent = self
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_flowspec_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.l2vpn_evpn_address = None
                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnvplsAddress()
                                        self.l2vpnvpls_address.parent = self
                                        self.ls_ls_address = None
                                        self.rt_constraint_address = None


                                    class L2VpnvplsAddress(object):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnvplsAddress']['meta_info']


                                    class L2VpnMspwAddress(object):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnMspwAddress']['meta_info']


                                    class Ipv4SrPolicyAddress(object):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress']['meta_info']


                                    class Ipv6SrPolicyAddress(object):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv6_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv6_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cfg-local-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.afi is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv4_flowspec_address is not None:
                                            return True

                                        if self.ipv4_label_address is not None:
                                            return True

                                        if self.ipv4_mcast_address is not None:
                                            return True

                                        if self.ipv4_tunnel_address is not None:
                                            return True

                                        if self.ipv4mdt_address is not None:
                                            return True

                                        if self.ipv4mvpn_address is not None:
                                            return True

                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                            return True

                                        if self.ipv4vpn_address is not None:
                                            return True

                                        if self.ipv4vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv4vpna_mcastddress is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        if self.ipv6_flowspec_address is not None:
                                            return True

                                        if self.ipv6_label_address is not None:
                                            return True

                                        if self.ipv6_mcast_address is not None:
                                            return True

                                        if self.ipv6mvpn_address is not None:
                                            return True

                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                            return True

                                        if self.ipv6vpn_address is not None:
                                            return True

                                        if self.ipv6vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv6vpn_mcast_address is not None:
                                            return True

                                        if self.l2vpn_evpn_address is not None:
                                            return True

                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                            return True

                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                            return True

                                        if self.ls_ls_address is not None:
                                            return True

                                        if self.rt_constraint_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress']['meta_info']


                                class AfData(object):
                                    """
                                    Address family specific neighbor data
                                    
                                    .. attribute:: accept_own_enabled
                                    
                                    	Accept\-Own enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: address_family_long_lived_time
                                    
                                    	AF specific Long\-lived\-time config
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: advertise_afi
                                    
                                    	Encode in Advertise AFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_afi_disable
                                    
                                    	Encode in Advertise AFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_afi_local
                                    
                                    	Encode in Advertise AFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_afi_reorg
                                    
                                    	Encode in Advertise AFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_v4_flags
                                    
                                    	Advertise options for VPNV4
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: advertise_v6_flags
                                    
                                    	Advertise options for VPNV6
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: afrpki_allow_invalid
                                    
                                    	Prefix v. allow invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: afrpki_disable
                                    
                                    	Prefix validation disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: afrpki_signal_ibgp
                                    
                                    	Prefix v. signal ibgp
                                    	**type**\:  bool
                                    
                                    .. attribute:: afrpki_use_validity
                                    
                                    	Prefix v. use validity
                                    	**type**\:  bool
                                    
                                    .. attribute:: allow_as_in_count
                                    
                                    	Allowas\-in count config
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: always_use_next_hop_local
                                    
                                    	Local router always used for next\-hop
                                    	**type**\:  bool
                                    
                                    .. attribute:: extended_community
                                    
                                    	Extended community attribute
                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity>`
                                    
                                    .. attribute:: extended_community_standby
                                    
                                    	Extended community attribute
                                    	**type**\: list of    :py:class:`ExtendedCommunityStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby>`
                                    
                                    .. attribute:: flowspec_redirect_validation_d_isable
                                    
                                    	Flowspec Redirect Validation Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flowspec_validation_d_isable
                                    
                                    	Flowspec Validation Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: import_reoriginate
                                    
                                    	Import Reoriginate enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: import_reoriginate_stitching
                                    
                                    	Import Reoriginate Stitching enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: import_stitching
                                    
                                    	Import Stitching enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_add_path_receive_capability_advertised
                                    
                                    	Addpath Receive capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_add_path_receive_capability_received
                                    
                                    	Addpath Receive capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_add_path_send_capability_advertised
                                    
                                    	Addpath Send capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_add_path_send_capability_received
                                    
                                    	Addpath Send capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_addpath_receive_operational
                                    
                                    	Addpath is operational on receive\-side
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_addpath_send_operational
                                    
                                    	Addpath is operational on send\-side
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_advertise_permanent_network
                                    
                                    	Advertise Permanent Network
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_advertised_graceful_restart
                                    
                                    	Graceful Restart Capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_advertised_orf_receive
                                    
                                    	Prefix based ORF receive mode capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_advertised_orf_send
                                    
                                    	Prefix based ORF send mode capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_aigp_set
                                    
                                    	AIGP set 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_allow_as_in_set
                                    
                                    	Allowas\-in set 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_as_override_set
                                    
                                    	As override set 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_graceful_restart_state_flag
                                    
                                    	Restart state flag enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_legacy_pe_rt
                                    
                                    	Nbr accepts route from legacy PE for RT\-Constraint AF 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_af_capable
                                    
                                    	Address family capability received from neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_ebgp_without_inbound_policy
                                    
                                    	eBGP neighbor with no configured inbound policy
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_ebgp_without_outbound_policy
                                    
                                    	eBGP neighbor with no configured outbound policy
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_route_reflector_client
                                    
                                    	Nbr is a route reflector client
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_orf_send_scheduled
                                    
                                    	Scheduled to send prefix based ORF
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_orf_sent
                                    
                                    	Outbound route filter sent to neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_orr_root_address_configured
                                    
                                    	ORR Root address configuredfor the neighbor connection
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_peer_orf_capable
                                    
                                    	Peer has outbound route filter capability
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_prefix_orf_present
                                    
                                    	Outbound route filter prefix ORF present
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_received_graceful_restart_capable
                                    
                                    	Graceful Restart Capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_received_orf_receive_capable
                                    
                                    	Prefix based ORF receive mode capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_received_orf_send_capable
                                    
                                    	Prefix based ORF send mode capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_rt_present
                                    
                                    	RT attribute list present
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_rt_present_standby
                                    
                                    	RT attribute list present
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_send_mcast_attr
                                    
                                    	Send Mcast Attr
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_soft_reconfiguration_inbound_allowed
                                    
                                    	Inbound soft reconfiguration allowed
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_update_deferred
                                    
                                    	Update deferred until ORF/route refresh received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_use_soft_reconfiguration_always_on
                                    
                                    	Soft reconf overrides route refresh
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_restart_time
                                    
                                    	Local Restart time (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: long_lived_graceful_restart_capability_received
                                    
                                    	Long\-lived graceful\-restart capability received from the neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_accept
                                    
                                    	Maximum long\-lived graceful\-restart stale time acceptable from the neighbor (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_configured
                                    
                                    	Long\-lived graceful\-restart stale time is configured
                                    	**type**\:  bool
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_received
                                    
                                    	Long\-lived graceful\-restart stale time received from the neighbor (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_sent
                                    
                                    	Stale time sent in long\-lived graceful\-restart capability (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: max_prefix_discard_extra_paths
                                    
                                    	Discard extra paths when prefix limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: max_prefix_exceed_discard_paths
                                    
                                    	Did we discard extra paths when prefix limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: max_prefix_limit
                                    
                                    	Max limit for # of prefixes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: max_prefix_restart_time
                                    
                                    	Time interval (in minutes) after which peering session will be reestablished
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: minute
                                    
                                    .. attribute:: max_prefix_threshold_percent
                                    
                                    	Percentage of maximum no. of prefixes at which to generate warning
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: percentage
                                    
                                    .. attribute:: neighbor_default_originate
                                    
                                    	Neighbor originates default
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_long_lived_graceful_restart_capable
                                    
                                    	Treat neighbor as long\-lived graceful\-restart capable
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_long_lived_graceful_restart_time_remaining
                                    
                                    	Remaining long\-lived graceful\-restart time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_preserved_forwarding_state
                                    
                                    	Neighbor preserved forwarding state
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_preserved_long_lived_forwarding_state
                                    
                                    	Neighbor preserved long\-lived forwarding state
                                    	**type**\:  bool
                                    
                                    .. attribute:: next_hop_unchanged
                                    
                                    	router does not change next\-hop
                                    	**type**\:  bool
                                    
                                    .. attribute:: orf_entries_received
                                    
                                    	Number of outbound route filter entries received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: orr_group_index
                                    
                                    	ORR Group Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: orr_group_name
                                    
                                    	ORR Group Name
                                    	**type**\:  str
                                    
                                    .. attribute:: remove_private_as_entire_aspath_from_inbound_updates
                                    
                                    	Private AS numbers removed from updates from this nbr only if the aspath has only private ASes
                                    	**type**\:  bool
                                    
                                    .. attribute:: remove_private_as_entire_aspath_from_updates
                                    
                                    	Private AS numbers removed from updates to thisnbr only if the aspath hasonly private ASes
                                    	**type**\:  bool
                                    
                                    .. attribute:: remove_private_as_from_inbound_updates
                                    
                                    	Private AS numbers removed from updates from this nbr
                                    	**type**\:  bool
                                    
                                    .. attribute:: remove_private_as_from_updates
                                    
                                    	Private AS numbers removed from updates to this nbr
                                    	**type**\:  bool
                                    
                                    .. attribute:: restart_time
                                    
                                    	Restart time advertised (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: rib_purge_timeout_value
                                    
                                    	RIB purge timeout time (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: route_policy_default_originate
                                    
                                    	Default\-originate route policy name
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_in
                                    
                                    	Incoming route policy name
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_out
                                    
                                    	Outgoing route policy name
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_prefix_orf
                                    
                                    	Prefix based ORF for incoming updates
                                    	**type**\:  str
                                    
                                    .. attribute:: selective_multipath_eligible
                                    
                                    	Selective multipath eligible
                                    	**type**\:  bool
                                    
                                    .. attribute:: sent_community_to_neighbor
                                    
                                    	Community attribute sent to neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: sent_extended_community_to_neighbor
                                    
                                    	Extended community attribute sent to neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: sent_gshut_community_to_neighbor
                                    
                                    	GSHUT Community attribute sent to neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: stale_path_timeout
                                    
                                    	Stale path timeout time (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: use_max_prefix_warning_only
                                    
                                    	Warning only when maximum prefix limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: vpn_update_gen_enabled
                                    
                                    	RT Nbr enabled for updategento another
                                    	**type**\:  bool
                                    
                                    .. attribute:: vpn_update_gen_trigger_enabled
                                    
                                    	RT Nbr enabled for updategento another
                                    	**type**\:  bool
                                    
                                    .. attribute:: weight
                                    
                                    	Weight for this AF
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.accept_own_enabled = None
                                        self.address_family_long_lived_time = None
                                        self.advertise_afi = None
                                        self.advertise_afi_disable = None
                                        self.advertise_afi_local = None
                                        self.advertise_afi_reorg = None
                                        self.advertise_v4_flags = None
                                        self.advertise_v6_flags = None
                                        self.af_name = None
                                        self.afrpki_allow_invalid = None
                                        self.afrpki_disable = None
                                        self.afrpki_signal_ibgp = None
                                        self.afrpki_use_validity = None
                                        self.allow_as_in_count = None
                                        self.always_use_next_hop_local = None
                                        self.extended_community = YList()
                                        self.extended_community.parent = self
                                        self.extended_community.name = 'extended_community'
                                        self.extended_community_standby = YList()
                                        self.extended_community_standby.parent = self
                                        self.extended_community_standby.name = 'extended_community_standby'
                                        self.flowspec_redirect_validation_d_isable = None
                                        self.flowspec_validation_d_isable = None
                                        self.import_reoriginate = None
                                        self.import_reoriginate_stitching = None
                                        self.import_stitching = None
                                        self.is_add_path_receive_capability_advertised = None
                                        self.is_add_path_receive_capability_received = None
                                        self.is_add_path_send_capability_advertised = None
                                        self.is_add_path_send_capability_received = None
                                        self.is_addpath_receive_operational = None
                                        self.is_addpath_send_operational = None
                                        self.is_advertise_permanent_network = None
                                        self.is_advertised_graceful_restart = None
                                        self.is_advertised_orf_receive = None
                                        self.is_advertised_orf_send = None
                                        self.is_aigp_set = None
                                        self.is_allow_as_in_set = None
                                        self.is_as_override_set = None
                                        self.is_graceful_restart_state_flag = None
                                        self.is_legacy_pe_rt = None
                                        self.is_neighbor_af_capable = None
                                        self.is_neighbor_ebgp_without_inbound_policy = None
                                        self.is_neighbor_ebgp_without_outbound_policy = None
                                        self.is_neighbor_route_reflector_client = None
                                        self.is_orf_send_scheduled = None
                                        self.is_orf_sent = None
                                        self.is_orr_root_address_configured = None
                                        self.is_peer_orf_capable = None
                                        self.is_prefix_orf_present = None
                                        self.is_received_graceful_restart_capable = None
                                        self.is_received_orf_receive_capable = None
                                        self.is_received_orf_send_capable = None
                                        self.is_rt_present = None
                                        self.is_rt_present_standby = None
                                        self.is_send_mcast_attr = None
                                        self.is_soft_reconfiguration_inbound_allowed = None
                                        self.is_update_deferred = None
                                        self.is_use_soft_reconfiguration_always_on = None
                                        self.local_restart_time = None
                                        self.long_lived_graceful_restart_capability_received = None
                                        self.long_lived_graceful_restart_stale_time_accept = None
                                        self.long_lived_graceful_restart_stale_time_configured = None
                                        self.long_lived_graceful_restart_stale_time_received = None
                                        self.long_lived_graceful_restart_stale_time_sent = None
                                        self.max_prefix_discard_extra_paths = None
                                        self.max_prefix_exceed_discard_paths = None
                                        self.max_prefix_limit = None
                                        self.max_prefix_restart_time = None
                                        self.max_prefix_threshold_percent = None
                                        self.neighbor_default_originate = None
                                        self.neighbor_long_lived_graceful_restart_capable = None
                                        self.neighbor_long_lived_graceful_restart_time_remaining = None
                                        self.neighbor_preserved_forwarding_state = None
                                        self.neighbor_preserved_long_lived_forwarding_state = None
                                        self.next_hop_unchanged = None
                                        self.orf_entries_received = None
                                        self.orr_group_index = None
                                        self.orr_group_name = None
                                        self.remove_private_as_entire_aspath_from_inbound_updates = None
                                        self.remove_private_as_entire_aspath_from_updates = None
                                        self.remove_private_as_from_inbound_updates = None
                                        self.remove_private_as_from_updates = None
                                        self.restart_time = None
                                        self.rib_purge_timeout_value = None
                                        self.route_policy_default_originate = None
                                        self.route_policy_in = None
                                        self.route_policy_out = None
                                        self.route_policy_prefix_orf = None
                                        self.selective_multipath_eligible = None
                                        self.sent_community_to_neighbor = None
                                        self.sent_extended_community_to_neighbor = None
                                        self.sent_gshut_community_to_neighbor = None
                                        self.stale_path_timeout = None
                                        self.use_max_prefix_warning_only = None
                                        self.vpn_update_gen_enabled = None
                                        self.vpn_update_gen_trigger_enabled = None
                                        self.weight = None


                                    class ExtendedCommunity(object):
                                        """
                                        Extended community attribute
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.entry = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.entry is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity']['meta_info']


                                    class ExtendedCommunityStandby(object):
                                        """
                                        Extended community attribute
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.entry = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community-standby'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.entry is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af-data'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.accept_own_enabled is not None:
                                            return True

                                        if self.address_family_long_lived_time is not None:
                                            return True

                                        if self.advertise_afi is not None:
                                            return True

                                        if self.advertise_afi_disable is not None:
                                            return True

                                        if self.advertise_afi_local is not None:
                                            return True

                                        if self.advertise_afi_reorg is not None:
                                            return True

                                        if self.advertise_v4_flags is not None:
                                            return True

                                        if self.advertise_v6_flags is not None:
                                            return True

                                        if self.af_name is not None:
                                            return True

                                        if self.afrpki_allow_invalid is not None:
                                            return True

                                        if self.afrpki_disable is not None:
                                            return True

                                        if self.afrpki_signal_ibgp is not None:
                                            return True

                                        if self.afrpki_use_validity is not None:
                                            return True

                                        if self.allow_as_in_count is not None:
                                            return True

                                        if self.always_use_next_hop_local is not None:
                                            return True

                                        if self.extended_community is not None:
                                            for child_ref in self.extended_community:
                                                if child_ref._has_data():
                                                    return True

                                        if self.extended_community_standby is not None:
                                            for child_ref in self.extended_community_standby:
                                                if child_ref._has_data():
                                                    return True

                                        if self.flowspec_redirect_validation_d_isable is not None:
                                            return True

                                        if self.flowspec_validation_d_isable is not None:
                                            return True

                                        if self.import_reoriginate is not None:
                                            return True

                                        if self.import_reoriginate_stitching is not None:
                                            return True

                                        if self.import_stitching is not None:
                                            return True

                                        if self.is_add_path_receive_capability_advertised is not None:
                                            return True

                                        if self.is_add_path_receive_capability_received is not None:
                                            return True

                                        if self.is_add_path_send_capability_advertised is not None:
                                            return True

                                        if self.is_add_path_send_capability_received is not None:
                                            return True

                                        if self.is_addpath_receive_operational is not None:
                                            return True

                                        if self.is_addpath_send_operational is not None:
                                            return True

                                        if self.is_advertise_permanent_network is not None:
                                            return True

                                        if self.is_advertised_graceful_restart is not None:
                                            return True

                                        if self.is_advertised_orf_receive is not None:
                                            return True

                                        if self.is_advertised_orf_send is not None:
                                            return True

                                        if self.is_aigp_set is not None:
                                            return True

                                        if self.is_allow_as_in_set is not None:
                                            return True

                                        if self.is_as_override_set is not None:
                                            return True

                                        if self.is_graceful_restart_state_flag is not None:
                                            return True

                                        if self.is_legacy_pe_rt is not None:
                                            return True

                                        if self.is_neighbor_af_capable is not None:
                                            return True

                                        if self.is_neighbor_ebgp_without_inbound_policy is not None:
                                            return True

                                        if self.is_neighbor_ebgp_without_outbound_policy is not None:
                                            return True

                                        if self.is_neighbor_route_reflector_client is not None:
                                            return True

                                        if self.is_orf_send_scheduled is not None:
                                            return True

                                        if self.is_orf_sent is not None:
                                            return True

                                        if self.is_orr_root_address_configured is not None:
                                            return True

                                        if self.is_peer_orf_capable is not None:
                                            return True

                                        if self.is_prefix_orf_present is not None:
                                            return True

                                        if self.is_received_graceful_restart_capable is not None:
                                            return True

                                        if self.is_received_orf_receive_capable is not None:
                                            return True

                                        if self.is_received_orf_send_capable is not None:
                                            return True

                                        if self.is_rt_present is not None:
                                            return True

                                        if self.is_rt_present_standby is not None:
                                            return True

                                        if self.is_send_mcast_attr is not None:
                                            return True

                                        if self.is_soft_reconfiguration_inbound_allowed is not None:
                                            return True

                                        if self.is_update_deferred is not None:
                                            return True

                                        if self.is_use_soft_reconfiguration_always_on is not None:
                                            return True

                                        if self.local_restart_time is not None:
                                            return True

                                        if self.long_lived_graceful_restart_capability_received is not None:
                                            return True

                                        if self.long_lived_graceful_restart_stale_time_accept is not None:
                                            return True

                                        if self.long_lived_graceful_restart_stale_time_configured is not None:
                                            return True

                                        if self.long_lived_graceful_restart_stale_time_received is not None:
                                            return True

                                        if self.long_lived_graceful_restart_stale_time_sent is not None:
                                            return True

                                        if self.max_prefix_discard_extra_paths is not None:
                                            return True

                                        if self.max_prefix_exceed_discard_paths is not None:
                                            return True

                                        if self.max_prefix_limit is not None:
                                            return True

                                        if self.max_prefix_restart_time is not None:
                                            return True

                                        if self.max_prefix_threshold_percent is not None:
                                            return True

                                        if self.neighbor_default_originate is not None:
                                            return True

                                        if self.neighbor_long_lived_graceful_restart_capable is not None:
                                            return True

                                        if self.neighbor_long_lived_graceful_restart_time_remaining is not None:
                                            return True

                                        if self.neighbor_preserved_forwarding_state is not None:
                                            return True

                                        if self.neighbor_preserved_long_lived_forwarding_state is not None:
                                            return True

                                        if self.next_hop_unchanged is not None:
                                            return True

                                        if self.orf_entries_received is not None:
                                            return True

                                        if self.orr_group_index is not None:
                                            return True

                                        if self.orr_group_name is not None:
                                            return True

                                        if self.remove_private_as_entire_aspath_from_inbound_updates is not None:
                                            return True

                                        if self.remove_private_as_entire_aspath_from_updates is not None:
                                            return True

                                        if self.remove_private_as_from_inbound_updates is not None:
                                            return True

                                        if self.remove_private_as_from_updates is not None:
                                            return True

                                        if self.restart_time is not None:
                                            return True

                                        if self.rib_purge_timeout_value is not None:
                                            return True

                                        if self.route_policy_default_originate is not None:
                                            return True

                                        if self.route_policy_in is not None:
                                            return True

                                        if self.route_policy_out is not None:
                                            return True

                                        if self.route_policy_prefix_orf is not None:
                                            return True

                                        if self.selective_multipath_eligible is not None:
                                            return True

                                        if self.sent_community_to_neighbor is not None:
                                            return True

                                        if self.sent_extended_community_to_neighbor is not None:
                                            return True

                                        if self.sent_gshut_community_to_neighbor is not None:
                                            return True

                                        if self.stale_path_timeout is not None:
                                            return True

                                        if self.use_max_prefix_warning_only is not None:
                                            return True

                                        if self.vpn_update_gen_enabled is not None:
                                            return True

                                        if self.vpn_update_gen_trigger_enabled is not None:
                                            return True

                                        if self.weight is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData']['meta_info']


                                class Instance_(object):
                                    """
                                    Dynamic Neighbor Instance List
                                    
                                    .. attribute:: connection_state
                                    
                                    	State of connection
                                    	**type**\:   :py:class:`BgpConnStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnStateEnum>`
                                    
                                    .. attribute:: idle_watch_timer_remaining_value
                                    
                                    	Idle watch timer remaining time
                                    	**type**\:   :py:class:`IdleWatchTimerRemainingValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.IdleWatchTimerRemainingValue>`
                                    
                                    .. attribute:: is_idle_watch_timer_running
                                    
                                    	Is idle watch timer running
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Dynamic Neighbor address
                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress>`
                                    
                                    .. attribute:: neighbor_age
                                    
                                    	Neighbor age
                                    	**type**\:   :py:class:`NeighborAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAge>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.connection_state = None
                                        self.idle_watch_timer_remaining_value = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.IdleWatchTimerRemainingValue()
                                        self.idle_watch_timer_remaining_value.parent = self
                                        self.is_idle_watch_timer_running = None
                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress()
                                        self.neighbor_address.parent = self
                                        self.neighbor_age = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAge()
                                        self.neighbor_age.parent = self


                                    class NeighborAddress(object):
                                        """
                                        Dynamic Neighbor address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress']['meta_info']


                                    class NeighborAge(object):
                                        """
                                        Neighbor age
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-age'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAge']['meta_info']


                                    class IdleWatchTimerRemainingValue(object):
                                        """
                                        Idle watch timer remaining time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:idle-watch-timer-remaining-value'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.IdleWatchTimerRemainingValue']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:instance'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.connection_state is not None:
                                            return True

                                        if self.idle_watch_timer_remaining_value is not None and self.idle_watch_timer_remaining_value._has_data():
                                            return True

                                        if self.is_idle_watch_timer_running is not None:
                                            return True

                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                            return True

                                        if self.neighbor_age is not None and self.neighbor_age._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.neighbor_range_address is None:
                                        raise YPYModelError('Key property neighbor_range_address is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-range[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-range-address = ' + str(self.neighbor_range_address) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.neighbor_range_address is not None:
                                        return True

                                    if self.active_bmp_servers is not None:
                                        return True

                                    if self.addpath_receive_disable is not None:
                                        return True

                                    if self.addpath_receive_enable is not None:
                                        return True

                                    if self.addpath_send_disable is not None:
                                        return True

                                    if self.addpath_send_enable is not None:
                                        return True

                                    if self.af_data is not None:
                                        for child_ref in self.af_data:
                                            if child_ref._has_data():
                                                return True

                                    if self.attrf_group_name is not None:
                                        return True

                                    if self.bfd_minintervalval is not None:
                                        return True

                                    if self.bfd_multiplierval is not None:
                                        return True

                                    if self.bfd_session_enable_mode is not None:
                                        return True

                                    if self.cfg_local_address is not None and self.cfg_local_address._has_data():
                                        return True

                                    if self.configured_hold_time is not None:
                                        return True

                                    if self.configured_keepalive is not None:
                                        return True

                                    if self.configured_min_acc_hold_time is not None:
                                        return True

                                    if self.connection_local_address is not None and self.connection_local_address._has_data():
                                        return True

                                    if self.connection_remote_address is not None and self.connection_remote_address._has_data():
                                        return True

                                    if self.current_peers is not None:
                                        return True

                                    if self.description is not None:
                                        return True

                                    if self.discard_as4_path is not None:
                                        return True

                                    if self.dmz_link_bandwidth is not None:
                                        return True

                                    if self.ebgp_recv_dmz is not None:
                                        return True

                                    if self.ebgp_send_dmz_mode is not None:
                                        return True

                                    if self.ebgp_time_to_live is not None:
                                        return True

                                    if self.egress_peer_engineering_enabled is not None:
                                        return True

                                    if self.gr_restart_time is not None:
                                        return True

                                    if self.gr_stale_path_time is not None:
                                        return True

                                    if self.graceful_maintenance is not None and self.graceful_maintenance._has_data():
                                        return True

                                    if self.graceful_restart_enabled_nbr is not None:
                                        return True

                                    if self.has_internal_link is not None:
                                        return True

                                    if self.idle_watch_time is not None:
                                        return True

                                    if self.ignore_connected is not None:
                                        return True

                                    if self.instance is not None:
                                        for child_ref in self.instance:
                                            if child_ref._has_data():
                                                return True

                                    if self.internal_vpn_client is not None:
                                        return True

                                    if self.is_administratively_shut_down is not None:
                                        return True

                                    if self.is_capability_negotiation_performed is not None:
                                        return True

                                    if self.is_ebgp_multihop_bgpmpls_forwarding_disabled is not None:
                                        return True

                                    if self.is_local_address_configured is not None:
                                        return True

                                    if self.is_neighbor_max_prefix_shutdown is not None:
                                        return True

                                    if self.is_out_of_memory_forced_up is not None:
                                        return True

                                    if self.is_passive_close is not None:
                                        return True

                                    if self.islocal_address_cfg is not None:
                                        return True

                                    if self.local_as is not None:
                                        return True

                                    if self.local_as_dual_as is not None:
                                        return True

                                    if self.local_as_dual_as_mode_native is not None:
                                        return True

                                    if self.local_as_no_prepend is not None:
                                        return True

                                    if self.local_as_replace_as is not None:
                                        return True

                                    if self.max_peers is not None:
                                        return True

                                    if self.min_advertise_interval is not None:
                                        return True

                                    if self.min_advertise_interval_msecs is not None:
                                        return True

                                    if self.min_origination_interval is not None:
                                        return True

                                    if self.msg_buf_count is not None:
                                        return True

                                    if self.msg_bug_circular is not None:
                                        return True

                                    if self.msg_log_in is not None:
                                        return True

                                    if self.msg_log_out is not None:
                                        return True

                                    if self.nbr_cluster_id is not None:
                                        return True

                                    if self.nbr_enforce_first_as is not None:
                                        return True

                                    if self.nbr_in_cluster is not None:
                                        return True

                                    if self.nbr_rcv_size is not None:
                                        return True

                                    if self.nbr_send_size is not None:
                                        return True

                                    if self.neighbor_local_as is not None:
                                        return True

                                    if self.neighbor_range_prefix_length is not None:
                                        return True

                                    if self.nsr_enabled is not None:
                                        return True

                                    if self.oper_attrf_enable is not None:
                                        return True

                                    if self.range_inst_error is not None:
                                        return True

                                    if self.range_max_drop is not None:
                                        return True

                                    if self.range_open_accepted is not None:
                                        return True

                                    if self.range_open_match is not None:
                                        return True

                                    if self.remote_as is not None:
                                        return True

                                    if self.remote_as_list_name is not None:
                                        return True

                                    if self.remote_as_number is not None:
                                        return True

                                    if self.rpki_allow_invalid is not None:
                                        return True

                                    if self.rpki_disable is not None:
                                        return True

                                    if self.rpki_signal_ibgp is not None:
                                        return True

                                    if self.rpki_use_validity is not None:
                                        return True

                                    if self.speaker_id is not None:
                                        return True

                                    if self.standby_rp is not None:
                                        return True

                                    if self.suppress4_byte_as is not None:
                                        return True

                                    if self.syslog_enable is not None:
                                        return True

                                    if self.tcp_session_open_mode is not None:
                                        return True

                                    if self.tcpmss is not None:
                                        return True

                                    if self.tos_type is not None:
                                        return True

                                    if self.tos_value is not None:
                                        return True

                                    if self.ttl_security_enabled is not None:
                                        return True

                                    if self.upd_errh_noreset is not None:
                                        return True

                                    if self.update_source is not None:
                                        return True

                                    if self.vrf_name is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-ranges'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.neighbor_range is not None:
                                    for child_ref in self.neighbor_range:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges']['meta_info']


                        class MessageLogs(object):
                            """
                            The BGP Neighbor Message table
                            
                            .. attribute:: message_log
                            
                            	A BGP Message log entry
                            	**type**\: list of    :py:class:`MessageLog <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.message_log = YList()
                                self.message_log.parent = self
                                self.message_log.name = 'message_log'


                            class MessageLog(object):
                                """
                                A BGP Message log entry
                                
                                .. attribute:: direction
                                
                                	Direction
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: neighbor_message
                                
                                	Array of Neighbor Messages in one direction
                                	**type**\: list of    :py:class:`NeighborMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.direction = None
                                    self.neighbor_address = None
                                    self.neighbor_message = YList()
                                    self.neighbor_message.parent = self
                                    self.neighbor_message.name = 'neighbor_message'


                                class NeighborMessage(object):
                                    """
                                    Array of Neighbor Messages in one direction
                                    
                                    .. attribute:: logged_message_data
                                    
                                    	Raw Message data in binary format
                                    	**type**\: list of    :py:class:`LoggedMessageData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData>`
                                    
                                    .. attribute:: message_data_length
                                    
                                    	Message data length
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: message_timestamp
                                    
                                    	message received time\: time elapsed since 00\:00 \:00 UTC, January 1, 1970
                                    	**type**\:   :py:class:`MessageTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp>`
                                    
                                    .. attribute:: message_type_received
                                    
                                    	Type of messages Received
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: total_logged_message_count
                                    
                                    	Total logged messages count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.logged_message_data = YList()
                                        self.logged_message_data.parent = self
                                        self.logged_message_data.name = 'logged_message_data'
                                        self.message_data_length = None
                                        self.message_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp()
                                        self.message_timestamp.parent = self
                                        self.message_type_received = None
                                        self.total_logged_message_count = None


                                    class MessageTimestamp(object):
                                        """
                                        message received time\: time elapsed since 00\:00
                                        \:00 UTC, January 1, 1970
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:message-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp']['meta_info']


                                    class LoggedMessageData(object):
                                        """
                                        Raw Message data in binary format
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.entry = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:logged-message-data'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.entry is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-message'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.logged_message_data is not None:
                                            for child_ref in self.logged_message_data:
                                                if child_ref._has_data():
                                                    return True

                                        if self.message_data_length is not None:
                                            return True

                                        if self.message_timestamp is not None and self.message_timestamp._has_data():
                                            return True

                                        if self.message_type_received is not None:
                                            return True

                                        if self.total_logged_message_count is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:message-log'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.direction is not None:
                                        return True

                                    if self.neighbor_address is not None:
                                        return True

                                    if self.neighbor_message is not None:
                                        for child_ref in self.neighbor_message:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:message-logs'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.message_log is not None:
                                    for child_ref in self.message_log:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.vrf_name is None:
                                raise YPYModelError('Key property vrf_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:vrf[Cisco-IOS-XR-ipv4-bgp-oper:vrf-name = ' + str(self.vrf_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.vrf_name is not None:
                                return True

                            if self.afs is not None and self.afs._has_data():
                                return True

                            if self.bmp is not None and self.bmp._has_data():
                                return True

                            if self.global_process_info is not None and self.global_process_info._has_data():
                                return True

                            if self.information is not None and self.information._has_data():
                                return True

                            if self.message_logs is not None and self.message_logs._has_data():
                                return True

                            if self.neighbor_ranges is not None and self.neighbor_ranges._has_data():
                                return True

                            if self.neighbors is not None and self.neighbors._has_data():
                                return True

                            if self.next_hop_vrf is not None and self.next_hop_vrf._has_data():
                                return True

                            if self.postits is not None and self.postits._has_data():
                                return True

                            if self.process_info is not None and self.process_info._has_data():
                                return True

                            if self.sessions is not None and self.sessions._has_data():
                                return True

                            if self.update_inbound_error_neighbors is not None and self.update_inbound_error_neighbors._has_data():
                                return True

                            if self.update_inbound_error_vrf is not None and self.update_inbound_error_vrf._has_data():
                                return True

                            if self.update_inbound_filter_neighbors is not None and self.update_inbound_filter_neighbors._has_data():
                                return True

                            if self.update_inbound_filter_vrf is not None and self.update_inbound_filter_vrf._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:vrfs'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.vrf is not None:
                            for child_ref in self.vrf:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Vrfs']['meta_info']


                class DefaultVrf(object):
                    """
                    Default VRF related operational data
                    
                    .. attribute:: afs
                    
                    	BGP address family table
                    	**type**\:   :py:class:`Afs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs>`
                    
                    .. attribute:: bmp
                    
                    	BMP related Operational Data
                    	**type**\:   :py:class:`Bmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp>`
                    
                    .. attribute:: global_process_info
                    
                    	The Global Process information table
                    	**type**\:   :py:class:`GlobalProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo>`
                    
                    .. attribute:: information
                    
                    	Meta data for VRF
                    	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Information>`
                    
                    .. attribute:: message_logs
                    
                    	The BGP Neighbor Message table
                    	**type**\:   :py:class:`MessageLogs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs>`
                    
                    .. attribute:: neighbor_ranges
                    
                    	The BGP Dynamic Neighbor Range table
                    	**type**\:   :py:class:`NeighborRanges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges>`
                    
                    .. attribute:: neighbors
                    
                    	The BGP Neighbor table
                    	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors>`
                    
                    .. attribute:: next_hop_vrf
                    
                    	A BGP Next\-hop VRF table entry
                    	**type**\:   :py:class:`NextHopVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NextHopVrf>`
                    
                    .. attribute:: postits
                    
                    	The BGP Neighbor table
                    	**type**\:   :py:class:`Postits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits>`
                    
                    .. attribute:: process_info
                    
                    	A Process instance table entry
                    	**type**\:   :py:class:`ProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo>`
                    
                    .. attribute:: sessions
                    
                    	The BGP session table
                    	**type**\:   :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions>`
                    
                    .. attribute:: update_inbound_error_neighbors
                    
                    	Update inbound error information for all neighbors
                    	**type**\:   :py:class:`UpdateInboundErrorNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors>`
                    
                    .. attribute:: update_inbound_error_vrf
                    
                    	Update inbound error information for the VRF
                    	**type**\:   :py:class:`UpdateInboundErrorVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorVrf>`
                    
                    .. attribute:: update_inbound_filter_neighbors
                    
                    	Update inbound filtering information for all neighbors
                    	**type**\:   :py:class:`UpdateInboundFilterNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors>`
                    
                    .. attribute:: update_inbound_filter_vrf
                    
                    	Update inbound filtering information for the VRF
                    	**type**\:   :py:class:`UpdateInboundFilterVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterVrf>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2015-08-27'

                    def __init__(self):
                        self.parent = None
                        self.afs = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs()
                        self.afs.parent = self
                        self.bmp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp()
                        self.bmp.parent = self
                        self.global_process_info = Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo()
                        self.global_process_info.parent = self
                        self.information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Information()
                        self.information.parent = self
                        self.message_logs = Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs()
                        self.message_logs.parent = self
                        self.neighbor_ranges = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges()
                        self.neighbor_ranges.parent = self
                        self.neighbors = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors()
                        self.neighbors.parent = self
                        self.next_hop_vrf = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NextHopVrf()
                        self.next_hop_vrf.parent = self
                        self.postits = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits()
                        self.postits.parent = self
                        self.process_info = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo()
                        self.process_info.parent = self
                        self.sessions = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions()
                        self.sessions.parent = self
                        self.update_inbound_error_neighbors = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors()
                        self.update_inbound_error_neighbors.parent = self
                        self.update_inbound_error_vrf = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorVrf()
                        self.update_inbound_error_vrf.parent = self
                        self.update_inbound_filter_neighbors = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors()
                        self.update_inbound_filter_neighbors.parent = self
                        self.update_inbound_filter_vrf = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterVrf()
                        self.update_inbound_filter_vrf.parent = self


                    class UpdateInboundErrorVrf(object):
                        """
                        Update inbound error information for the VRF
                        
                        .. attribute:: last_update_malformed_age
                        
                        	Time since last malformed messages received event (in seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: last_update_malformed_timestamp
                        
                        	Last malformed messages received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                        	**type**\:   :py:class:`LastUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp>`
                        
                        .. attribute:: update_malformed_message_count
                        
                        	Malformed messages count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_malformed_neighbor_count
                        
                        	Count of neighbors that received malformed messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_vrf_name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.last_update_malformed_age = None
                            self.last_update_malformed_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp()
                            self.last_update_malformed_timestamp.parent = self
                            self.update_malformed_message_count = None
                            self.update_malformed_neighbor_count = None
                            self.update_vrf_name = None


                        class LastUpdateMalformedTimestamp(object):
                            """
                            Last malformed messages received time\: time
                            elapsed since 00\:00\:00 UTC, January 1, 1970
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.nanoseconds = None
                                self.seconds = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-malformed-timestamp'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.nanoseconds is not None:
                                    return True

                                if self.seconds is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-inbound-error-vrf'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.last_update_malformed_age is not None:
                                return True

                            if self.last_update_malformed_timestamp is not None and self.last_update_malformed_timestamp._has_data():
                                return True

                            if self.update_malformed_message_count is not None:
                                return True

                            if self.update_malformed_neighbor_count is not None:
                                return True

                            if self.update_vrf_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorVrf']['meta_info']


                    class Afs(object):
                        """
                        BGP address family table
                        
                        .. attribute:: af
                        
                        	A particular address family
                        	**type**\: list of    :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.af = YList()
                            self.af.parent = self
                            self.af.name = 'af'


                        class Af(object):
                            """
                            A particular address family
                            
                            .. attribute:: af_name  <key>
                            
                            	Address family
                            	**type**\:   :py:class:`BgpAddressFamilyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamilyEnum>`
                            
                            .. attribute:: advertised_path_counts
                            
                            	The BGP Advertised paths table (bestpath)
                            	**type**\:   :py:class:`AdvertisedPathCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathCounts>`
                            
                            .. attribute:: advertised_path_xr
                            
                            	The BGP Advertised path table (bestpath)
                            	**type**\:   :py:class:`AdvertisedPathXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr>`
                            
                            .. attribute:: advertised_paths
                            
                            	The BGP Advertised paths table (add\-paths)
                            	**type**\:   :py:class:`AdvertisedPaths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths>`
                            
                            .. attribute:: af_process_info
                            
                            	A BGP Process address family table entry
                            	**type**\:   :py:class:`AfProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo>`
                            
                            .. attribute:: attributes
                            
                            	The BGP Attribute table
                            	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes>`
                            
                            .. attribute:: bmp_paths
                            
                            	The paths in BMP Table
                            	**type**\:   :py:class:`BmpPaths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths>`
                            
                            .. attribute:: convergence
                            
                            	A BGP Convergence table entry
                            	**type**\:   :py:class:`Convergence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Convergence>`
                            
                            .. attribute:: dampenings
                            
                            	The BGP Dampening table
                            	**type**\:   :py:class:`Dampenings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings>`
                            
                            .. attribute:: epes
                            
                            	The BGP Egress Engineering table
                            	**type**\:   :py:class:`Epes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes>`
                            
                            .. attribute:: global_af_process_info
                            
                            	The Global Address Family Process information table
                            	**type**\:   :py:class:`GlobalAfProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo>`
                            
                            .. attribute:: neighbor_af_table
                            
                            	The BGP Neighbor AF table
                            	**type**\:   :py:class:`NeighborAfTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable>`
                            
                            .. attribute:: network_all_rds
                            
                            	The BGP Network Lookup Table
                            	**type**\:   :py:class:`NetworkAllRds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds>`
                            
                            .. attribute:: network_lookup_all_rds
                            
                            	The BGP Network Lookup Table
                            	**type**\:   :py:class:`NetworkLookupAllRds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds>`
                            
                            .. attribute:: network_prefixes
                            
                            	The BGP Network Lookup table
                            	**type**\:   :py:class:`NetworkPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes>`
                            
                            .. attribute:: networks
                            
                            	The BGP Network Table
                            	**type**\:   :py:class:`Networks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks>`
                            
                            .. attribute:: next_hop_address_families
                            
                            	Address family of nexthop table
                            	**type**\:   :py:class:`NextHopAddressFamilies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies>`
                            
                            .. attribute:: path_labeled_table
                            
                            	The BGP Path Labeled Table
                            	**type**\:   :py:class:`PathLabeledTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable>`
                            
                            .. attribute:: path_table
                            
                            	The BGP Path Table
                            	**type**\:   :py:class:`PathTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable>`
                            
                            .. attribute:: path_used_table
                            
                            	The BGP Path Used Table
                            	**type**\:   :py:class:`PathUsedTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable>`
                            
                            .. attribute:: policies
                            
                            	The BGP Policy Table
                            	**type**\:   :py:class:`Policies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies>`
                            
                            .. attribute:: prefix_filters
                            
                            	The BGP Prefix Filter table
                            	**type**\:   :py:class:`PrefixFilters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters>`
                            
                            .. attribute:: rpc_sets
                            
                            	BGP next\-hop set table
                            	**type**\:   :py:class:`RpcSets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets>`
                            
                            .. attribute:: rt_set_counters
                            
                            	The RT\-set counter table
                            	**type**\:   :py:class:`RtSetCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters>`
                            
                            .. attribute:: sourced_networks
                            
                            	The BGP Convergence table
                            	**type**\:   :py:class:`SourcedNetworks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks>`
                            
                            .. attribute:: update_generation_address_family
                            
                            	Update generation for address\-family
                            	**type**\:   :py:class:`UpdateGenerationAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily>`
                            
                            .. attribute:: update_generation_filter_groups
                            
                            	Update generation for all filter\-groups under a sub\-group
                            	**type**\:   :py:class:`UpdateGenerationFilterGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups>`
                            
                            .. attribute:: update_generation_neighbors
                            
                            	Update generation for all neighbors
                            	**type**\:   :py:class:`UpdateGenerationNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors>`
                            
                            .. attribute:: update_generation_sub_groups
                            
                            	Update generation for all sub\-groups
                            	**type**\:   :py:class:`UpdateGenerationSubGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups>`
                            
                            .. attribute:: update_generation_update_groups
                            
                            	Update generation for all update\-groups
                            	**type**\:   :py:class:`UpdateGenerationUpdateGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups>`
                            
                            .. attribute:: update_groups
                            
                            	The BGP Update group table
                            	**type**\:   :py:class:`UpdateGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.advertised_path_counts = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathCounts()
                                self.advertised_path_counts.parent = self
                                self.advertised_path_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr()
                                self.advertised_path_xr.parent = self
                                self.advertised_paths = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths()
                                self.advertised_paths.parent = self
                                self.af_process_info = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo()
                                self.af_process_info.parent = self
                                self.attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes()
                                self.attributes.parent = self
                                self.bmp_paths = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths()
                                self.bmp_paths.parent = self
                                self.convergence = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Convergence()
                                self.convergence.parent = self
                                self.dampenings = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings()
                                self.dampenings.parent = self
                                self.epes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes()
                                self.epes.parent = self
                                self.global_af_process_info = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo()
                                self.global_af_process_info.parent = self
                                self.neighbor_af_table = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable()
                                self.neighbor_af_table.parent = self
                                self.network_all_rds = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds()
                                self.network_all_rds.parent = self
                                self.network_lookup_all_rds = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds()
                                self.network_lookup_all_rds.parent = self
                                self.network_prefixes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes()
                                self.network_prefixes.parent = self
                                self.networks = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks()
                                self.networks.parent = self
                                self.next_hop_address_families = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies()
                                self.next_hop_address_families.parent = self
                                self.path_labeled_table = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable()
                                self.path_labeled_table.parent = self
                                self.path_table = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable()
                                self.path_table.parent = self
                                self.path_used_table = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable()
                                self.path_used_table.parent = self
                                self.policies = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies()
                                self.policies.parent = self
                                self.prefix_filters = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters()
                                self.prefix_filters.parent = self
                                self.rpc_sets = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets()
                                self.rpc_sets.parent = self
                                self.rt_set_counters = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters()
                                self.rt_set_counters.parent = self
                                self.sourced_networks = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks()
                                self.sourced_networks.parent = self
                                self.update_generation_address_family = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily()
                                self.update_generation_address_family.parent = self
                                self.update_generation_filter_groups = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups()
                                self.update_generation_filter_groups.parent = self
                                self.update_generation_neighbors = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors()
                                self.update_generation_neighbors.parent = self
                                self.update_generation_sub_groups = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups()
                                self.update_generation_sub_groups.parent = self
                                self.update_generation_update_groups = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups()
                                self.update_generation_update_groups.parent = self
                                self.update_groups = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups()
                                self.update_groups.parent = self


                            class NetworkLookupAllRds(object):
                                """
                                The BGP Network Lookup Table
                                
                                .. attribute:: network_lookup_all_rd
                                
                                	The BGP Network Lookup table
                                	**type**\: list of    :py:class:`NetworkLookupAllRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.network_lookup_all_rd = YList()
                                    self.network_lookup_all_rd.parent = self
                                    self.network_lookup_all_rd.name = 'network_lookup_all_rd'


                                class NetworkLookupAllRd(object):
                                    """
                                    The BGP Network Lookup table
                                    
                                    .. attribute:: network_prefix  <key>
                                    
                                    	Network 
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: network_lookup_rds
                                    
                                    	The BGP Network Lookup table
                                    	**type**\:   :py:class:`NetworkLookupRds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.network_prefix = None
                                        self.network_lookup_rds = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds()
                                        self.network_lookup_rds.parent = self


                                    class NetworkLookupRds(object):
                                        """
                                        The BGP Network Lookup table
                                        
                                        .. attribute:: network_lookup_rd
                                        
                                        	A BGP Network table entry
                                        	**type**\: list of    :py:class:`NetworkLookupRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.network_lookup_rd = YList()
                                            self.network_lookup_rd.parent = self
                                            self.network_lookup_rd.name = 'network_lookup_rd'


                                        class NetworkLookupRd(object):
                                            """
                                            A BGP Network table entry
                                            
                                            .. attribute:: rd  <key>
                                            
                                            	Route Distinguisher value
                                            	**type**\:  str
                                            
                                            .. attribute:: active_path_element
                                            
                                            	Path element list received from Active inst
                                            	**type**\: list of    :py:class:`ActivePathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement>`
                                            
                                            .. attribute:: active_process_instance_path
                                            
                                            	Active's paths for this net 
                                            	**type**\: list of    :py:class:`ActiveProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath>`
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix>`
                                            
                                            .. attribute:: bit
                                            
                                            	Bit
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: flags
                                            
                                            	Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: gateway_array
                                            
                                            	Gateway array ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_inconsistent_paths
                                            
                                            	Net has inconsistent paths
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_lbl_retained
                                            
                                            	Net has label retained
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_label
                                            
                                            	Net has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_net_aggregation_suppressed
                                            
                                            	Net suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_net_ldp_signaled
                                            
                                            	L2VPN Net LDP signaled  aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_network
                                            
                                            	Permanent Network
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_element
                                            
                                            	Local path element list
                                            	**type**\: list of    :py:class:`LocalPathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement>`
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: local_process_instance_path
                                            
                                            	Local (to process instance) paths for this net 
                                            	**type**\: list of    :py:class:`LocalProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath>`
                                            
                                            .. attribute:: net_backup_available
                                            
                                            	Net has backup path
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_backup_label_rewrite_available
                                            
                                            	Net has label rewrite for backup path
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_eibgp_multipath
                                            
                                            	Net has EIBGP multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_extended_flags
                                            
                                            	Net extended flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: net_flags
                                            
                                            	Flags associated with                            net
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: net_local_label
                                            
                                            	Local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: net_local_label_rewrite
                                            
                                            	Net label has rewrite
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_local_label_srgb
                                            
                                            	Net label allocated fromSegment routing global block
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_multipath
                                            
                                            	Net has multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: num_of_path
                                            
                                            	Number of path for this net
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: process_instance_id
                                            
                                            	Process instance ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: resilient_nexthop_set
                                            
                                            	Resilient nexthop set ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	RIB install failed
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: table_brib_version
                                            
                                            	Table version # for updates
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: table_version
                                            
                                            	Table version # for net
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: version
                                            
                                            	Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: version_age
                                            
                                            	Version age
                                            	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionAge>`
                                            
                                            .. attribute:: version_timestamp
                                            
                                            	Version timestamp
                                            	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionTimestamp>`
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.rd = None
                                                self.active_path_element = YList()
                                                self.active_path_element.parent = self
                                                self.active_path_element.name = 'active_path_element'
                                                self.active_process_instance_path = YList()
                                                self.active_process_instance_path.parent = self
                                                self.active_process_instance_path.name = 'active_process_instance_path'
                                                self.add_path_orr_bitfield = YList()
                                                self.add_path_orr_bitfield.parent = self
                                                self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                self.advertisedto_pe = None
                                                self.af_name = None
                                                self.best_path_orr_bitfield = YList()
                                                self.best_path_orr_bitfield.parent = self
                                                self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self.bit = None
                                                self.flags = None
                                                self.gateway_array = None
                                                self.has_inconsistent_paths = None
                                                self.has_lbl_retained = None
                                                self.has_local_label = None
                                                self.is_net_aggregation_suppressed = None
                                                self.is_net_ldp_signaled = None
                                                self.is_permanent_network = None
                                                self.local_path_element = YList()
                                                self.local_path_element.parent = self
                                                self.local_path_element.name = 'local_path_element'
                                                self.local_peers_advertised_to = YList()
                                                self.local_peers_advertised_to.parent = self
                                                self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                self.local_process_instance_path = YList()
                                                self.local_process_instance_path.parent = self
                                                self.local_process_instance_path.name = 'local_process_instance_path'
                                                self.net_backup_available = None
                                                self.net_backup_label_rewrite_available = None
                                                self.net_eibgp_multipath = None
                                                self.net_extended_flags = None
                                                self.net_flags = None
                                                self.net_local_label = None
                                                self.net_local_label_rewrite = None
                                                self.net_local_label_srgb = None
                                                self.net_multipath = None
                                                self.num_of_path = None
                                                self.pe_peers_advertised_to = YList()
                                                self.pe_peers_advertised_to.parent = self
                                                self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                self.process_instance_id = None
                                                self.resilient_nexthop_set = None
                                                self.rib_failed = None
                                                self.route_distinguisher = None
                                                self.table_brib_version = None
                                                self.table_version = None
                                                self.version = None
                                                self.version_age = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionAge()
                                                self.version_age.parent = self
                                                self.version_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionTimestamp()
                                                self.version_timestamp.parent = self
                                                self.vrf_name = None


                                            class BgpPrefix(object):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self.prefix_length = None


                                                class Prefix(object):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.prefix is not None and self.prefix._has_data():
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix']['meta_info']


                                            class VersionTimestamp(object):
                                                """
                                                Version timestamp
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionTimestamp']['meta_info']


                                            class VersionAge(object):
                                                """
                                                Version age
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-age'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionAge']['meta_info']


                                            class LocalPeersAdvertisedTo(object):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo']['meta_info']


                                            class PePeersAdvertisedTo(object):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo']['meta_info']


                                            class BestPathOrrBitfield(object):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield']['meta_info']


                                            class AddPathOrrBitfield(object):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield']['meta_info']


                                            class LocalProcessInstancePath(object):
                                                """
                                                Local (to process instance) paths for this net 
                                                
                                                .. attribute:: af_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: attributes_after_policy_in
                                                
                                                	Attributes after inbound policy applied
                                                	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn>`
                                                
                                                .. attribute:: label_fail
                                                
                                                	LSD label allocation failed 
                                                	**type**\:  bool
                                                
                                                .. attribute:: label_o_or_version
                                                
                                                	Label Version when OOR happens
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_oor
                                                
                                                	LSD label space is exhausted
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address_xr
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr>`
                                                
                                                .. attribute:: no_path
                                                
                                                	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                                	**type**\:  bool
                                                
                                                .. attribute:: path_information
                                                
                                                	Path information
                                                	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation>`
                                                
                                                .. attribute:: prefix_version
                                                
                                                	Version of BGP Prefix Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: process_instance_id
                                                
                                                	Process instance ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: source_route_distinguisher
                                                
                                                	Source Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: source_vrf_name
                                                
                                                	Name of the source VRF
                                                	**type**\:  str
                                                
                                                .. attribute:: srcaf_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: vrf_name
                                                
                                                	Name of the VRF
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.af_name = None
                                                    self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn()
                                                    self.attributes_after_policy_in.parent = self
                                                    self.label_fail = None
                                                    self.label_o_or_version = None
                                                    self.label_oor = None
                                                    self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr()
                                                    self.neighbor_address_xr.parent = self
                                                    self.no_path = None
                                                    self.path_information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation()
                                                    self.path_information.parent = self
                                                    self.prefix_version = None
                                                    self.process_instance_id = None
                                                    self.route_distinguisher = None
                                                    self.source_route_distinguisher = None
                                                    self.source_vrf_name = None
                                                    self.srcaf_name = None
                                                    self.vrf_name = None


                                                class NeighborAddressXr(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr']['meta_info']


                                                class PathInformation(object):
                                                    """
                                                    Path information
                                                    
                                                    .. attribute:: accept_own_path
                                                    
                                                    	Accept Own
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: accept_own_self_originated_p_ath
                                                    
                                                    	Accept\-Own self\-originated
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: add_path_orr_bitfield
                                                    
                                                    	ORR Add path Bitfields
                                                    	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                    
                                                    .. attribute:: advertisedto_pe
                                                    
                                                    	Net could be advertised                          to PE peers
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: aigp_metric
                                                    
                                                    	Total AIGP metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: best_path_comp_stage
                                                    
                                                    	Stage where the path lost to the best path or group best
                                                    	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                                    
                                                    .. attribute:: best_path_comp_winner
                                                    
                                                    	Neighbor address of the path which won best path comparison
                                                    	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                    
                                                    .. attribute:: best_path_id
                                                    
                                                    	Best path ID; DEPRECATED BYLocalPathId
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: best_path_id_comp_winner
                                                    
                                                    	Path ID of the path which won best path comparison
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: best_path_orr_bitfield
                                                    
                                                    	ORR Best path Bitfields
                                                    	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                    
                                                    .. attribute:: bgp_prefix
                                                    
                                                    	BGP prefix
                                                    	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix>`
                                                    
                                                    .. attribute:: dampen_penalty
                                                    
                                                    	Dampening penalty
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Mvpn Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                    
                                                    .. attribute:: fspec_invalid_path
                                                    
                                                    	Is Fspec invalid path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: graceful_shutdown
                                                    
                                                    	Marked for graceful shutdown
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: gw_addr
                                                    
                                                    	Path GW Address
                                                    	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.GwAddr>`
                                                    
                                                    .. attribute:: halflife_time
                                                    
                                                    	Half\-life time for the penalty
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_esi
                                                    
                                                    	Path has EVPN ESI
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_gw_addr
                                                    
                                                    	Path has GW Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_local_net_label
                                                    
                                                    	Path has local label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mdt_group_addr
                                                    
                                                    	Path has MDT Group Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_extcomm
                                                    
                                                    	Path has MVPN EXTCOMM feedback
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_nbr_addr
                                                    
                                                    	Path has Mvpn nbr Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_nexthop_addr
                                                    
                                                    	Path has MVPN nexthop Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_pmsi
                                                    
                                                    	Path has MVPN PMSI feedback
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_rcvd_label
                                                    
                                                    	Path has received label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_second_label
                                                    
                                                    	Path has second received label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ibgp_signaled_validity
                                                    
                                                    	IBGP signalled validation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: igp_metric
                                                    
                                                    	IGP metric to the gateway
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_aggregation_suppressed
                                                    
                                                    	Path suppressed due to aggregation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_best
                                                    
                                                    	Best available path within AS
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_best_path
                                                    
                                                    	Best available path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_import_dampened
                                                    
                                                    	net import dampened
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_import_suspect
                                                    
                                                    	net import suspect
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_internal_path
                                                    
                                                    	Received over an internal link
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_best
                                                    
                                                    	Partial best path within distributed speaker
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_additional_path
                                                    
                                                    	Path is an additional\-path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_advertised_local_as_only
                                                    
                                                    	Not advertised outside local AS
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_af_install_eligible
                                                    
                                                    	Path can be installed in AF RIB
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_backup
                                                    
                                                    	Path is a backup path 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_backup_protect_multipath
                                                    
                                                    	Path is a backup path to protect multipaths
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_best_external
                                                    
                                                    	Path is a best external path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_damped
                                                    
                                                    	Path suppressed due to dampening
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_confederation_peer
                                                    
                                                    	Path received from confederation peer
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_network_command
                                                    
                                                    	Path sourced by network command
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_redistribute_command
                                                    
                                                    	Path sourced by redistribute command
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_route_reflector
                                                    
                                                    	Path received from route reflector
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_history_held
                                                    
                                                    	Path entry held to remember history
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_imp_candidate
                                                    
                                                    	Path is a candidate for multipath import
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_imported
                                                    
                                                    	Path is imported
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_local_aggregate
                                                    
                                                    	Path is a locally created aggregate
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_locally_sourced
                                                    
                                                    	Path sourced locally
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_long_lived_stale
                                                    
                                                    	Long lived stale routes learnt before neighbor restarts
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_multipath
                                                    
                                                    	Path is one of multipath best routes
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_nexthop_discarded
                                                    
                                                    	Path is redirected to Null0
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_not_advertised
                                                    
                                                    	Not advertised to any peer
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_not_advertised_to_ebg_ps
                                                    
                                                    	Not advertised to EBGPs
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_received_only
                                                    
                                                    	Path is received only
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_reoriginated
                                                    
                                                    	Path is reoriginated
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_reoriginated_stitching
                                                    
                                                    	Path is reoriginated with stitching RTs
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_stale
                                                    
                                                    	Stale routes learnt before neighbor restarts
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_synced_with_igp
                                                    
                                                    	Path synchronized with IGP
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_valid
                                                    
                                                    	Path attributes are usable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_vpn_only
                                                    
                                                    	Path is not in the vrf
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_permanent_path
                                                    
                                                    	Path is of type Permanent path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_received_path_not_modified
                                                    
                                                    	Received path used without modification
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_spkr_as_best
                                                    
                                                    	Best available path within AS in speaker
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2vpn_circuit_status_value
                                                    
                                                    	L2VPN Circuit Status Value
                                                    	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                    
                                                    .. attribute:: l2vpn_evpn_esi
                                                    
                                                    	L2VPN EVPN ESI
                                                    	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi>`
                                                    
                                                    .. attribute:: l2vpn_size
                                                    
                                                    	Path block size
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: labeled_unicast_safi_path
                                                    
                                                    	Path was learnt by labeled\-unicast SAFI
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: local_label
                                                    
                                                    	Path local label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_nh
                                                    
                                                    	Path has local nexthop
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: local_path_id
                                                    
                                                    	Local path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_peers_advertised_to
                                                    
                                                    	Local peers that this prefix has been advertised to
                                                    	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                    
                                                    .. attribute:: maximum_suppress_time
                                                    
                                                    	Maximum duration to suppress a stable route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mdt_group_addr
                                                    
                                                    	IPv4 MDT Group Address for the path
                                                    	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                    
                                                    .. attribute:: mvpn_nbr_addr
                                                    
                                                    	Mvpn nbr Address for the path
                                                    	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                    
                                                    .. attribute:: mvpn_nexthop_addr
                                                    
                                                    	Mvpn nexthop Address for the path
                                                    	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                    
                                                    .. attribute:: mvpn_path_flags
                                                    
                                                    	Mvpn path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: mvpn_pmsi_flags
                                                    
                                                    	Mvpn PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: mvpn_pmsi_label
                                                    
                                                    	Mvpn PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mvpn_pmsi_type
                                                    
                                                    	Mvpn PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: mvpn_pmsi_value
                                                    
                                                    	Mvpn PMSI Value
                                                    	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                    
                                                    .. attribute:: mvpn_sfs_path
                                                    
                                                    	Is MVPN single forwarder PE path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress>`
                                                    
                                                    .. attribute:: neighbor_router_id
                                                    
                                                    	Router ID of the neighbor for the path
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: next_hop
                                                    
                                                    	Next hop
                                                    	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop>`
                                                    
                                                    .. attribute:: nhte_tunnel
                                                    
                                                    	NH TE tunnel information
                                                    	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhteTunnel>`
                                                    
                                                    .. attribute:: path_flags
                                                    
                                                    	Flags associated with path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: path_flap_count
                                                    
                                                    	Number of times this route has flapped
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_import_flags
                                                    
                                                    	Path import flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_rt_set_id
                                                    
                                                    	RT\-set id of the path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_rt_set_route_count
                                                    
                                                    	Count in RT\-set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_table_version
                                                    
                                                    	Table version # for pelem
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_weight
                                                    
                                                    	Weight for the path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pe_peers_advertised_to
                                                    
                                                    	PE peers that this prefix has been advertised to
                                                    	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                    
                                                    .. attribute:: rcvd_label
                                                    
                                                    	Path received label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rcvd_path_id
                                                    
                                                    	Received path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: reuse_value
                                                    
                                                    	Value to start reusing a route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rib_failed
                                                    
                                                    	Is net failed installed                          in RIB
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: route_type
                                                    
                                                    	Route Type of path
                                                    	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                                    
                                                    .. attribute:: rpki_origin_as_validation_disabled
                                                    
                                                    	RPKI originAS V. Disabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rt_set_limit_enabled
                                                    
                                                    	Path subject to RT\-set net limit
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_label
                                                    
                                                    	Path second received label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: seconds_since_first_flap
                                                    
                                                    	Seconds since route first flapped
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: show_rpki_origin_as_validity
                                                    
                                                    	Display validity state ?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: sn_rpki_origin_as_validity
                                                    
                                                    	RPKI origin validation state
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: suppress_penalty
                                                    
                                                    	Value to start suppressing a route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: time_to_unsuppress
                                                    
                                                    	Seconds until route is unsuppressed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.accept_own_path = None
                                                        self.accept_own_self_originated_p_ath = None
                                                        self.add_path_orr_bitfield = YList()
                                                        self.add_path_orr_bitfield.parent = self
                                                        self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                        self.advertisedto_pe = None
                                                        self.aigp_metric = None
                                                        self.best_path_comp_stage = None
                                                        self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner()
                                                        self.best_path_comp_winner.parent = self
                                                        self.best_path_id = None
                                                        self.best_path_id_comp_winner = None
                                                        self.best_path_orr_bitfield = YList()
                                                        self.best_path_orr_bitfield.parent = self
                                                        self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                        self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix()
                                                        self.bgp_prefix.parent = self
                                                        self.dampen_penalty = None
                                                        self.extended_community = YList()
                                                        self.extended_community.parent = self
                                                        self.extended_community.name = 'extended_community'
                                                        self.fspec_invalid_path = None
                                                        self.graceful_shutdown = None
                                                        self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.GwAddr()
                                                        self.gw_addr.parent = self
                                                        self.halflife_time = None
                                                        self.has_esi = None
                                                        self.has_gw_addr = None
                                                        self.has_local_net_label = None
                                                        self.has_mdt_group_addr = None
                                                        self.has_mvpn_extcomm = None
                                                        self.has_mvpn_nbr_addr = None
                                                        self.has_mvpn_nexthop_addr = None
                                                        self.has_mvpn_pmsi = None
                                                        self.has_rcvd_label = None
                                                        self.has_second_label = None
                                                        self.ibgp_signaled_validity = None
                                                        self.igp_metric = None
                                                        self.is_aggregation_suppressed = None
                                                        self.is_as_best = None
                                                        self.is_best_path = None
                                                        self.is_import_dampened = None
                                                        self.is_import_suspect = None
                                                        self.is_internal_path = None
                                                        self.is_partial_best = None
                                                        self.is_path_additional_path = None
                                                        self.is_path_advertised_local_as_only = None
                                                        self.is_path_af_install_eligible = None
                                                        self.is_path_backup = None
                                                        self.is_path_backup_protect_multipath = None
                                                        self.is_path_best_external = None
                                                        self.is_path_damped = None
                                                        self.is_path_from_confederation_peer = None
                                                        self.is_path_from_network_command = None
                                                        self.is_path_from_redistribute_command = None
                                                        self.is_path_from_route_reflector = None
                                                        self.is_path_history_held = None
                                                        self.is_path_imp_candidate = None
                                                        self.is_path_imported = None
                                                        self.is_path_local_aggregate = None
                                                        self.is_path_locally_sourced = None
                                                        self.is_path_long_lived_stale = None
                                                        self.is_path_multipath = None
                                                        self.is_path_nexthop_discarded = None
                                                        self.is_path_not_advertised = None
                                                        self.is_path_not_advertised_to_ebg_ps = None
                                                        self.is_path_received_only = None
                                                        self.is_path_reoriginated = None
                                                        self.is_path_reoriginated_stitching = None
                                                        self.is_path_stale = None
                                                        self.is_path_synced_with_igp = None
                                                        self.is_path_valid = None
                                                        self.is_path_vpn_only = None
                                                        self.is_permanent_path = None
                                                        self.is_received_path_not_modified = None
                                                        self.is_spkr_as_best = None
                                                        self.l2vpn_circuit_status_value = YList()
                                                        self.l2vpn_circuit_status_value.parent = self
                                                        self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                        self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi()
                                                        self.l2vpn_evpn_esi.parent = self
                                                        self.l2vpn_size = None
                                                        self.labeled_unicast_safi_path = None
                                                        self.local_label = None
                                                        self.local_nh = None
                                                        self.local_path_id = None
                                                        self.local_peers_advertised_to = YList()
                                                        self.local_peers_advertised_to.parent = self
                                                        self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                        self.maximum_suppress_time = None
                                                        self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr()
                                                        self.mdt_group_addr.parent = self
                                                        self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                        self.mvpn_nbr_addr.parent = self
                                                        self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                        self.mvpn_nexthop_addr.parent = self
                                                        self.mvpn_path_flags = None
                                                        self.mvpn_pmsi_flags = None
                                                        self.mvpn_pmsi_label = None
                                                        self.mvpn_pmsi_type = None
                                                        self.mvpn_pmsi_value = YList()
                                                        self.mvpn_pmsi_value.parent = self
                                                        self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                        self.mvpn_sfs_path = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.neighbor_router_id = None
                                                        self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop()
                                                        self.next_hop.parent = self
                                                        self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhteTunnel()
                                                        self.nhte_tunnel.parent = self
                                                        self.path_flags = None
                                                        self.path_flap_count = None
                                                        self.path_import_flags = None
                                                        self.path_rt_set_id = None
                                                        self.path_rt_set_route_count = None
                                                        self.path_table_version = None
                                                        self.path_weight = None
                                                        self.pe_peers_advertised_to = YList()
                                                        self.pe_peers_advertised_to.parent = self
                                                        self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                        self.rcvd_label = None
                                                        self.rcvd_path_id = None
                                                        self.reuse_value = None
                                                        self.rib_failed = None
                                                        self.route_type = None
                                                        self.rpki_origin_as_validation_disabled = None
                                                        self.rt_set_limit_enabled = None
                                                        self.second_label = None
                                                        self.seconds_since_first_flap = None
                                                        self.show_rpki_origin_as_validity = None
                                                        self.sn_rpki_origin_as_validity = None
                                                        self.suppress_penalty = None
                                                        self.time_to_unsuppress = None


                                                    class BgpPrefix(object):
                                                        """
                                                        BGP prefix
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Prefix
                                                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                            self.prefix.parent = self
                                                            self.prefix_length = None


                                                        class Prefix(object):
                                                            """
                                                            Prefix
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.prefix is not None and self.prefix._has_data():
                                                                return True

                                                            if self.prefix_length is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix']['meta_info']


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress']['meta_info']


                                                    class NextHop(object):
                                                        """
                                                        Next hop
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop']['meta_info']


                                                    class NhteTunnel(object):
                                                        """
                                                        NH TE tunnel information
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	Binding label for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_te_tunnel
                                                        
                                                        	NH TE Tunnel info is present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_info_stale
                                                        
                                                        	Tunnel is stale
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_registered
                                                        
                                                        	Tunnel registered flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_up
                                                        
                                                        	Tunnel Up flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: last_tunnel_update
                                                        
                                                        	Time since the last rib update happened
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_if_handle
                                                        
                                                        	Interface handle for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_name
                                                        
                                                        	tunnel name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        .. attribute:: tunnel_type
                                                        
                                                        	tunnel type
                                                        	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                        
                                                        .. attribute:: tunnel_v6_enabled
                                                        
                                                        	IPv6 enabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_v6_required
                                                        
                                                        	Tunnel need IPv6
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.binding_label = None
                                                            self.has_te_tunnel = None
                                                            self.is_tunnel_info_stale = None
                                                            self.is_tunnel_registered = None
                                                            self.is_tunnel_up = None
                                                            self.last_tunnel_update = None
                                                            self.tunnel_if_handle = None
                                                            self.tunnel_name = None
                                                            self.tunnel_type = None
                                                            self.tunnel_v6_enabled = None
                                                            self.tunnel_v6_required = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.binding_label is not None:
                                                                return True

                                                            if self.has_te_tunnel is not None:
                                                                return True

                                                            if self.is_tunnel_info_stale is not None:
                                                                return True

                                                            if self.is_tunnel_registered is not None:
                                                                return True

                                                            if self.is_tunnel_up is not None:
                                                                return True

                                                            if self.last_tunnel_update is not None:
                                                                return True

                                                            if self.tunnel_if_handle is not None:
                                                                return True

                                                            if self.tunnel_name is not None:
                                                                return True

                                                            if self.tunnel_type is not None:
                                                                return True

                                                            if self.tunnel_v6_enabled is not None:
                                                                return True

                                                            if self.tunnel_v6_required is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhteTunnel']['meta_info']


                                                    class MdtGroupAddr(object):
                                                        """
                                                        IPv4 MDT Group Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr']['meta_info']


                                                    class L2VpnEvpnEsi(object):
                                                        """
                                                        L2VPN EVPN ESI
                                                        
                                                        .. attribute:: esi
                                                        
                                                        	esi
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.esi = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.esi is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi']['meta_info']


                                                    class GwAddr(object):
                                                        """
                                                        Path GW Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_address = None
                                                            self.ipv6_address = None
                                                            self.len = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.len is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.GwAddr']['meta_info']


                                                    class BestPathCompWinner(object):
                                                        """
                                                        Neighbor address of the path which won best path
                                                        comparison
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner']['meta_info']


                                                    class MvpnNbrAddr(object):
                                                        """
                                                        Mvpn nbr Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr']['meta_info']


                                                    class MvpnNexthopAddr(object):
                                                        """
                                                        Mvpn nexthop Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr']['meta_info']


                                                    class L2VpnCircuitStatusValue(object):
                                                        """
                                                        L2VPN Circuit Status Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                                    class MvpnPmsiValue(object):
                                                        """
                                                        Mvpn PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue']['meta_info']


                                                    class ExtendedCommunity(object):
                                                        """
                                                        Mvpn Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity']['meta_info']


                                                    class LocalPeersAdvertisedTo(object):
                                                        """
                                                        Local peers that this prefix has been advertised
                                                        to
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.is_neighbor = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.update_group_number = None


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.is_neighbor is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.update_group_number is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                                    class PePeersAdvertisedTo(object):
                                                        """
                                                        PE peers that this prefix has been advertised to
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.is_neighbor = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.update_group_number = None


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.is_neighbor is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.update_group_number is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo']['meta_info']


                                                    class BestPathOrrBitfield(object):
                                                        """
                                                        ORR Best path Bitfields
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.is_neighbor = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.update_group_number = None


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.is_neighbor is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.update_group_number is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield']['meta_info']


                                                    class AddPathOrrBitfield(object):
                                                        """
                                                        ORR Add path Bitfields
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.is_neighbor = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.update_group_number = None


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.is_neighbor is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.update_group_number is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.accept_own_path is not None:
                                                            return True

                                                        if self.accept_own_self_originated_p_ath is not None:
                                                            return True

                                                        if self.add_path_orr_bitfield is not None:
                                                            for child_ref in self.add_path_orr_bitfield:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.advertisedto_pe is not None:
                                                            return True

                                                        if self.aigp_metric is not None:
                                                            return True

                                                        if self.best_path_comp_stage is not None:
                                                            return True

                                                        if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                            return True

                                                        if self.best_path_id is not None:
                                                            return True

                                                        if self.best_path_id_comp_winner is not None:
                                                            return True

                                                        if self.best_path_orr_bitfield is not None:
                                                            for child_ref in self.best_path_orr_bitfield:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                            return True

                                                        if self.dampen_penalty is not None:
                                                            return True

                                                        if self.extended_community is not None:
                                                            for child_ref in self.extended_community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.fspec_invalid_path is not None:
                                                            return True

                                                        if self.graceful_shutdown is not None:
                                                            return True

                                                        if self.gw_addr is not None and self.gw_addr._has_data():
                                                            return True

                                                        if self.halflife_time is not None:
                                                            return True

                                                        if self.has_esi is not None:
                                                            return True

                                                        if self.has_gw_addr is not None:
                                                            return True

                                                        if self.has_local_net_label is not None:
                                                            return True

                                                        if self.has_mdt_group_addr is not None:
                                                            return True

                                                        if self.has_mvpn_extcomm is not None:
                                                            return True

                                                        if self.has_mvpn_nbr_addr is not None:
                                                            return True

                                                        if self.has_mvpn_nexthop_addr is not None:
                                                            return True

                                                        if self.has_mvpn_pmsi is not None:
                                                            return True

                                                        if self.has_rcvd_label is not None:
                                                            return True

                                                        if self.has_second_label is not None:
                                                            return True

                                                        if self.ibgp_signaled_validity is not None:
                                                            return True

                                                        if self.igp_metric is not None:
                                                            return True

                                                        if self.is_aggregation_suppressed is not None:
                                                            return True

                                                        if self.is_as_best is not None:
                                                            return True

                                                        if self.is_best_path is not None:
                                                            return True

                                                        if self.is_import_dampened is not None:
                                                            return True

                                                        if self.is_import_suspect is not None:
                                                            return True

                                                        if self.is_internal_path is not None:
                                                            return True

                                                        if self.is_partial_best is not None:
                                                            return True

                                                        if self.is_path_additional_path is not None:
                                                            return True

                                                        if self.is_path_advertised_local_as_only is not None:
                                                            return True

                                                        if self.is_path_af_install_eligible is not None:
                                                            return True

                                                        if self.is_path_backup is not None:
                                                            return True

                                                        if self.is_path_backup_protect_multipath is not None:
                                                            return True

                                                        if self.is_path_best_external is not None:
                                                            return True

                                                        if self.is_path_damped is not None:
                                                            return True

                                                        if self.is_path_from_confederation_peer is not None:
                                                            return True

                                                        if self.is_path_from_network_command is not None:
                                                            return True

                                                        if self.is_path_from_redistribute_command is not None:
                                                            return True

                                                        if self.is_path_from_route_reflector is not None:
                                                            return True

                                                        if self.is_path_history_held is not None:
                                                            return True

                                                        if self.is_path_imp_candidate is not None:
                                                            return True

                                                        if self.is_path_imported is not None:
                                                            return True

                                                        if self.is_path_local_aggregate is not None:
                                                            return True

                                                        if self.is_path_locally_sourced is not None:
                                                            return True

                                                        if self.is_path_long_lived_stale is not None:
                                                            return True

                                                        if self.is_path_multipath is not None:
                                                            return True

                                                        if self.is_path_nexthop_discarded is not None:
                                                            return True

                                                        if self.is_path_not_advertised is not None:
                                                            return True

                                                        if self.is_path_not_advertised_to_ebg_ps is not None:
                                                            return True

                                                        if self.is_path_received_only is not None:
                                                            return True

                                                        if self.is_path_reoriginated is not None:
                                                            return True

                                                        if self.is_path_reoriginated_stitching is not None:
                                                            return True

                                                        if self.is_path_stale is not None:
                                                            return True

                                                        if self.is_path_synced_with_igp is not None:
                                                            return True

                                                        if self.is_path_valid is not None:
                                                            return True

                                                        if self.is_path_vpn_only is not None:
                                                            return True

                                                        if self.is_permanent_path is not None:
                                                            return True

                                                        if self.is_received_path_not_modified is not None:
                                                            return True

                                                        if self.is_spkr_as_best is not None:
                                                            return True

                                                        if self.l2vpn_circuit_status_value is not None:
                                                            for child_ref in self.l2vpn_circuit_status_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                            return True

                                                        if self.l2vpn_size is not None:
                                                            return True

                                                        if self.labeled_unicast_safi_path is not None:
                                                            return True

                                                        if self.local_label is not None:
                                                            return True

                                                        if self.local_nh is not None:
                                                            return True

                                                        if self.local_path_id is not None:
                                                            return True

                                                        if self.local_peers_advertised_to is not None:
                                                            for child_ref in self.local_peers_advertised_to:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.maximum_suppress_time is not None:
                                                            return True

                                                        if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                            return True

                                                        if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                            return True

                                                        if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                            return True

                                                        if self.mvpn_path_flags is not None:
                                                            return True

                                                        if self.mvpn_pmsi_flags is not None:
                                                            return True

                                                        if self.mvpn_pmsi_label is not None:
                                                            return True

                                                        if self.mvpn_pmsi_type is not None:
                                                            return True

                                                        if self.mvpn_pmsi_value is not None:
                                                            for child_ref in self.mvpn_pmsi_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.mvpn_sfs_path is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.neighbor_router_id is not None:
                                                            return True

                                                        if self.next_hop is not None and self.next_hop._has_data():
                                                            return True

                                                        if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                            return True

                                                        if self.path_flags is not None:
                                                            return True

                                                        if self.path_flap_count is not None:
                                                            return True

                                                        if self.path_import_flags is not None:
                                                            return True

                                                        if self.path_rt_set_id is not None:
                                                            return True

                                                        if self.path_rt_set_route_count is not None:
                                                            return True

                                                        if self.path_table_version is not None:
                                                            return True

                                                        if self.path_weight is not None:
                                                            return True

                                                        if self.pe_peers_advertised_to is not None:
                                                            for child_ref in self.pe_peers_advertised_to:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.rcvd_label is not None:
                                                            return True

                                                        if self.rcvd_path_id is not None:
                                                            return True

                                                        if self.reuse_value is not None:
                                                            return True

                                                        if self.rib_failed is not None:
                                                            return True

                                                        if self.route_type is not None:
                                                            return True

                                                        if self.rpki_origin_as_validation_disabled is not None:
                                                            return True

                                                        if self.rt_set_limit_enabled is not None:
                                                            return True

                                                        if self.second_label is not None:
                                                            return True

                                                        if self.seconds_since_first_flap is not None:
                                                            return True

                                                        if self.show_rpki_origin_as_validity is not None:
                                                            return True

                                                        if self.sn_rpki_origin_as_validity is not None:
                                                            return True

                                                        if self.suppress_penalty is not None:
                                                            return True

                                                        if self.time_to_unsuppress is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation']['meta_info']


                                                class AttributesAfterPolicyIn(object):
                                                    """
                                                    Attributes after inbound policy applied
                                                    
                                                    .. attribute:: attr_set
                                                    
                                                    	ATTR\_SET attribute
                                                    	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                    
                                                    .. attribute:: attribute_key_number
                                                    
                                                    	Attribute key number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_config
                                                    
                                                    	Attribute reuse ID Configured
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: attribute_reuse_id_current
                                                    
                                                    	Attribute reuse ID current ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_keys
                                                    
                                                    	Attribute reuse ID allocated keys
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_max_id
                                                    
                                                    	Attribute reuse ID maximum ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_node
                                                    
                                                    	Attribute reuse ID nodes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_recover_sec
                                                    
                                                    	Attribute reuse ID timer in seconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: common_attributes
                                                    
                                                    	Common attributes
                                                    	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                    
                                                    .. attribute:: is_application_gateway_present
                                                    
                                                    	Application gateway present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path2_byte
                                                    
                                                    	AS path encoded as 2\-byte
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_attr_set_present
                                                    
                                                    	BGP ATTR\_SET attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ribrnh_present
                                                    
                                                    	RIB RNH Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_rnh_present
                                                    
                                                    	RNH Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ribrnh_encap
                                                    
                                                    	RIB RNH Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ribrnh_ip
                                                    
                                                    	RIB RNH IP Address
                                                    	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                    
                                                    .. attribute:: ribrnh_mac
                                                    
                                                    	RIB RNH MAC Address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    .. attribute:: ribrnh_table
                                                    
                                                    	RIB RNH Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ribrnh_vni
                                                    
                                                    	RIB RNH Vni
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ribrnhip_table
                                                    
                                                    	RIB RNH IP Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rnh_addr
                                                    
                                                    	RNH Address
                                                    	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                    
                                                    .. attribute:: rnh_addr_len
                                                    
                                                    	RNH Address Length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rnh_len
                                                    
                                                    	RNH Length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: rnh_type
                                                    
                                                    	RNH Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: set_aigp_inbound_igp
                                                    
                                                    	AIGP set by policy inbound IGP 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: set_aigp_inbound_metric
                                                    
                                                    	AIGP set by policy inbound metric
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: vpn_distinguisher
                                                    
                                                    	VPN Distinguisher
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                        self.attr_set.parent = self
                                                        self.attribute_key_number = None
                                                        self.attribute_reuse_id_config = None
                                                        self.attribute_reuse_id_current = None
                                                        self.attribute_reuse_id_keys = None
                                                        self.attribute_reuse_id_max_id = None
                                                        self.attribute_reuse_id_node = None
                                                        self.attribute_reuse_id_recover_sec = None
                                                        self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                        self.common_attributes.parent = self
                                                        self.is_application_gateway_present = None
                                                        self.is_as_path2_byte = None
                                                        self.is_attr_set_present = None
                                                        self.is_ribrnh_present = None
                                                        self.is_rnh_present = None
                                                        self.ribrnh_encap = None
                                                        self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                        self.ribrnh_ip.parent = self
                                                        self.ribrnh_mac = None
                                                        self.ribrnh_table = None
                                                        self.ribrnh_vni = None
                                                        self.ribrnhip_table = None
                                                        self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                        self.rnh_addr.parent = self
                                                        self.rnh_addr_len = None
                                                        self.rnh_len = None
                                                        self.rnh_type = None
                                                        self.set_aigp_inbound_igp = None
                                                        self.set_aigp_inbound_metric = None
                                                        self.vpn_distinguisher = None


                                                    class CommonAttributes(object):
                                                        """
                                                        Common attributes
                                                        
                                                        .. attribute:: aggregator_address
                                                        
                                                        	Address where aggregation was performed
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: aggregator_as
                                                        
                                                        	AS where aggregation was last performed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: aigp_metric_value
                                                        
                                                        	AIGP metric value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: as_path
                                                        
                                                        	AS path attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: cluster
                                                        
                                                        	Cluster list attribute
                                                        	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                        
                                                        .. attribute:: community
                                                        
                                                        	Community attribute
                                                        	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                        
                                                        .. attribute:: connector_type
                                                        
                                                        	Connector Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: connector_value
                                                        
                                                        	Connector Value
                                                        	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                        
                                                        .. attribute:: extended_community_flags
                                                        
                                                        	Extended community Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: is_aggregator_present
                                                        
                                                        	Aggregator attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_aigp_present
                                                        
                                                        	AIGP Present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path_present
                                                        
                                                        	AS path attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_atomic_aggregate_present
                                                        
                                                        	Atomic aggregate attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_community_present
                                                        
                                                        	Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_connector_present
                                                        
                                                        	Connector present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_extended_community_present
                                                        
                                                        	Extended community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_label_index_present
                                                        
                                                        	Label Index attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_local_pref_present
                                                        
                                                        	Local Preference attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ls_attribute_present
                                                        
                                                        	BGP LS attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_metric_present
                                                        
                                                        	Metric attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_origin_present
                                                        
                                                        	Origin attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pe_distinguisher_label_present
                                                        
                                                        	PE distinguisher label  attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pmsi_present
                                                        
                                                        	PMSI Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pppmp_present
                                                        
                                                        	PPMP Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ssa_present
                                                        
                                                        	SSA attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_encap_present
                                                        
                                                        	Tunnel Encap attribute present 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2tpv3_cookie
                                                        
                                                        	L2TPv3 Cookie
                                                        	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                        
                                                        .. attribute:: l2tpv3_session_id
                                                        
                                                        	L2TPv3 session id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: label_index_attr
                                                        
                                                        	Label Index attribute
                                                        	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                        
                                                        .. attribute:: local_preference
                                                        
                                                        	Local preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ls_attr
                                                        
                                                        	BGP LS attribute
                                                        	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: neighbor_as
                                                        
                                                        	Neighbor AS number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: origin
                                                        
                                                        	Origin
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: originator
                                                        
                                                        	Originator attribute
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: pe_distinguisher_label
                                                        
                                                        	PE distinguisher label attribute
                                                        	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                        
                                                        .. attribute:: pmsi_flags
                                                        
                                                        	PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pmsi_label
                                                        
                                                        	PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pmsi_type
                                                        
                                                        	PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pmsi_value
                                                        
                                                        	PMSI Value
                                                        	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                        
                                                        .. attribute:: ppm_pvalue
                                                        
                                                        	PPMP Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: sr_policy_allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                        
                                                        .. attribute:: sr_policy_binding_sid
                                                        
                                                        	SR Policy Binding sid
                                                        	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                        
                                                        .. attribute:: sr_policy_explicit_path
                                                        
                                                        	SR Policy Explicit paths
                                                        	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                        
                                                        .. attribute:: sr_policy_preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: sr_tunnel_request_state
                                                        
                                                        	SR Tunnel Request State
                                                        	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                        
                                                        .. attribute:: sr_tunnel_state
                                                        
                                                        	SR Tunnel State
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encap Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: unknown_attribute
                                                        
                                                        	Unknown attributes
                                                        	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.aggregator_address = None
                                                            self.aggregator_as = None
                                                            self.aigp_metric_value = None
                                                            self.as_path = None
                                                            self.cluster = YList()
                                                            self.cluster.parent = self
                                                            self.cluster.name = 'cluster'
                                                            self.community = YList()
                                                            self.community.parent = self
                                                            self.community.name = 'community'
                                                            self.connector_type = None
                                                            self.connector_value = YList()
                                                            self.connector_value.parent = self
                                                            self.connector_value.name = 'connector_value'
                                                            self.extended_community = YList()
                                                            self.extended_community.parent = self
                                                            self.extended_community.name = 'extended_community'
                                                            self.extended_community_flags = None
                                                            self.is_aggregator_present = None
                                                            self.is_aigp_present = None
                                                            self.is_as_path_present = None
                                                            self.is_atomic_aggregate_present = None
                                                            self.is_community_present = None
                                                            self.is_connector_present = None
                                                            self.is_extended_community_present = None
                                                            self.is_label_index_present = None
                                                            self.is_local_pref_present = None
                                                            self.is_ls_attribute_present = None
                                                            self.is_metric_present = None
                                                            self.is_origin_present = None
                                                            self.is_pe_distinguisher_label_present = None
                                                            self.is_pmsi_present = None
                                                            self.is_pppmp_present = None
                                                            self.is_ssa_present = None
                                                            self.is_tunnel_encap_present = None
                                                            self.l2tpv3_cookie = YList()
                                                            self.l2tpv3_cookie.parent = self
                                                            self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                            self.l2tpv3_session_id = None
                                                            self.label_index_attr = YList()
                                                            self.label_index_attr.parent = self
                                                            self.label_index_attr.name = 'label_index_attr'
                                                            self.local_preference = None
                                                            self.ls_attr = YList()
                                                            self.ls_attr.parent = self
                                                            self.ls_attr.name = 'ls_attr'
                                                            self.metric = None
                                                            self.neighbor_as = None
                                                            self.origin = None
                                                            self.originator = None
                                                            self.pe_distinguisher_label = YList()
                                                            self.pe_distinguisher_label.parent = self
                                                            self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                            self.pmsi_flags = None
                                                            self.pmsi_label = None
                                                            self.pmsi_type = None
                                                            self.pmsi_value = YList()
                                                            self.pmsi_value.parent = self
                                                            self.pmsi_value.name = 'pmsi_value'
                                                            self.ppm_pvalue = None
                                                            self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                            self.sr_policy_allocated_binding_sid.parent = self
                                                            self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                            self.sr_policy_binding_sid.parent = self
                                                            self.sr_policy_explicit_path = YList()
                                                            self.sr_policy_explicit_path.parent = self
                                                            self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                            self.sr_policy_preference = None
                                                            self.sr_tunnel_request_state = None
                                                            self.sr_tunnel_state = None
                                                            self.tunnel_encap_type = None
                                                            self.unknown_attribute = YList()
                                                            self.unknown_attribute.parent = self
                                                            self.unknown_attribute.name = 'unknown_attribute'


                                                        class SrPolicyBindingSid(object):
                                                            """
                                                            SR Policy Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_address = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                        class SrPolicyAllocatedBindingSid(object):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_address = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                        class Community(object):
                                                            """
                                                            Community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                        class ExtendedCommunity(object):
                                                            """
                                                            Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                        class UnknownAttribute(object):
                                                            """
                                                            Unknown attributes
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                        class Cluster(object):
                                                            """
                                                            Cluster list attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                        class L2Tpv3Cookie(object):
                                                            """
                                                            L2TPv3 Cookie
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                        class ConnectorValue(object):
                                                            """
                                                            Connector Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                        class PmsiValue(object):
                                                            """
                                                            PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                        class LsAttr(object):
                                                            """
                                                            BGP LS attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                        class LabelIndexAttr(object):
                                                            """
                                                            Label Index attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                        class PeDistinguisherLabel(object):
                                                            """
                                                            PE distinguisher label attribute
                                                            
                                                            .. attribute:: label
                                                            
                                                            	Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pe_address
                                                            
                                                            	 PE address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.label = None
                                                                self.pe_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.label is not None:
                                                                    return True

                                                                if self.pe_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                        class SrPolicyExplicitPath(object):
                                                            """
                                                            SR Policy Explicit paths
                                                            
                                                            .. attribute:: sid
                                                            
                                                            	Sidlist for explicit path
                                                            	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of explicit path
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.sid = YList()
                                                                self.sid.parent = self
                                                                self.sid.name = 'sid'
                                                                self.weight = None


                                                            class Sid(object):
                                                                """
                                                                Sidlist for explicit path
                                                                
                                                                .. attribute:: ipv4
                                                                
                                                                	IP Address sid
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6
                                                                
                                                                	IPv6 address sid
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label sid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Sid Type
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4 = None
                                                                    self.ipv6 = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4 is not None:
                                                                        return True

                                                                    if self.ipv6 is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.sid is not None:
                                                                    for child_ref in self.sid:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.weight is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.aggregator_address is not None:
                                                                return True

                                                            if self.aggregator_as is not None:
                                                                return True

                                                            if self.aigp_metric_value is not None:
                                                                return True

                                                            if self.as_path is not None:
                                                                return True

                                                            if self.cluster is not None:
                                                                for child_ref in self.cluster:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.community is not None:
                                                                for child_ref in self.community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.connector_type is not None:
                                                                return True

                                                            if self.connector_value is not None:
                                                                for child_ref in self.connector_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.extended_community is not None:
                                                                for child_ref in self.extended_community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.extended_community_flags is not None:
                                                                return True

                                                            if self.is_aggregator_present is not None:
                                                                return True

                                                            if self.is_aigp_present is not None:
                                                                return True

                                                            if self.is_as_path_present is not None:
                                                                return True

                                                            if self.is_atomic_aggregate_present is not None:
                                                                return True

                                                            if self.is_community_present is not None:
                                                                return True

                                                            if self.is_connector_present is not None:
                                                                return True

                                                            if self.is_extended_community_present is not None:
                                                                return True

                                                            if self.is_label_index_present is not None:
                                                                return True

                                                            if self.is_local_pref_present is not None:
                                                                return True

                                                            if self.is_ls_attribute_present is not None:
                                                                return True

                                                            if self.is_metric_present is not None:
                                                                return True

                                                            if self.is_origin_present is not None:
                                                                return True

                                                            if self.is_pe_distinguisher_label_present is not None:
                                                                return True

                                                            if self.is_pmsi_present is not None:
                                                                return True

                                                            if self.is_pppmp_present is not None:
                                                                return True

                                                            if self.is_ssa_present is not None:
                                                                return True

                                                            if self.is_tunnel_encap_present is not None:
                                                                return True

                                                            if self.l2tpv3_cookie is not None:
                                                                for child_ref in self.l2tpv3_cookie:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.l2tpv3_session_id is not None:
                                                                return True

                                                            if self.label_index_attr is not None:
                                                                for child_ref in self.label_index_attr:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.local_preference is not None:
                                                                return True

                                                            if self.ls_attr is not None:
                                                                for child_ref in self.ls_attr:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.neighbor_as is not None:
                                                                return True

                                                            if self.origin is not None:
                                                                return True

                                                            if self.originator is not None:
                                                                return True

                                                            if self.pe_distinguisher_label is not None:
                                                                for child_ref in self.pe_distinguisher_label:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.pmsi_flags is not None:
                                                                return True

                                                            if self.pmsi_label is not None:
                                                                return True

                                                            if self.pmsi_type is not None:
                                                                return True

                                                            if self.pmsi_value is not None:
                                                                for child_ref in self.pmsi_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.ppm_pvalue is not None:
                                                                return True

                                                            if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                                return True

                                                            if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                                return True

                                                            if self.sr_policy_explicit_path is not None:
                                                                for child_ref in self.sr_policy_explicit_path:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.sr_policy_preference is not None:
                                                                return True

                                                            if self.sr_tunnel_request_state is not None:
                                                                return True

                                                            if self.sr_tunnel_state is not None:
                                                                return True

                                                            if self.tunnel_encap_type is not None:
                                                                return True

                                                            if self.unknown_attribute is not None:
                                                                for child_ref in self.unknown_attribute:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                                    class AttrSet(object):
                                                        """
                                                        ATTR\_SET attribute
                                                        
                                                        .. attribute:: aggregator_address
                                                        
                                                        	Address where aggregation was performed
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: aggregator_as
                                                        
                                                        	AS where aggregation was last performed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: aigp_metric_value
                                                        
                                                        	AIGP metric value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: as_path
                                                        
                                                        	AS path attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: cluster
                                                        
                                                        	Cluster list attribute
                                                        	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                        
                                                        .. attribute:: community
                                                        
                                                        	Community attribute
                                                        	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                        
                                                        .. attribute:: connector_type
                                                        
                                                        	Connector Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: connector_value
                                                        
                                                        	Connector Value
                                                        	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                        
                                                        .. attribute:: extended_community_flags
                                                        
                                                        	Extended community Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: is_aggregator_present
                                                        
                                                        	Aggregator attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_aigp_present
                                                        
                                                        	AIGP Present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path_present
                                                        
                                                        	AS path attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_atomic_aggregate_present
                                                        
                                                        	Atomic aggregate attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_community_present
                                                        
                                                        	Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_connector_present
                                                        
                                                        	Connector present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_extended_community_present
                                                        
                                                        	Extended community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_label_index_present
                                                        
                                                        	Label Index attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_local_pref_present
                                                        
                                                        	Local Preference attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ls_attribute_present
                                                        
                                                        	BGP LS attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_metric_present
                                                        
                                                        	Metric attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_origin_present
                                                        
                                                        	Origin attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pe_distinguisher_label_present
                                                        
                                                        	PE distinguisher label  attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pmsi_present
                                                        
                                                        	PMSI Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pppmp_present
                                                        
                                                        	PPMP Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ssa_present
                                                        
                                                        	SSA attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_encap_present
                                                        
                                                        	Tunnel Encap attribute present 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2tpv3_cookie
                                                        
                                                        	L2TPv3 Cookie
                                                        	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                        
                                                        .. attribute:: l2tpv3_session_id
                                                        
                                                        	L2TPv3 session id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: label_index_attr
                                                        
                                                        	Label Index attribute
                                                        	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                        
                                                        .. attribute:: local_preference
                                                        
                                                        	Local preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ls_attr
                                                        
                                                        	BGP LS attribute
                                                        	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: neighbor_as
                                                        
                                                        	Neighbor AS number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: origin
                                                        
                                                        	Origin
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: originator
                                                        
                                                        	Originator attribute
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: pe_distinguisher_label
                                                        
                                                        	PE distinguisher label attribute
                                                        	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                        
                                                        .. attribute:: pmsi_flags
                                                        
                                                        	PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pmsi_label
                                                        
                                                        	PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pmsi_type
                                                        
                                                        	PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pmsi_value
                                                        
                                                        	PMSI Value
                                                        	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                        
                                                        .. attribute:: ppm_pvalue
                                                        
                                                        	PPMP Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: sr_policy_allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                        
                                                        .. attribute:: sr_policy_binding_sid
                                                        
                                                        	SR Policy Binding sid
                                                        	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                        
                                                        .. attribute:: sr_policy_explicit_path
                                                        
                                                        	SR Policy Explicit paths
                                                        	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                        
                                                        .. attribute:: sr_policy_preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: sr_tunnel_request_state
                                                        
                                                        	SR Tunnel Request State
                                                        	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                        
                                                        .. attribute:: sr_tunnel_state
                                                        
                                                        	SR Tunnel State
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encap Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: unknown_attribute
                                                        
                                                        	Unknown attributes
                                                        	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.aggregator_address = None
                                                            self.aggregator_as = None
                                                            self.aigp_metric_value = None
                                                            self.as_path = None
                                                            self.cluster = YList()
                                                            self.cluster.parent = self
                                                            self.cluster.name = 'cluster'
                                                            self.community = YList()
                                                            self.community.parent = self
                                                            self.community.name = 'community'
                                                            self.connector_type = None
                                                            self.connector_value = YList()
                                                            self.connector_value.parent = self
                                                            self.connector_value.name = 'connector_value'
                                                            self.extended_community = YList()
                                                            self.extended_community.parent = self
                                                            self.extended_community.name = 'extended_community'
                                                            self.extended_community_flags = None
                                                            self.is_aggregator_present = None
                                                            self.is_aigp_present = None
                                                            self.is_as_path_present = None
                                                            self.is_atomic_aggregate_present = None
                                                            self.is_community_present = None
                                                            self.is_connector_present = None
                                                            self.is_extended_community_present = None
                                                            self.is_label_index_present = None
                                                            self.is_local_pref_present = None
                                                            self.is_ls_attribute_present = None
                                                            self.is_metric_present = None
                                                            self.is_origin_present = None
                                                            self.is_pe_distinguisher_label_present = None
                                                            self.is_pmsi_present = None
                                                            self.is_pppmp_present = None
                                                            self.is_ssa_present = None
                                                            self.is_tunnel_encap_present = None
                                                            self.l2tpv3_cookie = YList()
                                                            self.l2tpv3_cookie.parent = self
                                                            self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                            self.l2tpv3_session_id = None
                                                            self.label_index_attr = YList()
                                                            self.label_index_attr.parent = self
                                                            self.label_index_attr.name = 'label_index_attr'
                                                            self.local_preference = None
                                                            self.ls_attr = YList()
                                                            self.ls_attr.parent = self
                                                            self.ls_attr.name = 'ls_attr'
                                                            self.metric = None
                                                            self.neighbor_as = None
                                                            self.origin = None
                                                            self.originator = None
                                                            self.pe_distinguisher_label = YList()
                                                            self.pe_distinguisher_label.parent = self
                                                            self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                            self.pmsi_flags = None
                                                            self.pmsi_label = None
                                                            self.pmsi_type = None
                                                            self.pmsi_value = YList()
                                                            self.pmsi_value.parent = self
                                                            self.pmsi_value.name = 'pmsi_value'
                                                            self.ppm_pvalue = None
                                                            self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                            self.sr_policy_allocated_binding_sid.parent = self
                                                            self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                            self.sr_policy_binding_sid.parent = self
                                                            self.sr_policy_explicit_path = YList()
                                                            self.sr_policy_explicit_path.parent = self
                                                            self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                            self.sr_policy_preference = None
                                                            self.sr_tunnel_request_state = None
                                                            self.sr_tunnel_state = None
                                                            self.tunnel_encap_type = None
                                                            self.unknown_attribute = YList()
                                                            self.unknown_attribute.parent = self
                                                            self.unknown_attribute.name = 'unknown_attribute'


                                                        class SrPolicyBindingSid(object):
                                                            """
                                                            SR Policy Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_address = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                        class SrPolicyAllocatedBindingSid(object):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_address = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                        class Community(object):
                                                            """
                                                            Community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                        class ExtendedCommunity(object):
                                                            """
                                                            Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                        class UnknownAttribute(object):
                                                            """
                                                            Unknown attributes
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                        class Cluster(object):
                                                            """
                                                            Cluster list attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                        class L2Tpv3Cookie(object):
                                                            """
                                                            L2TPv3 Cookie
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                        class ConnectorValue(object):
                                                            """
                                                            Connector Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                        class PmsiValue(object):
                                                            """
                                                            PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                        class LsAttr(object):
                                                            """
                                                            BGP LS attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                        class LabelIndexAttr(object):
                                                            """
                                                            Label Index attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                        class PeDistinguisherLabel(object):
                                                            """
                                                            PE distinguisher label attribute
                                                            
                                                            .. attribute:: label
                                                            
                                                            	Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pe_address
                                                            
                                                            	 PE address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.label = None
                                                                self.pe_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.label is not None:
                                                                    return True

                                                                if self.pe_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                        class SrPolicyExplicitPath(object):
                                                            """
                                                            SR Policy Explicit paths
                                                            
                                                            .. attribute:: sid
                                                            
                                                            	Sidlist for explicit path
                                                            	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of explicit path
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.sid = YList()
                                                                self.sid.parent = self
                                                                self.sid.name = 'sid'
                                                                self.weight = None


                                                            class Sid(object):
                                                                """
                                                                Sidlist for explicit path
                                                                
                                                                .. attribute:: ipv4
                                                                
                                                                	IP Address sid
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6
                                                                
                                                                	IPv6 address sid
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label sid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Sid Type
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4 = None
                                                                    self.ipv6 = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4 is not None:
                                                                        return True

                                                                    if self.ipv6 is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.sid is not None:
                                                                    for child_ref in self.sid:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.weight is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.aggregator_address is not None:
                                                                return True

                                                            if self.aggregator_as is not None:
                                                                return True

                                                            if self.aigp_metric_value is not None:
                                                                return True

                                                            if self.as_path is not None:
                                                                return True

                                                            if self.cluster is not None:
                                                                for child_ref in self.cluster:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.community is not None:
                                                                for child_ref in self.community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.connector_type is not None:
                                                                return True

                                                            if self.connector_value is not None:
                                                                for child_ref in self.connector_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.extended_community is not None:
                                                                for child_ref in self.extended_community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.extended_community_flags is not None:
                                                                return True

                                                            if self.is_aggregator_present is not None:
                                                                return True

                                                            if self.is_aigp_present is not None:
                                                                return True

                                                            if self.is_as_path_present is not None:
                                                                return True

                                                            if self.is_atomic_aggregate_present is not None:
                                                                return True

                                                            if self.is_community_present is not None:
                                                                return True

                                                            if self.is_connector_present is not None:
                                                                return True

                                                            if self.is_extended_community_present is not None:
                                                                return True

                                                            if self.is_label_index_present is not None:
                                                                return True

                                                            if self.is_local_pref_present is not None:
                                                                return True

                                                            if self.is_ls_attribute_present is not None:
                                                                return True

                                                            if self.is_metric_present is not None:
                                                                return True

                                                            if self.is_origin_present is not None:
                                                                return True

                                                            if self.is_pe_distinguisher_label_present is not None:
                                                                return True

                                                            if self.is_pmsi_present is not None:
                                                                return True

                                                            if self.is_pppmp_present is not None:
                                                                return True

                                                            if self.is_ssa_present is not None:
                                                                return True

                                                            if self.is_tunnel_encap_present is not None:
                                                                return True

                                                            if self.l2tpv3_cookie is not None:
                                                                for child_ref in self.l2tpv3_cookie:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.l2tpv3_session_id is not None:
                                                                return True

                                                            if self.label_index_attr is not None:
                                                                for child_ref in self.label_index_attr:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.local_preference is not None:
                                                                return True

                                                            if self.ls_attr is not None:
                                                                for child_ref in self.ls_attr:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.neighbor_as is not None:
                                                                return True

                                                            if self.origin is not None:
                                                                return True

                                                            if self.originator is not None:
                                                                return True

                                                            if self.pe_distinguisher_label is not None:
                                                                for child_ref in self.pe_distinguisher_label:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.pmsi_flags is not None:
                                                                return True

                                                            if self.pmsi_label is not None:
                                                                return True

                                                            if self.pmsi_type is not None:
                                                                return True

                                                            if self.pmsi_value is not None:
                                                                for child_ref in self.pmsi_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.ppm_pvalue is not None:
                                                                return True

                                                            if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                                return True

                                                            if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                                return True

                                                            if self.sr_policy_explicit_path is not None:
                                                                for child_ref in self.sr_policy_explicit_path:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.sr_policy_preference is not None:
                                                                return True

                                                            if self.sr_tunnel_request_state is not None:
                                                                return True

                                                            if self.sr_tunnel_state is not None:
                                                                return True

                                                            if self.tunnel_encap_type is not None:
                                                                return True

                                                            if self.unknown_attribute is not None:
                                                                for child_ref in self.unknown_attribute:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                                    class RnhAddr(object):
                                                        """
                                                        RNH Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                        
                                                        .. attribute:: mac_address
                                                        
                                                        	MAC Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_address = None
                                                            self.ipv6_address = None
                                                            self.len = None
                                                            self.mac_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.len is not None:
                                                                return True

                                                            if self.mac_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                                    class RibrnhIp(object):
                                                        """
                                                        RIB RNH IP Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.attr_set is not None and self.attr_set._has_data():
                                                            return True

                                                        if self.attribute_key_number is not None:
                                                            return True

                                                        if self.attribute_reuse_id_config is not None:
                                                            return True

                                                        if self.attribute_reuse_id_current is not None:
                                                            return True

                                                        if self.attribute_reuse_id_keys is not None:
                                                            return True

                                                        if self.attribute_reuse_id_max_id is not None:
                                                            return True

                                                        if self.attribute_reuse_id_node is not None:
                                                            return True

                                                        if self.attribute_reuse_id_recover_sec is not None:
                                                            return True

                                                        if self.common_attributes is not None and self.common_attributes._has_data():
                                                            return True

                                                        if self.is_application_gateway_present is not None:
                                                            return True

                                                        if self.is_as_path2_byte is not None:
                                                            return True

                                                        if self.is_attr_set_present is not None:
                                                            return True

                                                        if self.is_ribrnh_present is not None:
                                                            return True

                                                        if self.is_rnh_present is not None:
                                                            return True

                                                        if self.ribrnh_encap is not None:
                                                            return True

                                                        if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                            return True

                                                        if self.ribrnh_mac is not None:
                                                            return True

                                                        if self.ribrnh_table is not None:
                                                            return True

                                                        if self.ribrnh_vni is not None:
                                                            return True

                                                        if self.ribrnhip_table is not None:
                                                            return True

                                                        if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                            return True

                                                        if self.rnh_addr_len is not None:
                                                            return True

                                                        if self.rnh_len is not None:
                                                            return True

                                                        if self.rnh_type is not None:
                                                            return True

                                                        if self.set_aigp_inbound_igp is not None:
                                                            return True

                                                        if self.set_aigp_inbound_metric is not None:
                                                            return True

                                                        if self.vpn_distinguisher is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-process-instance-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.af_name is not None:
                                                        return True

                                                    if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                        return True

                                                    if self.label_fail is not None:
                                                        return True

                                                    if self.label_o_or_version is not None:
                                                        return True

                                                    if self.label_oor is not None:
                                                        return True

                                                    if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                        return True

                                                    if self.no_path is not None:
                                                        return True

                                                    if self.path_information is not None and self.path_information._has_data():
                                                        return True

                                                    if self.prefix_version is not None:
                                                        return True

                                                    if self.process_instance_id is not None:
                                                        return True

                                                    if self.route_distinguisher is not None:
                                                        return True

                                                    if self.source_route_distinguisher is not None:
                                                        return True

                                                    if self.source_vrf_name is not None:
                                                        return True

                                                    if self.srcaf_name is not None:
                                                        return True

                                                    if self.vrf_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath']['meta_info']


                                            class ActiveProcessInstancePath(object):
                                                """
                                                Active's paths for this net 
                                                
                                                .. attribute:: af_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: attributes_after_policy_in
                                                
                                                	Attributes after inbound policy applied
                                                	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn>`
                                                
                                                .. attribute:: label_fail
                                                
                                                	LSD label allocation failed 
                                                	**type**\:  bool
                                                
                                                .. attribute:: label_o_or_version
                                                
                                                	Label Version when OOR happens
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_oor
                                                
                                                	LSD label space is exhausted
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address_xr
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr>`
                                                
                                                .. attribute:: no_path
                                                
                                                	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                                	**type**\:  bool
                                                
                                                .. attribute:: path_information
                                                
                                                	Path information
                                                	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation>`
                                                
                                                .. attribute:: prefix_version
                                                
                                                	Version of BGP Prefix Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: process_instance_id
                                                
                                                	Process instance ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: source_route_distinguisher
                                                
                                                	Source Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: source_vrf_name
                                                
                                                	Name of the source VRF
                                                	**type**\:  str
                                                
                                                .. attribute:: srcaf_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: vrf_name
                                                
                                                	Name of the VRF
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.af_name = None
                                                    self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn()
                                                    self.attributes_after_policy_in.parent = self
                                                    self.label_fail = None
                                                    self.label_o_or_version = None
                                                    self.label_oor = None
                                                    self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr()
                                                    self.neighbor_address_xr.parent = self
                                                    self.no_path = None
                                                    self.path_information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation()
                                                    self.path_information.parent = self
                                                    self.prefix_version = None
                                                    self.process_instance_id = None
                                                    self.route_distinguisher = None
                                                    self.source_route_distinguisher = None
                                                    self.source_vrf_name = None
                                                    self.srcaf_name = None
                                                    self.vrf_name = None


                                                class NeighborAddressXr(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr']['meta_info']


                                                class PathInformation(object):
                                                    """
                                                    Path information
                                                    
                                                    .. attribute:: accept_own_path
                                                    
                                                    	Accept Own
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: accept_own_self_originated_p_ath
                                                    
                                                    	Accept\-Own self\-originated
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: add_path_orr_bitfield
                                                    
                                                    	ORR Add path Bitfields
                                                    	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                    
                                                    .. attribute:: advertisedto_pe
                                                    
                                                    	Net could be advertised                          to PE peers
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: aigp_metric
                                                    
                                                    	Total AIGP metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: best_path_comp_stage
                                                    
                                                    	Stage where the path lost to the best path or group best
                                                    	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                                    
                                                    .. attribute:: best_path_comp_winner
                                                    
                                                    	Neighbor address of the path which won best path comparison
                                                    	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                    
                                                    .. attribute:: best_path_id
                                                    
                                                    	Best path ID; DEPRECATED BYLocalPathId
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: best_path_id_comp_winner
                                                    
                                                    	Path ID of the path which won best path comparison
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: best_path_orr_bitfield
                                                    
                                                    	ORR Best path Bitfields
                                                    	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                    
                                                    .. attribute:: bgp_prefix
                                                    
                                                    	BGP prefix
                                                    	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix>`
                                                    
                                                    .. attribute:: dampen_penalty
                                                    
                                                    	Dampening penalty
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Mvpn Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                    
                                                    .. attribute:: fspec_invalid_path
                                                    
                                                    	Is Fspec invalid path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: graceful_shutdown
                                                    
                                                    	Marked for graceful shutdown
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: gw_addr
                                                    
                                                    	Path GW Address
                                                    	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.GwAddr>`
                                                    
                                                    .. attribute:: halflife_time
                                                    
                                                    	Half\-life time for the penalty
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_esi
                                                    
                                                    	Path has EVPN ESI
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_gw_addr
                                                    
                                                    	Path has GW Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_local_net_label
                                                    
                                                    	Path has local label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mdt_group_addr
                                                    
                                                    	Path has MDT Group Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_extcomm
                                                    
                                                    	Path has MVPN EXTCOMM feedback
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_nbr_addr
                                                    
                                                    	Path has Mvpn nbr Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_nexthop_addr
                                                    
                                                    	Path has MVPN nexthop Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_pmsi
                                                    
                                                    	Path has MVPN PMSI feedback
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_rcvd_label
                                                    
                                                    	Path has received label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_second_label
                                                    
                                                    	Path has second received label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ibgp_signaled_validity
                                                    
                                                    	IBGP signalled validation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: igp_metric
                                                    
                                                    	IGP metric to the gateway
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_aggregation_suppressed
                                                    
                                                    	Path suppressed due to aggregation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_best
                                                    
                                                    	Best available path within AS
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_best_path
                                                    
                                                    	Best available path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_import_dampened
                                                    
                                                    	net import dampened
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_import_suspect
                                                    
                                                    	net import suspect
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_internal_path
                                                    
                                                    	Received over an internal link
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_best
                                                    
                                                    	Partial best path within distributed speaker
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_additional_path
                                                    
                                                    	Path is an additional\-path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_advertised_local_as_only
                                                    
                                                    	Not advertised outside local AS
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_af_install_eligible
                                                    
                                                    	Path can be installed in AF RIB
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_backup
                                                    
                                                    	Path is a backup path 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_backup_protect_multipath
                                                    
                                                    	Path is a backup path to protect multipaths
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_best_external
                                                    
                                                    	Path is a best external path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_damped
                                                    
                                                    	Path suppressed due to dampening
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_confederation_peer
                                                    
                                                    	Path received from confederation peer
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_network_command
                                                    
                                                    	Path sourced by network command
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_redistribute_command
                                                    
                                                    	Path sourced by redistribute command
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_route_reflector
                                                    
                                                    	Path received from route reflector
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_history_held
                                                    
                                                    	Path entry held to remember history
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_imp_candidate
                                                    
                                                    	Path is a candidate for multipath import
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_imported
                                                    
                                                    	Path is imported
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_local_aggregate
                                                    
                                                    	Path is a locally created aggregate
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_locally_sourced
                                                    
                                                    	Path sourced locally
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_long_lived_stale
                                                    
                                                    	Long lived stale routes learnt before neighbor restarts
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_multipath
                                                    
                                                    	Path is one of multipath best routes
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_nexthop_discarded
                                                    
                                                    	Path is redirected to Null0
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_not_advertised
                                                    
                                                    	Not advertised to any peer
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_not_advertised_to_ebg_ps
                                                    
                                                    	Not advertised to EBGPs
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_received_only
                                                    
                                                    	Path is received only
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_reoriginated
                                                    
                                                    	Path is reoriginated
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_reoriginated_stitching
                                                    
                                                    	Path is reoriginated with stitching RTs
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_stale
                                                    
                                                    	Stale routes learnt before neighbor restarts
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_synced_with_igp
                                                    
                                                    	Path synchronized with IGP
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_valid
                                                    
                                                    	Path attributes are usable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_vpn_only
                                                    
                                                    	Path is not in the vrf
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_permanent_path
                                                    
                                                    	Path is of type Permanent path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_received_path_not_modified
                                                    
                                                    	Received path used without modification
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_spkr_as_best
                                                    
                                                    	Best available path within AS in speaker
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2vpn_circuit_status_value
                                                    
                                                    	L2VPN Circuit Status Value
                                                    	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                    
                                                    .. attribute:: l2vpn_evpn_esi
                                                    
                                                    	L2VPN EVPN ESI
                                                    	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi>`
                                                    
                                                    .. attribute:: l2vpn_size
                                                    
                                                    	Path block size
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: labeled_unicast_safi_path
                                                    
                                                    	Path was learnt by labeled\-unicast SAFI
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: local_label
                                                    
                                                    	Path local label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_nh
                                                    
                                                    	Path has local nexthop
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: local_path_id
                                                    
                                                    	Local path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_peers_advertised_to
                                                    
                                                    	Local peers that this prefix has been advertised to
                                                    	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                    
                                                    .. attribute:: maximum_suppress_time
                                                    
                                                    	Maximum duration to suppress a stable route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mdt_group_addr
                                                    
                                                    	IPv4 MDT Group Address for the path
                                                    	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                    
                                                    .. attribute:: mvpn_nbr_addr
                                                    
                                                    	Mvpn nbr Address for the path
                                                    	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                    
                                                    .. attribute:: mvpn_nexthop_addr
                                                    
                                                    	Mvpn nexthop Address for the path
                                                    	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                    
                                                    .. attribute:: mvpn_path_flags
                                                    
                                                    	Mvpn path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: mvpn_pmsi_flags
                                                    
                                                    	Mvpn PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: mvpn_pmsi_label
                                                    
                                                    	Mvpn PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mvpn_pmsi_type
                                                    
                                                    	Mvpn PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: mvpn_pmsi_value
                                                    
                                                    	Mvpn PMSI Value
                                                    	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                    
                                                    .. attribute:: mvpn_sfs_path
                                                    
                                                    	Is MVPN single forwarder PE path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress>`
                                                    
                                                    .. attribute:: neighbor_router_id
                                                    
                                                    	Router ID of the neighbor for the path
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: next_hop
                                                    
                                                    	Next hop
                                                    	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop>`
                                                    
                                                    .. attribute:: nhte_tunnel
                                                    
                                                    	NH TE tunnel information
                                                    	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhteTunnel>`
                                                    
                                                    .. attribute:: path_flags
                                                    
                                                    	Flags associated with path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: path_flap_count
                                                    
                                                    	Number of times this route has flapped
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_import_flags
                                                    
                                                    	Path import flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_rt_set_id
                                                    
                                                    	RT\-set id of the path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_rt_set_route_count
                                                    
                                                    	Count in RT\-set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_table_version
                                                    
                                                    	Table version # for pelem
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_weight
                                                    
                                                    	Weight for the path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pe_peers_advertised_to
                                                    
                                                    	PE peers that this prefix has been advertised to
                                                    	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                    
                                                    .. attribute:: rcvd_label
                                                    
                                                    	Path received label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rcvd_path_id
                                                    
                                                    	Received path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: reuse_value
                                                    
                                                    	Value to start reusing a route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rib_failed
                                                    
                                                    	Is net failed installed                          in RIB
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: route_type
                                                    
                                                    	Route Type of path
                                                    	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                                    
                                                    .. attribute:: rpki_origin_as_validation_disabled
                                                    
                                                    	RPKI originAS V. Disabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rt_set_limit_enabled
                                                    
                                                    	Path subject to RT\-set net limit
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_label
                                                    
                                                    	Path second received label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: seconds_since_first_flap
                                                    
                                                    	Seconds since route first flapped
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: show_rpki_origin_as_validity
                                                    
                                                    	Display validity state ?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: sn_rpki_origin_as_validity
                                                    
                                                    	RPKI origin validation state
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: suppress_penalty
                                                    
                                                    	Value to start suppressing a route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: time_to_unsuppress
                                                    
                                                    	Seconds until route is unsuppressed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.accept_own_path = None
                                                        self.accept_own_self_originated_p_ath = None
                                                        self.add_path_orr_bitfield = YList()
                                                        self.add_path_orr_bitfield.parent = self
                                                        self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                        self.advertisedto_pe = None
                                                        self.aigp_metric = None
                                                        self.best_path_comp_stage = None
                                                        self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner()
                                                        self.best_path_comp_winner.parent = self
                                                        self.best_path_id = None
                                                        self.best_path_id_comp_winner = None
                                                        self.best_path_orr_bitfield = YList()
                                                        self.best_path_orr_bitfield.parent = self
                                                        self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                        self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix()
                                                        self.bgp_prefix.parent = self
                                                        self.dampen_penalty = None
                                                        self.extended_community = YList()
                                                        self.extended_community.parent = self
                                                        self.extended_community.name = 'extended_community'
                                                        self.fspec_invalid_path = None
                                                        self.graceful_shutdown = None
                                                        self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.GwAddr()
                                                        self.gw_addr.parent = self
                                                        self.halflife_time = None
                                                        self.has_esi = None
                                                        self.has_gw_addr = None
                                                        self.has_local_net_label = None
                                                        self.has_mdt_group_addr = None
                                                        self.has_mvpn_extcomm = None
                                                        self.has_mvpn_nbr_addr = None
                                                        self.has_mvpn_nexthop_addr = None
                                                        self.has_mvpn_pmsi = None
                                                        self.has_rcvd_label = None
                                                        self.has_second_label = None
                                                        self.ibgp_signaled_validity = None
                                                        self.igp_metric = None
                                                        self.is_aggregation_suppressed = None
                                                        self.is_as_best = None
                                                        self.is_best_path = None
                                                        self.is_import_dampened = None
                                                        self.is_import_suspect = None
                                                        self.is_internal_path = None
                                                        self.is_partial_best = None
                                                        self.is_path_additional_path = None
                                                        self.is_path_advertised_local_as_only = None
                                                        self.is_path_af_install_eligible = None
                                                        self.is_path_backup = None
                                                        self.is_path_backup_protect_multipath = None
                                                        self.is_path_best_external = None
                                                        self.is_path_damped = None
                                                        self.is_path_from_confederation_peer = None
                                                        self.is_path_from_network_command = None
                                                        self.is_path_from_redistribute_command = None
                                                        self.is_path_from_route_reflector = None
                                                        self.is_path_history_held = None
                                                        self.is_path_imp_candidate = None
                                                        self.is_path_imported = None
                                                        self.is_path_local_aggregate = None
                                                        self.is_path_locally_sourced = None
                                                        self.is_path_long_lived_stale = None
                                                        self.is_path_multipath = None
                                                        self.is_path_nexthop_discarded = None
                                                        self.is_path_not_advertised = None
                                                        self.is_path_not_advertised_to_ebg_ps = None
                                                        self.is_path_received_only = None
                                                        self.is_path_reoriginated = None
                                                        self.is_path_reoriginated_stitching = None
                                                        self.is_path_stale = None
                                                        self.is_path_synced_with_igp = None
                                                        self.is_path_valid = None
                                                        self.is_path_vpn_only = None
                                                        self.is_permanent_path = None
                                                        self.is_received_path_not_modified = None
                                                        self.is_spkr_as_best = None
                                                        self.l2vpn_circuit_status_value = YList()
                                                        self.l2vpn_circuit_status_value.parent = self
                                                        self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                        self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi()
                                                        self.l2vpn_evpn_esi.parent = self
                                                        self.l2vpn_size = None
                                                        self.labeled_unicast_safi_path = None
                                                        self.local_label = None
                                                        self.local_nh = None
                                                        self.local_path_id = None
                                                        self.local_peers_advertised_to = YList()
                                                        self.local_peers_advertised_to.parent = self
                                                        self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                        self.maximum_suppress_time = None
                                                        self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr()
                                                        self.mdt_group_addr.parent = self
                                                        self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                        self.mvpn_nbr_addr.parent = self
                                                        self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                        self.mvpn_nexthop_addr.parent = self
                                                        self.mvpn_path_flags = None
                                                        self.mvpn_pmsi_flags = None
                                                        self.mvpn_pmsi_label = None
                                                        self.mvpn_pmsi_type = None
                                                        self.mvpn_pmsi_value = YList()
                                                        self.mvpn_pmsi_value.parent = self
                                                        self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                        self.mvpn_sfs_path = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.neighbor_router_id = None
                                                        self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop()
                                                        self.next_hop.parent = self
                                                        self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhteTunnel()
                                                        self.nhte_tunnel.parent = self
                                                        self.path_flags = None
                                                        self.path_flap_count = None
                                                        self.path_import_flags = None
                                                        self.path_rt_set_id = None
                                                        self.path_rt_set_route_count = None
                                                        self.path_table_version = None
                                                        self.path_weight = None
                                                        self.pe_peers_advertised_to = YList()
                                                        self.pe_peers_advertised_to.parent = self
                                                        self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                        self.rcvd_label = None
                                                        self.rcvd_path_id = None
                                                        self.reuse_value = None
                                                        self.rib_failed = None
                                                        self.route_type = None
                                                        self.rpki_origin_as_validation_disabled = None
                                                        self.rt_set_limit_enabled = None
                                                        self.second_label = None
                                                        self.seconds_since_first_flap = None
                                                        self.show_rpki_origin_as_validity = None
                                                        self.sn_rpki_origin_as_validity = None
                                                        self.suppress_penalty = None
                                                        self.time_to_unsuppress = None


                                                    class BgpPrefix(object):
                                                        """
                                                        BGP prefix
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Prefix
                                                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                            self.prefix.parent = self
                                                            self.prefix_length = None


                                                        class Prefix(object):
                                                            """
                                                            Prefix
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.prefix is not None and self.prefix._has_data():
                                                                return True

                                                            if self.prefix_length is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix']['meta_info']


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress']['meta_info']


                                                    class NextHop(object):
                                                        """
                                                        Next hop
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop']['meta_info']


                                                    class NhteTunnel(object):
                                                        """
                                                        NH TE tunnel information
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	Binding label for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_te_tunnel
                                                        
                                                        	NH TE Tunnel info is present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_info_stale
                                                        
                                                        	Tunnel is stale
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_registered
                                                        
                                                        	Tunnel registered flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_up
                                                        
                                                        	Tunnel Up flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: last_tunnel_update
                                                        
                                                        	Time since the last rib update happened
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_if_handle
                                                        
                                                        	Interface handle for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_name
                                                        
                                                        	tunnel name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        .. attribute:: tunnel_type
                                                        
                                                        	tunnel type
                                                        	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                        
                                                        .. attribute:: tunnel_v6_enabled
                                                        
                                                        	IPv6 enabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_v6_required
                                                        
                                                        	Tunnel need IPv6
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.binding_label = None
                                                            self.has_te_tunnel = None
                                                            self.is_tunnel_info_stale = None
                                                            self.is_tunnel_registered = None
                                                            self.is_tunnel_up = None
                                                            self.last_tunnel_update = None
                                                            self.tunnel_if_handle = None
                                                            self.tunnel_name = None
                                                            self.tunnel_type = None
                                                            self.tunnel_v6_enabled = None
                                                            self.tunnel_v6_required = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.binding_label is not None:
                                                                return True

                                                            if self.has_te_tunnel is not None:
                                                                return True

                                                            if self.is_tunnel_info_stale is not None:
                                                                return True

                                                            if self.is_tunnel_registered is not None:
                                                                return True

                                                            if self.is_tunnel_up is not None:
                                                                return True

                                                            if self.last_tunnel_update is not None:
                                                                return True

                                                            if self.tunnel_if_handle is not None:
                                                                return True

                                                            if self.tunnel_name is not None:
                                                                return True

                                                            if self.tunnel_type is not None:
                                                                return True

                                                            if self.tunnel_v6_enabled is not None:
                                                                return True

                                                            if self.tunnel_v6_required is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhteTunnel']['meta_info']


                                                    class MdtGroupAddr(object):
                                                        """
                                                        IPv4 MDT Group Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr']['meta_info']


                                                    class L2VpnEvpnEsi(object):
                                                        """
                                                        L2VPN EVPN ESI
                                                        
                                                        .. attribute:: esi
                                                        
                                                        	esi
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.esi = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.esi is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi']['meta_info']


                                                    class GwAddr(object):
                                                        """
                                                        Path GW Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_address = None
                                                            self.ipv6_address = None
                                                            self.len = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.len is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.GwAddr']['meta_info']


                                                    class BestPathCompWinner(object):
                                                        """
                                                        Neighbor address of the path which won best path
                                                        comparison
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner']['meta_info']


                                                    class MvpnNbrAddr(object):
                                                        """
                                                        Mvpn nbr Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr']['meta_info']


                                                    class MvpnNexthopAddr(object):
                                                        """
                                                        Mvpn nexthop Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr']['meta_info']


                                                    class L2VpnCircuitStatusValue(object):
                                                        """
                                                        L2VPN Circuit Status Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                                    class MvpnPmsiValue(object):
                                                        """
                                                        Mvpn PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue']['meta_info']


                                                    class ExtendedCommunity(object):
                                                        """
                                                        Mvpn Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity']['meta_info']


                                                    class LocalPeersAdvertisedTo(object):
                                                        """
                                                        Local peers that this prefix has been advertised
                                                        to
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.is_neighbor = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.update_group_number = None


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.is_neighbor is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.update_group_number is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                                    class PePeersAdvertisedTo(object):
                                                        """
                                                        PE peers that this prefix has been advertised to
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.is_neighbor = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.update_group_number = None


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.is_neighbor is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.update_group_number is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo']['meta_info']


                                                    class BestPathOrrBitfield(object):
                                                        """
                                                        ORR Best path Bitfields
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.is_neighbor = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.update_group_number = None


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.is_neighbor is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.update_group_number is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield']['meta_info']


                                                    class AddPathOrrBitfield(object):
                                                        """
                                                        ORR Add path Bitfields
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.is_neighbor = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.update_group_number = None


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.is_neighbor is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.update_group_number is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.accept_own_path is not None:
                                                            return True

                                                        if self.accept_own_self_originated_p_ath is not None:
                                                            return True

                                                        if self.add_path_orr_bitfield is not None:
                                                            for child_ref in self.add_path_orr_bitfield:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.advertisedto_pe is not None:
                                                            return True

                                                        if self.aigp_metric is not None:
                                                            return True

                                                        if self.best_path_comp_stage is not None:
                                                            return True

                                                        if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                            return True

                                                        if self.best_path_id is not None:
                                                            return True

                                                        if self.best_path_id_comp_winner is not None:
                                                            return True

                                                        if self.best_path_orr_bitfield is not None:
                                                            for child_ref in self.best_path_orr_bitfield:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                            return True

                                                        if self.dampen_penalty is not None:
                                                            return True

                                                        if self.extended_community is not None:
                                                            for child_ref in self.extended_community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.fspec_invalid_path is not None:
                                                            return True

                                                        if self.graceful_shutdown is not None:
                                                            return True

                                                        if self.gw_addr is not None and self.gw_addr._has_data():
                                                            return True

                                                        if self.halflife_time is not None:
                                                            return True

                                                        if self.has_esi is not None:
                                                            return True

                                                        if self.has_gw_addr is not None:
                                                            return True

                                                        if self.has_local_net_label is not None:
                                                            return True

                                                        if self.has_mdt_group_addr is not None:
                                                            return True

                                                        if self.has_mvpn_extcomm is not None:
                                                            return True

                                                        if self.has_mvpn_nbr_addr is not None:
                                                            return True

                                                        if self.has_mvpn_nexthop_addr is not None:
                                                            return True

                                                        if self.has_mvpn_pmsi is not None:
                                                            return True

                                                        if self.has_rcvd_label is not None:
                                                            return True

                                                        if self.has_second_label is not None:
                                                            return True

                                                        if self.ibgp_signaled_validity is not None:
                                                            return True

                                                        if self.igp_metric is not None:
                                                            return True

                                                        if self.is_aggregation_suppressed is not None:
                                                            return True

                                                        if self.is_as_best is not None:
                                                            return True

                                                        if self.is_best_path is not None:
                                                            return True

                                                        if self.is_import_dampened is not None:
                                                            return True

                                                        if self.is_import_suspect is not None:
                                                            return True

                                                        if self.is_internal_path is not None:
                                                            return True

                                                        if self.is_partial_best is not None:
                                                            return True

                                                        if self.is_path_additional_path is not None:
                                                            return True

                                                        if self.is_path_advertised_local_as_only is not None:
                                                            return True

                                                        if self.is_path_af_install_eligible is not None:
                                                            return True

                                                        if self.is_path_backup is not None:
                                                            return True

                                                        if self.is_path_backup_protect_multipath is not None:
                                                            return True

                                                        if self.is_path_best_external is not None:
                                                            return True

                                                        if self.is_path_damped is not None:
                                                            return True

                                                        if self.is_path_from_confederation_peer is not None:
                                                            return True

                                                        if self.is_path_from_network_command is not None:
                                                            return True

                                                        if self.is_path_from_redistribute_command is not None:
                                                            return True

                                                        if self.is_path_from_route_reflector is not None:
                                                            return True

                                                        if self.is_path_history_held is not None:
                                                            return True

                                                        if self.is_path_imp_candidate is not None:
                                                            return True

                                                        if self.is_path_imported is not None:
                                                            return True

                                                        if self.is_path_local_aggregate is not None:
                                                            return True

                                                        if self.is_path_locally_sourced is not None:
                                                            return True

                                                        if self.is_path_long_lived_stale is not None:
                                                            return True

                                                        if self.is_path_multipath is not None:
                                                            return True

                                                        if self.is_path_nexthop_discarded is not None:
                                                            return True

                                                        if self.is_path_not_advertised is not None:
                                                            return True

                                                        if self.is_path_not_advertised_to_ebg_ps is not None:
                                                            return True

                                                        if self.is_path_received_only is not None:
                                                            return True

                                                        if self.is_path_reoriginated is not None:
                                                            return True

                                                        if self.is_path_reoriginated_stitching is not None:
                                                            return True

                                                        if self.is_path_stale is not None:
                                                            return True

                                                        if self.is_path_synced_with_igp is not None:
                                                            return True

                                                        if self.is_path_valid is not None:
                                                            return True

                                                        if self.is_path_vpn_only is not None:
                                                            return True

                                                        if self.is_permanent_path is not None:
                                                            return True

                                                        if self.is_received_path_not_modified is not None:
                                                            return True

                                                        if self.is_spkr_as_best is not None:
                                                            return True

                                                        if self.l2vpn_circuit_status_value is not None:
                                                            for child_ref in self.l2vpn_circuit_status_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                            return True

                                                        if self.l2vpn_size is not None:
                                                            return True

                                                        if self.labeled_unicast_safi_path is not None:
                                                            return True

                                                        if self.local_label is not None:
                                                            return True

                                                        if self.local_nh is not None:
                                                            return True

                                                        if self.local_path_id is not None:
                                                            return True

                                                        if self.local_peers_advertised_to is not None:
                                                            for child_ref in self.local_peers_advertised_to:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.maximum_suppress_time is not None:
                                                            return True

                                                        if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                            return True

                                                        if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                            return True

                                                        if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                            return True

                                                        if self.mvpn_path_flags is not None:
                                                            return True

                                                        if self.mvpn_pmsi_flags is not None:
                                                            return True

                                                        if self.mvpn_pmsi_label is not None:
                                                            return True

                                                        if self.mvpn_pmsi_type is not None:
                                                            return True

                                                        if self.mvpn_pmsi_value is not None:
                                                            for child_ref in self.mvpn_pmsi_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.mvpn_sfs_path is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.neighbor_router_id is not None:
                                                            return True

                                                        if self.next_hop is not None and self.next_hop._has_data():
                                                            return True

                                                        if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                            return True

                                                        if self.path_flags is not None:
                                                            return True

                                                        if self.path_flap_count is not None:
                                                            return True

                                                        if self.path_import_flags is not None:
                                                            return True

                                                        if self.path_rt_set_id is not None:
                                                            return True

                                                        if self.path_rt_set_route_count is not None:
                                                            return True

                                                        if self.path_table_version is not None:
                                                            return True

                                                        if self.path_weight is not None:
                                                            return True

                                                        if self.pe_peers_advertised_to is not None:
                                                            for child_ref in self.pe_peers_advertised_to:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.rcvd_label is not None:
                                                            return True

                                                        if self.rcvd_path_id is not None:
                                                            return True

                                                        if self.reuse_value is not None:
                                                            return True

                                                        if self.rib_failed is not None:
                                                            return True

                                                        if self.route_type is not None:
                                                            return True

                                                        if self.rpki_origin_as_validation_disabled is not None:
                                                            return True

                                                        if self.rt_set_limit_enabled is not None:
                                                            return True

                                                        if self.second_label is not None:
                                                            return True

                                                        if self.seconds_since_first_flap is not None:
                                                            return True

                                                        if self.show_rpki_origin_as_validity is not None:
                                                            return True

                                                        if self.sn_rpki_origin_as_validity is not None:
                                                            return True

                                                        if self.suppress_penalty is not None:
                                                            return True

                                                        if self.time_to_unsuppress is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation']['meta_info']


                                                class AttributesAfterPolicyIn(object):
                                                    """
                                                    Attributes after inbound policy applied
                                                    
                                                    .. attribute:: attr_set
                                                    
                                                    	ATTR\_SET attribute
                                                    	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                    
                                                    .. attribute:: attribute_key_number
                                                    
                                                    	Attribute key number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_config
                                                    
                                                    	Attribute reuse ID Configured
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: attribute_reuse_id_current
                                                    
                                                    	Attribute reuse ID current ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_keys
                                                    
                                                    	Attribute reuse ID allocated keys
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_max_id
                                                    
                                                    	Attribute reuse ID maximum ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_node
                                                    
                                                    	Attribute reuse ID nodes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_recover_sec
                                                    
                                                    	Attribute reuse ID timer in seconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: common_attributes
                                                    
                                                    	Common attributes
                                                    	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                    
                                                    .. attribute:: is_application_gateway_present
                                                    
                                                    	Application gateway present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path2_byte
                                                    
                                                    	AS path encoded as 2\-byte
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_attr_set_present
                                                    
                                                    	BGP ATTR\_SET attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ribrnh_present
                                                    
                                                    	RIB RNH Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_rnh_present
                                                    
                                                    	RNH Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ribrnh_encap
                                                    
                                                    	RIB RNH Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ribrnh_ip
                                                    
                                                    	RIB RNH IP Address
                                                    	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                    
                                                    .. attribute:: ribrnh_mac
                                                    
                                                    	RIB RNH MAC Address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    .. attribute:: ribrnh_table
                                                    
                                                    	RIB RNH Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ribrnh_vni
                                                    
                                                    	RIB RNH Vni
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ribrnhip_table
                                                    
                                                    	RIB RNH IP Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rnh_addr
                                                    
                                                    	RNH Address
                                                    	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                    
                                                    .. attribute:: rnh_addr_len
                                                    
                                                    	RNH Address Length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rnh_len
                                                    
                                                    	RNH Length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: rnh_type
                                                    
                                                    	RNH Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: set_aigp_inbound_igp
                                                    
                                                    	AIGP set by policy inbound IGP 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: set_aigp_inbound_metric
                                                    
                                                    	AIGP set by policy inbound metric
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: vpn_distinguisher
                                                    
                                                    	VPN Distinguisher
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                        self.attr_set.parent = self
                                                        self.attribute_key_number = None
                                                        self.attribute_reuse_id_config = None
                                                        self.attribute_reuse_id_current = None
                                                        self.attribute_reuse_id_keys = None
                                                        self.attribute_reuse_id_max_id = None
                                                        self.attribute_reuse_id_node = None
                                                        self.attribute_reuse_id_recover_sec = None
                                                        self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                        self.common_attributes.parent = self
                                                        self.is_application_gateway_present = None
                                                        self.is_as_path2_byte = None
                                                        self.is_attr_set_present = None
                                                        self.is_ribrnh_present = None
                                                        self.is_rnh_present = None
                                                        self.ribrnh_encap = None
                                                        self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                        self.ribrnh_ip.parent = self
                                                        self.ribrnh_mac = None
                                                        self.ribrnh_table = None
                                                        self.ribrnh_vni = None
                                                        self.ribrnhip_table = None
                                                        self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                        self.rnh_addr.parent = self
                                                        self.rnh_addr_len = None
                                                        self.rnh_len = None
                                                        self.rnh_type = None
                                                        self.set_aigp_inbound_igp = None
                                                        self.set_aigp_inbound_metric = None
                                                        self.vpn_distinguisher = None


                                                    class CommonAttributes(object):
                                                        """
                                                        Common attributes
                                                        
                                                        .. attribute:: aggregator_address
                                                        
                                                        	Address where aggregation was performed
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: aggregator_as
                                                        
                                                        	AS where aggregation was last performed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: aigp_metric_value
                                                        
                                                        	AIGP metric value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: as_path
                                                        
                                                        	AS path attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: cluster
                                                        
                                                        	Cluster list attribute
                                                        	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                        
                                                        .. attribute:: community
                                                        
                                                        	Community attribute
                                                        	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                        
                                                        .. attribute:: connector_type
                                                        
                                                        	Connector Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: connector_value
                                                        
                                                        	Connector Value
                                                        	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                        
                                                        .. attribute:: extended_community_flags
                                                        
                                                        	Extended community Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: is_aggregator_present
                                                        
                                                        	Aggregator attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_aigp_present
                                                        
                                                        	AIGP Present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path_present
                                                        
                                                        	AS path attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_atomic_aggregate_present
                                                        
                                                        	Atomic aggregate attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_community_present
                                                        
                                                        	Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_connector_present
                                                        
                                                        	Connector present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_extended_community_present
                                                        
                                                        	Extended community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_label_index_present
                                                        
                                                        	Label Index attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_local_pref_present
                                                        
                                                        	Local Preference attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ls_attribute_present
                                                        
                                                        	BGP LS attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_metric_present
                                                        
                                                        	Metric attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_origin_present
                                                        
                                                        	Origin attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pe_distinguisher_label_present
                                                        
                                                        	PE distinguisher label  attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pmsi_present
                                                        
                                                        	PMSI Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pppmp_present
                                                        
                                                        	PPMP Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ssa_present
                                                        
                                                        	SSA attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_encap_present
                                                        
                                                        	Tunnel Encap attribute present 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2tpv3_cookie
                                                        
                                                        	L2TPv3 Cookie
                                                        	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                        
                                                        .. attribute:: l2tpv3_session_id
                                                        
                                                        	L2TPv3 session id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: label_index_attr
                                                        
                                                        	Label Index attribute
                                                        	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                        
                                                        .. attribute:: local_preference
                                                        
                                                        	Local preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ls_attr
                                                        
                                                        	BGP LS attribute
                                                        	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: neighbor_as
                                                        
                                                        	Neighbor AS number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: origin
                                                        
                                                        	Origin
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: originator
                                                        
                                                        	Originator attribute
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: pe_distinguisher_label
                                                        
                                                        	PE distinguisher label attribute
                                                        	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                        
                                                        .. attribute:: pmsi_flags
                                                        
                                                        	PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pmsi_label
                                                        
                                                        	PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pmsi_type
                                                        
                                                        	PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pmsi_value
                                                        
                                                        	PMSI Value
                                                        	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                        
                                                        .. attribute:: ppm_pvalue
                                                        
                                                        	PPMP Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: sr_policy_allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                        
                                                        .. attribute:: sr_policy_binding_sid
                                                        
                                                        	SR Policy Binding sid
                                                        	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                        
                                                        .. attribute:: sr_policy_explicit_path
                                                        
                                                        	SR Policy Explicit paths
                                                        	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                        
                                                        .. attribute:: sr_policy_preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: sr_tunnel_request_state
                                                        
                                                        	SR Tunnel Request State
                                                        	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                        
                                                        .. attribute:: sr_tunnel_state
                                                        
                                                        	SR Tunnel State
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encap Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: unknown_attribute
                                                        
                                                        	Unknown attributes
                                                        	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.aggregator_address = None
                                                            self.aggregator_as = None
                                                            self.aigp_metric_value = None
                                                            self.as_path = None
                                                            self.cluster = YList()
                                                            self.cluster.parent = self
                                                            self.cluster.name = 'cluster'
                                                            self.community = YList()
                                                            self.community.parent = self
                                                            self.community.name = 'community'
                                                            self.connector_type = None
                                                            self.connector_value = YList()
                                                            self.connector_value.parent = self
                                                            self.connector_value.name = 'connector_value'
                                                            self.extended_community = YList()
                                                            self.extended_community.parent = self
                                                            self.extended_community.name = 'extended_community'
                                                            self.extended_community_flags = None
                                                            self.is_aggregator_present = None
                                                            self.is_aigp_present = None
                                                            self.is_as_path_present = None
                                                            self.is_atomic_aggregate_present = None
                                                            self.is_community_present = None
                                                            self.is_connector_present = None
                                                            self.is_extended_community_present = None
                                                            self.is_label_index_present = None
                                                            self.is_local_pref_present = None
                                                            self.is_ls_attribute_present = None
                                                            self.is_metric_present = None
                                                            self.is_origin_present = None
                                                            self.is_pe_distinguisher_label_present = None
                                                            self.is_pmsi_present = None
                                                            self.is_pppmp_present = None
                                                            self.is_ssa_present = None
                                                            self.is_tunnel_encap_present = None
                                                            self.l2tpv3_cookie = YList()
                                                            self.l2tpv3_cookie.parent = self
                                                            self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                            self.l2tpv3_session_id = None
                                                            self.label_index_attr = YList()
                                                            self.label_index_attr.parent = self
                                                            self.label_index_attr.name = 'label_index_attr'
                                                            self.local_preference = None
                                                            self.ls_attr = YList()
                                                            self.ls_attr.parent = self
                                                            self.ls_attr.name = 'ls_attr'
                                                            self.metric = None
                                                            self.neighbor_as = None
                                                            self.origin = None
                                                            self.originator = None
                                                            self.pe_distinguisher_label = YList()
                                                            self.pe_distinguisher_label.parent = self
                                                            self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                            self.pmsi_flags = None
                                                            self.pmsi_label = None
                                                            self.pmsi_type = None
                                                            self.pmsi_value = YList()
                                                            self.pmsi_value.parent = self
                                                            self.pmsi_value.name = 'pmsi_value'
                                                            self.ppm_pvalue = None
                                                            self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                            self.sr_policy_allocated_binding_sid.parent = self
                                                            self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                            self.sr_policy_binding_sid.parent = self
                                                            self.sr_policy_explicit_path = YList()
                                                            self.sr_policy_explicit_path.parent = self
                                                            self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                            self.sr_policy_preference = None
                                                            self.sr_tunnel_request_state = None
                                                            self.sr_tunnel_state = None
                                                            self.tunnel_encap_type = None
                                                            self.unknown_attribute = YList()
                                                            self.unknown_attribute.parent = self
                                                            self.unknown_attribute.name = 'unknown_attribute'


                                                        class SrPolicyBindingSid(object):
                                                            """
                                                            SR Policy Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_address = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                        class SrPolicyAllocatedBindingSid(object):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_address = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                        class Community(object):
                                                            """
                                                            Community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                        class ExtendedCommunity(object):
                                                            """
                                                            Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                        class UnknownAttribute(object):
                                                            """
                                                            Unknown attributes
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                        class Cluster(object):
                                                            """
                                                            Cluster list attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                        class L2Tpv3Cookie(object):
                                                            """
                                                            L2TPv3 Cookie
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                        class ConnectorValue(object):
                                                            """
                                                            Connector Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                        class PmsiValue(object):
                                                            """
                                                            PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                        class LsAttr(object):
                                                            """
                                                            BGP LS attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                        class LabelIndexAttr(object):
                                                            """
                                                            Label Index attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                        class PeDistinguisherLabel(object):
                                                            """
                                                            PE distinguisher label attribute
                                                            
                                                            .. attribute:: label
                                                            
                                                            	Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pe_address
                                                            
                                                            	 PE address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.label = None
                                                                self.pe_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.label is not None:
                                                                    return True

                                                                if self.pe_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                        class SrPolicyExplicitPath(object):
                                                            """
                                                            SR Policy Explicit paths
                                                            
                                                            .. attribute:: sid
                                                            
                                                            	Sidlist for explicit path
                                                            	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of explicit path
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.sid = YList()
                                                                self.sid.parent = self
                                                                self.sid.name = 'sid'
                                                                self.weight = None


                                                            class Sid(object):
                                                                """
                                                                Sidlist for explicit path
                                                                
                                                                .. attribute:: ipv4
                                                                
                                                                	IP Address sid
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6
                                                                
                                                                	IPv6 address sid
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label sid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Sid Type
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4 = None
                                                                    self.ipv6 = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4 is not None:
                                                                        return True

                                                                    if self.ipv6 is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.sid is not None:
                                                                    for child_ref in self.sid:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.weight is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.aggregator_address is not None:
                                                                return True

                                                            if self.aggregator_as is not None:
                                                                return True

                                                            if self.aigp_metric_value is not None:
                                                                return True

                                                            if self.as_path is not None:
                                                                return True

                                                            if self.cluster is not None:
                                                                for child_ref in self.cluster:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.community is not None:
                                                                for child_ref in self.community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.connector_type is not None:
                                                                return True

                                                            if self.connector_value is not None:
                                                                for child_ref in self.connector_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.extended_community is not None:
                                                                for child_ref in self.extended_community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.extended_community_flags is not None:
                                                                return True

                                                            if self.is_aggregator_present is not None:
                                                                return True

                                                            if self.is_aigp_present is not None:
                                                                return True

                                                            if self.is_as_path_present is not None:
                                                                return True

                                                            if self.is_atomic_aggregate_present is not None:
                                                                return True

                                                            if self.is_community_present is not None:
                                                                return True

                                                            if self.is_connector_present is not None:
                                                                return True

                                                            if self.is_extended_community_present is not None:
                                                                return True

                                                            if self.is_label_index_present is not None:
                                                                return True

                                                            if self.is_local_pref_present is not None:
                                                                return True

                                                            if self.is_ls_attribute_present is not None:
                                                                return True

                                                            if self.is_metric_present is not None:
                                                                return True

                                                            if self.is_origin_present is not None:
                                                                return True

                                                            if self.is_pe_distinguisher_label_present is not None:
                                                                return True

                                                            if self.is_pmsi_present is not None:
                                                                return True

                                                            if self.is_pppmp_present is not None:
                                                                return True

                                                            if self.is_ssa_present is not None:
                                                                return True

                                                            if self.is_tunnel_encap_present is not None:
                                                                return True

                                                            if self.l2tpv3_cookie is not None:
                                                                for child_ref in self.l2tpv3_cookie:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.l2tpv3_session_id is not None:
                                                                return True

                                                            if self.label_index_attr is not None:
                                                                for child_ref in self.label_index_attr:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.local_preference is not None:
                                                                return True

                                                            if self.ls_attr is not None:
                                                                for child_ref in self.ls_attr:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.neighbor_as is not None:
                                                                return True

                                                            if self.origin is not None:
                                                                return True

                                                            if self.originator is not None:
                                                                return True

                                                            if self.pe_distinguisher_label is not None:
                                                                for child_ref in self.pe_distinguisher_label:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.pmsi_flags is not None:
                                                                return True

                                                            if self.pmsi_label is not None:
                                                                return True

                                                            if self.pmsi_type is not None:
                                                                return True

                                                            if self.pmsi_value is not None:
                                                                for child_ref in self.pmsi_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.ppm_pvalue is not None:
                                                                return True

                                                            if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                                return True

                                                            if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                                return True

                                                            if self.sr_policy_explicit_path is not None:
                                                                for child_ref in self.sr_policy_explicit_path:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.sr_policy_preference is not None:
                                                                return True

                                                            if self.sr_tunnel_request_state is not None:
                                                                return True

                                                            if self.sr_tunnel_state is not None:
                                                                return True

                                                            if self.tunnel_encap_type is not None:
                                                                return True

                                                            if self.unknown_attribute is not None:
                                                                for child_ref in self.unknown_attribute:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                                    class AttrSet(object):
                                                        """
                                                        ATTR\_SET attribute
                                                        
                                                        .. attribute:: aggregator_address
                                                        
                                                        	Address where aggregation was performed
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: aggregator_as
                                                        
                                                        	AS where aggregation was last performed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: aigp_metric_value
                                                        
                                                        	AIGP metric value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: as_path
                                                        
                                                        	AS path attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: cluster
                                                        
                                                        	Cluster list attribute
                                                        	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                        
                                                        .. attribute:: community
                                                        
                                                        	Community attribute
                                                        	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                        
                                                        .. attribute:: connector_type
                                                        
                                                        	Connector Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: connector_value
                                                        
                                                        	Connector Value
                                                        	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                        
                                                        .. attribute:: extended_community_flags
                                                        
                                                        	Extended community Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: is_aggregator_present
                                                        
                                                        	Aggregator attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_aigp_present
                                                        
                                                        	AIGP Present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path_present
                                                        
                                                        	AS path attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_atomic_aggregate_present
                                                        
                                                        	Atomic aggregate attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_community_present
                                                        
                                                        	Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_connector_present
                                                        
                                                        	Connector present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_extended_community_present
                                                        
                                                        	Extended community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_label_index_present
                                                        
                                                        	Label Index attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_local_pref_present
                                                        
                                                        	Local Preference attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ls_attribute_present
                                                        
                                                        	BGP LS attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_metric_present
                                                        
                                                        	Metric attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_origin_present
                                                        
                                                        	Origin attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pe_distinguisher_label_present
                                                        
                                                        	PE distinguisher label  attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pmsi_present
                                                        
                                                        	PMSI Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pppmp_present
                                                        
                                                        	PPMP Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ssa_present
                                                        
                                                        	SSA attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_encap_present
                                                        
                                                        	Tunnel Encap attribute present 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2tpv3_cookie
                                                        
                                                        	L2TPv3 Cookie
                                                        	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                        
                                                        .. attribute:: l2tpv3_session_id
                                                        
                                                        	L2TPv3 session id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: label_index_attr
                                                        
                                                        	Label Index attribute
                                                        	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                        
                                                        .. attribute:: local_preference
                                                        
                                                        	Local preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ls_attr
                                                        
                                                        	BGP LS attribute
                                                        	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: neighbor_as
                                                        
                                                        	Neighbor AS number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: origin
                                                        
                                                        	Origin
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: originator
                                                        
                                                        	Originator attribute
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: pe_distinguisher_label
                                                        
                                                        	PE distinguisher label attribute
                                                        	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                        
                                                        .. attribute:: pmsi_flags
                                                        
                                                        	PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pmsi_label
                                                        
                                                        	PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pmsi_type
                                                        
                                                        	PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pmsi_value
                                                        
                                                        	PMSI Value
                                                        	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                        
                                                        .. attribute:: ppm_pvalue
                                                        
                                                        	PPMP Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: sr_policy_allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                        
                                                        .. attribute:: sr_policy_binding_sid
                                                        
                                                        	SR Policy Binding sid
                                                        	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                        
                                                        .. attribute:: sr_policy_explicit_path
                                                        
                                                        	SR Policy Explicit paths
                                                        	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                        
                                                        .. attribute:: sr_policy_preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: sr_tunnel_request_state
                                                        
                                                        	SR Tunnel Request State
                                                        	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                        
                                                        .. attribute:: sr_tunnel_state
                                                        
                                                        	SR Tunnel State
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encap Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: unknown_attribute
                                                        
                                                        	Unknown attributes
                                                        	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.aggregator_address = None
                                                            self.aggregator_as = None
                                                            self.aigp_metric_value = None
                                                            self.as_path = None
                                                            self.cluster = YList()
                                                            self.cluster.parent = self
                                                            self.cluster.name = 'cluster'
                                                            self.community = YList()
                                                            self.community.parent = self
                                                            self.community.name = 'community'
                                                            self.connector_type = None
                                                            self.connector_value = YList()
                                                            self.connector_value.parent = self
                                                            self.connector_value.name = 'connector_value'
                                                            self.extended_community = YList()
                                                            self.extended_community.parent = self
                                                            self.extended_community.name = 'extended_community'
                                                            self.extended_community_flags = None
                                                            self.is_aggregator_present = None
                                                            self.is_aigp_present = None
                                                            self.is_as_path_present = None
                                                            self.is_atomic_aggregate_present = None
                                                            self.is_community_present = None
                                                            self.is_connector_present = None
                                                            self.is_extended_community_present = None
                                                            self.is_label_index_present = None
                                                            self.is_local_pref_present = None
                                                            self.is_ls_attribute_present = None
                                                            self.is_metric_present = None
                                                            self.is_origin_present = None
                                                            self.is_pe_distinguisher_label_present = None
                                                            self.is_pmsi_present = None
                                                            self.is_pppmp_present = None
                                                            self.is_ssa_present = None
                                                            self.is_tunnel_encap_present = None
                                                            self.l2tpv3_cookie = YList()
                                                            self.l2tpv3_cookie.parent = self
                                                            self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                            self.l2tpv3_session_id = None
                                                            self.label_index_attr = YList()
                                                            self.label_index_attr.parent = self
                                                            self.label_index_attr.name = 'label_index_attr'
                                                            self.local_preference = None
                                                            self.ls_attr = YList()
                                                            self.ls_attr.parent = self
                                                            self.ls_attr.name = 'ls_attr'
                                                            self.metric = None
                                                            self.neighbor_as = None
                                                            self.origin = None
                                                            self.originator = None
                                                            self.pe_distinguisher_label = YList()
                                                            self.pe_distinguisher_label.parent = self
                                                            self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                            self.pmsi_flags = None
                                                            self.pmsi_label = None
                                                            self.pmsi_type = None
                                                            self.pmsi_value = YList()
                                                            self.pmsi_value.parent = self
                                                            self.pmsi_value.name = 'pmsi_value'
                                                            self.ppm_pvalue = None
                                                            self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                            self.sr_policy_allocated_binding_sid.parent = self
                                                            self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                            self.sr_policy_binding_sid.parent = self
                                                            self.sr_policy_explicit_path = YList()
                                                            self.sr_policy_explicit_path.parent = self
                                                            self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                            self.sr_policy_preference = None
                                                            self.sr_tunnel_request_state = None
                                                            self.sr_tunnel_state = None
                                                            self.tunnel_encap_type = None
                                                            self.unknown_attribute = YList()
                                                            self.unknown_attribute.parent = self
                                                            self.unknown_attribute.name = 'unknown_attribute'


                                                        class SrPolicyBindingSid(object):
                                                            """
                                                            SR Policy Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_address = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                        class SrPolicyAllocatedBindingSid(object):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_address = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                        class Community(object):
                                                            """
                                                            Community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                        class ExtendedCommunity(object):
                                                            """
                                                            Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                        class UnknownAttribute(object):
                                                            """
                                                            Unknown attributes
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                        class Cluster(object):
                                                            """
                                                            Cluster list attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                        class L2Tpv3Cookie(object):
                                                            """
                                                            L2TPv3 Cookie
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                        class ConnectorValue(object):
                                                            """
                                                            Connector Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                        class PmsiValue(object):
                                                            """
                                                            PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                        class LsAttr(object):
                                                            """
                                                            BGP LS attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                        class LabelIndexAttr(object):
                                                            """
                                                            Label Index attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                        class PeDistinguisherLabel(object):
                                                            """
                                                            PE distinguisher label attribute
                                                            
                                                            .. attribute:: label
                                                            
                                                            	Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pe_address
                                                            
                                                            	 PE address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.label = None
                                                                self.pe_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.label is not None:
                                                                    return True

                                                                if self.pe_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                        class SrPolicyExplicitPath(object):
                                                            """
                                                            SR Policy Explicit paths
                                                            
                                                            .. attribute:: sid
                                                            
                                                            	Sidlist for explicit path
                                                            	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of explicit path
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.sid = YList()
                                                                self.sid.parent = self
                                                                self.sid.name = 'sid'
                                                                self.weight = None


                                                            class Sid(object):
                                                                """
                                                                Sidlist for explicit path
                                                                
                                                                .. attribute:: ipv4
                                                                
                                                                	IP Address sid
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6
                                                                
                                                                	IPv6 address sid
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label sid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Sid Type
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4 = None
                                                                    self.ipv6 = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4 is not None:
                                                                        return True

                                                                    if self.ipv6 is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.sid is not None:
                                                                    for child_ref in self.sid:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.weight is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.aggregator_address is not None:
                                                                return True

                                                            if self.aggregator_as is not None:
                                                                return True

                                                            if self.aigp_metric_value is not None:
                                                                return True

                                                            if self.as_path is not None:
                                                                return True

                                                            if self.cluster is not None:
                                                                for child_ref in self.cluster:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.community is not None:
                                                                for child_ref in self.community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.connector_type is not None:
                                                                return True

                                                            if self.connector_value is not None:
                                                                for child_ref in self.connector_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.extended_community is not None:
                                                                for child_ref in self.extended_community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.extended_community_flags is not None:
                                                                return True

                                                            if self.is_aggregator_present is not None:
                                                                return True

                                                            if self.is_aigp_present is not None:
                                                                return True

                                                            if self.is_as_path_present is not None:
                                                                return True

                                                            if self.is_atomic_aggregate_present is not None:
                                                                return True

                                                            if self.is_community_present is not None:
                                                                return True

                                                            if self.is_connector_present is not None:
                                                                return True

                                                            if self.is_extended_community_present is not None:
                                                                return True

                                                            if self.is_label_index_present is not None:
                                                                return True

                                                            if self.is_local_pref_present is not None:
                                                                return True

                                                            if self.is_ls_attribute_present is not None:
                                                                return True

                                                            if self.is_metric_present is not None:
                                                                return True

                                                            if self.is_origin_present is not None:
                                                                return True

                                                            if self.is_pe_distinguisher_label_present is not None:
                                                                return True

                                                            if self.is_pmsi_present is not None:
                                                                return True

                                                            if self.is_pppmp_present is not None:
                                                                return True

                                                            if self.is_ssa_present is not None:
                                                                return True

                                                            if self.is_tunnel_encap_present is not None:
                                                                return True

                                                            if self.l2tpv3_cookie is not None:
                                                                for child_ref in self.l2tpv3_cookie:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.l2tpv3_session_id is not None:
                                                                return True

                                                            if self.label_index_attr is not None:
                                                                for child_ref in self.label_index_attr:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.local_preference is not None:
                                                                return True

                                                            if self.ls_attr is not None:
                                                                for child_ref in self.ls_attr:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.neighbor_as is not None:
                                                                return True

                                                            if self.origin is not None:
                                                                return True

                                                            if self.originator is not None:
                                                                return True

                                                            if self.pe_distinguisher_label is not None:
                                                                for child_ref in self.pe_distinguisher_label:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.pmsi_flags is not None:
                                                                return True

                                                            if self.pmsi_label is not None:
                                                                return True

                                                            if self.pmsi_type is not None:
                                                                return True

                                                            if self.pmsi_value is not None:
                                                                for child_ref in self.pmsi_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.ppm_pvalue is not None:
                                                                return True

                                                            if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                                return True

                                                            if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                                return True

                                                            if self.sr_policy_explicit_path is not None:
                                                                for child_ref in self.sr_policy_explicit_path:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.sr_policy_preference is not None:
                                                                return True

                                                            if self.sr_tunnel_request_state is not None:
                                                                return True

                                                            if self.sr_tunnel_state is not None:
                                                                return True

                                                            if self.tunnel_encap_type is not None:
                                                                return True

                                                            if self.unknown_attribute is not None:
                                                                for child_ref in self.unknown_attribute:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                                    class RnhAddr(object):
                                                        """
                                                        RNH Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                        
                                                        .. attribute:: mac_address
                                                        
                                                        	MAC Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_address = None
                                                            self.ipv6_address = None
                                                            self.len = None
                                                            self.mac_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.len is not None:
                                                                return True

                                                            if self.mac_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                                    class RibrnhIp(object):
                                                        """
                                                        RIB RNH IP Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.attr_set is not None and self.attr_set._has_data():
                                                            return True

                                                        if self.attribute_key_number is not None:
                                                            return True

                                                        if self.attribute_reuse_id_config is not None:
                                                            return True

                                                        if self.attribute_reuse_id_current is not None:
                                                            return True

                                                        if self.attribute_reuse_id_keys is not None:
                                                            return True

                                                        if self.attribute_reuse_id_max_id is not None:
                                                            return True

                                                        if self.attribute_reuse_id_node is not None:
                                                            return True

                                                        if self.attribute_reuse_id_recover_sec is not None:
                                                            return True

                                                        if self.common_attributes is not None and self.common_attributes._has_data():
                                                            return True

                                                        if self.is_application_gateway_present is not None:
                                                            return True

                                                        if self.is_as_path2_byte is not None:
                                                            return True

                                                        if self.is_attr_set_present is not None:
                                                            return True

                                                        if self.is_ribrnh_present is not None:
                                                            return True

                                                        if self.is_rnh_present is not None:
                                                            return True

                                                        if self.ribrnh_encap is not None:
                                                            return True

                                                        if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                            return True

                                                        if self.ribrnh_mac is not None:
                                                            return True

                                                        if self.ribrnh_table is not None:
                                                            return True

                                                        if self.ribrnh_vni is not None:
                                                            return True

                                                        if self.ribrnhip_table is not None:
                                                            return True

                                                        if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                            return True

                                                        if self.rnh_addr_len is not None:
                                                            return True

                                                        if self.rnh_len is not None:
                                                            return True

                                                        if self.rnh_type is not None:
                                                            return True

                                                        if self.set_aigp_inbound_igp is not None:
                                                            return True

                                                        if self.set_aigp_inbound_metric is not None:
                                                            return True

                                                        if self.vpn_distinguisher is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-process-instance-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.af_name is not None:
                                                        return True

                                                    if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                        return True

                                                    if self.label_fail is not None:
                                                        return True

                                                    if self.label_o_or_version is not None:
                                                        return True

                                                    if self.label_oor is not None:
                                                        return True

                                                    if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                        return True

                                                    if self.no_path is not None:
                                                        return True

                                                    if self.path_information is not None and self.path_information._has_data():
                                                        return True

                                                    if self.prefix_version is not None:
                                                        return True

                                                    if self.process_instance_id is not None:
                                                        return True

                                                    if self.route_distinguisher is not None:
                                                        return True

                                                    if self.source_route_distinguisher is not None:
                                                        return True

                                                    if self.source_vrf_name is not None:
                                                        return True

                                                    if self.srcaf_name is not None:
                                                        return True

                                                    if self.vrf_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath']['meta_info']


                                            class LocalPathElement(object):
                                                """
                                                Local path element list
                                                
                                                .. attribute:: is_perm_path_pelem
                                                
                                                	Pelem for permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: nhte_tunnel
                                                
                                                	NH TE tunnel information
                                                	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.NhteTunnel>`
                                                
                                                .. attribute:: pelem_flags
                                                
                                                	Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_gw_metric
                                                
                                                	Gateway metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_no_addpath_table_attr_version
                                                
                                                	No\-addpath Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_no_bestpath_table_attr_version
                                                
                                                	No\-bestpath Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_flags
                                                
                                                	Path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pelem_path_id
                                                
                                                	Local Path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_neighbor_addr
                                                
                                                	Path neighbor address
                                                	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr>`
                                                
                                                .. attribute:: pelem_path_nexthop
                                                
                                                	Path nexthop address
                                                	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop>`
                                                
                                                .. attribute:: pelem_path_peer_path_id
                                                
                                                	Path peer path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_table_attr_version
                                                
                                                	Path Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_table_attr_version
                                                
                                                	Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_version
                                                
                                                	Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_perm_path_pelem = None
                                                    self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.NhteTunnel()
                                                    self.nhte_tunnel.parent = self
                                                    self.pelem_flags = None
                                                    self.pelem_gw_metric = None
                                                    self.pelem_no_addpath_table_attr_version = None
                                                    self.pelem_no_bestpath_table_attr_version = None
                                                    self.pelem_path_flags = None
                                                    self.pelem_path_id = None
                                                    self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr()
                                                    self.pelem_path_neighbor_addr.parent = self
                                                    self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop()
                                                    self.pelem_path_nexthop.parent = self
                                                    self.pelem_path_peer_path_id = None
                                                    self.pelem_path_table_attr_version = None
                                                    self.pelem_table_attr_version = None
                                                    self.pelem_version = None


                                                class PelemPathNexthop(object):
                                                    """
                                                    Path nexthop address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-nexthop'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop']['meta_info']


                                                class NhteTunnel(object):
                                                    """
                                                    NH TE tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_te_tunnel
                                                    
                                                    	NH TE Tunnel info is present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last rib update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	tunnel name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	tunnel type
                                                    	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.binding_label = None
                                                        self.has_te_tunnel = None
                                                        self.is_tunnel_info_stale = None
                                                        self.is_tunnel_registered = None
                                                        self.is_tunnel_up = None
                                                        self.last_tunnel_update = None
                                                        self.tunnel_if_handle = None
                                                        self.tunnel_name = None
                                                        self.tunnel_type = None
                                                        self.tunnel_v6_enabled = None
                                                        self.tunnel_v6_required = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.binding_label is not None:
                                                            return True

                                                        if self.has_te_tunnel is not None:
                                                            return True

                                                        if self.is_tunnel_info_stale is not None:
                                                            return True

                                                        if self.is_tunnel_registered is not None:
                                                            return True

                                                        if self.is_tunnel_up is not None:
                                                            return True

                                                        if self.last_tunnel_update is not None:
                                                            return True

                                                        if self.tunnel_if_handle is not None:
                                                            return True

                                                        if self.tunnel_name is not None:
                                                            return True

                                                        if self.tunnel_type is not None:
                                                            return True

                                                        if self.tunnel_v6_enabled is not None:
                                                            return True

                                                        if self.tunnel_v6_required is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.NhteTunnel']['meta_info']


                                                class PelemPathNeighborAddr(object):
                                                    """
                                                    Path neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-neighbor-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-path-element'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_perm_path_pelem is not None:
                                                        return True

                                                    if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                        return True

                                                    if self.pelem_flags is not None:
                                                        return True

                                                    if self.pelem_gw_metric is not None:
                                                        return True

                                                    if self.pelem_no_addpath_table_attr_version is not None:
                                                        return True

                                                    if self.pelem_no_bestpath_table_attr_version is not None:
                                                        return True

                                                    if self.pelem_path_flags is not None:
                                                        return True

                                                    if self.pelem_path_id is not None:
                                                        return True

                                                    if self.pelem_path_neighbor_addr is not None and self.pelem_path_neighbor_addr._has_data():
                                                        return True

                                                    if self.pelem_path_nexthop is not None and self.pelem_path_nexthop._has_data():
                                                        return True

                                                    if self.pelem_path_peer_path_id is not None:
                                                        return True

                                                    if self.pelem_path_table_attr_version is not None:
                                                        return True

                                                    if self.pelem_table_attr_version is not None:
                                                        return True

                                                    if self.pelem_version is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement']['meta_info']


                                            class ActivePathElement(object):
                                                """
                                                Path element list received from Active inst
                                                
                                                .. attribute:: is_perm_path_pelem
                                                
                                                	Pelem for permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: nhte_tunnel
                                                
                                                	NH TE tunnel information
                                                	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.NhteTunnel>`
                                                
                                                .. attribute:: pelem_flags
                                                
                                                	Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_gw_metric
                                                
                                                	Gateway metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_no_addpath_table_attr_version
                                                
                                                	No\-addpath Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_no_bestpath_table_attr_version
                                                
                                                	No\-bestpath Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_flags
                                                
                                                	Path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pelem_path_id
                                                
                                                	Local Path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_neighbor_addr
                                                
                                                	Path neighbor address
                                                	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr>`
                                                
                                                .. attribute:: pelem_path_nexthop
                                                
                                                	Path nexthop address
                                                	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop>`
                                                
                                                .. attribute:: pelem_path_peer_path_id
                                                
                                                	Path peer path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_table_attr_version
                                                
                                                	Path Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_table_attr_version
                                                
                                                	Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_version
                                                
                                                	Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_perm_path_pelem = None
                                                    self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.NhteTunnel()
                                                    self.nhte_tunnel.parent = self
                                                    self.pelem_flags = None
                                                    self.pelem_gw_metric = None
                                                    self.pelem_no_addpath_table_attr_version = None
                                                    self.pelem_no_bestpath_table_attr_version = None
                                                    self.pelem_path_flags = None
                                                    self.pelem_path_id = None
                                                    self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr()
                                                    self.pelem_path_neighbor_addr.parent = self
                                                    self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop()
                                                    self.pelem_path_nexthop.parent = self
                                                    self.pelem_path_peer_path_id = None
                                                    self.pelem_path_table_attr_version = None
                                                    self.pelem_table_attr_version = None
                                                    self.pelem_version = None


                                                class PelemPathNexthop(object):
                                                    """
                                                    Path nexthop address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-nexthop'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop']['meta_info']


                                                class NhteTunnel(object):
                                                    """
                                                    NH TE tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_te_tunnel
                                                    
                                                    	NH TE Tunnel info is present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last rib update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	tunnel name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	tunnel type
                                                    	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.binding_label = None
                                                        self.has_te_tunnel = None
                                                        self.is_tunnel_info_stale = None
                                                        self.is_tunnel_registered = None
                                                        self.is_tunnel_up = None
                                                        self.last_tunnel_update = None
                                                        self.tunnel_if_handle = None
                                                        self.tunnel_name = None
                                                        self.tunnel_type = None
                                                        self.tunnel_v6_enabled = None
                                                        self.tunnel_v6_required = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.binding_label is not None:
                                                            return True

                                                        if self.has_te_tunnel is not None:
                                                            return True

                                                        if self.is_tunnel_info_stale is not None:
                                                            return True

                                                        if self.is_tunnel_registered is not None:
                                                            return True

                                                        if self.is_tunnel_up is not None:
                                                            return True

                                                        if self.last_tunnel_update is not None:
                                                            return True

                                                        if self.tunnel_if_handle is not None:
                                                            return True

                                                        if self.tunnel_name is not None:
                                                            return True

                                                        if self.tunnel_type is not None:
                                                            return True

                                                        if self.tunnel_v6_enabled is not None:
                                                            return True

                                                        if self.tunnel_v6_required is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.NhteTunnel']['meta_info']


                                                class PelemPathNeighborAddr(object):
                                                    """
                                                    Path neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-neighbor-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-path-element'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_perm_path_pelem is not None:
                                                        return True

                                                    if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                        return True

                                                    if self.pelem_flags is not None:
                                                        return True

                                                    if self.pelem_gw_metric is not None:
                                                        return True

                                                    if self.pelem_no_addpath_table_attr_version is not None:
                                                        return True

                                                    if self.pelem_no_bestpath_table_attr_version is not None:
                                                        return True

                                                    if self.pelem_path_flags is not None:
                                                        return True

                                                    if self.pelem_path_id is not None:
                                                        return True

                                                    if self.pelem_path_neighbor_addr is not None and self.pelem_path_neighbor_addr._has_data():
                                                        return True

                                                    if self.pelem_path_nexthop is not None and self.pelem_path_nexthop._has_data():
                                                        return True

                                                    if self.pelem_path_peer_path_id is not None:
                                                        return True

                                                    if self.pelem_path_table_attr_version is not None:
                                                        return True

                                                    if self.pelem_table_attr_version is not None:
                                                        return True

                                                    if self.pelem_version is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.rd is None:
                                                    raise YPYModelError('Key property rd is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-lookup-rd[Cisco-IOS-XR-ipv4-bgp-oper:rd = ' + str(self.rd) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.rd is not None:
                                                    return True

                                                if self.active_path_element is not None:
                                                    for child_ref in self.active_path_element:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.active_process_instance_path is not None:
                                                    for child_ref in self.active_process_instance_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.add_path_orr_bitfield is not None:
                                                    for child_ref in self.add_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.advertisedto_pe is not None:
                                                    return True

                                                if self.af_name is not None:
                                                    return True

                                                if self.best_path_orr_bitfield is not None:
                                                    for child_ref in self.best_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                    return True

                                                if self.bit is not None:
                                                    return True

                                                if self.flags is not None:
                                                    return True

                                                if self.gateway_array is not None:
                                                    return True

                                                if self.has_inconsistent_paths is not None:
                                                    return True

                                                if self.has_lbl_retained is not None:
                                                    return True

                                                if self.has_local_label is not None:
                                                    return True

                                                if self.is_net_aggregation_suppressed is not None:
                                                    return True

                                                if self.is_net_ldp_signaled is not None:
                                                    return True

                                                if self.is_permanent_network is not None:
                                                    return True

                                                if self.local_path_element is not None:
                                                    for child_ref in self.local_path_element:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_peers_advertised_to is not None:
                                                    for child_ref in self.local_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_process_instance_path is not None:
                                                    for child_ref in self.local_process_instance_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.net_backup_available is not None:
                                                    return True

                                                if self.net_backup_label_rewrite_available is not None:
                                                    return True

                                                if self.net_eibgp_multipath is not None:
                                                    return True

                                                if self.net_extended_flags is not None:
                                                    return True

                                                if self.net_flags is not None:
                                                    return True

                                                if self.net_local_label is not None:
                                                    return True

                                                if self.net_local_label_rewrite is not None:
                                                    return True

                                                if self.net_local_label_srgb is not None:
                                                    return True

                                                if self.net_multipath is not None:
                                                    return True

                                                if self.num_of_path is not None:
                                                    return True

                                                if self.pe_peers_advertised_to is not None:
                                                    for child_ref in self.pe_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.process_instance_id is not None:
                                                    return True

                                                if self.resilient_nexthop_set is not None:
                                                    return True

                                                if self.rib_failed is not None:
                                                    return True

                                                if self.route_distinguisher is not None:
                                                    return True

                                                if self.table_brib_version is not None:
                                                    return True

                                                if self.table_version is not None:
                                                    return True

                                                if self.version is not None:
                                                    return True

                                                if self.version_age is not None and self.version_age._has_data():
                                                    return True

                                                if self.version_timestamp is not None and self.version_timestamp._has_data():
                                                    return True

                                                if self.vrf_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-lookup-rds'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.network_lookup_rd is not None:
                                                for child_ref in self.network_lookup_rd:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.network_prefix is None:
                                            raise YPYModelError('Key property network_prefix is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-lookup-all-rd[Cisco-IOS-XR-ipv4-bgp-oper:network-prefix = ' + str(self.network_prefix) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.network_prefix is not None:
                                            return True

                                        if self.network_lookup_rds is not None and self.network_lookup_rds._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-lookup-all-rds'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.network_lookup_all_rd is not None:
                                        for child_ref in self.network_lookup_all_rd:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkLookupAllRds']['meta_info']


                            class Policies(object):
                                """
                                The BGP Policy Table
                                
                                .. attribute:: policy
                                
                                	A BGP Policy table entry
                                	**type**\: list of    :py:class:`Policy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.policy = YList()
                                    self.policy.parent = self
                                    self.policy.name = 'policy'


                                class Policy(object):
                                    """
                                    A BGP Policy table entry
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: attributes_after_policy_in
                                    
                                    	Attributes after inbound policy
                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn>`
                                    
                                    .. attribute:: attributes_after_policy_out
                                    
                                    	Attributes after outbound policy
                                    	**type**\:   :py:class:`AttributesAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut>`
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr>`
                                    
                                    .. attribute:: network
                                    
                                    	Network Prefix in Hex format
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: no_path
                                    
                                    	No path exists All 'sp\_path\_in' fields except 'sp\_path\_in\->bag\_prefix' are invalid.  All 'sp\_path\_out' fields are invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_info_after_policy_in
                                    
                                    	Path information after inbound policy
                                    	**type**\:   :py:class:`PathInfoAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn>`
                                    
                                    .. attribute:: path_info_after_policy_out
                                    
                                    	Path information after outbound policy
                                    	**type**\:   :py:class:`PathInfoAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_route_distinguisher
                                    
                                    	Source Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn()
                                        self.attributes_after_policy_in.parent = self
                                        self.attributes_after_policy_out = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut()
                                        self.attributes_after_policy_out.parent = self
                                        self.neighbor_address = None
                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr()
                                        self.neighbor_address_xr.parent = self
                                        self.network = None
                                        self.no_path = None
                                        self.path_info_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn()
                                        self.path_info_after_policy_in.parent = self
                                        self.path_info_after_policy_out = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut()
                                        self.path_info_after_policy_out.parent = self
                                        self.prefix_length = None
                                        self.rd = None
                                        self.route_distinguisher = None
                                        self.source_route_distinguisher = None
                                        self.vrf_name = None


                                    class NeighborAddressXr(object):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr']['meta_info']


                                    class PathInfoAfterPolicyIn(object):
                                        """
                                        Path information after inbound policy
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_own_self_originated_p_ath
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\:  bool
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield>`
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner>`
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix>`
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity>`
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\:  bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\:  bool
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr>`
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_esi
                                        
                                        	Path has EVPN ESI
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_rcvd_label
                                        
                                        	Path has received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\:  bool
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebg_ps
                                        
                                        	Not advertised to EBGPs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue>`
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2VpnEvpnEsi>`
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr>`
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue>`
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress>`
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop>`
                                        
                                        .. attribute:: nhte_tunnel
                                        
                                        	NH TE tunnel information
                                        	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhteTunnel>`
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\:  bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.accept_own_path = None
                                            self.accept_own_self_originated_p_ath = None
                                            self.add_path_orr_bitfield = YList()
                                            self.add_path_orr_bitfield.parent = self
                                            self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                            self.advertisedto_pe = None
                                            self.aigp_metric = None
                                            self.best_path_comp_stage = None
                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self.best_path_id = None
                                            self.best_path_id_comp_winner = None
                                            self.best_path_orr_bitfield = YList()
                                            self.best_path_orr_bitfield.parent = self
                                            self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self.dampen_penalty = None
                                            self.extended_community = YList()
                                            self.extended_community.parent = self
                                            self.extended_community.name = 'extended_community'
                                            self.fspec_invalid_path = None
                                            self.graceful_shutdown = None
                                            self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr()
                                            self.gw_addr.parent = self
                                            self.halflife_time = None
                                            self.has_esi = None
                                            self.has_gw_addr = None
                                            self.has_local_net_label = None
                                            self.has_mdt_group_addr = None
                                            self.has_mvpn_extcomm = None
                                            self.has_mvpn_nbr_addr = None
                                            self.has_mvpn_nexthop_addr = None
                                            self.has_mvpn_pmsi = None
                                            self.has_rcvd_label = None
                                            self.has_second_label = None
                                            self.ibgp_signaled_validity = None
                                            self.igp_metric = None
                                            self.is_aggregation_suppressed = None
                                            self.is_as_best = None
                                            self.is_best_path = None
                                            self.is_import_dampened = None
                                            self.is_import_suspect = None
                                            self.is_internal_path = None
                                            self.is_partial_best = None
                                            self.is_path_additional_path = None
                                            self.is_path_advertised_local_as_only = None
                                            self.is_path_af_install_eligible = None
                                            self.is_path_backup = None
                                            self.is_path_backup_protect_multipath = None
                                            self.is_path_best_external = None
                                            self.is_path_damped = None
                                            self.is_path_from_confederation_peer = None
                                            self.is_path_from_network_command = None
                                            self.is_path_from_redistribute_command = None
                                            self.is_path_from_route_reflector = None
                                            self.is_path_history_held = None
                                            self.is_path_imp_candidate = None
                                            self.is_path_imported = None
                                            self.is_path_local_aggregate = None
                                            self.is_path_locally_sourced = None
                                            self.is_path_long_lived_stale = None
                                            self.is_path_multipath = None
                                            self.is_path_nexthop_discarded = None
                                            self.is_path_not_advertised = None
                                            self.is_path_not_advertised_to_ebg_ps = None
                                            self.is_path_received_only = None
                                            self.is_path_reoriginated = None
                                            self.is_path_reoriginated_stitching = None
                                            self.is_path_stale = None
                                            self.is_path_synced_with_igp = None
                                            self.is_path_valid = None
                                            self.is_path_vpn_only = None
                                            self.is_permanent_path = None
                                            self.is_received_path_not_modified = None
                                            self.is_spkr_as_best = None
                                            self.l2vpn_circuit_status_value = YList()
                                            self.l2vpn_circuit_status_value.parent = self
                                            self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                            self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2VpnEvpnEsi()
                                            self.l2vpn_evpn_esi.parent = self
                                            self.l2vpn_size = None
                                            self.labeled_unicast_safi_path = None
                                            self.local_label = None
                                            self.local_nh = None
                                            self.local_path_id = None
                                            self.local_peers_advertised_to = YList()
                                            self.local_peers_advertised_to.parent = self
                                            self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                            self.maximum_suppress_time = None
                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self.mvpn_path_flags = None
                                            self.mvpn_pmsi_flags = None
                                            self.mvpn_pmsi_label = None
                                            self.mvpn_pmsi_type = None
                                            self.mvpn_pmsi_value = YList()
                                            self.mvpn_pmsi_value.parent = self
                                            self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                            self.mvpn_sfs_path = None
                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self.neighbor_router_id = None
                                            self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop()
                                            self.next_hop.parent = self
                                            self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhteTunnel()
                                            self.nhte_tunnel.parent = self
                                            self.path_flags = None
                                            self.path_flap_count = None
                                            self.path_import_flags = None
                                            self.path_rt_set_id = None
                                            self.path_rt_set_route_count = None
                                            self.path_table_version = None
                                            self.path_weight = None
                                            self.pe_peers_advertised_to = YList()
                                            self.pe_peers_advertised_to.parent = self
                                            self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                            self.rcvd_label = None
                                            self.rcvd_path_id = None
                                            self.reuse_value = None
                                            self.rib_failed = None
                                            self.route_type = None
                                            self.rpki_origin_as_validation_disabled = None
                                            self.rt_set_limit_enabled = None
                                            self.second_label = None
                                            self.seconds_since_first_flap = None
                                            self.show_rpki_origin_as_validity = None
                                            self.sn_rpki_origin_as_validity = None
                                            self.suppress_penalty = None
                                            self.time_to_unsuppress = None


                                        class BgpPrefix(object):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self.prefix_length = None


                                            class Prefix(object):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.prefix is not None and self.prefix._has_data():
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix']['meta_info']


                                        class NeighborAddress(object):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress']['meta_info']


                                        class NextHop(object):
                                            """
                                            Next hop
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop']['meta_info']


                                        class NhteTunnel(object):
                                            """
                                            NH TE tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_te_tunnel
                                            
                                            	NH TE Tunnel info is present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last rib update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	tunnel name
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	tunnel type
                                            	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.binding_label = None
                                                self.has_te_tunnel = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.is_tunnel_up = None
                                                self.last_tunnel_update = None
                                                self.tunnel_if_handle = None
                                                self.tunnel_name = None
                                                self.tunnel_type = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_v6_required = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.binding_label is not None:
                                                    return True

                                                if self.has_te_tunnel is not None:
                                                    return True

                                                if self.is_tunnel_info_stale is not None:
                                                    return True

                                                if self.is_tunnel_registered is not None:
                                                    return True

                                                if self.is_tunnel_up is not None:
                                                    return True

                                                if self.last_tunnel_update is not None:
                                                    return True

                                                if self.tunnel_if_handle is not None:
                                                    return True

                                                if self.tunnel_name is not None:
                                                    return True

                                                if self.tunnel_type is not None:
                                                    return True

                                                if self.tunnel_v6_enabled is not None:
                                                    return True

                                                if self.tunnel_v6_required is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhteTunnel']['meta_info']


                                        class MdtGroupAddr(object):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr']['meta_info']


                                        class L2VpnEvpnEsi(object):
                                            """
                                            L2VPN EVPN ESI
                                            
                                            .. attribute:: esi
                                            
                                            	esi
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.esi = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.esi is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2VpnEvpnEsi']['meta_info']


                                        class GwAddr(object):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.len = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.len is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr']['meta_info']


                                        class BestPathCompWinner(object):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner']['meta_info']


                                        class MvpnNbrAddr(object):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr']['meta_info']


                                        class MvpnNexthopAddr(object):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr']['meta_info']


                                        class L2VpnCircuitStatusValue(object):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue']['meta_info']


                                        class MvpnPmsiValue(object):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue']['meta_info']


                                        class ExtendedCommunity(object):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity']['meta_info']


                                        class LocalPeersAdvertisedTo(object):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo']['meta_info']


                                        class PePeersAdvertisedTo(object):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo']['meta_info']


                                        class BestPathOrrBitfield(object):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield']['meta_info']


                                        class AddPathOrrBitfield(object):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-info-after-policy-in'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.accept_own_path is not None:
                                                return True

                                            if self.accept_own_self_originated_p_ath is not None:
                                                return True

                                            if self.add_path_orr_bitfield is not None:
                                                for child_ref in self.add_path_orr_bitfield:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.advertisedto_pe is not None:
                                                return True

                                            if self.aigp_metric is not None:
                                                return True

                                            if self.best_path_comp_stage is not None:
                                                return True

                                            if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                return True

                                            if self.best_path_id is not None:
                                                return True

                                            if self.best_path_id_comp_winner is not None:
                                                return True

                                            if self.best_path_orr_bitfield is not None:
                                                for child_ref in self.best_path_orr_bitfield:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                return True

                                            if self.dampen_penalty is not None:
                                                return True

                                            if self.extended_community is not None:
                                                for child_ref in self.extended_community:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.fspec_invalid_path is not None:
                                                return True

                                            if self.graceful_shutdown is not None:
                                                return True

                                            if self.gw_addr is not None and self.gw_addr._has_data():
                                                return True

                                            if self.halflife_time is not None:
                                                return True

                                            if self.has_esi is not None:
                                                return True

                                            if self.has_gw_addr is not None:
                                                return True

                                            if self.has_local_net_label is not None:
                                                return True

                                            if self.has_mdt_group_addr is not None:
                                                return True

                                            if self.has_mvpn_extcomm is not None:
                                                return True

                                            if self.has_mvpn_nbr_addr is not None:
                                                return True

                                            if self.has_mvpn_nexthop_addr is not None:
                                                return True

                                            if self.has_mvpn_pmsi is not None:
                                                return True

                                            if self.has_rcvd_label is not None:
                                                return True

                                            if self.has_second_label is not None:
                                                return True

                                            if self.ibgp_signaled_validity is not None:
                                                return True

                                            if self.igp_metric is not None:
                                                return True

                                            if self.is_aggregation_suppressed is not None:
                                                return True

                                            if self.is_as_best is not None:
                                                return True

                                            if self.is_best_path is not None:
                                                return True

                                            if self.is_import_dampened is not None:
                                                return True

                                            if self.is_import_suspect is not None:
                                                return True

                                            if self.is_internal_path is not None:
                                                return True

                                            if self.is_partial_best is not None:
                                                return True

                                            if self.is_path_additional_path is not None:
                                                return True

                                            if self.is_path_advertised_local_as_only is not None:
                                                return True

                                            if self.is_path_af_install_eligible is not None:
                                                return True

                                            if self.is_path_backup is not None:
                                                return True

                                            if self.is_path_backup_protect_multipath is not None:
                                                return True

                                            if self.is_path_best_external is not None:
                                                return True

                                            if self.is_path_damped is not None:
                                                return True

                                            if self.is_path_from_confederation_peer is not None:
                                                return True

                                            if self.is_path_from_network_command is not None:
                                                return True

                                            if self.is_path_from_redistribute_command is not None:
                                                return True

                                            if self.is_path_from_route_reflector is not None:
                                                return True

                                            if self.is_path_history_held is not None:
                                                return True

                                            if self.is_path_imp_candidate is not None:
                                                return True

                                            if self.is_path_imported is not None:
                                                return True

                                            if self.is_path_local_aggregate is not None:
                                                return True

                                            if self.is_path_locally_sourced is not None:
                                                return True

                                            if self.is_path_long_lived_stale is not None:
                                                return True

                                            if self.is_path_multipath is not None:
                                                return True

                                            if self.is_path_nexthop_discarded is not None:
                                                return True

                                            if self.is_path_not_advertised is not None:
                                                return True

                                            if self.is_path_not_advertised_to_ebg_ps is not None:
                                                return True

                                            if self.is_path_received_only is not None:
                                                return True

                                            if self.is_path_reoriginated is not None:
                                                return True

                                            if self.is_path_reoriginated_stitching is not None:
                                                return True

                                            if self.is_path_stale is not None:
                                                return True

                                            if self.is_path_synced_with_igp is not None:
                                                return True

                                            if self.is_path_valid is not None:
                                                return True

                                            if self.is_path_vpn_only is not None:
                                                return True

                                            if self.is_permanent_path is not None:
                                                return True

                                            if self.is_received_path_not_modified is not None:
                                                return True

                                            if self.is_spkr_as_best is not None:
                                                return True

                                            if self.l2vpn_circuit_status_value is not None:
                                                for child_ref in self.l2vpn_circuit_status_value:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                return True

                                            if self.l2vpn_size is not None:
                                                return True

                                            if self.labeled_unicast_safi_path is not None:
                                                return True

                                            if self.local_label is not None:
                                                return True

                                            if self.local_nh is not None:
                                                return True

                                            if self.local_path_id is not None:
                                                return True

                                            if self.local_peers_advertised_to is not None:
                                                for child_ref in self.local_peers_advertised_to:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.maximum_suppress_time is not None:
                                                return True

                                            if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                return True

                                            if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                return True

                                            if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                return True

                                            if self.mvpn_path_flags is not None:
                                                return True

                                            if self.mvpn_pmsi_flags is not None:
                                                return True

                                            if self.mvpn_pmsi_label is not None:
                                                return True

                                            if self.mvpn_pmsi_type is not None:
                                                return True

                                            if self.mvpn_pmsi_value is not None:
                                                for child_ref in self.mvpn_pmsi_value:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.mvpn_sfs_path is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            if self.neighbor_router_id is not None:
                                                return True

                                            if self.next_hop is not None and self.next_hop._has_data():
                                                return True

                                            if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                return True

                                            if self.path_flags is not None:
                                                return True

                                            if self.path_flap_count is not None:
                                                return True

                                            if self.path_import_flags is not None:
                                                return True

                                            if self.path_rt_set_id is not None:
                                                return True

                                            if self.path_rt_set_route_count is not None:
                                                return True

                                            if self.path_table_version is not None:
                                                return True

                                            if self.path_weight is not None:
                                                return True

                                            if self.pe_peers_advertised_to is not None:
                                                for child_ref in self.pe_peers_advertised_to:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.rcvd_label is not None:
                                                return True

                                            if self.rcvd_path_id is not None:
                                                return True

                                            if self.reuse_value is not None:
                                                return True

                                            if self.rib_failed is not None:
                                                return True

                                            if self.route_type is not None:
                                                return True

                                            if self.rpki_origin_as_validation_disabled is not None:
                                                return True

                                            if self.rt_set_limit_enabled is not None:
                                                return True

                                            if self.second_label is not None:
                                                return True

                                            if self.seconds_since_first_flap is not None:
                                                return True

                                            if self.show_rpki_origin_as_validity is not None:
                                                return True

                                            if self.sn_rpki_origin_as_validity is not None:
                                                return True

                                            if self.suppress_penalty is not None:
                                                return True

                                            if self.time_to_unsuppress is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn']['meta_info']


                                    class PathInfoAfterPolicyOut(object):
                                        """
                                        Path information after outbound policy
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_own_self_originated_p_ath
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\:  bool
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield>`
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner>`
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix>`
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity>`
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\:  bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\:  bool
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr>`
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_esi
                                        
                                        	Path has EVPN ESI
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_rcvd_label
                                        
                                        	Path has received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\:  bool
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebg_ps
                                        
                                        	Not advertised to EBGPs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue>`
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2VpnEvpnEsi>`
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr>`
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue>`
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress>`
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop>`
                                        
                                        .. attribute:: nhte_tunnel
                                        
                                        	NH TE tunnel information
                                        	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhteTunnel>`
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\:  bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.accept_own_path = None
                                            self.accept_own_self_originated_p_ath = None
                                            self.add_path_orr_bitfield = YList()
                                            self.add_path_orr_bitfield.parent = self
                                            self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                            self.advertisedto_pe = None
                                            self.aigp_metric = None
                                            self.best_path_comp_stage = None
                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self.best_path_id = None
                                            self.best_path_id_comp_winner = None
                                            self.best_path_orr_bitfield = YList()
                                            self.best_path_orr_bitfield.parent = self
                                            self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self.dampen_penalty = None
                                            self.extended_community = YList()
                                            self.extended_community.parent = self
                                            self.extended_community.name = 'extended_community'
                                            self.fspec_invalid_path = None
                                            self.graceful_shutdown = None
                                            self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr()
                                            self.gw_addr.parent = self
                                            self.halflife_time = None
                                            self.has_esi = None
                                            self.has_gw_addr = None
                                            self.has_local_net_label = None
                                            self.has_mdt_group_addr = None
                                            self.has_mvpn_extcomm = None
                                            self.has_mvpn_nbr_addr = None
                                            self.has_mvpn_nexthop_addr = None
                                            self.has_mvpn_pmsi = None
                                            self.has_rcvd_label = None
                                            self.has_second_label = None
                                            self.ibgp_signaled_validity = None
                                            self.igp_metric = None
                                            self.is_aggregation_suppressed = None
                                            self.is_as_best = None
                                            self.is_best_path = None
                                            self.is_import_dampened = None
                                            self.is_import_suspect = None
                                            self.is_internal_path = None
                                            self.is_partial_best = None
                                            self.is_path_additional_path = None
                                            self.is_path_advertised_local_as_only = None
                                            self.is_path_af_install_eligible = None
                                            self.is_path_backup = None
                                            self.is_path_backup_protect_multipath = None
                                            self.is_path_best_external = None
                                            self.is_path_damped = None
                                            self.is_path_from_confederation_peer = None
                                            self.is_path_from_network_command = None
                                            self.is_path_from_redistribute_command = None
                                            self.is_path_from_route_reflector = None
                                            self.is_path_history_held = None
                                            self.is_path_imp_candidate = None
                                            self.is_path_imported = None
                                            self.is_path_local_aggregate = None
                                            self.is_path_locally_sourced = None
                                            self.is_path_long_lived_stale = None
                                            self.is_path_multipath = None
                                            self.is_path_nexthop_discarded = None
                                            self.is_path_not_advertised = None
                                            self.is_path_not_advertised_to_ebg_ps = None
                                            self.is_path_received_only = None
                                            self.is_path_reoriginated = None
                                            self.is_path_reoriginated_stitching = None
                                            self.is_path_stale = None
                                            self.is_path_synced_with_igp = None
                                            self.is_path_valid = None
                                            self.is_path_vpn_only = None
                                            self.is_permanent_path = None
                                            self.is_received_path_not_modified = None
                                            self.is_spkr_as_best = None
                                            self.l2vpn_circuit_status_value = YList()
                                            self.l2vpn_circuit_status_value.parent = self
                                            self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                            self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2VpnEvpnEsi()
                                            self.l2vpn_evpn_esi.parent = self
                                            self.l2vpn_size = None
                                            self.labeled_unicast_safi_path = None
                                            self.local_label = None
                                            self.local_nh = None
                                            self.local_path_id = None
                                            self.local_peers_advertised_to = YList()
                                            self.local_peers_advertised_to.parent = self
                                            self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                            self.maximum_suppress_time = None
                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self.mvpn_path_flags = None
                                            self.mvpn_pmsi_flags = None
                                            self.mvpn_pmsi_label = None
                                            self.mvpn_pmsi_type = None
                                            self.mvpn_pmsi_value = YList()
                                            self.mvpn_pmsi_value.parent = self
                                            self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                            self.mvpn_sfs_path = None
                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self.neighbor_router_id = None
                                            self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop()
                                            self.next_hop.parent = self
                                            self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhteTunnel()
                                            self.nhte_tunnel.parent = self
                                            self.path_flags = None
                                            self.path_flap_count = None
                                            self.path_import_flags = None
                                            self.path_rt_set_id = None
                                            self.path_rt_set_route_count = None
                                            self.path_table_version = None
                                            self.path_weight = None
                                            self.pe_peers_advertised_to = YList()
                                            self.pe_peers_advertised_to.parent = self
                                            self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                            self.rcvd_label = None
                                            self.rcvd_path_id = None
                                            self.reuse_value = None
                                            self.rib_failed = None
                                            self.route_type = None
                                            self.rpki_origin_as_validation_disabled = None
                                            self.rt_set_limit_enabled = None
                                            self.second_label = None
                                            self.seconds_since_first_flap = None
                                            self.show_rpki_origin_as_validity = None
                                            self.sn_rpki_origin_as_validity = None
                                            self.suppress_penalty = None
                                            self.time_to_unsuppress = None


                                        class BgpPrefix(object):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self.prefix_length = None


                                            class Prefix(object):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.prefix is not None and self.prefix._has_data():
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix']['meta_info']


                                        class NeighborAddress(object):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress']['meta_info']


                                        class NextHop(object):
                                            """
                                            Next hop
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop']['meta_info']


                                        class NhteTunnel(object):
                                            """
                                            NH TE tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_te_tunnel
                                            
                                            	NH TE Tunnel info is present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last rib update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	tunnel name
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	tunnel type
                                            	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.binding_label = None
                                                self.has_te_tunnel = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.is_tunnel_up = None
                                                self.last_tunnel_update = None
                                                self.tunnel_if_handle = None
                                                self.tunnel_name = None
                                                self.tunnel_type = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_v6_required = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.binding_label is not None:
                                                    return True

                                                if self.has_te_tunnel is not None:
                                                    return True

                                                if self.is_tunnel_info_stale is not None:
                                                    return True

                                                if self.is_tunnel_registered is not None:
                                                    return True

                                                if self.is_tunnel_up is not None:
                                                    return True

                                                if self.last_tunnel_update is not None:
                                                    return True

                                                if self.tunnel_if_handle is not None:
                                                    return True

                                                if self.tunnel_name is not None:
                                                    return True

                                                if self.tunnel_type is not None:
                                                    return True

                                                if self.tunnel_v6_enabled is not None:
                                                    return True

                                                if self.tunnel_v6_required is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhteTunnel']['meta_info']


                                        class MdtGroupAddr(object):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr']['meta_info']


                                        class L2VpnEvpnEsi(object):
                                            """
                                            L2VPN EVPN ESI
                                            
                                            .. attribute:: esi
                                            
                                            	esi
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.esi = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.esi is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2VpnEvpnEsi']['meta_info']


                                        class GwAddr(object):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.len = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.len is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr']['meta_info']


                                        class BestPathCompWinner(object):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner']['meta_info']


                                        class MvpnNbrAddr(object):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr']['meta_info']


                                        class MvpnNexthopAddr(object):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr']['meta_info']


                                        class L2VpnCircuitStatusValue(object):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue']['meta_info']


                                        class MvpnPmsiValue(object):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue']['meta_info']


                                        class ExtendedCommunity(object):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity']['meta_info']


                                        class LocalPeersAdvertisedTo(object):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo']['meta_info']


                                        class PePeersAdvertisedTo(object):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo']['meta_info']


                                        class BestPathOrrBitfield(object):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield']['meta_info']


                                        class AddPathOrrBitfield(object):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-info-after-policy-out'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.accept_own_path is not None:
                                                return True

                                            if self.accept_own_self_originated_p_ath is not None:
                                                return True

                                            if self.add_path_orr_bitfield is not None:
                                                for child_ref in self.add_path_orr_bitfield:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.advertisedto_pe is not None:
                                                return True

                                            if self.aigp_metric is not None:
                                                return True

                                            if self.best_path_comp_stage is not None:
                                                return True

                                            if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                return True

                                            if self.best_path_id is not None:
                                                return True

                                            if self.best_path_id_comp_winner is not None:
                                                return True

                                            if self.best_path_orr_bitfield is not None:
                                                for child_ref in self.best_path_orr_bitfield:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                return True

                                            if self.dampen_penalty is not None:
                                                return True

                                            if self.extended_community is not None:
                                                for child_ref in self.extended_community:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.fspec_invalid_path is not None:
                                                return True

                                            if self.graceful_shutdown is not None:
                                                return True

                                            if self.gw_addr is not None and self.gw_addr._has_data():
                                                return True

                                            if self.halflife_time is not None:
                                                return True

                                            if self.has_esi is not None:
                                                return True

                                            if self.has_gw_addr is not None:
                                                return True

                                            if self.has_local_net_label is not None:
                                                return True

                                            if self.has_mdt_group_addr is not None:
                                                return True

                                            if self.has_mvpn_extcomm is not None:
                                                return True

                                            if self.has_mvpn_nbr_addr is not None:
                                                return True

                                            if self.has_mvpn_nexthop_addr is not None:
                                                return True

                                            if self.has_mvpn_pmsi is not None:
                                                return True

                                            if self.has_rcvd_label is not None:
                                                return True

                                            if self.has_second_label is not None:
                                                return True

                                            if self.ibgp_signaled_validity is not None:
                                                return True

                                            if self.igp_metric is not None:
                                                return True

                                            if self.is_aggregation_suppressed is not None:
                                                return True

                                            if self.is_as_best is not None:
                                                return True

                                            if self.is_best_path is not None:
                                                return True

                                            if self.is_import_dampened is not None:
                                                return True

                                            if self.is_import_suspect is not None:
                                                return True

                                            if self.is_internal_path is not None:
                                                return True

                                            if self.is_partial_best is not None:
                                                return True

                                            if self.is_path_additional_path is not None:
                                                return True

                                            if self.is_path_advertised_local_as_only is not None:
                                                return True

                                            if self.is_path_af_install_eligible is not None:
                                                return True

                                            if self.is_path_backup is not None:
                                                return True

                                            if self.is_path_backup_protect_multipath is not None:
                                                return True

                                            if self.is_path_best_external is not None:
                                                return True

                                            if self.is_path_damped is not None:
                                                return True

                                            if self.is_path_from_confederation_peer is not None:
                                                return True

                                            if self.is_path_from_network_command is not None:
                                                return True

                                            if self.is_path_from_redistribute_command is not None:
                                                return True

                                            if self.is_path_from_route_reflector is not None:
                                                return True

                                            if self.is_path_history_held is not None:
                                                return True

                                            if self.is_path_imp_candidate is not None:
                                                return True

                                            if self.is_path_imported is not None:
                                                return True

                                            if self.is_path_local_aggregate is not None:
                                                return True

                                            if self.is_path_locally_sourced is not None:
                                                return True

                                            if self.is_path_long_lived_stale is not None:
                                                return True

                                            if self.is_path_multipath is not None:
                                                return True

                                            if self.is_path_nexthop_discarded is not None:
                                                return True

                                            if self.is_path_not_advertised is not None:
                                                return True

                                            if self.is_path_not_advertised_to_ebg_ps is not None:
                                                return True

                                            if self.is_path_received_only is not None:
                                                return True

                                            if self.is_path_reoriginated is not None:
                                                return True

                                            if self.is_path_reoriginated_stitching is not None:
                                                return True

                                            if self.is_path_stale is not None:
                                                return True

                                            if self.is_path_synced_with_igp is not None:
                                                return True

                                            if self.is_path_valid is not None:
                                                return True

                                            if self.is_path_vpn_only is not None:
                                                return True

                                            if self.is_permanent_path is not None:
                                                return True

                                            if self.is_received_path_not_modified is not None:
                                                return True

                                            if self.is_spkr_as_best is not None:
                                                return True

                                            if self.l2vpn_circuit_status_value is not None:
                                                for child_ref in self.l2vpn_circuit_status_value:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                return True

                                            if self.l2vpn_size is not None:
                                                return True

                                            if self.labeled_unicast_safi_path is not None:
                                                return True

                                            if self.local_label is not None:
                                                return True

                                            if self.local_nh is not None:
                                                return True

                                            if self.local_path_id is not None:
                                                return True

                                            if self.local_peers_advertised_to is not None:
                                                for child_ref in self.local_peers_advertised_to:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.maximum_suppress_time is not None:
                                                return True

                                            if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                return True

                                            if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                return True

                                            if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                return True

                                            if self.mvpn_path_flags is not None:
                                                return True

                                            if self.mvpn_pmsi_flags is not None:
                                                return True

                                            if self.mvpn_pmsi_label is not None:
                                                return True

                                            if self.mvpn_pmsi_type is not None:
                                                return True

                                            if self.mvpn_pmsi_value is not None:
                                                for child_ref in self.mvpn_pmsi_value:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.mvpn_sfs_path is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            if self.neighbor_router_id is not None:
                                                return True

                                            if self.next_hop is not None and self.next_hop._has_data():
                                                return True

                                            if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                return True

                                            if self.path_flags is not None:
                                                return True

                                            if self.path_flap_count is not None:
                                                return True

                                            if self.path_import_flags is not None:
                                                return True

                                            if self.path_rt_set_id is not None:
                                                return True

                                            if self.path_rt_set_route_count is not None:
                                                return True

                                            if self.path_table_version is not None:
                                                return True

                                            if self.path_weight is not None:
                                                return True

                                            if self.pe_peers_advertised_to is not None:
                                                for child_ref in self.pe_peers_advertised_to:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.rcvd_label is not None:
                                                return True

                                            if self.rcvd_path_id is not None:
                                                return True

                                            if self.reuse_value is not None:
                                                return True

                                            if self.rib_failed is not None:
                                                return True

                                            if self.route_type is not None:
                                                return True

                                            if self.rpki_origin_as_validation_disabled is not None:
                                                return True

                                            if self.rt_set_limit_enabled is not None:
                                                return True

                                            if self.second_label is not None:
                                                return True

                                            if self.seconds_since_first_flap is not None:
                                                return True

                                            if self.show_rpki_origin_as_validity is not None:
                                                return True

                                            if self.sn_rpki_origin_as_validity is not None:
                                                return True

                                            if self.suppress_penalty is not None:
                                                return True

                                            if self.time_to_unsuppress is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut']['meta_info']


                                    class AttributesAfterPolicyIn(object):
                                        """
                                        Attributes after inbound policy
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet>`
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes>`
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp>`
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr>`
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\:  bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet()
                                            self.attr_set.parent = self
                                            self.attribute_key_number = None
                                            self.attribute_reuse_id_config = None
                                            self.attribute_reuse_id_current = None
                                            self.attribute_reuse_id_keys = None
                                            self.attribute_reuse_id_max_id = None
                                            self.attribute_reuse_id_node = None
                                            self.attribute_reuse_id_recover_sec = None
                                            self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self.is_application_gateway_present = None
                                            self.is_as_path2_byte = None
                                            self.is_attr_set_present = None
                                            self.is_ribrnh_present = None
                                            self.is_rnh_present = None
                                            self.ribrnh_encap = None
                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self.ribrnh_mac = None
                                            self.ribrnh_table = None
                                            self.ribrnh_vni = None
                                            self.ribrnhip_table = None
                                            self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self.rnh_addr_len = None
                                            self.rnh_len = None
                                            self.rnh_type = None
                                            self.set_aigp_inbound_igp = None
                                            self.set_aigp_inbound_metric = None
                                            self.vpn_distinguisher = None


                                        class CommonAttributes(object):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_encap_present
                                            
                                            	Tunnel Encap attribute present 
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_policy_allocated_binding_sid
                                            
                                            	SR Policy allocated Binding sid by the router
                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                            
                                            .. attribute:: sr_policy_binding_sid
                                            
                                            	SR Policy Binding sid
                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                            
                                            .. attribute:: sr_policy_explicit_path
                                            
                                            	SR Policy Explicit paths
                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                            
                                            .. attribute:: sr_policy_preference
                                            
                                            	SR Policy Preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_tunnel_request_state
                                            
                                            	SR Tunnel Request State
                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                            
                                            .. attribute:: sr_tunnel_state
                                            
                                            	SR Tunnel State
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap_type
                                            
                                            	Tunnel Encap Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.aggregator_address = None
                                                self.aggregator_as = None
                                                self.aigp_metric_value = None
                                                self.as_path = None
                                                self.cluster = YList()
                                                self.cluster.parent = self
                                                self.cluster.name = 'cluster'
                                                self.community = YList()
                                                self.community.parent = self
                                                self.community.name = 'community'
                                                self.connector_type = None
                                                self.connector_value = YList()
                                                self.connector_value.parent = self
                                                self.connector_value.name = 'connector_value'
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.extended_community_flags = None
                                                self.is_aggregator_present = None
                                                self.is_aigp_present = None
                                                self.is_as_path_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_community_present = None
                                                self.is_connector_present = None
                                                self.is_extended_community_present = None
                                                self.is_label_index_present = None
                                                self.is_local_pref_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_metric_present = None
                                                self.is_origin_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_ssa_present = None
                                                self.is_tunnel_encap_present = None
                                                self.l2tpv3_cookie = YList()
                                                self.l2tpv3_cookie.parent = self
                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                self.l2tpv3_session_id = None
                                                self.label_index_attr = YList()
                                                self.label_index_attr.parent = self
                                                self.label_index_attr.name = 'label_index_attr'
                                                self.local_preference = None
                                                self.ls_attr = YList()
                                                self.ls_attr.parent = self
                                                self.ls_attr.name = 'ls_attr'
                                                self.metric = None
                                                self.neighbor_as = None
                                                self.origin = None
                                                self.originator = None
                                                self.pe_distinguisher_label = YList()
                                                self.pe_distinguisher_label.parent = self
                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.pmsi_type = None
                                                self.pmsi_value = YList()
                                                self.pmsi_value.parent = self
                                                self.pmsi_value.name = 'pmsi_value'
                                                self.ppm_pvalue = None
                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                self.sr_policy_allocated_binding_sid.parent = self
                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                self.sr_policy_binding_sid.parent = self
                                                self.sr_policy_explicit_path = YList()
                                                self.sr_policy_explicit_path.parent = self
                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                self.sr_policy_preference = None
                                                self.sr_tunnel_request_state = None
                                                self.sr_tunnel_state = None
                                                self.tunnel_encap_type = None
                                                self.unknown_attribute = YList()
                                                self.unknown_attribute.parent = self
                                                self.unknown_attribute.name = 'unknown_attribute'


                                            class SrPolicyBindingSid(object):
                                                """
                                                SR Policy Binding sid
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                            class SrPolicyAllocatedBindingSid(object):
                                                """
                                                SR Policy allocated Binding sid by the router
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                            class Community(object):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                            class UnknownAttribute(object):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                            class Cluster(object):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                            class L2Tpv3Cookie(object):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                            class ConnectorValue(object):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                            class PmsiValue(object):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                            class LsAttr(object):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                            class LabelIndexAttr(object):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                            class PeDistinguisherLabel(object):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.label = None
                                                    self.pe_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.label is not None:
                                                        return True

                                                    if self.pe_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                            class SrPolicyExplicitPath(object):
                                                """
                                                SR Policy Explicit paths
                                                
                                                .. attribute:: sid
                                                
                                                	Sidlist for explicit path
                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                
                                                .. attribute:: weight
                                                
                                                	Weight of explicit path
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.sid = YList()
                                                    self.sid.parent = self
                                                    self.sid.name = 'sid'
                                                    self.weight = None


                                                class Sid(object):
                                                    """
                                                    Sidlist for explicit path
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IP Address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label sid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Sid Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4 is not None:
                                                            return True

                                                        if self.ipv6 is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.sid is not None:
                                                        for child_ref in self.sid:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.weight is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.aggregator_address is not None:
                                                    return True

                                                if self.aggregator_as is not None:
                                                    return True

                                                if self.aigp_metric_value is not None:
                                                    return True

                                                if self.as_path is not None:
                                                    return True

                                                if self.cluster is not None:
                                                    for child_ref in self.cluster:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.community is not None:
                                                    for child_ref in self.community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.connector_type is not None:
                                                    return True

                                                if self.connector_value is not None:
                                                    for child_ref in self.connector_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community_flags is not None:
                                                    return True

                                                if self.is_aggregator_present is not None:
                                                    return True

                                                if self.is_aigp_present is not None:
                                                    return True

                                                if self.is_as_path_present is not None:
                                                    return True

                                                if self.is_atomic_aggregate_present is not None:
                                                    return True

                                                if self.is_community_present is not None:
                                                    return True

                                                if self.is_connector_present is not None:
                                                    return True

                                                if self.is_extended_community_present is not None:
                                                    return True

                                                if self.is_label_index_present is not None:
                                                    return True

                                                if self.is_local_pref_present is not None:
                                                    return True

                                                if self.is_ls_attribute_present is not None:
                                                    return True

                                                if self.is_metric_present is not None:
                                                    return True

                                                if self.is_origin_present is not None:
                                                    return True

                                                if self.is_pe_distinguisher_label_present is not None:
                                                    return True

                                                if self.is_pmsi_present is not None:
                                                    return True

                                                if self.is_pppmp_present is not None:
                                                    return True

                                                if self.is_ssa_present is not None:
                                                    return True

                                                if self.is_tunnel_encap_present is not None:
                                                    return True

                                                if self.l2tpv3_cookie is not None:
                                                    for child_ref in self.l2tpv3_cookie:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2tpv3_session_id is not None:
                                                    return True

                                                if self.label_index_attr is not None:
                                                    for child_ref in self.label_index_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_preference is not None:
                                                    return True

                                                if self.ls_attr is not None:
                                                    for child_ref in self.ls_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.metric is not None:
                                                    return True

                                                if self.neighbor_as is not None:
                                                    return True

                                                if self.origin is not None:
                                                    return True

                                                if self.originator is not None:
                                                    return True

                                                if self.pe_distinguisher_label is not None:
                                                    for child_ref in self.pe_distinguisher_label:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.pmsi_flags is not None:
                                                    return True

                                                if self.pmsi_label is not None:
                                                    return True

                                                if self.pmsi_type is not None:
                                                    return True

                                                if self.pmsi_value is not None:
                                                    for child_ref in self.pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.ppm_pvalue is not None:
                                                    return True

                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_explicit_path is not None:
                                                    for child_ref in self.sr_policy_explicit_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.sr_policy_preference is not None:
                                                    return True

                                                if self.sr_tunnel_request_state is not None:
                                                    return True

                                                if self.sr_tunnel_state is not None:
                                                    return True

                                                if self.tunnel_encap_type is not None:
                                                    return True

                                                if self.unknown_attribute is not None:
                                                    for child_ref in self.unknown_attribute:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                        class AttrSet(object):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_encap_present
                                            
                                            	Tunnel Encap attribute present 
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_policy_allocated_binding_sid
                                            
                                            	SR Policy allocated Binding sid by the router
                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                            
                                            .. attribute:: sr_policy_binding_sid
                                            
                                            	SR Policy Binding sid
                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                            
                                            .. attribute:: sr_policy_explicit_path
                                            
                                            	SR Policy Explicit paths
                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                            
                                            .. attribute:: sr_policy_preference
                                            
                                            	SR Policy Preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_tunnel_request_state
                                            
                                            	SR Tunnel Request State
                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                            
                                            .. attribute:: sr_tunnel_state
                                            
                                            	SR Tunnel State
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap_type
                                            
                                            	Tunnel Encap Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.aggregator_address = None
                                                self.aggregator_as = None
                                                self.aigp_metric_value = None
                                                self.as_path = None
                                                self.cluster = YList()
                                                self.cluster.parent = self
                                                self.cluster.name = 'cluster'
                                                self.community = YList()
                                                self.community.parent = self
                                                self.community.name = 'community'
                                                self.connector_type = None
                                                self.connector_value = YList()
                                                self.connector_value.parent = self
                                                self.connector_value.name = 'connector_value'
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.extended_community_flags = None
                                                self.is_aggregator_present = None
                                                self.is_aigp_present = None
                                                self.is_as_path_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_community_present = None
                                                self.is_connector_present = None
                                                self.is_extended_community_present = None
                                                self.is_label_index_present = None
                                                self.is_local_pref_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_metric_present = None
                                                self.is_origin_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_ssa_present = None
                                                self.is_tunnel_encap_present = None
                                                self.l2tpv3_cookie = YList()
                                                self.l2tpv3_cookie.parent = self
                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                self.l2tpv3_session_id = None
                                                self.label_index_attr = YList()
                                                self.label_index_attr.parent = self
                                                self.label_index_attr.name = 'label_index_attr'
                                                self.local_preference = None
                                                self.ls_attr = YList()
                                                self.ls_attr.parent = self
                                                self.ls_attr.name = 'ls_attr'
                                                self.metric = None
                                                self.neighbor_as = None
                                                self.origin = None
                                                self.originator = None
                                                self.pe_distinguisher_label = YList()
                                                self.pe_distinguisher_label.parent = self
                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.pmsi_type = None
                                                self.pmsi_value = YList()
                                                self.pmsi_value.parent = self
                                                self.pmsi_value.name = 'pmsi_value'
                                                self.ppm_pvalue = None
                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                self.sr_policy_allocated_binding_sid.parent = self
                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                self.sr_policy_binding_sid.parent = self
                                                self.sr_policy_explicit_path = YList()
                                                self.sr_policy_explicit_path.parent = self
                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                self.sr_policy_preference = None
                                                self.sr_tunnel_request_state = None
                                                self.sr_tunnel_state = None
                                                self.tunnel_encap_type = None
                                                self.unknown_attribute = YList()
                                                self.unknown_attribute.parent = self
                                                self.unknown_attribute.name = 'unknown_attribute'


                                            class SrPolicyBindingSid(object):
                                                """
                                                SR Policy Binding sid
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                            class SrPolicyAllocatedBindingSid(object):
                                                """
                                                SR Policy allocated Binding sid by the router
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                            class Community(object):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                            class UnknownAttribute(object):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                            class Cluster(object):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                            class L2Tpv3Cookie(object):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                            class ConnectorValue(object):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                            class PmsiValue(object):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                            class LsAttr(object):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                            class LabelIndexAttr(object):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                            class PeDistinguisherLabel(object):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.label = None
                                                    self.pe_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.label is not None:
                                                        return True

                                                    if self.pe_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                            class SrPolicyExplicitPath(object):
                                                """
                                                SR Policy Explicit paths
                                                
                                                .. attribute:: sid
                                                
                                                	Sidlist for explicit path
                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                
                                                .. attribute:: weight
                                                
                                                	Weight of explicit path
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.sid = YList()
                                                    self.sid.parent = self
                                                    self.sid.name = 'sid'
                                                    self.weight = None


                                                class Sid(object):
                                                    """
                                                    Sidlist for explicit path
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IP Address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label sid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Sid Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4 is not None:
                                                            return True

                                                        if self.ipv6 is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.sid is not None:
                                                        for child_ref in self.sid:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.weight is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.aggregator_address is not None:
                                                    return True

                                                if self.aggregator_as is not None:
                                                    return True

                                                if self.aigp_metric_value is not None:
                                                    return True

                                                if self.as_path is not None:
                                                    return True

                                                if self.cluster is not None:
                                                    for child_ref in self.cluster:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.community is not None:
                                                    for child_ref in self.community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.connector_type is not None:
                                                    return True

                                                if self.connector_value is not None:
                                                    for child_ref in self.connector_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community_flags is not None:
                                                    return True

                                                if self.is_aggregator_present is not None:
                                                    return True

                                                if self.is_aigp_present is not None:
                                                    return True

                                                if self.is_as_path_present is not None:
                                                    return True

                                                if self.is_atomic_aggregate_present is not None:
                                                    return True

                                                if self.is_community_present is not None:
                                                    return True

                                                if self.is_connector_present is not None:
                                                    return True

                                                if self.is_extended_community_present is not None:
                                                    return True

                                                if self.is_label_index_present is not None:
                                                    return True

                                                if self.is_local_pref_present is not None:
                                                    return True

                                                if self.is_ls_attribute_present is not None:
                                                    return True

                                                if self.is_metric_present is not None:
                                                    return True

                                                if self.is_origin_present is not None:
                                                    return True

                                                if self.is_pe_distinguisher_label_present is not None:
                                                    return True

                                                if self.is_pmsi_present is not None:
                                                    return True

                                                if self.is_pppmp_present is not None:
                                                    return True

                                                if self.is_ssa_present is not None:
                                                    return True

                                                if self.is_tunnel_encap_present is not None:
                                                    return True

                                                if self.l2tpv3_cookie is not None:
                                                    for child_ref in self.l2tpv3_cookie:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2tpv3_session_id is not None:
                                                    return True

                                                if self.label_index_attr is not None:
                                                    for child_ref in self.label_index_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_preference is not None:
                                                    return True

                                                if self.ls_attr is not None:
                                                    for child_ref in self.ls_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.metric is not None:
                                                    return True

                                                if self.neighbor_as is not None:
                                                    return True

                                                if self.origin is not None:
                                                    return True

                                                if self.originator is not None:
                                                    return True

                                                if self.pe_distinguisher_label is not None:
                                                    for child_ref in self.pe_distinguisher_label:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.pmsi_flags is not None:
                                                    return True

                                                if self.pmsi_label is not None:
                                                    return True

                                                if self.pmsi_type is not None:
                                                    return True

                                                if self.pmsi_value is not None:
                                                    for child_ref in self.pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.ppm_pvalue is not None:
                                                    return True

                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_explicit_path is not None:
                                                    for child_ref in self.sr_policy_explicit_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.sr_policy_preference is not None:
                                                    return True

                                                if self.sr_tunnel_request_state is not None:
                                                    return True

                                                if self.sr_tunnel_state is not None:
                                                    return True

                                                if self.tunnel_encap_type is not None:
                                                    return True

                                                if self.unknown_attribute is not None:
                                                    for child_ref in self.unknown_attribute:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                        class RnhAddr(object):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.len = None
                                                self.mac_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.len is not None:
                                                    return True

                                                if self.mac_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                        class RibrnhIp(object):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.attr_set is not None and self.attr_set._has_data():
                                                return True

                                            if self.attribute_key_number is not None:
                                                return True

                                            if self.attribute_reuse_id_config is not None:
                                                return True

                                            if self.attribute_reuse_id_current is not None:
                                                return True

                                            if self.attribute_reuse_id_keys is not None:
                                                return True

                                            if self.attribute_reuse_id_max_id is not None:
                                                return True

                                            if self.attribute_reuse_id_node is not None:
                                                return True

                                            if self.attribute_reuse_id_recover_sec is not None:
                                                return True

                                            if self.common_attributes is not None and self.common_attributes._has_data():
                                                return True

                                            if self.is_application_gateway_present is not None:
                                                return True

                                            if self.is_as_path2_byte is not None:
                                                return True

                                            if self.is_attr_set_present is not None:
                                                return True

                                            if self.is_ribrnh_present is not None:
                                                return True

                                            if self.is_rnh_present is not None:
                                                return True

                                            if self.ribrnh_encap is not None:
                                                return True

                                            if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                return True

                                            if self.ribrnh_mac is not None:
                                                return True

                                            if self.ribrnh_table is not None:
                                                return True

                                            if self.ribrnh_vni is not None:
                                                return True

                                            if self.ribrnhip_table is not None:
                                                return True

                                            if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                return True

                                            if self.rnh_addr_len is not None:
                                                return True

                                            if self.rnh_len is not None:
                                                return True

                                            if self.rnh_type is not None:
                                                return True

                                            if self.set_aigp_inbound_igp is not None:
                                                return True

                                            if self.set_aigp_inbound_metric is not None:
                                                return True

                                            if self.vpn_distinguisher is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn']['meta_info']


                                    class AttributesAfterPolicyOut(object):
                                        """
                                        Attributes after outbound policy
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet>`
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes>`
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp>`
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr>`
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\:  bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet()
                                            self.attr_set.parent = self
                                            self.attribute_key_number = None
                                            self.attribute_reuse_id_config = None
                                            self.attribute_reuse_id_current = None
                                            self.attribute_reuse_id_keys = None
                                            self.attribute_reuse_id_max_id = None
                                            self.attribute_reuse_id_node = None
                                            self.attribute_reuse_id_recover_sec = None
                                            self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self.is_application_gateway_present = None
                                            self.is_as_path2_byte = None
                                            self.is_attr_set_present = None
                                            self.is_ribrnh_present = None
                                            self.is_rnh_present = None
                                            self.ribrnh_encap = None
                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self.ribrnh_mac = None
                                            self.ribrnh_table = None
                                            self.ribrnh_vni = None
                                            self.ribrnhip_table = None
                                            self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self.rnh_addr_len = None
                                            self.rnh_len = None
                                            self.rnh_type = None
                                            self.set_aigp_inbound_igp = None
                                            self.set_aigp_inbound_metric = None
                                            self.vpn_distinguisher = None


                                        class CommonAttributes(object):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_encap_present
                                            
                                            	Tunnel Encap attribute present 
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_policy_allocated_binding_sid
                                            
                                            	SR Policy allocated Binding sid by the router
                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                            
                                            .. attribute:: sr_policy_binding_sid
                                            
                                            	SR Policy Binding sid
                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyBindingSid>`
                                            
                                            .. attribute:: sr_policy_explicit_path
                                            
                                            	SR Policy Explicit paths
                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyExplicitPath>`
                                            
                                            .. attribute:: sr_policy_preference
                                            
                                            	SR Policy Preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_tunnel_request_state
                                            
                                            	SR Tunnel Request State
                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                            
                                            .. attribute:: sr_tunnel_state
                                            
                                            	SR Tunnel State
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap_type
                                            
                                            	Tunnel Encap Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.aggregator_address = None
                                                self.aggregator_as = None
                                                self.aigp_metric_value = None
                                                self.as_path = None
                                                self.cluster = YList()
                                                self.cluster.parent = self
                                                self.cluster.name = 'cluster'
                                                self.community = YList()
                                                self.community.parent = self
                                                self.community.name = 'community'
                                                self.connector_type = None
                                                self.connector_value = YList()
                                                self.connector_value.parent = self
                                                self.connector_value.name = 'connector_value'
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.extended_community_flags = None
                                                self.is_aggregator_present = None
                                                self.is_aigp_present = None
                                                self.is_as_path_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_community_present = None
                                                self.is_connector_present = None
                                                self.is_extended_community_present = None
                                                self.is_label_index_present = None
                                                self.is_local_pref_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_metric_present = None
                                                self.is_origin_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_ssa_present = None
                                                self.is_tunnel_encap_present = None
                                                self.l2tpv3_cookie = YList()
                                                self.l2tpv3_cookie.parent = self
                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                self.l2tpv3_session_id = None
                                                self.label_index_attr = YList()
                                                self.label_index_attr.parent = self
                                                self.label_index_attr.name = 'label_index_attr'
                                                self.local_preference = None
                                                self.ls_attr = YList()
                                                self.ls_attr.parent = self
                                                self.ls_attr.name = 'ls_attr'
                                                self.metric = None
                                                self.neighbor_as = None
                                                self.origin = None
                                                self.originator = None
                                                self.pe_distinguisher_label = YList()
                                                self.pe_distinguisher_label.parent = self
                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.pmsi_type = None
                                                self.pmsi_value = YList()
                                                self.pmsi_value.parent = self
                                                self.pmsi_value.name = 'pmsi_value'
                                                self.ppm_pvalue = None
                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                self.sr_policy_allocated_binding_sid.parent = self
                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyBindingSid()
                                                self.sr_policy_binding_sid.parent = self
                                                self.sr_policy_explicit_path = YList()
                                                self.sr_policy_explicit_path.parent = self
                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                self.sr_policy_preference = None
                                                self.sr_tunnel_request_state = None
                                                self.sr_tunnel_state = None
                                                self.tunnel_encap_type = None
                                                self.unknown_attribute = YList()
                                                self.unknown_attribute.parent = self
                                                self.unknown_attribute.name = 'unknown_attribute'


                                            class SrPolicyBindingSid(object):
                                                """
                                                SR Policy Binding sid
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                            class SrPolicyAllocatedBindingSid(object):
                                                """
                                                SR Policy allocated Binding sid by the router
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                            class Community(object):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity']['meta_info']


                                            class UnknownAttribute(object):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute']['meta_info']


                                            class Cluster(object):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster']['meta_info']


                                            class L2Tpv3Cookie(object):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                            class ConnectorValue(object):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue']['meta_info']


                                            class PmsiValue(object):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue']['meta_info']


                                            class LsAttr(object):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr']['meta_info']


                                            class LabelIndexAttr(object):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr']['meta_info']


                                            class PeDistinguisherLabel(object):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.label = None
                                                    self.pe_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.label is not None:
                                                        return True

                                                    if self.pe_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                            class SrPolicyExplicitPath(object):
                                                """
                                                SR Policy Explicit paths
                                                
                                                .. attribute:: sid
                                                
                                                	Sidlist for explicit path
                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                
                                                .. attribute:: weight
                                                
                                                	Weight of explicit path
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.sid = YList()
                                                    self.sid.parent = self
                                                    self.sid.name = 'sid'
                                                    self.weight = None


                                                class Sid(object):
                                                    """
                                                    Sidlist for explicit path
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IP Address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label sid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Sid Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4 is not None:
                                                            return True

                                                        if self.ipv6 is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.sid is not None:
                                                        for child_ref in self.sid:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.weight is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.aggregator_address is not None:
                                                    return True

                                                if self.aggregator_as is not None:
                                                    return True

                                                if self.aigp_metric_value is not None:
                                                    return True

                                                if self.as_path is not None:
                                                    return True

                                                if self.cluster is not None:
                                                    for child_ref in self.cluster:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.community is not None:
                                                    for child_ref in self.community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.connector_type is not None:
                                                    return True

                                                if self.connector_value is not None:
                                                    for child_ref in self.connector_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community_flags is not None:
                                                    return True

                                                if self.is_aggregator_present is not None:
                                                    return True

                                                if self.is_aigp_present is not None:
                                                    return True

                                                if self.is_as_path_present is not None:
                                                    return True

                                                if self.is_atomic_aggregate_present is not None:
                                                    return True

                                                if self.is_community_present is not None:
                                                    return True

                                                if self.is_connector_present is not None:
                                                    return True

                                                if self.is_extended_community_present is not None:
                                                    return True

                                                if self.is_label_index_present is not None:
                                                    return True

                                                if self.is_local_pref_present is not None:
                                                    return True

                                                if self.is_ls_attribute_present is not None:
                                                    return True

                                                if self.is_metric_present is not None:
                                                    return True

                                                if self.is_origin_present is not None:
                                                    return True

                                                if self.is_pe_distinguisher_label_present is not None:
                                                    return True

                                                if self.is_pmsi_present is not None:
                                                    return True

                                                if self.is_pppmp_present is not None:
                                                    return True

                                                if self.is_ssa_present is not None:
                                                    return True

                                                if self.is_tunnel_encap_present is not None:
                                                    return True

                                                if self.l2tpv3_cookie is not None:
                                                    for child_ref in self.l2tpv3_cookie:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2tpv3_session_id is not None:
                                                    return True

                                                if self.label_index_attr is not None:
                                                    for child_ref in self.label_index_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_preference is not None:
                                                    return True

                                                if self.ls_attr is not None:
                                                    for child_ref in self.ls_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.metric is not None:
                                                    return True

                                                if self.neighbor_as is not None:
                                                    return True

                                                if self.origin is not None:
                                                    return True

                                                if self.originator is not None:
                                                    return True

                                                if self.pe_distinguisher_label is not None:
                                                    for child_ref in self.pe_distinguisher_label:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.pmsi_flags is not None:
                                                    return True

                                                if self.pmsi_label is not None:
                                                    return True

                                                if self.pmsi_type is not None:
                                                    return True

                                                if self.pmsi_value is not None:
                                                    for child_ref in self.pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.ppm_pvalue is not None:
                                                    return True

                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_explicit_path is not None:
                                                    for child_ref in self.sr_policy_explicit_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.sr_policy_preference is not None:
                                                    return True

                                                if self.sr_tunnel_request_state is not None:
                                                    return True

                                                if self.sr_tunnel_state is not None:
                                                    return True

                                                if self.tunnel_encap_type is not None:
                                                    return True

                                                if self.unknown_attribute is not None:
                                                    for child_ref in self.unknown_attribute:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes']['meta_info']


                                        class AttrSet(object):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_encap_present
                                            
                                            	Tunnel Encap attribute present 
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_policy_allocated_binding_sid
                                            
                                            	SR Policy allocated Binding sid by the router
                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyAllocatedBindingSid>`
                                            
                                            .. attribute:: sr_policy_binding_sid
                                            
                                            	SR Policy Binding sid
                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyBindingSid>`
                                            
                                            .. attribute:: sr_policy_explicit_path
                                            
                                            	SR Policy Explicit paths
                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyExplicitPath>`
                                            
                                            .. attribute:: sr_policy_preference
                                            
                                            	SR Policy Preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_tunnel_request_state
                                            
                                            	SR Tunnel Request State
                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                            
                                            .. attribute:: sr_tunnel_state
                                            
                                            	SR Tunnel State
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap_type
                                            
                                            	Tunnel Encap Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.aggregator_address = None
                                                self.aggregator_as = None
                                                self.aigp_metric_value = None
                                                self.as_path = None
                                                self.cluster = YList()
                                                self.cluster.parent = self
                                                self.cluster.name = 'cluster'
                                                self.community = YList()
                                                self.community.parent = self
                                                self.community.name = 'community'
                                                self.connector_type = None
                                                self.connector_value = YList()
                                                self.connector_value.parent = self
                                                self.connector_value.name = 'connector_value'
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.extended_community_flags = None
                                                self.is_aggregator_present = None
                                                self.is_aigp_present = None
                                                self.is_as_path_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_community_present = None
                                                self.is_connector_present = None
                                                self.is_extended_community_present = None
                                                self.is_label_index_present = None
                                                self.is_local_pref_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_metric_present = None
                                                self.is_origin_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_ssa_present = None
                                                self.is_tunnel_encap_present = None
                                                self.l2tpv3_cookie = YList()
                                                self.l2tpv3_cookie.parent = self
                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                self.l2tpv3_session_id = None
                                                self.label_index_attr = YList()
                                                self.label_index_attr.parent = self
                                                self.label_index_attr.name = 'label_index_attr'
                                                self.local_preference = None
                                                self.ls_attr = YList()
                                                self.ls_attr.parent = self
                                                self.ls_attr.name = 'ls_attr'
                                                self.metric = None
                                                self.neighbor_as = None
                                                self.origin = None
                                                self.originator = None
                                                self.pe_distinguisher_label = YList()
                                                self.pe_distinguisher_label.parent = self
                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.pmsi_type = None
                                                self.pmsi_value = YList()
                                                self.pmsi_value.parent = self
                                                self.pmsi_value.name = 'pmsi_value'
                                                self.ppm_pvalue = None
                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyAllocatedBindingSid()
                                                self.sr_policy_allocated_binding_sid.parent = self
                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyBindingSid()
                                                self.sr_policy_binding_sid.parent = self
                                                self.sr_policy_explicit_path = YList()
                                                self.sr_policy_explicit_path.parent = self
                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                self.sr_policy_preference = None
                                                self.sr_tunnel_request_state = None
                                                self.sr_tunnel_state = None
                                                self.tunnel_encap_type = None
                                                self.unknown_attribute = YList()
                                                self.unknown_attribute.parent = self
                                                self.unknown_attribute.name = 'unknown_attribute'


                                            class SrPolicyBindingSid(object):
                                                """
                                                SR Policy Binding sid
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyBindingSid']['meta_info']


                                            class SrPolicyAllocatedBindingSid(object):
                                                """
                                                SR Policy allocated Binding sid by the router
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                            class Community(object):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity']['meta_info']


                                            class UnknownAttribute(object):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute']['meta_info']


                                            class Cluster(object):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster']['meta_info']


                                            class L2Tpv3Cookie(object):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie']['meta_info']


                                            class ConnectorValue(object):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue']['meta_info']


                                            class PmsiValue(object):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue']['meta_info']


                                            class LsAttr(object):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr']['meta_info']


                                            class LabelIndexAttr(object):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr']['meta_info']


                                            class PeDistinguisherLabel(object):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.label = None
                                                    self.pe_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.label is not None:
                                                        return True

                                                    if self.pe_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel']['meta_info']


                                            class SrPolicyExplicitPath(object):
                                                """
                                                SR Policy Explicit paths
                                                
                                                .. attribute:: sid
                                                
                                                	Sidlist for explicit path
                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyExplicitPath.Sid>`
                                                
                                                .. attribute:: weight
                                                
                                                	Weight of explicit path
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.sid = YList()
                                                    self.sid.parent = self
                                                    self.sid.name = 'sid'
                                                    self.weight = None


                                                class Sid(object):
                                                    """
                                                    Sidlist for explicit path
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IP Address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label sid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Sid Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4 is not None:
                                                            return True

                                                        if self.ipv6 is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.sid is not None:
                                                        for child_ref in self.sid:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.weight is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyExplicitPath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.aggregator_address is not None:
                                                    return True

                                                if self.aggregator_as is not None:
                                                    return True

                                                if self.aigp_metric_value is not None:
                                                    return True

                                                if self.as_path is not None:
                                                    return True

                                                if self.cluster is not None:
                                                    for child_ref in self.cluster:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.community is not None:
                                                    for child_ref in self.community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.connector_type is not None:
                                                    return True

                                                if self.connector_value is not None:
                                                    for child_ref in self.connector_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community_flags is not None:
                                                    return True

                                                if self.is_aggregator_present is not None:
                                                    return True

                                                if self.is_aigp_present is not None:
                                                    return True

                                                if self.is_as_path_present is not None:
                                                    return True

                                                if self.is_atomic_aggregate_present is not None:
                                                    return True

                                                if self.is_community_present is not None:
                                                    return True

                                                if self.is_connector_present is not None:
                                                    return True

                                                if self.is_extended_community_present is not None:
                                                    return True

                                                if self.is_label_index_present is not None:
                                                    return True

                                                if self.is_local_pref_present is not None:
                                                    return True

                                                if self.is_ls_attribute_present is not None:
                                                    return True

                                                if self.is_metric_present is not None:
                                                    return True

                                                if self.is_origin_present is not None:
                                                    return True

                                                if self.is_pe_distinguisher_label_present is not None:
                                                    return True

                                                if self.is_pmsi_present is not None:
                                                    return True

                                                if self.is_pppmp_present is not None:
                                                    return True

                                                if self.is_ssa_present is not None:
                                                    return True

                                                if self.is_tunnel_encap_present is not None:
                                                    return True

                                                if self.l2tpv3_cookie is not None:
                                                    for child_ref in self.l2tpv3_cookie:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2tpv3_session_id is not None:
                                                    return True

                                                if self.label_index_attr is not None:
                                                    for child_ref in self.label_index_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_preference is not None:
                                                    return True

                                                if self.ls_attr is not None:
                                                    for child_ref in self.ls_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.metric is not None:
                                                    return True

                                                if self.neighbor_as is not None:
                                                    return True

                                                if self.origin is not None:
                                                    return True

                                                if self.originator is not None:
                                                    return True

                                                if self.pe_distinguisher_label is not None:
                                                    for child_ref in self.pe_distinguisher_label:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.pmsi_flags is not None:
                                                    return True

                                                if self.pmsi_label is not None:
                                                    return True

                                                if self.pmsi_type is not None:
                                                    return True

                                                if self.pmsi_value is not None:
                                                    for child_ref in self.pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.ppm_pvalue is not None:
                                                    return True

                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_explicit_path is not None:
                                                    for child_ref in self.sr_policy_explicit_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.sr_policy_preference is not None:
                                                    return True

                                                if self.sr_tunnel_request_state is not None:
                                                    return True

                                                if self.sr_tunnel_state is not None:
                                                    return True

                                                if self.tunnel_encap_type is not None:
                                                    return True

                                                if self.unknown_attribute is not None:
                                                    for child_ref in self.unknown_attribute:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet']['meta_info']


                                        class RnhAddr(object):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.len = None
                                                self.mac_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.len is not None:
                                                    return True

                                                if self.mac_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr']['meta_info']


                                        class RibrnhIp(object):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-out'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.attr_set is not None and self.attr_set._has_data():
                                                return True

                                            if self.attribute_key_number is not None:
                                                return True

                                            if self.attribute_reuse_id_config is not None:
                                                return True

                                            if self.attribute_reuse_id_current is not None:
                                                return True

                                            if self.attribute_reuse_id_keys is not None:
                                                return True

                                            if self.attribute_reuse_id_max_id is not None:
                                                return True

                                            if self.attribute_reuse_id_node is not None:
                                                return True

                                            if self.attribute_reuse_id_recover_sec is not None:
                                                return True

                                            if self.common_attributes is not None and self.common_attributes._has_data():
                                                return True

                                            if self.is_application_gateway_present is not None:
                                                return True

                                            if self.is_as_path2_byte is not None:
                                                return True

                                            if self.is_attr_set_present is not None:
                                                return True

                                            if self.is_ribrnh_present is not None:
                                                return True

                                            if self.is_rnh_present is not None:
                                                return True

                                            if self.ribrnh_encap is not None:
                                                return True

                                            if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                return True

                                            if self.ribrnh_mac is not None:
                                                return True

                                            if self.ribrnh_table is not None:
                                                return True

                                            if self.ribrnh_vni is not None:
                                                return True

                                            if self.ribrnhip_table is not None:
                                                return True

                                            if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                return True

                                            if self.rnh_addr_len is not None:
                                                return True

                                            if self.rnh_len is not None:
                                                return True

                                            if self.rnh_type is not None:
                                                return True

                                            if self.set_aigp_inbound_igp is not None:
                                                return True

                                            if self.set_aigp_inbound_metric is not None:
                                                return True

                                            if self.vpn_distinguisher is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:policy'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                            return True

                                        if self.attributes_after_policy_out is not None and self.attributes_after_policy_out._has_data():
                                            return True

                                        if self.neighbor_address is not None:
                                            return True

                                        if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                            return True

                                        if self.network is not None:
                                            return True

                                        if self.no_path is not None:
                                            return True

                                        if self.path_info_after_policy_in is not None and self.path_info_after_policy_in._has_data():
                                            return True

                                        if self.path_info_after_policy_out is not None and self.path_info_after_policy_out._has_data():
                                            return True

                                        if self.prefix_length is not None:
                                            return True

                                        if self.rd is not None:
                                            return True

                                        if self.route_distinguisher is not None:
                                            return True

                                        if self.source_route_distinguisher is not None:
                                            return True

                                        if self.vrf_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:policies'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.policy is not None:
                                        for child_ref in self.policy:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies']['meta_info']


                            class Convergence(object):
                                """
                                A BGP Convergence table entry
                                
                                .. attribute:: af_name
                                
                                	Address family identifier
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: are_write_queues_empty
                                
                                	All neighbor write queues are empty
                                	**type**\:  bool
                                
                                .. attribute:: has_converged
                                
                                	Convergence has been reached
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.are_write_queues_empty = None
                                    self.has_converged = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:convergence'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.are_write_queues_empty is not None:
                                        return True

                                    if self.has_converged is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Convergence']['meta_info']


                            class AfProcessInfo(object):
                                """
                                A BGP Process address family table entry
                                
                                .. attribute:: af_name
                                
                                	Address family id
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: global_
                                
                                	Global information
                                	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_>`
                                
                                .. attribute:: performance_statistics
                                
                                	Performance statistics
                                	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics>`
                                
                                .. attribute:: process_instance
                                
                                	ID for the BGP process instance
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Vrf>`
                                
                                .. attribute:: vrf_name
                                
                                	Name of the VRF
                                	**type**\:  str
                                
                                .. attribute:: vrf_totals
                                
                                	per VRF information aggregated across all VRFs
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.global_ = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_()
                                    self.global_.parent = self
                                    self.performance_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics()
                                    self.performance_statistics.parent = self
                                    self.process_instance = None
                                    self.vrf = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Vrf()
                                    self.vrf.parent = self
                                    self.vrf_name = None
                                    self.vrf_totals = None


                                class Global_(object):
                                    """
                                    Global information
                                    
                                    .. attribute:: freed_rd_count
                                    
                                    	Activity\: Number of RDs freed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: import_bgp_version
                                    
                                    	BGP version when Import thread is last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: import_last_trigger
                                    
                                    	Timestamp when Import thread is last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: import_triggers
                                    
                                    	Import thread triggers
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: import_version
                                    
                                    	Version updated by import thread
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: imported_paths_memory
                                    
                                    	Total imported paths memory
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: imported_paths_num
                                    
                                    	Total impoorted paths 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_bgp_version
                                    
                                    	BGP version when label thread is last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_last_trigger
                                    
                                    	Timestamp when Label thread is last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: label_triggers
                                    
                                    	Label thread triggers
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_version
                                    
                                    	Version updated by label thread
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_import_version
                                    
                                    	Import thread version when last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_label_version
                                    
                                    	Label thread version when last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_rib_version
                                    
                                    	RIB thread version when last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_networks_freed_num
                                    
                                    	Total local networks freed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_networks_malloced_num
                                    
                                    	Total local networks malloced
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_networks_memory
                                    
                                    	Total local networks memory
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_networks_num
                                    
                                    	Total local networks
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_paths_freed_num
                                    
                                    	Total local paths freed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_paths_malloced_num
                                    
                                    	Total local paths malloced
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_paths_memory
                                    
                                    	Total local paths memory
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_paths_num
                                    
                                    	Total local paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: malloced_rd_count
                                    
                                    	Activity\: Number of RDs malloced
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: max_active_pelem_version
                                    
                                    	Maximum Active Pelem Version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: merged_table_version
                                    
                                    	Merged Table Version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: multipath_network_entry_count
                                    
                                    	Number of multipath network entries
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: multipath_network_entry_memory
                                    
                                    	Memory (in bytes) used bymultipath network entries
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: multipath_paths_count
                                    
                                    	Number of multipath paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: multipath_paths_memory
                                    
                                    	Memory (in bytes) used bymultimpath paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: networks_freed_num
                                    
                                    	Total networks freed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: networks_malloced_num
                                    
                                    	Total networks malloced
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: networks_memory
                                    
                                    	Total networks memory
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: networks_num
                                    
                                    	Total Num of networks
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_init_sync_pfx
                                    
                                    	Num of prefix synced during Initsync
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_elems_freed_num
                                    
                                    	Total path\-elems freed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_elems_malloced_num
                                    
                                    	Total path\-elems malloced
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_elems_memory
                                    
                                    	Total path\-elems memory
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_elems_num
                                    
                                    	Total Num of path\-elems
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: paths_freed_num
                                    
                                    	Total paths freed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: paths_malloced_num
                                    
                                    	Total paths malloced
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: paths_memory
                                    
                                    	Total paths memory
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: paths_num
                                    
                                    	Total Num of paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rd_memory
                                    
                                    	Memory (in bytes) used by RD data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: rib_ack_requests
                                    
                                    	Counter for RIB ack requests
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_acked_table_version
                                    
                                    	Table version acked by RIB
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_acks_received
                                    
                                    	Counter for RIB ack received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_brib_received_version
                                    
                                    	Version received from 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_install
                                    
                                    	RIB install info
                                    	**type**\:   :py:class:`RibInstall <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall>`
                                    
                                    .. attribute:: rib_last_trigger
                                    
                                    	Timestamp when RIB thread is last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: rib_slow_acks
                                    
                                    	Counter for slow RIB acks
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_triggers
                                    
                                    	RIB thread triggers
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ribbgp_version
                                    
                                    	BGP version when RIB thread is last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_download_go_active_done_pending
                                    
                                    	Route Download Go Active Done Pending
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: router_state
                                    
                                    	Router state
                                    	**type**\:   :py:class:`BgpRtrStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRtrStateEnum>`
                                    
                                    .. attribute:: send_version
                                    
                                    	Version for sending updates to peers
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: standby_version
                                    
                                    	Version updated by sync thread
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_brib_version
                                    
                                    	Version sent to RIB/bRIB
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_version
                                    
                                    	BGP table version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_r_ds_num
                                    
                                    	Total Num of RDs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_remote_r_ds_num
                                    
                                    	Total Num of remote RDs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_same_r_ds_num
                                    
                                    	Total Num of same RDs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: trigger_import
                                    
                                    	Trigger import
                                    	**type**\:   :py:class:`TriggerImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport>`
                                    
                                    .. attribute:: trigger_label
                                    
                                    	Trigger label
                                    	**type**\:   :py:class:`TriggerLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel>`
                                    
                                    .. attribute:: trigger_rib
                                    
                                    	Trigger RIB
                                    	**type**\:   :py:class:`TriggerRib <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib>`
                                    
                                    .. attribute:: trigger_update
                                    
                                    	Trigger update
                                    	**type**\:   :py:class:`TriggerUpdate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate>`
                                    
                                    .. attribute:: update_gen_bgp_version
                                    
                                    	BGP version when Update generation thread is last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_gen_last_trigger
                                    
                                    	Timestamp when Update generation thread is last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: update_triggers
                                    
                                    	Update thread triggers
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_wait_install_enabled
                                    
                                    	Update wait\-install enabled
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version_wrap_done_time_spec
                                    
                                    	Version Wrap handle Done timestamp
                                    	**type**\:   :py:class:`VersionWrapDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapDoneTimeSpec>`
                                    
                                    .. attribute:: version_wrap_start_time_spec
                                    
                                    	Version Wrap handle start timestamp
                                    	**type**\:   :py:class:`VersionWrapStartTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapStartTimeSpec>`
                                    
                                    .. attribute:: version_wrap_time_spec
                                    
                                    	Version Wrap timestamp
                                    	**type**\:   :py:class:`VersionWrapTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapTimeSpec>`
                                    
                                    .. attribute:: version_wrapped
                                    
                                    	Number of times Version Wrap happened
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version_wrapped_tid
                                    
                                    	Version Wrapped trigger tid
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.freed_rd_count = None
                                        self.import_bgp_version = None
                                        self.import_last_trigger = None
                                        self.import_triggers = None
                                        self.import_version = None
                                        self.imported_paths_memory = None
                                        self.imported_paths_num = None
                                        self.label_bgp_version = None
                                        self.label_last_trigger = None
                                        self.label_triggers = None
                                        self.label_version = None
                                        self.last_import_version = None
                                        self.last_label_version = None
                                        self.last_rib_version = None
                                        self.local_networks_freed_num = None
                                        self.local_networks_malloced_num = None
                                        self.local_networks_memory = None
                                        self.local_networks_num = None
                                        self.local_paths_freed_num = None
                                        self.local_paths_malloced_num = None
                                        self.local_paths_memory = None
                                        self.local_paths_num = None
                                        self.malloced_rd_count = None
                                        self.max_active_pelem_version = None
                                        self.merged_table_version = None
                                        self.multipath_network_entry_count = None
                                        self.multipath_network_entry_memory = None
                                        self.multipath_paths_count = None
                                        self.multipath_paths_memory = None
                                        self.networks_freed_num = None
                                        self.networks_malloced_num = None
                                        self.networks_memory = None
                                        self.networks_num = None
                                        self.num_init_sync_pfx = None
                                        self.path_elems_freed_num = None
                                        self.path_elems_malloced_num = None
                                        self.path_elems_memory = None
                                        self.path_elems_num = None
                                        self.paths_freed_num = None
                                        self.paths_malloced_num = None
                                        self.paths_memory = None
                                        self.paths_num = None
                                        self.rd_memory = None
                                        self.rib_ack_requests = None
                                        self.rib_acked_table_version = None
                                        self.rib_acks_received = None
                                        self.rib_brib_received_version = None
                                        self.rib_install = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall()
                                        self.rib_install.parent = self
                                        self.rib_last_trigger = None
                                        self.rib_slow_acks = None
                                        self.rib_triggers = None
                                        self.ribbgp_version = None
                                        self.route_download_go_active_done_pending = None
                                        self.router_state = None
                                        self.send_version = None
                                        self.standby_version = None
                                        self.table_brib_version = None
                                        self.table_version = None
                                        self.total_r_ds_num = None
                                        self.total_remote_r_ds_num = None
                                        self.total_same_r_ds_num = None
                                        self.trigger_import = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport()
                                        self.trigger_import.parent = self
                                        self.trigger_label = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel()
                                        self.trigger_label.parent = self
                                        self.trigger_rib = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib()
                                        self.trigger_rib.parent = self
                                        self.trigger_update = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate()
                                        self.trigger_update.parent = self
                                        self.update_gen_bgp_version = None
                                        self.update_gen_last_trigger = None
                                        self.update_triggers = None
                                        self.update_wait_install_enabled = None
                                        self.version_wrap_done_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapDoneTimeSpec()
                                        self.version_wrap_done_time_spec.parent = self
                                        self.version_wrap_start_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapStartTimeSpec()
                                        self.version_wrap_start_time_spec.parent = self
                                        self.version_wrap_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapTimeSpec()
                                        self.version_wrap_time_spec.parent = self
                                        self.version_wrapped = None
                                        self.version_wrapped_tid = None


                                    class VersionWrapTimeSpec(object):
                                        """
                                        Version Wrap timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-wrap-time-spec'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapTimeSpec']['meta_info']


                                    class VersionWrapStartTimeSpec(object):
                                        """
                                        Version Wrap handle start timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-wrap-start-time-spec'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapStartTimeSpec']['meta_info']


                                    class VersionWrapDoneTimeSpec(object):
                                        """
                                        Version Wrap handle Done timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-wrap-done-time-spec'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapDoneTimeSpec']['meta_info']


                                    class TriggerRib(object):
                                        """
                                        Trigger RIB
                                        
                                        .. attribute:: statistic
                                        
                                        	statistic
                                        	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic>`
                                        
                                        .. attribute:: triggers
                                        
                                        	Triggers
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.statistic = YList()
                                            self.statistic.parent = self
                                            self.statistic.name = 'statistic'
                                            self.triggers = None


                                        class Statistic(object):
                                            """
                                            statistic
                                            
                                            .. attribute:: trigger_table_version
                                            
                                            	TriggerTableVersion
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: trigger_time_spec
                                            
                                            	trigger time spec
                                            	**type**\:   :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic.TriggerTimeSpec>`
                                            
                                            .. attribute:: trigger_version
                                            
                                            	TriggerVersion
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.trigger_table_version = None
                                                self.trigger_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic.TriggerTimeSpec()
                                                self.trigger_time_spec.parent = self
                                                self.trigger_version = None


                                            class TriggerTimeSpec(object):
                                                """
                                                trigger time spec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:trigger-time-spec'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic.TriggerTimeSpec']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:statistic'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.trigger_table_version is not None:
                                                    return True

                                                if self.trigger_time_spec is not None and self.trigger_time_spec._has_data():
                                                    return True

                                                if self.trigger_version is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:trigger-rib'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.statistic is not None:
                                                for child_ref in self.statistic:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.triggers is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib']['meta_info']


                                    class TriggerImport(object):
                                        """
                                        Trigger import
                                        
                                        .. attribute:: statistic
                                        
                                        	statistic
                                        	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic>`
                                        
                                        .. attribute:: triggers
                                        
                                        	Triggers
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.statistic = YList()
                                            self.statistic.parent = self
                                            self.statistic.name = 'statistic'
                                            self.triggers = None


                                        class Statistic(object):
                                            """
                                            statistic
                                            
                                            .. attribute:: trigger_table_version
                                            
                                            	TriggerTableVersion
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: trigger_time_spec
                                            
                                            	trigger time spec
                                            	**type**\:   :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic.TriggerTimeSpec>`
                                            
                                            .. attribute:: trigger_version
                                            
                                            	TriggerVersion
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.trigger_table_version = None
                                                self.trigger_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic.TriggerTimeSpec()
                                                self.trigger_time_spec.parent = self
                                                self.trigger_version = None


                                            class TriggerTimeSpec(object):
                                                """
                                                trigger time spec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:trigger-time-spec'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic.TriggerTimeSpec']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:statistic'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.trigger_table_version is not None:
                                                    return True

                                                if self.trigger_time_spec is not None and self.trigger_time_spec._has_data():
                                                    return True

                                                if self.trigger_version is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:trigger-import'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.statistic is not None:
                                                for child_ref in self.statistic:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.triggers is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport']['meta_info']


                                    class TriggerUpdate(object):
                                        """
                                        Trigger update
                                        
                                        .. attribute:: statistic
                                        
                                        	statistic
                                        	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic>`
                                        
                                        .. attribute:: triggers
                                        
                                        	Triggers
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.statistic = YList()
                                            self.statistic.parent = self
                                            self.statistic.name = 'statistic'
                                            self.triggers = None


                                        class Statistic(object):
                                            """
                                            statistic
                                            
                                            .. attribute:: trigger_table_version
                                            
                                            	TriggerTableVersion
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: trigger_time_spec
                                            
                                            	trigger time spec
                                            	**type**\:   :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic.TriggerTimeSpec>`
                                            
                                            .. attribute:: trigger_version
                                            
                                            	TriggerVersion
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.trigger_table_version = None
                                                self.trigger_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic.TriggerTimeSpec()
                                                self.trigger_time_spec.parent = self
                                                self.trigger_version = None


                                            class TriggerTimeSpec(object):
                                                """
                                                trigger time spec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:trigger-time-spec'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic.TriggerTimeSpec']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:statistic'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.trigger_table_version is not None:
                                                    return True

                                                if self.trigger_time_spec is not None and self.trigger_time_spec._has_data():
                                                    return True

                                                if self.trigger_version is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:trigger-update'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.statistic is not None:
                                                for child_ref in self.statistic:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.triggers is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate']['meta_info']


                                    class TriggerLabel(object):
                                        """
                                        Trigger label
                                        
                                        .. attribute:: statistic
                                        
                                        	statistic
                                        	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic>`
                                        
                                        .. attribute:: triggers
                                        
                                        	Triggers
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.statistic = YList()
                                            self.statistic.parent = self
                                            self.statistic.name = 'statistic'
                                            self.triggers = None


                                        class Statistic(object):
                                            """
                                            statistic
                                            
                                            .. attribute:: trigger_table_version
                                            
                                            	TriggerTableVersion
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: trigger_time_spec
                                            
                                            	trigger time spec
                                            	**type**\:   :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic.TriggerTimeSpec>`
                                            
                                            .. attribute:: trigger_version
                                            
                                            	TriggerVersion
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.trigger_table_version = None
                                                self.trigger_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic.TriggerTimeSpec()
                                                self.trigger_time_spec.parent = self
                                                self.trigger_version = None


                                            class TriggerTimeSpec(object):
                                                """
                                                trigger time spec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:trigger-time-spec'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic.TriggerTimeSpec']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:statistic'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.trigger_table_version is not None:
                                                    return True

                                                if self.trigger_time_spec is not None and self.trigger_time_spec._has_data():
                                                    return True

                                                if self.trigger_version is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:trigger-label'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.statistic is not None:
                                                for child_ref in self.statistic:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.triggers is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel']['meta_info']


                                    class RibInstall(object):
                                        """
                                        RIB install info
                                        
                                        .. attribute:: install_time
                                        
                                        	RIB install time
                                        	**type**\:   :py:class:`InstallTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall.InstallTime>`
                                        
                                        .. attribute:: installed_count
                                        
                                        	Installed routes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: modified_count
                                        
                                        	Modified routes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: start_version
                                        
                                        	Start version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: target_version
                                        
                                        	Target version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_time
                                        
                                        	RIB update time
                                        	**type**\:   :py:class:`UpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall.UpdateTime>`
                                        
                                        .. attribute:: withdrawn_count
                                        
                                        	Withdrawn routes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.install_time = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall.InstallTime()
                                            self.install_time.parent = self
                                            self.installed_count = None
                                            self.modified_count = None
                                            self.start_version = None
                                            self.target_version = None
                                            self.update_time = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall.UpdateTime()
                                            self.update_time.parent = self
                                            self.withdrawn_count = None


                                        class UpdateTime(object):
                                            """
                                            RIB update time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-time'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall.UpdateTime']['meta_info']


                                        class InstallTime(object):
                                            """
                                            RIB install time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:install-time'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall.InstallTime']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rib-install'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.install_time is not None and self.install_time._has_data():
                                                return True

                                            if self.installed_count is not None:
                                                return True

                                            if self.modified_count is not None:
                                                return True

                                            if self.start_version is not None:
                                                return True

                                            if self.target_version is not None:
                                                return True

                                            if self.update_time is not None and self.update_time._has_data():
                                                return True

                                            if self.withdrawn_count is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:global'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.freed_rd_count is not None:
                                            return True

                                        if self.import_bgp_version is not None:
                                            return True

                                        if self.import_last_trigger is not None:
                                            return True

                                        if self.import_triggers is not None:
                                            return True

                                        if self.import_version is not None:
                                            return True

                                        if self.imported_paths_memory is not None:
                                            return True

                                        if self.imported_paths_num is not None:
                                            return True

                                        if self.label_bgp_version is not None:
                                            return True

                                        if self.label_last_trigger is not None:
                                            return True

                                        if self.label_triggers is not None:
                                            return True

                                        if self.label_version is not None:
                                            return True

                                        if self.last_import_version is not None:
                                            return True

                                        if self.last_label_version is not None:
                                            return True

                                        if self.last_rib_version is not None:
                                            return True

                                        if self.local_networks_freed_num is not None:
                                            return True

                                        if self.local_networks_malloced_num is not None:
                                            return True

                                        if self.local_networks_memory is not None:
                                            return True

                                        if self.local_networks_num is not None:
                                            return True

                                        if self.local_paths_freed_num is not None:
                                            return True

                                        if self.local_paths_malloced_num is not None:
                                            return True

                                        if self.local_paths_memory is not None:
                                            return True

                                        if self.local_paths_num is not None:
                                            return True

                                        if self.malloced_rd_count is not None:
                                            return True

                                        if self.max_active_pelem_version is not None:
                                            return True

                                        if self.merged_table_version is not None:
                                            return True

                                        if self.multipath_network_entry_count is not None:
                                            return True

                                        if self.multipath_network_entry_memory is not None:
                                            return True

                                        if self.multipath_paths_count is not None:
                                            return True

                                        if self.multipath_paths_memory is not None:
                                            return True

                                        if self.networks_freed_num is not None:
                                            return True

                                        if self.networks_malloced_num is not None:
                                            return True

                                        if self.networks_memory is not None:
                                            return True

                                        if self.networks_num is not None:
                                            return True

                                        if self.num_init_sync_pfx is not None:
                                            return True

                                        if self.path_elems_freed_num is not None:
                                            return True

                                        if self.path_elems_malloced_num is not None:
                                            return True

                                        if self.path_elems_memory is not None:
                                            return True

                                        if self.path_elems_num is not None:
                                            return True

                                        if self.paths_freed_num is not None:
                                            return True

                                        if self.paths_malloced_num is not None:
                                            return True

                                        if self.paths_memory is not None:
                                            return True

                                        if self.paths_num is not None:
                                            return True

                                        if self.rd_memory is not None:
                                            return True

                                        if self.rib_ack_requests is not None:
                                            return True

                                        if self.rib_acked_table_version is not None:
                                            return True

                                        if self.rib_acks_received is not None:
                                            return True

                                        if self.rib_brib_received_version is not None:
                                            return True

                                        if self.rib_install is not None and self.rib_install._has_data():
                                            return True

                                        if self.rib_last_trigger is not None:
                                            return True

                                        if self.rib_slow_acks is not None:
                                            return True

                                        if self.rib_triggers is not None:
                                            return True

                                        if self.ribbgp_version is not None:
                                            return True

                                        if self.route_download_go_active_done_pending is not None:
                                            return True

                                        if self.router_state is not None:
                                            return True

                                        if self.send_version is not None:
                                            return True

                                        if self.standby_version is not None:
                                            return True

                                        if self.table_brib_version is not None:
                                            return True

                                        if self.table_version is not None:
                                            return True

                                        if self.total_r_ds_num is not None:
                                            return True

                                        if self.total_remote_r_ds_num is not None:
                                            return True

                                        if self.total_same_r_ds_num is not None:
                                            return True

                                        if self.trigger_import is not None and self.trigger_import._has_data():
                                            return True

                                        if self.trigger_label is not None and self.trigger_label._has_data():
                                            return True

                                        if self.trigger_rib is not None and self.trigger_rib._has_data():
                                            return True

                                        if self.trigger_update is not None and self.trigger_update._has_data():
                                            return True

                                        if self.update_gen_bgp_version is not None:
                                            return True

                                        if self.update_gen_last_trigger is not None:
                                            return True

                                        if self.update_triggers is not None:
                                            return True

                                        if self.update_wait_install_enabled is not None:
                                            return True

                                        if self.version_wrap_done_time_spec is not None and self.version_wrap_done_time_spec._has_data():
                                            return True

                                        if self.version_wrap_start_time_spec is not None and self.version_wrap_start_time_spec._has_data():
                                            return True

                                        if self.version_wrap_time_spec is not None and self.version_wrap_time_spec._has_data():
                                            return True

                                        if self.version_wrapped is not None:
                                            return True

                                        if self.version_wrapped_tid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global_']['meta_info']


                                class Vrf(object):
                                    """
                                    VRF information
                                    
                                    .. attribute:: add_path_install_disable
                                    
                                    	Additional paths installation is disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: add_path_install_enable
                                    
                                    	Additional paths installation is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: any_ebgp_neighbor_missing_policy
                                    
                                    	Is there any neighbor which is missing either inbound or outbound or both routing policy for this address family?
                                    	**type**\:  bool
                                    
                                    .. attribute:: asbr
                                    
                                    	Router is an ASBR for this AF
                                    	**type**\:  bool
                                    
                                    .. attribute:: attribute_download
                                    
                                    	Attribute download is 
                                    	**type**\:  bool
                                    
                                    .. attribute:: best_external
                                    
                                    	Best External is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: best_external_disable
                                    
                                    	Best External is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: bmp_network_entry_count
                                    
                                    	Number of BMP net entries
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_path_memory
                                    
                                    	Memory (in bytes) used by path data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: bmp_paths_count
                                    
                                    	Total Number of BMP paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_prefix_memory
                                    
                                    	Memory (in bytes) used by prefix data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: damped_path_count
                                    
                                    	Number of dampened paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: freed_path_count
                                    
                                    	Activity\: Number of paths freed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: freed_path_elem_count
                                    
                                    	Activity\: Number of pathelems freed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: freed_prefix_count
                                    
                                    	Activity\: Number of prefixes freed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: history_path_count
                                    
                                    	Number of history paths (for dampening)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ibgp_nexthop_self_count
                                    
                                    	Number of iBGP sessions configured with nh\-self
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: imported_path_memory
                                    
                                    	Memory (in bytes) used by imported paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: imported_paths
                                    
                                    	Number of imported paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_route_reflector
                                    
                                    	Router is an RR for this AF
                                    	**type**\:  bool
                                    
                                    .. attribute:: label_retain
                                    
                                    	Label retention is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: label_retainvalue
                                    
                                    	Label retention value enabled
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_path_memory
                                    
                                    	Memory (in bytes) used by local paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: local_paths
                                    
                                    	Number of local paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: malloced_path_count
                                    
                                    	Activity\: Number of paths malloced
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: malloced_path_elem_count
                                    
                                    	Activity\: Number of path elems malloced
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: malloced_prefix_count
                                    
                                    	Activity\: Number of prefixes malloced
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: network_entry_count
                                    
                                    	Number of network entries
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_elem_memory
                                    
                                    	Memory (in bytes) used by pathelem data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: path_elems_count
                                    
                                    	Number of path elems
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_memory
                                    
                                    	Memory (in bytes) used by path data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: paths_count
                                    
                                    	Number of paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefix_memory
                                    
                                    	Memory (in bytes) used by prefix data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: received_path_count
                                    
                                    	Number of (unused) received paths for inbound soft reconfiguration
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: retain_rt_all
                                    
                                    	Retain\-RT\-All enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_target_download
                                    
                                    	Route Target download is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: tbl_bitf_size
                                    
                                    	Bitfield size on table
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: tbl_chunk_bitf_size
                                    
                                    	Chunk Bitfield size on table
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: use_igpsr_label
                                    
                                    	Use IGP SR label for resolution
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.add_path_install_disable = None
                                        self.add_path_install_enable = None
                                        self.any_ebgp_neighbor_missing_policy = None
                                        self.asbr = None
                                        self.attribute_download = None
                                        self.best_external = None
                                        self.best_external_disable = None
                                        self.bmp_network_entry_count = None
                                        self.bmp_path_memory = None
                                        self.bmp_paths_count = None
                                        self.bmp_prefix_memory = None
                                        self.damped_path_count = None
                                        self.freed_path_count = None
                                        self.freed_path_elem_count = None
                                        self.freed_prefix_count = None
                                        self.history_path_count = None
                                        self.ibgp_nexthop_self_count = None
                                        self.imported_path_memory = None
                                        self.imported_paths = None
                                        self.is_route_reflector = None
                                        self.label_retain = None
                                        self.label_retainvalue = None
                                        self.local_path_memory = None
                                        self.local_paths = None
                                        self.malloced_path_count = None
                                        self.malloced_path_elem_count = None
                                        self.malloced_prefix_count = None
                                        self.network_entry_count = None
                                        self.path_elem_memory = None
                                        self.path_elems_count = None
                                        self.path_memory = None
                                        self.paths_count = None
                                        self.prefix_memory = None
                                        self.received_path_count = None
                                        self.retain_rt_all = None
                                        self.route_target_download = None
                                        self.tbl_bitf_size = None
                                        self.tbl_chunk_bitf_size = None
                                        self.use_igpsr_label = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:vrf'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.add_path_install_disable is not None:
                                            return True

                                        if self.add_path_install_enable is not None:
                                            return True

                                        if self.any_ebgp_neighbor_missing_policy is not None:
                                            return True

                                        if self.asbr is not None:
                                            return True

                                        if self.attribute_download is not None:
                                            return True

                                        if self.best_external is not None:
                                            return True

                                        if self.best_external_disable is not None:
                                            return True

                                        if self.bmp_network_entry_count is not None:
                                            return True

                                        if self.bmp_path_memory is not None:
                                            return True

                                        if self.bmp_paths_count is not None:
                                            return True

                                        if self.bmp_prefix_memory is not None:
                                            return True

                                        if self.damped_path_count is not None:
                                            return True

                                        if self.freed_path_count is not None:
                                            return True

                                        if self.freed_path_elem_count is not None:
                                            return True

                                        if self.freed_prefix_count is not None:
                                            return True

                                        if self.history_path_count is not None:
                                            return True

                                        if self.ibgp_nexthop_self_count is not None:
                                            return True

                                        if self.imported_path_memory is not None:
                                            return True

                                        if self.imported_paths is not None:
                                            return True

                                        if self.is_route_reflector is not None:
                                            return True

                                        if self.label_retain is not None:
                                            return True

                                        if self.label_retainvalue is not None:
                                            return True

                                        if self.local_path_memory is not None:
                                            return True

                                        if self.local_paths is not None:
                                            return True

                                        if self.malloced_path_count is not None:
                                            return True

                                        if self.malloced_path_elem_count is not None:
                                            return True

                                        if self.malloced_prefix_count is not None:
                                            return True

                                        if self.network_entry_count is not None:
                                            return True

                                        if self.path_elem_memory is not None:
                                            return True

                                        if self.path_elems_count is not None:
                                            return True

                                        if self.path_memory is not None:
                                            return True

                                        if self.paths_count is not None:
                                            return True

                                        if self.prefix_memory is not None:
                                            return True

                                        if self.received_path_count is not None:
                                            return True

                                        if self.retain_rt_all is not None:
                                            return True

                                        if self.route_target_download is not None:
                                            return True

                                        if self.tbl_bitf_size is not None:
                                            return True

                                        if self.tbl_chunk_bitf_size is not None:
                                            return True

                                        if self.use_igpsr_label is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Vrf']['meta_info']


                                class PerformanceStatistics(object):
                                    """
                                    Performance statistics
                                    
                                    .. attribute:: global_
                                    
                                    	Global information
                                    	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_>`
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.global_ = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_()
                                        self.global_.parent = self
                                        self.vrf = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf()
                                        self.vrf.parent = self


                                    class Global_(object):
                                        """
                                        Global information
                                        
                                        .. attribute:: first_nbr_up_time
                                        
                                        	Time when first peer came up (seconds since Jan 1 1970)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: has_converged
                                        
                                        	TRUE if process has converged
                                        	**type**\:  bool
                                        
                                        .. attribute:: mode_enter_time
                                        
                                        	Time that each mode was entered (seconds since  Jan 1 1970)
                                        	**type**\: list of    :py:class:`ModeEnterTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.ModeEnterTime>`
                                        
                                        .. attribute:: total_pim_callback_add
                                        
                                        	Total number of Pim callbacks for add
                                        	**type**\: list of    :py:class:`TotalPimCallbackAdd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAdd>`
                                        
                                        .. attribute:: total_pim_callback_add_local
                                        
                                        	Total number of Pim callbacks for local add
                                        	**type**\: list of    :py:class:`TotalPimCallbackAddLocal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAddLocal>`
                                        
                                        .. attribute:: total_pim_callback_batch
                                        
                                        	Total number of Pim callback batches
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_pim_callback_del
                                        
                                        	Total number of Pim callbacks for del
                                        	**type**\: list of    :py:class:`TotalPimCallbackDel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDel>`
                                        
                                        .. attribute:: total_pim_callback_del_local
                                        
                                        	Total number of Pim callbacks for Local del
                                        	**type**\: list of    :py:class:`TotalPimCallbackDelLocal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDelLocal>`
                                        
                                        .. attribute:: total_pim_callbacks
                                        
                                        	Total number of PIM callbacks
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_pim_install
                                        
                                        	Total number of install to PIM
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_pim_install_add
                                        
                                        	Total number of install to PIM for add
                                        	**type**\: list of    :py:class:`TotalPimInstallAdd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallAdd>`
                                        
                                        .. attribute:: total_pim_install_del
                                        
                                        	Total number of install to PIM for del
                                        	**type**\: list of    :py:class:`TotalPimInstallDel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallDel>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.first_nbr_up_time = None
                                            self.has_converged = None
                                            self.mode_enter_time = YList()
                                            self.mode_enter_time.parent = self
                                            self.mode_enter_time.name = 'mode_enter_time'
                                            self.total_pim_callback_add = YList()
                                            self.total_pim_callback_add.parent = self
                                            self.total_pim_callback_add.name = 'total_pim_callback_add'
                                            self.total_pim_callback_add_local = YList()
                                            self.total_pim_callback_add_local.parent = self
                                            self.total_pim_callback_add_local.name = 'total_pim_callback_add_local'
                                            self.total_pim_callback_batch = None
                                            self.total_pim_callback_del = YList()
                                            self.total_pim_callback_del.parent = self
                                            self.total_pim_callback_del.name = 'total_pim_callback_del'
                                            self.total_pim_callback_del_local = YList()
                                            self.total_pim_callback_del_local.parent = self
                                            self.total_pim_callback_del_local.name = 'total_pim_callback_del_local'
                                            self.total_pim_callbacks = None
                                            self.total_pim_install = None
                                            self.total_pim_install_add = YList()
                                            self.total_pim_install_add.parent = self
                                            self.total_pim_install_add.name = 'total_pim_install_add'
                                            self.total_pim_install_del = YList()
                                            self.total_pim_install_del.parent = self
                                            self.total_pim_install_del.name = 'total_pim_install_del'


                                        class ModeEnterTime(object):
                                            """
                                            Time that each mode was entered (seconds since
                                            
                                            Jan 1 1970)
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mode-enter-time'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.ModeEnterTime']['meta_info']


                                        class TotalPimInstallAdd(object):
                                            """
                                            Total number of install to PIM for add
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:total-pim-install-add'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallAdd']['meta_info']


                                        class TotalPimInstallDel(object):
                                            """
                                            Total number of install to PIM for del
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:total-pim-install-del'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallDel']['meta_info']


                                        class TotalPimCallbackAdd(object):
                                            """
                                            Total number of Pim callbacks for add
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:total-pim-callback-add'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAdd']['meta_info']


                                        class TotalPimCallbackDel(object):
                                            """
                                            Total number of Pim callbacks for del
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:total-pim-callback-del'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDel']['meta_info']


                                        class TotalPimCallbackAddLocal(object):
                                            """
                                            Total number of Pim callbacks for local add
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:total-pim-callback-add-local'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAddLocal']['meta_info']


                                        class TotalPimCallbackDelLocal(object):
                                            """
                                            Total number of Pim callbacks for Local del
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:total-pim-callback-del-local'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDelLocal']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:global'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.first_nbr_up_time is not None:
                                                return True

                                            if self.has_converged is not None:
                                                return True

                                            if self.mode_enter_time is not None:
                                                for child_ref in self.mode_enter_time:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.total_pim_callback_add is not None:
                                                for child_ref in self.total_pim_callback_add:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.total_pim_callback_add_local is not None:
                                                for child_ref in self.total_pim_callback_add_local:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.total_pim_callback_batch is not None:
                                                return True

                                            if self.total_pim_callback_del is not None:
                                                for child_ref in self.total_pim_callback_del:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.total_pim_callback_del_local is not None:
                                                for child_ref in self.total_pim_callback_del_local:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.total_pim_callbacks is not None:
                                                return True

                                            if self.total_pim_install is not None:
                                                return True

                                            if self.total_pim_install_add is not None:
                                                for child_ref in self.total_pim_install_add:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.total_pim_install_del is not None:
                                                for child_ref in self.total_pim_install_del:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_']['meta_info']


                                    class Vrf(object):
                                        """
                                        VRF information
                                        
                                        .. attribute:: attributes_recover_from_rib
                                        
                                        	No. of attributes recovered from RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attributes_removed_from_rib
                                        
                                        	No. of attributes withdrawn from RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attributes_sent_to_rib
                                        
                                        	No. of attributes sent to RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: first_rib_table_full_timestamp
                                        
                                        	Timestamp when RIB table was full for the first time
                                        	**type**\:   :py:class:`FirstRibTableFullTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableFullTimestamp>`
                                        
                                        .. attribute:: first_rib_table_full_version
                                        
                                        	Version when RIB table was full for the first time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: first_rib_table_has_space_timestamp
                                        
                                        	Timestamp when RIB table had space for the first time
                                        	**type**\:   :py:class:`FirstRibTableHasSpaceTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableHasSpaceTimestamp>`
                                        
                                        .. attribute:: first_rib_table_has_space_version
                                        
                                        	Version when RIB table had space for the first time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_added_path_count
                                        
                                        	Number of imported paths added
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_calls
                                        
                                        	Number of calls to import processing function
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_dest_net_processed_count
                                        
                                        	Number of destination nets processed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_removed_path_count
                                        
                                        	Number of imported paths removed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_replaced_path_count
                                        
                                        	Number of imported paths 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_src_net_processed_count
                                        
                                        	Number of source nets processed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_time
                                        
                                        	Time spent in import processing (milliseconds) Note time accounted against source nets
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: is_rib_table_full
                                        
                                        	Indicates if RIB table is in prefix\-limit state
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_added_count
                                        
                                        	Number of labels requested
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_calls
                                        
                                        	No. of calls to label allocation processing function
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_release_count
                                        
                                        	Number of labels released
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_rewrite_count
                                        
                                        	Number of label rewrites created
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_time
                                        
                                        	Time spent running label processing (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: last_rib_table_full_age
                                        
                                        	Time since RIB table was full for the last time (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_rib_table_full_timestamp
                                        
                                        	Timestamp when RIB table was full for the last time
                                        	**type**\:   :py:class:`LastRibTableFullTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableFullTimestamp>`
                                        
                                        .. attribute:: last_rib_table_full_version
                                        
                                        	Version when RIB table was full for the last time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_rib_table_has_space_age
                                        
                                        	Times since RIB table had space for the last time (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_rib_table_has_space_timestamp
                                        
                                        	Timestamp when RIB table had space for the last time
                                        	**type**\:   :py:class:`LastRibTableHasSpaceTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableHasSpaceTimestamp>`
                                        
                                        .. attribute:: last_rib_table_has_space_version
                                        
                                        	Version when RIB table had space for the last time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_removed_from_rib
                                        
                                        	No. of prefixes withdrawn from RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_resent_to_rib
                                        
                                        	No. of prefixes re\-sent to RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_sent_to_rib
                                        
                                        	No. of prefixes sent to RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_table_full_version
                                        
                                        	Version when RIB table became full (from non\-full)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_tbl_del_calls
                                        
                                        	No. of rib update skipped on account of table delete
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_tbl_invalid_calls
                                        
                                        	No. of  rib update skipped due to table invalid
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_tbl_local_label
                                        
                                        	No. of rib update skipped. due to no local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_tbl_retry
                                        
                                        	No. of table rib retires
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_tbl_skip_calls
                                        
                                        	No. of rib update skipped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_trigger
                                        
                                        	Rib trigger enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: rib_update_calls
                                        
                                        	No. of calls to RIB update function
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_update_time
                                        
                                        	Time spent sending RIB updates (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: scanner_runs
                                        
                                        	# of times scanner has run
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: scanner_time
                                        
                                        	Time spent running scanner (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: subgroup_count
                                        
                                        	No. of update subgroup
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_label_retain
                                        
                                        	Time last label retentiontriggered 
                                        	**type**\:   :py:class:`TimeLabelRetain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeLabelRetain>`
                                        
                                        .. attribute:: time_last_update_sent
                                        
                                        	Time last update was sent (seconds since Jan 1 1970)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_rib_coverged
                                        
                                        	Time last RIB ack was sent 
                                        	**type**\:   :py:class:`TimeRibCoverged <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibCoverged>`
                                        
                                        .. attribute:: time_rib_down
                                        
                                        	Time last RIB down wassent. This field is deprecated
                                        	**type**\:   :py:class:`TimeRibDown <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibDown>`
                                        
                                        .. attribute:: update_generation_be_prefixes_count
                                        
                                        	No. of be prefixes updates generated for
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_calls
                                        
                                        	No. of calls to update generation function
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_messages_count
                                        
                                        	No. of update messages generated
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_prefixes_count
                                        
                                        	No. of prefixes updates generated for
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_time
                                        
                                        	Time spent generating updates (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: update_group_count
                                        
                                        	No. of update group
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf_flags
                                        
                                        	VRF flags for debug display
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.attributes_recover_from_rib = None
                                            self.attributes_removed_from_rib = None
                                            self.attributes_sent_to_rib = None
                                            self.first_rib_table_full_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableFullTimestamp()
                                            self.first_rib_table_full_timestamp.parent = self
                                            self.first_rib_table_full_version = None
                                            self.first_rib_table_has_space_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableHasSpaceTimestamp()
                                            self.first_rib_table_has_space_timestamp.parent = self
                                            self.first_rib_table_has_space_version = None
                                            self.import_added_path_count = None
                                            self.import_calls = None
                                            self.import_dest_net_processed_count = None
                                            self.import_removed_path_count = None
                                            self.import_replaced_path_count = None
                                            self.import_src_net_processed_count = None
                                            self.import_time = None
                                            self.is_rib_table_full = None
                                            self.label_added_count = None
                                            self.label_calls = None
                                            self.label_release_count = None
                                            self.label_rewrite_count = None
                                            self.label_time = None
                                            self.last_rib_table_full_age = None
                                            self.last_rib_table_full_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableFullTimestamp()
                                            self.last_rib_table_full_timestamp.parent = self
                                            self.last_rib_table_full_version = None
                                            self.last_rib_table_has_space_age = None
                                            self.last_rib_table_has_space_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableHasSpaceTimestamp()
                                            self.last_rib_table_has_space_timestamp.parent = self
                                            self.last_rib_table_has_space_version = None
                                            self.prefixes_removed_from_rib = None
                                            self.prefixes_resent_to_rib = None
                                            self.prefixes_sent_to_rib = None
                                            self.rib_table_full_version = None
                                            self.rib_tbl_del_calls = None
                                            self.rib_tbl_invalid_calls = None
                                            self.rib_tbl_local_label = None
                                            self.rib_tbl_retry = None
                                            self.rib_tbl_skip_calls = None
                                            self.rib_trigger = None
                                            self.rib_update_calls = None
                                            self.rib_update_time = None
                                            self.scanner_runs = None
                                            self.scanner_time = None
                                            self.subgroup_count = None
                                            self.time_label_retain = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeLabelRetain()
                                            self.time_label_retain.parent = self
                                            self.time_last_update_sent = None
                                            self.time_rib_coverged = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibCoverged()
                                            self.time_rib_coverged.parent = self
                                            self.time_rib_down = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibDown()
                                            self.time_rib_down.parent = self
                                            self.update_generation_be_prefixes_count = None
                                            self.update_generation_calls = None
                                            self.update_generation_messages_count = None
                                            self.update_generation_prefixes_count = None
                                            self.update_generation_time = None
                                            self.update_group_count = None
                                            self.vrf_flags = None


                                        class TimeRibCoverged(object):
                                            """
                                            Time last RIB ack was sent 
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:time-rib-coverged'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibCoverged']['meta_info']


                                        class TimeRibDown(object):
                                            """
                                            Time last RIB down wassent. This field is
                                            deprecated
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:time-rib-down'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibDown']['meta_info']


                                        class FirstRibTableFullTimestamp(object):
                                            """
                                            Timestamp when RIB table was full for the first
                                            time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-rib-table-full-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableFullTimestamp']['meta_info']


                                        class LastRibTableFullTimestamp(object):
                                            """
                                            Timestamp when RIB table was full for the last
                                            time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-rib-table-full-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableFullTimestamp']['meta_info']


                                        class FirstRibTableHasSpaceTimestamp(object):
                                            """
                                            Timestamp when RIB table had space for the first
                                            time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-rib-table-has-space-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableHasSpaceTimestamp']['meta_info']


                                        class LastRibTableHasSpaceTimestamp(object):
                                            """
                                            Timestamp when RIB table had space for the last
                                            time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-rib-table-has-space-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableHasSpaceTimestamp']['meta_info']


                                        class TimeLabelRetain(object):
                                            """
                                            Time last label retentiontriggered 
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:time-label-retain'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeLabelRetain']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:vrf'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.attributes_recover_from_rib is not None:
                                                return True

                                            if self.attributes_removed_from_rib is not None:
                                                return True

                                            if self.attributes_sent_to_rib is not None:
                                                return True

                                            if self.first_rib_table_full_timestamp is not None and self.first_rib_table_full_timestamp._has_data():
                                                return True

                                            if self.first_rib_table_full_version is not None:
                                                return True

                                            if self.first_rib_table_has_space_timestamp is not None and self.first_rib_table_has_space_timestamp._has_data():
                                                return True

                                            if self.first_rib_table_has_space_version is not None:
                                                return True

                                            if self.import_added_path_count is not None:
                                                return True

                                            if self.import_calls is not None:
                                                return True

                                            if self.import_dest_net_processed_count is not None:
                                                return True

                                            if self.import_removed_path_count is not None:
                                                return True

                                            if self.import_replaced_path_count is not None:
                                                return True

                                            if self.import_src_net_processed_count is not None:
                                                return True

                                            if self.import_time is not None:
                                                return True

                                            if self.is_rib_table_full is not None:
                                                return True

                                            if self.label_added_count is not None:
                                                return True

                                            if self.label_calls is not None:
                                                return True

                                            if self.label_release_count is not None:
                                                return True

                                            if self.label_rewrite_count is not None:
                                                return True

                                            if self.label_time is not None:
                                                return True

                                            if self.last_rib_table_full_age is not None:
                                                return True

                                            if self.last_rib_table_full_timestamp is not None and self.last_rib_table_full_timestamp._has_data():
                                                return True

                                            if self.last_rib_table_full_version is not None:
                                                return True

                                            if self.last_rib_table_has_space_age is not None:
                                                return True

                                            if self.last_rib_table_has_space_timestamp is not None and self.last_rib_table_has_space_timestamp._has_data():
                                                return True

                                            if self.last_rib_table_has_space_version is not None:
                                                return True

                                            if self.prefixes_removed_from_rib is not None:
                                                return True

                                            if self.prefixes_resent_to_rib is not None:
                                                return True

                                            if self.prefixes_sent_to_rib is not None:
                                                return True

                                            if self.rib_table_full_version is not None:
                                                return True

                                            if self.rib_tbl_del_calls is not None:
                                                return True

                                            if self.rib_tbl_invalid_calls is not None:
                                                return True

                                            if self.rib_tbl_local_label is not None:
                                                return True

                                            if self.rib_tbl_retry is not None:
                                                return True

                                            if self.rib_tbl_skip_calls is not None:
                                                return True

                                            if self.rib_trigger is not None:
                                                return True

                                            if self.rib_update_calls is not None:
                                                return True

                                            if self.rib_update_time is not None:
                                                return True

                                            if self.scanner_runs is not None:
                                                return True

                                            if self.scanner_time is not None:
                                                return True

                                            if self.subgroup_count is not None:
                                                return True

                                            if self.time_label_retain is not None and self.time_label_retain._has_data():
                                                return True

                                            if self.time_last_update_sent is not None:
                                                return True

                                            if self.time_rib_coverged is not None and self.time_rib_coverged._has_data():
                                                return True

                                            if self.time_rib_down is not None and self.time_rib_down._has_data():
                                                return True

                                            if self.update_generation_be_prefixes_count is not None:
                                                return True

                                            if self.update_generation_calls is not None:
                                                return True

                                            if self.update_generation_messages_count is not None:
                                                return True

                                            if self.update_generation_prefixes_count is not None:
                                                return True

                                            if self.update_generation_time is not None:
                                                return True

                                            if self.update_group_count is not None:
                                                return True

                                            if self.vrf_flags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:performance-statistics'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.global_ is not None and self.global_._has_data():
                                            return True

                                        if self.vrf is not None and self.vrf._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af-process-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.global_ is not None and self.global_._has_data():
                                        return True

                                    if self.performance_statistics is not None and self.performance_statistics._has_data():
                                        return True

                                    if self.process_instance is not None:
                                        return True

                                    if self.vrf is not None and self.vrf._has_data():
                                        return True

                                    if self.vrf_name is not None:
                                        return True

                                    if self.vrf_totals is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo']['meta_info']


                            class PathUsedTable(object):
                                """
                                The BGP Path Used Table
                                
                                .. attribute:: path
                                
                                	A BGP path table entry
                                	**type**\: list of    :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.path = YList()
                                    self.path.parent = self
                                    self.path.name = 'path'


                                class Path(object):
                                    """
                                    A BGP path table entry
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: attributes_after_policy_in
                                    
                                    	Attributes after inbound policy applied
                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn>`
                                    
                                    .. attribute:: label_fail
                                    
                                    	LSD label allocation failed 
                                    	**type**\:  bool
                                    
                                    .. attribute:: label_o_or_version
                                    
                                    	Label Version when OOR happens
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_oor
                                    
                                    	LSD label space is exhausted
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor adddress
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr>`
                                    
                                    .. attribute:: network
                                    
                                    	Network Prefix in Hex format
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: no_path
                                    
                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_id
                                    
                                    	Received Path ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: path_information
                                    
                                    	Path information
                                    	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: prefix_version
                                    
                                    	Version of BGP Prefix Table
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: route_type
                                    
                                    	Route Type
                                    	**type**\:   :py:class:`BgpRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRouteEnum>`
                                    
                                    .. attribute:: source_rd
                                    
                                    	Source Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: source_route_distinguisher
                                    
                                    	Source Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_vrf_name
                                    
                                    	Name of the source VRF
                                    	**type**\:  str
                                    
                                    .. attribute:: srcaf_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn()
                                        self.attributes_after_policy_in.parent = self
                                        self.label_fail = None
                                        self.label_o_or_version = None
                                        self.label_oor = None
                                        self.neighbor_address = None
                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr()
                                        self.neighbor_address_xr.parent = self
                                        self.network = None
                                        self.no_path = None
                                        self.path_id = None
                                        self.path_information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation()
                                        self.path_information.parent = self
                                        self.prefix_length = None
                                        self.prefix_version = None
                                        self.process_instance_id = None
                                        self.rd = None
                                        self.route_distinguisher = None
                                        self.route_type = None
                                        self.source_rd = None
                                        self.source_route_distinguisher = None
                                        self.source_vrf_name = None
                                        self.srcaf_name = None
                                        self.vrf_name = None


                                    class NeighborAddressXr(object):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr']['meta_info']


                                    class PathInformation(object):
                                        """
                                        Path information
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_own_self_originated_p_ath
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\:  bool
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield>`
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner>`
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix>`
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity>`
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\:  bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\:  bool
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr>`
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_esi
                                        
                                        	Path has EVPN ESI
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_rcvd_label
                                        
                                        	Path has received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\:  bool
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebg_ps
                                        
                                        	Not advertised to EBGPs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.L2VpnCircuitStatusValue>`
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.L2VpnEvpnEsi>`
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr>`
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue>`
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress>`
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop>`
                                        
                                        .. attribute:: nhte_tunnel
                                        
                                        	NH TE tunnel information
                                        	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhteTunnel>`
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\:  bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.accept_own_path = None
                                            self.accept_own_self_originated_p_ath = None
                                            self.add_path_orr_bitfield = YList()
                                            self.add_path_orr_bitfield.parent = self
                                            self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                            self.advertisedto_pe = None
                                            self.aigp_metric = None
                                            self.best_path_comp_stage = None
                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self.best_path_id = None
                                            self.best_path_id_comp_winner = None
                                            self.best_path_orr_bitfield = YList()
                                            self.best_path_orr_bitfield.parent = self
                                            self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self.dampen_penalty = None
                                            self.extended_community = YList()
                                            self.extended_community.parent = self
                                            self.extended_community.name = 'extended_community'
                                            self.fspec_invalid_path = None
                                            self.graceful_shutdown = None
                                            self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr()
                                            self.gw_addr.parent = self
                                            self.halflife_time = None
                                            self.has_esi = None
                                            self.has_gw_addr = None
                                            self.has_local_net_label = None
                                            self.has_mdt_group_addr = None
                                            self.has_mvpn_extcomm = None
                                            self.has_mvpn_nbr_addr = None
                                            self.has_mvpn_nexthop_addr = None
                                            self.has_mvpn_pmsi = None
                                            self.has_rcvd_label = None
                                            self.has_second_label = None
                                            self.ibgp_signaled_validity = None
                                            self.igp_metric = None
                                            self.is_aggregation_suppressed = None
                                            self.is_as_best = None
                                            self.is_best_path = None
                                            self.is_import_dampened = None
                                            self.is_import_suspect = None
                                            self.is_internal_path = None
                                            self.is_partial_best = None
                                            self.is_path_additional_path = None
                                            self.is_path_advertised_local_as_only = None
                                            self.is_path_af_install_eligible = None
                                            self.is_path_backup = None
                                            self.is_path_backup_protect_multipath = None
                                            self.is_path_best_external = None
                                            self.is_path_damped = None
                                            self.is_path_from_confederation_peer = None
                                            self.is_path_from_network_command = None
                                            self.is_path_from_redistribute_command = None
                                            self.is_path_from_route_reflector = None
                                            self.is_path_history_held = None
                                            self.is_path_imp_candidate = None
                                            self.is_path_imported = None
                                            self.is_path_local_aggregate = None
                                            self.is_path_locally_sourced = None
                                            self.is_path_long_lived_stale = None
                                            self.is_path_multipath = None
                                            self.is_path_nexthop_discarded = None
                                            self.is_path_not_advertised = None
                                            self.is_path_not_advertised_to_ebg_ps = None
                                            self.is_path_received_only = None
                                            self.is_path_reoriginated = None
                                            self.is_path_reoriginated_stitching = None
                                            self.is_path_stale = None
                                            self.is_path_synced_with_igp = None
                                            self.is_path_valid = None
                                            self.is_path_vpn_only = None
                                            self.is_permanent_path = None
                                            self.is_received_path_not_modified = None
                                            self.is_spkr_as_best = None
                                            self.l2vpn_circuit_status_value = YList()
                                            self.l2vpn_circuit_status_value.parent = self
                                            self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                            self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.L2VpnEvpnEsi()
                                            self.l2vpn_evpn_esi.parent = self
                                            self.l2vpn_size = None
                                            self.labeled_unicast_safi_path = None
                                            self.local_label = None
                                            self.local_nh = None
                                            self.local_path_id = None
                                            self.local_peers_advertised_to = YList()
                                            self.local_peers_advertised_to.parent = self
                                            self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                            self.maximum_suppress_time = None
                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self.mvpn_path_flags = None
                                            self.mvpn_pmsi_flags = None
                                            self.mvpn_pmsi_label = None
                                            self.mvpn_pmsi_type = None
                                            self.mvpn_pmsi_value = YList()
                                            self.mvpn_pmsi_value.parent = self
                                            self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                            self.mvpn_sfs_path = None
                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self.neighbor_router_id = None
                                            self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop()
                                            self.next_hop.parent = self
                                            self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhteTunnel()
                                            self.nhte_tunnel.parent = self
                                            self.path_flags = None
                                            self.path_flap_count = None
                                            self.path_import_flags = None
                                            self.path_rt_set_id = None
                                            self.path_rt_set_route_count = None
                                            self.path_table_version = None
                                            self.path_weight = None
                                            self.pe_peers_advertised_to = YList()
                                            self.pe_peers_advertised_to.parent = self
                                            self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                            self.rcvd_label = None
                                            self.rcvd_path_id = None
                                            self.reuse_value = None
                                            self.rib_failed = None
                                            self.route_type = None
                                            self.rpki_origin_as_validation_disabled = None
                                            self.rt_set_limit_enabled = None
                                            self.second_label = None
                                            self.seconds_since_first_flap = None
                                            self.show_rpki_origin_as_validity = None
                                            self.sn_rpki_origin_as_validity = None
                                            self.suppress_penalty = None
                                            self.time_to_unsuppress = None


                                        class BgpPrefix(object):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self.prefix_length = None


                                            class Prefix(object):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.prefix is not None and self.prefix._has_data():
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix']['meta_info']


                                        class NeighborAddress(object):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress']['meta_info']


                                        class NextHop(object):
                                            """
                                            Next hop
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop']['meta_info']


                                        class NhteTunnel(object):
                                            """
                                            NH TE tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_te_tunnel
                                            
                                            	NH TE Tunnel info is present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last rib update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	tunnel name
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	tunnel type
                                            	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.binding_label = None
                                                self.has_te_tunnel = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.is_tunnel_up = None
                                                self.last_tunnel_update = None
                                                self.tunnel_if_handle = None
                                                self.tunnel_name = None
                                                self.tunnel_type = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_v6_required = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.binding_label is not None:
                                                    return True

                                                if self.has_te_tunnel is not None:
                                                    return True

                                                if self.is_tunnel_info_stale is not None:
                                                    return True

                                                if self.is_tunnel_registered is not None:
                                                    return True

                                                if self.is_tunnel_up is not None:
                                                    return True

                                                if self.last_tunnel_update is not None:
                                                    return True

                                                if self.tunnel_if_handle is not None:
                                                    return True

                                                if self.tunnel_name is not None:
                                                    return True

                                                if self.tunnel_type is not None:
                                                    return True

                                                if self.tunnel_v6_enabled is not None:
                                                    return True

                                                if self.tunnel_v6_required is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhteTunnel']['meta_info']


                                        class MdtGroupAddr(object):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr']['meta_info']


                                        class L2VpnEvpnEsi(object):
                                            """
                                            L2VPN EVPN ESI
                                            
                                            .. attribute:: esi
                                            
                                            	esi
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.esi = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.esi is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.L2VpnEvpnEsi']['meta_info']


                                        class GwAddr(object):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.len = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.len is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr']['meta_info']


                                        class BestPathCompWinner(object):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner']['meta_info']


                                        class MvpnNbrAddr(object):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr']['meta_info']


                                        class MvpnNexthopAddr(object):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr']['meta_info']


                                        class L2VpnCircuitStatusValue(object):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                        class MvpnPmsiValue(object):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue']['meta_info']


                                        class ExtendedCommunity(object):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity']['meta_info']


                                        class LocalPeersAdvertisedTo(object):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                        class PePeersAdvertisedTo(object):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo']['meta_info']


                                        class BestPathOrrBitfield(object):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield']['meta_info']


                                        class AddPathOrrBitfield(object):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.accept_own_path is not None:
                                                return True

                                            if self.accept_own_self_originated_p_ath is not None:
                                                return True

                                            if self.add_path_orr_bitfield is not None:
                                                for child_ref in self.add_path_orr_bitfield:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.advertisedto_pe is not None:
                                                return True

                                            if self.aigp_metric is not None:
                                                return True

                                            if self.best_path_comp_stage is not None:
                                                return True

                                            if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                return True

                                            if self.best_path_id is not None:
                                                return True

                                            if self.best_path_id_comp_winner is not None:
                                                return True

                                            if self.best_path_orr_bitfield is not None:
                                                for child_ref in self.best_path_orr_bitfield:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                return True

                                            if self.dampen_penalty is not None:
                                                return True

                                            if self.extended_community is not None:
                                                for child_ref in self.extended_community:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.fspec_invalid_path is not None:
                                                return True

                                            if self.graceful_shutdown is not None:
                                                return True

                                            if self.gw_addr is not None and self.gw_addr._has_data():
                                                return True

                                            if self.halflife_time is not None:
                                                return True

                                            if self.has_esi is not None:
                                                return True

                                            if self.has_gw_addr is not None:
                                                return True

                                            if self.has_local_net_label is not None:
                                                return True

                                            if self.has_mdt_group_addr is not None:
                                                return True

                                            if self.has_mvpn_extcomm is not None:
                                                return True

                                            if self.has_mvpn_nbr_addr is not None:
                                                return True

                                            if self.has_mvpn_nexthop_addr is not None:
                                                return True

                                            if self.has_mvpn_pmsi is not None:
                                                return True

                                            if self.has_rcvd_label is not None:
                                                return True

                                            if self.has_second_label is not None:
                                                return True

                                            if self.ibgp_signaled_validity is not None:
                                                return True

                                            if self.igp_metric is not None:
                                                return True

                                            if self.is_aggregation_suppressed is not None:
                                                return True

                                            if self.is_as_best is not None:
                                                return True

                                            if self.is_best_path is not None:
                                                return True

                                            if self.is_import_dampened is not None:
                                                return True

                                            if self.is_import_suspect is not None:
                                                return True

                                            if self.is_internal_path is not None:
                                                return True

                                            if self.is_partial_best is not None:
                                                return True

                                            if self.is_path_additional_path is not None:
                                                return True

                                            if self.is_path_advertised_local_as_only is not None:
                                                return True

                                            if self.is_path_af_install_eligible is not None:
                                                return True

                                            if self.is_path_backup is not None:
                                                return True

                                            if self.is_path_backup_protect_multipath is not None:
                                                return True

                                            if self.is_path_best_external is not None:
                                                return True

                                            if self.is_path_damped is not None:
                                                return True

                                            if self.is_path_from_confederation_peer is not None:
                                                return True

                                            if self.is_path_from_network_command is not None:
                                                return True

                                            if self.is_path_from_redistribute_command is not None:
                                                return True

                                            if self.is_path_from_route_reflector is not None:
                                                return True

                                            if self.is_path_history_held is not None:
                                                return True

                                            if self.is_path_imp_candidate is not None:
                                                return True

                                            if self.is_path_imported is not None:
                                                return True

                                            if self.is_path_local_aggregate is not None:
                                                return True

                                            if self.is_path_locally_sourced is not None:
                                                return True

                                            if self.is_path_long_lived_stale is not None:
                                                return True

                                            if self.is_path_multipath is not None:
                                                return True

                                            if self.is_path_nexthop_discarded is not None:
                                                return True

                                            if self.is_path_not_advertised is not None:
                                                return True

                                            if self.is_path_not_advertised_to_ebg_ps is not None:
                                                return True

                                            if self.is_path_received_only is not None:
                                                return True

                                            if self.is_path_reoriginated is not None:
                                                return True

                                            if self.is_path_reoriginated_stitching is not None:
                                                return True

                                            if self.is_path_stale is not None:
                                                return True

                                            if self.is_path_synced_with_igp is not None:
                                                return True

                                            if self.is_path_valid is not None:
                                                return True

                                            if self.is_path_vpn_only is not None:
                                                return True

                                            if self.is_permanent_path is not None:
                                                return True

                                            if self.is_received_path_not_modified is not None:
                                                return True

                                            if self.is_spkr_as_best is not None:
                                                return True

                                            if self.l2vpn_circuit_status_value is not None:
                                                for child_ref in self.l2vpn_circuit_status_value:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                return True

                                            if self.l2vpn_size is not None:
                                                return True

                                            if self.labeled_unicast_safi_path is not None:
                                                return True

                                            if self.local_label is not None:
                                                return True

                                            if self.local_nh is not None:
                                                return True

                                            if self.local_path_id is not None:
                                                return True

                                            if self.local_peers_advertised_to is not None:
                                                for child_ref in self.local_peers_advertised_to:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.maximum_suppress_time is not None:
                                                return True

                                            if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                return True

                                            if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                return True

                                            if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                return True

                                            if self.mvpn_path_flags is not None:
                                                return True

                                            if self.mvpn_pmsi_flags is not None:
                                                return True

                                            if self.mvpn_pmsi_label is not None:
                                                return True

                                            if self.mvpn_pmsi_type is not None:
                                                return True

                                            if self.mvpn_pmsi_value is not None:
                                                for child_ref in self.mvpn_pmsi_value:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.mvpn_sfs_path is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            if self.neighbor_router_id is not None:
                                                return True

                                            if self.next_hop is not None and self.next_hop._has_data():
                                                return True

                                            if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                return True

                                            if self.path_flags is not None:
                                                return True

                                            if self.path_flap_count is not None:
                                                return True

                                            if self.path_import_flags is not None:
                                                return True

                                            if self.path_rt_set_id is not None:
                                                return True

                                            if self.path_rt_set_route_count is not None:
                                                return True

                                            if self.path_table_version is not None:
                                                return True

                                            if self.path_weight is not None:
                                                return True

                                            if self.pe_peers_advertised_to is not None:
                                                for child_ref in self.pe_peers_advertised_to:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.rcvd_label is not None:
                                                return True

                                            if self.rcvd_path_id is not None:
                                                return True

                                            if self.reuse_value is not None:
                                                return True

                                            if self.rib_failed is not None:
                                                return True

                                            if self.route_type is not None:
                                                return True

                                            if self.rpki_origin_as_validation_disabled is not None:
                                                return True

                                            if self.rt_set_limit_enabled is not None:
                                                return True

                                            if self.second_label is not None:
                                                return True

                                            if self.seconds_since_first_flap is not None:
                                                return True

                                            if self.show_rpki_origin_as_validity is not None:
                                                return True

                                            if self.sn_rpki_origin_as_validity is not None:
                                                return True

                                            if self.suppress_penalty is not None:
                                                return True

                                            if self.time_to_unsuppress is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation']['meta_info']


                                    class AttributesAfterPolicyIn(object):
                                        """
                                        Attributes after inbound policy applied
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet>`
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes>`
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp>`
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr>`
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\:  bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet()
                                            self.attr_set.parent = self
                                            self.attribute_key_number = None
                                            self.attribute_reuse_id_config = None
                                            self.attribute_reuse_id_current = None
                                            self.attribute_reuse_id_keys = None
                                            self.attribute_reuse_id_max_id = None
                                            self.attribute_reuse_id_node = None
                                            self.attribute_reuse_id_recover_sec = None
                                            self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self.is_application_gateway_present = None
                                            self.is_as_path2_byte = None
                                            self.is_attr_set_present = None
                                            self.is_ribrnh_present = None
                                            self.is_rnh_present = None
                                            self.ribrnh_encap = None
                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self.ribrnh_mac = None
                                            self.ribrnh_table = None
                                            self.ribrnh_vni = None
                                            self.ribrnhip_table = None
                                            self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self.rnh_addr_len = None
                                            self.rnh_len = None
                                            self.rnh_type = None
                                            self.set_aigp_inbound_igp = None
                                            self.set_aigp_inbound_metric = None
                                            self.vpn_distinguisher = None


                                        class CommonAttributes(object):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_encap_present
                                            
                                            	Tunnel Encap attribute present 
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_policy_allocated_binding_sid
                                            
                                            	SR Policy allocated Binding sid by the router
                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                            
                                            .. attribute:: sr_policy_binding_sid
                                            
                                            	SR Policy Binding sid
                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                            
                                            .. attribute:: sr_policy_explicit_path
                                            
                                            	SR Policy Explicit paths
                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                            
                                            .. attribute:: sr_policy_preference
                                            
                                            	SR Policy Preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_tunnel_request_state
                                            
                                            	SR Tunnel Request State
                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                            
                                            .. attribute:: sr_tunnel_state
                                            
                                            	SR Tunnel State
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap_type
                                            
                                            	Tunnel Encap Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.aggregator_address = None
                                                self.aggregator_as = None
                                                self.aigp_metric_value = None
                                                self.as_path = None
                                                self.cluster = YList()
                                                self.cluster.parent = self
                                                self.cluster.name = 'cluster'
                                                self.community = YList()
                                                self.community.parent = self
                                                self.community.name = 'community'
                                                self.connector_type = None
                                                self.connector_value = YList()
                                                self.connector_value.parent = self
                                                self.connector_value.name = 'connector_value'
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.extended_community_flags = None
                                                self.is_aggregator_present = None
                                                self.is_aigp_present = None
                                                self.is_as_path_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_community_present = None
                                                self.is_connector_present = None
                                                self.is_extended_community_present = None
                                                self.is_label_index_present = None
                                                self.is_local_pref_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_metric_present = None
                                                self.is_origin_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_ssa_present = None
                                                self.is_tunnel_encap_present = None
                                                self.l2tpv3_cookie = YList()
                                                self.l2tpv3_cookie.parent = self
                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                self.l2tpv3_session_id = None
                                                self.label_index_attr = YList()
                                                self.label_index_attr.parent = self
                                                self.label_index_attr.name = 'label_index_attr'
                                                self.local_preference = None
                                                self.ls_attr = YList()
                                                self.ls_attr.parent = self
                                                self.ls_attr.name = 'ls_attr'
                                                self.metric = None
                                                self.neighbor_as = None
                                                self.origin = None
                                                self.originator = None
                                                self.pe_distinguisher_label = YList()
                                                self.pe_distinguisher_label.parent = self
                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.pmsi_type = None
                                                self.pmsi_value = YList()
                                                self.pmsi_value.parent = self
                                                self.pmsi_value.name = 'pmsi_value'
                                                self.ppm_pvalue = None
                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                self.sr_policy_allocated_binding_sid.parent = self
                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                self.sr_policy_binding_sid.parent = self
                                                self.sr_policy_explicit_path = YList()
                                                self.sr_policy_explicit_path.parent = self
                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                self.sr_policy_preference = None
                                                self.sr_tunnel_request_state = None
                                                self.sr_tunnel_state = None
                                                self.tunnel_encap_type = None
                                                self.unknown_attribute = YList()
                                                self.unknown_attribute.parent = self
                                                self.unknown_attribute.name = 'unknown_attribute'


                                            class SrPolicyBindingSid(object):
                                                """
                                                SR Policy Binding sid
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                            class SrPolicyAllocatedBindingSid(object):
                                                """
                                                SR Policy allocated Binding sid by the router
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                            class Community(object):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                            class UnknownAttribute(object):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                            class Cluster(object):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                            class L2Tpv3Cookie(object):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                            class ConnectorValue(object):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                            class PmsiValue(object):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                            class LsAttr(object):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                            class LabelIndexAttr(object):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                            class PeDistinguisherLabel(object):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.label = None
                                                    self.pe_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.label is not None:
                                                        return True

                                                    if self.pe_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                            class SrPolicyExplicitPath(object):
                                                """
                                                SR Policy Explicit paths
                                                
                                                .. attribute:: sid
                                                
                                                	Sidlist for explicit path
                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                
                                                .. attribute:: weight
                                                
                                                	Weight of explicit path
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.sid = YList()
                                                    self.sid.parent = self
                                                    self.sid.name = 'sid'
                                                    self.weight = None


                                                class Sid(object):
                                                    """
                                                    Sidlist for explicit path
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IP Address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label sid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Sid Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4 is not None:
                                                            return True

                                                        if self.ipv6 is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.sid is not None:
                                                        for child_ref in self.sid:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.weight is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.aggregator_address is not None:
                                                    return True

                                                if self.aggregator_as is not None:
                                                    return True

                                                if self.aigp_metric_value is not None:
                                                    return True

                                                if self.as_path is not None:
                                                    return True

                                                if self.cluster is not None:
                                                    for child_ref in self.cluster:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.community is not None:
                                                    for child_ref in self.community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.connector_type is not None:
                                                    return True

                                                if self.connector_value is not None:
                                                    for child_ref in self.connector_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community_flags is not None:
                                                    return True

                                                if self.is_aggregator_present is not None:
                                                    return True

                                                if self.is_aigp_present is not None:
                                                    return True

                                                if self.is_as_path_present is not None:
                                                    return True

                                                if self.is_atomic_aggregate_present is not None:
                                                    return True

                                                if self.is_community_present is not None:
                                                    return True

                                                if self.is_connector_present is not None:
                                                    return True

                                                if self.is_extended_community_present is not None:
                                                    return True

                                                if self.is_label_index_present is not None:
                                                    return True

                                                if self.is_local_pref_present is not None:
                                                    return True

                                                if self.is_ls_attribute_present is not None:
                                                    return True

                                                if self.is_metric_present is not None:
                                                    return True

                                                if self.is_origin_present is not None:
                                                    return True

                                                if self.is_pe_distinguisher_label_present is not None:
                                                    return True

                                                if self.is_pmsi_present is not None:
                                                    return True

                                                if self.is_pppmp_present is not None:
                                                    return True

                                                if self.is_ssa_present is not None:
                                                    return True

                                                if self.is_tunnel_encap_present is not None:
                                                    return True

                                                if self.l2tpv3_cookie is not None:
                                                    for child_ref in self.l2tpv3_cookie:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2tpv3_session_id is not None:
                                                    return True

                                                if self.label_index_attr is not None:
                                                    for child_ref in self.label_index_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_preference is not None:
                                                    return True

                                                if self.ls_attr is not None:
                                                    for child_ref in self.ls_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.metric is not None:
                                                    return True

                                                if self.neighbor_as is not None:
                                                    return True

                                                if self.origin is not None:
                                                    return True

                                                if self.originator is not None:
                                                    return True

                                                if self.pe_distinguisher_label is not None:
                                                    for child_ref in self.pe_distinguisher_label:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.pmsi_flags is not None:
                                                    return True

                                                if self.pmsi_label is not None:
                                                    return True

                                                if self.pmsi_type is not None:
                                                    return True

                                                if self.pmsi_value is not None:
                                                    for child_ref in self.pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.ppm_pvalue is not None:
                                                    return True

                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_explicit_path is not None:
                                                    for child_ref in self.sr_policy_explicit_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.sr_policy_preference is not None:
                                                    return True

                                                if self.sr_tunnel_request_state is not None:
                                                    return True

                                                if self.sr_tunnel_state is not None:
                                                    return True

                                                if self.tunnel_encap_type is not None:
                                                    return True

                                                if self.unknown_attribute is not None:
                                                    for child_ref in self.unknown_attribute:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                        class AttrSet(object):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_encap_present
                                            
                                            	Tunnel Encap attribute present 
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_policy_allocated_binding_sid
                                            
                                            	SR Policy allocated Binding sid by the router
                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                            
                                            .. attribute:: sr_policy_binding_sid
                                            
                                            	SR Policy Binding sid
                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                            
                                            .. attribute:: sr_policy_explicit_path
                                            
                                            	SR Policy Explicit paths
                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                            
                                            .. attribute:: sr_policy_preference
                                            
                                            	SR Policy Preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_tunnel_request_state
                                            
                                            	SR Tunnel Request State
                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                            
                                            .. attribute:: sr_tunnel_state
                                            
                                            	SR Tunnel State
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap_type
                                            
                                            	Tunnel Encap Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.aggregator_address = None
                                                self.aggregator_as = None
                                                self.aigp_metric_value = None
                                                self.as_path = None
                                                self.cluster = YList()
                                                self.cluster.parent = self
                                                self.cluster.name = 'cluster'
                                                self.community = YList()
                                                self.community.parent = self
                                                self.community.name = 'community'
                                                self.connector_type = None
                                                self.connector_value = YList()
                                                self.connector_value.parent = self
                                                self.connector_value.name = 'connector_value'
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.extended_community_flags = None
                                                self.is_aggregator_present = None
                                                self.is_aigp_present = None
                                                self.is_as_path_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_community_present = None
                                                self.is_connector_present = None
                                                self.is_extended_community_present = None
                                                self.is_label_index_present = None
                                                self.is_local_pref_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_metric_present = None
                                                self.is_origin_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_ssa_present = None
                                                self.is_tunnel_encap_present = None
                                                self.l2tpv3_cookie = YList()
                                                self.l2tpv3_cookie.parent = self
                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                self.l2tpv3_session_id = None
                                                self.label_index_attr = YList()
                                                self.label_index_attr.parent = self
                                                self.label_index_attr.name = 'label_index_attr'
                                                self.local_preference = None
                                                self.ls_attr = YList()
                                                self.ls_attr.parent = self
                                                self.ls_attr.name = 'ls_attr'
                                                self.metric = None
                                                self.neighbor_as = None
                                                self.origin = None
                                                self.originator = None
                                                self.pe_distinguisher_label = YList()
                                                self.pe_distinguisher_label.parent = self
                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.pmsi_type = None
                                                self.pmsi_value = YList()
                                                self.pmsi_value.parent = self
                                                self.pmsi_value.name = 'pmsi_value'
                                                self.ppm_pvalue = None
                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                self.sr_policy_allocated_binding_sid.parent = self
                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                self.sr_policy_binding_sid.parent = self
                                                self.sr_policy_explicit_path = YList()
                                                self.sr_policy_explicit_path.parent = self
                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                self.sr_policy_preference = None
                                                self.sr_tunnel_request_state = None
                                                self.sr_tunnel_state = None
                                                self.tunnel_encap_type = None
                                                self.unknown_attribute = YList()
                                                self.unknown_attribute.parent = self
                                                self.unknown_attribute.name = 'unknown_attribute'


                                            class SrPolicyBindingSid(object):
                                                """
                                                SR Policy Binding sid
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                            class SrPolicyAllocatedBindingSid(object):
                                                """
                                                SR Policy allocated Binding sid by the router
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                            class Community(object):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                            class UnknownAttribute(object):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                            class Cluster(object):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                            class L2Tpv3Cookie(object):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                            class ConnectorValue(object):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                            class PmsiValue(object):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                            class LsAttr(object):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                            class LabelIndexAttr(object):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                            class PeDistinguisherLabel(object):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.label = None
                                                    self.pe_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.label is not None:
                                                        return True

                                                    if self.pe_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                            class SrPolicyExplicitPath(object):
                                                """
                                                SR Policy Explicit paths
                                                
                                                .. attribute:: sid
                                                
                                                	Sidlist for explicit path
                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                
                                                .. attribute:: weight
                                                
                                                	Weight of explicit path
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.sid = YList()
                                                    self.sid.parent = self
                                                    self.sid.name = 'sid'
                                                    self.weight = None


                                                class Sid(object):
                                                    """
                                                    Sidlist for explicit path
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IP Address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label sid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Sid Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4 is not None:
                                                            return True

                                                        if self.ipv6 is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.sid is not None:
                                                        for child_ref in self.sid:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.weight is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.aggregator_address is not None:
                                                    return True

                                                if self.aggregator_as is not None:
                                                    return True

                                                if self.aigp_metric_value is not None:
                                                    return True

                                                if self.as_path is not None:
                                                    return True

                                                if self.cluster is not None:
                                                    for child_ref in self.cluster:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.community is not None:
                                                    for child_ref in self.community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.connector_type is not None:
                                                    return True

                                                if self.connector_value is not None:
                                                    for child_ref in self.connector_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community_flags is not None:
                                                    return True

                                                if self.is_aggregator_present is not None:
                                                    return True

                                                if self.is_aigp_present is not None:
                                                    return True

                                                if self.is_as_path_present is not None:
                                                    return True

                                                if self.is_atomic_aggregate_present is not None:
                                                    return True

                                                if self.is_community_present is not None:
                                                    return True

                                                if self.is_connector_present is not None:
                                                    return True

                                                if self.is_extended_community_present is not None:
                                                    return True

                                                if self.is_label_index_present is not None:
                                                    return True

                                                if self.is_local_pref_present is not None:
                                                    return True

                                                if self.is_ls_attribute_present is not None:
                                                    return True

                                                if self.is_metric_present is not None:
                                                    return True

                                                if self.is_origin_present is not None:
                                                    return True

                                                if self.is_pe_distinguisher_label_present is not None:
                                                    return True

                                                if self.is_pmsi_present is not None:
                                                    return True

                                                if self.is_pppmp_present is not None:
                                                    return True

                                                if self.is_ssa_present is not None:
                                                    return True

                                                if self.is_tunnel_encap_present is not None:
                                                    return True

                                                if self.l2tpv3_cookie is not None:
                                                    for child_ref in self.l2tpv3_cookie:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2tpv3_session_id is not None:
                                                    return True

                                                if self.label_index_attr is not None:
                                                    for child_ref in self.label_index_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_preference is not None:
                                                    return True

                                                if self.ls_attr is not None:
                                                    for child_ref in self.ls_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.metric is not None:
                                                    return True

                                                if self.neighbor_as is not None:
                                                    return True

                                                if self.origin is not None:
                                                    return True

                                                if self.originator is not None:
                                                    return True

                                                if self.pe_distinguisher_label is not None:
                                                    for child_ref in self.pe_distinguisher_label:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.pmsi_flags is not None:
                                                    return True

                                                if self.pmsi_label is not None:
                                                    return True

                                                if self.pmsi_type is not None:
                                                    return True

                                                if self.pmsi_value is not None:
                                                    for child_ref in self.pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.ppm_pvalue is not None:
                                                    return True

                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_explicit_path is not None:
                                                    for child_ref in self.sr_policy_explicit_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.sr_policy_preference is not None:
                                                    return True

                                                if self.sr_tunnel_request_state is not None:
                                                    return True

                                                if self.sr_tunnel_state is not None:
                                                    return True

                                                if self.tunnel_encap_type is not None:
                                                    return True

                                                if self.unknown_attribute is not None:
                                                    for child_ref in self.unknown_attribute:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                        class RnhAddr(object):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.len = None
                                                self.mac_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.len is not None:
                                                    return True

                                                if self.mac_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                        class RibrnhIp(object):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.attr_set is not None and self.attr_set._has_data():
                                                return True

                                            if self.attribute_key_number is not None:
                                                return True

                                            if self.attribute_reuse_id_config is not None:
                                                return True

                                            if self.attribute_reuse_id_current is not None:
                                                return True

                                            if self.attribute_reuse_id_keys is not None:
                                                return True

                                            if self.attribute_reuse_id_max_id is not None:
                                                return True

                                            if self.attribute_reuse_id_node is not None:
                                                return True

                                            if self.attribute_reuse_id_recover_sec is not None:
                                                return True

                                            if self.common_attributes is not None and self.common_attributes._has_data():
                                                return True

                                            if self.is_application_gateway_present is not None:
                                                return True

                                            if self.is_as_path2_byte is not None:
                                                return True

                                            if self.is_attr_set_present is not None:
                                                return True

                                            if self.is_ribrnh_present is not None:
                                                return True

                                            if self.is_rnh_present is not None:
                                                return True

                                            if self.ribrnh_encap is not None:
                                                return True

                                            if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                return True

                                            if self.ribrnh_mac is not None:
                                                return True

                                            if self.ribrnh_table is not None:
                                                return True

                                            if self.ribrnh_vni is not None:
                                                return True

                                            if self.ribrnhip_table is not None:
                                                return True

                                            if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                return True

                                            if self.rnh_addr_len is not None:
                                                return True

                                            if self.rnh_len is not None:
                                                return True

                                            if self.rnh_type is not None:
                                                return True

                                            if self.set_aigp_inbound_igp is not None:
                                                return True

                                            if self.set_aigp_inbound_metric is not None:
                                                return True

                                            if self.vpn_distinguisher is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                            return True

                                        if self.label_fail is not None:
                                            return True

                                        if self.label_o_or_version is not None:
                                            return True

                                        if self.label_oor is not None:
                                            return True

                                        if self.neighbor_address is not None:
                                            return True

                                        if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                            return True

                                        if self.network is not None:
                                            return True

                                        if self.no_path is not None:
                                            return True

                                        if self.path_id is not None:
                                            return True

                                        if self.path_information is not None and self.path_information._has_data():
                                            return True

                                        if self.prefix_length is not None:
                                            return True

                                        if self.prefix_version is not None:
                                            return True

                                        if self.process_instance_id is not None:
                                            return True

                                        if self.rd is not None:
                                            return True

                                        if self.route_distinguisher is not None:
                                            return True

                                        if self.route_type is not None:
                                            return True

                                        if self.source_rd is not None:
                                            return True

                                        if self.source_route_distinguisher is not None:
                                            return True

                                        if self.source_vrf_name is not None:
                                            return True

                                        if self.srcaf_name is not None:
                                            return True

                                        if self.vrf_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-used-table'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.path is not None:
                                        for child_ref in self.path:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable']['meta_info']


                            class RpcSets(object):
                                """
                                BGP next\-hop set table
                                
                                .. attribute:: rpc_set
                                
                                	A BGP next\-hop set
                                	**type**\: list of    :py:class:`RpcSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.rpc_set = YList()
                                    self.rpc_set.parent = self
                                    self.rpc_set.name = 'rpc_set'


                                class RpcSet(object):
                                    """
                                    A BGP next\-hop set
                                    
                                    .. attribute:: rpc_set_index  <key>
                                    
                                    	Nexthop set index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: label
                                    
                                    	Label assigned to the RPCnext\-hop set
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hop
                                    
                                    	List of multipath next\-hops
                                    	**type**\: list of    :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop>`
                                    
                                    .. attribute:: next_hop_xr
                                    
                                    	Number of multipath next\-hops
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ref_count
                                    
                                    	Refcount
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.rpc_set_index = None
                                        self.label = None
                                        self.next_hop = YList()
                                        self.next_hop.parent = self
                                        self.next_hop.name = 'next_hop'
                                        self.next_hop_xr = None
                                        self.ref_count = None


                                    class NextHop(object):
                                        """
                                        List of multipath next\-hops
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.rpc_set_index is None:
                                            raise YPYModelError('Key property rpc_set_index is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rpc-set[Cisco-IOS-XR-ipv4-bgp-oper:rpc-set-index = ' + str(self.rpc_set_index) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.rpc_set_index is not None:
                                            return True

                                        if self.label is not None:
                                            return True

                                        if self.next_hop is not None:
                                            for child_ref in self.next_hop:
                                                if child_ref._has_data():
                                                    return True

                                        if self.next_hop_xr is not None:
                                            return True

                                        if self.ref_count is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rpc-sets'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.rpc_set is not None:
                                        for child_ref in self.rpc_set:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets']['meta_info']


                            class GlobalAfProcessInfo(object):
                                """
                                The Global Address Family Process information
                                table
                                
                                .. attribute:: af_name
                                
                                	Address family id
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: global_
                                
                                	Global information
                                	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_>`
                                
                                .. attribute:: is_nsr_enabled
                                
                                	Non\-stop routing enabled
                                	**type**\:  bool
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Vrf>`
                                
                                .. attribute:: vrf_name
                                
                                	Name of the VRF
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.global_ = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_()
                                    self.global_.parent = self
                                    self.is_nsr_enabled = None
                                    self.vrf = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Vrf()
                                    self.vrf.parent = self
                                    self.vrf_name = None


                                class Global_(object):
                                    """
                                    Global information
                                    
                                    .. attribute:: gblafrpki_allow_invalid
                                    
                                    	Prefix v. allow invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: gblafrpki_disable
                                    
                                    	Prefix validation disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: gblafrpki_signal_ibgp
                                    
                                    	Prefix v. signal ibgp
                                    	**type**\:  bool
                                    
                                    .. attribute:: gblafrpki_use_validity
                                    
                                    	Prefix v. use validity
                                    	**type**\:  bool
                                    
                                    .. attribute:: global_mcast_enabled
                                    
                                    	Is global table mcast enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: inter_as_install_enabled
                                    
                                    	Is inter\-AS install to pim on ASBR enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_perm_net_cfg
                                    
                                    	Permanent Network Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: nh_tunnel_version
                                    
                                    	NH Tunnel Version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: perm_nbr_count
                                    
                                    	Count of neighbors configured with perm net
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_del_count
                                    
                                    	Count of removed perm paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_existing_count
                                    
                                    	Count of existing perm paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_insert_count
                                    
                                    	Count of inserted perm paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_rpl_process_count
                                    
                                    	Count of perm nets processed in RPL
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_rpl_query_count
                                    
                                    	Count of perm nets given by RPL
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_stale_del_count
                                    
                                    	Count of stale perm paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_stale_mark_count
                                    
                                    	Count of stale marked perm paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_path_refresh_count
                                    
                                    	Count of perm paths refreshed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_pelem_all_bump_count
                                    
                                    	Count of bumped perm pelems
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_pelem_bump_count
                                    
                                    	Count of bumped perm pelems
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_pelem_free_count
                                    
                                    	Count of freed perm pelems
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rib_ack_requests
                                    
                                    	Counter for RIB ack requests
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_acks_received
                                    
                                    	Counter for RIB ack received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_install
                                    
                                    	RIB install info
                                    	**type**\:   :py:class:`RibInstall <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall>`
                                    
                                    .. attribute:: rib_perm_path_found_count
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rib_perm_path_not_found_count
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rib_perm_pelem_found_count
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rib_perm_pelem_not_found_count
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rib_reg_path_found_count
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rib_slow_acks
                                    
                                    	Counter for slow RIB acks
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: scan_prefixes
                                    
                                    	Total prefixes of address\-family scanned
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: scan_segment_prefixes
                                    
                                    	Number of prefixes scanned in a segment of address\-family
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: scan_segments
                                    
                                    	Number of segments to scan all prefixes of address\-family
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: scanner_period
                                    
                                    	Period (in seconds) of address\-family scanner runs
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: segmented_mcast_enabled
                                    
                                    	Is segmented mcast enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: syncgrp_version
                                    
                                    	Sync\-group Version
                                    	**type**\: list of    :py:class:`SyncgrpVersion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.SyncgrpVersion>`
                                    
                                    .. attribute:: update_wait_install_enabled
                                    
                                    	Update wait\-install enabled
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.gblafrpki_allow_invalid = None
                                        self.gblafrpki_disable = None
                                        self.gblafrpki_signal_ibgp = None
                                        self.gblafrpki_use_validity = None
                                        self.global_mcast_enabled = None
                                        self.inter_as_install_enabled = None
                                        self.is_perm_net_cfg = None
                                        self.nh_tunnel_version = None
                                        self.perm_nbr_count = None
                                        self.perm_net_del_count = None
                                        self.perm_net_existing_count = None
                                        self.perm_net_insert_count = None
                                        self.perm_net_rpl_process_count = None
                                        self.perm_net_rpl_query_count = None
                                        self.perm_net_stale_del_count = None
                                        self.perm_net_stale_mark_count = None
                                        self.perm_path_refresh_count = None
                                        self.perm_pelem_all_bump_count = None
                                        self.perm_pelem_bump_count = None
                                        self.perm_pelem_free_count = None
                                        self.rib_ack_requests = None
                                        self.rib_acks_received = None
                                        self.rib_install = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall()
                                        self.rib_install.parent = self
                                        self.rib_perm_path_found_count = None
                                        self.rib_perm_path_not_found_count = None
                                        self.rib_perm_pelem_found_count = None
                                        self.rib_perm_pelem_not_found_count = None
                                        self.rib_reg_path_found_count = None
                                        self.rib_slow_acks = None
                                        self.scan_prefixes = None
                                        self.scan_segment_prefixes = None
                                        self.scan_segments = None
                                        self.scanner_period = None
                                        self.segmented_mcast_enabled = None
                                        self.syncgrp_version = YList()
                                        self.syncgrp_version.parent = self
                                        self.syncgrp_version.name = 'syncgrp_version'
                                        self.update_wait_install_enabled = None


                                    class RibInstall(object):
                                        """
                                        RIB install info
                                        
                                        .. attribute:: install_time
                                        
                                        	RIB install time
                                        	**type**\:   :py:class:`InstallTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.InstallTime>`
                                        
                                        .. attribute:: installed_count
                                        
                                        	Installed routes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: modified_count
                                        
                                        	Modified routes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: start_version
                                        
                                        	Start version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: target_version
                                        
                                        	Target version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_time
                                        
                                        	RIB update time
                                        	**type**\:   :py:class:`UpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.UpdateTime>`
                                        
                                        .. attribute:: withdrawn_count
                                        
                                        	Withdrawn routes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.install_time = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.InstallTime()
                                            self.install_time.parent = self
                                            self.installed_count = None
                                            self.modified_count = None
                                            self.start_version = None
                                            self.target_version = None
                                            self.update_time = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.UpdateTime()
                                            self.update_time.parent = self
                                            self.withdrawn_count = None


                                        class UpdateTime(object):
                                            """
                                            RIB update time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-time'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.UpdateTime']['meta_info']


                                        class InstallTime(object):
                                            """
                                            RIB install time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:install-time'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.InstallTime']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rib-install'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.install_time is not None and self.install_time._has_data():
                                                return True

                                            if self.installed_count is not None:
                                                return True

                                            if self.modified_count is not None:
                                                return True

                                            if self.start_version is not None:
                                                return True

                                            if self.target_version is not None:
                                                return True

                                            if self.update_time is not None and self.update_time._has_data():
                                                return True

                                            if self.withdrawn_count is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall']['meta_info']


                                    class SyncgrpVersion(object):
                                        """
                                        Sync\-group Version
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.entry = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:syncgrp-version'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.entry is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.SyncgrpVersion']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:global'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.gblafrpki_allow_invalid is not None:
                                            return True

                                        if self.gblafrpki_disable is not None:
                                            return True

                                        if self.gblafrpki_signal_ibgp is not None:
                                            return True

                                        if self.gblafrpki_use_validity is not None:
                                            return True

                                        if self.global_mcast_enabled is not None:
                                            return True

                                        if self.inter_as_install_enabled is not None:
                                            return True

                                        if self.is_perm_net_cfg is not None:
                                            return True

                                        if self.nh_tunnel_version is not None:
                                            return True

                                        if self.perm_nbr_count is not None:
                                            return True

                                        if self.perm_net_del_count is not None:
                                            return True

                                        if self.perm_net_existing_count is not None:
                                            return True

                                        if self.perm_net_insert_count is not None:
                                            return True

                                        if self.perm_net_rpl_process_count is not None:
                                            return True

                                        if self.perm_net_rpl_query_count is not None:
                                            return True

                                        if self.perm_net_stale_del_count is not None:
                                            return True

                                        if self.perm_net_stale_mark_count is not None:
                                            return True

                                        if self.perm_path_refresh_count is not None:
                                            return True

                                        if self.perm_pelem_all_bump_count is not None:
                                            return True

                                        if self.perm_pelem_bump_count is not None:
                                            return True

                                        if self.perm_pelem_free_count is not None:
                                            return True

                                        if self.rib_ack_requests is not None:
                                            return True

                                        if self.rib_acks_received is not None:
                                            return True

                                        if self.rib_install is not None and self.rib_install._has_data():
                                            return True

                                        if self.rib_perm_path_found_count is not None:
                                            return True

                                        if self.rib_perm_path_not_found_count is not None:
                                            return True

                                        if self.rib_perm_pelem_found_count is not None:
                                            return True

                                        if self.rib_perm_pelem_not_found_count is not None:
                                            return True

                                        if self.rib_reg_path_found_count is not None:
                                            return True

                                        if self.rib_slow_acks is not None:
                                            return True

                                        if self.scan_prefixes is not None:
                                            return True

                                        if self.scan_segment_prefixes is not None:
                                            return True

                                        if self.scan_segments is not None:
                                            return True

                                        if self.scanner_period is not None:
                                            return True

                                        if self.segmented_mcast_enabled is not None:
                                            return True

                                        if self.syncgrp_version is not None:
                                            for child_ref in self.syncgrp_version:
                                                if child_ref._has_data():
                                                    return True

                                        if self.update_wait_install_enabled is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_']['meta_info']


                                class Vrf(object):
                                    """
                                    VRF information
                                    
                                    .. attribute:: aggregates_distance
                                    
                                    	Dist for aggregate routes (local)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: client_reflection_enabled
                                    
                                    	Client reflection enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: dampening_enabled
                                    
                                    	Dampening enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: dynamic_med_enabled
                                    
                                    	Update generation enabled for MED change
                                    	**type**\:  bool
                                    
                                    .. attribute:: dynamic_med_interval
                                    
                                    	Delay in update generation after a MED change (in minutes)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: minute
                                    
                                    .. attribute:: dynamic_med_periodic_timer_running
                                    
                                    	Dynamic MED periodic timer running
                                    	**type**\:  bool
                                    
                                    .. attribute:: dynamic_med_periodic_timer_value
                                    
                                    	Dynamic MED periodic timer value (in seconds) left on the timer
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: dynamic_med_timer_running
                                    
                                    	Dynamic MED timer running
                                    	**type**\:  bool
                                    
                                    .. attribute:: dynamic_med_timer_value
                                    
                                    	Dynamic MED timer value (in seconds) left on the timer
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: ebgp_distance
                                    
                                    	Distance for eBGP routes (external)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: ibgp_distance
                                    
                                    	Distance for iBGP routes (internal)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: is_rib_table_full
                                    
                                    	Indicates if RIB table is in prefix\-limit state
                                    	**type**\:  bool
                                    
                                    .. attribute:: nexthop_resolution_minimum_prefix_length
                                    
                                    	Nexthop resoultion minimum prefix\-length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nexthop_resolution_minimum_prefix_length_configured
                                    
                                    	Is nexthop resoultion minimum prefix\-length configured ?
                                    	**type**\:  bool
                                    
                                    .. attribute:: nsr_conv_version
                                    
                                    	NSR conv version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_is_conv
                                    
                                    	NSR is converged
                                    	**type**\:  bool
                                    
                                    .. attribute:: rd_version
                                    
                                    	RD version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_acked_table_version
                                    
                                    	Table version acked by RIB
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_convergence_version
                                    
                                    	Last convergence version received from RIB
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_has_converged
                                    
                                    	Received convergence notification from RIB
                                    	**type**\:  bool
                                    
                                    .. attribute:: rib_table_full_version
                                    
                                    	Version when RIB table became full (from non\-full)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_version
                                    
                                    	Table version synced to RIB
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: selective_ebgp_multipath_enabled
                                    
                                    	Selective eBGP multipath isenabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: selective_eibgp_multipath_enabled
                                    
                                    	Selective eiBGP multipath isenabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: selective_ibgp_multipath_enabled
                                    
                                    	Selective iBGP multipath isenabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: table_id
                                    
                                    	Table ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_is_active
                                    
                                    	Table state is active
                                    	**type**\:  bool
                                    
                                    .. attribute:: table_version
                                    
                                    	Table version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.aggregates_distance = None
                                        self.client_reflection_enabled = None
                                        self.dampening_enabled = None
                                        self.dynamic_med_enabled = None
                                        self.dynamic_med_interval = None
                                        self.dynamic_med_periodic_timer_running = None
                                        self.dynamic_med_periodic_timer_value = None
                                        self.dynamic_med_timer_running = None
                                        self.dynamic_med_timer_value = None
                                        self.ebgp_distance = None
                                        self.ibgp_distance = None
                                        self.is_rib_table_full = None
                                        self.nexthop_resolution_minimum_prefix_length = None
                                        self.nexthop_resolution_minimum_prefix_length_configured = None
                                        self.nsr_conv_version = None
                                        self.nsr_is_conv = None
                                        self.rd_version = None
                                        self.rib_acked_table_version = None
                                        self.rib_convergence_version = None
                                        self.rib_has_converged = None
                                        self.rib_table_full_version = None
                                        self.rib_version = None
                                        self.selective_ebgp_multipath_enabled = None
                                        self.selective_eibgp_multipath_enabled = None
                                        self.selective_ibgp_multipath_enabled = None
                                        self.table_id = None
                                        self.table_is_active = None
                                        self.table_version = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:vrf'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.aggregates_distance is not None:
                                            return True

                                        if self.client_reflection_enabled is not None:
                                            return True

                                        if self.dampening_enabled is not None:
                                            return True

                                        if self.dynamic_med_enabled is not None:
                                            return True

                                        if self.dynamic_med_interval is not None:
                                            return True

                                        if self.dynamic_med_periodic_timer_running is not None:
                                            return True

                                        if self.dynamic_med_periodic_timer_value is not None:
                                            return True

                                        if self.dynamic_med_timer_running is not None:
                                            return True

                                        if self.dynamic_med_timer_value is not None:
                                            return True

                                        if self.ebgp_distance is not None:
                                            return True

                                        if self.ibgp_distance is not None:
                                            return True

                                        if self.is_rib_table_full is not None:
                                            return True

                                        if self.nexthop_resolution_minimum_prefix_length is not None:
                                            return True

                                        if self.nexthop_resolution_minimum_prefix_length_configured is not None:
                                            return True

                                        if self.nsr_conv_version is not None:
                                            return True

                                        if self.nsr_is_conv is not None:
                                            return True

                                        if self.rd_version is not None:
                                            return True

                                        if self.rib_acked_table_version is not None:
                                            return True

                                        if self.rib_convergence_version is not None:
                                            return True

                                        if self.rib_has_converged is not None:
                                            return True

                                        if self.rib_table_full_version is not None:
                                            return True

                                        if self.rib_version is not None:
                                            return True

                                        if self.selective_ebgp_multipath_enabled is not None:
                                            return True

                                        if self.selective_eibgp_multipath_enabled is not None:
                                            return True

                                        if self.selective_ibgp_multipath_enabled is not None:
                                            return True

                                        if self.table_id is not None:
                                            return True

                                        if self.table_is_active is not None:
                                            return True

                                        if self.table_version is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Vrf']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:global-af-process-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.global_ is not None and self.global_._has_data():
                                        return True

                                    if self.is_nsr_enabled is not None:
                                        return True

                                    if self.vrf is not None and self.vrf._has_data():
                                        return True

                                    if self.vrf_name is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo']['meta_info']


                            class NetworkPrefixes(object):
                                """
                                The BGP Network Lookup table
                                
                                .. attribute:: network_prefix
                                
                                	A BGP Network Lookup prefix entry
                                	**type**\: list of    :py:class:`NetworkPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.network_prefix = YList()
                                    self.network_prefix.parent = self
                                    self.network_prefix.name = 'network_prefix'


                                class NetworkPrefix(object):
                                    """
                                    A BGP Network Lookup prefix entry
                                    
                                    .. attribute:: active_path_element
                                    
                                    	Path element list received from Active inst
                                    	**type**\: list of    :py:class:`ActivePathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement>`
                                    
                                    .. attribute:: active_process_instance_path
                                    
                                    	Active's paths for this net 
                                    	**type**\: list of    :py:class:`ActiveProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath>`
                                    
                                    .. attribute:: add_path_orr_bitfield
                                    
                                    	ORR Add path Bitfields
                                    	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield>`
                                    
                                    .. attribute:: advertisedto_pe
                                    
                                    	Net could be advertised                          to PE peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: best_path_orr_bitfield
                                    
                                    	ORR Best path Bitfields
                                    	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield>`
                                    
                                    .. attribute:: bgp_prefix
                                    
                                    	BGP prefix
                                    	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix>`
                                    
                                    .. attribute:: bit
                                    
                                    	Bit
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: flags
                                    
                                    	Flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: gateway_array
                                    
                                    	Gateway array ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: has_inconsistent_paths
                                    
                                    	Net has inconsistent paths
                                    	**type**\:  bool
                                    
                                    .. attribute:: has_lbl_retained
                                    
                                    	Net has label retained
                                    	**type**\:  bool
                                    
                                    .. attribute:: has_local_label
                                    
                                    	Net has local label
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_net_aggregation_suppressed
                                    
                                    	Net suppressed due to aggregation
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_net_ldp_signaled
                                    
                                    	L2VPN Net LDP signaled  aggregation
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_permanent_network
                                    
                                    	Permanent Network
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_path_element
                                    
                                    	Local path element list
                                    	**type**\: list of    :py:class:`LocalPathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement>`
                                    
                                    .. attribute:: local_peers_advertised_to
                                    
                                    	Local peers that this prefix has been advertised to
                                    	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo>`
                                    
                                    .. attribute:: local_process_instance_path
                                    
                                    	Local (to process instance) paths for this net 
                                    	**type**\: list of    :py:class:`LocalProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath>`
                                    
                                    .. attribute:: net_backup_available
                                    
                                    	Net has backup path
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_backup_label_rewrite_available
                                    
                                    	Net has label rewrite for backup path
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_eibgp_multipath
                                    
                                    	Net has EIBGP multipaths
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_extended_flags
                                    
                                    	Net extended flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: net_flags
                                    
                                    	Flags associated with                            net
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: net_local_label
                                    
                                    	Local label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: net_local_label_rewrite
                                    
                                    	Net label has rewrite
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_local_label_srgb
                                    
                                    	Net label allocated fromSegment routing global block
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_multipath
                                    
                                    	Net has multipaths
                                    	**type**\:  bool
                                    
                                    .. attribute:: network_prefix
                                    
                                    	Network prefix
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: num_of_path
                                    
                                    	Number of path for this net
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pe_peers_advertised_to
                                    
                                    	PE peers that this prefix has been advertised to
                                    	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo>`
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: resilient_nexthop_set
                                    
                                    	Resilient nexthop set ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_failed
                                    
                                    	RIB install failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: table_brib_version
                                    
                                    	Table version # for updates
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_version
                                    
                                    	Table version # for net
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version
                                    
                                    	Version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version_age
                                    
                                    	Version age
                                    	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionAge>`
                                    
                                    .. attribute:: version_timestamp
                                    
                                    	Version timestamp
                                    	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionTimestamp>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.active_path_element = YList()
                                        self.active_path_element.parent = self
                                        self.active_path_element.name = 'active_path_element'
                                        self.active_process_instance_path = YList()
                                        self.active_process_instance_path.parent = self
                                        self.active_process_instance_path.name = 'active_process_instance_path'
                                        self.add_path_orr_bitfield = YList()
                                        self.add_path_orr_bitfield.parent = self
                                        self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                        self.advertisedto_pe = None
                                        self.af_name = None
                                        self.best_path_orr_bitfield = YList()
                                        self.best_path_orr_bitfield.parent = self
                                        self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                        self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix()
                                        self.bgp_prefix.parent = self
                                        self.bit = None
                                        self.flags = None
                                        self.gateway_array = None
                                        self.has_inconsistent_paths = None
                                        self.has_lbl_retained = None
                                        self.has_local_label = None
                                        self.is_net_aggregation_suppressed = None
                                        self.is_net_ldp_signaled = None
                                        self.is_permanent_network = None
                                        self.local_path_element = YList()
                                        self.local_path_element.parent = self
                                        self.local_path_element.name = 'local_path_element'
                                        self.local_peers_advertised_to = YList()
                                        self.local_peers_advertised_to.parent = self
                                        self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                        self.local_process_instance_path = YList()
                                        self.local_process_instance_path.parent = self
                                        self.local_process_instance_path.name = 'local_process_instance_path'
                                        self.net_backup_available = None
                                        self.net_backup_label_rewrite_available = None
                                        self.net_eibgp_multipath = None
                                        self.net_extended_flags = None
                                        self.net_flags = None
                                        self.net_local_label = None
                                        self.net_local_label_rewrite = None
                                        self.net_local_label_srgb = None
                                        self.net_multipath = None
                                        self.network_prefix = None
                                        self.num_of_path = None
                                        self.pe_peers_advertised_to = YList()
                                        self.pe_peers_advertised_to.parent = self
                                        self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                        self.process_instance_id = None
                                        self.rd = None
                                        self.resilient_nexthop_set = None
                                        self.rib_failed = None
                                        self.route_distinguisher = None
                                        self.table_brib_version = None
                                        self.table_version = None
                                        self.version = None
                                        self.version_age = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionAge()
                                        self.version_age.parent = self
                                        self.version_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionTimestamp()
                                        self.version_timestamp.parent = self
                                        self.vrf_name = None


                                    class BgpPrefix(object):
                                        """
                                        BGP prefix
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix()
                                            self.prefix.parent = self
                                            self.prefix_length = None


                                        class Prefix(object):
                                            """
                                            Prefix
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.prefix is not None and self.prefix._has_data():
                                                return True

                                            if self.prefix_length is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix']['meta_info']


                                    class VersionTimestamp(object):
                                        """
                                        Version timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionTimestamp']['meta_info']


                                    class VersionAge(object):
                                        """
                                        Version age
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-age'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionAge']['meta_info']


                                    class LocalPeersAdvertisedTo(object):
                                        """
                                        Local peers that this prefix has been advertised
                                        to
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress>`
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.is_neighbor = None
                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self.update_group_number = None


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.is_neighbor is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            if self.update_group_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo']['meta_info']


                                    class PePeersAdvertisedTo(object):
                                        """
                                        PE peers that this prefix has been advertised to
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress>`
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.is_neighbor = None
                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self.update_group_number = None


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.is_neighbor is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            if self.update_group_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo']['meta_info']


                                    class BestPathOrrBitfield(object):
                                        """
                                        ORR Best path Bitfields
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress>`
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.is_neighbor = None
                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self.update_group_number = None


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.is_neighbor is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            if self.update_group_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield']['meta_info']


                                    class AddPathOrrBitfield(object):
                                        """
                                        ORR Add path Bitfields
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress>`
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.is_neighbor = None
                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self.update_group_number = None


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.is_neighbor is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            if self.update_group_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield']['meta_info']


                                    class LocalProcessInstancePath(object):
                                        """
                                        Local (to process instance) paths for this net 
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation>`
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self.label_fail = None
                                            self.label_o_or_version = None
                                            self.label_oor = None
                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self.no_path = None
                                            self.path_information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation()
                                            self.path_information.parent = self
                                            self.prefix_version = None
                                            self.process_instance_id = None
                                            self.route_distinguisher = None
                                            self.source_route_distinguisher = None
                                            self.source_vrf_name = None
                                            self.srcaf_name = None
                                            self.vrf_name = None


                                        class NeighborAddressXr(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr']['meta_info']


                                        class PathInformation(object):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_esi
                                            
                                            	Path has EVPN ESI
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_rcvd_label
                                            
                                            	Path has received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebg_ps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi>`
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop>`
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhteTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_p_ath = None
                                                self.add_path_orr_bitfield = YList()
                                                self.add_path_orr_bitfield.parent = self
                                                self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                self.advertisedto_pe = None
                                                self.aigp_metric = None
                                                self.best_path_comp_stage = None
                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self.best_path_id = None
                                                self.best_path_id_comp_winner = None
                                                self.best_path_orr_bitfield = YList()
                                                self.best_path_orr_bitfield.parent = self
                                                self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self.dampen_penalty = None
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.fspec_invalid_path = None
                                                self.graceful_shutdown = None
                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self.halflife_time = None
                                                self.has_esi = None
                                                self.has_gw_addr = None
                                                self.has_local_net_label = None
                                                self.has_mdt_group_addr = None
                                                self.has_mvpn_extcomm = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.has_rcvd_label = None
                                                self.has_second_label = None
                                                self.ibgp_signaled_validity = None
                                                self.igp_metric = None
                                                self.is_aggregation_suppressed = None
                                                self.is_as_best = None
                                                self.is_best_path = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_internal_path = None
                                                self.is_partial_best = None
                                                self.is_path_additional_path = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_af_install_eligible = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_damped = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_history_held = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_imported = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_multipath = None
                                                self.is_path_nexthop_discarded = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebg_ps = None
                                                self.is_path_received_only = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_stale = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_valid = None
                                                self.is_path_vpn_only = None
                                                self.is_permanent_path = None
                                                self.is_received_path_not_modified = None
                                                self.is_spkr_as_best = None
                                                self.l2vpn_circuit_status_value = YList()
                                                self.l2vpn_circuit_status_value.parent = self
                                                self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi()
                                                self.l2vpn_evpn_esi.parent = self
                                                self.l2vpn_size = None
                                                self.labeled_unicast_safi_path = None
                                                self.local_label = None
                                                self.local_nh = None
                                                self.local_path_id = None
                                                self.local_peers_advertised_to = YList()
                                                self.local_peers_advertised_to.parent = self
                                                self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                self.maximum_suppress_time = None
                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self.mvpn_path_flags = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_value = YList()
                                                self.mvpn_pmsi_value.parent = self
                                                self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                self.mvpn_sfs_path = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.neighbor_router_id = None
                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.path_flags = None
                                                self.path_flap_count = None
                                                self.path_import_flags = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.path_table_version = None
                                                self.path_weight = None
                                                self.pe_peers_advertised_to = YList()
                                                self.pe_peers_advertised_to.parent = self
                                                self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                self.rcvd_label = None
                                                self.rcvd_path_id = None
                                                self.reuse_value = None
                                                self.rib_failed = None
                                                self.route_type = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.rt_set_limit_enabled = None
                                                self.second_label = None
                                                self.seconds_since_first_flap = None
                                                self.show_rpki_origin_as_validity = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.suppress_penalty = None
                                                self.time_to_unsuppress = None


                                            class BgpPrefix(object):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self.prefix_length = None


                                                class Prefix(object):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.prefix is not None and self.prefix._has_data():
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix']['meta_info']


                                            class NeighborAddress(object):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress']['meta_info']


                                            class NextHop(object):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhteTunnel']['meta_info']


                                            class MdtGroupAddr(object):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr']['meta_info']


                                            class L2VpnEvpnEsi(object):
                                                """
                                                L2VPN EVPN ESI
                                                
                                                .. attribute:: esi
                                                
                                                	esi
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.esi = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.esi is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi']['meta_info']


                                            class GwAddr(object):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.GwAddr']['meta_info']


                                            class BestPathCompWinner(object):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner']['meta_info']


                                            class MvpnNbrAddr(object):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr']['meta_info']


                                            class MvpnNexthopAddr(object):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr']['meta_info']


                                            class L2VpnCircuitStatusValue(object):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                            class MvpnPmsiValue(object):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnPmsiValue']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.ExtendedCommunity']['meta_info']


                                            class LocalPeersAdvertisedTo(object):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                            class PePeersAdvertisedTo(object):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo']['meta_info']


                                            class BestPathOrrBitfield(object):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield']['meta_info']


                                            class AddPathOrrBitfield(object):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.accept_own_path is not None:
                                                    return True

                                                if self.accept_own_self_originated_p_ath is not None:
                                                    return True

                                                if self.add_path_orr_bitfield is not None:
                                                    for child_ref in self.add_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.advertisedto_pe is not None:
                                                    return True

                                                if self.aigp_metric is not None:
                                                    return True

                                                if self.best_path_comp_stage is not None:
                                                    return True

                                                if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                    return True

                                                if self.best_path_id is not None:
                                                    return True

                                                if self.best_path_id_comp_winner is not None:
                                                    return True

                                                if self.best_path_orr_bitfield is not None:
                                                    for child_ref in self.best_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                    return True

                                                if self.dampen_penalty is not None:
                                                    return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.fspec_invalid_path is not None:
                                                    return True

                                                if self.graceful_shutdown is not None:
                                                    return True

                                                if self.gw_addr is not None and self.gw_addr._has_data():
                                                    return True

                                                if self.halflife_time is not None:
                                                    return True

                                                if self.has_esi is not None:
                                                    return True

                                                if self.has_gw_addr is not None:
                                                    return True

                                                if self.has_local_net_label is not None:
                                                    return True

                                                if self.has_mdt_group_addr is not None:
                                                    return True

                                                if self.has_mvpn_extcomm is not None:
                                                    return True

                                                if self.has_mvpn_nbr_addr is not None:
                                                    return True

                                                if self.has_mvpn_nexthop_addr is not None:
                                                    return True

                                                if self.has_mvpn_pmsi is not None:
                                                    return True

                                                if self.has_rcvd_label is not None:
                                                    return True

                                                if self.has_second_label is not None:
                                                    return True

                                                if self.ibgp_signaled_validity is not None:
                                                    return True

                                                if self.igp_metric is not None:
                                                    return True

                                                if self.is_aggregation_suppressed is not None:
                                                    return True

                                                if self.is_as_best is not None:
                                                    return True

                                                if self.is_best_path is not None:
                                                    return True

                                                if self.is_import_dampened is not None:
                                                    return True

                                                if self.is_import_suspect is not None:
                                                    return True

                                                if self.is_internal_path is not None:
                                                    return True

                                                if self.is_partial_best is not None:
                                                    return True

                                                if self.is_path_additional_path is not None:
                                                    return True

                                                if self.is_path_advertised_local_as_only is not None:
                                                    return True

                                                if self.is_path_af_install_eligible is not None:
                                                    return True

                                                if self.is_path_backup is not None:
                                                    return True

                                                if self.is_path_backup_protect_multipath is not None:
                                                    return True

                                                if self.is_path_best_external is not None:
                                                    return True

                                                if self.is_path_damped is not None:
                                                    return True

                                                if self.is_path_from_confederation_peer is not None:
                                                    return True

                                                if self.is_path_from_network_command is not None:
                                                    return True

                                                if self.is_path_from_redistribute_command is not None:
                                                    return True

                                                if self.is_path_from_route_reflector is not None:
                                                    return True

                                                if self.is_path_history_held is not None:
                                                    return True

                                                if self.is_path_imp_candidate is not None:
                                                    return True

                                                if self.is_path_imported is not None:
                                                    return True

                                                if self.is_path_local_aggregate is not None:
                                                    return True

                                                if self.is_path_locally_sourced is not None:
                                                    return True

                                                if self.is_path_long_lived_stale is not None:
                                                    return True

                                                if self.is_path_multipath is not None:
                                                    return True

                                                if self.is_path_nexthop_discarded is not None:
                                                    return True

                                                if self.is_path_not_advertised is not None:
                                                    return True

                                                if self.is_path_not_advertised_to_ebg_ps is not None:
                                                    return True

                                                if self.is_path_received_only is not None:
                                                    return True

                                                if self.is_path_reoriginated is not None:
                                                    return True

                                                if self.is_path_reoriginated_stitching is not None:
                                                    return True

                                                if self.is_path_stale is not None:
                                                    return True

                                                if self.is_path_synced_with_igp is not None:
                                                    return True

                                                if self.is_path_valid is not None:
                                                    return True

                                                if self.is_path_vpn_only is not None:
                                                    return True

                                                if self.is_permanent_path is not None:
                                                    return True

                                                if self.is_received_path_not_modified is not None:
                                                    return True

                                                if self.is_spkr_as_best is not None:
                                                    return True

                                                if self.l2vpn_circuit_status_value is not None:
                                                    for child_ref in self.l2vpn_circuit_status_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                    return True

                                                if self.l2vpn_size is not None:
                                                    return True

                                                if self.labeled_unicast_safi_path is not None:
                                                    return True

                                                if self.local_label is not None:
                                                    return True

                                                if self.local_nh is not None:
                                                    return True

                                                if self.local_path_id is not None:
                                                    return True

                                                if self.local_peers_advertised_to is not None:
                                                    for child_ref in self.local_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.maximum_suppress_time is not None:
                                                    return True

                                                if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                    return True

                                                if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                    return True

                                                if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                    return True

                                                if self.mvpn_path_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_label is not None:
                                                    return True

                                                if self.mvpn_pmsi_type is not None:
                                                    return True

                                                if self.mvpn_pmsi_value is not None:
                                                    for child_ref in self.mvpn_pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.mvpn_sfs_path is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.neighbor_router_id is not None:
                                                    return True

                                                if self.next_hop is not None and self.next_hop._has_data():
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.path_flags is not None:
                                                    return True

                                                if self.path_flap_count is not None:
                                                    return True

                                                if self.path_import_flags is not None:
                                                    return True

                                                if self.path_rt_set_id is not None:
                                                    return True

                                                if self.path_rt_set_route_count is not None:
                                                    return True

                                                if self.path_table_version is not None:
                                                    return True

                                                if self.path_weight is not None:
                                                    return True

                                                if self.pe_peers_advertised_to is not None:
                                                    for child_ref in self.pe_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.rcvd_label is not None:
                                                    return True

                                                if self.rcvd_path_id is not None:
                                                    return True

                                                if self.reuse_value is not None:
                                                    return True

                                                if self.rib_failed is not None:
                                                    return True

                                                if self.route_type is not None:
                                                    return True

                                                if self.rpki_origin_as_validation_disabled is not None:
                                                    return True

                                                if self.rt_set_limit_enabled is not None:
                                                    return True

                                                if self.second_label is not None:
                                                    return True

                                                if self.seconds_since_first_flap is not None:
                                                    return True

                                                if self.show_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.sn_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.suppress_penalty is not None:
                                                    return True

                                                if self.time_to_unsuppress is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation']['meta_info']


                                        class AttributesAfterPolicyIn(object):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self.is_application_gateway_present = None
                                                self.is_as_path2_byte = None
                                                self.is_attr_set_present = None
                                                self.is_ribrnh_present = None
                                                self.is_rnh_present = None
                                                self.ribrnh_encap = None
                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self.ribrnh_mac = None
                                                self.ribrnh_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnhip_table = None
                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self.rnh_addr_len = None
                                                self.rnh_len = None
                                                self.rnh_type = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.vpn_distinguisher = None


                                            class CommonAttributes(object):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                            class AttrSet(object):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                            class RnhAddr(object):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None
                                                    self.mac_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    if self.mac_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                            class RibrnhIp(object):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.attr_set is not None and self.attr_set._has_data():
                                                    return True

                                                if self.attribute_key_number is not None:
                                                    return True

                                                if self.attribute_reuse_id_config is not None:
                                                    return True

                                                if self.attribute_reuse_id_current is not None:
                                                    return True

                                                if self.attribute_reuse_id_keys is not None:
                                                    return True

                                                if self.attribute_reuse_id_max_id is not None:
                                                    return True

                                                if self.attribute_reuse_id_node is not None:
                                                    return True

                                                if self.attribute_reuse_id_recover_sec is not None:
                                                    return True

                                                if self.common_attributes is not None and self.common_attributes._has_data():
                                                    return True

                                                if self.is_application_gateway_present is not None:
                                                    return True

                                                if self.is_as_path2_byte is not None:
                                                    return True

                                                if self.is_attr_set_present is not None:
                                                    return True

                                                if self.is_ribrnh_present is not None:
                                                    return True

                                                if self.is_rnh_present is not None:
                                                    return True

                                                if self.ribrnh_encap is not None:
                                                    return True

                                                if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                    return True

                                                if self.ribrnh_mac is not None:
                                                    return True

                                                if self.ribrnh_table is not None:
                                                    return True

                                                if self.ribrnh_vni is not None:
                                                    return True

                                                if self.ribrnhip_table is not None:
                                                    return True

                                                if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                    return True

                                                if self.rnh_addr_len is not None:
                                                    return True

                                                if self.rnh_len is not None:
                                                    return True

                                                if self.rnh_type is not None:
                                                    return True

                                                if self.set_aigp_inbound_igp is not None:
                                                    return True

                                                if self.set_aigp_inbound_metric is not None:
                                                    return True

                                                if self.vpn_distinguisher is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-process-instance-path'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                return True

                                            if self.label_fail is not None:
                                                return True

                                            if self.label_o_or_version is not None:
                                                return True

                                            if self.label_oor is not None:
                                                return True

                                            if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                return True

                                            if self.no_path is not None:
                                                return True

                                            if self.path_information is not None and self.path_information._has_data():
                                                return True

                                            if self.prefix_version is not None:
                                                return True

                                            if self.process_instance_id is not None:
                                                return True

                                            if self.route_distinguisher is not None:
                                                return True

                                            if self.source_route_distinguisher is not None:
                                                return True

                                            if self.source_vrf_name is not None:
                                                return True

                                            if self.srcaf_name is not None:
                                                return True

                                            if self.vrf_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath']['meta_info']


                                    class ActiveProcessInstancePath(object):
                                        """
                                        Active's paths for this net 
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation>`
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self.label_fail = None
                                            self.label_o_or_version = None
                                            self.label_oor = None
                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self.no_path = None
                                            self.path_information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation()
                                            self.path_information.parent = self
                                            self.prefix_version = None
                                            self.process_instance_id = None
                                            self.route_distinguisher = None
                                            self.source_route_distinguisher = None
                                            self.source_vrf_name = None
                                            self.srcaf_name = None
                                            self.vrf_name = None


                                        class NeighborAddressXr(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr']['meta_info']


                                        class PathInformation(object):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_esi
                                            
                                            	Path has EVPN ESI
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_rcvd_label
                                            
                                            	Path has received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebg_ps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi>`
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop>`
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhteTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_p_ath = None
                                                self.add_path_orr_bitfield = YList()
                                                self.add_path_orr_bitfield.parent = self
                                                self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                self.advertisedto_pe = None
                                                self.aigp_metric = None
                                                self.best_path_comp_stage = None
                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self.best_path_id = None
                                                self.best_path_id_comp_winner = None
                                                self.best_path_orr_bitfield = YList()
                                                self.best_path_orr_bitfield.parent = self
                                                self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self.dampen_penalty = None
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.fspec_invalid_path = None
                                                self.graceful_shutdown = None
                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self.halflife_time = None
                                                self.has_esi = None
                                                self.has_gw_addr = None
                                                self.has_local_net_label = None
                                                self.has_mdt_group_addr = None
                                                self.has_mvpn_extcomm = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.has_rcvd_label = None
                                                self.has_second_label = None
                                                self.ibgp_signaled_validity = None
                                                self.igp_metric = None
                                                self.is_aggregation_suppressed = None
                                                self.is_as_best = None
                                                self.is_best_path = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_internal_path = None
                                                self.is_partial_best = None
                                                self.is_path_additional_path = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_af_install_eligible = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_damped = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_history_held = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_imported = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_multipath = None
                                                self.is_path_nexthop_discarded = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebg_ps = None
                                                self.is_path_received_only = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_stale = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_valid = None
                                                self.is_path_vpn_only = None
                                                self.is_permanent_path = None
                                                self.is_received_path_not_modified = None
                                                self.is_spkr_as_best = None
                                                self.l2vpn_circuit_status_value = YList()
                                                self.l2vpn_circuit_status_value.parent = self
                                                self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi()
                                                self.l2vpn_evpn_esi.parent = self
                                                self.l2vpn_size = None
                                                self.labeled_unicast_safi_path = None
                                                self.local_label = None
                                                self.local_nh = None
                                                self.local_path_id = None
                                                self.local_peers_advertised_to = YList()
                                                self.local_peers_advertised_to.parent = self
                                                self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                self.maximum_suppress_time = None
                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self.mvpn_path_flags = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_value = YList()
                                                self.mvpn_pmsi_value.parent = self
                                                self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                self.mvpn_sfs_path = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.neighbor_router_id = None
                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.path_flags = None
                                                self.path_flap_count = None
                                                self.path_import_flags = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.path_table_version = None
                                                self.path_weight = None
                                                self.pe_peers_advertised_to = YList()
                                                self.pe_peers_advertised_to.parent = self
                                                self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                self.rcvd_label = None
                                                self.rcvd_path_id = None
                                                self.reuse_value = None
                                                self.rib_failed = None
                                                self.route_type = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.rt_set_limit_enabled = None
                                                self.second_label = None
                                                self.seconds_since_first_flap = None
                                                self.show_rpki_origin_as_validity = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.suppress_penalty = None
                                                self.time_to_unsuppress = None


                                            class BgpPrefix(object):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self.prefix_length = None


                                                class Prefix(object):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.prefix is not None and self.prefix._has_data():
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix']['meta_info']


                                            class NeighborAddress(object):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress']['meta_info']


                                            class NextHop(object):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhteTunnel']['meta_info']


                                            class MdtGroupAddr(object):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr']['meta_info']


                                            class L2VpnEvpnEsi(object):
                                                """
                                                L2VPN EVPN ESI
                                                
                                                .. attribute:: esi
                                                
                                                	esi
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.esi = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.esi is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi']['meta_info']


                                            class GwAddr(object):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.GwAddr']['meta_info']


                                            class BestPathCompWinner(object):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner']['meta_info']


                                            class MvpnNbrAddr(object):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr']['meta_info']


                                            class MvpnNexthopAddr(object):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr']['meta_info']


                                            class L2VpnCircuitStatusValue(object):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                            class MvpnPmsiValue(object):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.ExtendedCommunity']['meta_info']


                                            class LocalPeersAdvertisedTo(object):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                            class PePeersAdvertisedTo(object):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo']['meta_info']


                                            class BestPathOrrBitfield(object):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield']['meta_info']


                                            class AddPathOrrBitfield(object):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.accept_own_path is not None:
                                                    return True

                                                if self.accept_own_self_originated_p_ath is not None:
                                                    return True

                                                if self.add_path_orr_bitfield is not None:
                                                    for child_ref in self.add_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.advertisedto_pe is not None:
                                                    return True

                                                if self.aigp_metric is not None:
                                                    return True

                                                if self.best_path_comp_stage is not None:
                                                    return True

                                                if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                    return True

                                                if self.best_path_id is not None:
                                                    return True

                                                if self.best_path_id_comp_winner is not None:
                                                    return True

                                                if self.best_path_orr_bitfield is not None:
                                                    for child_ref in self.best_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                    return True

                                                if self.dampen_penalty is not None:
                                                    return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.fspec_invalid_path is not None:
                                                    return True

                                                if self.graceful_shutdown is not None:
                                                    return True

                                                if self.gw_addr is not None and self.gw_addr._has_data():
                                                    return True

                                                if self.halflife_time is not None:
                                                    return True

                                                if self.has_esi is not None:
                                                    return True

                                                if self.has_gw_addr is not None:
                                                    return True

                                                if self.has_local_net_label is not None:
                                                    return True

                                                if self.has_mdt_group_addr is not None:
                                                    return True

                                                if self.has_mvpn_extcomm is not None:
                                                    return True

                                                if self.has_mvpn_nbr_addr is not None:
                                                    return True

                                                if self.has_mvpn_nexthop_addr is not None:
                                                    return True

                                                if self.has_mvpn_pmsi is not None:
                                                    return True

                                                if self.has_rcvd_label is not None:
                                                    return True

                                                if self.has_second_label is not None:
                                                    return True

                                                if self.ibgp_signaled_validity is not None:
                                                    return True

                                                if self.igp_metric is not None:
                                                    return True

                                                if self.is_aggregation_suppressed is not None:
                                                    return True

                                                if self.is_as_best is not None:
                                                    return True

                                                if self.is_best_path is not None:
                                                    return True

                                                if self.is_import_dampened is not None:
                                                    return True

                                                if self.is_import_suspect is not None:
                                                    return True

                                                if self.is_internal_path is not None:
                                                    return True

                                                if self.is_partial_best is not None:
                                                    return True

                                                if self.is_path_additional_path is not None:
                                                    return True

                                                if self.is_path_advertised_local_as_only is not None:
                                                    return True

                                                if self.is_path_af_install_eligible is not None:
                                                    return True

                                                if self.is_path_backup is not None:
                                                    return True

                                                if self.is_path_backup_protect_multipath is not None:
                                                    return True

                                                if self.is_path_best_external is not None:
                                                    return True

                                                if self.is_path_damped is not None:
                                                    return True

                                                if self.is_path_from_confederation_peer is not None:
                                                    return True

                                                if self.is_path_from_network_command is not None:
                                                    return True

                                                if self.is_path_from_redistribute_command is not None:
                                                    return True

                                                if self.is_path_from_route_reflector is not None:
                                                    return True

                                                if self.is_path_history_held is not None:
                                                    return True

                                                if self.is_path_imp_candidate is not None:
                                                    return True

                                                if self.is_path_imported is not None:
                                                    return True

                                                if self.is_path_local_aggregate is not None:
                                                    return True

                                                if self.is_path_locally_sourced is not None:
                                                    return True

                                                if self.is_path_long_lived_stale is not None:
                                                    return True

                                                if self.is_path_multipath is not None:
                                                    return True

                                                if self.is_path_nexthop_discarded is not None:
                                                    return True

                                                if self.is_path_not_advertised is not None:
                                                    return True

                                                if self.is_path_not_advertised_to_ebg_ps is not None:
                                                    return True

                                                if self.is_path_received_only is not None:
                                                    return True

                                                if self.is_path_reoriginated is not None:
                                                    return True

                                                if self.is_path_reoriginated_stitching is not None:
                                                    return True

                                                if self.is_path_stale is not None:
                                                    return True

                                                if self.is_path_synced_with_igp is not None:
                                                    return True

                                                if self.is_path_valid is not None:
                                                    return True

                                                if self.is_path_vpn_only is not None:
                                                    return True

                                                if self.is_permanent_path is not None:
                                                    return True

                                                if self.is_received_path_not_modified is not None:
                                                    return True

                                                if self.is_spkr_as_best is not None:
                                                    return True

                                                if self.l2vpn_circuit_status_value is not None:
                                                    for child_ref in self.l2vpn_circuit_status_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                    return True

                                                if self.l2vpn_size is not None:
                                                    return True

                                                if self.labeled_unicast_safi_path is not None:
                                                    return True

                                                if self.local_label is not None:
                                                    return True

                                                if self.local_nh is not None:
                                                    return True

                                                if self.local_path_id is not None:
                                                    return True

                                                if self.local_peers_advertised_to is not None:
                                                    for child_ref in self.local_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.maximum_suppress_time is not None:
                                                    return True

                                                if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                    return True

                                                if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                    return True

                                                if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                    return True

                                                if self.mvpn_path_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_label is not None:
                                                    return True

                                                if self.mvpn_pmsi_type is not None:
                                                    return True

                                                if self.mvpn_pmsi_value is not None:
                                                    for child_ref in self.mvpn_pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.mvpn_sfs_path is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.neighbor_router_id is not None:
                                                    return True

                                                if self.next_hop is not None and self.next_hop._has_data():
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.path_flags is not None:
                                                    return True

                                                if self.path_flap_count is not None:
                                                    return True

                                                if self.path_import_flags is not None:
                                                    return True

                                                if self.path_rt_set_id is not None:
                                                    return True

                                                if self.path_rt_set_route_count is not None:
                                                    return True

                                                if self.path_table_version is not None:
                                                    return True

                                                if self.path_weight is not None:
                                                    return True

                                                if self.pe_peers_advertised_to is not None:
                                                    for child_ref in self.pe_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.rcvd_label is not None:
                                                    return True

                                                if self.rcvd_path_id is not None:
                                                    return True

                                                if self.reuse_value is not None:
                                                    return True

                                                if self.rib_failed is not None:
                                                    return True

                                                if self.route_type is not None:
                                                    return True

                                                if self.rpki_origin_as_validation_disabled is not None:
                                                    return True

                                                if self.rt_set_limit_enabled is not None:
                                                    return True

                                                if self.second_label is not None:
                                                    return True

                                                if self.seconds_since_first_flap is not None:
                                                    return True

                                                if self.show_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.sn_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.suppress_penalty is not None:
                                                    return True

                                                if self.time_to_unsuppress is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation']['meta_info']


                                        class AttributesAfterPolicyIn(object):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self.is_application_gateway_present = None
                                                self.is_as_path2_byte = None
                                                self.is_attr_set_present = None
                                                self.is_ribrnh_present = None
                                                self.is_rnh_present = None
                                                self.ribrnh_encap = None
                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self.ribrnh_mac = None
                                                self.ribrnh_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnhip_table = None
                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self.rnh_addr_len = None
                                                self.rnh_len = None
                                                self.rnh_type = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.vpn_distinguisher = None


                                            class CommonAttributes(object):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                            class AttrSet(object):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                            class RnhAddr(object):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None
                                                    self.mac_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    if self.mac_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                            class RibrnhIp(object):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.attr_set is not None and self.attr_set._has_data():
                                                    return True

                                                if self.attribute_key_number is not None:
                                                    return True

                                                if self.attribute_reuse_id_config is not None:
                                                    return True

                                                if self.attribute_reuse_id_current is not None:
                                                    return True

                                                if self.attribute_reuse_id_keys is not None:
                                                    return True

                                                if self.attribute_reuse_id_max_id is not None:
                                                    return True

                                                if self.attribute_reuse_id_node is not None:
                                                    return True

                                                if self.attribute_reuse_id_recover_sec is not None:
                                                    return True

                                                if self.common_attributes is not None and self.common_attributes._has_data():
                                                    return True

                                                if self.is_application_gateway_present is not None:
                                                    return True

                                                if self.is_as_path2_byte is not None:
                                                    return True

                                                if self.is_attr_set_present is not None:
                                                    return True

                                                if self.is_ribrnh_present is not None:
                                                    return True

                                                if self.is_rnh_present is not None:
                                                    return True

                                                if self.ribrnh_encap is not None:
                                                    return True

                                                if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                    return True

                                                if self.ribrnh_mac is not None:
                                                    return True

                                                if self.ribrnh_table is not None:
                                                    return True

                                                if self.ribrnh_vni is not None:
                                                    return True

                                                if self.ribrnhip_table is not None:
                                                    return True

                                                if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                    return True

                                                if self.rnh_addr_len is not None:
                                                    return True

                                                if self.rnh_len is not None:
                                                    return True

                                                if self.rnh_type is not None:
                                                    return True

                                                if self.set_aigp_inbound_igp is not None:
                                                    return True

                                                if self.set_aigp_inbound_metric is not None:
                                                    return True

                                                if self.vpn_distinguisher is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-process-instance-path'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                return True

                                            if self.label_fail is not None:
                                                return True

                                            if self.label_o_or_version is not None:
                                                return True

                                            if self.label_oor is not None:
                                                return True

                                            if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                return True

                                            if self.no_path is not None:
                                                return True

                                            if self.path_information is not None and self.path_information._has_data():
                                                return True

                                            if self.prefix_version is not None:
                                                return True

                                            if self.process_instance_id is not None:
                                                return True

                                            if self.route_distinguisher is not None:
                                                return True

                                            if self.source_route_distinguisher is not None:
                                                return True

                                            if self.source_vrf_name is not None:
                                                return True

                                            if self.srcaf_name is not None:
                                                return True

                                            if self.vrf_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath']['meta_info']


                                    class LocalPathElement(object):
                                        """
                                        Local path element list
                                        
                                        .. attribute:: is_perm_path_pelem
                                        
                                        	Pelem for permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: nhte_tunnel
                                        
                                        	NH TE tunnel information
                                        	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.NhteTunnel>`
                                        
                                        .. attribute:: pelem_flags
                                        
                                        	Flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_gw_metric
                                        
                                        	Gateway metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_addpath_table_attr_version
                                        
                                        	No\-addpath Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_bestpath_table_attr_version
                                        
                                        	No\-bestpath Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_flags
                                        
                                        	Path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: pelem_path_id
                                        
                                        	Local Path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_neighbor_addr
                                        
                                        	Path neighbor address
                                        	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr>`
                                        
                                        .. attribute:: pelem_path_nexthop
                                        
                                        	Path nexthop address
                                        	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop>`
                                        
                                        .. attribute:: pelem_path_peer_path_id
                                        
                                        	Path peer path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_table_attr_version
                                        
                                        	Path Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_table_attr_version
                                        
                                        	Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_version
                                        
                                        	Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.is_perm_path_pelem = None
                                            self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.NhteTunnel()
                                            self.nhte_tunnel.parent = self
                                            self.pelem_flags = None
                                            self.pelem_gw_metric = None
                                            self.pelem_no_addpath_table_attr_version = None
                                            self.pelem_no_bestpath_table_attr_version = None
                                            self.pelem_path_flags = None
                                            self.pelem_path_id = None
                                            self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr()
                                            self.pelem_path_neighbor_addr.parent = self
                                            self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop()
                                            self.pelem_path_nexthop.parent = self
                                            self.pelem_path_peer_path_id = None
                                            self.pelem_path_table_attr_version = None
                                            self.pelem_table_attr_version = None
                                            self.pelem_version = None


                                        class PelemPathNexthop(object):
                                            """
                                            Path nexthop address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-nexthop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop']['meta_info']


                                        class NhteTunnel(object):
                                            """
                                            NH TE tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_te_tunnel
                                            
                                            	NH TE Tunnel info is present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last rib update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	tunnel name
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	tunnel type
                                            	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.binding_label = None
                                                self.has_te_tunnel = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.is_tunnel_up = None
                                                self.last_tunnel_update = None
                                                self.tunnel_if_handle = None
                                                self.tunnel_name = None
                                                self.tunnel_type = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_v6_required = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.binding_label is not None:
                                                    return True

                                                if self.has_te_tunnel is not None:
                                                    return True

                                                if self.is_tunnel_info_stale is not None:
                                                    return True

                                                if self.is_tunnel_registered is not None:
                                                    return True

                                                if self.is_tunnel_up is not None:
                                                    return True

                                                if self.last_tunnel_update is not None:
                                                    return True

                                                if self.tunnel_if_handle is not None:
                                                    return True

                                                if self.tunnel_name is not None:
                                                    return True

                                                if self.tunnel_type is not None:
                                                    return True

                                                if self.tunnel_v6_enabled is not None:
                                                    return True

                                                if self.tunnel_v6_required is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.NhteTunnel']['meta_info']


                                        class PelemPathNeighborAddr(object):
                                            """
                                            Path neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-neighbor-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-path-element'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.is_perm_path_pelem is not None:
                                                return True

                                            if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                return True

                                            if self.pelem_flags is not None:
                                                return True

                                            if self.pelem_gw_metric is not None:
                                                return True

                                            if self.pelem_no_addpath_table_attr_version is not None:
                                                return True

                                            if self.pelem_no_bestpath_table_attr_version is not None:
                                                return True

                                            if self.pelem_path_flags is not None:
                                                return True

                                            if self.pelem_path_id is not None:
                                                return True

                                            if self.pelem_path_neighbor_addr is not None and self.pelem_path_neighbor_addr._has_data():
                                                return True

                                            if self.pelem_path_nexthop is not None and self.pelem_path_nexthop._has_data():
                                                return True

                                            if self.pelem_path_peer_path_id is not None:
                                                return True

                                            if self.pelem_path_table_attr_version is not None:
                                                return True

                                            if self.pelem_table_attr_version is not None:
                                                return True

                                            if self.pelem_version is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement']['meta_info']


                                    class ActivePathElement(object):
                                        """
                                        Path element list received from Active inst
                                        
                                        .. attribute:: is_perm_path_pelem
                                        
                                        	Pelem for permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: nhte_tunnel
                                        
                                        	NH TE tunnel information
                                        	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.NhteTunnel>`
                                        
                                        .. attribute:: pelem_flags
                                        
                                        	Flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_gw_metric
                                        
                                        	Gateway metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_addpath_table_attr_version
                                        
                                        	No\-addpath Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_bestpath_table_attr_version
                                        
                                        	No\-bestpath Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_flags
                                        
                                        	Path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: pelem_path_id
                                        
                                        	Local Path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_neighbor_addr
                                        
                                        	Path neighbor address
                                        	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr>`
                                        
                                        .. attribute:: pelem_path_nexthop
                                        
                                        	Path nexthop address
                                        	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop>`
                                        
                                        .. attribute:: pelem_path_peer_path_id
                                        
                                        	Path peer path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_table_attr_version
                                        
                                        	Path Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_table_attr_version
                                        
                                        	Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_version
                                        
                                        	Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.is_perm_path_pelem = None
                                            self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.NhteTunnel()
                                            self.nhte_tunnel.parent = self
                                            self.pelem_flags = None
                                            self.pelem_gw_metric = None
                                            self.pelem_no_addpath_table_attr_version = None
                                            self.pelem_no_bestpath_table_attr_version = None
                                            self.pelem_path_flags = None
                                            self.pelem_path_id = None
                                            self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr()
                                            self.pelem_path_neighbor_addr.parent = self
                                            self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop()
                                            self.pelem_path_nexthop.parent = self
                                            self.pelem_path_peer_path_id = None
                                            self.pelem_path_table_attr_version = None
                                            self.pelem_table_attr_version = None
                                            self.pelem_version = None


                                        class PelemPathNexthop(object):
                                            """
                                            Path nexthop address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-nexthop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop']['meta_info']


                                        class NhteTunnel(object):
                                            """
                                            NH TE tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_te_tunnel
                                            
                                            	NH TE Tunnel info is present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last rib update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	tunnel name
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	tunnel type
                                            	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.binding_label = None
                                                self.has_te_tunnel = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.is_tunnel_up = None
                                                self.last_tunnel_update = None
                                                self.tunnel_if_handle = None
                                                self.tunnel_name = None
                                                self.tunnel_type = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_v6_required = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.binding_label is not None:
                                                    return True

                                                if self.has_te_tunnel is not None:
                                                    return True

                                                if self.is_tunnel_info_stale is not None:
                                                    return True

                                                if self.is_tunnel_registered is not None:
                                                    return True

                                                if self.is_tunnel_up is not None:
                                                    return True

                                                if self.last_tunnel_update is not None:
                                                    return True

                                                if self.tunnel_if_handle is not None:
                                                    return True

                                                if self.tunnel_name is not None:
                                                    return True

                                                if self.tunnel_type is not None:
                                                    return True

                                                if self.tunnel_v6_enabled is not None:
                                                    return True

                                                if self.tunnel_v6_required is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.NhteTunnel']['meta_info']


                                        class PelemPathNeighborAddr(object):
                                            """
                                            Path neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-neighbor-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-path-element'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.is_perm_path_pelem is not None:
                                                return True

                                            if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                return True

                                            if self.pelem_flags is not None:
                                                return True

                                            if self.pelem_gw_metric is not None:
                                                return True

                                            if self.pelem_no_addpath_table_attr_version is not None:
                                                return True

                                            if self.pelem_no_bestpath_table_attr_version is not None:
                                                return True

                                            if self.pelem_path_flags is not None:
                                                return True

                                            if self.pelem_path_id is not None:
                                                return True

                                            if self.pelem_path_neighbor_addr is not None and self.pelem_path_neighbor_addr._has_data():
                                                return True

                                            if self.pelem_path_nexthop is not None and self.pelem_path_nexthop._has_data():
                                                return True

                                            if self.pelem_path_peer_path_id is not None:
                                                return True

                                            if self.pelem_path_table_attr_version is not None:
                                                return True

                                            if self.pelem_table_attr_version is not None:
                                                return True

                                            if self.pelem_version is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-prefix'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.active_path_element is not None:
                                            for child_ref in self.active_path_element:
                                                if child_ref._has_data():
                                                    return True

                                        if self.active_process_instance_path is not None:
                                            for child_ref in self.active_process_instance_path:
                                                if child_ref._has_data():
                                                    return True

                                        if self.add_path_orr_bitfield is not None:
                                            for child_ref in self.add_path_orr_bitfield:
                                                if child_ref._has_data():
                                                    return True

                                        if self.advertisedto_pe is not None:
                                            return True

                                        if self.af_name is not None:
                                            return True

                                        if self.best_path_orr_bitfield is not None:
                                            for child_ref in self.best_path_orr_bitfield:
                                                if child_ref._has_data():
                                                    return True

                                        if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                            return True

                                        if self.bit is not None:
                                            return True

                                        if self.flags is not None:
                                            return True

                                        if self.gateway_array is not None:
                                            return True

                                        if self.has_inconsistent_paths is not None:
                                            return True

                                        if self.has_lbl_retained is not None:
                                            return True

                                        if self.has_local_label is not None:
                                            return True

                                        if self.is_net_aggregation_suppressed is not None:
                                            return True

                                        if self.is_net_ldp_signaled is not None:
                                            return True

                                        if self.is_permanent_network is not None:
                                            return True

                                        if self.local_path_element is not None:
                                            for child_ref in self.local_path_element:
                                                if child_ref._has_data():
                                                    return True

                                        if self.local_peers_advertised_to is not None:
                                            for child_ref in self.local_peers_advertised_to:
                                                if child_ref._has_data():
                                                    return True

                                        if self.local_process_instance_path is not None:
                                            for child_ref in self.local_process_instance_path:
                                                if child_ref._has_data():
                                                    return True

                                        if self.net_backup_available is not None:
                                            return True

                                        if self.net_backup_label_rewrite_available is not None:
                                            return True

                                        if self.net_eibgp_multipath is not None:
                                            return True

                                        if self.net_extended_flags is not None:
                                            return True

                                        if self.net_flags is not None:
                                            return True

                                        if self.net_local_label is not None:
                                            return True

                                        if self.net_local_label_rewrite is not None:
                                            return True

                                        if self.net_local_label_srgb is not None:
                                            return True

                                        if self.net_multipath is not None:
                                            return True

                                        if self.network_prefix is not None:
                                            return True

                                        if self.num_of_path is not None:
                                            return True

                                        if self.pe_peers_advertised_to is not None:
                                            for child_ref in self.pe_peers_advertised_to:
                                                if child_ref._has_data():
                                                    return True

                                        if self.process_instance_id is not None:
                                            return True

                                        if self.rd is not None:
                                            return True

                                        if self.resilient_nexthop_set is not None:
                                            return True

                                        if self.rib_failed is not None:
                                            return True

                                        if self.route_distinguisher is not None:
                                            return True

                                        if self.table_brib_version is not None:
                                            return True

                                        if self.table_version is not None:
                                            return True

                                        if self.version is not None:
                                            return True

                                        if self.version_age is not None and self.version_age._has_data():
                                            return True

                                        if self.version_timestamp is not None and self.version_timestamp._has_data():
                                            return True

                                        if self.vrf_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-prefixes'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.network_prefix is not None:
                                        for child_ref in self.network_prefix:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkPrefixes']['meta_info']


                            class AdvertisedPathXr(object):
                                """
                                The BGP Advertised path table (bestpath)
                                
                                .. attribute:: advertised_path
                                
                                	A BGP Advertised path table entry (bestpath)
                                	**type**\: list of    :py:class:`AdvertisedPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.advertised_path = YList()
                                    self.advertised_path.parent = self
                                    self.advertised_path.name = 'advertised_path'


                                class AdvertisedPath(object):
                                    """
                                    A BGP Advertised path table entry (bestpath)
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: attributes_after_policy_in
                                    
                                    	Attributes after inbound policy applied
                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn>`
                                    
                                    .. attribute:: label_fail
                                    
                                    	LSD label allocation failed 
                                    	**type**\:  bool
                                    
                                    .. attribute:: label_o_or_version
                                    
                                    	Label Version when OOR happens
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_oor
                                    
                                    	LSD label space is exhausted
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr>`
                                    
                                    .. attribute:: network
                                    
                                    	Network Prefix in Hex format
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: no_path
                                    
                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_information
                                    
                                    	Path information
                                    	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: prefix_version
                                    
                                    	Version of BGP Prefix Table
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_route_distinguisher
                                    
                                    	Source Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_vrf_name
                                    
                                    	Name of the source VRF
                                    	**type**\:  str
                                    
                                    .. attribute:: srcaf_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn()
                                        self.attributes_after_policy_in.parent = self
                                        self.label_fail = None
                                        self.label_o_or_version = None
                                        self.label_oor = None
                                        self.neighbor_address = None
                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr()
                                        self.neighbor_address_xr.parent = self
                                        self.network = None
                                        self.no_path = None
                                        self.path_information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation()
                                        self.path_information.parent = self
                                        self.prefix_length = None
                                        self.prefix_version = None
                                        self.process_instance_id = None
                                        self.rd = None
                                        self.route_distinguisher = None
                                        self.source_route_distinguisher = None
                                        self.source_vrf_name = None
                                        self.srcaf_name = None
                                        self.vrf_name = None


                                    class NeighborAddressXr(object):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr']['meta_info']


                                    class PathInformation(object):
                                        """
                                        Path information
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_own_self_originated_p_ath
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\:  bool
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield>`
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner>`
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix>`
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity>`
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\:  bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\:  bool
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr>`
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_esi
                                        
                                        	Path has EVPN ESI
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_rcvd_label
                                        
                                        	Path has received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\:  bool
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebg_ps
                                        
                                        	Not advertised to EBGPs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2VpnCircuitStatusValue>`
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2VpnEvpnEsi>`
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr>`
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue>`
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress>`
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop>`
                                        
                                        .. attribute:: nhte_tunnel
                                        
                                        	NH TE tunnel information
                                        	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhteTunnel>`
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\:  bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.accept_own_path = None
                                            self.accept_own_self_originated_p_ath = None
                                            self.add_path_orr_bitfield = YList()
                                            self.add_path_orr_bitfield.parent = self
                                            self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                            self.advertisedto_pe = None
                                            self.aigp_metric = None
                                            self.best_path_comp_stage = None
                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self.best_path_id = None
                                            self.best_path_id_comp_winner = None
                                            self.best_path_orr_bitfield = YList()
                                            self.best_path_orr_bitfield.parent = self
                                            self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self.dampen_penalty = None
                                            self.extended_community = YList()
                                            self.extended_community.parent = self
                                            self.extended_community.name = 'extended_community'
                                            self.fspec_invalid_path = None
                                            self.graceful_shutdown = None
                                            self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr()
                                            self.gw_addr.parent = self
                                            self.halflife_time = None
                                            self.has_esi = None
                                            self.has_gw_addr = None
                                            self.has_local_net_label = None
                                            self.has_mdt_group_addr = None
                                            self.has_mvpn_extcomm = None
                                            self.has_mvpn_nbr_addr = None
                                            self.has_mvpn_nexthop_addr = None
                                            self.has_mvpn_pmsi = None
                                            self.has_rcvd_label = None
                                            self.has_second_label = None
                                            self.ibgp_signaled_validity = None
                                            self.igp_metric = None
                                            self.is_aggregation_suppressed = None
                                            self.is_as_best = None
                                            self.is_best_path = None
                                            self.is_import_dampened = None
                                            self.is_import_suspect = None
                                            self.is_internal_path = None
                                            self.is_partial_best = None
                                            self.is_path_additional_path = None
                                            self.is_path_advertised_local_as_only = None
                                            self.is_path_af_install_eligible = None
                                            self.is_path_backup = None
                                            self.is_path_backup_protect_multipath = None
                                            self.is_path_best_external = None
                                            self.is_path_damped = None
                                            self.is_path_from_confederation_peer = None
                                            self.is_path_from_network_command = None
                                            self.is_path_from_redistribute_command = None
                                            self.is_path_from_route_reflector = None
                                            self.is_path_history_held = None
                                            self.is_path_imp_candidate = None
                                            self.is_path_imported = None
                                            self.is_path_local_aggregate = None
                                            self.is_path_locally_sourced = None
                                            self.is_path_long_lived_stale = None
                                            self.is_path_multipath = None
                                            self.is_path_nexthop_discarded = None
                                            self.is_path_not_advertised = None
                                            self.is_path_not_advertised_to_ebg_ps = None
                                            self.is_path_received_only = None
                                            self.is_path_reoriginated = None
                                            self.is_path_reoriginated_stitching = None
                                            self.is_path_stale = None
                                            self.is_path_synced_with_igp = None
                                            self.is_path_valid = None
                                            self.is_path_vpn_only = None
                                            self.is_permanent_path = None
                                            self.is_received_path_not_modified = None
                                            self.is_spkr_as_best = None
                                            self.l2vpn_circuit_status_value = YList()
                                            self.l2vpn_circuit_status_value.parent = self
                                            self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                            self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2VpnEvpnEsi()
                                            self.l2vpn_evpn_esi.parent = self
                                            self.l2vpn_size = None
                                            self.labeled_unicast_safi_path = None
                                            self.local_label = None
                                            self.local_nh = None
                                            self.local_path_id = None
                                            self.local_peers_advertised_to = YList()
                                            self.local_peers_advertised_to.parent = self
                                            self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                            self.maximum_suppress_time = None
                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self.mvpn_path_flags = None
                                            self.mvpn_pmsi_flags = None
                                            self.mvpn_pmsi_label = None
                                            self.mvpn_pmsi_type = None
                                            self.mvpn_pmsi_value = YList()
                                            self.mvpn_pmsi_value.parent = self
                                            self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                            self.mvpn_sfs_path = None
                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self.neighbor_router_id = None
                                            self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop()
                                            self.next_hop.parent = self
                                            self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhteTunnel()
                                            self.nhte_tunnel.parent = self
                                            self.path_flags = None
                                            self.path_flap_count = None
                                            self.path_import_flags = None
                                            self.path_rt_set_id = None
                                            self.path_rt_set_route_count = None
                                            self.path_table_version = None
                                            self.path_weight = None
                                            self.pe_peers_advertised_to = YList()
                                            self.pe_peers_advertised_to.parent = self
                                            self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                            self.rcvd_label = None
                                            self.rcvd_path_id = None
                                            self.reuse_value = None
                                            self.rib_failed = None
                                            self.route_type = None
                                            self.rpki_origin_as_validation_disabled = None
                                            self.rt_set_limit_enabled = None
                                            self.second_label = None
                                            self.seconds_since_first_flap = None
                                            self.show_rpki_origin_as_validity = None
                                            self.sn_rpki_origin_as_validity = None
                                            self.suppress_penalty = None
                                            self.time_to_unsuppress = None


                                        class BgpPrefix(object):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self.prefix_length = None


                                            class Prefix(object):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.prefix is not None and self.prefix._has_data():
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix']['meta_info']


                                        class NeighborAddress(object):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress']['meta_info']


                                        class NextHop(object):
                                            """
                                            Next hop
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop']['meta_info']


                                        class NhteTunnel(object):
                                            """
                                            NH TE tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_te_tunnel
                                            
                                            	NH TE Tunnel info is present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last rib update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	tunnel name
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	tunnel type
                                            	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.binding_label = None
                                                self.has_te_tunnel = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.is_tunnel_up = None
                                                self.last_tunnel_update = None
                                                self.tunnel_if_handle = None
                                                self.tunnel_name = None
                                                self.tunnel_type = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_v6_required = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.binding_label is not None:
                                                    return True

                                                if self.has_te_tunnel is not None:
                                                    return True

                                                if self.is_tunnel_info_stale is not None:
                                                    return True

                                                if self.is_tunnel_registered is not None:
                                                    return True

                                                if self.is_tunnel_up is not None:
                                                    return True

                                                if self.last_tunnel_update is not None:
                                                    return True

                                                if self.tunnel_if_handle is not None:
                                                    return True

                                                if self.tunnel_name is not None:
                                                    return True

                                                if self.tunnel_type is not None:
                                                    return True

                                                if self.tunnel_v6_enabled is not None:
                                                    return True

                                                if self.tunnel_v6_required is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhteTunnel']['meta_info']


                                        class MdtGroupAddr(object):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr']['meta_info']


                                        class L2VpnEvpnEsi(object):
                                            """
                                            L2VPN EVPN ESI
                                            
                                            .. attribute:: esi
                                            
                                            	esi
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.esi = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.esi is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2VpnEvpnEsi']['meta_info']


                                        class GwAddr(object):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.len = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.len is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr']['meta_info']


                                        class BestPathCompWinner(object):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner']['meta_info']


                                        class MvpnNbrAddr(object):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr']['meta_info']


                                        class MvpnNexthopAddr(object):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr']['meta_info']


                                        class L2VpnCircuitStatusValue(object):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                        class MvpnPmsiValue(object):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue']['meta_info']


                                        class ExtendedCommunity(object):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity']['meta_info']


                                        class LocalPeersAdvertisedTo(object):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                        class PePeersAdvertisedTo(object):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo']['meta_info']


                                        class BestPathOrrBitfield(object):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield']['meta_info']


                                        class AddPathOrrBitfield(object):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.accept_own_path is not None:
                                                return True

                                            if self.accept_own_self_originated_p_ath is not None:
                                                return True

                                            if self.add_path_orr_bitfield is not None:
                                                for child_ref in self.add_path_orr_bitfield:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.advertisedto_pe is not None:
                                                return True

                                            if self.aigp_metric is not None:
                                                return True

                                            if self.best_path_comp_stage is not None:
                                                return True

                                            if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                return True

                                            if self.best_path_id is not None:
                                                return True

                                            if self.best_path_id_comp_winner is not None:
                                                return True

                                            if self.best_path_orr_bitfield is not None:
                                                for child_ref in self.best_path_orr_bitfield:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                return True

                                            if self.dampen_penalty is not None:
                                                return True

                                            if self.extended_community is not None:
                                                for child_ref in self.extended_community:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.fspec_invalid_path is not None:
                                                return True

                                            if self.graceful_shutdown is not None:
                                                return True

                                            if self.gw_addr is not None and self.gw_addr._has_data():
                                                return True

                                            if self.halflife_time is not None:
                                                return True

                                            if self.has_esi is not None:
                                                return True

                                            if self.has_gw_addr is not None:
                                                return True

                                            if self.has_local_net_label is not None:
                                                return True

                                            if self.has_mdt_group_addr is not None:
                                                return True

                                            if self.has_mvpn_extcomm is not None:
                                                return True

                                            if self.has_mvpn_nbr_addr is not None:
                                                return True

                                            if self.has_mvpn_nexthop_addr is not None:
                                                return True

                                            if self.has_mvpn_pmsi is not None:
                                                return True

                                            if self.has_rcvd_label is not None:
                                                return True

                                            if self.has_second_label is not None:
                                                return True

                                            if self.ibgp_signaled_validity is not None:
                                                return True

                                            if self.igp_metric is not None:
                                                return True

                                            if self.is_aggregation_suppressed is not None:
                                                return True

                                            if self.is_as_best is not None:
                                                return True

                                            if self.is_best_path is not None:
                                                return True

                                            if self.is_import_dampened is not None:
                                                return True

                                            if self.is_import_suspect is not None:
                                                return True

                                            if self.is_internal_path is not None:
                                                return True

                                            if self.is_partial_best is not None:
                                                return True

                                            if self.is_path_additional_path is not None:
                                                return True

                                            if self.is_path_advertised_local_as_only is not None:
                                                return True

                                            if self.is_path_af_install_eligible is not None:
                                                return True

                                            if self.is_path_backup is not None:
                                                return True

                                            if self.is_path_backup_protect_multipath is not None:
                                                return True

                                            if self.is_path_best_external is not None:
                                                return True

                                            if self.is_path_damped is not None:
                                                return True

                                            if self.is_path_from_confederation_peer is not None:
                                                return True

                                            if self.is_path_from_network_command is not None:
                                                return True

                                            if self.is_path_from_redistribute_command is not None:
                                                return True

                                            if self.is_path_from_route_reflector is not None:
                                                return True

                                            if self.is_path_history_held is not None:
                                                return True

                                            if self.is_path_imp_candidate is not None:
                                                return True

                                            if self.is_path_imported is not None:
                                                return True

                                            if self.is_path_local_aggregate is not None:
                                                return True

                                            if self.is_path_locally_sourced is not None:
                                                return True

                                            if self.is_path_long_lived_stale is not None:
                                                return True

                                            if self.is_path_multipath is not None:
                                                return True

                                            if self.is_path_nexthop_discarded is not None:
                                                return True

                                            if self.is_path_not_advertised is not None:
                                                return True

                                            if self.is_path_not_advertised_to_ebg_ps is not None:
                                                return True

                                            if self.is_path_received_only is not None:
                                                return True

                                            if self.is_path_reoriginated is not None:
                                                return True

                                            if self.is_path_reoriginated_stitching is not None:
                                                return True

                                            if self.is_path_stale is not None:
                                                return True

                                            if self.is_path_synced_with_igp is not None:
                                                return True

                                            if self.is_path_valid is not None:
                                                return True

                                            if self.is_path_vpn_only is not None:
                                                return True

                                            if self.is_permanent_path is not None:
                                                return True

                                            if self.is_received_path_not_modified is not None:
                                                return True

                                            if self.is_spkr_as_best is not None:
                                                return True

                                            if self.l2vpn_circuit_status_value is not None:
                                                for child_ref in self.l2vpn_circuit_status_value:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                return True

                                            if self.l2vpn_size is not None:
                                                return True

                                            if self.labeled_unicast_safi_path is not None:
                                                return True

                                            if self.local_label is not None:
                                                return True

                                            if self.local_nh is not None:
                                                return True

                                            if self.local_path_id is not None:
                                                return True

                                            if self.local_peers_advertised_to is not None:
                                                for child_ref in self.local_peers_advertised_to:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.maximum_suppress_time is not None:
                                                return True

                                            if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                return True

                                            if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                return True

                                            if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                return True

                                            if self.mvpn_path_flags is not None:
                                                return True

                                            if self.mvpn_pmsi_flags is not None:
                                                return True

                                            if self.mvpn_pmsi_label is not None:
                                                return True

                                            if self.mvpn_pmsi_type is not None:
                                                return True

                                            if self.mvpn_pmsi_value is not None:
                                                for child_ref in self.mvpn_pmsi_value:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.mvpn_sfs_path is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            if self.neighbor_router_id is not None:
                                                return True

                                            if self.next_hop is not None and self.next_hop._has_data():
                                                return True

                                            if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                return True

                                            if self.path_flags is not None:
                                                return True

                                            if self.path_flap_count is not None:
                                                return True

                                            if self.path_import_flags is not None:
                                                return True

                                            if self.path_rt_set_id is not None:
                                                return True

                                            if self.path_rt_set_route_count is not None:
                                                return True

                                            if self.path_table_version is not None:
                                                return True

                                            if self.path_weight is not None:
                                                return True

                                            if self.pe_peers_advertised_to is not None:
                                                for child_ref in self.pe_peers_advertised_to:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.rcvd_label is not None:
                                                return True

                                            if self.rcvd_path_id is not None:
                                                return True

                                            if self.reuse_value is not None:
                                                return True

                                            if self.rib_failed is not None:
                                                return True

                                            if self.route_type is not None:
                                                return True

                                            if self.rpki_origin_as_validation_disabled is not None:
                                                return True

                                            if self.rt_set_limit_enabled is not None:
                                                return True

                                            if self.second_label is not None:
                                                return True

                                            if self.seconds_since_first_flap is not None:
                                                return True

                                            if self.show_rpki_origin_as_validity is not None:
                                                return True

                                            if self.sn_rpki_origin_as_validity is not None:
                                                return True

                                            if self.suppress_penalty is not None:
                                                return True

                                            if self.time_to_unsuppress is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation']['meta_info']


                                    class AttributesAfterPolicyIn(object):
                                        """
                                        Attributes after inbound policy applied
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet>`
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes>`
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp>`
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr>`
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\:  bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet()
                                            self.attr_set.parent = self
                                            self.attribute_key_number = None
                                            self.attribute_reuse_id_config = None
                                            self.attribute_reuse_id_current = None
                                            self.attribute_reuse_id_keys = None
                                            self.attribute_reuse_id_max_id = None
                                            self.attribute_reuse_id_node = None
                                            self.attribute_reuse_id_recover_sec = None
                                            self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self.is_application_gateway_present = None
                                            self.is_as_path2_byte = None
                                            self.is_attr_set_present = None
                                            self.is_ribrnh_present = None
                                            self.is_rnh_present = None
                                            self.ribrnh_encap = None
                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self.ribrnh_mac = None
                                            self.ribrnh_table = None
                                            self.ribrnh_vni = None
                                            self.ribrnhip_table = None
                                            self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self.rnh_addr_len = None
                                            self.rnh_len = None
                                            self.rnh_type = None
                                            self.set_aigp_inbound_igp = None
                                            self.set_aigp_inbound_metric = None
                                            self.vpn_distinguisher = None


                                        class CommonAttributes(object):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_encap_present
                                            
                                            	Tunnel Encap attribute present 
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_policy_allocated_binding_sid
                                            
                                            	SR Policy allocated Binding sid by the router
                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                            
                                            .. attribute:: sr_policy_binding_sid
                                            
                                            	SR Policy Binding sid
                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                            
                                            .. attribute:: sr_policy_explicit_path
                                            
                                            	SR Policy Explicit paths
                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                            
                                            .. attribute:: sr_policy_preference
                                            
                                            	SR Policy Preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_tunnel_request_state
                                            
                                            	SR Tunnel Request State
                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                            
                                            .. attribute:: sr_tunnel_state
                                            
                                            	SR Tunnel State
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap_type
                                            
                                            	Tunnel Encap Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.aggregator_address = None
                                                self.aggregator_as = None
                                                self.aigp_metric_value = None
                                                self.as_path = None
                                                self.cluster = YList()
                                                self.cluster.parent = self
                                                self.cluster.name = 'cluster'
                                                self.community = YList()
                                                self.community.parent = self
                                                self.community.name = 'community'
                                                self.connector_type = None
                                                self.connector_value = YList()
                                                self.connector_value.parent = self
                                                self.connector_value.name = 'connector_value'
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.extended_community_flags = None
                                                self.is_aggregator_present = None
                                                self.is_aigp_present = None
                                                self.is_as_path_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_community_present = None
                                                self.is_connector_present = None
                                                self.is_extended_community_present = None
                                                self.is_label_index_present = None
                                                self.is_local_pref_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_metric_present = None
                                                self.is_origin_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_ssa_present = None
                                                self.is_tunnel_encap_present = None
                                                self.l2tpv3_cookie = YList()
                                                self.l2tpv3_cookie.parent = self
                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                self.l2tpv3_session_id = None
                                                self.label_index_attr = YList()
                                                self.label_index_attr.parent = self
                                                self.label_index_attr.name = 'label_index_attr'
                                                self.local_preference = None
                                                self.ls_attr = YList()
                                                self.ls_attr.parent = self
                                                self.ls_attr.name = 'ls_attr'
                                                self.metric = None
                                                self.neighbor_as = None
                                                self.origin = None
                                                self.originator = None
                                                self.pe_distinguisher_label = YList()
                                                self.pe_distinguisher_label.parent = self
                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.pmsi_type = None
                                                self.pmsi_value = YList()
                                                self.pmsi_value.parent = self
                                                self.pmsi_value.name = 'pmsi_value'
                                                self.ppm_pvalue = None
                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                self.sr_policy_allocated_binding_sid.parent = self
                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                self.sr_policy_binding_sid.parent = self
                                                self.sr_policy_explicit_path = YList()
                                                self.sr_policy_explicit_path.parent = self
                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                self.sr_policy_preference = None
                                                self.sr_tunnel_request_state = None
                                                self.sr_tunnel_state = None
                                                self.tunnel_encap_type = None
                                                self.unknown_attribute = YList()
                                                self.unknown_attribute.parent = self
                                                self.unknown_attribute.name = 'unknown_attribute'


                                            class SrPolicyBindingSid(object):
                                                """
                                                SR Policy Binding sid
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                            class SrPolicyAllocatedBindingSid(object):
                                                """
                                                SR Policy allocated Binding sid by the router
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                            class Community(object):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                            class UnknownAttribute(object):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                            class Cluster(object):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                            class L2Tpv3Cookie(object):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                            class ConnectorValue(object):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                            class PmsiValue(object):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                            class LsAttr(object):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                            class LabelIndexAttr(object):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                            class PeDistinguisherLabel(object):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.label = None
                                                    self.pe_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.label is not None:
                                                        return True

                                                    if self.pe_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                            class SrPolicyExplicitPath(object):
                                                """
                                                SR Policy Explicit paths
                                                
                                                .. attribute:: sid
                                                
                                                	Sidlist for explicit path
                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                
                                                .. attribute:: weight
                                                
                                                	Weight of explicit path
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.sid = YList()
                                                    self.sid.parent = self
                                                    self.sid.name = 'sid'
                                                    self.weight = None


                                                class Sid(object):
                                                    """
                                                    Sidlist for explicit path
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IP Address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label sid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Sid Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4 is not None:
                                                            return True

                                                        if self.ipv6 is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.sid is not None:
                                                        for child_ref in self.sid:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.weight is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.aggregator_address is not None:
                                                    return True

                                                if self.aggregator_as is not None:
                                                    return True

                                                if self.aigp_metric_value is not None:
                                                    return True

                                                if self.as_path is not None:
                                                    return True

                                                if self.cluster is not None:
                                                    for child_ref in self.cluster:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.community is not None:
                                                    for child_ref in self.community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.connector_type is not None:
                                                    return True

                                                if self.connector_value is not None:
                                                    for child_ref in self.connector_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community_flags is not None:
                                                    return True

                                                if self.is_aggregator_present is not None:
                                                    return True

                                                if self.is_aigp_present is not None:
                                                    return True

                                                if self.is_as_path_present is not None:
                                                    return True

                                                if self.is_atomic_aggregate_present is not None:
                                                    return True

                                                if self.is_community_present is not None:
                                                    return True

                                                if self.is_connector_present is not None:
                                                    return True

                                                if self.is_extended_community_present is not None:
                                                    return True

                                                if self.is_label_index_present is not None:
                                                    return True

                                                if self.is_local_pref_present is not None:
                                                    return True

                                                if self.is_ls_attribute_present is not None:
                                                    return True

                                                if self.is_metric_present is not None:
                                                    return True

                                                if self.is_origin_present is not None:
                                                    return True

                                                if self.is_pe_distinguisher_label_present is not None:
                                                    return True

                                                if self.is_pmsi_present is not None:
                                                    return True

                                                if self.is_pppmp_present is not None:
                                                    return True

                                                if self.is_ssa_present is not None:
                                                    return True

                                                if self.is_tunnel_encap_present is not None:
                                                    return True

                                                if self.l2tpv3_cookie is not None:
                                                    for child_ref in self.l2tpv3_cookie:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2tpv3_session_id is not None:
                                                    return True

                                                if self.label_index_attr is not None:
                                                    for child_ref in self.label_index_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_preference is not None:
                                                    return True

                                                if self.ls_attr is not None:
                                                    for child_ref in self.ls_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.metric is not None:
                                                    return True

                                                if self.neighbor_as is not None:
                                                    return True

                                                if self.origin is not None:
                                                    return True

                                                if self.originator is not None:
                                                    return True

                                                if self.pe_distinguisher_label is not None:
                                                    for child_ref in self.pe_distinguisher_label:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.pmsi_flags is not None:
                                                    return True

                                                if self.pmsi_label is not None:
                                                    return True

                                                if self.pmsi_type is not None:
                                                    return True

                                                if self.pmsi_value is not None:
                                                    for child_ref in self.pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.ppm_pvalue is not None:
                                                    return True

                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_explicit_path is not None:
                                                    for child_ref in self.sr_policy_explicit_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.sr_policy_preference is not None:
                                                    return True

                                                if self.sr_tunnel_request_state is not None:
                                                    return True

                                                if self.sr_tunnel_state is not None:
                                                    return True

                                                if self.tunnel_encap_type is not None:
                                                    return True

                                                if self.unknown_attribute is not None:
                                                    for child_ref in self.unknown_attribute:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                        class AttrSet(object):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_encap_present
                                            
                                            	Tunnel Encap attribute present 
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_policy_allocated_binding_sid
                                            
                                            	SR Policy allocated Binding sid by the router
                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                            
                                            .. attribute:: sr_policy_binding_sid
                                            
                                            	SR Policy Binding sid
                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                            
                                            .. attribute:: sr_policy_explicit_path
                                            
                                            	SR Policy Explicit paths
                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                            
                                            .. attribute:: sr_policy_preference
                                            
                                            	SR Policy Preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_tunnel_request_state
                                            
                                            	SR Tunnel Request State
                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                            
                                            .. attribute:: sr_tunnel_state
                                            
                                            	SR Tunnel State
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap_type
                                            
                                            	Tunnel Encap Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.aggregator_address = None
                                                self.aggregator_as = None
                                                self.aigp_metric_value = None
                                                self.as_path = None
                                                self.cluster = YList()
                                                self.cluster.parent = self
                                                self.cluster.name = 'cluster'
                                                self.community = YList()
                                                self.community.parent = self
                                                self.community.name = 'community'
                                                self.connector_type = None
                                                self.connector_value = YList()
                                                self.connector_value.parent = self
                                                self.connector_value.name = 'connector_value'
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.extended_community_flags = None
                                                self.is_aggregator_present = None
                                                self.is_aigp_present = None
                                                self.is_as_path_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_community_present = None
                                                self.is_connector_present = None
                                                self.is_extended_community_present = None
                                                self.is_label_index_present = None
                                                self.is_local_pref_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_metric_present = None
                                                self.is_origin_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_ssa_present = None
                                                self.is_tunnel_encap_present = None
                                                self.l2tpv3_cookie = YList()
                                                self.l2tpv3_cookie.parent = self
                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                self.l2tpv3_session_id = None
                                                self.label_index_attr = YList()
                                                self.label_index_attr.parent = self
                                                self.label_index_attr.name = 'label_index_attr'
                                                self.local_preference = None
                                                self.ls_attr = YList()
                                                self.ls_attr.parent = self
                                                self.ls_attr.name = 'ls_attr'
                                                self.metric = None
                                                self.neighbor_as = None
                                                self.origin = None
                                                self.originator = None
                                                self.pe_distinguisher_label = YList()
                                                self.pe_distinguisher_label.parent = self
                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.pmsi_type = None
                                                self.pmsi_value = YList()
                                                self.pmsi_value.parent = self
                                                self.pmsi_value.name = 'pmsi_value'
                                                self.ppm_pvalue = None
                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                self.sr_policy_allocated_binding_sid.parent = self
                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                self.sr_policy_binding_sid.parent = self
                                                self.sr_policy_explicit_path = YList()
                                                self.sr_policy_explicit_path.parent = self
                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                self.sr_policy_preference = None
                                                self.sr_tunnel_request_state = None
                                                self.sr_tunnel_state = None
                                                self.tunnel_encap_type = None
                                                self.unknown_attribute = YList()
                                                self.unknown_attribute.parent = self
                                                self.unknown_attribute.name = 'unknown_attribute'


                                            class SrPolicyBindingSid(object):
                                                """
                                                SR Policy Binding sid
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                            class SrPolicyAllocatedBindingSid(object):
                                                """
                                                SR Policy allocated Binding sid by the router
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                            class Community(object):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                            class UnknownAttribute(object):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                            class Cluster(object):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                            class L2Tpv3Cookie(object):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                            class ConnectorValue(object):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                            class PmsiValue(object):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                            class LsAttr(object):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                            class LabelIndexAttr(object):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                            class PeDistinguisherLabel(object):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.label = None
                                                    self.pe_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.label is not None:
                                                        return True

                                                    if self.pe_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                            class SrPolicyExplicitPath(object):
                                                """
                                                SR Policy Explicit paths
                                                
                                                .. attribute:: sid
                                                
                                                	Sidlist for explicit path
                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                
                                                .. attribute:: weight
                                                
                                                	Weight of explicit path
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.sid = YList()
                                                    self.sid.parent = self
                                                    self.sid.name = 'sid'
                                                    self.weight = None


                                                class Sid(object):
                                                    """
                                                    Sidlist for explicit path
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IP Address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label sid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Sid Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4 is not None:
                                                            return True

                                                        if self.ipv6 is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.sid is not None:
                                                        for child_ref in self.sid:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.weight is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.aggregator_address is not None:
                                                    return True

                                                if self.aggregator_as is not None:
                                                    return True

                                                if self.aigp_metric_value is not None:
                                                    return True

                                                if self.as_path is not None:
                                                    return True

                                                if self.cluster is not None:
                                                    for child_ref in self.cluster:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.community is not None:
                                                    for child_ref in self.community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.connector_type is not None:
                                                    return True

                                                if self.connector_value is not None:
                                                    for child_ref in self.connector_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community_flags is not None:
                                                    return True

                                                if self.is_aggregator_present is not None:
                                                    return True

                                                if self.is_aigp_present is not None:
                                                    return True

                                                if self.is_as_path_present is not None:
                                                    return True

                                                if self.is_atomic_aggregate_present is not None:
                                                    return True

                                                if self.is_community_present is not None:
                                                    return True

                                                if self.is_connector_present is not None:
                                                    return True

                                                if self.is_extended_community_present is not None:
                                                    return True

                                                if self.is_label_index_present is not None:
                                                    return True

                                                if self.is_local_pref_present is not None:
                                                    return True

                                                if self.is_ls_attribute_present is not None:
                                                    return True

                                                if self.is_metric_present is not None:
                                                    return True

                                                if self.is_origin_present is not None:
                                                    return True

                                                if self.is_pe_distinguisher_label_present is not None:
                                                    return True

                                                if self.is_pmsi_present is not None:
                                                    return True

                                                if self.is_pppmp_present is not None:
                                                    return True

                                                if self.is_ssa_present is not None:
                                                    return True

                                                if self.is_tunnel_encap_present is not None:
                                                    return True

                                                if self.l2tpv3_cookie is not None:
                                                    for child_ref in self.l2tpv3_cookie:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2tpv3_session_id is not None:
                                                    return True

                                                if self.label_index_attr is not None:
                                                    for child_ref in self.label_index_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_preference is not None:
                                                    return True

                                                if self.ls_attr is not None:
                                                    for child_ref in self.ls_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.metric is not None:
                                                    return True

                                                if self.neighbor_as is not None:
                                                    return True

                                                if self.origin is not None:
                                                    return True

                                                if self.originator is not None:
                                                    return True

                                                if self.pe_distinguisher_label is not None:
                                                    for child_ref in self.pe_distinguisher_label:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.pmsi_flags is not None:
                                                    return True

                                                if self.pmsi_label is not None:
                                                    return True

                                                if self.pmsi_type is not None:
                                                    return True

                                                if self.pmsi_value is not None:
                                                    for child_ref in self.pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.ppm_pvalue is not None:
                                                    return True

                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_explicit_path is not None:
                                                    for child_ref in self.sr_policy_explicit_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.sr_policy_preference is not None:
                                                    return True

                                                if self.sr_tunnel_request_state is not None:
                                                    return True

                                                if self.sr_tunnel_state is not None:
                                                    return True

                                                if self.tunnel_encap_type is not None:
                                                    return True

                                                if self.unknown_attribute is not None:
                                                    for child_ref in self.unknown_attribute:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                        class RnhAddr(object):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.len = None
                                                self.mac_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.len is not None:
                                                    return True

                                                if self.mac_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                        class RibrnhIp(object):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.attr_set is not None and self.attr_set._has_data():
                                                return True

                                            if self.attribute_key_number is not None:
                                                return True

                                            if self.attribute_reuse_id_config is not None:
                                                return True

                                            if self.attribute_reuse_id_current is not None:
                                                return True

                                            if self.attribute_reuse_id_keys is not None:
                                                return True

                                            if self.attribute_reuse_id_max_id is not None:
                                                return True

                                            if self.attribute_reuse_id_node is not None:
                                                return True

                                            if self.attribute_reuse_id_recover_sec is not None:
                                                return True

                                            if self.common_attributes is not None and self.common_attributes._has_data():
                                                return True

                                            if self.is_application_gateway_present is not None:
                                                return True

                                            if self.is_as_path2_byte is not None:
                                                return True

                                            if self.is_attr_set_present is not None:
                                                return True

                                            if self.is_ribrnh_present is not None:
                                                return True

                                            if self.is_rnh_present is not None:
                                                return True

                                            if self.ribrnh_encap is not None:
                                                return True

                                            if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                return True

                                            if self.ribrnh_mac is not None:
                                                return True

                                            if self.ribrnh_table is not None:
                                                return True

                                            if self.ribrnh_vni is not None:
                                                return True

                                            if self.ribrnhip_table is not None:
                                                return True

                                            if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                return True

                                            if self.rnh_addr_len is not None:
                                                return True

                                            if self.rnh_len is not None:
                                                return True

                                            if self.rnh_type is not None:
                                                return True

                                            if self.set_aigp_inbound_igp is not None:
                                                return True

                                            if self.set_aigp_inbound_metric is not None:
                                                return True

                                            if self.vpn_distinguisher is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertised-path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                            return True

                                        if self.label_fail is not None:
                                            return True

                                        if self.label_o_or_version is not None:
                                            return True

                                        if self.label_oor is not None:
                                            return True

                                        if self.neighbor_address is not None:
                                            return True

                                        if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                            return True

                                        if self.network is not None:
                                            return True

                                        if self.no_path is not None:
                                            return True

                                        if self.path_information is not None and self.path_information._has_data():
                                            return True

                                        if self.prefix_length is not None:
                                            return True

                                        if self.prefix_version is not None:
                                            return True

                                        if self.process_instance_id is not None:
                                            return True

                                        if self.rd is not None:
                                            return True

                                        if self.route_distinguisher is not None:
                                            return True

                                        if self.source_route_distinguisher is not None:
                                            return True

                                        if self.source_vrf_name is not None:
                                            return True

                                        if self.srcaf_name is not None:
                                            return True

                                        if self.vrf_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertised-path-xr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.advertised_path is not None:
                                        for child_ref in self.advertised_path:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr']['meta_info']


                            class SourcedNetworks(object):
                                """
                                The BGP Convergence table
                                
                                .. attribute:: sourced_network
                                
                                	A BGP network command table entry
                                	**type**\: list of    :py:class:`SourcedNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.sourced_network = YList()
                                    self.sourced_network.parent = self
                                    self.sourced_network.name = 'sourced_network'


                                class SourcedNetwork(object):
                                    """
                                    A BGP network command table entry
                                    
                                    .. attribute:: network  <key>
                                    
                                    	Network in prefix/length format
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    
                                    ----
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: is_backdoor
                                    
                                    	TRUE if net is a backdoor route
                                    	**type**\:  bool
                                    
                                    .. attribute:: sourced_prefix
                                    
                                    	Prefix length
                                    	**type**\:   :py:class:`SourcedPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.network = None
                                        self.af_name = None
                                        self.is_backdoor = None
                                        self.sourced_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix()
                                        self.sourced_prefix.parent = self


                                    class SourcedPrefix(object):
                                        """
                                        Prefix length
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix()
                                            self.prefix.parent = self
                                            self.prefix_length = None


                                        class Prefix(object):
                                            """
                                            Prefix
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sourced-prefix'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.prefix is not None and self.prefix._has_data():
                                                return True

                                            if self.prefix_length is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.network is None:
                                            raise YPYModelError('Key property network is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sourced-network[Cisco-IOS-XR-ipv4-bgp-oper:network = ' + str(self.network) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.network is not None:
                                            return True

                                        if self.af_name is not None:
                                            return True

                                        if self.is_backdoor is not None:
                                            return True

                                        if self.sourced_prefix is not None and self.sourced_prefix._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sourced-networks'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.sourced_network is not None:
                                        for child_ref in self.sourced_network:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks']['meta_info']


                            class UpdateGroups(object):
                                """
                                The BGP Update group table
                                
                                .. attribute:: update_group
                                
                                	A BGP Update group table entry
                                	**type**\: list of    :py:class:`UpdateGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.update_group = YList()
                                    self.update_group.parent = self
                                    self.update_group.name = 'update_group'


                                class UpdateGroup(object):
                                    """
                                    A BGP Update group table entry
                                    
                                    .. attribute:: accepts_legacy_pe_rt_route
                                    
                                    	accept\-legacy\-pe\-RT route
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_local_labeled_route_unicast
                                    
                                    	Advertise routes with local\-label via Unicast SAFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_rt_type
                                    
                                    	Advertise RT type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: as_override
                                    
                                    	AS Override option
                                    	**type**\:  bool
                                    
                                    .. attribute:: desync_count
                                    
                                    	Number of times the update has been desynchronized
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: disable_def_vrf_imp_advertisement
                                    
                                    	Disable advertising default VRF  imported routes
                                    	**type**\:  bool
                                    
                                    .. attribute:: disable_native_advertisement
                                    
                                    	Disable advertising native routes
                                    	**type**\:  bool
                                    
                                    .. attribute:: disable_vrf_re_imp_advertisement
                                    
                                    	Disable advertising VRF re\-imported routes
                                    	**type**\:  bool
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation type
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ext_nh_encoding
                                    
                                    	Extended nexthop encoding cap received
                                    	**type**\:  bool
                                    
                                    .. attribute:: filter_group_id
                                    
                                    	Filter group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: gshut_active
                                    
                                    	GSHUT active
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_locpref
                                    
                                    	GSHUT local preference
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: gshut_locpref_set
                                    
                                    	GSHUT local preference set
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_prepends
                                    
                                    	GSHUT AS prepends
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: has_orf_receive_capability
                                    
                                    	ORF receive capability
                                    	**type**\:  bool
                                    
                                    .. attribute:: is4_byte_as_peer
                                    
                                    	4\-byte AS capable peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_addpath_capable
                                    
                                    	Add\-path capable peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_adv_capable
                                    
                                    	Send tranlsated paths
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_adv_perm_net_capable
                                    
                                    	Advertise Permanent\-Net capable peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_adv_reorg_capable
                                    
                                    	Send Re\-orig paths
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_aigp_capable
                                    
                                    	AIGP capable peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_aigp_cost_community_capable
                                    
                                    	Send AIGP cost community to peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_aigp_med_capable
                                    
                                    	Send AIGP cost in MED
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_client_reflection_disabled
                                    
                                    	True if client\-to\-client reflection is disabled 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_common_admin_peers
                                    
                                    	Common admin peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_directly_connected_ebgp_v6_peers
                                    
                                    	Directly connected EBGP v6 peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_internal_peers
                                    
                                    	Internal peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_labeled_afi_enabled
                                    
                                    	Update group has labeled AFI enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_llgr_capable
                                    
                                    	Send Long\-lived Stale paths
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_orr_root_address_configured
                                    
                                    	ORR Root address configuredfor the neighbor connection
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_route_reflector_client
                                    
                                    	Route\-reflector client
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_send_mcast_attr_enabled
                                    
                                    	Send mcast attribute enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_unlabeled_afi_enabled
                                    
                                    	Update group has unlabeled AFI enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_as
                                    
                                    	Local AS number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_as_replace_as
                                    
                                    	Local AS Replace\-AS option
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_advertisement_interval
                                    
                                    	Minimum advertisement interval, secs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: minimum_advertisement_interval_msecs
                                    
                                    	Minimum advertisement interval, msecs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: neighbor
                                    
                                    	Neighbors in this update group which are not in any sub\-group
                                    	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor>`
                                    
                                    .. attribute:: orr_group_index
                                    
                                    	ORR Group Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: orr_group_name
                                    
                                    	ORR Group Name
                                    	**type**\:  str
                                    
                                    .. attribute:: performance_statistics
                                    
                                    	Performance statistics
                                    	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics>`
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: refresh_subgrp_count
                                    
                                    	Current count of refresh subgroups
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_as
                                    
                                    	Remote AS number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_policy_out
                                    
                                    	Outbound route policy name
                                    	**type**\:  str
                                    
                                    .. attribute:: session_af_name
                                    
                                    	Neighbor session Address family
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: should_remove_private_a_ss
                                    
                                    	Remove private AS numbers
                                    	**type**\:  bool
                                    
                                    .. attribute:: should_remove_private_as_ent_path
                                    
                                    	Remove private AS numbersif the entire path consistsof private ASes
                                    	**type**\:  bool
                                    
                                    .. attribute:: should_send_communities
                                    
                                    	Send communities
                                    	**type**\:  bool
                                    
                                    .. attribute:: should_send_ext_communities
                                    
                                    	Send Extended communities
                                    	**type**\:  bool
                                    
                                    .. attribute:: should_send_gshut_community
                                    
                                    	Send GSHUT community
                                    	**type**\:  bool
                                    
                                    .. attribute:: should_send_stitching_rt
                                    
                                    	Send Stitching RT
                                    	**type**\:  bool
                                    
                                    .. attribute:: soo
                                    
                                    	Site\-of\-origin option
                                    	**type**\:  bool
                                    
                                    .. attribute:: soo_value
                                    
                                    	Site\-of\-origin value
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: split_horizon
                                    
                                    	Split horizon check
                                    	**type**\:  bool
                                    
                                    .. attribute:: subgrp_merge_count
                                    
                                    	Number of times sub\-groups have been merged
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_group_af_name
                                    
                                    	Address family for update group
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: update_group_id
                                    
                                    	Update group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: update_group_number
                                    
                                    	Update group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_sub_group
                                    
                                    	Update sub\-group list
                                    	**type**\: list of    :py:class:`UpdateSubGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup>`
                                    
                                    .. attribute:: updates_formatted
                                    
                                    	Number of updates formatted
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: updates_replicated
                                    
                                    	No. of updates replicated
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: updgrp_cluster_id
                                    
                                    	Cluster ID (populated ifclient\-to\-client reflectionis disabled)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: updgrp_cluster_type
                                    
                                    	Cluster ID type\:undefined/number/Ip address
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: use_next_hop_self
                                    
                                    	Next hop self
                                    	**type**\:  bool
                                    
                                    .. attribute:: use_next_hop_unchanged_mpath
                                    
                                    	Next\-hop\-unchanged multipath
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.accepts_legacy_pe_rt_route = None
                                        self.advertise_local_labeled_route_unicast = None
                                        self.advertise_rt_type = None
                                        self.as_override = None
                                        self.desync_count = None
                                        self.disable_def_vrf_imp_advertisement = None
                                        self.disable_native_advertisement = None
                                        self.disable_vrf_re_imp_advertisement = None
                                        self.encapsulation_type = None
                                        self.ext_nh_encoding = None
                                        self.filter_group_id = None
                                        self.gshut_active = None
                                        self.gshut_locpref = None
                                        self.gshut_locpref_set = None
                                        self.gshut_prepends = None
                                        self.has_orf_receive_capability = None
                                        self.is4_byte_as_peer = None
                                        self.is_addpath_capable = None
                                        self.is_adv_capable = None
                                        self.is_adv_perm_net_capable = None
                                        self.is_adv_reorg_capable = None
                                        self.is_aigp_capable = None
                                        self.is_aigp_cost_community_capable = None
                                        self.is_aigp_med_capable = None
                                        self.is_client_reflection_disabled = None
                                        self.is_common_admin_peers = None
                                        self.is_directly_connected_ebgp_v6_peers = None
                                        self.is_internal_peers = None
                                        self.is_labeled_afi_enabled = None
                                        self.is_llgr_capable = None
                                        self.is_orr_root_address_configured = None
                                        self.is_route_reflector_client = None
                                        self.is_send_mcast_attr_enabled = None
                                        self.is_unlabeled_afi_enabled = None
                                        self.local_as = None
                                        self.local_as_replace_as = None
                                        self.minimum_advertisement_interval = None
                                        self.minimum_advertisement_interval_msecs = None
                                        self.neighbor = YList()
                                        self.neighbor.parent = self
                                        self.neighbor.name = 'neighbor'
                                        self.orr_group_index = None
                                        self.orr_group_name = None
                                        self.performance_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics()
                                        self.performance_statistics.parent = self
                                        self.process_instance_id = None
                                        self.refresh_subgrp_count = None
                                        self.remote_as = None
                                        self.route_policy_out = None
                                        self.session_af_name = None
                                        self.should_remove_private_a_ss = None
                                        self.should_remove_private_as_ent_path = None
                                        self.should_send_communities = None
                                        self.should_send_ext_communities = None
                                        self.should_send_gshut_community = None
                                        self.should_send_stitching_rt = None
                                        self.soo = None
                                        self.soo_value = None
                                        self.split_horizon = None
                                        self.subgrp_merge_count = None
                                        self.update_group_af_name = None
                                        self.update_group_id = None
                                        self.update_group_number = None
                                        self.update_sub_group = YList()
                                        self.update_sub_group.parent = self
                                        self.update_sub_group.name = 'update_sub_group'
                                        self.updates_formatted = None
                                        self.updates_replicated = None
                                        self.updgrp_cluster_id = None
                                        self.updgrp_cluster_type = None
                                        self.use_next_hop_self = None
                                        self.use_next_hop_unchanged_mpath = None


                                    class PerformanceStatistics(object):
                                        """
                                        Performance statistics
                                        
                                        .. attribute:: update_generation_be_prefixes_count
                                        
                                        	No. of be prefixes updates generated for
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_calls
                                        
                                        	No. of calls to update generation function
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_messages_count
                                        
                                        	No. of update messages generated
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_prefixes_count
                                        
                                        	No. of prefixes updates generated for
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_time
                                        
                                        	Time spent generating updates (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: updgen_timer_process_time
                                        
                                        	Timestamp when update timer processed for updgrp
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: updgen_timer_start_time
                                        
                                        	Timestamp when update timer started for updgrp
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: updgen_timer_stop_time
                                        
                                        	Timestamp when update timer stopped for updgrp
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.update_generation_be_prefixes_count = None
                                            self.update_generation_calls = None
                                            self.update_generation_messages_count = None
                                            self.update_generation_prefixes_count = None
                                            self.update_generation_time = None
                                            self.updgen_timer_process_time = None
                                            self.updgen_timer_start_time = None
                                            self.updgen_timer_stop_time = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:performance-statistics'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.update_generation_be_prefixes_count is not None:
                                                return True

                                            if self.update_generation_calls is not None:
                                                return True

                                            if self.update_generation_messages_count is not None:
                                                return True

                                            if self.update_generation_prefixes_count is not None:
                                                return True

                                            if self.update_generation_time is not None:
                                                return True

                                            if self.updgen_timer_process_time is not None:
                                                return True

                                            if self.updgen_timer_start_time is not None:
                                                return True

                                            if self.updgen_timer_stop_time is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics']['meta_info']


                                    class Neighbor(object):
                                        """
                                        Neighbors in this update group which are not in
                                        any sub\-group
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor']['meta_info']


                                    class UpdateSubGroup(object):
                                        """
                                        Update sub\-group list
                                        
                                        .. attribute:: filter_group
                                        
                                        	Update sub\-group fgrp\-num
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: neighbor
                                        
                                        	Neighbors in this subgrp not in any filtergrp
                                        	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor>`
                                        
                                        .. attribute:: update_filter_group
                                        
                                        	Update f\-group list
                                        	**type**\: list of    :py:class:`UpdateFilterGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup>`
                                        
                                        .. attribute:: update_sub_group_number
                                        
                                        	Update sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: wait_for_eo_rs
                                        
                                        	Wait for  RT Nbr EoRs
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.filter_group = None
                                            self.neighbor = YList()
                                            self.neighbor.parent = self
                                            self.neighbor.name = 'neighbor'
                                            self.update_filter_group = YList()
                                            self.update_filter_group.parent = self
                                            self.update_filter_group.name = 'update_filter_group'
                                            self.update_sub_group_number = None
                                            self.wait_for_eo_rs = None


                                        class UpdateFilterGroup(object):
                                            """
                                            Update f\-group list
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity>`
                                            
                                            .. attribute:: fgroup_advertised_prefixes
                                            
                                            	Number of prefixes advertised to filtergroup in last update walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_created_message_elements
                                            
                                            	Number of message elems created for filtergroup
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_deleted_message_elements
                                            
                                            	Number of message elems deleted
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_flags
                                            
                                            	Flags per filter group
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fgroup_neighbors
                                            
                                            	Nbrs per filter group
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: fgroup_queued_message_elements
                                            
                                            	Number of message elems queued
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_skipped_prefixes
                                            
                                            	Number of prefixes skipped for filtergroup in last update walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_suppressed_prefixes
                                            
                                            	Number of prefixes suppressed for filtergroup in last update walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_total_advertised_prefixes
                                            
                                            	Number of prefixes advertised to filtergroup in all update walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_total_non_optimised_prefixes
                                            
                                            	Number of prefixes  non\-optm from filtergroupin all update walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_total_withdrawn_prefixes
                                            
                                            	Number of prefixes withdrawn f`rom filtergroupin all update walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_withdrawn_prefixes
                                            
                                            	Number of prefixes withdrawn f`rom filtergroupin last update walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_rt_present
                                            
                                            	RT attribute list present
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor
                                            
                                            	Neighbors in this update sub\-group
                                            	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor>`
                                            
                                            .. attribute:: rts
                                            
                                            	RT count per filter group
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_filter_group_number
                                            
                                            	Update sub\-group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.fgroup_advertised_prefixes = None
                                                self.fgroup_created_message_elements = None
                                                self.fgroup_deleted_message_elements = None
                                                self.fgroup_flags = None
                                                self.fgroup_neighbors = None
                                                self.fgroup_queued_message_elements = None
                                                self.fgroup_skipped_prefixes = None
                                                self.fgroup_suppressed_prefixes = None
                                                self.fgroup_total_advertised_prefixes = None
                                                self.fgroup_total_non_optimised_prefixes = None
                                                self.fgroup_total_withdrawn_prefixes = None
                                                self.fgroup_withdrawn_prefixes = None
                                                self.is_rt_present = None
                                                self.neighbor = YList()
                                                self.neighbor.parent = self
                                                self.neighbor.name = 'neighbor'
                                                self.rts = None
                                                self.update_filter_group_number = None


                                            class ExtendedCommunity(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity']['meta_info']


                                            class Neighbor(object):
                                                """
                                                Neighbors in this update sub\-group
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-filter-group'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.fgroup_advertised_prefixes is not None:
                                                    return True

                                                if self.fgroup_created_message_elements is not None:
                                                    return True

                                                if self.fgroup_deleted_message_elements is not None:
                                                    return True

                                                if self.fgroup_flags is not None:
                                                    return True

                                                if self.fgroup_neighbors is not None:
                                                    return True

                                                if self.fgroup_queued_message_elements is not None:
                                                    return True

                                                if self.fgroup_skipped_prefixes is not None:
                                                    return True

                                                if self.fgroup_suppressed_prefixes is not None:
                                                    return True

                                                if self.fgroup_total_advertised_prefixes is not None:
                                                    return True

                                                if self.fgroup_total_non_optimised_prefixes is not None:
                                                    return True

                                                if self.fgroup_total_withdrawn_prefixes is not None:
                                                    return True

                                                if self.fgroup_withdrawn_prefixes is not None:
                                                    return True

                                                if self.is_rt_present is not None:
                                                    return True

                                                if self.neighbor is not None:
                                                    for child_ref in self.neighbor:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.rts is not None:
                                                    return True

                                                if self.update_filter_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup']['meta_info']


                                        class Neighbor(object):
                                            """
                                            Neighbors in this subgrp not in any filtergrp
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-sub-group'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.filter_group is not None:
                                                return True

                                            if self.neighbor is not None:
                                                for child_ref in self.neighbor:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.update_filter_group is not None:
                                                for child_ref in self.update_filter_group:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.update_sub_group_number is not None:
                                                return True

                                            if self.wait_for_eo_rs is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-group'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.accepts_legacy_pe_rt_route is not None:
                                            return True

                                        if self.advertise_local_labeled_route_unicast is not None:
                                            return True

                                        if self.advertise_rt_type is not None:
                                            return True

                                        if self.as_override is not None:
                                            return True

                                        if self.desync_count is not None:
                                            return True

                                        if self.disable_def_vrf_imp_advertisement is not None:
                                            return True

                                        if self.disable_native_advertisement is not None:
                                            return True

                                        if self.disable_vrf_re_imp_advertisement is not None:
                                            return True

                                        if self.encapsulation_type is not None:
                                            return True

                                        if self.ext_nh_encoding is not None:
                                            return True

                                        if self.filter_group_id is not None:
                                            return True

                                        if self.gshut_active is not None:
                                            return True

                                        if self.gshut_locpref is not None:
                                            return True

                                        if self.gshut_locpref_set is not None:
                                            return True

                                        if self.gshut_prepends is not None:
                                            return True

                                        if self.has_orf_receive_capability is not None:
                                            return True

                                        if self.is4_byte_as_peer is not None:
                                            return True

                                        if self.is_addpath_capable is not None:
                                            return True

                                        if self.is_adv_capable is not None:
                                            return True

                                        if self.is_adv_perm_net_capable is not None:
                                            return True

                                        if self.is_adv_reorg_capable is not None:
                                            return True

                                        if self.is_aigp_capable is not None:
                                            return True

                                        if self.is_aigp_cost_community_capable is not None:
                                            return True

                                        if self.is_aigp_med_capable is not None:
                                            return True

                                        if self.is_client_reflection_disabled is not None:
                                            return True

                                        if self.is_common_admin_peers is not None:
                                            return True

                                        if self.is_directly_connected_ebgp_v6_peers is not None:
                                            return True

                                        if self.is_internal_peers is not None:
                                            return True

                                        if self.is_labeled_afi_enabled is not None:
                                            return True

                                        if self.is_llgr_capable is not None:
                                            return True

                                        if self.is_orr_root_address_configured is not None:
                                            return True

                                        if self.is_route_reflector_client is not None:
                                            return True

                                        if self.is_send_mcast_attr_enabled is not None:
                                            return True

                                        if self.is_unlabeled_afi_enabled is not None:
                                            return True

                                        if self.local_as is not None:
                                            return True

                                        if self.local_as_replace_as is not None:
                                            return True

                                        if self.minimum_advertisement_interval is not None:
                                            return True

                                        if self.minimum_advertisement_interval_msecs is not None:
                                            return True

                                        if self.neighbor is not None:
                                            for child_ref in self.neighbor:
                                                if child_ref._has_data():
                                                    return True

                                        if self.orr_group_index is not None:
                                            return True

                                        if self.orr_group_name is not None:
                                            return True

                                        if self.performance_statistics is not None and self.performance_statistics._has_data():
                                            return True

                                        if self.process_instance_id is not None:
                                            return True

                                        if self.refresh_subgrp_count is not None:
                                            return True

                                        if self.remote_as is not None:
                                            return True

                                        if self.route_policy_out is not None:
                                            return True

                                        if self.session_af_name is not None:
                                            return True

                                        if self.should_remove_private_a_ss is not None:
                                            return True

                                        if self.should_remove_private_as_ent_path is not None:
                                            return True

                                        if self.should_send_communities is not None:
                                            return True

                                        if self.should_send_ext_communities is not None:
                                            return True

                                        if self.should_send_gshut_community is not None:
                                            return True

                                        if self.should_send_stitching_rt is not None:
                                            return True

                                        if self.soo is not None:
                                            return True

                                        if self.soo_value is not None:
                                            return True

                                        if self.split_horizon is not None:
                                            return True

                                        if self.subgrp_merge_count is not None:
                                            return True

                                        if self.update_group_af_name is not None:
                                            return True

                                        if self.update_group_id is not None:
                                            return True

                                        if self.update_group_number is not None:
                                            return True

                                        if self.update_sub_group is not None:
                                            for child_ref in self.update_sub_group:
                                                if child_ref._has_data():
                                                    return True

                                        if self.updates_formatted is not None:
                                            return True

                                        if self.updates_replicated is not None:
                                            return True

                                        if self.updgrp_cluster_id is not None:
                                            return True

                                        if self.updgrp_cluster_type is not None:
                                            return True

                                        if self.use_next_hop_self is not None:
                                            return True

                                        if self.use_next_hop_unchanged_mpath is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-groups'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.update_group is not None:
                                        for child_ref in self.update_group:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups']['meta_info']


                            class UpdateGenerationSubGroups(object):
                                """
                                Update generation for all sub\-groups
                                
                                .. attribute:: update_generation_sub_group
                                
                                	Update generation for sub\-group
                                	**type**\: list of    :py:class:`UpdateGenerationSubGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.update_generation_sub_group = YList()
                                    self.update_generation_sub_group.parent = self
                                    self.update_generation_sub_group.name = 'update_generation_sub_group'


                                class UpdateGenerationSubGroup(object):
                                    """
                                    Update generation for sub\-group
                                    
                                    .. attribute:: configured_update_limit_sub_group
                                    
                                    	Configured update limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: creation_timestamp
                                    
                                    	Creation time
                                    	**type**\:   :py:class:`CreationTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp>`
                                    
                                    .. attribute:: current_update_limit_sub_group
                                    
                                    	Current update limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: eo_r_attempted
                                    
                                    	Sending EoR has been attempted
                                    	**type**\:  bool
                                    
                                    .. attribute:: filter_group_count
                                    
                                    	Filter\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: first_update_walk_end_timestamp
                                    
                                    	First update walk end time
                                    	**type**\:   :py:class:`FirstUpdateWalkEndTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp>`
                                    
                                    .. attribute:: first_update_walk_start_timestamp
                                    
                                    	First update walk start time
                                    	**type**\:   :py:class:`FirstUpdateWalkStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp>`
                                    
                                    .. attribute:: io_write_event_pending
                                    
                                    	Is IO write event pending
                                    	**type**\:  bool
                                    
                                    .. attribute:: last_merge_timestamp
                                    
                                    	Last merge time
                                    	**type**\:   :py:class:`LastMergeTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp>`
                                    
                                    .. attribute:: last_merged_sub_group_index
                                    
                                    	Last merged sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_update_queued_age
                                    
                                    	Time since last update queued event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_queued_timestamp
                                    
                                    	Last update queued time
                                    	**type**\:   :py:class:`LastUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp>`
                                    
                                    .. attribute:: last_update_walk_end_age
                                    
                                    	Time since last update walk end event
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_update_walk_end_timestamp
                                    
                                    	Last update walk end time
                                    	**type**\:   :py:class:`LastUpdateWalkEndTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp>`
                                    
                                    .. attribute:: last_update_walk_start_timestamp
                                    
                                    	Last update walk start time
                                    	**type**\:   :py:class:`LastUpdateWalkStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp>`
                                    
                                    .. attribute:: merge_count
                                    
                                    	Merge count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_count
                                    
                                    	Neighbor count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_resume_version
                                    
                                    	Next resume version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_version
                                    
                                    	NSR version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: parent_sub_group_id
                                    
                                    	Parent Sub\-group identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: parent_sub_group_index
                                    
                                    	Parent Sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pending_target_version
                                    
                                    	Pending target version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_id
                                    
                                    	ProcessID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_count
                                    
                                    	Refresh sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_id
                                    
                                    	Sub\-group ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sub_group_id_xr
                                    
                                    	Sub\-group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_index
                                    
                                    	Sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sub_group_index_xr
                                    
                                    	Sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_default_route_sent
                                    
                                    	Is default route sent
                                    	**type**\:  bool
                                    
                                    .. attribute:: update_group_af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: update_group_index
                                    
                                    	Update\-group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: update_group_index_xr
                                    
                                    	Update\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_main_table_version
                                    
                                    	Main table version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages
                                    
                                    	OutQueue messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_size
                                    
                                    	OutQueue size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_refresh_target_version
                                    
                                    	Refresh target version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_statistics
                                    
                                    	Update statistics
                                    	**type**\:   :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics>`
                                    
                                    .. attribute:: update_throttled
                                    
                                    	Is update throttled
                                    	**type**\:  bool
                                    
                                    .. attribute:: update_vrf_name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    .. attribute:: update_vrf_table_rib_version
                                    
                                    	VRF Table RIB version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version
                                    
                                    	Version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.configured_update_limit_sub_group = None
                                        self.creation_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp()
                                        self.creation_timestamp.parent = self
                                        self.current_update_limit_sub_group = None
                                        self.eo_r_attempted = None
                                        self.filter_group_count = None
                                        self.first_update_walk_end_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp()
                                        self.first_update_walk_end_timestamp.parent = self
                                        self.first_update_walk_start_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp()
                                        self.first_update_walk_start_timestamp.parent = self
                                        self.io_write_event_pending = None
                                        self.last_merge_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp()
                                        self.last_merge_timestamp.parent = self
                                        self.last_merged_sub_group_index = None
                                        self.last_update_queued_age = None
                                        self.last_update_queued_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp()
                                        self.last_update_queued_timestamp.parent = self
                                        self.last_update_walk_end_age = None
                                        self.last_update_walk_end_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp()
                                        self.last_update_walk_end_timestamp.parent = self
                                        self.last_update_walk_start_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp()
                                        self.last_update_walk_start_timestamp.parent = self
                                        self.merge_count = None
                                        self.neighbor_count = None
                                        self.next_resume_version = None
                                        self.nsr_version = None
                                        self.parent_sub_group_id = None
                                        self.parent_sub_group_index = None
                                        self.pending_target_version = None
                                        self.process_id = None
                                        self.refresh_sub_group_count = None
                                        self.sub_group_id = None
                                        self.sub_group_id_xr = None
                                        self.sub_group_index = None
                                        self.sub_group_index_xr = None
                                        self.update_default_route_sent = None
                                        self.update_group_af_name = None
                                        self.update_group_index = None
                                        self.update_group_index_xr = None
                                        self.update_main_table_version = None
                                        self.update_out_queue_messages = None
                                        self.update_out_queue_size = None
                                        self.update_refresh_target_version = None
                                        self.update_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics()
                                        self.update_statistics.parent = self
                                        self.update_throttled = None
                                        self.update_vrf_name = None
                                        self.update_vrf_table_rib_version = None
                                        self.version = None


                                    class CreationTimestamp(object):
                                        """
                                        Creation time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:creation-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp']['meta_info']


                                    class LastMergeTimestamp(object):
                                        """
                                        Last merge time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-merge-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp']['meta_info']


                                    class FirstUpdateWalkStartTimestamp(object):
                                        """
                                        First update walk start time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-update-walk-start-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp']['meta_info']


                                    class FirstUpdateWalkEndTimestamp(object):
                                        """
                                        First update walk end time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-update-walk-end-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp']['meta_info']


                                    class LastUpdateWalkStartTimestamp(object):
                                        """
                                        Last update walk start time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-walk-start-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp']['meta_info']


                                    class LastUpdateWalkEndTimestamp(object):
                                        """
                                        Last update walk end time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-walk-end-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp']['meta_info']


                                    class LastUpdateQueuedTimestamp(object):
                                        """
                                        Last update queued time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-queued-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp']['meta_info']


                                    class UpdateStatistics(object):
                                        """
                                        Update statistics
                                        
                                        .. attribute:: last_update_cleard_age
                                        
                                        	Time since last Clear event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_cleared_timestamp
                                        
                                        	Last Cleared time
                                        	**type**\:   :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp>`
                                        
                                        .. attribute:: last_update_discard_age
                                        
                                        	Time since last Discard event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_discard_timestamp
                                        
                                        	Last Discarded time
                                        	**type**\:   :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                        
                                        .. attribute:: last_update_memory_allocation_fail_age
                                        
                                        	Time since last memory allocation failure event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_memory_allocation_fail_timestamp
                                        
                                        	Memory allocation failure time
                                        	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                        
                                        .. attribute:: last_update_recovery_age
                                        
                                        	Time since last Recovery event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_recovery_timestamp
                                        
                                        	Last Recovery time
                                        	**type**\:   :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                        
                                        .. attribute:: last_update_throttle_age
                                        
                                        	Time since last Throttle event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_throttle_timestamp
                                        
                                        	Last Throttled time
                                        	**type**\:   :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                        
                                        .. attribute:: update_memory_allocation_fail_count
                                        
                                        	Memory allocation failure count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cleared
                                        
                                        	OutQueue Cleared Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cumulative
                                        
                                        	OutQueue Cumulative Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_discarded
                                        
                                        	OutQueue Discarded Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_high
                                        
                                        	OutQueue High Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size_cleared
                                        
                                        	OutQueue Cleared Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_cumulative
                                        
                                        	OutQueue Cumulative Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_discarded
                                        
                                        	OutQueue Discarded Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_high
                                        
                                        	OutQueue Hi Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_recovery_count
                                        
                                        	Recovery Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_throttle_count
                                        
                                        	Throttle Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.last_update_cleard_age = None
                                            self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp()
                                            self.last_update_cleared_timestamp.parent = self
                                            self.last_update_discard_age = None
                                            self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp()
                                            self.last_update_discard_timestamp.parent = self
                                            self.last_update_memory_allocation_fail_age = None
                                            self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                            self.last_update_memory_allocation_fail_timestamp.parent = self
                                            self.last_update_recovery_age = None
                                            self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                            self.last_update_recovery_timestamp.parent = self
                                            self.last_update_throttle_age = None
                                            self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp()
                                            self.last_update_throttle_timestamp.parent = self
                                            self.update_memory_allocation_fail_count = None
                                            self.update_out_queue_messages_cleared = None
                                            self.update_out_queue_messages_cumulative = None
                                            self.update_out_queue_messages_discarded = None
                                            self.update_out_queue_messages_high = None
                                            self.update_out_queue_size_cleared = None
                                            self.update_out_queue_size_cumulative = None
                                            self.update_out_queue_size_discarded = None
                                            self.update_out_queue_size_high = None
                                            self.update_recovery_count = None
                                            self.update_throttle_count = None


                                        class LastUpdateDiscardTimestamp(object):
                                            """
                                            Last Discarded time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-discard-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp']['meta_info']


                                        class LastUpdateClearedTimestamp(object):
                                            """
                                            Last Cleared time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-cleared-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp']['meta_info']


                                        class LastUpdateThrottleTimestamp(object):
                                            """
                                            Last Throttled time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-throttle-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp']['meta_info']


                                        class LastUpdateRecoveryTimestamp(object):
                                            """
                                            Last Recovery time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-recovery-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp']['meta_info']


                                        class LastUpdateMemoryAllocationFailTimestamp(object):
                                            """
                                            Memory allocation failure time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-memory-allocation-fail-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-statistics'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.last_update_cleard_age is not None:
                                                return True

                                            if self.last_update_cleared_timestamp is not None and self.last_update_cleared_timestamp._has_data():
                                                return True

                                            if self.last_update_discard_age is not None:
                                                return True

                                            if self.last_update_discard_timestamp is not None and self.last_update_discard_timestamp._has_data():
                                                return True

                                            if self.last_update_memory_allocation_fail_age is not None:
                                                return True

                                            if self.last_update_memory_allocation_fail_timestamp is not None and self.last_update_memory_allocation_fail_timestamp._has_data():
                                                return True

                                            if self.last_update_recovery_age is not None:
                                                return True

                                            if self.last_update_recovery_timestamp is not None and self.last_update_recovery_timestamp._has_data():
                                                return True

                                            if self.last_update_throttle_age is not None:
                                                return True

                                            if self.last_update_throttle_timestamp is not None and self.last_update_throttle_timestamp._has_data():
                                                return True

                                            if self.update_memory_allocation_fail_count is not None:
                                                return True

                                            if self.update_out_queue_messages_cleared is not None:
                                                return True

                                            if self.update_out_queue_messages_cumulative is not None:
                                                return True

                                            if self.update_out_queue_messages_discarded is not None:
                                                return True

                                            if self.update_out_queue_messages_high is not None:
                                                return True

                                            if self.update_out_queue_size_cleared is not None:
                                                return True

                                            if self.update_out_queue_size_cumulative is not None:
                                                return True

                                            if self.update_out_queue_size_discarded is not None:
                                                return True

                                            if self.update_out_queue_size_high is not None:
                                                return True

                                            if self.update_recovery_count is not None:
                                                return True

                                            if self.update_throttle_count is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-sub-group'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.configured_update_limit_sub_group is not None:
                                            return True

                                        if self.creation_timestamp is not None and self.creation_timestamp._has_data():
                                            return True

                                        if self.current_update_limit_sub_group is not None:
                                            return True

                                        if self.eo_r_attempted is not None:
                                            return True

                                        if self.filter_group_count is not None:
                                            return True

                                        if self.first_update_walk_end_timestamp is not None and self.first_update_walk_end_timestamp._has_data():
                                            return True

                                        if self.first_update_walk_start_timestamp is not None and self.first_update_walk_start_timestamp._has_data():
                                            return True

                                        if self.io_write_event_pending is not None:
                                            return True

                                        if self.last_merge_timestamp is not None and self.last_merge_timestamp._has_data():
                                            return True

                                        if self.last_merged_sub_group_index is not None:
                                            return True

                                        if self.last_update_queued_age is not None:
                                            return True

                                        if self.last_update_queued_timestamp is not None and self.last_update_queued_timestamp._has_data():
                                            return True

                                        if self.last_update_walk_end_age is not None:
                                            return True

                                        if self.last_update_walk_end_timestamp is not None and self.last_update_walk_end_timestamp._has_data():
                                            return True

                                        if self.last_update_walk_start_timestamp is not None and self.last_update_walk_start_timestamp._has_data():
                                            return True

                                        if self.merge_count is not None:
                                            return True

                                        if self.neighbor_count is not None:
                                            return True

                                        if self.next_resume_version is not None:
                                            return True

                                        if self.nsr_version is not None:
                                            return True

                                        if self.parent_sub_group_id is not None:
                                            return True

                                        if self.parent_sub_group_index is not None:
                                            return True

                                        if self.pending_target_version is not None:
                                            return True

                                        if self.process_id is not None:
                                            return True

                                        if self.refresh_sub_group_count is not None:
                                            return True

                                        if self.sub_group_id is not None:
                                            return True

                                        if self.sub_group_id_xr is not None:
                                            return True

                                        if self.sub_group_index is not None:
                                            return True

                                        if self.sub_group_index_xr is not None:
                                            return True

                                        if self.update_default_route_sent is not None:
                                            return True

                                        if self.update_group_af_name is not None:
                                            return True

                                        if self.update_group_index is not None:
                                            return True

                                        if self.update_group_index_xr is not None:
                                            return True

                                        if self.update_main_table_version is not None:
                                            return True

                                        if self.update_out_queue_messages is not None:
                                            return True

                                        if self.update_out_queue_size is not None:
                                            return True

                                        if self.update_refresh_target_version is not None:
                                            return True

                                        if self.update_statistics is not None and self.update_statistics._has_data():
                                            return True

                                        if self.update_throttled is not None:
                                            return True

                                        if self.update_vrf_name is not None:
                                            return True

                                        if self.update_vrf_table_rib_version is not None:
                                            return True

                                        if self.version is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-sub-groups'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.update_generation_sub_group is not None:
                                        for child_ref in self.update_generation_sub_group:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups']['meta_info']


                            class NextHopAddressFamilies(object):
                                """
                                Address family of nexthop table
                                
                                .. attribute:: next_hop_address_family
                                
                                	Nexthop Address family
                                	**type**\: list of    :py:class:`NextHopAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.next_hop_address_family = YList()
                                    self.next_hop_address_family.parent = self
                                    self.next_hop_address_family.name = 'next_hop_address_family'


                                class NextHopAddressFamily(object):
                                    """
                                    Nexthop Address family
                                    
                                    .. attribute:: next_hop_af_name  <key>
                                    
                                    	Address family
                                    	**type**\:   :py:class:`BgpAddressFamilyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamilyEnum>`
                                    
                                    .. attribute:: next_hop_af_vrf_af
                                    
                                    	A BGP Next\-hop VRF AF table entry
                                    	**type**\:   :py:class:`NextHopAfVrfAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf>`
                                    
                                    .. attribute:: next_hop_afs
                                    
                                    	The BGP Next\-hop table
                                    	**type**\:   :py:class:`NextHopAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.next_hop_af_name = None
                                        self.next_hop_af_vrf_af = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf()
                                        self.next_hop_af_vrf_af.parent = self
                                        self.next_hop_afs = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs()
                                        self.next_hop_afs.parent = self


                                    class NextHopAfVrfAf(object):
                                        """
                                        A BGP Next\-hop VRF AF table entry
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: critical_trigger_delay
                                        
                                        	Trigger delay for critical event processing
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_downloaded_version
                                        
                                        	Version of the EPE table downloaded
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_label_version
                                        
                                        	Version of the EPE label walk
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_standby_version
                                        
                                        	Version of the EPE table processed by sync thread
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_table_version
                                        
                                        	Version of the EPE table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: gwaf_name
                                        
                                        	GW Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: nh_nexthop_version
                                        
                                        	NH version for gw\_ctx
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nh_rib_up
                                        
                                        	Whether the VRF is active
                                        	**type**\:  bool
                                        
                                        .. attribute:: nh_rib_version
                                        
                                        	RIB version for gw\_ctx
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nh_table_id
                                        
                                        	Gateway context table id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: non_critical_trigger_delay
                                        
                                        	Trigger delay for non\-critical event processing
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: performance_statistics
                                        
                                        	Performance statistics
                                        	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics>`
                                        
                                        .. attribute:: table_active
                                        
                                        	Whether the VRF is active
                                        	**type**\:  bool
                                        
                                        .. attribute:: total_nexthops
                                        
                                        	Total number of nexthops
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.critical_trigger_delay = None
                                            self.epe_downloaded_version = None
                                            self.epe_label_version = None
                                            self.epe_standby_version = None
                                            self.epe_table_version = None
                                            self.gwaf_name = None
                                            self.nh_nexthop_version = None
                                            self.nh_rib_up = None
                                            self.nh_rib_version = None
                                            self.nh_table_id = None
                                            self.non_critical_trigger_delay = None
                                            self.performance_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics()
                                            self.performance_statistics.parent = self
                                            self.table_active = None
                                            self.total_nexthops = None


                                        class PerformanceStatistics(object):
                                            """
                                            Performance statistics
                                            
                                            .. attribute:: critical_notf_count
                                            
                                            	Number of critical event notifications from RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_notf_bestpath_changes
                                            
                                            	Number of bestpath changes due to last notification
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_notf_bestpath_deletes
                                            
                                            	Number of bestpath deletes due to last notification
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nexthops_removed_from_rib
                                            
                                            	No. of nexthops withdrawn from RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nexthops_resent_to_rib
                                            
                                            	No. of nexthops re\-sent to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nexthops_sent_to_rib
                                            
                                            	No. of nexthops sent to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_batch_finish_calls
                                            
                                            	NH batch finish calls
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_flush_timer_calls
                                            
                                            	NH flush timer calls
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_last_a_sync_reg_ts
                                            
                                            	NH Last async Register TS
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_last_a_sync_un_reg_ts
                                            
                                            	NH Last async UnRegister TS
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_last_batch_finish_ts
                                            
                                            	NH Last batch finish TS
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_last_flush_timer_ts
                                            
                                            	NH Last flush timer TS
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_last_sync_reg_ts
                                            
                                            	NH Last sync Register TS
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_peak_registrations
                                            
                                            	NH Registration List Count Peak
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_pending_registrations
                                            
                                            	NH Registration List Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_sync_reg_calls
                                            
                                            	NH sync register calls
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nha_sync_reg_calls
                                            
                                            	NH async register calls
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nha_sync_un_reg_calls
                                            
                                            	NH async unregister calls
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nhrib_update_calls
                                            
                                            	No. of calls to RIB update function
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nhrib_update_time
                                            
                                            	Time spent sending RIB updates (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: noncritical_notf_count
                                            
                                            	Number of non\-critical event notifications from RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_sync_registers_failed
                                            
                                            	No. of sync registers with RIB that failed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: riba_sync_registers_failed
                                            
                                            	No. of async registers with RIB that failed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribnh_reg_failed_for_no_rib_conn
                                            
                                            	No. of nh registers failed because of no rib conn
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribnh_reg_failed_for_no_tbl_id
                                            
                                            	No. of nh registers failed because of no tbl\-id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_walk_backup_creates
                                            
                                            	No. of times backup tid created during tunnel walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_walk_gw_not_found
                                            
                                            	No. of times gw was not found during tunnel walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_walk_nh_not_found
                                            
                                            	No. of times nexthop was not found during tunnel walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.critical_notf_count = None
                                                self.last_notf_bestpath_changes = None
                                                self.last_notf_bestpath_deletes = None
                                                self.nexthops_removed_from_rib = None
                                                self.nexthops_resent_to_rib = None
                                                self.nexthops_sent_to_rib = None
                                                self.nh_batch_finish_calls = None
                                                self.nh_flush_timer_calls = None
                                                self.nh_last_a_sync_reg_ts = None
                                                self.nh_last_a_sync_un_reg_ts = None
                                                self.nh_last_batch_finish_ts = None
                                                self.nh_last_flush_timer_ts = None
                                                self.nh_last_sync_reg_ts = None
                                                self.nh_peak_registrations = None
                                                self.nh_pending_registrations = None
                                                self.nh_sync_reg_calls = None
                                                self.nha_sync_reg_calls = None
                                                self.nha_sync_un_reg_calls = None
                                                self.nhrib_update_calls = None
                                                self.nhrib_update_time = None
                                                self.noncritical_notf_count = None
                                                self.rib_sync_registers_failed = None
                                                self.riba_sync_registers_failed = None
                                                self.ribnh_reg_failed_for_no_rib_conn = None
                                                self.ribnh_reg_failed_for_no_tbl_id = None
                                                self.tunnel_walk_backup_creates = None
                                                self.tunnel_walk_gw_not_found = None
                                                self.tunnel_walk_nh_not_found = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:performance-statistics'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.critical_notf_count is not None:
                                                    return True

                                                if self.last_notf_bestpath_changes is not None:
                                                    return True

                                                if self.last_notf_bestpath_deletes is not None:
                                                    return True

                                                if self.nexthops_removed_from_rib is not None:
                                                    return True

                                                if self.nexthops_resent_to_rib is not None:
                                                    return True

                                                if self.nexthops_sent_to_rib is not None:
                                                    return True

                                                if self.nh_batch_finish_calls is not None:
                                                    return True

                                                if self.nh_flush_timer_calls is not None:
                                                    return True

                                                if self.nh_last_a_sync_reg_ts is not None:
                                                    return True

                                                if self.nh_last_a_sync_un_reg_ts is not None:
                                                    return True

                                                if self.nh_last_batch_finish_ts is not None:
                                                    return True

                                                if self.nh_last_flush_timer_ts is not None:
                                                    return True

                                                if self.nh_last_sync_reg_ts is not None:
                                                    return True

                                                if self.nh_peak_registrations is not None:
                                                    return True

                                                if self.nh_pending_registrations is not None:
                                                    return True

                                                if self.nh_sync_reg_calls is not None:
                                                    return True

                                                if self.nha_sync_reg_calls is not None:
                                                    return True

                                                if self.nha_sync_un_reg_calls is not None:
                                                    return True

                                                if self.nhrib_update_calls is not None:
                                                    return True

                                                if self.nhrib_update_time is not None:
                                                    return True

                                                if self.noncritical_notf_count is not None:
                                                    return True

                                                if self.rib_sync_registers_failed is not None:
                                                    return True

                                                if self.riba_sync_registers_failed is not None:
                                                    return True

                                                if self.ribnh_reg_failed_for_no_rib_conn is not None:
                                                    return True

                                                if self.ribnh_reg_failed_for_no_tbl_id is not None:
                                                    return True

                                                if self.tunnel_walk_backup_creates is not None:
                                                    return True

                                                if self.tunnel_walk_gw_not_found is not None:
                                                    return True

                                                if self.tunnel_walk_nh_not_found is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop-af-vrf-af'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.critical_trigger_delay is not None:
                                                return True

                                            if self.epe_downloaded_version is not None:
                                                return True

                                            if self.epe_label_version is not None:
                                                return True

                                            if self.epe_standby_version is not None:
                                                return True

                                            if self.epe_table_version is not None:
                                                return True

                                            if self.gwaf_name is not None:
                                                return True

                                            if self.nh_nexthop_version is not None:
                                                return True

                                            if self.nh_rib_up is not None:
                                                return True

                                            if self.nh_rib_version is not None:
                                                return True

                                            if self.nh_table_id is not None:
                                                return True

                                            if self.non_critical_trigger_delay is not None:
                                                return True

                                            if self.performance_statistics is not None and self.performance_statistics._has_data():
                                                return True

                                            if self.table_active is not None:
                                                return True

                                            if self.total_nexthops is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf']['meta_info']


                                    class NextHopAfs(object):
                                        """
                                        The BGP Next\-hop table
                                        
                                        .. attribute:: next_hop_af
                                        
                                        	A BGP Next hop entry
                                        	**type**\: list of    :py:class:`NextHopAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.next_hop_af = YList()
                                            self.next_hop_af.parent = self
                                            self.next_hop_af.name = 'next_hop_af'


                                        class NextHopAf(object):
                                            """
                                            A BGP Next hop entry
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: attribute_set
                                            
                                            	Attribute Set Name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address List
                                            	**type**\: list of    :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress>`
                                            
                                            .. attribute:: next_hop_address
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: nexthop_address
                                            
                                            	Nexthop address
                                            	**type**\:   :py:class:`NexthopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress>`
                                            
                                            .. attribute:: nexthop_aigp_metric
                                            
                                            	AIGP metrice of nexthop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nexthop_gateway_info
                                            
                                            	Gateway related info, includingOptimal Route Reflector Gateways
                                            	**type**\: list of    :py:class:`NexthopGatewayInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo>`
                                            
                                            .. attribute:: nexthop_gateway_prefix_connected
                                            
                                            	Is Gateway resolved through Connected route ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: nexthop_gateway_prefix_length
                                            
                                            	Gateway prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nexthop_gateway_reachable
                                            
                                            	Is Gateway reachable ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: nexthop_internal_info
                                            
                                            	Internal nexthop info
                                            	**type**\:   :py:class:`NexthopInternalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo>`
                                            
                                            .. attribute:: nexthop_pending_registration
                                            
                                            	Nexthop registration is pending
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nexthop_reference_count
                                            
                                            	Number of neighbors/prefixes referencing this nexthop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_first_hop_if_handle
                                            
                                            	First\-hop interface handle
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: nh_reference_count_total
                                            
                                            	Number of neighbors/prefixes referencing this nexthop (AFs)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhteTunnel>`
                                            
                                            .. attribute:: rib_nexthop_id
                                            
                                            	RIB Nexthop Id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.af_name = None
                                                self.attribute_set = None
                                                self.neighbor_address = YList()
                                                self.neighbor_address.parent = self
                                                self.neighbor_address.name = 'neighbor_address'
                                                self.next_hop_address = None
                                                self.nexthop_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress()
                                                self.nexthop_address.parent = self
                                                self.nexthop_aigp_metric = None
                                                self.nexthop_gateway_info = YList()
                                                self.nexthop_gateway_info.parent = self
                                                self.nexthop_gateway_info.name = 'nexthop_gateway_info'
                                                self.nexthop_gateway_prefix_connected = None
                                                self.nexthop_gateway_prefix_length = None
                                                self.nexthop_gateway_reachable = None
                                                self.nexthop_internal_info = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo()
                                                self.nexthop_internal_info.parent = self
                                                self.nexthop_pending_registration = None
                                                self.nexthop_reference_count = None
                                                self.nh_first_hop_if_handle = None
                                                self.nh_reference_count_total = None
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.rib_nexthop_id = None


                                            class NexthopAddress(object):
                                                """
                                                Nexthop address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhteTunnel']['meta_info']


                                            class NexthopInternalInfo(object):
                                                """
                                                Internal nexthop info
                                                
                                                .. attribute:: gateway_flags
                                                
                                                	Gateway flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_address
                                                
                                                	Nexthop address
                                                	**type**\:   :py:class:`NexthopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress>`
                                                
                                                .. attribute:: nexthop_af_user_bits
                                                
                                                	Bitmask indicating the AFs which share the nexthop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_flags
                                                
                                                	Nexthop flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_gateway_internal_info
                                                
                                                	Internal nexthop Gateway info
                                                	**type**\: list of    :py:class:`NexthopGatewayInternalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo>`
                                                
                                                .. attribute:: nexthop_id
                                                
                                                	Comm librray ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_if_handle
                                                
                                                	Nexthop ifhandle
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_label
                                                
                                                	Nexthop label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_metrice
                                                
                                                	Nexthop metrices
                                                	**type**\: list of    :py:class:`NexthopMetrice <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice>`
                                                
                                                .. attribute:: nexthop_refcount
                                                
                                                	Nexthop refcounts
                                                	**type**\: list of    :py:class:`NexthopRefcount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount>`
                                                
                                                .. attribute:: nexthop_version
                                                
                                                	Table version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.gateway_flags = None
                                                    self.nexthop_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress()
                                                    self.nexthop_address.parent = self
                                                    self.nexthop_af_user_bits = None
                                                    self.nexthop_flags = None
                                                    self.nexthop_gateway_internal_info = YList()
                                                    self.nexthop_gateway_internal_info.parent = self
                                                    self.nexthop_gateway_internal_info.name = 'nexthop_gateway_internal_info'
                                                    self.nexthop_id = None
                                                    self.nexthop_if_handle = None
                                                    self.nexthop_label = None
                                                    self.nexthop_metrice = YList()
                                                    self.nexthop_metrice.parent = self
                                                    self.nexthop_metrice.name = 'nexthop_metrice'
                                                    self.nexthop_refcount = YList()
                                                    self.nexthop_refcount.parent = self
                                                    self.nexthop_refcount.name = 'nexthop_refcount'
                                                    self.nexthop_version = None


                                                class NexthopAddress(object):
                                                    """
                                                    Nexthop address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress']['meta_info']


                                                class NexthopMetrice(object):
                                                    """
                                                    Nexthop metrices
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-metrice'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice']['meta_info']


                                                class NexthopRefcount(object):
                                                    """
                                                    Nexthop refcounts
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-refcount'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount']['meta_info']


                                                class NexthopGatewayInternalInfo(object):
                                                    """
                                                    Internal nexthop Gateway info
                                                    
                                                    .. attribute:: gateway_flags
                                                    
                                                    	Gateway flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: registration_since
                                                    
                                                    	Time since registration
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: registration_type
                                                    
                                                    	Nexthop registration type
                                                    	**type**\:   :py:class:`BgpNhValidateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpNhValidateEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.gateway_flags = None
                                                        self.registration_since = None
                                                        self.registration_type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-gateway-internal-info'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.gateway_flags is not None:
                                                            return True

                                                        if self.registration_since is not None:
                                                            return True

                                                        if self.registration_type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-internal-info'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.gateway_flags is not None:
                                                        return True

                                                    if self.nexthop_address is not None and self.nexthop_address._has_data():
                                                        return True

                                                    if self.nexthop_af_user_bits is not None:
                                                        return True

                                                    if self.nexthop_flags is not None:
                                                        return True

                                                    if self.nexthop_gateway_internal_info is not None:
                                                        for child_ref in self.nexthop_gateway_internal_info:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.nexthop_id is not None:
                                                        return True

                                                    if self.nexthop_if_handle is not None:
                                                        return True

                                                    if self.nexthop_label is not None:
                                                        return True

                                                    if self.nexthop_metrice is not None:
                                                        for child_ref in self.nexthop_metrice:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.nexthop_refcount is not None:
                                                        for child_ref in self.nexthop_refcount:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.nexthop_version is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo']['meta_info']


                                            class NexthopGatewayInfo(object):
                                                """
                                                Gateway related info, includingOptimal Route
                                                Reflector Gateways
                                                
                                                .. attribute:: critical_events
                                                
                                                	Number of critical events received from RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_event_since
                                                
                                                	Time since the last event sent to or received from RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_event_type
                                                
                                                	Last nexthop event type
                                                	**type**\:   :py:class:`BgpNhEventEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpNhEventEnum>`
                                                
                                                .. attribute:: last_rib_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_update_type
                                                
                                                	Last nexthop update type
                                                	**type**\:   :py:class:`BgpNhUpdateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpNhUpdateEnum>`
                                                
                                                .. attribute:: nexthop_af_invalid_bits
                                                
                                                	Bitmask indicating the AFs which have been invalidated for the nexthop
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: nexthop_metric
                                                
                                                	IGP metric for nexthop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_mpls_enabled
                                                
                                                	TRUE if MPLS is configured for IAS/CsC application
                                                	**type**\:  bool
                                                
                                                .. attribute:: nexthop_mpls_interfaces
                                                
                                                	Number of interfaces on which MPLS is enabled
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_mpls_label
                                                
                                                	Local label allocated for IAS/CsC application
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_route
                                                
                                                	Route resolving the nethop
                                                	**type**\:   :py:class:`NexthopRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute>`
                                                
                                                .. attribute:: nexthop_route_path
                                                
                                                	Nexthops of the resolving route
                                                	**type**\: list of    :py:class:`NexthopRoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath>`
                                                
                                                .. attribute:: nexthop_route_path_count
                                                
                                                	Number of paths in the resolving route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_route_prefix_length
                                                
                                                	Prefix length of the route resolving the nexthop
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nexthop_route_protocol
                                                
                                                	Protocol that resolves the route to the nexthop
                                                	**type**\:  str
                                                
                                                .. attribute:: nexthop_status
                                                
                                                	Nexthop status
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nexthop_tableid
                                                
                                                	Nexthop Table id
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: non_critical_events
                                                
                                                	Number of non\-critical events received from RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.critical_events = None
                                                    self.last_event_since = None
                                                    self.last_event_type = None
                                                    self.last_rib_update = None
                                                    self.last_update_type = None
                                                    self.nexthop_af_invalid_bits = None
                                                    self.nexthop_metric = None
                                                    self.nexthop_mpls_enabled = None
                                                    self.nexthop_mpls_interfaces = None
                                                    self.nexthop_mpls_label = None
                                                    self.nexthop_route = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute()
                                                    self.nexthop_route.parent = self
                                                    self.nexthop_route_path = YList()
                                                    self.nexthop_route_path.parent = self
                                                    self.nexthop_route_path.name = 'nexthop_route_path'
                                                    self.nexthop_route_path_count = None
                                                    self.nexthop_route_prefix_length = None
                                                    self.nexthop_route_protocol = None
                                                    self.nexthop_status = None
                                                    self.nexthop_tableid = None
                                                    self.non_critical_events = None


                                                class NexthopRoute(object):
                                                    """
                                                    Route resolving the nethop
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-route'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute']['meta_info']


                                                class NexthopRoutePath(object):
                                                    """
                                                    Nexthops of the resolving route
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-route-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-gateway-info'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.critical_events is not None:
                                                        return True

                                                    if self.last_event_since is not None:
                                                        return True

                                                    if self.last_event_type is not None:
                                                        return True

                                                    if self.last_rib_update is not None:
                                                        return True

                                                    if self.last_update_type is not None:
                                                        return True

                                                    if self.nexthop_af_invalid_bits is not None:
                                                        return True

                                                    if self.nexthop_metric is not None:
                                                        return True

                                                    if self.nexthop_mpls_enabled is not None:
                                                        return True

                                                    if self.nexthop_mpls_interfaces is not None:
                                                        return True

                                                    if self.nexthop_mpls_label is not None:
                                                        return True

                                                    if self.nexthop_route is not None and self.nexthop_route._has_data():
                                                        return True

                                                    if self.nexthop_route_path is not None:
                                                        for child_ref in self.nexthop_route_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.nexthop_route_path_count is not None:
                                                        return True

                                                    if self.nexthop_route_prefix_length is not None:
                                                        return True

                                                    if self.nexthop_route_protocol is not None:
                                                        return True

                                                    if self.nexthop_status is not None:
                                                        return True

                                                    if self.nexthop_tableid is not None:
                                                        return True

                                                    if self.non_critical_events is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo']['meta_info']


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address List
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop-af'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.af_name is not None:
                                                    return True

                                                if self.attribute_set is not None:
                                                    return True

                                                if self.neighbor_address is not None:
                                                    for child_ref in self.neighbor_address:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.next_hop_address is not None:
                                                    return True

                                                if self.nexthop_address is not None and self.nexthop_address._has_data():
                                                    return True

                                                if self.nexthop_aigp_metric is not None:
                                                    return True

                                                if self.nexthop_gateway_info is not None:
                                                    for child_ref in self.nexthop_gateway_info:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.nexthop_gateway_prefix_connected is not None:
                                                    return True

                                                if self.nexthop_gateway_prefix_length is not None:
                                                    return True

                                                if self.nexthop_gateway_reachable is not None:
                                                    return True

                                                if self.nexthop_internal_info is not None and self.nexthop_internal_info._has_data():
                                                    return True

                                                if self.nexthop_pending_registration is not None:
                                                    return True

                                                if self.nexthop_reference_count is not None:
                                                    return True

                                                if self.nh_first_hop_if_handle is not None:
                                                    return True

                                                if self.nh_reference_count_total is not None:
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.rib_nexthop_id is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop-afs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.next_hop_af is not None:
                                                for child_ref in self.next_hop_af:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.next_hop_af_name is None:
                                            raise YPYModelError('Key property next_hop_af_name is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop-address-family[Cisco-IOS-XR-ipv4-bgp-oper:next-hop-af-name = ' + str(self.next_hop_af_name) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.next_hop_af_name is not None:
                                            return True

                                        if self.next_hop_af_vrf_af is not None and self.next_hop_af_vrf_af._has_data():
                                            return True

                                        if self.next_hop_afs is not None and self.next_hop_afs._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop-address-families'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.next_hop_address_family is not None:
                                        for child_ref in self.next_hop_address_family:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies']['meta_info']


                            class RtSetCounters(object):
                                """
                                The RT\-set counter table
                                
                                .. attribute:: rt_set_counter
                                
                                	One RT\-set counter table entry
                                	**type**\: list of    :py:class:`RtSetCounter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.rt_set_counter = YList()
                                    self.rt_set_counter.parent = self
                                    self.rt_set_counter.name = 'rt_set_counter'


                                class RtSetCounter(object):
                                    """
                                    One RT\-set counter table entry
                                    
                                    .. attribute:: rt_set_id  <key>
                                    
                                    	RTSet ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: route_target_set
                                    
                                    	Route Target set
                                    	**type**\:   :py:class:`RouteTargetSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.rt_set_id = None
                                        self.route_target_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet()
                                        self.route_target_set.parent = self


                                    class RouteTargetSet(object):
                                        """
                                        Route Target set
                                        
                                        .. attribute:: rt_set
                                        
                                        	Set of route targets
                                        	**type**\: list of    :py:class:`RtSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet>`
                                        
                                        .. attribute:: rt_set_id
                                        
                                        	Identifier of the rtset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rt_set_len
                                        
                                        	Length in bytes of set of route targets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rt_set_net_count
                                        
                                        	Count of nets with paths with the rtset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.rt_set = YList()
                                            self.rt_set.parent = self
                                            self.rt_set.name = 'rt_set'
                                            self.rt_set_id = None
                                            self.rt_set_len = None
                                            self.rt_set_net_count = None


                                        class RtSet(object):
                                            """
                                            Set of route targets
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rt-set'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:route-target-set'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.rt_set is not None:
                                                for child_ref in self.rt_set:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.rt_set_id is not None:
                                                return True

                                            if self.rt_set_len is not None:
                                                return True

                                            if self.rt_set_net_count is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.rt_set_id is None:
                                            raise YPYModelError('Key property rt_set_id is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rt-set-counter[Cisco-IOS-XR-ipv4-bgp-oper:rt-set-id = ' + str(self.rt_set_id) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.rt_set_id is not None:
                                            return True

                                        if self.route_target_set is not None and self.route_target_set._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rt-set-counters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.rt_set_counter is not None:
                                        for child_ref in self.rt_set_counter:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters']['meta_info']


                            class BmpPaths(object):
                                """
                                The paths in BMP Table
                                
                                .. attribute:: bmp_path
                                
                                	A BMP path table entry
                                	**type**\: list of    :py:class:`BmpPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.bmp_path = YList()
                                    self.bmp_path.parent = self
                                    self.bmp_path.name = 'bmp_path'


                                class BmpPath(object):
                                    """
                                    A BMP path table entry
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: bgp_prefix
                                    
                                    	BGP prefix
                                    	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix>`
                                    
                                    .. attribute:: bmp_net_flags
                                    
                                    	Flags associated with net
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_net_version
                                    
                                    	Net's version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_path
                                    
                                    	List of paths under the BMP net
                                    	**type**\: list of    :py:class:`BmpPath_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_>`
                                    
                                    .. attribute:: has_local_label
                                    
                                    	Net has local label
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_local_label
                                    
                                    	Local label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: network
                                    
                                    	Network Prefix in Hex format
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: num_of_path
                                    
                                    	Number of path for the net
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: version_age
                                    
                                    	Net Version bump age
                                    	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionAge>`
                                    
                                    .. attribute:: version_timestamp
                                    
                                    	Net Version bump timestamp
                                    	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix()
                                        self.bgp_prefix.parent = self
                                        self.bmp_net_flags = None
                                        self.bmp_net_version = None
                                        self.bmp_path = YList()
                                        self.bmp_path.parent = self
                                        self.bmp_path.name = 'bmp_path'
                                        self.has_local_label = None
                                        self.net_local_label = None
                                        self.network = None
                                        self.num_of_path = None
                                        self.prefix_length = None
                                        self.version_age = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionAge()
                                        self.version_age.parent = self
                                        self.version_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp()
                                        self.version_timestamp.parent = self


                                    class BgpPrefix(object):
                                        """
                                        BGP prefix
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix()
                                            self.prefix.parent = self
                                            self.prefix_length = None


                                        class Prefix(object):
                                            """
                                            Prefix
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.prefix is not None and self.prefix._has_data():
                                                return True

                                            if self.prefix_length is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix']['meta_info']


                                    class VersionTimestamp(object):
                                        """
                                        Net Version bump timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp']['meta_info']


                                    class VersionAge(object):
                                        """
                                        Net Version bump age
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-age'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionAge']['meta_info']


                                    class BmpPath_(object):
                                        """
                                        List of paths under the BMP net
                                        
                                        .. attribute:: bmp_nbr_bit_map
                                        
                                        	Paths Nbr bmp bit map
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_path_adv_bit_map
                                        
                                        	Path's Adv bit map
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: bmp_path_flags
                                        
                                        	Flags associated with path
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_path_snd_bit_map
                                        
                                        	Path's pending snd bit map
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: bpath_pointer
                                        
                                        	BGP Path pointer
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: local_path
                                        
                                        	Is path originated locally?
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress>`
                                        
                                        .. attribute:: received_label
                                        
                                        	Label received from peer
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bmp_nbr_bit_map = None
                                            self.bmp_path_adv_bit_map = None
                                            self.bmp_path_flags = None
                                            self.bmp_path_snd_bit_map = None
                                            self.bpath_pointer = None
                                            self.local_path = None
                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self.received_label = None


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-path'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bmp_nbr_bit_map is not None:
                                                return True

                                            if self.bmp_path_adv_bit_map is not None:
                                                return True

                                            if self.bmp_path_flags is not None:
                                                return True

                                            if self.bmp_path_snd_bit_map is not None:
                                                return True

                                            if self.bpath_pointer is not None:
                                                return True

                                            if self.local_path is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            if self.received_label is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                            return True

                                        if self.bmp_net_flags is not None:
                                            return True

                                        if self.bmp_net_version is not None:
                                            return True

                                        if self.bmp_path is not None:
                                            for child_ref in self.bmp_path:
                                                if child_ref._has_data():
                                                    return True

                                        if self.has_local_label is not None:
                                            return True

                                        if self.net_local_label is not None:
                                            return True

                                        if self.network is not None:
                                            return True

                                        if self.num_of_path is not None:
                                            return True

                                        if self.prefix_length is not None:
                                            return True

                                        if self.version_age is not None and self.version_age._has_data():
                                            return True

                                        if self.version_timestamp is not None and self.version_timestamp._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-paths'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bmp_path is not None:
                                        for child_ref in self.bmp_path:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths']['meta_info']


                            class UpdateGenerationUpdateGroups(object):
                                """
                                Update generation for all update\-groups
                                
                                .. attribute:: update_generation_update_group
                                
                                	Update generation for update\-group
                                	**type**\: list of    :py:class:`UpdateGenerationUpdateGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.update_generation_update_group = YList()
                                    self.update_generation_update_group.parent = self
                                    self.update_generation_update_group.name = 'update_generation_update_group'


                                class UpdateGenerationUpdateGroup(object):
                                    """
                                    Update generation for update\-group
                                    
                                    .. attribute:: update_group_index  <key>
                                    
                                    	Update\-group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: filter_group_count
                                    
                                    	Filter\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_permanent
                                    
                                    	Permanent UG check
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_update_timer_running
                                    
                                    	Is update timer running
                                    	**type**\:  bool
                                    
                                    .. attribute:: last_update_timer_delay_value
                                    
                                    	Last update timer delay value
                                    	**type**\:   :py:class:`LastUpdateTimerDelayValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue>`
                                    
                                    .. attribute:: last_update_timer_expiry_age
                                    
                                    	Time since last update timer expiry event
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_update_timer_expiry_timestamp
                                    
                                    	Last update timer expiry time
                                    	**type**\:   :py:class:`LastUpdateTimerExpiryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp>`
                                    
                                    .. attribute:: last_update_timer_remaining_value
                                    
                                    	Update timer remaining time
                                    	**type**\:   :py:class:`LastUpdateTimerRemainingValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue>`
                                    
                                    .. attribute:: last_update_timer_start_timestamp
                                    
                                    	Last update timer start time
                                    	**type**\:   :py:class:`LastUpdateTimerStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp>`
                                    
                                    .. attribute:: last_update_timer_stop_timestamp
                                    
                                    	Last update timer stop time
                                    	**type**\:   :py:class:`LastUpdateTimerStopTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp>`
                                    
                                    .. attribute:: neighbor_count
                                    
                                    	Neighbor count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_leaving_count
                                    
                                    	Count of neighbors leaving the update\-group
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_session_af_name
                                    
                                    	Neighbor session address family
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: perm_pelem_allowed
                                    
                                    	Count of Perm Pelems allowed by updgen
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: perm_pelem_encountered
                                    
                                    	Count of Perm Pelems seen by updgen
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: perm_pelem_exp_wdr
                                    
                                    	Count of Perm Pelems explicitly wdrn by updgen
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: perm_pelem_not_allowed
                                    
                                    	Count of Perm Pelems not allowed by updgen
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: perm_pelem_spur_wdr
                                    
                                    	Count of Perm Pelems Spurious withdraws by updgen
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_id
                                    
                                    	ProcessID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_count
                                    
                                    	Refresh sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_throttled_count
                                    
                                    	Throttled refresh sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_throttled_count
                                    
                                    	Throttled sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_generation_recovery_pending
                                    
                                    	Is update generation recovery pending
                                    	**type**\:  bool
                                    
                                    .. attribute:: update_group_af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: update_group_flags2
                                    
                                    	Update\-group internal flags2
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_group_index_xr
                                    
                                    	Update\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages
                                    
                                    	OutQueue Messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_size
                                    
                                    	OutQueue Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_statistics
                                    
                                    	Update statistics
                                    	**type**\:   :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics>`
                                    
                                    .. attribute:: update_sub_group_count
                                    
                                    	Sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_vrf_name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.update_group_index = None
                                        self.filter_group_count = None
                                        self.is_permanent = None
                                        self.is_update_timer_running = None
                                        self.last_update_timer_delay_value = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue()
                                        self.last_update_timer_delay_value.parent = self
                                        self.last_update_timer_expiry_age = None
                                        self.last_update_timer_expiry_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp()
                                        self.last_update_timer_expiry_timestamp.parent = self
                                        self.last_update_timer_remaining_value = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue()
                                        self.last_update_timer_remaining_value.parent = self
                                        self.last_update_timer_start_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp()
                                        self.last_update_timer_start_timestamp.parent = self
                                        self.last_update_timer_stop_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp()
                                        self.last_update_timer_stop_timestamp.parent = self
                                        self.neighbor_count = None
                                        self.neighbor_leaving_count = None
                                        self.neighbor_session_af_name = None
                                        self.perm_pelem_allowed = None
                                        self.perm_pelem_encountered = None
                                        self.perm_pelem_exp_wdr = None
                                        self.perm_pelem_not_allowed = None
                                        self.perm_pelem_spur_wdr = None
                                        self.process_id = None
                                        self.refresh_sub_group_count = None
                                        self.refresh_sub_group_throttled_count = None
                                        self.sub_group_throttled_count = None
                                        self.update_generation_recovery_pending = None
                                        self.update_group_af_name = None
                                        self.update_group_flags2 = None
                                        self.update_group_index_xr = None
                                        self.update_out_queue_messages = None
                                        self.update_out_queue_size = None
                                        self.update_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics()
                                        self.update_statistics.parent = self
                                        self.update_sub_group_count = None
                                        self.update_vrf_name = None


                                    class LastUpdateTimerStartTimestamp(object):
                                        """
                                        Last update timer start time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-timer-start-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp']['meta_info']


                                    class LastUpdateTimerStopTimestamp(object):
                                        """
                                        Last update timer stop time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-timer-stop-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp']['meta_info']


                                    class LastUpdateTimerExpiryTimestamp(object):
                                        """
                                        Last update timer expiry time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-timer-expiry-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp']['meta_info']


                                    class LastUpdateTimerRemainingValue(object):
                                        """
                                        Update timer remaining time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-timer-remaining-value'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue']['meta_info']


                                    class LastUpdateTimerDelayValue(object):
                                        """
                                        Last update timer delay value
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-timer-delay-value'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue']['meta_info']


                                    class UpdateStatistics(object):
                                        """
                                        Update statistics
                                        
                                        .. attribute:: last_update_cleard_age
                                        
                                        	Time since last Clear event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_cleared_timestamp
                                        
                                        	Last Cleared time
                                        	**type**\:   :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp>`
                                        
                                        .. attribute:: last_update_discard_age
                                        
                                        	Time since last Discard event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_discard_timestamp
                                        
                                        	Last Discarded time
                                        	**type**\:   :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                        
                                        .. attribute:: last_update_memory_allocation_fail_age
                                        
                                        	Time since last memory allocation failure event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_memory_allocation_fail_timestamp
                                        
                                        	Memory allocation failure time
                                        	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                        
                                        .. attribute:: last_update_recovery_age
                                        
                                        	Time since last Recovery event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_recovery_timestamp
                                        
                                        	Last Recovery time
                                        	**type**\:   :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                        
                                        .. attribute:: last_update_throttle_age
                                        
                                        	Time since last Throttle event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_throttle_timestamp
                                        
                                        	Last Throttled time
                                        	**type**\:   :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                        
                                        .. attribute:: update_memory_allocation_fail_count
                                        
                                        	Memory allocation failure count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cleared
                                        
                                        	OutQueue Cleared Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cumulative
                                        
                                        	OutQueue Cumulative Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_discarded
                                        
                                        	OutQueue Discarded Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_high
                                        
                                        	OutQueue High Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size_cleared
                                        
                                        	OutQueue Cleared Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_cumulative
                                        
                                        	OutQueue Cumulative Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_discarded
                                        
                                        	OutQueue Discarded Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_high
                                        
                                        	OutQueue Hi Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_recovery_count
                                        
                                        	Recovery Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_throttle_count
                                        
                                        	Throttle Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.last_update_cleard_age = None
                                            self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp()
                                            self.last_update_cleared_timestamp.parent = self
                                            self.last_update_discard_age = None
                                            self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp()
                                            self.last_update_discard_timestamp.parent = self
                                            self.last_update_memory_allocation_fail_age = None
                                            self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                            self.last_update_memory_allocation_fail_timestamp.parent = self
                                            self.last_update_recovery_age = None
                                            self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                            self.last_update_recovery_timestamp.parent = self
                                            self.last_update_throttle_age = None
                                            self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp()
                                            self.last_update_throttle_timestamp.parent = self
                                            self.update_memory_allocation_fail_count = None
                                            self.update_out_queue_messages_cleared = None
                                            self.update_out_queue_messages_cumulative = None
                                            self.update_out_queue_messages_discarded = None
                                            self.update_out_queue_messages_high = None
                                            self.update_out_queue_size_cleared = None
                                            self.update_out_queue_size_cumulative = None
                                            self.update_out_queue_size_discarded = None
                                            self.update_out_queue_size_high = None
                                            self.update_recovery_count = None
                                            self.update_throttle_count = None


                                        class LastUpdateDiscardTimestamp(object):
                                            """
                                            Last Discarded time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-discard-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp']['meta_info']


                                        class LastUpdateClearedTimestamp(object):
                                            """
                                            Last Cleared time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-cleared-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp']['meta_info']


                                        class LastUpdateThrottleTimestamp(object):
                                            """
                                            Last Throttled time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-throttle-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp']['meta_info']


                                        class LastUpdateRecoveryTimestamp(object):
                                            """
                                            Last Recovery time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-recovery-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp']['meta_info']


                                        class LastUpdateMemoryAllocationFailTimestamp(object):
                                            """
                                            Memory allocation failure time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-memory-allocation-fail-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-statistics'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.last_update_cleard_age is not None:
                                                return True

                                            if self.last_update_cleared_timestamp is not None and self.last_update_cleared_timestamp._has_data():
                                                return True

                                            if self.last_update_discard_age is not None:
                                                return True

                                            if self.last_update_discard_timestamp is not None and self.last_update_discard_timestamp._has_data():
                                                return True

                                            if self.last_update_memory_allocation_fail_age is not None:
                                                return True

                                            if self.last_update_memory_allocation_fail_timestamp is not None and self.last_update_memory_allocation_fail_timestamp._has_data():
                                                return True

                                            if self.last_update_recovery_age is not None:
                                                return True

                                            if self.last_update_recovery_timestamp is not None and self.last_update_recovery_timestamp._has_data():
                                                return True

                                            if self.last_update_throttle_age is not None:
                                                return True

                                            if self.last_update_throttle_timestamp is not None and self.last_update_throttle_timestamp._has_data():
                                                return True

                                            if self.update_memory_allocation_fail_count is not None:
                                                return True

                                            if self.update_out_queue_messages_cleared is not None:
                                                return True

                                            if self.update_out_queue_messages_cumulative is not None:
                                                return True

                                            if self.update_out_queue_messages_discarded is not None:
                                                return True

                                            if self.update_out_queue_messages_high is not None:
                                                return True

                                            if self.update_out_queue_size_cleared is not None:
                                                return True

                                            if self.update_out_queue_size_cumulative is not None:
                                                return True

                                            if self.update_out_queue_size_discarded is not None:
                                                return True

                                            if self.update_out_queue_size_high is not None:
                                                return True

                                            if self.update_recovery_count is not None:
                                                return True

                                            if self.update_throttle_count is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.update_group_index is None:
                                            raise YPYModelError('Key property update_group_index is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-update-group[Cisco-IOS-XR-ipv4-bgp-oper:update-group-index = ' + str(self.update_group_index) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.update_group_index is not None:
                                            return True

                                        if self.filter_group_count is not None:
                                            return True

                                        if self.is_permanent is not None:
                                            return True

                                        if self.is_update_timer_running is not None:
                                            return True

                                        if self.last_update_timer_delay_value is not None and self.last_update_timer_delay_value._has_data():
                                            return True

                                        if self.last_update_timer_expiry_age is not None:
                                            return True

                                        if self.last_update_timer_expiry_timestamp is not None and self.last_update_timer_expiry_timestamp._has_data():
                                            return True

                                        if self.last_update_timer_remaining_value is not None and self.last_update_timer_remaining_value._has_data():
                                            return True

                                        if self.last_update_timer_start_timestamp is not None and self.last_update_timer_start_timestamp._has_data():
                                            return True

                                        if self.last_update_timer_stop_timestamp is not None and self.last_update_timer_stop_timestamp._has_data():
                                            return True

                                        if self.neighbor_count is not None:
                                            return True

                                        if self.neighbor_leaving_count is not None:
                                            return True

                                        if self.neighbor_session_af_name is not None:
                                            return True

                                        if self.perm_pelem_allowed is not None:
                                            return True

                                        if self.perm_pelem_encountered is not None:
                                            return True

                                        if self.perm_pelem_exp_wdr is not None:
                                            return True

                                        if self.perm_pelem_not_allowed is not None:
                                            return True

                                        if self.perm_pelem_spur_wdr is not None:
                                            return True

                                        if self.process_id is not None:
                                            return True

                                        if self.refresh_sub_group_count is not None:
                                            return True

                                        if self.refresh_sub_group_throttled_count is not None:
                                            return True

                                        if self.sub_group_throttled_count is not None:
                                            return True

                                        if self.update_generation_recovery_pending is not None:
                                            return True

                                        if self.update_group_af_name is not None:
                                            return True

                                        if self.update_group_flags2 is not None:
                                            return True

                                        if self.update_group_index_xr is not None:
                                            return True

                                        if self.update_out_queue_messages is not None:
                                            return True

                                        if self.update_out_queue_size is not None:
                                            return True

                                        if self.update_statistics is not None and self.update_statistics._has_data():
                                            return True

                                        if self.update_sub_group_count is not None:
                                            return True

                                        if self.update_vrf_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-update-groups'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.update_generation_update_group is not None:
                                        for child_ref in self.update_generation_update_group:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups']['meta_info']


                            class UpdateGenerationFilterGroups(object):
                                """
                                Update generation for all filter\-groups under
                                a sub\-group
                                
                                .. attribute:: update_generation_filter_group
                                
                                	Update generation for filter\-group
                                	**type**\: list of    :py:class:`UpdateGenerationFilterGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.update_generation_filter_group = YList()
                                    self.update_generation_filter_group.parent = self
                                    self.update_generation_filter_group.name = 'update_generation_filter_group'


                                class UpdateGenerationFilterGroup(object):
                                    """
                                    Update generation for filter\-group
                                    
                                    .. attribute:: filter_group_index
                                    
                                    	Filter\-group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: neighbor_count
                                    
                                    	Neighbor count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: parent_filter_group_index
                                    
                                    	Parent Filter\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: parent_sub_group_id
                                    
                                    	Parent Sub\-group identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: parent_sub_group_index
                                    
                                    	Parent Sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_id
                                    
                                    	ProcessID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_id
                                    
                                    	Sub\-group ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sub_group_id_xr
                                    
                                    	Sub\-group identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_index
                                    
                                    	Sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sub_group_index_xr
                                    
                                    	Sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_filter_group_index
                                    
                                    	Filter\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_group_af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: update_group_index
                                    
                                    	Update\-group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: update_group_index_xr
                                    
                                    	Update\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_vrf_name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.filter_group_index = None
                                        self.neighbor_count = None
                                        self.parent_filter_group_index = None
                                        self.parent_sub_group_id = None
                                        self.parent_sub_group_index = None
                                        self.process_id = None
                                        self.sub_group_id = None
                                        self.sub_group_id_xr = None
                                        self.sub_group_index = None
                                        self.sub_group_index_xr = None
                                        self.update_filter_group_index = None
                                        self.update_group_af_name = None
                                        self.update_group_index = None
                                        self.update_group_index_xr = None
                                        self.update_vrf_name = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-filter-group'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.filter_group_index is not None:
                                            return True

                                        if self.neighbor_count is not None:
                                            return True

                                        if self.parent_filter_group_index is not None:
                                            return True

                                        if self.parent_sub_group_id is not None:
                                            return True

                                        if self.parent_sub_group_index is not None:
                                            return True

                                        if self.process_id is not None:
                                            return True

                                        if self.sub_group_id is not None:
                                            return True

                                        if self.sub_group_id_xr is not None:
                                            return True

                                        if self.sub_group_index is not None:
                                            return True

                                        if self.sub_group_index_xr is not None:
                                            return True

                                        if self.update_filter_group_index is not None:
                                            return True

                                        if self.update_group_af_name is not None:
                                            return True

                                        if self.update_group_index is not None:
                                            return True

                                        if self.update_group_index_xr is not None:
                                            return True

                                        if self.update_vrf_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-filter-groups'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.update_generation_filter_group is not None:
                                        for child_ref in self.update_generation_filter_group:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups']['meta_info']


                            class Networks(object):
                                """
                                The BGP Network Table
                                
                                .. attribute:: network
                                
                                	A BGP Network table entry
                                	**type**\: list of    :py:class:`Network <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.network = YList()
                                    self.network.parent = self
                                    self.network.name = 'network'


                                class Network(object):
                                    """
                                    A BGP Network table entry
                                    
                                    .. attribute:: active_path_element
                                    
                                    	Path element list received from Active inst
                                    	**type**\: list of    :py:class:`ActivePathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement>`
                                    
                                    .. attribute:: active_process_instance_path
                                    
                                    	Active's paths for this net 
                                    	**type**\: list of    :py:class:`ActiveProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath>`
                                    
                                    .. attribute:: add_path_orr_bitfield
                                    
                                    	ORR Add path Bitfields
                                    	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield>`
                                    
                                    .. attribute:: advertisedto_pe
                                    
                                    	Net could be advertised                          to PE peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: best_path_orr_bitfield
                                    
                                    	ORR Best path Bitfields
                                    	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield>`
                                    
                                    .. attribute:: bgp_prefix
                                    
                                    	BGP prefix
                                    	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix>`
                                    
                                    .. attribute:: bit
                                    
                                    	Bit
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: flags
                                    
                                    	Flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: gateway_array
                                    
                                    	Gateway array ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: has_inconsistent_paths
                                    
                                    	Net has inconsistent paths
                                    	**type**\:  bool
                                    
                                    .. attribute:: has_lbl_retained
                                    
                                    	Net has label retained
                                    	**type**\:  bool
                                    
                                    .. attribute:: has_local_label
                                    
                                    	Net has local label
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_net_aggregation_suppressed
                                    
                                    	Net suppressed due to aggregation
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_net_ldp_signaled
                                    
                                    	L2VPN Net LDP signaled  aggregation
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_permanent_network
                                    
                                    	Permanent Network
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_path_element
                                    
                                    	Local path element list
                                    	**type**\: list of    :py:class:`LocalPathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement>`
                                    
                                    .. attribute:: local_peers_advertised_to
                                    
                                    	Local peers that this prefix has been advertised to
                                    	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo>`
                                    
                                    .. attribute:: local_process_instance_path
                                    
                                    	Local (to process instance) paths for this net 
                                    	**type**\: list of    :py:class:`LocalProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath>`
                                    
                                    .. attribute:: net_backup_available
                                    
                                    	Net has backup path
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_backup_label_rewrite_available
                                    
                                    	Net has label rewrite for backup path
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_eibgp_multipath
                                    
                                    	Net has EIBGP multipaths
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_extended_flags
                                    
                                    	Net extended flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: net_flags
                                    
                                    	Flags associated with                            net
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: net_local_label
                                    
                                    	Local label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: net_local_label_rewrite
                                    
                                    	Net label has rewrite
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_local_label_srgb
                                    
                                    	Net label allocated fromSegment routing global block
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_multipath
                                    
                                    	Net has multipaths
                                    	**type**\:  bool
                                    
                                    .. attribute:: network
                                    
                                    	Network in prefix/length format
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    
                                    ----
                                    .. attribute:: num_of_path
                                    
                                    	Number of path for this net
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pe_peers_advertised_to
                                    
                                    	PE peers that this prefix has been advertised to
                                    	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo>`
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: resilient_nexthop_set
                                    
                                    	Resilient nexthop set ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_failed
                                    
                                    	RIB install failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: table_brib_version
                                    
                                    	Table version # for updates
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_version
                                    
                                    	Table version # for net
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version
                                    
                                    	Version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version_age
                                    
                                    	Version age
                                    	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.VersionAge>`
                                    
                                    .. attribute:: version_timestamp
                                    
                                    	Version timestamp
                                    	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.VersionTimestamp>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.active_path_element = YList()
                                        self.active_path_element.parent = self
                                        self.active_path_element.name = 'active_path_element'
                                        self.active_process_instance_path = YList()
                                        self.active_process_instance_path.parent = self
                                        self.active_process_instance_path.name = 'active_process_instance_path'
                                        self.add_path_orr_bitfield = YList()
                                        self.add_path_orr_bitfield.parent = self
                                        self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                        self.advertisedto_pe = None
                                        self.af_name = None
                                        self.best_path_orr_bitfield = YList()
                                        self.best_path_orr_bitfield.parent = self
                                        self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                        self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix()
                                        self.bgp_prefix.parent = self
                                        self.bit = None
                                        self.flags = None
                                        self.gateway_array = None
                                        self.has_inconsistent_paths = None
                                        self.has_lbl_retained = None
                                        self.has_local_label = None
                                        self.is_net_aggregation_suppressed = None
                                        self.is_net_ldp_signaled = None
                                        self.is_permanent_network = None
                                        self.local_path_element = YList()
                                        self.local_path_element.parent = self
                                        self.local_path_element.name = 'local_path_element'
                                        self.local_peers_advertised_to = YList()
                                        self.local_peers_advertised_to.parent = self
                                        self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                        self.local_process_instance_path = YList()
                                        self.local_process_instance_path.parent = self
                                        self.local_process_instance_path.name = 'local_process_instance_path'
                                        self.net_backup_available = None
                                        self.net_backup_label_rewrite_available = None
                                        self.net_eibgp_multipath = None
                                        self.net_extended_flags = None
                                        self.net_flags = None
                                        self.net_local_label = None
                                        self.net_local_label_rewrite = None
                                        self.net_local_label_srgb = None
                                        self.net_multipath = None
                                        self.network = None
                                        self.num_of_path = None
                                        self.pe_peers_advertised_to = YList()
                                        self.pe_peers_advertised_to.parent = self
                                        self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                        self.process_instance_id = None
                                        self.rd = None
                                        self.resilient_nexthop_set = None
                                        self.rib_failed = None
                                        self.route_distinguisher = None
                                        self.table_brib_version = None
                                        self.table_version = None
                                        self.version = None
                                        self.version_age = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.VersionAge()
                                        self.version_age.parent = self
                                        self.version_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.VersionTimestamp()
                                        self.version_timestamp.parent = self
                                        self.vrf_name = None


                                    class BgpPrefix(object):
                                        """
                                        BGP prefix
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix()
                                            self.prefix.parent = self
                                            self.prefix_length = None


                                        class Prefix(object):
                                            """
                                            Prefix
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.prefix is not None and self.prefix._has_data():
                                                return True

                                            if self.prefix_length is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix']['meta_info']


                                    class VersionTimestamp(object):
                                        """
                                        Version timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.VersionTimestamp']['meta_info']


                                    class VersionAge(object):
                                        """
                                        Version age
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-age'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.VersionAge']['meta_info']


                                    class LocalPeersAdvertisedTo(object):
                                        """
                                        Local peers that this prefix has been advertised
                                        to
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress>`
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.is_neighbor = None
                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self.update_group_number = None


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.is_neighbor is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            if self.update_group_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo']['meta_info']


                                    class PePeersAdvertisedTo(object):
                                        """
                                        PE peers that this prefix has been advertised to
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress>`
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.is_neighbor = None
                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self.update_group_number = None


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.is_neighbor is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            if self.update_group_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo']['meta_info']


                                    class BestPathOrrBitfield(object):
                                        """
                                        ORR Best path Bitfields
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress>`
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.is_neighbor = None
                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self.update_group_number = None


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.is_neighbor is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            if self.update_group_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield']['meta_info']


                                    class AddPathOrrBitfield(object):
                                        """
                                        ORR Add path Bitfields
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress>`
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.is_neighbor = None
                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self.update_group_number = None


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.is_neighbor is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            if self.update_group_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield']['meta_info']


                                    class LocalProcessInstancePath(object):
                                        """
                                        Local (to process instance) paths for this net 
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation>`
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self.label_fail = None
                                            self.label_o_or_version = None
                                            self.label_oor = None
                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self.no_path = None
                                            self.path_information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation()
                                            self.path_information.parent = self
                                            self.prefix_version = None
                                            self.process_instance_id = None
                                            self.route_distinguisher = None
                                            self.source_route_distinguisher = None
                                            self.source_vrf_name = None
                                            self.srcaf_name = None
                                            self.vrf_name = None


                                        class NeighborAddressXr(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr']['meta_info']


                                        class PathInformation(object):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_esi
                                            
                                            	Path has EVPN ESI
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_rcvd_label
                                            
                                            	Path has received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebg_ps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi>`
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop>`
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhteTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_p_ath = None
                                                self.add_path_orr_bitfield = YList()
                                                self.add_path_orr_bitfield.parent = self
                                                self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                self.advertisedto_pe = None
                                                self.aigp_metric = None
                                                self.best_path_comp_stage = None
                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self.best_path_id = None
                                                self.best_path_id_comp_winner = None
                                                self.best_path_orr_bitfield = YList()
                                                self.best_path_orr_bitfield.parent = self
                                                self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self.dampen_penalty = None
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.fspec_invalid_path = None
                                                self.graceful_shutdown = None
                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self.halflife_time = None
                                                self.has_esi = None
                                                self.has_gw_addr = None
                                                self.has_local_net_label = None
                                                self.has_mdt_group_addr = None
                                                self.has_mvpn_extcomm = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.has_rcvd_label = None
                                                self.has_second_label = None
                                                self.ibgp_signaled_validity = None
                                                self.igp_metric = None
                                                self.is_aggregation_suppressed = None
                                                self.is_as_best = None
                                                self.is_best_path = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_internal_path = None
                                                self.is_partial_best = None
                                                self.is_path_additional_path = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_af_install_eligible = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_damped = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_history_held = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_imported = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_multipath = None
                                                self.is_path_nexthop_discarded = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebg_ps = None
                                                self.is_path_received_only = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_stale = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_valid = None
                                                self.is_path_vpn_only = None
                                                self.is_permanent_path = None
                                                self.is_received_path_not_modified = None
                                                self.is_spkr_as_best = None
                                                self.l2vpn_circuit_status_value = YList()
                                                self.l2vpn_circuit_status_value.parent = self
                                                self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi()
                                                self.l2vpn_evpn_esi.parent = self
                                                self.l2vpn_size = None
                                                self.labeled_unicast_safi_path = None
                                                self.local_label = None
                                                self.local_nh = None
                                                self.local_path_id = None
                                                self.local_peers_advertised_to = YList()
                                                self.local_peers_advertised_to.parent = self
                                                self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                self.maximum_suppress_time = None
                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self.mvpn_path_flags = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_value = YList()
                                                self.mvpn_pmsi_value.parent = self
                                                self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                self.mvpn_sfs_path = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.neighbor_router_id = None
                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.path_flags = None
                                                self.path_flap_count = None
                                                self.path_import_flags = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.path_table_version = None
                                                self.path_weight = None
                                                self.pe_peers_advertised_to = YList()
                                                self.pe_peers_advertised_to.parent = self
                                                self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                self.rcvd_label = None
                                                self.rcvd_path_id = None
                                                self.reuse_value = None
                                                self.rib_failed = None
                                                self.route_type = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.rt_set_limit_enabled = None
                                                self.second_label = None
                                                self.seconds_since_first_flap = None
                                                self.show_rpki_origin_as_validity = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.suppress_penalty = None
                                                self.time_to_unsuppress = None


                                            class BgpPrefix(object):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self.prefix_length = None


                                                class Prefix(object):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.prefix is not None and self.prefix._has_data():
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix']['meta_info']


                                            class NeighborAddress(object):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress']['meta_info']


                                            class NextHop(object):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhteTunnel']['meta_info']


                                            class MdtGroupAddr(object):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr']['meta_info']


                                            class L2VpnEvpnEsi(object):
                                                """
                                                L2VPN EVPN ESI
                                                
                                                .. attribute:: esi
                                                
                                                	esi
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.esi = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.esi is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi']['meta_info']


                                            class GwAddr(object):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr']['meta_info']


                                            class BestPathCompWinner(object):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner']['meta_info']


                                            class MvpnNbrAddr(object):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr']['meta_info']


                                            class MvpnNexthopAddr(object):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr']['meta_info']


                                            class L2VpnCircuitStatusValue(object):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                            class MvpnPmsiValue(object):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity']['meta_info']


                                            class LocalPeersAdvertisedTo(object):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                            class PePeersAdvertisedTo(object):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo']['meta_info']


                                            class BestPathOrrBitfield(object):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield']['meta_info']


                                            class AddPathOrrBitfield(object):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.accept_own_path is not None:
                                                    return True

                                                if self.accept_own_self_originated_p_ath is not None:
                                                    return True

                                                if self.add_path_orr_bitfield is not None:
                                                    for child_ref in self.add_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.advertisedto_pe is not None:
                                                    return True

                                                if self.aigp_metric is not None:
                                                    return True

                                                if self.best_path_comp_stage is not None:
                                                    return True

                                                if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                    return True

                                                if self.best_path_id is not None:
                                                    return True

                                                if self.best_path_id_comp_winner is not None:
                                                    return True

                                                if self.best_path_orr_bitfield is not None:
                                                    for child_ref in self.best_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                    return True

                                                if self.dampen_penalty is not None:
                                                    return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.fspec_invalid_path is not None:
                                                    return True

                                                if self.graceful_shutdown is not None:
                                                    return True

                                                if self.gw_addr is not None and self.gw_addr._has_data():
                                                    return True

                                                if self.halflife_time is not None:
                                                    return True

                                                if self.has_esi is not None:
                                                    return True

                                                if self.has_gw_addr is not None:
                                                    return True

                                                if self.has_local_net_label is not None:
                                                    return True

                                                if self.has_mdt_group_addr is not None:
                                                    return True

                                                if self.has_mvpn_extcomm is not None:
                                                    return True

                                                if self.has_mvpn_nbr_addr is not None:
                                                    return True

                                                if self.has_mvpn_nexthop_addr is not None:
                                                    return True

                                                if self.has_mvpn_pmsi is not None:
                                                    return True

                                                if self.has_rcvd_label is not None:
                                                    return True

                                                if self.has_second_label is not None:
                                                    return True

                                                if self.ibgp_signaled_validity is not None:
                                                    return True

                                                if self.igp_metric is not None:
                                                    return True

                                                if self.is_aggregation_suppressed is not None:
                                                    return True

                                                if self.is_as_best is not None:
                                                    return True

                                                if self.is_best_path is not None:
                                                    return True

                                                if self.is_import_dampened is not None:
                                                    return True

                                                if self.is_import_suspect is not None:
                                                    return True

                                                if self.is_internal_path is not None:
                                                    return True

                                                if self.is_partial_best is not None:
                                                    return True

                                                if self.is_path_additional_path is not None:
                                                    return True

                                                if self.is_path_advertised_local_as_only is not None:
                                                    return True

                                                if self.is_path_af_install_eligible is not None:
                                                    return True

                                                if self.is_path_backup is not None:
                                                    return True

                                                if self.is_path_backup_protect_multipath is not None:
                                                    return True

                                                if self.is_path_best_external is not None:
                                                    return True

                                                if self.is_path_damped is not None:
                                                    return True

                                                if self.is_path_from_confederation_peer is not None:
                                                    return True

                                                if self.is_path_from_network_command is not None:
                                                    return True

                                                if self.is_path_from_redistribute_command is not None:
                                                    return True

                                                if self.is_path_from_route_reflector is not None:
                                                    return True

                                                if self.is_path_history_held is not None:
                                                    return True

                                                if self.is_path_imp_candidate is not None:
                                                    return True

                                                if self.is_path_imported is not None:
                                                    return True

                                                if self.is_path_local_aggregate is not None:
                                                    return True

                                                if self.is_path_locally_sourced is not None:
                                                    return True

                                                if self.is_path_long_lived_stale is not None:
                                                    return True

                                                if self.is_path_multipath is not None:
                                                    return True

                                                if self.is_path_nexthop_discarded is not None:
                                                    return True

                                                if self.is_path_not_advertised is not None:
                                                    return True

                                                if self.is_path_not_advertised_to_ebg_ps is not None:
                                                    return True

                                                if self.is_path_received_only is not None:
                                                    return True

                                                if self.is_path_reoriginated is not None:
                                                    return True

                                                if self.is_path_reoriginated_stitching is not None:
                                                    return True

                                                if self.is_path_stale is not None:
                                                    return True

                                                if self.is_path_synced_with_igp is not None:
                                                    return True

                                                if self.is_path_valid is not None:
                                                    return True

                                                if self.is_path_vpn_only is not None:
                                                    return True

                                                if self.is_permanent_path is not None:
                                                    return True

                                                if self.is_received_path_not_modified is not None:
                                                    return True

                                                if self.is_spkr_as_best is not None:
                                                    return True

                                                if self.l2vpn_circuit_status_value is not None:
                                                    for child_ref in self.l2vpn_circuit_status_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                    return True

                                                if self.l2vpn_size is not None:
                                                    return True

                                                if self.labeled_unicast_safi_path is not None:
                                                    return True

                                                if self.local_label is not None:
                                                    return True

                                                if self.local_nh is not None:
                                                    return True

                                                if self.local_path_id is not None:
                                                    return True

                                                if self.local_peers_advertised_to is not None:
                                                    for child_ref in self.local_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.maximum_suppress_time is not None:
                                                    return True

                                                if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                    return True

                                                if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                    return True

                                                if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                    return True

                                                if self.mvpn_path_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_label is not None:
                                                    return True

                                                if self.mvpn_pmsi_type is not None:
                                                    return True

                                                if self.mvpn_pmsi_value is not None:
                                                    for child_ref in self.mvpn_pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.mvpn_sfs_path is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.neighbor_router_id is not None:
                                                    return True

                                                if self.next_hop is not None and self.next_hop._has_data():
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.path_flags is not None:
                                                    return True

                                                if self.path_flap_count is not None:
                                                    return True

                                                if self.path_import_flags is not None:
                                                    return True

                                                if self.path_rt_set_id is not None:
                                                    return True

                                                if self.path_rt_set_route_count is not None:
                                                    return True

                                                if self.path_table_version is not None:
                                                    return True

                                                if self.path_weight is not None:
                                                    return True

                                                if self.pe_peers_advertised_to is not None:
                                                    for child_ref in self.pe_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.rcvd_label is not None:
                                                    return True

                                                if self.rcvd_path_id is not None:
                                                    return True

                                                if self.reuse_value is not None:
                                                    return True

                                                if self.rib_failed is not None:
                                                    return True

                                                if self.route_type is not None:
                                                    return True

                                                if self.rpki_origin_as_validation_disabled is not None:
                                                    return True

                                                if self.rt_set_limit_enabled is not None:
                                                    return True

                                                if self.second_label is not None:
                                                    return True

                                                if self.seconds_since_first_flap is not None:
                                                    return True

                                                if self.show_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.sn_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.suppress_penalty is not None:
                                                    return True

                                                if self.time_to_unsuppress is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation']['meta_info']


                                        class AttributesAfterPolicyIn(object):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self.is_application_gateway_present = None
                                                self.is_as_path2_byte = None
                                                self.is_attr_set_present = None
                                                self.is_ribrnh_present = None
                                                self.is_rnh_present = None
                                                self.ribrnh_encap = None
                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self.ribrnh_mac = None
                                                self.ribrnh_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnhip_table = None
                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self.rnh_addr_len = None
                                                self.rnh_len = None
                                                self.rnh_type = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.vpn_distinguisher = None


                                            class CommonAttributes(object):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                            class AttrSet(object):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                            class RnhAddr(object):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None
                                                    self.mac_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    if self.mac_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                            class RibrnhIp(object):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.attr_set is not None and self.attr_set._has_data():
                                                    return True

                                                if self.attribute_key_number is not None:
                                                    return True

                                                if self.attribute_reuse_id_config is not None:
                                                    return True

                                                if self.attribute_reuse_id_current is not None:
                                                    return True

                                                if self.attribute_reuse_id_keys is not None:
                                                    return True

                                                if self.attribute_reuse_id_max_id is not None:
                                                    return True

                                                if self.attribute_reuse_id_node is not None:
                                                    return True

                                                if self.attribute_reuse_id_recover_sec is not None:
                                                    return True

                                                if self.common_attributes is not None and self.common_attributes._has_data():
                                                    return True

                                                if self.is_application_gateway_present is not None:
                                                    return True

                                                if self.is_as_path2_byte is not None:
                                                    return True

                                                if self.is_attr_set_present is not None:
                                                    return True

                                                if self.is_ribrnh_present is not None:
                                                    return True

                                                if self.is_rnh_present is not None:
                                                    return True

                                                if self.ribrnh_encap is not None:
                                                    return True

                                                if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                    return True

                                                if self.ribrnh_mac is not None:
                                                    return True

                                                if self.ribrnh_table is not None:
                                                    return True

                                                if self.ribrnh_vni is not None:
                                                    return True

                                                if self.ribrnhip_table is not None:
                                                    return True

                                                if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                    return True

                                                if self.rnh_addr_len is not None:
                                                    return True

                                                if self.rnh_len is not None:
                                                    return True

                                                if self.rnh_type is not None:
                                                    return True

                                                if self.set_aigp_inbound_igp is not None:
                                                    return True

                                                if self.set_aigp_inbound_metric is not None:
                                                    return True

                                                if self.vpn_distinguisher is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-process-instance-path'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                return True

                                            if self.label_fail is not None:
                                                return True

                                            if self.label_o_or_version is not None:
                                                return True

                                            if self.label_oor is not None:
                                                return True

                                            if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                return True

                                            if self.no_path is not None:
                                                return True

                                            if self.path_information is not None and self.path_information._has_data():
                                                return True

                                            if self.prefix_version is not None:
                                                return True

                                            if self.process_instance_id is not None:
                                                return True

                                            if self.route_distinguisher is not None:
                                                return True

                                            if self.source_route_distinguisher is not None:
                                                return True

                                            if self.source_vrf_name is not None:
                                                return True

                                            if self.srcaf_name is not None:
                                                return True

                                            if self.vrf_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath']['meta_info']


                                    class ActiveProcessInstancePath(object):
                                        """
                                        Active's paths for this net 
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation>`
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self.label_fail = None
                                            self.label_o_or_version = None
                                            self.label_oor = None
                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self.no_path = None
                                            self.path_information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation()
                                            self.path_information.parent = self
                                            self.prefix_version = None
                                            self.process_instance_id = None
                                            self.route_distinguisher = None
                                            self.source_route_distinguisher = None
                                            self.source_vrf_name = None
                                            self.srcaf_name = None
                                            self.vrf_name = None


                                        class NeighborAddressXr(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr']['meta_info']


                                        class PathInformation(object):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_esi
                                            
                                            	Path has EVPN ESI
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_rcvd_label
                                            
                                            	Path has received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebg_ps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi>`
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop>`
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhteTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_p_ath = None
                                                self.add_path_orr_bitfield = YList()
                                                self.add_path_orr_bitfield.parent = self
                                                self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                self.advertisedto_pe = None
                                                self.aigp_metric = None
                                                self.best_path_comp_stage = None
                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self.best_path_id = None
                                                self.best_path_id_comp_winner = None
                                                self.best_path_orr_bitfield = YList()
                                                self.best_path_orr_bitfield.parent = self
                                                self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self.dampen_penalty = None
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.fspec_invalid_path = None
                                                self.graceful_shutdown = None
                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self.halflife_time = None
                                                self.has_esi = None
                                                self.has_gw_addr = None
                                                self.has_local_net_label = None
                                                self.has_mdt_group_addr = None
                                                self.has_mvpn_extcomm = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.has_rcvd_label = None
                                                self.has_second_label = None
                                                self.ibgp_signaled_validity = None
                                                self.igp_metric = None
                                                self.is_aggregation_suppressed = None
                                                self.is_as_best = None
                                                self.is_best_path = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_internal_path = None
                                                self.is_partial_best = None
                                                self.is_path_additional_path = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_af_install_eligible = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_damped = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_history_held = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_imported = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_multipath = None
                                                self.is_path_nexthop_discarded = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebg_ps = None
                                                self.is_path_received_only = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_stale = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_valid = None
                                                self.is_path_vpn_only = None
                                                self.is_permanent_path = None
                                                self.is_received_path_not_modified = None
                                                self.is_spkr_as_best = None
                                                self.l2vpn_circuit_status_value = YList()
                                                self.l2vpn_circuit_status_value.parent = self
                                                self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi()
                                                self.l2vpn_evpn_esi.parent = self
                                                self.l2vpn_size = None
                                                self.labeled_unicast_safi_path = None
                                                self.local_label = None
                                                self.local_nh = None
                                                self.local_path_id = None
                                                self.local_peers_advertised_to = YList()
                                                self.local_peers_advertised_to.parent = self
                                                self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                self.maximum_suppress_time = None
                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self.mvpn_path_flags = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_value = YList()
                                                self.mvpn_pmsi_value.parent = self
                                                self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                self.mvpn_sfs_path = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.neighbor_router_id = None
                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.path_flags = None
                                                self.path_flap_count = None
                                                self.path_import_flags = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.path_table_version = None
                                                self.path_weight = None
                                                self.pe_peers_advertised_to = YList()
                                                self.pe_peers_advertised_to.parent = self
                                                self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                self.rcvd_label = None
                                                self.rcvd_path_id = None
                                                self.reuse_value = None
                                                self.rib_failed = None
                                                self.route_type = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.rt_set_limit_enabled = None
                                                self.second_label = None
                                                self.seconds_since_first_flap = None
                                                self.show_rpki_origin_as_validity = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.suppress_penalty = None
                                                self.time_to_unsuppress = None


                                            class BgpPrefix(object):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self.prefix_length = None


                                                class Prefix(object):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.prefix is not None and self.prefix._has_data():
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix']['meta_info']


                                            class NeighborAddress(object):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress']['meta_info']


                                            class NextHop(object):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhteTunnel']['meta_info']


                                            class MdtGroupAddr(object):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr']['meta_info']


                                            class L2VpnEvpnEsi(object):
                                                """
                                                L2VPN EVPN ESI
                                                
                                                .. attribute:: esi
                                                
                                                	esi
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.esi = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.esi is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi']['meta_info']


                                            class GwAddr(object):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr']['meta_info']


                                            class BestPathCompWinner(object):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner']['meta_info']


                                            class MvpnNbrAddr(object):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr']['meta_info']


                                            class MvpnNexthopAddr(object):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr']['meta_info']


                                            class L2VpnCircuitStatusValue(object):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                            class MvpnPmsiValue(object):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity']['meta_info']


                                            class LocalPeersAdvertisedTo(object):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                            class PePeersAdvertisedTo(object):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo']['meta_info']


                                            class BestPathOrrBitfield(object):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield']['meta_info']


                                            class AddPathOrrBitfield(object):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.accept_own_path is not None:
                                                    return True

                                                if self.accept_own_self_originated_p_ath is not None:
                                                    return True

                                                if self.add_path_orr_bitfield is not None:
                                                    for child_ref in self.add_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.advertisedto_pe is not None:
                                                    return True

                                                if self.aigp_metric is not None:
                                                    return True

                                                if self.best_path_comp_stage is not None:
                                                    return True

                                                if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                    return True

                                                if self.best_path_id is not None:
                                                    return True

                                                if self.best_path_id_comp_winner is not None:
                                                    return True

                                                if self.best_path_orr_bitfield is not None:
                                                    for child_ref in self.best_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                    return True

                                                if self.dampen_penalty is not None:
                                                    return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.fspec_invalid_path is not None:
                                                    return True

                                                if self.graceful_shutdown is not None:
                                                    return True

                                                if self.gw_addr is not None and self.gw_addr._has_data():
                                                    return True

                                                if self.halflife_time is not None:
                                                    return True

                                                if self.has_esi is not None:
                                                    return True

                                                if self.has_gw_addr is not None:
                                                    return True

                                                if self.has_local_net_label is not None:
                                                    return True

                                                if self.has_mdt_group_addr is not None:
                                                    return True

                                                if self.has_mvpn_extcomm is not None:
                                                    return True

                                                if self.has_mvpn_nbr_addr is not None:
                                                    return True

                                                if self.has_mvpn_nexthop_addr is not None:
                                                    return True

                                                if self.has_mvpn_pmsi is not None:
                                                    return True

                                                if self.has_rcvd_label is not None:
                                                    return True

                                                if self.has_second_label is not None:
                                                    return True

                                                if self.ibgp_signaled_validity is not None:
                                                    return True

                                                if self.igp_metric is not None:
                                                    return True

                                                if self.is_aggregation_suppressed is not None:
                                                    return True

                                                if self.is_as_best is not None:
                                                    return True

                                                if self.is_best_path is not None:
                                                    return True

                                                if self.is_import_dampened is not None:
                                                    return True

                                                if self.is_import_suspect is not None:
                                                    return True

                                                if self.is_internal_path is not None:
                                                    return True

                                                if self.is_partial_best is not None:
                                                    return True

                                                if self.is_path_additional_path is not None:
                                                    return True

                                                if self.is_path_advertised_local_as_only is not None:
                                                    return True

                                                if self.is_path_af_install_eligible is not None:
                                                    return True

                                                if self.is_path_backup is not None:
                                                    return True

                                                if self.is_path_backup_protect_multipath is not None:
                                                    return True

                                                if self.is_path_best_external is not None:
                                                    return True

                                                if self.is_path_damped is not None:
                                                    return True

                                                if self.is_path_from_confederation_peer is not None:
                                                    return True

                                                if self.is_path_from_network_command is not None:
                                                    return True

                                                if self.is_path_from_redistribute_command is not None:
                                                    return True

                                                if self.is_path_from_route_reflector is not None:
                                                    return True

                                                if self.is_path_history_held is not None:
                                                    return True

                                                if self.is_path_imp_candidate is not None:
                                                    return True

                                                if self.is_path_imported is not None:
                                                    return True

                                                if self.is_path_local_aggregate is not None:
                                                    return True

                                                if self.is_path_locally_sourced is not None:
                                                    return True

                                                if self.is_path_long_lived_stale is not None:
                                                    return True

                                                if self.is_path_multipath is not None:
                                                    return True

                                                if self.is_path_nexthop_discarded is not None:
                                                    return True

                                                if self.is_path_not_advertised is not None:
                                                    return True

                                                if self.is_path_not_advertised_to_ebg_ps is not None:
                                                    return True

                                                if self.is_path_received_only is not None:
                                                    return True

                                                if self.is_path_reoriginated is not None:
                                                    return True

                                                if self.is_path_reoriginated_stitching is not None:
                                                    return True

                                                if self.is_path_stale is not None:
                                                    return True

                                                if self.is_path_synced_with_igp is not None:
                                                    return True

                                                if self.is_path_valid is not None:
                                                    return True

                                                if self.is_path_vpn_only is not None:
                                                    return True

                                                if self.is_permanent_path is not None:
                                                    return True

                                                if self.is_received_path_not_modified is not None:
                                                    return True

                                                if self.is_spkr_as_best is not None:
                                                    return True

                                                if self.l2vpn_circuit_status_value is not None:
                                                    for child_ref in self.l2vpn_circuit_status_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                    return True

                                                if self.l2vpn_size is not None:
                                                    return True

                                                if self.labeled_unicast_safi_path is not None:
                                                    return True

                                                if self.local_label is not None:
                                                    return True

                                                if self.local_nh is not None:
                                                    return True

                                                if self.local_path_id is not None:
                                                    return True

                                                if self.local_peers_advertised_to is not None:
                                                    for child_ref in self.local_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.maximum_suppress_time is not None:
                                                    return True

                                                if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                    return True

                                                if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                    return True

                                                if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                    return True

                                                if self.mvpn_path_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_label is not None:
                                                    return True

                                                if self.mvpn_pmsi_type is not None:
                                                    return True

                                                if self.mvpn_pmsi_value is not None:
                                                    for child_ref in self.mvpn_pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.mvpn_sfs_path is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.neighbor_router_id is not None:
                                                    return True

                                                if self.next_hop is not None and self.next_hop._has_data():
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.path_flags is not None:
                                                    return True

                                                if self.path_flap_count is not None:
                                                    return True

                                                if self.path_import_flags is not None:
                                                    return True

                                                if self.path_rt_set_id is not None:
                                                    return True

                                                if self.path_rt_set_route_count is not None:
                                                    return True

                                                if self.path_table_version is not None:
                                                    return True

                                                if self.path_weight is not None:
                                                    return True

                                                if self.pe_peers_advertised_to is not None:
                                                    for child_ref in self.pe_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.rcvd_label is not None:
                                                    return True

                                                if self.rcvd_path_id is not None:
                                                    return True

                                                if self.reuse_value is not None:
                                                    return True

                                                if self.rib_failed is not None:
                                                    return True

                                                if self.route_type is not None:
                                                    return True

                                                if self.rpki_origin_as_validation_disabled is not None:
                                                    return True

                                                if self.rt_set_limit_enabled is not None:
                                                    return True

                                                if self.second_label is not None:
                                                    return True

                                                if self.seconds_since_first_flap is not None:
                                                    return True

                                                if self.show_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.sn_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.suppress_penalty is not None:
                                                    return True

                                                if self.time_to_unsuppress is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation']['meta_info']


                                        class AttributesAfterPolicyIn(object):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self.is_application_gateway_present = None
                                                self.is_as_path2_byte = None
                                                self.is_attr_set_present = None
                                                self.is_ribrnh_present = None
                                                self.is_rnh_present = None
                                                self.ribrnh_encap = None
                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self.ribrnh_mac = None
                                                self.ribrnh_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnhip_table = None
                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self.rnh_addr_len = None
                                                self.rnh_len = None
                                                self.rnh_type = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.vpn_distinguisher = None


                                            class CommonAttributes(object):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                            class AttrSet(object):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                            class RnhAddr(object):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None
                                                    self.mac_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    if self.mac_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                            class RibrnhIp(object):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.attr_set is not None and self.attr_set._has_data():
                                                    return True

                                                if self.attribute_key_number is not None:
                                                    return True

                                                if self.attribute_reuse_id_config is not None:
                                                    return True

                                                if self.attribute_reuse_id_current is not None:
                                                    return True

                                                if self.attribute_reuse_id_keys is not None:
                                                    return True

                                                if self.attribute_reuse_id_max_id is not None:
                                                    return True

                                                if self.attribute_reuse_id_node is not None:
                                                    return True

                                                if self.attribute_reuse_id_recover_sec is not None:
                                                    return True

                                                if self.common_attributes is not None and self.common_attributes._has_data():
                                                    return True

                                                if self.is_application_gateway_present is not None:
                                                    return True

                                                if self.is_as_path2_byte is not None:
                                                    return True

                                                if self.is_attr_set_present is not None:
                                                    return True

                                                if self.is_ribrnh_present is not None:
                                                    return True

                                                if self.is_rnh_present is not None:
                                                    return True

                                                if self.ribrnh_encap is not None:
                                                    return True

                                                if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                    return True

                                                if self.ribrnh_mac is not None:
                                                    return True

                                                if self.ribrnh_table is not None:
                                                    return True

                                                if self.ribrnh_vni is not None:
                                                    return True

                                                if self.ribrnhip_table is not None:
                                                    return True

                                                if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                    return True

                                                if self.rnh_addr_len is not None:
                                                    return True

                                                if self.rnh_len is not None:
                                                    return True

                                                if self.rnh_type is not None:
                                                    return True

                                                if self.set_aigp_inbound_igp is not None:
                                                    return True

                                                if self.set_aigp_inbound_metric is not None:
                                                    return True

                                                if self.vpn_distinguisher is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-process-instance-path'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                return True

                                            if self.label_fail is not None:
                                                return True

                                            if self.label_o_or_version is not None:
                                                return True

                                            if self.label_oor is not None:
                                                return True

                                            if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                return True

                                            if self.no_path is not None:
                                                return True

                                            if self.path_information is not None and self.path_information._has_data():
                                                return True

                                            if self.prefix_version is not None:
                                                return True

                                            if self.process_instance_id is not None:
                                                return True

                                            if self.route_distinguisher is not None:
                                                return True

                                            if self.source_route_distinguisher is not None:
                                                return True

                                            if self.source_vrf_name is not None:
                                                return True

                                            if self.srcaf_name is not None:
                                                return True

                                            if self.vrf_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath']['meta_info']


                                    class LocalPathElement(object):
                                        """
                                        Local path element list
                                        
                                        .. attribute:: is_perm_path_pelem
                                        
                                        	Pelem for permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: nhte_tunnel
                                        
                                        	NH TE tunnel information
                                        	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.NhteTunnel>`
                                        
                                        .. attribute:: pelem_flags
                                        
                                        	Flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_gw_metric
                                        
                                        	Gateway metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_addpath_table_attr_version
                                        
                                        	No\-addpath Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_bestpath_table_attr_version
                                        
                                        	No\-bestpath Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_flags
                                        
                                        	Path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: pelem_path_id
                                        
                                        	Local Path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_neighbor_addr
                                        
                                        	Path neighbor address
                                        	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr>`
                                        
                                        .. attribute:: pelem_path_nexthop
                                        
                                        	Path nexthop address
                                        	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop>`
                                        
                                        .. attribute:: pelem_path_peer_path_id
                                        
                                        	Path peer path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_table_attr_version
                                        
                                        	Path Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_table_attr_version
                                        
                                        	Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_version
                                        
                                        	Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.is_perm_path_pelem = None
                                            self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.NhteTunnel()
                                            self.nhte_tunnel.parent = self
                                            self.pelem_flags = None
                                            self.pelem_gw_metric = None
                                            self.pelem_no_addpath_table_attr_version = None
                                            self.pelem_no_bestpath_table_attr_version = None
                                            self.pelem_path_flags = None
                                            self.pelem_path_id = None
                                            self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr()
                                            self.pelem_path_neighbor_addr.parent = self
                                            self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop()
                                            self.pelem_path_nexthop.parent = self
                                            self.pelem_path_peer_path_id = None
                                            self.pelem_path_table_attr_version = None
                                            self.pelem_table_attr_version = None
                                            self.pelem_version = None


                                        class PelemPathNexthop(object):
                                            """
                                            Path nexthop address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-nexthop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop']['meta_info']


                                        class NhteTunnel(object):
                                            """
                                            NH TE tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_te_tunnel
                                            
                                            	NH TE Tunnel info is present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last rib update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	tunnel name
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	tunnel type
                                            	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.binding_label = None
                                                self.has_te_tunnel = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.is_tunnel_up = None
                                                self.last_tunnel_update = None
                                                self.tunnel_if_handle = None
                                                self.tunnel_name = None
                                                self.tunnel_type = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_v6_required = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.binding_label is not None:
                                                    return True

                                                if self.has_te_tunnel is not None:
                                                    return True

                                                if self.is_tunnel_info_stale is not None:
                                                    return True

                                                if self.is_tunnel_registered is not None:
                                                    return True

                                                if self.is_tunnel_up is not None:
                                                    return True

                                                if self.last_tunnel_update is not None:
                                                    return True

                                                if self.tunnel_if_handle is not None:
                                                    return True

                                                if self.tunnel_name is not None:
                                                    return True

                                                if self.tunnel_type is not None:
                                                    return True

                                                if self.tunnel_v6_enabled is not None:
                                                    return True

                                                if self.tunnel_v6_required is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.NhteTunnel']['meta_info']


                                        class PelemPathNeighborAddr(object):
                                            """
                                            Path neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-neighbor-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-path-element'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.is_perm_path_pelem is not None:
                                                return True

                                            if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                return True

                                            if self.pelem_flags is not None:
                                                return True

                                            if self.pelem_gw_metric is not None:
                                                return True

                                            if self.pelem_no_addpath_table_attr_version is not None:
                                                return True

                                            if self.pelem_no_bestpath_table_attr_version is not None:
                                                return True

                                            if self.pelem_path_flags is not None:
                                                return True

                                            if self.pelem_path_id is not None:
                                                return True

                                            if self.pelem_path_neighbor_addr is not None and self.pelem_path_neighbor_addr._has_data():
                                                return True

                                            if self.pelem_path_nexthop is not None and self.pelem_path_nexthop._has_data():
                                                return True

                                            if self.pelem_path_peer_path_id is not None:
                                                return True

                                            if self.pelem_path_table_attr_version is not None:
                                                return True

                                            if self.pelem_table_attr_version is not None:
                                                return True

                                            if self.pelem_version is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement']['meta_info']


                                    class ActivePathElement(object):
                                        """
                                        Path element list received from Active inst
                                        
                                        .. attribute:: is_perm_path_pelem
                                        
                                        	Pelem for permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: nhte_tunnel
                                        
                                        	NH TE tunnel information
                                        	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.NhteTunnel>`
                                        
                                        .. attribute:: pelem_flags
                                        
                                        	Flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_gw_metric
                                        
                                        	Gateway metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_addpath_table_attr_version
                                        
                                        	No\-addpath Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_bestpath_table_attr_version
                                        
                                        	No\-bestpath Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_flags
                                        
                                        	Path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: pelem_path_id
                                        
                                        	Local Path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_neighbor_addr
                                        
                                        	Path neighbor address
                                        	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr>`
                                        
                                        .. attribute:: pelem_path_nexthop
                                        
                                        	Path nexthop address
                                        	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop>`
                                        
                                        .. attribute:: pelem_path_peer_path_id
                                        
                                        	Path peer path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_table_attr_version
                                        
                                        	Path Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_table_attr_version
                                        
                                        	Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_version
                                        
                                        	Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.is_perm_path_pelem = None
                                            self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.NhteTunnel()
                                            self.nhte_tunnel.parent = self
                                            self.pelem_flags = None
                                            self.pelem_gw_metric = None
                                            self.pelem_no_addpath_table_attr_version = None
                                            self.pelem_no_bestpath_table_attr_version = None
                                            self.pelem_path_flags = None
                                            self.pelem_path_id = None
                                            self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr()
                                            self.pelem_path_neighbor_addr.parent = self
                                            self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop()
                                            self.pelem_path_nexthop.parent = self
                                            self.pelem_path_peer_path_id = None
                                            self.pelem_path_table_attr_version = None
                                            self.pelem_table_attr_version = None
                                            self.pelem_version = None


                                        class PelemPathNexthop(object):
                                            """
                                            Path nexthop address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-nexthop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop']['meta_info']


                                        class NhteTunnel(object):
                                            """
                                            NH TE tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_te_tunnel
                                            
                                            	NH TE Tunnel info is present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last rib update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	tunnel name
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	tunnel type
                                            	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.binding_label = None
                                                self.has_te_tunnel = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.is_tunnel_up = None
                                                self.last_tunnel_update = None
                                                self.tunnel_if_handle = None
                                                self.tunnel_name = None
                                                self.tunnel_type = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_v6_required = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.binding_label is not None:
                                                    return True

                                                if self.has_te_tunnel is not None:
                                                    return True

                                                if self.is_tunnel_info_stale is not None:
                                                    return True

                                                if self.is_tunnel_registered is not None:
                                                    return True

                                                if self.is_tunnel_up is not None:
                                                    return True

                                                if self.last_tunnel_update is not None:
                                                    return True

                                                if self.tunnel_if_handle is not None:
                                                    return True

                                                if self.tunnel_name is not None:
                                                    return True

                                                if self.tunnel_type is not None:
                                                    return True

                                                if self.tunnel_v6_enabled is not None:
                                                    return True

                                                if self.tunnel_v6_required is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.NhteTunnel']['meta_info']


                                        class PelemPathNeighborAddr(object):
                                            """
                                            Path neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-neighbor-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-path-element'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.is_perm_path_pelem is not None:
                                                return True

                                            if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                return True

                                            if self.pelem_flags is not None:
                                                return True

                                            if self.pelem_gw_metric is not None:
                                                return True

                                            if self.pelem_no_addpath_table_attr_version is not None:
                                                return True

                                            if self.pelem_no_bestpath_table_attr_version is not None:
                                                return True

                                            if self.pelem_path_flags is not None:
                                                return True

                                            if self.pelem_path_id is not None:
                                                return True

                                            if self.pelem_path_neighbor_addr is not None and self.pelem_path_neighbor_addr._has_data():
                                                return True

                                            if self.pelem_path_nexthop is not None and self.pelem_path_nexthop._has_data():
                                                return True

                                            if self.pelem_path_peer_path_id is not None:
                                                return True

                                            if self.pelem_path_table_attr_version is not None:
                                                return True

                                            if self.pelem_table_attr_version is not None:
                                                return True

                                            if self.pelem_version is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.active_path_element is not None:
                                            for child_ref in self.active_path_element:
                                                if child_ref._has_data():
                                                    return True

                                        if self.active_process_instance_path is not None:
                                            for child_ref in self.active_process_instance_path:
                                                if child_ref._has_data():
                                                    return True

                                        if self.add_path_orr_bitfield is not None:
                                            for child_ref in self.add_path_orr_bitfield:
                                                if child_ref._has_data():
                                                    return True

                                        if self.advertisedto_pe is not None:
                                            return True

                                        if self.af_name is not None:
                                            return True

                                        if self.best_path_orr_bitfield is not None:
                                            for child_ref in self.best_path_orr_bitfield:
                                                if child_ref._has_data():
                                                    return True

                                        if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                            return True

                                        if self.bit is not None:
                                            return True

                                        if self.flags is not None:
                                            return True

                                        if self.gateway_array is not None:
                                            return True

                                        if self.has_inconsistent_paths is not None:
                                            return True

                                        if self.has_lbl_retained is not None:
                                            return True

                                        if self.has_local_label is not None:
                                            return True

                                        if self.is_net_aggregation_suppressed is not None:
                                            return True

                                        if self.is_net_ldp_signaled is not None:
                                            return True

                                        if self.is_permanent_network is not None:
                                            return True

                                        if self.local_path_element is not None:
                                            for child_ref in self.local_path_element:
                                                if child_ref._has_data():
                                                    return True

                                        if self.local_peers_advertised_to is not None:
                                            for child_ref in self.local_peers_advertised_to:
                                                if child_ref._has_data():
                                                    return True

                                        if self.local_process_instance_path is not None:
                                            for child_ref in self.local_process_instance_path:
                                                if child_ref._has_data():
                                                    return True

                                        if self.net_backup_available is not None:
                                            return True

                                        if self.net_backup_label_rewrite_available is not None:
                                            return True

                                        if self.net_eibgp_multipath is not None:
                                            return True

                                        if self.net_extended_flags is not None:
                                            return True

                                        if self.net_flags is not None:
                                            return True

                                        if self.net_local_label is not None:
                                            return True

                                        if self.net_local_label_rewrite is not None:
                                            return True

                                        if self.net_local_label_srgb is not None:
                                            return True

                                        if self.net_multipath is not None:
                                            return True

                                        if self.network is not None:
                                            return True

                                        if self.num_of_path is not None:
                                            return True

                                        if self.pe_peers_advertised_to is not None:
                                            for child_ref in self.pe_peers_advertised_to:
                                                if child_ref._has_data():
                                                    return True

                                        if self.process_instance_id is not None:
                                            return True

                                        if self.rd is not None:
                                            return True

                                        if self.resilient_nexthop_set is not None:
                                            return True

                                        if self.rib_failed is not None:
                                            return True

                                        if self.route_distinguisher is not None:
                                            return True

                                        if self.table_brib_version is not None:
                                            return True

                                        if self.table_version is not None:
                                            return True

                                        if self.version is not None:
                                            return True

                                        if self.version_age is not None and self.version_age._has_data():
                                            return True

                                        if self.version_timestamp is not None and self.version_timestamp._has_data():
                                            return True

                                        if self.vrf_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:networks'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.network is not None:
                                        for child_ref in self.network:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks']['meta_info']


                            class PathTable(object):
                                """
                                The BGP Path Table
                                
                                .. attribute:: path
                                
                                	A BGP path table entry
                                	**type**\: list of    :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.path = YList()
                                    self.path.parent = self
                                    self.path.name = 'path'


                                class Path(object):
                                    """
                                    A BGP path table entry
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: attributes_after_policy_in
                                    
                                    	Attributes after inbound policy applied
                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn>`
                                    
                                    .. attribute:: label_fail
                                    
                                    	LSD label allocation failed 
                                    	**type**\:  bool
                                    
                                    .. attribute:: label_o_or_version
                                    
                                    	Label Version when OOR happens
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_oor
                                    
                                    	LSD label space is exhausted
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor adddress
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr>`
                                    
                                    .. attribute:: network
                                    
                                    	Network Prefix in Hex format
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: no_path
                                    
                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_id
                                    
                                    	Received Path ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: path_information
                                    
                                    	Path information
                                    	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: prefix_version
                                    
                                    	Version of BGP Prefix Table
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: route_type
                                    
                                    	Route Type
                                    	**type**\:   :py:class:`BgpRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRouteEnum>`
                                    
                                    .. attribute:: source_rd
                                    
                                    	Source Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: source_route_distinguisher
                                    
                                    	Source Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_vrf_name
                                    
                                    	Name of the source VRF
                                    	**type**\:  str
                                    
                                    .. attribute:: srcaf_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn()
                                        self.attributes_after_policy_in.parent = self
                                        self.label_fail = None
                                        self.label_o_or_version = None
                                        self.label_oor = None
                                        self.neighbor_address = None
                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr()
                                        self.neighbor_address_xr.parent = self
                                        self.network = None
                                        self.no_path = None
                                        self.path_id = None
                                        self.path_information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation()
                                        self.path_information.parent = self
                                        self.prefix_length = None
                                        self.prefix_version = None
                                        self.process_instance_id = None
                                        self.rd = None
                                        self.route_distinguisher = None
                                        self.route_type = None
                                        self.source_rd = None
                                        self.source_route_distinguisher = None
                                        self.source_vrf_name = None
                                        self.srcaf_name = None
                                        self.vrf_name = None


                                    class NeighborAddressXr(object):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr']['meta_info']


                                    class PathInformation(object):
                                        """
                                        Path information
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_own_self_originated_p_ath
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\:  bool
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield>`
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner>`
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix>`
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity>`
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\:  bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\:  bool
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.GwAddr>`
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_esi
                                        
                                        	Path has EVPN ESI
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_rcvd_label
                                        
                                        	Path has received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\:  bool
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebg_ps
                                        
                                        	Not advertised to EBGPs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.L2VpnCircuitStatusValue>`
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.L2VpnEvpnEsi>`
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr>`
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue>`
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress>`
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop>`
                                        
                                        .. attribute:: nhte_tunnel
                                        
                                        	NH TE tunnel information
                                        	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhteTunnel>`
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\:  bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.accept_own_path = None
                                            self.accept_own_self_originated_p_ath = None
                                            self.add_path_orr_bitfield = YList()
                                            self.add_path_orr_bitfield.parent = self
                                            self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                            self.advertisedto_pe = None
                                            self.aigp_metric = None
                                            self.best_path_comp_stage = None
                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self.best_path_id = None
                                            self.best_path_id_comp_winner = None
                                            self.best_path_orr_bitfield = YList()
                                            self.best_path_orr_bitfield.parent = self
                                            self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self.dampen_penalty = None
                                            self.extended_community = YList()
                                            self.extended_community.parent = self
                                            self.extended_community.name = 'extended_community'
                                            self.fspec_invalid_path = None
                                            self.graceful_shutdown = None
                                            self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.GwAddr()
                                            self.gw_addr.parent = self
                                            self.halflife_time = None
                                            self.has_esi = None
                                            self.has_gw_addr = None
                                            self.has_local_net_label = None
                                            self.has_mdt_group_addr = None
                                            self.has_mvpn_extcomm = None
                                            self.has_mvpn_nbr_addr = None
                                            self.has_mvpn_nexthop_addr = None
                                            self.has_mvpn_pmsi = None
                                            self.has_rcvd_label = None
                                            self.has_second_label = None
                                            self.ibgp_signaled_validity = None
                                            self.igp_metric = None
                                            self.is_aggregation_suppressed = None
                                            self.is_as_best = None
                                            self.is_best_path = None
                                            self.is_import_dampened = None
                                            self.is_import_suspect = None
                                            self.is_internal_path = None
                                            self.is_partial_best = None
                                            self.is_path_additional_path = None
                                            self.is_path_advertised_local_as_only = None
                                            self.is_path_af_install_eligible = None
                                            self.is_path_backup = None
                                            self.is_path_backup_protect_multipath = None
                                            self.is_path_best_external = None
                                            self.is_path_damped = None
                                            self.is_path_from_confederation_peer = None
                                            self.is_path_from_network_command = None
                                            self.is_path_from_redistribute_command = None
                                            self.is_path_from_route_reflector = None
                                            self.is_path_history_held = None
                                            self.is_path_imp_candidate = None
                                            self.is_path_imported = None
                                            self.is_path_local_aggregate = None
                                            self.is_path_locally_sourced = None
                                            self.is_path_long_lived_stale = None
                                            self.is_path_multipath = None
                                            self.is_path_nexthop_discarded = None
                                            self.is_path_not_advertised = None
                                            self.is_path_not_advertised_to_ebg_ps = None
                                            self.is_path_received_only = None
                                            self.is_path_reoriginated = None
                                            self.is_path_reoriginated_stitching = None
                                            self.is_path_stale = None
                                            self.is_path_synced_with_igp = None
                                            self.is_path_valid = None
                                            self.is_path_vpn_only = None
                                            self.is_permanent_path = None
                                            self.is_received_path_not_modified = None
                                            self.is_spkr_as_best = None
                                            self.l2vpn_circuit_status_value = YList()
                                            self.l2vpn_circuit_status_value.parent = self
                                            self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                            self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.L2VpnEvpnEsi()
                                            self.l2vpn_evpn_esi.parent = self
                                            self.l2vpn_size = None
                                            self.labeled_unicast_safi_path = None
                                            self.local_label = None
                                            self.local_nh = None
                                            self.local_path_id = None
                                            self.local_peers_advertised_to = YList()
                                            self.local_peers_advertised_to.parent = self
                                            self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                            self.maximum_suppress_time = None
                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self.mvpn_path_flags = None
                                            self.mvpn_pmsi_flags = None
                                            self.mvpn_pmsi_label = None
                                            self.mvpn_pmsi_type = None
                                            self.mvpn_pmsi_value = YList()
                                            self.mvpn_pmsi_value.parent = self
                                            self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                            self.mvpn_sfs_path = None
                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self.neighbor_router_id = None
                                            self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop()
                                            self.next_hop.parent = self
                                            self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhteTunnel()
                                            self.nhte_tunnel.parent = self
                                            self.path_flags = None
                                            self.path_flap_count = None
                                            self.path_import_flags = None
                                            self.path_rt_set_id = None
                                            self.path_rt_set_route_count = None
                                            self.path_table_version = None
                                            self.path_weight = None
                                            self.pe_peers_advertised_to = YList()
                                            self.pe_peers_advertised_to.parent = self
                                            self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                            self.rcvd_label = None
                                            self.rcvd_path_id = None
                                            self.reuse_value = None
                                            self.rib_failed = None
                                            self.route_type = None
                                            self.rpki_origin_as_validation_disabled = None
                                            self.rt_set_limit_enabled = None
                                            self.second_label = None
                                            self.seconds_since_first_flap = None
                                            self.show_rpki_origin_as_validity = None
                                            self.sn_rpki_origin_as_validity = None
                                            self.suppress_penalty = None
                                            self.time_to_unsuppress = None


                                        class BgpPrefix(object):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self.prefix_length = None


                                            class Prefix(object):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.prefix is not None and self.prefix._has_data():
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix']['meta_info']


                                        class NeighborAddress(object):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress']['meta_info']


                                        class NextHop(object):
                                            """
                                            Next hop
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop']['meta_info']


                                        class NhteTunnel(object):
                                            """
                                            NH TE tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_te_tunnel
                                            
                                            	NH TE Tunnel info is present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last rib update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	tunnel name
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	tunnel type
                                            	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.binding_label = None
                                                self.has_te_tunnel = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.is_tunnel_up = None
                                                self.last_tunnel_update = None
                                                self.tunnel_if_handle = None
                                                self.tunnel_name = None
                                                self.tunnel_type = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_v6_required = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.binding_label is not None:
                                                    return True

                                                if self.has_te_tunnel is not None:
                                                    return True

                                                if self.is_tunnel_info_stale is not None:
                                                    return True

                                                if self.is_tunnel_registered is not None:
                                                    return True

                                                if self.is_tunnel_up is not None:
                                                    return True

                                                if self.last_tunnel_update is not None:
                                                    return True

                                                if self.tunnel_if_handle is not None:
                                                    return True

                                                if self.tunnel_name is not None:
                                                    return True

                                                if self.tunnel_type is not None:
                                                    return True

                                                if self.tunnel_v6_enabled is not None:
                                                    return True

                                                if self.tunnel_v6_required is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhteTunnel']['meta_info']


                                        class MdtGroupAddr(object):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr']['meta_info']


                                        class L2VpnEvpnEsi(object):
                                            """
                                            L2VPN EVPN ESI
                                            
                                            .. attribute:: esi
                                            
                                            	esi
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.esi = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.esi is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.L2VpnEvpnEsi']['meta_info']


                                        class GwAddr(object):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.len = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.len is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.GwAddr']['meta_info']


                                        class BestPathCompWinner(object):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner']['meta_info']


                                        class MvpnNbrAddr(object):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr']['meta_info']


                                        class MvpnNexthopAddr(object):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr']['meta_info']


                                        class L2VpnCircuitStatusValue(object):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                        class MvpnPmsiValue(object):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue']['meta_info']


                                        class ExtendedCommunity(object):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity']['meta_info']


                                        class LocalPeersAdvertisedTo(object):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                        class PePeersAdvertisedTo(object):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo']['meta_info']


                                        class BestPathOrrBitfield(object):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield']['meta_info']


                                        class AddPathOrrBitfield(object):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.accept_own_path is not None:
                                                return True

                                            if self.accept_own_self_originated_p_ath is not None:
                                                return True

                                            if self.add_path_orr_bitfield is not None:
                                                for child_ref in self.add_path_orr_bitfield:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.advertisedto_pe is not None:
                                                return True

                                            if self.aigp_metric is not None:
                                                return True

                                            if self.best_path_comp_stage is not None:
                                                return True

                                            if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                return True

                                            if self.best_path_id is not None:
                                                return True

                                            if self.best_path_id_comp_winner is not None:
                                                return True

                                            if self.best_path_orr_bitfield is not None:
                                                for child_ref in self.best_path_orr_bitfield:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                return True

                                            if self.dampen_penalty is not None:
                                                return True

                                            if self.extended_community is not None:
                                                for child_ref in self.extended_community:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.fspec_invalid_path is not None:
                                                return True

                                            if self.graceful_shutdown is not None:
                                                return True

                                            if self.gw_addr is not None and self.gw_addr._has_data():
                                                return True

                                            if self.halflife_time is not None:
                                                return True

                                            if self.has_esi is not None:
                                                return True

                                            if self.has_gw_addr is not None:
                                                return True

                                            if self.has_local_net_label is not None:
                                                return True

                                            if self.has_mdt_group_addr is not None:
                                                return True

                                            if self.has_mvpn_extcomm is not None:
                                                return True

                                            if self.has_mvpn_nbr_addr is not None:
                                                return True

                                            if self.has_mvpn_nexthop_addr is not None:
                                                return True

                                            if self.has_mvpn_pmsi is not None:
                                                return True

                                            if self.has_rcvd_label is not None:
                                                return True

                                            if self.has_second_label is not None:
                                                return True

                                            if self.ibgp_signaled_validity is not None:
                                                return True

                                            if self.igp_metric is not None:
                                                return True

                                            if self.is_aggregation_suppressed is not None:
                                                return True

                                            if self.is_as_best is not None:
                                                return True

                                            if self.is_best_path is not None:
                                                return True

                                            if self.is_import_dampened is not None:
                                                return True

                                            if self.is_import_suspect is not None:
                                                return True

                                            if self.is_internal_path is not None:
                                                return True

                                            if self.is_partial_best is not None:
                                                return True

                                            if self.is_path_additional_path is not None:
                                                return True

                                            if self.is_path_advertised_local_as_only is not None:
                                                return True

                                            if self.is_path_af_install_eligible is not None:
                                                return True

                                            if self.is_path_backup is not None:
                                                return True

                                            if self.is_path_backup_protect_multipath is not None:
                                                return True

                                            if self.is_path_best_external is not None:
                                                return True

                                            if self.is_path_damped is not None:
                                                return True

                                            if self.is_path_from_confederation_peer is not None:
                                                return True

                                            if self.is_path_from_network_command is not None:
                                                return True

                                            if self.is_path_from_redistribute_command is not None:
                                                return True

                                            if self.is_path_from_route_reflector is not None:
                                                return True

                                            if self.is_path_history_held is not None:
                                                return True

                                            if self.is_path_imp_candidate is not None:
                                                return True

                                            if self.is_path_imported is not None:
                                                return True

                                            if self.is_path_local_aggregate is not None:
                                                return True

                                            if self.is_path_locally_sourced is not None:
                                                return True

                                            if self.is_path_long_lived_stale is not None:
                                                return True

                                            if self.is_path_multipath is not None:
                                                return True

                                            if self.is_path_nexthop_discarded is not None:
                                                return True

                                            if self.is_path_not_advertised is not None:
                                                return True

                                            if self.is_path_not_advertised_to_ebg_ps is not None:
                                                return True

                                            if self.is_path_received_only is not None:
                                                return True

                                            if self.is_path_reoriginated is not None:
                                                return True

                                            if self.is_path_reoriginated_stitching is not None:
                                                return True

                                            if self.is_path_stale is not None:
                                                return True

                                            if self.is_path_synced_with_igp is not None:
                                                return True

                                            if self.is_path_valid is not None:
                                                return True

                                            if self.is_path_vpn_only is not None:
                                                return True

                                            if self.is_permanent_path is not None:
                                                return True

                                            if self.is_received_path_not_modified is not None:
                                                return True

                                            if self.is_spkr_as_best is not None:
                                                return True

                                            if self.l2vpn_circuit_status_value is not None:
                                                for child_ref in self.l2vpn_circuit_status_value:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                return True

                                            if self.l2vpn_size is not None:
                                                return True

                                            if self.labeled_unicast_safi_path is not None:
                                                return True

                                            if self.local_label is not None:
                                                return True

                                            if self.local_nh is not None:
                                                return True

                                            if self.local_path_id is not None:
                                                return True

                                            if self.local_peers_advertised_to is not None:
                                                for child_ref in self.local_peers_advertised_to:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.maximum_suppress_time is not None:
                                                return True

                                            if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                return True

                                            if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                return True

                                            if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                return True

                                            if self.mvpn_path_flags is not None:
                                                return True

                                            if self.mvpn_pmsi_flags is not None:
                                                return True

                                            if self.mvpn_pmsi_label is not None:
                                                return True

                                            if self.mvpn_pmsi_type is not None:
                                                return True

                                            if self.mvpn_pmsi_value is not None:
                                                for child_ref in self.mvpn_pmsi_value:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.mvpn_sfs_path is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            if self.neighbor_router_id is not None:
                                                return True

                                            if self.next_hop is not None and self.next_hop._has_data():
                                                return True

                                            if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                return True

                                            if self.path_flags is not None:
                                                return True

                                            if self.path_flap_count is not None:
                                                return True

                                            if self.path_import_flags is not None:
                                                return True

                                            if self.path_rt_set_id is not None:
                                                return True

                                            if self.path_rt_set_route_count is not None:
                                                return True

                                            if self.path_table_version is not None:
                                                return True

                                            if self.path_weight is not None:
                                                return True

                                            if self.pe_peers_advertised_to is not None:
                                                for child_ref in self.pe_peers_advertised_to:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.rcvd_label is not None:
                                                return True

                                            if self.rcvd_path_id is not None:
                                                return True

                                            if self.reuse_value is not None:
                                                return True

                                            if self.rib_failed is not None:
                                                return True

                                            if self.route_type is not None:
                                                return True

                                            if self.rpki_origin_as_validation_disabled is not None:
                                                return True

                                            if self.rt_set_limit_enabled is not None:
                                                return True

                                            if self.second_label is not None:
                                                return True

                                            if self.seconds_since_first_flap is not None:
                                                return True

                                            if self.show_rpki_origin_as_validity is not None:
                                                return True

                                            if self.sn_rpki_origin_as_validity is not None:
                                                return True

                                            if self.suppress_penalty is not None:
                                                return True

                                            if self.time_to_unsuppress is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation']['meta_info']


                                    class AttributesAfterPolicyIn(object):
                                        """
                                        Attributes after inbound policy applied
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet>`
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes>`
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp>`
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr>`
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\:  bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet()
                                            self.attr_set.parent = self
                                            self.attribute_key_number = None
                                            self.attribute_reuse_id_config = None
                                            self.attribute_reuse_id_current = None
                                            self.attribute_reuse_id_keys = None
                                            self.attribute_reuse_id_max_id = None
                                            self.attribute_reuse_id_node = None
                                            self.attribute_reuse_id_recover_sec = None
                                            self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self.is_application_gateway_present = None
                                            self.is_as_path2_byte = None
                                            self.is_attr_set_present = None
                                            self.is_ribrnh_present = None
                                            self.is_rnh_present = None
                                            self.ribrnh_encap = None
                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self.ribrnh_mac = None
                                            self.ribrnh_table = None
                                            self.ribrnh_vni = None
                                            self.ribrnhip_table = None
                                            self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self.rnh_addr_len = None
                                            self.rnh_len = None
                                            self.rnh_type = None
                                            self.set_aigp_inbound_igp = None
                                            self.set_aigp_inbound_metric = None
                                            self.vpn_distinguisher = None


                                        class CommonAttributes(object):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_encap_present
                                            
                                            	Tunnel Encap attribute present 
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_policy_allocated_binding_sid
                                            
                                            	SR Policy allocated Binding sid by the router
                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                            
                                            .. attribute:: sr_policy_binding_sid
                                            
                                            	SR Policy Binding sid
                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                            
                                            .. attribute:: sr_policy_explicit_path
                                            
                                            	SR Policy Explicit paths
                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                            
                                            .. attribute:: sr_policy_preference
                                            
                                            	SR Policy Preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_tunnel_request_state
                                            
                                            	SR Tunnel Request State
                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                            
                                            .. attribute:: sr_tunnel_state
                                            
                                            	SR Tunnel State
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap_type
                                            
                                            	Tunnel Encap Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.aggregator_address = None
                                                self.aggregator_as = None
                                                self.aigp_metric_value = None
                                                self.as_path = None
                                                self.cluster = YList()
                                                self.cluster.parent = self
                                                self.cluster.name = 'cluster'
                                                self.community = YList()
                                                self.community.parent = self
                                                self.community.name = 'community'
                                                self.connector_type = None
                                                self.connector_value = YList()
                                                self.connector_value.parent = self
                                                self.connector_value.name = 'connector_value'
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.extended_community_flags = None
                                                self.is_aggregator_present = None
                                                self.is_aigp_present = None
                                                self.is_as_path_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_community_present = None
                                                self.is_connector_present = None
                                                self.is_extended_community_present = None
                                                self.is_label_index_present = None
                                                self.is_local_pref_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_metric_present = None
                                                self.is_origin_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_ssa_present = None
                                                self.is_tunnel_encap_present = None
                                                self.l2tpv3_cookie = YList()
                                                self.l2tpv3_cookie.parent = self
                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                self.l2tpv3_session_id = None
                                                self.label_index_attr = YList()
                                                self.label_index_attr.parent = self
                                                self.label_index_attr.name = 'label_index_attr'
                                                self.local_preference = None
                                                self.ls_attr = YList()
                                                self.ls_attr.parent = self
                                                self.ls_attr.name = 'ls_attr'
                                                self.metric = None
                                                self.neighbor_as = None
                                                self.origin = None
                                                self.originator = None
                                                self.pe_distinguisher_label = YList()
                                                self.pe_distinguisher_label.parent = self
                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.pmsi_type = None
                                                self.pmsi_value = YList()
                                                self.pmsi_value.parent = self
                                                self.pmsi_value.name = 'pmsi_value'
                                                self.ppm_pvalue = None
                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                self.sr_policy_allocated_binding_sid.parent = self
                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                self.sr_policy_binding_sid.parent = self
                                                self.sr_policy_explicit_path = YList()
                                                self.sr_policy_explicit_path.parent = self
                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                self.sr_policy_preference = None
                                                self.sr_tunnel_request_state = None
                                                self.sr_tunnel_state = None
                                                self.tunnel_encap_type = None
                                                self.unknown_attribute = YList()
                                                self.unknown_attribute.parent = self
                                                self.unknown_attribute.name = 'unknown_attribute'


                                            class SrPolicyBindingSid(object):
                                                """
                                                SR Policy Binding sid
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                            class SrPolicyAllocatedBindingSid(object):
                                                """
                                                SR Policy allocated Binding sid by the router
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                            class Community(object):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                            class UnknownAttribute(object):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                            class Cluster(object):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                            class L2Tpv3Cookie(object):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                            class ConnectorValue(object):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                            class PmsiValue(object):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                            class LsAttr(object):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                            class LabelIndexAttr(object):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                            class PeDistinguisherLabel(object):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.label = None
                                                    self.pe_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.label is not None:
                                                        return True

                                                    if self.pe_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                            class SrPolicyExplicitPath(object):
                                                """
                                                SR Policy Explicit paths
                                                
                                                .. attribute:: sid
                                                
                                                	Sidlist for explicit path
                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                
                                                .. attribute:: weight
                                                
                                                	Weight of explicit path
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.sid = YList()
                                                    self.sid.parent = self
                                                    self.sid.name = 'sid'
                                                    self.weight = None


                                                class Sid(object):
                                                    """
                                                    Sidlist for explicit path
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IP Address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label sid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Sid Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4 is not None:
                                                            return True

                                                        if self.ipv6 is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.sid is not None:
                                                        for child_ref in self.sid:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.weight is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.aggregator_address is not None:
                                                    return True

                                                if self.aggregator_as is not None:
                                                    return True

                                                if self.aigp_metric_value is not None:
                                                    return True

                                                if self.as_path is not None:
                                                    return True

                                                if self.cluster is not None:
                                                    for child_ref in self.cluster:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.community is not None:
                                                    for child_ref in self.community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.connector_type is not None:
                                                    return True

                                                if self.connector_value is not None:
                                                    for child_ref in self.connector_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community_flags is not None:
                                                    return True

                                                if self.is_aggregator_present is not None:
                                                    return True

                                                if self.is_aigp_present is not None:
                                                    return True

                                                if self.is_as_path_present is not None:
                                                    return True

                                                if self.is_atomic_aggregate_present is not None:
                                                    return True

                                                if self.is_community_present is not None:
                                                    return True

                                                if self.is_connector_present is not None:
                                                    return True

                                                if self.is_extended_community_present is not None:
                                                    return True

                                                if self.is_label_index_present is not None:
                                                    return True

                                                if self.is_local_pref_present is not None:
                                                    return True

                                                if self.is_ls_attribute_present is not None:
                                                    return True

                                                if self.is_metric_present is not None:
                                                    return True

                                                if self.is_origin_present is not None:
                                                    return True

                                                if self.is_pe_distinguisher_label_present is not None:
                                                    return True

                                                if self.is_pmsi_present is not None:
                                                    return True

                                                if self.is_pppmp_present is not None:
                                                    return True

                                                if self.is_ssa_present is not None:
                                                    return True

                                                if self.is_tunnel_encap_present is not None:
                                                    return True

                                                if self.l2tpv3_cookie is not None:
                                                    for child_ref in self.l2tpv3_cookie:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2tpv3_session_id is not None:
                                                    return True

                                                if self.label_index_attr is not None:
                                                    for child_ref in self.label_index_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_preference is not None:
                                                    return True

                                                if self.ls_attr is not None:
                                                    for child_ref in self.ls_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.metric is not None:
                                                    return True

                                                if self.neighbor_as is not None:
                                                    return True

                                                if self.origin is not None:
                                                    return True

                                                if self.originator is not None:
                                                    return True

                                                if self.pe_distinguisher_label is not None:
                                                    for child_ref in self.pe_distinguisher_label:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.pmsi_flags is not None:
                                                    return True

                                                if self.pmsi_label is not None:
                                                    return True

                                                if self.pmsi_type is not None:
                                                    return True

                                                if self.pmsi_value is not None:
                                                    for child_ref in self.pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.ppm_pvalue is not None:
                                                    return True

                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_explicit_path is not None:
                                                    for child_ref in self.sr_policy_explicit_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.sr_policy_preference is not None:
                                                    return True

                                                if self.sr_tunnel_request_state is not None:
                                                    return True

                                                if self.sr_tunnel_state is not None:
                                                    return True

                                                if self.tunnel_encap_type is not None:
                                                    return True

                                                if self.unknown_attribute is not None:
                                                    for child_ref in self.unknown_attribute:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                        class AttrSet(object):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_encap_present
                                            
                                            	Tunnel Encap attribute present 
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_policy_allocated_binding_sid
                                            
                                            	SR Policy allocated Binding sid by the router
                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                            
                                            .. attribute:: sr_policy_binding_sid
                                            
                                            	SR Policy Binding sid
                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                            
                                            .. attribute:: sr_policy_explicit_path
                                            
                                            	SR Policy Explicit paths
                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                            
                                            .. attribute:: sr_policy_preference
                                            
                                            	SR Policy Preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_tunnel_request_state
                                            
                                            	SR Tunnel Request State
                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                            
                                            .. attribute:: sr_tunnel_state
                                            
                                            	SR Tunnel State
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap_type
                                            
                                            	Tunnel Encap Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.aggregator_address = None
                                                self.aggregator_as = None
                                                self.aigp_metric_value = None
                                                self.as_path = None
                                                self.cluster = YList()
                                                self.cluster.parent = self
                                                self.cluster.name = 'cluster'
                                                self.community = YList()
                                                self.community.parent = self
                                                self.community.name = 'community'
                                                self.connector_type = None
                                                self.connector_value = YList()
                                                self.connector_value.parent = self
                                                self.connector_value.name = 'connector_value'
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.extended_community_flags = None
                                                self.is_aggregator_present = None
                                                self.is_aigp_present = None
                                                self.is_as_path_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_community_present = None
                                                self.is_connector_present = None
                                                self.is_extended_community_present = None
                                                self.is_label_index_present = None
                                                self.is_local_pref_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_metric_present = None
                                                self.is_origin_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_ssa_present = None
                                                self.is_tunnel_encap_present = None
                                                self.l2tpv3_cookie = YList()
                                                self.l2tpv3_cookie.parent = self
                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                self.l2tpv3_session_id = None
                                                self.label_index_attr = YList()
                                                self.label_index_attr.parent = self
                                                self.label_index_attr.name = 'label_index_attr'
                                                self.local_preference = None
                                                self.ls_attr = YList()
                                                self.ls_attr.parent = self
                                                self.ls_attr.name = 'ls_attr'
                                                self.metric = None
                                                self.neighbor_as = None
                                                self.origin = None
                                                self.originator = None
                                                self.pe_distinguisher_label = YList()
                                                self.pe_distinguisher_label.parent = self
                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.pmsi_type = None
                                                self.pmsi_value = YList()
                                                self.pmsi_value.parent = self
                                                self.pmsi_value.name = 'pmsi_value'
                                                self.ppm_pvalue = None
                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                self.sr_policy_allocated_binding_sid.parent = self
                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                self.sr_policy_binding_sid.parent = self
                                                self.sr_policy_explicit_path = YList()
                                                self.sr_policy_explicit_path.parent = self
                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                self.sr_policy_preference = None
                                                self.sr_tunnel_request_state = None
                                                self.sr_tunnel_state = None
                                                self.tunnel_encap_type = None
                                                self.unknown_attribute = YList()
                                                self.unknown_attribute.parent = self
                                                self.unknown_attribute.name = 'unknown_attribute'


                                            class SrPolicyBindingSid(object):
                                                """
                                                SR Policy Binding sid
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                            class SrPolicyAllocatedBindingSid(object):
                                                """
                                                SR Policy allocated Binding sid by the router
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                            class Community(object):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                            class UnknownAttribute(object):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                            class Cluster(object):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                            class L2Tpv3Cookie(object):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                            class ConnectorValue(object):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                            class PmsiValue(object):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                            class LsAttr(object):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                            class LabelIndexAttr(object):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                            class PeDistinguisherLabel(object):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.label = None
                                                    self.pe_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.label is not None:
                                                        return True

                                                    if self.pe_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                            class SrPolicyExplicitPath(object):
                                                """
                                                SR Policy Explicit paths
                                                
                                                .. attribute:: sid
                                                
                                                	Sidlist for explicit path
                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                
                                                .. attribute:: weight
                                                
                                                	Weight of explicit path
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.sid = YList()
                                                    self.sid.parent = self
                                                    self.sid.name = 'sid'
                                                    self.weight = None


                                                class Sid(object):
                                                    """
                                                    Sidlist for explicit path
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IP Address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label sid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Sid Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4 is not None:
                                                            return True

                                                        if self.ipv6 is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.sid is not None:
                                                        for child_ref in self.sid:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.weight is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.aggregator_address is not None:
                                                    return True

                                                if self.aggregator_as is not None:
                                                    return True

                                                if self.aigp_metric_value is not None:
                                                    return True

                                                if self.as_path is not None:
                                                    return True

                                                if self.cluster is not None:
                                                    for child_ref in self.cluster:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.community is not None:
                                                    for child_ref in self.community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.connector_type is not None:
                                                    return True

                                                if self.connector_value is not None:
                                                    for child_ref in self.connector_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community_flags is not None:
                                                    return True

                                                if self.is_aggregator_present is not None:
                                                    return True

                                                if self.is_aigp_present is not None:
                                                    return True

                                                if self.is_as_path_present is not None:
                                                    return True

                                                if self.is_atomic_aggregate_present is not None:
                                                    return True

                                                if self.is_community_present is not None:
                                                    return True

                                                if self.is_connector_present is not None:
                                                    return True

                                                if self.is_extended_community_present is not None:
                                                    return True

                                                if self.is_label_index_present is not None:
                                                    return True

                                                if self.is_local_pref_present is not None:
                                                    return True

                                                if self.is_ls_attribute_present is not None:
                                                    return True

                                                if self.is_metric_present is not None:
                                                    return True

                                                if self.is_origin_present is not None:
                                                    return True

                                                if self.is_pe_distinguisher_label_present is not None:
                                                    return True

                                                if self.is_pmsi_present is not None:
                                                    return True

                                                if self.is_pppmp_present is not None:
                                                    return True

                                                if self.is_ssa_present is not None:
                                                    return True

                                                if self.is_tunnel_encap_present is not None:
                                                    return True

                                                if self.l2tpv3_cookie is not None:
                                                    for child_ref in self.l2tpv3_cookie:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2tpv3_session_id is not None:
                                                    return True

                                                if self.label_index_attr is not None:
                                                    for child_ref in self.label_index_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_preference is not None:
                                                    return True

                                                if self.ls_attr is not None:
                                                    for child_ref in self.ls_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.metric is not None:
                                                    return True

                                                if self.neighbor_as is not None:
                                                    return True

                                                if self.origin is not None:
                                                    return True

                                                if self.originator is not None:
                                                    return True

                                                if self.pe_distinguisher_label is not None:
                                                    for child_ref in self.pe_distinguisher_label:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.pmsi_flags is not None:
                                                    return True

                                                if self.pmsi_label is not None:
                                                    return True

                                                if self.pmsi_type is not None:
                                                    return True

                                                if self.pmsi_value is not None:
                                                    for child_ref in self.pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.ppm_pvalue is not None:
                                                    return True

                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_explicit_path is not None:
                                                    for child_ref in self.sr_policy_explicit_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.sr_policy_preference is not None:
                                                    return True

                                                if self.sr_tunnel_request_state is not None:
                                                    return True

                                                if self.sr_tunnel_state is not None:
                                                    return True

                                                if self.tunnel_encap_type is not None:
                                                    return True

                                                if self.unknown_attribute is not None:
                                                    for child_ref in self.unknown_attribute:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                        class RnhAddr(object):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.len = None
                                                self.mac_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.len is not None:
                                                    return True

                                                if self.mac_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                        class RibrnhIp(object):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.attr_set is not None and self.attr_set._has_data():
                                                return True

                                            if self.attribute_key_number is not None:
                                                return True

                                            if self.attribute_reuse_id_config is not None:
                                                return True

                                            if self.attribute_reuse_id_current is not None:
                                                return True

                                            if self.attribute_reuse_id_keys is not None:
                                                return True

                                            if self.attribute_reuse_id_max_id is not None:
                                                return True

                                            if self.attribute_reuse_id_node is not None:
                                                return True

                                            if self.attribute_reuse_id_recover_sec is not None:
                                                return True

                                            if self.common_attributes is not None and self.common_attributes._has_data():
                                                return True

                                            if self.is_application_gateway_present is not None:
                                                return True

                                            if self.is_as_path2_byte is not None:
                                                return True

                                            if self.is_attr_set_present is not None:
                                                return True

                                            if self.is_ribrnh_present is not None:
                                                return True

                                            if self.is_rnh_present is not None:
                                                return True

                                            if self.ribrnh_encap is not None:
                                                return True

                                            if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                return True

                                            if self.ribrnh_mac is not None:
                                                return True

                                            if self.ribrnh_table is not None:
                                                return True

                                            if self.ribrnh_vni is not None:
                                                return True

                                            if self.ribrnhip_table is not None:
                                                return True

                                            if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                return True

                                            if self.rnh_addr_len is not None:
                                                return True

                                            if self.rnh_len is not None:
                                                return True

                                            if self.rnh_type is not None:
                                                return True

                                            if self.set_aigp_inbound_igp is not None:
                                                return True

                                            if self.set_aigp_inbound_metric is not None:
                                                return True

                                            if self.vpn_distinguisher is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                            return True

                                        if self.label_fail is not None:
                                            return True

                                        if self.label_o_or_version is not None:
                                            return True

                                        if self.label_oor is not None:
                                            return True

                                        if self.neighbor_address is not None:
                                            return True

                                        if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                            return True

                                        if self.network is not None:
                                            return True

                                        if self.no_path is not None:
                                            return True

                                        if self.path_id is not None:
                                            return True

                                        if self.path_information is not None and self.path_information._has_data():
                                            return True

                                        if self.prefix_length is not None:
                                            return True

                                        if self.prefix_version is not None:
                                            return True

                                        if self.process_instance_id is not None:
                                            return True

                                        if self.rd is not None:
                                            return True

                                        if self.route_distinguisher is not None:
                                            return True

                                        if self.route_type is not None:
                                            return True

                                        if self.source_rd is not None:
                                            return True

                                        if self.source_route_distinguisher is not None:
                                            return True

                                        if self.source_vrf_name is not None:
                                            return True

                                        if self.srcaf_name is not None:
                                            return True

                                        if self.vrf_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-table'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.path is not None:
                                        for child_ref in self.path:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable']['meta_info']


                            class Epes(object):
                                """
                                The BGP Egress Engineering table
                                
                                .. attribute:: epe
                                
                                	A BGP Egress Engineering table entry
                                	**type**\: list of    :py:class:`Epe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.epe = YList()
                                    self.epe.parent = self
                                    self.epe.name = 'epe'


                                class Epe(object):
                                    """
                                    A BGP Egress Engineering table entry
                                    
                                    .. attribute:: epe_flags
                                    
                                    	EPE object's flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: epe_key
                                    
                                    	Key of EPE object
                                    	**type**\: list of    :py:class:`EpeKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeKey>`
                                    
                                    .. attribute:: epe_key_length
                                    
                                    	Epe Key Length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: epe_key_length_xr
                                    
                                    	EPE key length in bits
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: epe_local_address
                                    
                                    	Local address
                                    	**type**\:   :py:class:`EpeLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress>`
                                    
                                    .. attribute:: epe_local_asn
                                    
                                    	Local AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: epe_local_router_id
                                    
                                    	Local router id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: epe_next_hop
                                    
                                    	Nexthop address
                                    	**type**\:   :py:class:`EpeNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop>`
                                    
                                    .. attribute:: epe_remote_asn
                                    
                                    	Remote AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: epe_remote_router_id
                                    
                                    	Remote router id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: epe_set_key
                                    
                                    	Epe Set Key
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: epe_version
                                    
                                    	EPE object's version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: first_hop
                                    
                                    	List of firsthops of EPE
                                    	**type**\: list of    :py:class:`FirstHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop>`
                                    
                                    .. attribute:: ifhandle
                                    
                                    	List of ifhandle of EPE
                                    	**type**\: list of    :py:class:`Ifhandle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.Ifhandle>`
                                    
                                    .. attribute:: label
                                    
                                    	Label assigned to the RPCnext\-hop set
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nexthop_id
                                    
                                    	List of nexthop ID of EPE
                                    	**type**\: list of    :py:class:`NexthopId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.NexthopId>`
                                    
                                    .. attribute:: ref_count
                                    
                                    	Refcount
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.epe_flags = None
                                        self.epe_key = YList()
                                        self.epe_key.parent = self
                                        self.epe_key.name = 'epe_key'
                                        self.epe_key_length = None
                                        self.epe_key_length_xr = None
                                        self.epe_local_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress()
                                        self.epe_local_address.parent = self
                                        self.epe_local_asn = None
                                        self.epe_local_router_id = None
                                        self.epe_next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop()
                                        self.epe_next_hop.parent = self
                                        self.epe_remote_asn = None
                                        self.epe_remote_router_id = None
                                        self.epe_set_key = None
                                        self.epe_version = None
                                        self.first_hop = YList()
                                        self.first_hop.parent = self
                                        self.first_hop.name = 'first_hop'
                                        self.ifhandle = YList()
                                        self.ifhandle.parent = self
                                        self.ifhandle.name = 'ifhandle'
                                        self.label = None
                                        self.nexthop_id = YList()
                                        self.nexthop_id.parent = self
                                        self.nexthop_id.name = 'nexthop_id'
                                        self.ref_count = None


                                    class EpeLocalAddress(object):
                                        """
                                        Local address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:epe-local-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress']['meta_info']


                                    class EpeNextHop(object):
                                        """
                                        Nexthop address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:epe-next-hop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop']['meta_info']


                                    class EpeKey(object):
                                        """
                                        Key of EPE object
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.entry = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:epe-key'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.entry is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeKey']['meta_info']


                                    class NexthopId(object):
                                        """
                                        List of nexthop ID of EPE
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.entry = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-id'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.entry is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.NexthopId']['meta_info']


                                    class Ifhandle(object):
                                        """
                                        List of ifhandle of EPE
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.entry = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ifhandle'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.entry is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.Ifhandle']['meta_info']


                                    class FirstHop(object):
                                        """
                                        List of firsthops of EPE
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-hop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:epe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.epe_flags is not None:
                                            return True

                                        if self.epe_key is not None:
                                            for child_ref in self.epe_key:
                                                if child_ref._has_data():
                                                    return True

                                        if self.epe_key_length is not None:
                                            return True

                                        if self.epe_key_length_xr is not None:
                                            return True

                                        if self.epe_local_address is not None and self.epe_local_address._has_data():
                                            return True

                                        if self.epe_local_asn is not None:
                                            return True

                                        if self.epe_local_router_id is not None:
                                            return True

                                        if self.epe_next_hop is not None and self.epe_next_hop._has_data():
                                            return True

                                        if self.epe_remote_asn is not None:
                                            return True

                                        if self.epe_remote_router_id is not None:
                                            return True

                                        if self.epe_set_key is not None:
                                            return True

                                        if self.epe_version is not None:
                                            return True

                                        if self.first_hop is not None:
                                            for child_ref in self.first_hop:
                                                if child_ref._has_data():
                                                    return True

                                        if self.ifhandle is not None:
                                            for child_ref in self.ifhandle:
                                                if child_ref._has_data():
                                                    return True

                                        if self.label is not None:
                                            return True

                                        if self.nexthop_id is not None:
                                            for child_ref in self.nexthop_id:
                                                if child_ref._has_data():
                                                    return True

                                        if self.ref_count is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:epes'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.epe is not None:
                                        for child_ref in self.epe:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes']['meta_info']


                            class AdvertisedPathCounts(object):
                                """
                                The BGP Advertised paths table (bestpath)
                                
                                .. attribute:: advertised_path_count
                                
                                	The BGP Advertised path table Count (bestpath)
                                	**type**\: list of    :py:class:`AdvertisedPathCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.advertised_path_count = YList()
                                    self.advertised_path_count.parent = self
                                    self.advertised_path_count.name = 'advertised_path_count'


                                class AdvertisedPathCount(object):
                                    """
                                    The BGP Advertised path table Count
                                    (bestpath)
                                    
                                    .. attribute:: neighbor_address  <key>
                                    
                                    	Neighbor address
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: max_prefix_advertisedcount
                                    
                                    	Number of prefixes advertsied to neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.neighbor_address = None
                                        self.max_prefix_advertisedcount = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.neighbor_address is None:
                                            raise YPYModelError('Key property neighbor_address is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertised-path-count[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address = ' + str(self.neighbor_address) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.neighbor_address is not None:
                                            return True

                                        if self.max_prefix_advertisedcount is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertised-path-counts'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.advertised_path_count is not None:
                                        for child_ref in self.advertised_path_count:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathCounts']['meta_info']


                            class PathLabeledTable(object):
                                """
                                The BGP Path Labeled Table
                                
                                .. attribute:: path
                                
                                	A BGP path table entry
                                	**type**\: list of    :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.path = YList()
                                    self.path.parent = self
                                    self.path.name = 'path'


                                class Path(object):
                                    """
                                    A BGP path table entry
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: attributes_after_policy_in
                                    
                                    	Attributes after inbound policy applied
                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn>`
                                    
                                    .. attribute:: label_fail
                                    
                                    	LSD label allocation failed 
                                    	**type**\:  bool
                                    
                                    .. attribute:: label_o_or_version
                                    
                                    	Label Version when OOR happens
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_oor
                                    
                                    	LSD label space is exhausted
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor adddress
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr>`
                                    
                                    .. attribute:: network
                                    
                                    	Network Prefix in Hex format
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: no_path
                                    
                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_id
                                    
                                    	Received Path ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: path_information
                                    
                                    	Path information
                                    	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: prefix_version
                                    
                                    	Version of BGP Prefix Table
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: route_type
                                    
                                    	Route Type
                                    	**type**\:   :py:class:`BgpRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRouteEnum>`
                                    
                                    .. attribute:: source_rd
                                    
                                    	Source Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: source_route_distinguisher
                                    
                                    	Source Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_vrf_name
                                    
                                    	Name of the source VRF
                                    	**type**\:  str
                                    
                                    .. attribute:: srcaf_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn()
                                        self.attributes_after_policy_in.parent = self
                                        self.label_fail = None
                                        self.label_o_or_version = None
                                        self.label_oor = None
                                        self.neighbor_address = None
                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr()
                                        self.neighbor_address_xr.parent = self
                                        self.network = None
                                        self.no_path = None
                                        self.path_id = None
                                        self.path_information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation()
                                        self.path_information.parent = self
                                        self.prefix_length = None
                                        self.prefix_version = None
                                        self.process_instance_id = None
                                        self.rd = None
                                        self.route_distinguisher = None
                                        self.route_type = None
                                        self.source_rd = None
                                        self.source_route_distinguisher = None
                                        self.source_vrf_name = None
                                        self.srcaf_name = None
                                        self.vrf_name = None


                                    class NeighborAddressXr(object):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr']['meta_info']


                                    class PathInformation(object):
                                        """
                                        Path information
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_own_self_originated_p_ath
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\:  bool
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield>`
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner>`
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix>`
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity>`
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\:  bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\:  bool
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr>`
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_esi
                                        
                                        	Path has EVPN ESI
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_rcvd_label
                                        
                                        	Path has received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\:  bool
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebg_ps
                                        
                                        	Not advertised to EBGPs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2VpnCircuitStatusValue>`
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2VpnEvpnEsi>`
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr>`
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue>`
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress>`
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop>`
                                        
                                        .. attribute:: nhte_tunnel
                                        
                                        	NH TE tunnel information
                                        	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhteTunnel>`
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\:  bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.accept_own_path = None
                                            self.accept_own_self_originated_p_ath = None
                                            self.add_path_orr_bitfield = YList()
                                            self.add_path_orr_bitfield.parent = self
                                            self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                            self.advertisedto_pe = None
                                            self.aigp_metric = None
                                            self.best_path_comp_stage = None
                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self.best_path_id = None
                                            self.best_path_id_comp_winner = None
                                            self.best_path_orr_bitfield = YList()
                                            self.best_path_orr_bitfield.parent = self
                                            self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self.dampen_penalty = None
                                            self.extended_community = YList()
                                            self.extended_community.parent = self
                                            self.extended_community.name = 'extended_community'
                                            self.fspec_invalid_path = None
                                            self.graceful_shutdown = None
                                            self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr()
                                            self.gw_addr.parent = self
                                            self.halflife_time = None
                                            self.has_esi = None
                                            self.has_gw_addr = None
                                            self.has_local_net_label = None
                                            self.has_mdt_group_addr = None
                                            self.has_mvpn_extcomm = None
                                            self.has_mvpn_nbr_addr = None
                                            self.has_mvpn_nexthop_addr = None
                                            self.has_mvpn_pmsi = None
                                            self.has_rcvd_label = None
                                            self.has_second_label = None
                                            self.ibgp_signaled_validity = None
                                            self.igp_metric = None
                                            self.is_aggregation_suppressed = None
                                            self.is_as_best = None
                                            self.is_best_path = None
                                            self.is_import_dampened = None
                                            self.is_import_suspect = None
                                            self.is_internal_path = None
                                            self.is_partial_best = None
                                            self.is_path_additional_path = None
                                            self.is_path_advertised_local_as_only = None
                                            self.is_path_af_install_eligible = None
                                            self.is_path_backup = None
                                            self.is_path_backup_protect_multipath = None
                                            self.is_path_best_external = None
                                            self.is_path_damped = None
                                            self.is_path_from_confederation_peer = None
                                            self.is_path_from_network_command = None
                                            self.is_path_from_redistribute_command = None
                                            self.is_path_from_route_reflector = None
                                            self.is_path_history_held = None
                                            self.is_path_imp_candidate = None
                                            self.is_path_imported = None
                                            self.is_path_local_aggregate = None
                                            self.is_path_locally_sourced = None
                                            self.is_path_long_lived_stale = None
                                            self.is_path_multipath = None
                                            self.is_path_nexthop_discarded = None
                                            self.is_path_not_advertised = None
                                            self.is_path_not_advertised_to_ebg_ps = None
                                            self.is_path_received_only = None
                                            self.is_path_reoriginated = None
                                            self.is_path_reoriginated_stitching = None
                                            self.is_path_stale = None
                                            self.is_path_synced_with_igp = None
                                            self.is_path_valid = None
                                            self.is_path_vpn_only = None
                                            self.is_permanent_path = None
                                            self.is_received_path_not_modified = None
                                            self.is_spkr_as_best = None
                                            self.l2vpn_circuit_status_value = YList()
                                            self.l2vpn_circuit_status_value.parent = self
                                            self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                            self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2VpnEvpnEsi()
                                            self.l2vpn_evpn_esi.parent = self
                                            self.l2vpn_size = None
                                            self.labeled_unicast_safi_path = None
                                            self.local_label = None
                                            self.local_nh = None
                                            self.local_path_id = None
                                            self.local_peers_advertised_to = YList()
                                            self.local_peers_advertised_to.parent = self
                                            self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                            self.maximum_suppress_time = None
                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self.mvpn_path_flags = None
                                            self.mvpn_pmsi_flags = None
                                            self.mvpn_pmsi_label = None
                                            self.mvpn_pmsi_type = None
                                            self.mvpn_pmsi_value = YList()
                                            self.mvpn_pmsi_value.parent = self
                                            self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                            self.mvpn_sfs_path = None
                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self.neighbor_router_id = None
                                            self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop()
                                            self.next_hop.parent = self
                                            self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhteTunnel()
                                            self.nhte_tunnel.parent = self
                                            self.path_flags = None
                                            self.path_flap_count = None
                                            self.path_import_flags = None
                                            self.path_rt_set_id = None
                                            self.path_rt_set_route_count = None
                                            self.path_table_version = None
                                            self.path_weight = None
                                            self.pe_peers_advertised_to = YList()
                                            self.pe_peers_advertised_to.parent = self
                                            self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                            self.rcvd_label = None
                                            self.rcvd_path_id = None
                                            self.reuse_value = None
                                            self.rib_failed = None
                                            self.route_type = None
                                            self.rpki_origin_as_validation_disabled = None
                                            self.rt_set_limit_enabled = None
                                            self.second_label = None
                                            self.seconds_since_first_flap = None
                                            self.show_rpki_origin_as_validity = None
                                            self.sn_rpki_origin_as_validity = None
                                            self.suppress_penalty = None
                                            self.time_to_unsuppress = None


                                        class BgpPrefix(object):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self.prefix_length = None


                                            class Prefix(object):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.prefix is not None and self.prefix._has_data():
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix']['meta_info']


                                        class NeighborAddress(object):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress']['meta_info']


                                        class NextHop(object):
                                            """
                                            Next hop
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop']['meta_info']


                                        class NhteTunnel(object):
                                            """
                                            NH TE tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_te_tunnel
                                            
                                            	NH TE Tunnel info is present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last rib update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	tunnel name
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	tunnel type
                                            	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.binding_label = None
                                                self.has_te_tunnel = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.is_tunnel_up = None
                                                self.last_tunnel_update = None
                                                self.tunnel_if_handle = None
                                                self.tunnel_name = None
                                                self.tunnel_type = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_v6_required = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.binding_label is not None:
                                                    return True

                                                if self.has_te_tunnel is not None:
                                                    return True

                                                if self.is_tunnel_info_stale is not None:
                                                    return True

                                                if self.is_tunnel_registered is not None:
                                                    return True

                                                if self.is_tunnel_up is not None:
                                                    return True

                                                if self.last_tunnel_update is not None:
                                                    return True

                                                if self.tunnel_if_handle is not None:
                                                    return True

                                                if self.tunnel_name is not None:
                                                    return True

                                                if self.tunnel_type is not None:
                                                    return True

                                                if self.tunnel_v6_enabled is not None:
                                                    return True

                                                if self.tunnel_v6_required is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhteTunnel']['meta_info']


                                        class MdtGroupAddr(object):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr']['meta_info']


                                        class L2VpnEvpnEsi(object):
                                            """
                                            L2VPN EVPN ESI
                                            
                                            .. attribute:: esi
                                            
                                            	esi
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.esi = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.esi is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2VpnEvpnEsi']['meta_info']


                                        class GwAddr(object):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.len = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.len is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr']['meta_info']


                                        class BestPathCompWinner(object):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner']['meta_info']


                                        class MvpnNbrAddr(object):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr']['meta_info']


                                        class MvpnNexthopAddr(object):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr']['meta_info']


                                        class L2VpnCircuitStatusValue(object):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                        class MvpnPmsiValue(object):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue']['meta_info']


                                        class ExtendedCommunity(object):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity']['meta_info']


                                        class LocalPeersAdvertisedTo(object):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                        class PePeersAdvertisedTo(object):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo']['meta_info']


                                        class BestPathOrrBitfield(object):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield']['meta_info']


                                        class AddPathOrrBitfield(object):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.accept_own_path is not None:
                                                return True

                                            if self.accept_own_self_originated_p_ath is not None:
                                                return True

                                            if self.add_path_orr_bitfield is not None:
                                                for child_ref in self.add_path_orr_bitfield:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.advertisedto_pe is not None:
                                                return True

                                            if self.aigp_metric is not None:
                                                return True

                                            if self.best_path_comp_stage is not None:
                                                return True

                                            if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                return True

                                            if self.best_path_id is not None:
                                                return True

                                            if self.best_path_id_comp_winner is not None:
                                                return True

                                            if self.best_path_orr_bitfield is not None:
                                                for child_ref in self.best_path_orr_bitfield:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                return True

                                            if self.dampen_penalty is not None:
                                                return True

                                            if self.extended_community is not None:
                                                for child_ref in self.extended_community:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.fspec_invalid_path is not None:
                                                return True

                                            if self.graceful_shutdown is not None:
                                                return True

                                            if self.gw_addr is not None and self.gw_addr._has_data():
                                                return True

                                            if self.halflife_time is not None:
                                                return True

                                            if self.has_esi is not None:
                                                return True

                                            if self.has_gw_addr is not None:
                                                return True

                                            if self.has_local_net_label is not None:
                                                return True

                                            if self.has_mdt_group_addr is not None:
                                                return True

                                            if self.has_mvpn_extcomm is not None:
                                                return True

                                            if self.has_mvpn_nbr_addr is not None:
                                                return True

                                            if self.has_mvpn_nexthop_addr is not None:
                                                return True

                                            if self.has_mvpn_pmsi is not None:
                                                return True

                                            if self.has_rcvd_label is not None:
                                                return True

                                            if self.has_second_label is not None:
                                                return True

                                            if self.ibgp_signaled_validity is not None:
                                                return True

                                            if self.igp_metric is not None:
                                                return True

                                            if self.is_aggregation_suppressed is not None:
                                                return True

                                            if self.is_as_best is not None:
                                                return True

                                            if self.is_best_path is not None:
                                                return True

                                            if self.is_import_dampened is not None:
                                                return True

                                            if self.is_import_suspect is not None:
                                                return True

                                            if self.is_internal_path is not None:
                                                return True

                                            if self.is_partial_best is not None:
                                                return True

                                            if self.is_path_additional_path is not None:
                                                return True

                                            if self.is_path_advertised_local_as_only is not None:
                                                return True

                                            if self.is_path_af_install_eligible is not None:
                                                return True

                                            if self.is_path_backup is not None:
                                                return True

                                            if self.is_path_backup_protect_multipath is not None:
                                                return True

                                            if self.is_path_best_external is not None:
                                                return True

                                            if self.is_path_damped is not None:
                                                return True

                                            if self.is_path_from_confederation_peer is not None:
                                                return True

                                            if self.is_path_from_network_command is not None:
                                                return True

                                            if self.is_path_from_redistribute_command is not None:
                                                return True

                                            if self.is_path_from_route_reflector is not None:
                                                return True

                                            if self.is_path_history_held is not None:
                                                return True

                                            if self.is_path_imp_candidate is not None:
                                                return True

                                            if self.is_path_imported is not None:
                                                return True

                                            if self.is_path_local_aggregate is not None:
                                                return True

                                            if self.is_path_locally_sourced is not None:
                                                return True

                                            if self.is_path_long_lived_stale is not None:
                                                return True

                                            if self.is_path_multipath is not None:
                                                return True

                                            if self.is_path_nexthop_discarded is not None:
                                                return True

                                            if self.is_path_not_advertised is not None:
                                                return True

                                            if self.is_path_not_advertised_to_ebg_ps is not None:
                                                return True

                                            if self.is_path_received_only is not None:
                                                return True

                                            if self.is_path_reoriginated is not None:
                                                return True

                                            if self.is_path_reoriginated_stitching is not None:
                                                return True

                                            if self.is_path_stale is not None:
                                                return True

                                            if self.is_path_synced_with_igp is not None:
                                                return True

                                            if self.is_path_valid is not None:
                                                return True

                                            if self.is_path_vpn_only is not None:
                                                return True

                                            if self.is_permanent_path is not None:
                                                return True

                                            if self.is_received_path_not_modified is not None:
                                                return True

                                            if self.is_spkr_as_best is not None:
                                                return True

                                            if self.l2vpn_circuit_status_value is not None:
                                                for child_ref in self.l2vpn_circuit_status_value:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                return True

                                            if self.l2vpn_size is not None:
                                                return True

                                            if self.labeled_unicast_safi_path is not None:
                                                return True

                                            if self.local_label is not None:
                                                return True

                                            if self.local_nh is not None:
                                                return True

                                            if self.local_path_id is not None:
                                                return True

                                            if self.local_peers_advertised_to is not None:
                                                for child_ref in self.local_peers_advertised_to:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.maximum_suppress_time is not None:
                                                return True

                                            if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                return True

                                            if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                return True

                                            if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                return True

                                            if self.mvpn_path_flags is not None:
                                                return True

                                            if self.mvpn_pmsi_flags is not None:
                                                return True

                                            if self.mvpn_pmsi_label is not None:
                                                return True

                                            if self.mvpn_pmsi_type is not None:
                                                return True

                                            if self.mvpn_pmsi_value is not None:
                                                for child_ref in self.mvpn_pmsi_value:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.mvpn_sfs_path is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            if self.neighbor_router_id is not None:
                                                return True

                                            if self.next_hop is not None and self.next_hop._has_data():
                                                return True

                                            if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                return True

                                            if self.path_flags is not None:
                                                return True

                                            if self.path_flap_count is not None:
                                                return True

                                            if self.path_import_flags is not None:
                                                return True

                                            if self.path_rt_set_id is not None:
                                                return True

                                            if self.path_rt_set_route_count is not None:
                                                return True

                                            if self.path_table_version is not None:
                                                return True

                                            if self.path_weight is not None:
                                                return True

                                            if self.pe_peers_advertised_to is not None:
                                                for child_ref in self.pe_peers_advertised_to:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.rcvd_label is not None:
                                                return True

                                            if self.rcvd_path_id is not None:
                                                return True

                                            if self.reuse_value is not None:
                                                return True

                                            if self.rib_failed is not None:
                                                return True

                                            if self.route_type is not None:
                                                return True

                                            if self.rpki_origin_as_validation_disabled is not None:
                                                return True

                                            if self.rt_set_limit_enabled is not None:
                                                return True

                                            if self.second_label is not None:
                                                return True

                                            if self.seconds_since_first_flap is not None:
                                                return True

                                            if self.show_rpki_origin_as_validity is not None:
                                                return True

                                            if self.sn_rpki_origin_as_validity is not None:
                                                return True

                                            if self.suppress_penalty is not None:
                                                return True

                                            if self.time_to_unsuppress is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation']['meta_info']


                                    class AttributesAfterPolicyIn(object):
                                        """
                                        Attributes after inbound policy applied
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet>`
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes>`
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp>`
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr>`
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\:  bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet()
                                            self.attr_set.parent = self
                                            self.attribute_key_number = None
                                            self.attribute_reuse_id_config = None
                                            self.attribute_reuse_id_current = None
                                            self.attribute_reuse_id_keys = None
                                            self.attribute_reuse_id_max_id = None
                                            self.attribute_reuse_id_node = None
                                            self.attribute_reuse_id_recover_sec = None
                                            self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self.is_application_gateway_present = None
                                            self.is_as_path2_byte = None
                                            self.is_attr_set_present = None
                                            self.is_ribrnh_present = None
                                            self.is_rnh_present = None
                                            self.ribrnh_encap = None
                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self.ribrnh_mac = None
                                            self.ribrnh_table = None
                                            self.ribrnh_vni = None
                                            self.ribrnhip_table = None
                                            self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self.rnh_addr_len = None
                                            self.rnh_len = None
                                            self.rnh_type = None
                                            self.set_aigp_inbound_igp = None
                                            self.set_aigp_inbound_metric = None
                                            self.vpn_distinguisher = None


                                        class CommonAttributes(object):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_encap_present
                                            
                                            	Tunnel Encap attribute present 
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_policy_allocated_binding_sid
                                            
                                            	SR Policy allocated Binding sid by the router
                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                            
                                            .. attribute:: sr_policy_binding_sid
                                            
                                            	SR Policy Binding sid
                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                            
                                            .. attribute:: sr_policy_explicit_path
                                            
                                            	SR Policy Explicit paths
                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                            
                                            .. attribute:: sr_policy_preference
                                            
                                            	SR Policy Preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_tunnel_request_state
                                            
                                            	SR Tunnel Request State
                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                            
                                            .. attribute:: sr_tunnel_state
                                            
                                            	SR Tunnel State
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap_type
                                            
                                            	Tunnel Encap Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.aggregator_address = None
                                                self.aggregator_as = None
                                                self.aigp_metric_value = None
                                                self.as_path = None
                                                self.cluster = YList()
                                                self.cluster.parent = self
                                                self.cluster.name = 'cluster'
                                                self.community = YList()
                                                self.community.parent = self
                                                self.community.name = 'community'
                                                self.connector_type = None
                                                self.connector_value = YList()
                                                self.connector_value.parent = self
                                                self.connector_value.name = 'connector_value'
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.extended_community_flags = None
                                                self.is_aggregator_present = None
                                                self.is_aigp_present = None
                                                self.is_as_path_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_community_present = None
                                                self.is_connector_present = None
                                                self.is_extended_community_present = None
                                                self.is_label_index_present = None
                                                self.is_local_pref_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_metric_present = None
                                                self.is_origin_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_ssa_present = None
                                                self.is_tunnel_encap_present = None
                                                self.l2tpv3_cookie = YList()
                                                self.l2tpv3_cookie.parent = self
                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                self.l2tpv3_session_id = None
                                                self.label_index_attr = YList()
                                                self.label_index_attr.parent = self
                                                self.label_index_attr.name = 'label_index_attr'
                                                self.local_preference = None
                                                self.ls_attr = YList()
                                                self.ls_attr.parent = self
                                                self.ls_attr.name = 'ls_attr'
                                                self.metric = None
                                                self.neighbor_as = None
                                                self.origin = None
                                                self.originator = None
                                                self.pe_distinguisher_label = YList()
                                                self.pe_distinguisher_label.parent = self
                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.pmsi_type = None
                                                self.pmsi_value = YList()
                                                self.pmsi_value.parent = self
                                                self.pmsi_value.name = 'pmsi_value'
                                                self.ppm_pvalue = None
                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                self.sr_policy_allocated_binding_sid.parent = self
                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                self.sr_policy_binding_sid.parent = self
                                                self.sr_policy_explicit_path = YList()
                                                self.sr_policy_explicit_path.parent = self
                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                self.sr_policy_preference = None
                                                self.sr_tunnel_request_state = None
                                                self.sr_tunnel_state = None
                                                self.tunnel_encap_type = None
                                                self.unknown_attribute = YList()
                                                self.unknown_attribute.parent = self
                                                self.unknown_attribute.name = 'unknown_attribute'


                                            class SrPolicyBindingSid(object):
                                                """
                                                SR Policy Binding sid
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                            class SrPolicyAllocatedBindingSid(object):
                                                """
                                                SR Policy allocated Binding sid by the router
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                            class Community(object):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                            class UnknownAttribute(object):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                            class Cluster(object):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                            class L2Tpv3Cookie(object):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                            class ConnectorValue(object):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                            class PmsiValue(object):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                            class LsAttr(object):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                            class LabelIndexAttr(object):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                            class PeDistinguisherLabel(object):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.label = None
                                                    self.pe_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.label is not None:
                                                        return True

                                                    if self.pe_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                            class SrPolicyExplicitPath(object):
                                                """
                                                SR Policy Explicit paths
                                                
                                                .. attribute:: sid
                                                
                                                	Sidlist for explicit path
                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                
                                                .. attribute:: weight
                                                
                                                	Weight of explicit path
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.sid = YList()
                                                    self.sid.parent = self
                                                    self.sid.name = 'sid'
                                                    self.weight = None


                                                class Sid(object):
                                                    """
                                                    Sidlist for explicit path
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IP Address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label sid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Sid Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4 is not None:
                                                            return True

                                                        if self.ipv6 is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.sid is not None:
                                                        for child_ref in self.sid:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.weight is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.aggregator_address is not None:
                                                    return True

                                                if self.aggregator_as is not None:
                                                    return True

                                                if self.aigp_metric_value is not None:
                                                    return True

                                                if self.as_path is not None:
                                                    return True

                                                if self.cluster is not None:
                                                    for child_ref in self.cluster:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.community is not None:
                                                    for child_ref in self.community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.connector_type is not None:
                                                    return True

                                                if self.connector_value is not None:
                                                    for child_ref in self.connector_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community_flags is not None:
                                                    return True

                                                if self.is_aggregator_present is not None:
                                                    return True

                                                if self.is_aigp_present is not None:
                                                    return True

                                                if self.is_as_path_present is not None:
                                                    return True

                                                if self.is_atomic_aggregate_present is not None:
                                                    return True

                                                if self.is_community_present is not None:
                                                    return True

                                                if self.is_connector_present is not None:
                                                    return True

                                                if self.is_extended_community_present is not None:
                                                    return True

                                                if self.is_label_index_present is not None:
                                                    return True

                                                if self.is_local_pref_present is not None:
                                                    return True

                                                if self.is_ls_attribute_present is not None:
                                                    return True

                                                if self.is_metric_present is not None:
                                                    return True

                                                if self.is_origin_present is not None:
                                                    return True

                                                if self.is_pe_distinguisher_label_present is not None:
                                                    return True

                                                if self.is_pmsi_present is not None:
                                                    return True

                                                if self.is_pppmp_present is not None:
                                                    return True

                                                if self.is_ssa_present is not None:
                                                    return True

                                                if self.is_tunnel_encap_present is not None:
                                                    return True

                                                if self.l2tpv3_cookie is not None:
                                                    for child_ref in self.l2tpv3_cookie:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2tpv3_session_id is not None:
                                                    return True

                                                if self.label_index_attr is not None:
                                                    for child_ref in self.label_index_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_preference is not None:
                                                    return True

                                                if self.ls_attr is not None:
                                                    for child_ref in self.ls_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.metric is not None:
                                                    return True

                                                if self.neighbor_as is not None:
                                                    return True

                                                if self.origin is not None:
                                                    return True

                                                if self.originator is not None:
                                                    return True

                                                if self.pe_distinguisher_label is not None:
                                                    for child_ref in self.pe_distinguisher_label:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.pmsi_flags is not None:
                                                    return True

                                                if self.pmsi_label is not None:
                                                    return True

                                                if self.pmsi_type is not None:
                                                    return True

                                                if self.pmsi_value is not None:
                                                    for child_ref in self.pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.ppm_pvalue is not None:
                                                    return True

                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_explicit_path is not None:
                                                    for child_ref in self.sr_policy_explicit_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.sr_policy_preference is not None:
                                                    return True

                                                if self.sr_tunnel_request_state is not None:
                                                    return True

                                                if self.sr_tunnel_state is not None:
                                                    return True

                                                if self.tunnel_encap_type is not None:
                                                    return True

                                                if self.unknown_attribute is not None:
                                                    for child_ref in self.unknown_attribute:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                        class AttrSet(object):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_encap_present
                                            
                                            	Tunnel Encap attribute present 
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_policy_allocated_binding_sid
                                            
                                            	SR Policy allocated Binding sid by the router
                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                            
                                            .. attribute:: sr_policy_binding_sid
                                            
                                            	SR Policy Binding sid
                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                            
                                            .. attribute:: sr_policy_explicit_path
                                            
                                            	SR Policy Explicit paths
                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                            
                                            .. attribute:: sr_policy_preference
                                            
                                            	SR Policy Preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_tunnel_request_state
                                            
                                            	SR Tunnel Request State
                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                            
                                            .. attribute:: sr_tunnel_state
                                            
                                            	SR Tunnel State
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap_type
                                            
                                            	Tunnel Encap Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.aggregator_address = None
                                                self.aggregator_as = None
                                                self.aigp_metric_value = None
                                                self.as_path = None
                                                self.cluster = YList()
                                                self.cluster.parent = self
                                                self.cluster.name = 'cluster'
                                                self.community = YList()
                                                self.community.parent = self
                                                self.community.name = 'community'
                                                self.connector_type = None
                                                self.connector_value = YList()
                                                self.connector_value.parent = self
                                                self.connector_value.name = 'connector_value'
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.extended_community_flags = None
                                                self.is_aggregator_present = None
                                                self.is_aigp_present = None
                                                self.is_as_path_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_community_present = None
                                                self.is_connector_present = None
                                                self.is_extended_community_present = None
                                                self.is_label_index_present = None
                                                self.is_local_pref_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_metric_present = None
                                                self.is_origin_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_ssa_present = None
                                                self.is_tunnel_encap_present = None
                                                self.l2tpv3_cookie = YList()
                                                self.l2tpv3_cookie.parent = self
                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                self.l2tpv3_session_id = None
                                                self.label_index_attr = YList()
                                                self.label_index_attr.parent = self
                                                self.label_index_attr.name = 'label_index_attr'
                                                self.local_preference = None
                                                self.ls_attr = YList()
                                                self.ls_attr.parent = self
                                                self.ls_attr.name = 'ls_attr'
                                                self.metric = None
                                                self.neighbor_as = None
                                                self.origin = None
                                                self.originator = None
                                                self.pe_distinguisher_label = YList()
                                                self.pe_distinguisher_label.parent = self
                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.pmsi_type = None
                                                self.pmsi_value = YList()
                                                self.pmsi_value.parent = self
                                                self.pmsi_value.name = 'pmsi_value'
                                                self.ppm_pvalue = None
                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                self.sr_policy_allocated_binding_sid.parent = self
                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                self.sr_policy_binding_sid.parent = self
                                                self.sr_policy_explicit_path = YList()
                                                self.sr_policy_explicit_path.parent = self
                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                self.sr_policy_preference = None
                                                self.sr_tunnel_request_state = None
                                                self.sr_tunnel_state = None
                                                self.tunnel_encap_type = None
                                                self.unknown_attribute = YList()
                                                self.unknown_attribute.parent = self
                                                self.unknown_attribute.name = 'unknown_attribute'


                                            class SrPolicyBindingSid(object):
                                                """
                                                SR Policy Binding sid
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                            class SrPolicyAllocatedBindingSid(object):
                                                """
                                                SR Policy allocated Binding sid by the router
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                            class Community(object):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                            class UnknownAttribute(object):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                            class Cluster(object):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                            class L2Tpv3Cookie(object):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                            class ConnectorValue(object):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                            class PmsiValue(object):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                            class LsAttr(object):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                            class LabelIndexAttr(object):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                            class PeDistinguisherLabel(object):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.label = None
                                                    self.pe_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.label is not None:
                                                        return True

                                                    if self.pe_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                            class SrPolicyExplicitPath(object):
                                                """
                                                SR Policy Explicit paths
                                                
                                                .. attribute:: sid
                                                
                                                	Sidlist for explicit path
                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                
                                                .. attribute:: weight
                                                
                                                	Weight of explicit path
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.sid = YList()
                                                    self.sid.parent = self
                                                    self.sid.name = 'sid'
                                                    self.weight = None


                                                class Sid(object):
                                                    """
                                                    Sidlist for explicit path
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IP Address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label sid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Sid Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4 is not None:
                                                            return True

                                                        if self.ipv6 is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.sid is not None:
                                                        for child_ref in self.sid:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.weight is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.aggregator_address is not None:
                                                    return True

                                                if self.aggregator_as is not None:
                                                    return True

                                                if self.aigp_metric_value is not None:
                                                    return True

                                                if self.as_path is not None:
                                                    return True

                                                if self.cluster is not None:
                                                    for child_ref in self.cluster:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.community is not None:
                                                    for child_ref in self.community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.connector_type is not None:
                                                    return True

                                                if self.connector_value is not None:
                                                    for child_ref in self.connector_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community_flags is not None:
                                                    return True

                                                if self.is_aggregator_present is not None:
                                                    return True

                                                if self.is_aigp_present is not None:
                                                    return True

                                                if self.is_as_path_present is not None:
                                                    return True

                                                if self.is_atomic_aggregate_present is not None:
                                                    return True

                                                if self.is_community_present is not None:
                                                    return True

                                                if self.is_connector_present is not None:
                                                    return True

                                                if self.is_extended_community_present is not None:
                                                    return True

                                                if self.is_label_index_present is not None:
                                                    return True

                                                if self.is_local_pref_present is not None:
                                                    return True

                                                if self.is_ls_attribute_present is not None:
                                                    return True

                                                if self.is_metric_present is not None:
                                                    return True

                                                if self.is_origin_present is not None:
                                                    return True

                                                if self.is_pe_distinguisher_label_present is not None:
                                                    return True

                                                if self.is_pmsi_present is not None:
                                                    return True

                                                if self.is_pppmp_present is not None:
                                                    return True

                                                if self.is_ssa_present is not None:
                                                    return True

                                                if self.is_tunnel_encap_present is not None:
                                                    return True

                                                if self.l2tpv3_cookie is not None:
                                                    for child_ref in self.l2tpv3_cookie:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2tpv3_session_id is not None:
                                                    return True

                                                if self.label_index_attr is not None:
                                                    for child_ref in self.label_index_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_preference is not None:
                                                    return True

                                                if self.ls_attr is not None:
                                                    for child_ref in self.ls_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.metric is not None:
                                                    return True

                                                if self.neighbor_as is not None:
                                                    return True

                                                if self.origin is not None:
                                                    return True

                                                if self.originator is not None:
                                                    return True

                                                if self.pe_distinguisher_label is not None:
                                                    for child_ref in self.pe_distinguisher_label:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.pmsi_flags is not None:
                                                    return True

                                                if self.pmsi_label is not None:
                                                    return True

                                                if self.pmsi_type is not None:
                                                    return True

                                                if self.pmsi_value is not None:
                                                    for child_ref in self.pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.ppm_pvalue is not None:
                                                    return True

                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_explicit_path is not None:
                                                    for child_ref in self.sr_policy_explicit_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.sr_policy_preference is not None:
                                                    return True

                                                if self.sr_tunnel_request_state is not None:
                                                    return True

                                                if self.sr_tunnel_state is not None:
                                                    return True

                                                if self.tunnel_encap_type is not None:
                                                    return True

                                                if self.unknown_attribute is not None:
                                                    for child_ref in self.unknown_attribute:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                        class RnhAddr(object):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.len = None
                                                self.mac_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.len is not None:
                                                    return True

                                                if self.mac_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                        class RibrnhIp(object):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.attr_set is not None and self.attr_set._has_data():
                                                return True

                                            if self.attribute_key_number is not None:
                                                return True

                                            if self.attribute_reuse_id_config is not None:
                                                return True

                                            if self.attribute_reuse_id_current is not None:
                                                return True

                                            if self.attribute_reuse_id_keys is not None:
                                                return True

                                            if self.attribute_reuse_id_max_id is not None:
                                                return True

                                            if self.attribute_reuse_id_node is not None:
                                                return True

                                            if self.attribute_reuse_id_recover_sec is not None:
                                                return True

                                            if self.common_attributes is not None and self.common_attributes._has_data():
                                                return True

                                            if self.is_application_gateway_present is not None:
                                                return True

                                            if self.is_as_path2_byte is not None:
                                                return True

                                            if self.is_attr_set_present is not None:
                                                return True

                                            if self.is_ribrnh_present is not None:
                                                return True

                                            if self.is_rnh_present is not None:
                                                return True

                                            if self.ribrnh_encap is not None:
                                                return True

                                            if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                return True

                                            if self.ribrnh_mac is not None:
                                                return True

                                            if self.ribrnh_table is not None:
                                                return True

                                            if self.ribrnh_vni is not None:
                                                return True

                                            if self.ribrnhip_table is not None:
                                                return True

                                            if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                return True

                                            if self.rnh_addr_len is not None:
                                                return True

                                            if self.rnh_len is not None:
                                                return True

                                            if self.rnh_type is not None:
                                                return True

                                            if self.set_aigp_inbound_igp is not None:
                                                return True

                                            if self.set_aigp_inbound_metric is not None:
                                                return True

                                            if self.vpn_distinguisher is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                            return True

                                        if self.label_fail is not None:
                                            return True

                                        if self.label_o_or_version is not None:
                                            return True

                                        if self.label_oor is not None:
                                            return True

                                        if self.neighbor_address is not None:
                                            return True

                                        if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                            return True

                                        if self.network is not None:
                                            return True

                                        if self.no_path is not None:
                                            return True

                                        if self.path_id is not None:
                                            return True

                                        if self.path_information is not None and self.path_information._has_data():
                                            return True

                                        if self.prefix_length is not None:
                                            return True

                                        if self.prefix_version is not None:
                                            return True

                                        if self.process_instance_id is not None:
                                            return True

                                        if self.rd is not None:
                                            return True

                                        if self.route_distinguisher is not None:
                                            return True

                                        if self.route_type is not None:
                                            return True

                                        if self.source_rd is not None:
                                            return True

                                        if self.source_route_distinguisher is not None:
                                            return True

                                        if self.source_vrf_name is not None:
                                            return True

                                        if self.srcaf_name is not None:
                                            return True

                                        if self.vrf_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-labeled-table'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.path is not None:
                                        for child_ref in self.path:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable']['meta_info']


                            class AdvertisedPaths(object):
                                """
                                The BGP Advertised paths table (add\-paths)
                                
                                .. attribute:: advertised_path
                                
                                	A BGP Advertised paths table entry (add\-paths)
                                	**type**\: list of    :py:class:`AdvertisedPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.advertised_path = YList()
                                    self.advertised_path.parent = self
                                    self.advertised_path.name = 'advertised_path'


                                class AdvertisedPath(object):
                                    """
                                    A BGP Advertised paths table entry
                                    (add\-paths)
                                    
                                    .. attribute:: adv_path_info
                                    
                                    	Net Advertized Paths
                                    	**type**\: list of    :py:class:`AdvPathInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo>`
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor 
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: network
                                    
                                    	Network in hex string bytes format
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: paths
                                    
                                    	paths
                                    	**type**\: list of    :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.adv_path_info = YList()
                                        self.adv_path_info.parent = self
                                        self.adv_path_info.name = 'adv_path_info'
                                        self.neighbor_address = None
                                        self.network = None
                                        self.paths = YList()
                                        self.paths.parent = self
                                        self.paths.name = 'paths'
                                        self.prefix_length = None
                                        self.rd = None


                                    class Paths(object):
                                        """
                                        paths
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation>`
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self.label_fail = None
                                            self.label_o_or_version = None
                                            self.label_oor = None
                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self.no_path = None
                                            self.path_information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation()
                                            self.path_information.parent = self
                                            self.prefix_version = None
                                            self.process_instance_id = None
                                            self.route_distinguisher = None
                                            self.source_route_distinguisher = None
                                            self.source_vrf_name = None
                                            self.srcaf_name = None
                                            self.vrf_name = None


                                        class NeighborAddressXr(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr']['meta_info']


                                        class PathInformation(object):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_esi
                                            
                                            	Path has EVPN ESI
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_rcvd_label
                                            
                                            	Path has received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebg_ps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2VpnEvpnEsi>`
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop>`
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhteTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_p_ath = None
                                                self.add_path_orr_bitfield = YList()
                                                self.add_path_orr_bitfield.parent = self
                                                self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                self.advertisedto_pe = None
                                                self.aigp_metric = None
                                                self.best_path_comp_stage = None
                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self.best_path_id = None
                                                self.best_path_id_comp_winner = None
                                                self.best_path_orr_bitfield = YList()
                                                self.best_path_orr_bitfield.parent = self
                                                self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self.dampen_penalty = None
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.fspec_invalid_path = None
                                                self.graceful_shutdown = None
                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self.halflife_time = None
                                                self.has_esi = None
                                                self.has_gw_addr = None
                                                self.has_local_net_label = None
                                                self.has_mdt_group_addr = None
                                                self.has_mvpn_extcomm = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.has_rcvd_label = None
                                                self.has_second_label = None
                                                self.ibgp_signaled_validity = None
                                                self.igp_metric = None
                                                self.is_aggregation_suppressed = None
                                                self.is_as_best = None
                                                self.is_best_path = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_internal_path = None
                                                self.is_partial_best = None
                                                self.is_path_additional_path = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_af_install_eligible = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_damped = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_history_held = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_imported = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_multipath = None
                                                self.is_path_nexthop_discarded = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebg_ps = None
                                                self.is_path_received_only = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_stale = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_valid = None
                                                self.is_path_vpn_only = None
                                                self.is_permanent_path = None
                                                self.is_received_path_not_modified = None
                                                self.is_spkr_as_best = None
                                                self.l2vpn_circuit_status_value = YList()
                                                self.l2vpn_circuit_status_value.parent = self
                                                self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2VpnEvpnEsi()
                                                self.l2vpn_evpn_esi.parent = self
                                                self.l2vpn_size = None
                                                self.labeled_unicast_safi_path = None
                                                self.local_label = None
                                                self.local_nh = None
                                                self.local_path_id = None
                                                self.local_peers_advertised_to = YList()
                                                self.local_peers_advertised_to.parent = self
                                                self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                self.maximum_suppress_time = None
                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self.mvpn_path_flags = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_value = YList()
                                                self.mvpn_pmsi_value.parent = self
                                                self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                self.mvpn_sfs_path = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.neighbor_router_id = None
                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.path_flags = None
                                                self.path_flap_count = None
                                                self.path_import_flags = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.path_table_version = None
                                                self.path_weight = None
                                                self.pe_peers_advertised_to = YList()
                                                self.pe_peers_advertised_to.parent = self
                                                self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                self.rcvd_label = None
                                                self.rcvd_path_id = None
                                                self.reuse_value = None
                                                self.rib_failed = None
                                                self.route_type = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.rt_set_limit_enabled = None
                                                self.second_label = None
                                                self.seconds_since_first_flap = None
                                                self.show_rpki_origin_as_validity = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.suppress_penalty = None
                                                self.time_to_unsuppress = None


                                            class BgpPrefix(object):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self.prefix_length = None


                                                class Prefix(object):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.prefix is not None and self.prefix._has_data():
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix']['meta_info']


                                            class NeighborAddress(object):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress']['meta_info']


                                            class NextHop(object):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhteTunnel']['meta_info']


                                            class MdtGroupAddr(object):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr']['meta_info']


                                            class L2VpnEvpnEsi(object):
                                                """
                                                L2VPN EVPN ESI
                                                
                                                .. attribute:: esi
                                                
                                                	esi
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.esi = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.esi is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2VpnEvpnEsi']['meta_info']


                                            class GwAddr(object):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr']['meta_info']


                                            class BestPathCompWinner(object):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner']['meta_info']


                                            class MvpnNbrAddr(object):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr']['meta_info']


                                            class MvpnNexthopAddr(object):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr']['meta_info']


                                            class L2VpnCircuitStatusValue(object):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                            class MvpnPmsiValue(object):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity']['meta_info']


                                            class LocalPeersAdvertisedTo(object):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                            class PePeersAdvertisedTo(object):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo']['meta_info']


                                            class BestPathOrrBitfield(object):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield']['meta_info']


                                            class AddPathOrrBitfield(object):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.accept_own_path is not None:
                                                    return True

                                                if self.accept_own_self_originated_p_ath is not None:
                                                    return True

                                                if self.add_path_orr_bitfield is not None:
                                                    for child_ref in self.add_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.advertisedto_pe is not None:
                                                    return True

                                                if self.aigp_metric is not None:
                                                    return True

                                                if self.best_path_comp_stage is not None:
                                                    return True

                                                if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                    return True

                                                if self.best_path_id is not None:
                                                    return True

                                                if self.best_path_id_comp_winner is not None:
                                                    return True

                                                if self.best_path_orr_bitfield is not None:
                                                    for child_ref in self.best_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                    return True

                                                if self.dampen_penalty is not None:
                                                    return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.fspec_invalid_path is not None:
                                                    return True

                                                if self.graceful_shutdown is not None:
                                                    return True

                                                if self.gw_addr is not None and self.gw_addr._has_data():
                                                    return True

                                                if self.halflife_time is not None:
                                                    return True

                                                if self.has_esi is not None:
                                                    return True

                                                if self.has_gw_addr is not None:
                                                    return True

                                                if self.has_local_net_label is not None:
                                                    return True

                                                if self.has_mdt_group_addr is not None:
                                                    return True

                                                if self.has_mvpn_extcomm is not None:
                                                    return True

                                                if self.has_mvpn_nbr_addr is not None:
                                                    return True

                                                if self.has_mvpn_nexthop_addr is not None:
                                                    return True

                                                if self.has_mvpn_pmsi is not None:
                                                    return True

                                                if self.has_rcvd_label is not None:
                                                    return True

                                                if self.has_second_label is not None:
                                                    return True

                                                if self.ibgp_signaled_validity is not None:
                                                    return True

                                                if self.igp_metric is not None:
                                                    return True

                                                if self.is_aggregation_suppressed is not None:
                                                    return True

                                                if self.is_as_best is not None:
                                                    return True

                                                if self.is_best_path is not None:
                                                    return True

                                                if self.is_import_dampened is not None:
                                                    return True

                                                if self.is_import_suspect is not None:
                                                    return True

                                                if self.is_internal_path is not None:
                                                    return True

                                                if self.is_partial_best is not None:
                                                    return True

                                                if self.is_path_additional_path is not None:
                                                    return True

                                                if self.is_path_advertised_local_as_only is not None:
                                                    return True

                                                if self.is_path_af_install_eligible is not None:
                                                    return True

                                                if self.is_path_backup is not None:
                                                    return True

                                                if self.is_path_backup_protect_multipath is not None:
                                                    return True

                                                if self.is_path_best_external is not None:
                                                    return True

                                                if self.is_path_damped is not None:
                                                    return True

                                                if self.is_path_from_confederation_peer is not None:
                                                    return True

                                                if self.is_path_from_network_command is not None:
                                                    return True

                                                if self.is_path_from_redistribute_command is not None:
                                                    return True

                                                if self.is_path_from_route_reflector is not None:
                                                    return True

                                                if self.is_path_history_held is not None:
                                                    return True

                                                if self.is_path_imp_candidate is not None:
                                                    return True

                                                if self.is_path_imported is not None:
                                                    return True

                                                if self.is_path_local_aggregate is not None:
                                                    return True

                                                if self.is_path_locally_sourced is not None:
                                                    return True

                                                if self.is_path_long_lived_stale is not None:
                                                    return True

                                                if self.is_path_multipath is not None:
                                                    return True

                                                if self.is_path_nexthop_discarded is not None:
                                                    return True

                                                if self.is_path_not_advertised is not None:
                                                    return True

                                                if self.is_path_not_advertised_to_ebg_ps is not None:
                                                    return True

                                                if self.is_path_received_only is not None:
                                                    return True

                                                if self.is_path_reoriginated is not None:
                                                    return True

                                                if self.is_path_reoriginated_stitching is not None:
                                                    return True

                                                if self.is_path_stale is not None:
                                                    return True

                                                if self.is_path_synced_with_igp is not None:
                                                    return True

                                                if self.is_path_valid is not None:
                                                    return True

                                                if self.is_path_vpn_only is not None:
                                                    return True

                                                if self.is_permanent_path is not None:
                                                    return True

                                                if self.is_received_path_not_modified is not None:
                                                    return True

                                                if self.is_spkr_as_best is not None:
                                                    return True

                                                if self.l2vpn_circuit_status_value is not None:
                                                    for child_ref in self.l2vpn_circuit_status_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                    return True

                                                if self.l2vpn_size is not None:
                                                    return True

                                                if self.labeled_unicast_safi_path is not None:
                                                    return True

                                                if self.local_label is not None:
                                                    return True

                                                if self.local_nh is not None:
                                                    return True

                                                if self.local_path_id is not None:
                                                    return True

                                                if self.local_peers_advertised_to is not None:
                                                    for child_ref in self.local_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.maximum_suppress_time is not None:
                                                    return True

                                                if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                    return True

                                                if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                    return True

                                                if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                    return True

                                                if self.mvpn_path_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_label is not None:
                                                    return True

                                                if self.mvpn_pmsi_type is not None:
                                                    return True

                                                if self.mvpn_pmsi_value is not None:
                                                    for child_ref in self.mvpn_pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.mvpn_sfs_path is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.neighbor_router_id is not None:
                                                    return True

                                                if self.next_hop is not None and self.next_hop._has_data():
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.path_flags is not None:
                                                    return True

                                                if self.path_flap_count is not None:
                                                    return True

                                                if self.path_import_flags is not None:
                                                    return True

                                                if self.path_rt_set_id is not None:
                                                    return True

                                                if self.path_rt_set_route_count is not None:
                                                    return True

                                                if self.path_table_version is not None:
                                                    return True

                                                if self.path_weight is not None:
                                                    return True

                                                if self.pe_peers_advertised_to is not None:
                                                    for child_ref in self.pe_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.rcvd_label is not None:
                                                    return True

                                                if self.rcvd_path_id is not None:
                                                    return True

                                                if self.reuse_value is not None:
                                                    return True

                                                if self.rib_failed is not None:
                                                    return True

                                                if self.route_type is not None:
                                                    return True

                                                if self.rpki_origin_as_validation_disabled is not None:
                                                    return True

                                                if self.rt_set_limit_enabled is not None:
                                                    return True

                                                if self.second_label is not None:
                                                    return True

                                                if self.seconds_since_first_flap is not None:
                                                    return True

                                                if self.show_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.sn_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.suppress_penalty is not None:
                                                    return True

                                                if self.time_to_unsuppress is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation']['meta_info']


                                        class AttributesAfterPolicyIn(object):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self.is_application_gateway_present = None
                                                self.is_as_path2_byte = None
                                                self.is_attr_set_present = None
                                                self.is_ribrnh_present = None
                                                self.is_rnh_present = None
                                                self.ribrnh_encap = None
                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self.ribrnh_mac = None
                                                self.ribrnh_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnhip_table = None
                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self.rnh_addr_len = None
                                                self.rnh_len = None
                                                self.rnh_type = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.vpn_distinguisher = None


                                            class CommonAttributes(object):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                            class AttrSet(object):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                            class RnhAddr(object):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None
                                                    self.mac_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    if self.mac_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                            class RibrnhIp(object):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.attr_set is not None and self.attr_set._has_data():
                                                    return True

                                                if self.attribute_key_number is not None:
                                                    return True

                                                if self.attribute_reuse_id_config is not None:
                                                    return True

                                                if self.attribute_reuse_id_current is not None:
                                                    return True

                                                if self.attribute_reuse_id_keys is not None:
                                                    return True

                                                if self.attribute_reuse_id_max_id is not None:
                                                    return True

                                                if self.attribute_reuse_id_node is not None:
                                                    return True

                                                if self.attribute_reuse_id_recover_sec is not None:
                                                    return True

                                                if self.common_attributes is not None and self.common_attributes._has_data():
                                                    return True

                                                if self.is_application_gateway_present is not None:
                                                    return True

                                                if self.is_as_path2_byte is not None:
                                                    return True

                                                if self.is_attr_set_present is not None:
                                                    return True

                                                if self.is_ribrnh_present is not None:
                                                    return True

                                                if self.is_rnh_present is not None:
                                                    return True

                                                if self.ribrnh_encap is not None:
                                                    return True

                                                if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                    return True

                                                if self.ribrnh_mac is not None:
                                                    return True

                                                if self.ribrnh_table is not None:
                                                    return True

                                                if self.ribrnh_vni is not None:
                                                    return True

                                                if self.ribrnhip_table is not None:
                                                    return True

                                                if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                    return True

                                                if self.rnh_addr_len is not None:
                                                    return True

                                                if self.rnh_len is not None:
                                                    return True

                                                if self.rnh_type is not None:
                                                    return True

                                                if self.set_aigp_inbound_igp is not None:
                                                    return True

                                                if self.set_aigp_inbound_metric is not None:
                                                    return True

                                                if self.vpn_distinguisher is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:paths'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                return True

                                            if self.label_fail is not None:
                                                return True

                                            if self.label_o_or_version is not None:
                                                return True

                                            if self.label_oor is not None:
                                                return True

                                            if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                return True

                                            if self.no_path is not None:
                                                return True

                                            if self.path_information is not None and self.path_information._has_data():
                                                return True

                                            if self.prefix_version is not None:
                                                return True

                                            if self.process_instance_id is not None:
                                                return True

                                            if self.route_distinguisher is not None:
                                                return True

                                            if self.source_route_distinguisher is not None:
                                                return True

                                            if self.source_vrf_name is not None:
                                                return True

                                            if self.srcaf_name is not None:
                                                return True

                                            if self.vrf_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths']['meta_info']


                                    class AdvPathInfo(object):
                                        """
                                        Net Advertized Paths
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: attributes_after_policy_out
                                        
                                        	Attributes after outbound policy
                                        	**type**\:   :py:class:`AttributesAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut>`
                                        
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists All 'sp\_path\_in' fields except 'sp\_path\_in\->bag\_prefix' are invalid.  All 'sp\_path\_out' fields are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_info_after_policy_in
                                        
                                        	Path information after inbound policy
                                        	**type**\:   :py:class:`PathInfoAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn>`
                                        
                                        .. attribute:: path_info_after_policy_out
                                        
                                        	Path information after outbound policy
                                        	**type**\:   :py:class:`PathInfoAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut>`
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self.attributes_after_policy_out = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut()
                                            self.attributes_after_policy_out.parent = self
                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self.no_path = None
                                            self.path_info_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn()
                                            self.path_info_after_policy_in.parent = self
                                            self.path_info_after_policy_out = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut()
                                            self.path_info_after_policy_out.parent = self
                                            self.route_distinguisher = None
                                            self.source_route_distinguisher = None
                                            self.vrf_name = None


                                        class NeighborAddressXr(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr']['meta_info']


                                        class PathInfoAfterPolicyIn(object):
                                            """
                                            Path information after inbound policy
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_esi
                                            
                                            	Path has EVPN ESI
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_rcvd_label
                                            
                                            	Path has received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebg_ps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2VpnEvpnEsi>`
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop>`
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhteTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_p_ath = None
                                                self.add_path_orr_bitfield = YList()
                                                self.add_path_orr_bitfield.parent = self
                                                self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                self.advertisedto_pe = None
                                                self.aigp_metric = None
                                                self.best_path_comp_stage = None
                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self.best_path_id = None
                                                self.best_path_id_comp_winner = None
                                                self.best_path_orr_bitfield = YList()
                                                self.best_path_orr_bitfield.parent = self
                                                self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self.dampen_penalty = None
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.fspec_invalid_path = None
                                                self.graceful_shutdown = None
                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr()
                                                self.gw_addr.parent = self
                                                self.halflife_time = None
                                                self.has_esi = None
                                                self.has_gw_addr = None
                                                self.has_local_net_label = None
                                                self.has_mdt_group_addr = None
                                                self.has_mvpn_extcomm = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.has_rcvd_label = None
                                                self.has_second_label = None
                                                self.ibgp_signaled_validity = None
                                                self.igp_metric = None
                                                self.is_aggregation_suppressed = None
                                                self.is_as_best = None
                                                self.is_best_path = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_internal_path = None
                                                self.is_partial_best = None
                                                self.is_path_additional_path = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_af_install_eligible = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_damped = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_history_held = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_imported = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_multipath = None
                                                self.is_path_nexthop_discarded = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebg_ps = None
                                                self.is_path_received_only = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_stale = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_valid = None
                                                self.is_path_vpn_only = None
                                                self.is_permanent_path = None
                                                self.is_received_path_not_modified = None
                                                self.is_spkr_as_best = None
                                                self.l2vpn_circuit_status_value = YList()
                                                self.l2vpn_circuit_status_value.parent = self
                                                self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2VpnEvpnEsi()
                                                self.l2vpn_evpn_esi.parent = self
                                                self.l2vpn_size = None
                                                self.labeled_unicast_safi_path = None
                                                self.local_label = None
                                                self.local_nh = None
                                                self.local_path_id = None
                                                self.local_peers_advertised_to = YList()
                                                self.local_peers_advertised_to.parent = self
                                                self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                self.maximum_suppress_time = None
                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self.mvpn_path_flags = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_value = YList()
                                                self.mvpn_pmsi_value.parent = self
                                                self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                self.mvpn_sfs_path = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.neighbor_router_id = None
                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop()
                                                self.next_hop.parent = self
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.path_flags = None
                                                self.path_flap_count = None
                                                self.path_import_flags = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.path_table_version = None
                                                self.path_weight = None
                                                self.pe_peers_advertised_to = YList()
                                                self.pe_peers_advertised_to.parent = self
                                                self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                self.rcvd_label = None
                                                self.rcvd_path_id = None
                                                self.reuse_value = None
                                                self.rib_failed = None
                                                self.route_type = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.rt_set_limit_enabled = None
                                                self.second_label = None
                                                self.seconds_since_first_flap = None
                                                self.show_rpki_origin_as_validity = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.suppress_penalty = None
                                                self.time_to_unsuppress = None


                                            class BgpPrefix(object):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self.prefix_length = None


                                                class Prefix(object):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.prefix is not None and self.prefix._has_data():
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix']['meta_info']


                                            class NeighborAddress(object):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress']['meta_info']


                                            class NextHop(object):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhteTunnel']['meta_info']


                                            class MdtGroupAddr(object):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr']['meta_info']


                                            class L2VpnEvpnEsi(object):
                                                """
                                                L2VPN EVPN ESI
                                                
                                                .. attribute:: esi
                                                
                                                	esi
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.esi = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.esi is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2VpnEvpnEsi']['meta_info']


                                            class GwAddr(object):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr']['meta_info']


                                            class BestPathCompWinner(object):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner']['meta_info']


                                            class MvpnNbrAddr(object):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr']['meta_info']


                                            class MvpnNexthopAddr(object):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr']['meta_info']


                                            class L2VpnCircuitStatusValue(object):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue']['meta_info']


                                            class MvpnPmsiValue(object):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity']['meta_info']


                                            class LocalPeersAdvertisedTo(object):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo']['meta_info']


                                            class PePeersAdvertisedTo(object):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo']['meta_info']


                                            class BestPathOrrBitfield(object):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield']['meta_info']


                                            class AddPathOrrBitfield(object):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-info-after-policy-in'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.accept_own_path is not None:
                                                    return True

                                                if self.accept_own_self_originated_p_ath is not None:
                                                    return True

                                                if self.add_path_orr_bitfield is not None:
                                                    for child_ref in self.add_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.advertisedto_pe is not None:
                                                    return True

                                                if self.aigp_metric is not None:
                                                    return True

                                                if self.best_path_comp_stage is not None:
                                                    return True

                                                if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                    return True

                                                if self.best_path_id is not None:
                                                    return True

                                                if self.best_path_id_comp_winner is not None:
                                                    return True

                                                if self.best_path_orr_bitfield is not None:
                                                    for child_ref in self.best_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                    return True

                                                if self.dampen_penalty is not None:
                                                    return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.fspec_invalid_path is not None:
                                                    return True

                                                if self.graceful_shutdown is not None:
                                                    return True

                                                if self.gw_addr is not None and self.gw_addr._has_data():
                                                    return True

                                                if self.halflife_time is not None:
                                                    return True

                                                if self.has_esi is not None:
                                                    return True

                                                if self.has_gw_addr is not None:
                                                    return True

                                                if self.has_local_net_label is not None:
                                                    return True

                                                if self.has_mdt_group_addr is not None:
                                                    return True

                                                if self.has_mvpn_extcomm is not None:
                                                    return True

                                                if self.has_mvpn_nbr_addr is not None:
                                                    return True

                                                if self.has_mvpn_nexthop_addr is not None:
                                                    return True

                                                if self.has_mvpn_pmsi is not None:
                                                    return True

                                                if self.has_rcvd_label is not None:
                                                    return True

                                                if self.has_second_label is not None:
                                                    return True

                                                if self.ibgp_signaled_validity is not None:
                                                    return True

                                                if self.igp_metric is not None:
                                                    return True

                                                if self.is_aggregation_suppressed is not None:
                                                    return True

                                                if self.is_as_best is not None:
                                                    return True

                                                if self.is_best_path is not None:
                                                    return True

                                                if self.is_import_dampened is not None:
                                                    return True

                                                if self.is_import_suspect is not None:
                                                    return True

                                                if self.is_internal_path is not None:
                                                    return True

                                                if self.is_partial_best is not None:
                                                    return True

                                                if self.is_path_additional_path is not None:
                                                    return True

                                                if self.is_path_advertised_local_as_only is not None:
                                                    return True

                                                if self.is_path_af_install_eligible is not None:
                                                    return True

                                                if self.is_path_backup is not None:
                                                    return True

                                                if self.is_path_backup_protect_multipath is not None:
                                                    return True

                                                if self.is_path_best_external is not None:
                                                    return True

                                                if self.is_path_damped is not None:
                                                    return True

                                                if self.is_path_from_confederation_peer is not None:
                                                    return True

                                                if self.is_path_from_network_command is not None:
                                                    return True

                                                if self.is_path_from_redistribute_command is not None:
                                                    return True

                                                if self.is_path_from_route_reflector is not None:
                                                    return True

                                                if self.is_path_history_held is not None:
                                                    return True

                                                if self.is_path_imp_candidate is not None:
                                                    return True

                                                if self.is_path_imported is not None:
                                                    return True

                                                if self.is_path_local_aggregate is not None:
                                                    return True

                                                if self.is_path_locally_sourced is not None:
                                                    return True

                                                if self.is_path_long_lived_stale is not None:
                                                    return True

                                                if self.is_path_multipath is not None:
                                                    return True

                                                if self.is_path_nexthop_discarded is not None:
                                                    return True

                                                if self.is_path_not_advertised is not None:
                                                    return True

                                                if self.is_path_not_advertised_to_ebg_ps is not None:
                                                    return True

                                                if self.is_path_received_only is not None:
                                                    return True

                                                if self.is_path_reoriginated is not None:
                                                    return True

                                                if self.is_path_reoriginated_stitching is not None:
                                                    return True

                                                if self.is_path_stale is not None:
                                                    return True

                                                if self.is_path_synced_with_igp is not None:
                                                    return True

                                                if self.is_path_valid is not None:
                                                    return True

                                                if self.is_path_vpn_only is not None:
                                                    return True

                                                if self.is_permanent_path is not None:
                                                    return True

                                                if self.is_received_path_not_modified is not None:
                                                    return True

                                                if self.is_spkr_as_best is not None:
                                                    return True

                                                if self.l2vpn_circuit_status_value is not None:
                                                    for child_ref in self.l2vpn_circuit_status_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                    return True

                                                if self.l2vpn_size is not None:
                                                    return True

                                                if self.labeled_unicast_safi_path is not None:
                                                    return True

                                                if self.local_label is not None:
                                                    return True

                                                if self.local_nh is not None:
                                                    return True

                                                if self.local_path_id is not None:
                                                    return True

                                                if self.local_peers_advertised_to is not None:
                                                    for child_ref in self.local_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.maximum_suppress_time is not None:
                                                    return True

                                                if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                    return True

                                                if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                    return True

                                                if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                    return True

                                                if self.mvpn_path_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_label is not None:
                                                    return True

                                                if self.mvpn_pmsi_type is not None:
                                                    return True

                                                if self.mvpn_pmsi_value is not None:
                                                    for child_ref in self.mvpn_pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.mvpn_sfs_path is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.neighbor_router_id is not None:
                                                    return True

                                                if self.next_hop is not None and self.next_hop._has_data():
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.path_flags is not None:
                                                    return True

                                                if self.path_flap_count is not None:
                                                    return True

                                                if self.path_import_flags is not None:
                                                    return True

                                                if self.path_rt_set_id is not None:
                                                    return True

                                                if self.path_rt_set_route_count is not None:
                                                    return True

                                                if self.path_table_version is not None:
                                                    return True

                                                if self.path_weight is not None:
                                                    return True

                                                if self.pe_peers_advertised_to is not None:
                                                    for child_ref in self.pe_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.rcvd_label is not None:
                                                    return True

                                                if self.rcvd_path_id is not None:
                                                    return True

                                                if self.reuse_value is not None:
                                                    return True

                                                if self.rib_failed is not None:
                                                    return True

                                                if self.route_type is not None:
                                                    return True

                                                if self.rpki_origin_as_validation_disabled is not None:
                                                    return True

                                                if self.rt_set_limit_enabled is not None:
                                                    return True

                                                if self.second_label is not None:
                                                    return True

                                                if self.seconds_since_first_flap is not None:
                                                    return True

                                                if self.show_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.sn_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.suppress_penalty is not None:
                                                    return True

                                                if self.time_to_unsuppress is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn']['meta_info']


                                        class PathInfoAfterPolicyOut(object):
                                            """
                                            Path information after outbound policy
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_esi
                                            
                                            	Path has EVPN ESI
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_rcvd_label
                                            
                                            	Path has received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebg_ps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2VpnEvpnEsi>`
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop>`
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhteTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_p_ath = None
                                                self.add_path_orr_bitfield = YList()
                                                self.add_path_orr_bitfield.parent = self
                                                self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                self.advertisedto_pe = None
                                                self.aigp_metric = None
                                                self.best_path_comp_stage = None
                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self.best_path_id = None
                                                self.best_path_id_comp_winner = None
                                                self.best_path_orr_bitfield = YList()
                                                self.best_path_orr_bitfield.parent = self
                                                self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self.dampen_penalty = None
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.fspec_invalid_path = None
                                                self.graceful_shutdown = None
                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr()
                                                self.gw_addr.parent = self
                                                self.halflife_time = None
                                                self.has_esi = None
                                                self.has_gw_addr = None
                                                self.has_local_net_label = None
                                                self.has_mdt_group_addr = None
                                                self.has_mvpn_extcomm = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.has_rcvd_label = None
                                                self.has_second_label = None
                                                self.ibgp_signaled_validity = None
                                                self.igp_metric = None
                                                self.is_aggregation_suppressed = None
                                                self.is_as_best = None
                                                self.is_best_path = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_internal_path = None
                                                self.is_partial_best = None
                                                self.is_path_additional_path = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_af_install_eligible = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_damped = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_history_held = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_imported = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_multipath = None
                                                self.is_path_nexthop_discarded = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebg_ps = None
                                                self.is_path_received_only = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_stale = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_valid = None
                                                self.is_path_vpn_only = None
                                                self.is_permanent_path = None
                                                self.is_received_path_not_modified = None
                                                self.is_spkr_as_best = None
                                                self.l2vpn_circuit_status_value = YList()
                                                self.l2vpn_circuit_status_value.parent = self
                                                self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2VpnEvpnEsi()
                                                self.l2vpn_evpn_esi.parent = self
                                                self.l2vpn_size = None
                                                self.labeled_unicast_safi_path = None
                                                self.local_label = None
                                                self.local_nh = None
                                                self.local_path_id = None
                                                self.local_peers_advertised_to = YList()
                                                self.local_peers_advertised_to.parent = self
                                                self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                self.maximum_suppress_time = None
                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self.mvpn_path_flags = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_value = YList()
                                                self.mvpn_pmsi_value.parent = self
                                                self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                self.mvpn_sfs_path = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.neighbor_router_id = None
                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop()
                                                self.next_hop.parent = self
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.path_flags = None
                                                self.path_flap_count = None
                                                self.path_import_flags = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.path_table_version = None
                                                self.path_weight = None
                                                self.pe_peers_advertised_to = YList()
                                                self.pe_peers_advertised_to.parent = self
                                                self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                self.rcvd_label = None
                                                self.rcvd_path_id = None
                                                self.reuse_value = None
                                                self.rib_failed = None
                                                self.route_type = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.rt_set_limit_enabled = None
                                                self.second_label = None
                                                self.seconds_since_first_flap = None
                                                self.show_rpki_origin_as_validity = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.suppress_penalty = None
                                                self.time_to_unsuppress = None


                                            class BgpPrefix(object):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self.prefix_length = None


                                                class Prefix(object):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.prefix is not None and self.prefix._has_data():
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix']['meta_info']


                                            class NeighborAddress(object):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress']['meta_info']


                                            class NextHop(object):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhteTunnel']['meta_info']


                                            class MdtGroupAddr(object):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr']['meta_info']


                                            class L2VpnEvpnEsi(object):
                                                """
                                                L2VPN EVPN ESI
                                                
                                                .. attribute:: esi
                                                
                                                	esi
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.esi = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.esi is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2VpnEvpnEsi']['meta_info']


                                            class GwAddr(object):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr']['meta_info']


                                            class BestPathCompWinner(object):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner']['meta_info']


                                            class MvpnNbrAddr(object):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr']['meta_info']


                                            class MvpnNexthopAddr(object):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr']['meta_info']


                                            class L2VpnCircuitStatusValue(object):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue']['meta_info']


                                            class MvpnPmsiValue(object):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity']['meta_info']


                                            class LocalPeersAdvertisedTo(object):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo']['meta_info']


                                            class PePeersAdvertisedTo(object):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo']['meta_info']


                                            class BestPathOrrBitfield(object):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield']['meta_info']


                                            class AddPathOrrBitfield(object):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-info-after-policy-out'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.accept_own_path is not None:
                                                    return True

                                                if self.accept_own_self_originated_p_ath is not None:
                                                    return True

                                                if self.add_path_orr_bitfield is not None:
                                                    for child_ref in self.add_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.advertisedto_pe is not None:
                                                    return True

                                                if self.aigp_metric is not None:
                                                    return True

                                                if self.best_path_comp_stage is not None:
                                                    return True

                                                if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                    return True

                                                if self.best_path_id is not None:
                                                    return True

                                                if self.best_path_id_comp_winner is not None:
                                                    return True

                                                if self.best_path_orr_bitfield is not None:
                                                    for child_ref in self.best_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                    return True

                                                if self.dampen_penalty is not None:
                                                    return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.fspec_invalid_path is not None:
                                                    return True

                                                if self.graceful_shutdown is not None:
                                                    return True

                                                if self.gw_addr is not None and self.gw_addr._has_data():
                                                    return True

                                                if self.halflife_time is not None:
                                                    return True

                                                if self.has_esi is not None:
                                                    return True

                                                if self.has_gw_addr is not None:
                                                    return True

                                                if self.has_local_net_label is not None:
                                                    return True

                                                if self.has_mdt_group_addr is not None:
                                                    return True

                                                if self.has_mvpn_extcomm is not None:
                                                    return True

                                                if self.has_mvpn_nbr_addr is not None:
                                                    return True

                                                if self.has_mvpn_nexthop_addr is not None:
                                                    return True

                                                if self.has_mvpn_pmsi is not None:
                                                    return True

                                                if self.has_rcvd_label is not None:
                                                    return True

                                                if self.has_second_label is not None:
                                                    return True

                                                if self.ibgp_signaled_validity is not None:
                                                    return True

                                                if self.igp_metric is not None:
                                                    return True

                                                if self.is_aggregation_suppressed is not None:
                                                    return True

                                                if self.is_as_best is not None:
                                                    return True

                                                if self.is_best_path is not None:
                                                    return True

                                                if self.is_import_dampened is not None:
                                                    return True

                                                if self.is_import_suspect is not None:
                                                    return True

                                                if self.is_internal_path is not None:
                                                    return True

                                                if self.is_partial_best is not None:
                                                    return True

                                                if self.is_path_additional_path is not None:
                                                    return True

                                                if self.is_path_advertised_local_as_only is not None:
                                                    return True

                                                if self.is_path_af_install_eligible is not None:
                                                    return True

                                                if self.is_path_backup is not None:
                                                    return True

                                                if self.is_path_backup_protect_multipath is not None:
                                                    return True

                                                if self.is_path_best_external is not None:
                                                    return True

                                                if self.is_path_damped is not None:
                                                    return True

                                                if self.is_path_from_confederation_peer is not None:
                                                    return True

                                                if self.is_path_from_network_command is not None:
                                                    return True

                                                if self.is_path_from_redistribute_command is not None:
                                                    return True

                                                if self.is_path_from_route_reflector is not None:
                                                    return True

                                                if self.is_path_history_held is not None:
                                                    return True

                                                if self.is_path_imp_candidate is not None:
                                                    return True

                                                if self.is_path_imported is not None:
                                                    return True

                                                if self.is_path_local_aggregate is not None:
                                                    return True

                                                if self.is_path_locally_sourced is not None:
                                                    return True

                                                if self.is_path_long_lived_stale is not None:
                                                    return True

                                                if self.is_path_multipath is not None:
                                                    return True

                                                if self.is_path_nexthop_discarded is not None:
                                                    return True

                                                if self.is_path_not_advertised is not None:
                                                    return True

                                                if self.is_path_not_advertised_to_ebg_ps is not None:
                                                    return True

                                                if self.is_path_received_only is not None:
                                                    return True

                                                if self.is_path_reoriginated is not None:
                                                    return True

                                                if self.is_path_reoriginated_stitching is not None:
                                                    return True

                                                if self.is_path_stale is not None:
                                                    return True

                                                if self.is_path_synced_with_igp is not None:
                                                    return True

                                                if self.is_path_valid is not None:
                                                    return True

                                                if self.is_path_vpn_only is not None:
                                                    return True

                                                if self.is_permanent_path is not None:
                                                    return True

                                                if self.is_received_path_not_modified is not None:
                                                    return True

                                                if self.is_spkr_as_best is not None:
                                                    return True

                                                if self.l2vpn_circuit_status_value is not None:
                                                    for child_ref in self.l2vpn_circuit_status_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                    return True

                                                if self.l2vpn_size is not None:
                                                    return True

                                                if self.labeled_unicast_safi_path is not None:
                                                    return True

                                                if self.local_label is not None:
                                                    return True

                                                if self.local_nh is not None:
                                                    return True

                                                if self.local_path_id is not None:
                                                    return True

                                                if self.local_peers_advertised_to is not None:
                                                    for child_ref in self.local_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.maximum_suppress_time is not None:
                                                    return True

                                                if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                    return True

                                                if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                    return True

                                                if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                    return True

                                                if self.mvpn_path_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_label is not None:
                                                    return True

                                                if self.mvpn_pmsi_type is not None:
                                                    return True

                                                if self.mvpn_pmsi_value is not None:
                                                    for child_ref in self.mvpn_pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.mvpn_sfs_path is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.neighbor_router_id is not None:
                                                    return True

                                                if self.next_hop is not None and self.next_hop._has_data():
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.path_flags is not None:
                                                    return True

                                                if self.path_flap_count is not None:
                                                    return True

                                                if self.path_import_flags is not None:
                                                    return True

                                                if self.path_rt_set_id is not None:
                                                    return True

                                                if self.path_rt_set_route_count is not None:
                                                    return True

                                                if self.path_table_version is not None:
                                                    return True

                                                if self.path_weight is not None:
                                                    return True

                                                if self.pe_peers_advertised_to is not None:
                                                    for child_ref in self.pe_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.rcvd_label is not None:
                                                    return True

                                                if self.rcvd_path_id is not None:
                                                    return True

                                                if self.reuse_value is not None:
                                                    return True

                                                if self.rib_failed is not None:
                                                    return True

                                                if self.route_type is not None:
                                                    return True

                                                if self.rpki_origin_as_validation_disabled is not None:
                                                    return True

                                                if self.rt_set_limit_enabled is not None:
                                                    return True

                                                if self.second_label is not None:
                                                    return True

                                                if self.seconds_since_first_flap is not None:
                                                    return True

                                                if self.show_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.sn_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.suppress_penalty is not None:
                                                    return True

                                                if self.time_to_unsuppress is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut']['meta_info']


                                        class AttributesAfterPolicyIn(object):
                                            """
                                            Attributes after inbound policy
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self.is_application_gateway_present = None
                                                self.is_as_path2_byte = None
                                                self.is_attr_set_present = None
                                                self.is_ribrnh_present = None
                                                self.is_rnh_present = None
                                                self.ribrnh_encap = None
                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self.ribrnh_mac = None
                                                self.ribrnh_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnhip_table = None
                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self.rnh_addr_len = None
                                                self.rnh_len = None
                                                self.rnh_type = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.vpn_distinguisher = None


                                            class CommonAttributes(object):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                            class AttrSet(object):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                            class RnhAddr(object):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None
                                                    self.mac_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    if self.mac_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                            class RibrnhIp(object):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.attr_set is not None and self.attr_set._has_data():
                                                    return True

                                                if self.attribute_key_number is not None:
                                                    return True

                                                if self.attribute_reuse_id_config is not None:
                                                    return True

                                                if self.attribute_reuse_id_current is not None:
                                                    return True

                                                if self.attribute_reuse_id_keys is not None:
                                                    return True

                                                if self.attribute_reuse_id_max_id is not None:
                                                    return True

                                                if self.attribute_reuse_id_node is not None:
                                                    return True

                                                if self.attribute_reuse_id_recover_sec is not None:
                                                    return True

                                                if self.common_attributes is not None and self.common_attributes._has_data():
                                                    return True

                                                if self.is_application_gateway_present is not None:
                                                    return True

                                                if self.is_as_path2_byte is not None:
                                                    return True

                                                if self.is_attr_set_present is not None:
                                                    return True

                                                if self.is_ribrnh_present is not None:
                                                    return True

                                                if self.is_rnh_present is not None:
                                                    return True

                                                if self.ribrnh_encap is not None:
                                                    return True

                                                if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                    return True

                                                if self.ribrnh_mac is not None:
                                                    return True

                                                if self.ribrnh_table is not None:
                                                    return True

                                                if self.ribrnh_vni is not None:
                                                    return True

                                                if self.ribrnhip_table is not None:
                                                    return True

                                                if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                    return True

                                                if self.rnh_addr_len is not None:
                                                    return True

                                                if self.rnh_len is not None:
                                                    return True

                                                if self.rnh_type is not None:
                                                    return True

                                                if self.set_aigp_inbound_igp is not None:
                                                    return True

                                                if self.set_aigp_inbound_metric is not None:
                                                    return True

                                                if self.vpn_distinguisher is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn']['meta_info']


                                        class AttributesAfterPolicyOut(object):
                                            """
                                            Attributes after outbound policy
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet()
                                                self.attr_set.parent = self
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self.is_application_gateway_present = None
                                                self.is_as_path2_byte = None
                                                self.is_attr_set_present = None
                                                self.is_ribrnh_present = None
                                                self.is_rnh_present = None
                                                self.ribrnh_encap = None
                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self.ribrnh_mac = None
                                                self.ribrnh_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnhip_table = None
                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self.rnh_addr_len = None
                                                self.rnh_len = None
                                                self.rnh_type = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.vpn_distinguisher = None


                                            class CommonAttributes(object):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes']['meta_info']


                                            class AttrSet(object):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet']['meta_info']


                                            class RnhAddr(object):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None
                                                    self.mac_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    if self.mac_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr']['meta_info']


                                            class RibrnhIp(object):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-out'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.attr_set is not None and self.attr_set._has_data():
                                                    return True

                                                if self.attribute_key_number is not None:
                                                    return True

                                                if self.attribute_reuse_id_config is not None:
                                                    return True

                                                if self.attribute_reuse_id_current is not None:
                                                    return True

                                                if self.attribute_reuse_id_keys is not None:
                                                    return True

                                                if self.attribute_reuse_id_max_id is not None:
                                                    return True

                                                if self.attribute_reuse_id_node is not None:
                                                    return True

                                                if self.attribute_reuse_id_recover_sec is not None:
                                                    return True

                                                if self.common_attributes is not None and self.common_attributes._has_data():
                                                    return True

                                                if self.is_application_gateway_present is not None:
                                                    return True

                                                if self.is_as_path2_byte is not None:
                                                    return True

                                                if self.is_attr_set_present is not None:
                                                    return True

                                                if self.is_ribrnh_present is not None:
                                                    return True

                                                if self.is_rnh_present is not None:
                                                    return True

                                                if self.ribrnh_encap is not None:
                                                    return True

                                                if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                    return True

                                                if self.ribrnh_mac is not None:
                                                    return True

                                                if self.ribrnh_table is not None:
                                                    return True

                                                if self.ribrnh_vni is not None:
                                                    return True

                                                if self.ribrnhip_table is not None:
                                                    return True

                                                if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                    return True

                                                if self.rnh_addr_len is not None:
                                                    return True

                                                if self.rnh_len is not None:
                                                    return True

                                                if self.rnh_type is not None:
                                                    return True

                                                if self.set_aigp_inbound_igp is not None:
                                                    return True

                                                if self.set_aigp_inbound_metric is not None:
                                                    return True

                                                if self.vpn_distinguisher is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:adv-path-info'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                return True

                                            if self.attributes_after_policy_out is not None and self.attributes_after_policy_out._has_data():
                                                return True

                                            if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                return True

                                            if self.no_path is not None:
                                                return True

                                            if self.path_info_after_policy_in is not None and self.path_info_after_policy_in._has_data():
                                                return True

                                            if self.path_info_after_policy_out is not None and self.path_info_after_policy_out._has_data():
                                                return True

                                            if self.route_distinguisher is not None:
                                                return True

                                            if self.source_route_distinguisher is not None:
                                                return True

                                            if self.vrf_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertised-path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.adv_path_info is not None:
                                            for child_ref in self.adv_path_info:
                                                if child_ref._has_data():
                                                    return True

                                        if self.neighbor_address is not None:
                                            return True

                                        if self.network is not None:
                                            return True

                                        if self.paths is not None:
                                            for child_ref in self.paths:
                                                if child_ref._has_data():
                                                    return True

                                        if self.prefix_length is not None:
                                            return True

                                        if self.rd is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertised-paths'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.advertised_path is not None:
                                        for child_ref in self.advertised_path:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths']['meta_info']


                            class NeighborAfTable(object):
                                """
                                The BGP Neighbor AF table
                                
                                .. attribute:: neighbor
                                
                                	A BGP Neighbor table entry
                                	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.neighbor = YList()
                                    self.neighbor.parent = self
                                    self.neighbor.name = 'neighbor'


                                class Neighbor(object):
                                    """
                                    A BGP Neighbor table entry
                                    
                                    .. attribute:: neighbor_address  <key>
                                    
                                    	Neighbor address
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: active_bmp_servers
                                    
                                    	BMP Servers to which the neighbor sends logs
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: actual_last_write_bytes
                                    
                                    	Actual size of last write
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: actual_last_write_reset_bytes
                                    
                                    	Actual size of last write before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: actual_second_last_write_bytes
                                    
                                    	Actual size of second last write
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: actual_second_last_write_reset_bytes
                                    
                                    	Actual size of second last write before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: af_data
                                    
                                    	Address family specific neighbor data
                                    	**type**\: list of    :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData>`
                                    
                                    .. attribute:: attempted_last_write_bytes
                                    
                                    	Attempted size of last write
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: attempted_last_write_reset_bytes
                                    
                                    	Attempted size of last write before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: attempted_second_last_write_bytes
                                    
                                    	Attempted size of second last write
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: attempted_second_last_write_reset_bytes
                                    
                                    	Attempted size of second last write before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_minintervalval
                                    
                                    	BFD Mininterval for this peer
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_multiplierval
                                    
                                    	BFD Multiplier for this peer
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_session_created_state
                                    
                                    	BFD state for this peer
                                    	**type**\:   :py:class:`BgpBfdStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdStateEnum>`
                                    
                                    .. attribute:: bfd_session_enable_mode
                                    
                                    	BFD enable mode for this peer
                                    	**type**\:   :py:class:`BgpBfdEnableModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdEnableModeEnum>`
                                    
                                    .. attribute:: bfd_session_state
                                    
                                    	BFD state for this peer
                                    	**type**\:   :py:class:`BgpBfdStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdStateEnum>`
                                    
                                    .. attribute:: bfd_state_ts
                                    
                                    	Timestamp since when nbr is in this bfd state
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bytes_read
                                    
                                    	Total bytes read
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: bytes_written
                                    
                                    	Total bytes written by write thread
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: configured_hold_time
                                    
                                    	Hold time (in secs) configured for this connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: configured_keepalive
                                    
                                    	Keepalive time (in secs) configured for this connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: configured_min_acc_hold_time
                                    
                                    	Minimum acceptable hold time from neighbor (in secs) configured for this connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: connect_retry_interval
                                    
                                    	Time (in secs) for connect retry timer
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: connection_admin_status
                                    
                                    	Administrative status of connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: connection_down_count
                                    
                                    	Number of times connection was dropped
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: connection_established_time
                                    
                                    	Time (in secs) that the connection has been established
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: connection_local_address
                                    
                                    	Local address for the connection
                                    	**type**\:   :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress>`
                                    
                                    .. attribute:: connection_local_port
                                    
                                    	Local port for the connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: connection_remote_address
                                    
                                    	Remote address for the connection
                                    	**type**\:   :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress>`
                                    
                                    .. attribute:: connection_remote_port
                                    
                                    	Remote port for the connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: connection_state
                                    
                                    	State of connection
                                    	**type**\:   :py:class:`BgpConnStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnStateEnum>`
                                    
                                    .. attribute:: connection_up_count
                                    
                                    	Number of times the connection was established
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: count_last_write
                                    
                                    	Count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: description
                                    
                                    	Description
                                    	**type**\:  str
                                    
                                    .. attribute:: discard_as4_path
                                    
                                    	Discard AS4\_PATH in case there is a discrepancy in merging AS\_PATH and AS4\_PATH,retain ASPATH
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: discard_data_bytes
                                    
                                    	Remaining discard data (bytes) on Standby
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: dmz_link_bandwidth
                                    
                                    	Bandwidth of link to single\-hop eBGP peer
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: dynamic_neighbor
                                    
                                    	Dynamic neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: ebgp_recv_dmz
                                    
                                    	Receive Bandwidth of link to single\-hop eBGP peer
                                    	**type**\:  bool
                                    
                                    .. attribute:: ebgp_send_dmz_mode
                                    
                                    	Ebgp send dmz link bw mode
                                    	**type**\:   :py:class:`BgpEbgpSendDmzEnableModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableModeEnum>`
                                    
                                    .. attribute:: ebgp_time_to_live
                                    
                                    	Maximum number of hops for external BGP neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: egress_peer_engineering_enabled
                                    
                                    	Indicates if Egress Peer Engineering is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: error_notifies_received
                                    
                                    	Number of error notifications received on the connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: error_notifies_sent
                                    
                                    	Number of error notifications sent on the connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fpbsn_offset
                                    
                                    	First standby PDU boundary SeqNo offset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fssn_offset
                                    
                                    	First standby SeqNo offset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: gr_restart_time
                                    
                                    	Neighbor restart time (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: gr_stale_path_time
                                    
                                    	Neighbor stale\-path time (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: graceful_maintenance
                                    
                                    	Graceful Maintenance
                                    	**type**\:   :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance>`
                                    
                                    .. attribute:: graceful_restart_enabled_nbr
                                    
                                    	Neighbor supports graceful\-restart
                                    	**type**\:  bool
                                    
                                    .. attribute:: has_internal_link
                                    
                                    	Internal link to neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: hold_time
                                    
                                    	Hold time (in secs) negotiated for this connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: ignore_connected
                                    
                                    	If true, the VPN client isan IBGP CE peer
                                    	**type**\:  bool
                                    
                                    .. attribute:: internal_vpn_client
                                    
                                    	If true, don't do NHconnected check for nbr
                                    	**type**\:  bool
                                    
                                    .. attribute:: io_armed
                                    
                                    	If true, socket has beenauto\-armed for io control
                                    	**type**\:  bool
                                    
                                    .. attribute:: is4_byte_as_capability_received
                                    
                                    	4\-byte AScapability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is4_byte_as_capability_sent
                                    
                                    	4\-byte AScapability Snt
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_administratively_shut_down
                                    
                                    	Neighbor is administratively shut down
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_capability_negotiation_performed
                                    
                                    	Capability negotiation performed
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_capability_negotiation_suppressed
                                    
                                    	Capability negotiation suppressed
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ebgp_multihop_bgpmpls_forwarding_disabled
                                    
                                    	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ebgp_peer_as_league
                                    
                                    	EBGP peer belongs to AS League
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ebgp_peer_common_admin
                                    
                                    	EBGP peer with common administation
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_external_neighbor_not_directly_connected
                                    
                                    	External neighbor not directly connected
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_gr_aware
                                    
                                    	GR awareness received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_local_address_configured
                                    
                                    	Local address configured for the neighbor connection
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_max_prefix_shutdown
                                    
                                    	Neighbor shut down because it exceeded max prfx count
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_out_of_memory_forced_up
                                    
                                    	Neighbor forced up during a low memory condition
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_out_of_memory_shutdown
                                    
                                    	Neighbor shut down during a SEVERE low memory condition
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_passive_close
                                    
                                    	If true, active socket canbe closed if passive openis received for a GRcapable neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_read_disabled
                                    
                                    	If true, socket read isdisabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_route_refresh_capability_received
                                    
                                    	Route refresh capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_route_refresh_old_capability_received
                                    
                                    	Route refresh old capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: keep_alive_time
                                    
                                    	Keepalive time (in secs) negotiated for this connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_ackd_seq_no
                                    
                                    	SeqNo of the last Ackd byte
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_k_aerror_reset
                                    
                                    	Duration (in secs) since last time that an error was encountered after KA expiry
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_k_aexpiry_reset
                                    
                                    	Time (in secs) since last KA timer expiry before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_k_anotsent_reset
                                    
                                    	Duration (in secs) since last time that KA was not sent before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_k_astart_reset
                                    
                                    	Time (in secs) since the last KA timer start before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_notify_error_code
                                    
                                    	Code for the last error notification seen on the connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: last_notify_error_subcode
                                    
                                    	Error subcode of the last error notification seen on the connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: last_write_event
                                    
                                    	Time (in secs) since last write thread event
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: local_as
                                    
                                    	Local AS number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_as_dual_as
                                    
                                    	Local AS Dual\-AS option
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_as_dual_as_mode_native
                                    
                                    	Applies only if Local AS Dual\-AS option is enabled. Indicates if Dual\-AS mode is native
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_as_no_prepend
                                    
                                    	Option to not prepend the Local AS to announcements
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_as_replace_as
                                    
                                    	Local AS Replace\-AS option
                                    	**type**\:  bool
                                    
                                    .. attribute:: message_statistics
                                    
                                    	Message statistics
                                    	**type**\:   :py:class:`MessageStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics>`
                                    
                                    .. attribute:: messages_queued_in
                                    
                                    	No. of msgs on receive queue
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: messages_queued_out
                                    
                                    	No. of messages on send queue
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: messages_received
                                    
                                    	Number of messages received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: messages_sent
                                    
                                    	Number of messages sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: min_advertise_interval
                                    
                                    	Minimum advertisement interval, secs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: min_advertise_interval_msecs
                                    
                                    	Minimum advertisement interval, msecs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: min_origination_interval
                                    
                                    	Minimum origination interval (in secs)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: msg_log_in
                                    
                                    	Message in log count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: msg_log_out
                                    
                                    	Message out log count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: multi_protocol_capability_received
                                    
                                    	Multi\-protocol capability has been received
                                    	**type**\:  bool
                                    
                                    .. attribute:: nbr_cluster_id
                                    
                                    	Cluster id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nbr_enforce_first_as
                                    
                                    	Neighbor enforce first AS
                                    	**type**\:  bool
                                    
                                    .. attribute:: nbr_in_cluster
                                    
                                    	Type of cluster\_id\:undefined/number/Ip address
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: negotiated_protocol_version
                                    
                                    	Negotiated protocol version
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: neighbor_interface_handle
                                    
                                    	Interface Handle of Neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_local_as
                                    
                                    	Local AS configured on the neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_enabled
                                    
                                    	Neighbor supports NSR
                                    	**type**\:  bool
                                    
                                    .. attribute:: nsr_state
                                    
                                    	NSR state
                                    	**type**\:   :py:class:`BgpSyncNbrNsrStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrStateEnum>`
                                    
                                    .. attribute:: open_check_error_code
                                    
                                    	Open check error code
                                    	**type**\:   :py:class:`BgpOpenCheckErrEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpOpenCheckErrEnum>`
                                    
                                    .. attribute:: peer_error_code
                                    
                                    	If peer closed, error received from transport
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: peer_reset_reason
                                    
                                    	Reason for last peer close event
                                    	**type**\:   :py:class:`BgpPeerResetReasonIndexEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPeerResetReasonIndexEnum>`
                                    
                                    .. attribute:: performance_statistics
                                    
                                    	Performance statistics
                                    	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics>`
                                    
                                    .. attribute:: previous_connection_state
                                    
                                    	Previous state of connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: read_armed
                                    
                                    	If true, socket has beenauto\-armed for read
                                    	**type**\:  bool
                                    
                                    .. attribute:: received_notification_info
                                    
                                    	Information on the last notification received
                                    	**type**\:   :py:class:`ReceivedNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo>`
                                    
                                    .. attribute:: remote_as
                                    
                                    	Remote AS number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_as_number
                                    
                                    	Remote AS number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reset_notification_sent
                                    
                                    	Notification was sent during last reset
                                    	**type**\:  bool
                                    
                                    .. attribute:: reset_reason
                                    
                                    	Reason for last connection reset
                                    	**type**\:   :py:class:`BgpResetReasonIndexEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndexEnum>`
                                    
                                    .. attribute:: router_id
                                    
                                    	Router ID for the neighbor
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rpki_allow_invalid
                                    
                                    	Prefix v. allow invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: rpki_disable
                                    
                                    	Prefix validation disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: rpki_signal_ibgp
                                    
                                    	Prefix v. signal ibgp
                                    	**type**\:  bool
                                    
                                    .. attribute:: rpki_use_validity
                                    
                                    	Prefix v. use validity
                                    	**type**\:  bool
                                    
                                    .. attribute:: second_last_k_aexpiry_reset
                                    
                                    	Time (in secs) since second last KA timer expiry before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: second_last_k_astart_reset
                                    
                                    	Time (in secs) since the second last KA timer start before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: second_last_write_event
                                    
                                    	Time (in secs) since second last write thread event
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: send_notification_info
                                    
                                    	Information on the last notification sent
                                    	**type**\:   :py:class:`SendNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo>`
                                    
                                    .. attribute:: socket_read_bytes
                                    
                                    	Total read bytes value insocket\-lib
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: speaker_id
                                    
                                    	Speaker this neighbor is allocated to
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: standby_rp
                                    
                                    	Standby RP socket inited for Active Open
                                    	**type**\:  bool
                                    
                                    .. attribute:: suppress4_byte_as
                                    
                                    	Suppress 4byteas capability
                                    	**type**\:  bool
                                    
                                    .. attribute:: tcp_init_sync_done_time_spec
                                    
                                    	Time when neighbor entered TCP Init Sync Done
                                    	**type**\:   :py:class:`TcpInitSyncDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec>`
                                    
                                    .. attribute:: tcp_init_sync_phase_two_time_spec
                                    
                                    	Time when neighbor entered TCP Init Sync Phase Two
                                    	**type**\:   :py:class:`TcpInitSyncPhaseTwoTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec>`
                                    
                                    .. attribute:: tcp_init_sync_time_spec
                                    
                                    	Time When neighbor entered TCP Init Sync
                                    	**type**\:   :py:class:`TcpInitSyncTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec>`
                                    
                                    .. attribute:: tcp_session_open_mode
                                    
                                    	The TCP mode to be used to set up BGP session with the neighbor
                                    	**type**\:   :py:class:`BgpTcpModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpModeEnum>`
                                    
                                    .. attribute:: tcpmss
                                    
                                    	Neighbor TCP Maximum Segment                     size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: time_last_cb
                                    
                                    	CB
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: time_last_cb_reset
                                    
                                    	Last CB before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: time_last_fb
                                    
                                    	FB
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: time_since_connection_last_dropped
                                    
                                    	Time since the connection last went down (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: time_since_last_read
                                    
                                    	Time (in secs) since last read
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: time_since_last_read_reset
                                    
                                    	Time (in secs) since last read before last reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: time_since_last_update
                                    
                                    	Time (in secs) since last update message was received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: time_since_last_write
                                    
                                    	Time (in secs) since last write
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: time_since_last_write_reset
                                    
                                    	Time (in secs) since last write before last reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: time_since_second_last_write
                                    
                                    	Time (in secs) since second  last write
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: time_since_second_last_write_reset
                                    
                                    	Time (in secs) since last write before last reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: tos_type
                                    
                                    	Precedence or DSCP type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_value
                                    
                                    	Precedence or DSCP value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl_security_enabled
                                    
                                    	TTL Security enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: update_bytes_read
                                    
                                    	Total update bytes read
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: update_messages_in
                                    
                                    	No. of update msgs received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_messages_out
                                    
                                    	No. of update messages sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    .. attribute:: write_armed
                                    
                                    	If true, socket has beenauto\-armed for write
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.neighbor_address = None
                                        self.active_bmp_servers = None
                                        self.actual_last_write_bytes = None
                                        self.actual_last_write_reset_bytes = None
                                        self.actual_second_last_write_bytes = None
                                        self.actual_second_last_write_reset_bytes = None
                                        self.af_data = YList()
                                        self.af_data.parent = self
                                        self.af_data.name = 'af_data'
                                        self.attempted_last_write_bytes = None
                                        self.attempted_last_write_reset_bytes = None
                                        self.attempted_second_last_write_bytes = None
                                        self.attempted_second_last_write_reset_bytes = None
                                        self.bfd_minintervalval = None
                                        self.bfd_multiplierval = None
                                        self.bfd_session_created_state = None
                                        self.bfd_session_enable_mode = None
                                        self.bfd_session_state = None
                                        self.bfd_state_ts = None
                                        self.bytes_read = None
                                        self.bytes_written = None
                                        self.configured_hold_time = None
                                        self.configured_keepalive = None
                                        self.configured_min_acc_hold_time = None
                                        self.connect_retry_interval = None
                                        self.connection_admin_status = None
                                        self.connection_down_count = None
                                        self.connection_established_time = None
                                        self.connection_local_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress()
                                        self.connection_local_address.parent = self
                                        self.connection_local_port = None
                                        self.connection_remote_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress()
                                        self.connection_remote_address.parent = self
                                        self.connection_remote_port = None
                                        self.connection_state = None
                                        self.connection_up_count = None
                                        self.count_last_write = None
                                        self.description = None
                                        self.discard_as4_path = None
                                        self.discard_data_bytes = None
                                        self.dmz_link_bandwidth = None
                                        self.dynamic_neighbor = None
                                        self.ebgp_recv_dmz = None
                                        self.ebgp_send_dmz_mode = None
                                        self.ebgp_time_to_live = None
                                        self.egress_peer_engineering_enabled = None
                                        self.error_notifies_received = None
                                        self.error_notifies_sent = None
                                        self.fpbsn_offset = None
                                        self.fssn_offset = None
                                        self.gr_restart_time = None
                                        self.gr_stale_path_time = None
                                        self.graceful_maintenance = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance()
                                        self.graceful_maintenance.parent = self
                                        self.graceful_restart_enabled_nbr = None
                                        self.has_internal_link = None
                                        self.hold_time = None
                                        self.ignore_connected = None
                                        self.internal_vpn_client = None
                                        self.io_armed = None
                                        self.is4_byte_as_capability_received = None
                                        self.is4_byte_as_capability_sent = None
                                        self.is_administratively_shut_down = None
                                        self.is_capability_negotiation_performed = None
                                        self.is_capability_negotiation_suppressed = None
                                        self.is_ebgp_multihop_bgpmpls_forwarding_disabled = None
                                        self.is_ebgp_peer_as_league = None
                                        self.is_ebgp_peer_common_admin = None
                                        self.is_external_neighbor_not_directly_connected = None
                                        self.is_gr_aware = None
                                        self.is_local_address_configured = None
                                        self.is_neighbor_max_prefix_shutdown = None
                                        self.is_out_of_memory_forced_up = None
                                        self.is_out_of_memory_shutdown = None
                                        self.is_passive_close = None
                                        self.is_read_disabled = None
                                        self.is_route_refresh_capability_received = None
                                        self.is_route_refresh_old_capability_received = None
                                        self.keep_alive_time = None
                                        self.last_ackd_seq_no = None
                                        self.last_k_aerror_reset = None
                                        self.last_k_aexpiry_reset = None
                                        self.last_k_anotsent_reset = None
                                        self.last_k_astart_reset = None
                                        self.last_notify_error_code = None
                                        self.last_notify_error_subcode = None
                                        self.last_write_event = None
                                        self.local_as = None
                                        self.local_as_dual_as = None
                                        self.local_as_dual_as_mode_native = None
                                        self.local_as_no_prepend = None
                                        self.local_as_replace_as = None
                                        self.message_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics()
                                        self.message_statistics.parent = self
                                        self.messages_queued_in = None
                                        self.messages_queued_out = None
                                        self.messages_received = None
                                        self.messages_sent = None
                                        self.min_advertise_interval = None
                                        self.min_advertise_interval_msecs = None
                                        self.min_origination_interval = None
                                        self.msg_log_in = None
                                        self.msg_log_out = None
                                        self.multi_protocol_capability_received = None
                                        self.nbr_cluster_id = None
                                        self.nbr_enforce_first_as = None
                                        self.nbr_in_cluster = None
                                        self.negotiated_protocol_version = None
                                        self.neighbor_interface_handle = None
                                        self.neighbor_local_as = None
                                        self.nsr_enabled = None
                                        self.nsr_state = None
                                        self.open_check_error_code = None
                                        self.peer_error_code = None
                                        self.peer_reset_reason = None
                                        self.performance_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics()
                                        self.performance_statistics.parent = self
                                        self.previous_connection_state = None
                                        self.read_armed = None
                                        self.received_notification_info = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo()
                                        self.received_notification_info.parent = self
                                        self.remote_as = None
                                        self.remote_as_number = None
                                        self.reset_notification_sent = None
                                        self.reset_reason = None
                                        self.router_id = None
                                        self.rpki_allow_invalid = None
                                        self.rpki_disable = None
                                        self.rpki_signal_ibgp = None
                                        self.rpki_use_validity = None
                                        self.second_last_k_aexpiry_reset = None
                                        self.second_last_k_astart_reset = None
                                        self.second_last_write_event = None
                                        self.send_notification_info = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo()
                                        self.send_notification_info.parent = self
                                        self.socket_read_bytes = None
                                        self.speaker_id = None
                                        self.standby_rp = None
                                        self.suppress4_byte_as = None
                                        self.tcp_init_sync_done_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec()
                                        self.tcp_init_sync_done_time_spec.parent = self
                                        self.tcp_init_sync_phase_two_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec()
                                        self.tcp_init_sync_phase_two_time_spec.parent = self
                                        self.tcp_init_sync_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec()
                                        self.tcp_init_sync_time_spec.parent = self
                                        self.tcp_session_open_mode = None
                                        self.tcpmss = None
                                        self.time_last_cb = None
                                        self.time_last_cb_reset = None
                                        self.time_last_fb = None
                                        self.time_since_connection_last_dropped = None
                                        self.time_since_last_read = None
                                        self.time_since_last_read_reset = None
                                        self.time_since_last_update = None
                                        self.time_since_last_write = None
                                        self.time_since_last_write_reset = None
                                        self.time_since_second_last_write = None
                                        self.time_since_second_last_write_reset = None
                                        self.tos_type = None
                                        self.tos_value = None
                                        self.ttl_security_enabled = None
                                        self.update_bytes_read = None
                                        self.update_messages_in = None
                                        self.update_messages_out = None
                                        self.vrf_name = None
                                        self.write_armed = None


                                    class ConnectionLocalAddress(object):
                                        """
                                        Local address for the connection
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connection-local-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress']['meta_info']


                                    class ConnectionRemoteAddress(object):
                                        """
                                        Remote address for the connection
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connection-remote-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress']['meta_info']


                                    class SendNotificationInfo(object):
                                        """
                                        Information on the last notification sent
                                        
                                        .. attribute:: last_notification_data
                                        
                                        	Message data in last notification
                                        	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData>`
                                        
                                        .. attribute:: notification_error_code
                                        
                                        	Error code in last notification
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: notification_error_subcode
                                        
                                        	Error subcode in last notification
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: time_since_last_notification
                                        
                                        	Time since the last notification was sent or received (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.last_notification_data = YList()
                                            self.last_notification_data.parent = self
                                            self.last_notification_data.name = 'last_notification_data'
                                            self.notification_error_code = None
                                            self.notification_error_subcode = None
                                            self.time_since_last_notification = None


                                        class LastNotificationData(object):
                                            """
                                            Message data in last notification
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-notification-data'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:send-notification-info'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.last_notification_data is not None:
                                                for child_ref in self.last_notification_data:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.notification_error_code is not None:
                                                return True

                                            if self.notification_error_subcode is not None:
                                                return True

                                            if self.time_since_last_notification is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo']['meta_info']


                                    class ReceivedNotificationInfo(object):
                                        """
                                        Information on the last notification received
                                        
                                        .. attribute:: last_notification_data
                                        
                                        	Message data in last notification
                                        	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData>`
                                        
                                        .. attribute:: notification_error_code
                                        
                                        	Error code in last notification
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: notification_error_subcode
                                        
                                        	Error subcode in last notification
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: time_since_last_notification
                                        
                                        	Time since the last notification was sent or received (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.last_notification_data = YList()
                                            self.last_notification_data.parent = self
                                            self.last_notification_data.name = 'last_notification_data'
                                            self.notification_error_code = None
                                            self.notification_error_subcode = None
                                            self.time_since_last_notification = None


                                        class LastNotificationData(object):
                                            """
                                            Message data in last notification
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-notification-data'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:received-notification-info'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.last_notification_data is not None:
                                                for child_ref in self.last_notification_data:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.notification_error_code is not None:
                                                return True

                                            if self.notification_error_subcode is not None:
                                                return True

                                            if self.time_since_last_notification is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo']['meta_info']


                                    class PerformanceStatistics(object):
                                        """
                                        Performance statistics
                                        
                                        .. attribute:: active_collision
                                        
                                        	Number of Closed Active connections for this neighbor due to collision 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: actives
                                        
                                        	Number of retried Active opens for this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: control_to_read_thread_trigger
                                        
                                        	Number of times io\-control thread trigger read thread
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: control_to_write_thread_trigger
                                        
                                        	Number of times io\-control thread trigger write thread
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: data_bytes_read
                                        
                                        	No. of bytes of data read
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: data_bytes_written
                                        
                                        	No. of data bytes written
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: failed_post_actives
                                        
                                        	Number of Active Opens that failed in the Post Active State for this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: high_throttled_read
                                        
                                        	Num of socket reads after nbr crossed high threshold
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: inbound_update_messages
                                        
                                        	Number of inbound update messages processed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: inbound_update_messages_time
                                        
                                        	Time spent processing inbound update messages (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: io_read_time
                                        
                                        	Time spent reading inbound data (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: io_write_time
                                        
                                        	Time spent writing outbound data (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: last_nsr_scoped_sync
                                        
                                        	Last time NSR scoped syncwas done for the neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_sent_seq_no
                                        
                                        	Seq No of the last sent byte
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: low_throttled_read
                                        
                                        	Num socket reads after nbrs crossed low threshold
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_read_size
                                        
                                        	Size of largest socket (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: nbr_fd
                                        
                                        	Primary FD, per nbr
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: nbr_flags
                                        
                                        	Nbr flags, per thread
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: network_status
                                        
                                        	Socket status, TRUE if socket closed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nsr_oper_down_count
                                        
                                        	Number of times NSR scoped sync has been done
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: passive_collision
                                        
                                        	Number of Closed Remote opens for this neighborneighbor due to collision 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: passives
                                        
                                        	Number of retried Passive opens for this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: read_calls_count
                                        
                                        	No. of calls to function to read inbound data
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: read_messages_count
                                        
                                        	Number of BGP messages read
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: read_throttles
                                        
                                        	Number of partial read throttles
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rejected_passives
                                        
                                        	Number of rejected Passive opens for this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reset_flags
                                        
                                        	Reset flags, per thread
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reset_retries
                                        
                                        	Reset Retries, per nbr
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: subgroup_list_time
                                        
                                        	Time spent processing sub\-group message list  (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: sync_flags
                                        
                                        	Sync flags, per nbr
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_since_last_throttled_read
                                        
                                        	Time (in secs) since last read after being throttled
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: write_calls_count
                                        
                                        	No. of calls to function to write outbound data
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: write_queue_calls_count
                                        
                                        	No. of calls to function to process write queue
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: write_queue_messages_count
                                        
                                        	Number of write queue messages processed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: write_queue_time
                                        
                                        	Time spent processing write queue (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: write_subgroup_calls_count
                                        
                                        	No. of calls to function to process sub\-group message list
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: write_subgroup_messages_count
                                        
                                        	Number of sub\-group msgs processed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.active_collision = None
                                            self.actives = None
                                            self.control_to_read_thread_trigger = None
                                            self.control_to_write_thread_trigger = None
                                            self.data_bytes_read = None
                                            self.data_bytes_written = None
                                            self.failed_post_actives = None
                                            self.high_throttled_read = None
                                            self.inbound_update_messages = None
                                            self.inbound_update_messages_time = None
                                            self.io_read_time = None
                                            self.io_write_time = None
                                            self.last_nsr_scoped_sync = None
                                            self.last_sent_seq_no = None
                                            self.low_throttled_read = None
                                            self.maximum_read_size = None
                                            self.nbr_fd = None
                                            self.nbr_flags = None
                                            self.network_status = None
                                            self.nsr_oper_down_count = None
                                            self.passive_collision = None
                                            self.passives = None
                                            self.read_calls_count = None
                                            self.read_messages_count = None
                                            self.read_throttles = None
                                            self.rejected_passives = None
                                            self.reset_flags = None
                                            self.reset_retries = None
                                            self.subgroup_list_time = None
                                            self.sync_flags = None
                                            self.time_since_last_throttled_read = None
                                            self.write_calls_count = None
                                            self.write_queue_calls_count = None
                                            self.write_queue_messages_count = None
                                            self.write_queue_time = None
                                            self.write_subgroup_calls_count = None
                                            self.write_subgroup_messages_count = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:performance-statistics'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.active_collision is not None:
                                                return True

                                            if self.actives is not None:
                                                return True

                                            if self.control_to_read_thread_trigger is not None:
                                                return True

                                            if self.control_to_write_thread_trigger is not None:
                                                return True

                                            if self.data_bytes_read is not None:
                                                return True

                                            if self.data_bytes_written is not None:
                                                return True

                                            if self.failed_post_actives is not None:
                                                return True

                                            if self.high_throttled_read is not None:
                                                return True

                                            if self.inbound_update_messages is not None:
                                                return True

                                            if self.inbound_update_messages_time is not None:
                                                return True

                                            if self.io_read_time is not None:
                                                return True

                                            if self.io_write_time is not None:
                                                return True

                                            if self.last_nsr_scoped_sync is not None:
                                                return True

                                            if self.last_sent_seq_no is not None:
                                                return True

                                            if self.low_throttled_read is not None:
                                                return True

                                            if self.maximum_read_size is not None:
                                                return True

                                            if self.nbr_fd is not None:
                                                return True

                                            if self.nbr_flags is not None:
                                                return True

                                            if self.network_status is not None:
                                                return True

                                            if self.nsr_oper_down_count is not None:
                                                return True

                                            if self.passive_collision is not None:
                                                return True

                                            if self.passives is not None:
                                                return True

                                            if self.read_calls_count is not None:
                                                return True

                                            if self.read_messages_count is not None:
                                                return True

                                            if self.read_throttles is not None:
                                                return True

                                            if self.rejected_passives is not None:
                                                return True

                                            if self.reset_flags is not None:
                                                return True

                                            if self.reset_retries is not None:
                                                return True

                                            if self.subgroup_list_time is not None:
                                                return True

                                            if self.sync_flags is not None:
                                                return True

                                            if self.time_since_last_throttled_read is not None:
                                                return True

                                            if self.write_calls_count is not None:
                                                return True

                                            if self.write_queue_calls_count is not None:
                                                return True

                                            if self.write_queue_messages_count is not None:
                                                return True

                                            if self.write_queue_time is not None:
                                                return True

                                            if self.write_subgroup_calls_count is not None:
                                                return True

                                            if self.write_subgroup_messages_count is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics']['meta_info']


                                    class MessageStatistics(object):
                                        """
                                        Message statistics
                                        
                                        .. attribute:: keepalive
                                        
                                        	Keepalive
                                        	**type**\:   :py:class:`Keepalive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive>`
                                        
                                        .. attribute:: notification
                                        
                                        	Notification
                                        	**type**\:   :py:class:`Notification <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification>`
                                        
                                        .. attribute:: open
                                        
                                        	Open
                                        	**type**\:   :py:class:`Open <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open>`
                                        
                                        .. attribute:: route_refresh
                                        
                                        	Route refresh
                                        	**type**\:   :py:class:`RouteRefresh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh>`
                                        
                                        .. attribute:: total
                                        
                                        	Total
                                        	**type**\:   :py:class:`Total <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total>`
                                        
                                        .. attribute:: update
                                        
                                        	Update
                                        	**type**\:   :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.keepalive = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive()
                                            self.keepalive.parent = self
                                            self.notification = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification()
                                            self.notification.parent = self
                                            self.open = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open()
                                            self.open.parent = self
                                            self.route_refresh = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh()
                                            self.route_refresh.parent = self
                                            self.total = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total()
                                            self.total.parent = self
                                            self.update = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update()
                                            self.update.parent = self


                                        class Open(object):
                                            """
                                            Open
                                            
                                            .. attribute:: rx
                                            
                                            	Receive
                                            	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx>`
                                            
                                            .. attribute:: tx
                                            
                                            	Transmit
                                            	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.rx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx()
                                                self.rx.parent = self
                                                self.tx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx()
                                                self.tx.parent = self


                                            class Tx(object):
                                                """
                                                Transmit
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.count = None
                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec()
                                                    self.last_time_spec.parent = self


                                                class LastTimeSpec(object):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.count is not None:
                                                        return True

                                                    if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx']['meta_info']


                                            class Rx(object):
                                                """
                                                Receive
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.count = None
                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec()
                                                    self.last_time_spec.parent = self


                                                class LastTimeSpec(object):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.count is not None:
                                                        return True

                                                    if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:open'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.rx is not None and self.rx._has_data():
                                                    return True

                                                if self.tx is not None and self.tx._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open']['meta_info']


                                        class Notification(object):
                                            """
                                            Notification
                                            
                                            .. attribute:: rx
                                            
                                            	Receive
                                            	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx>`
                                            
                                            .. attribute:: tx
                                            
                                            	Transmit
                                            	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.rx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx()
                                                self.rx.parent = self
                                                self.tx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx()
                                                self.tx.parent = self


                                            class Tx(object):
                                                """
                                                Transmit
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.count = None
                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec()
                                                    self.last_time_spec.parent = self


                                                class LastTimeSpec(object):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.count is not None:
                                                        return True

                                                    if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx']['meta_info']


                                            class Rx(object):
                                                """
                                                Receive
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.count = None
                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec()
                                                    self.last_time_spec.parent = self


                                                class LastTimeSpec(object):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.count is not None:
                                                        return True

                                                    if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:notification'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.rx is not None and self.rx._has_data():
                                                    return True

                                                if self.tx is not None and self.tx._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification']['meta_info']


                                        class Update(object):
                                            """
                                            Update
                                            
                                            .. attribute:: rx
                                            
                                            	Receive
                                            	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx>`
                                            
                                            .. attribute:: tx
                                            
                                            	Transmit
                                            	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.rx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx()
                                                self.rx.parent = self
                                                self.tx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx()
                                                self.tx.parent = self


                                            class Tx(object):
                                                """
                                                Transmit
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.count = None
                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec()
                                                    self.last_time_spec.parent = self


                                                class LastTimeSpec(object):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.count is not None:
                                                        return True

                                                    if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx']['meta_info']


                                            class Rx(object):
                                                """
                                                Receive
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.count = None
                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec()
                                                    self.last_time_spec.parent = self


                                                class LastTimeSpec(object):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.count is not None:
                                                        return True

                                                    if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.rx is not None and self.rx._has_data():
                                                    return True

                                                if self.tx is not None and self.tx._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update']['meta_info']


                                        class Keepalive(object):
                                            """
                                            Keepalive
                                            
                                            .. attribute:: rx
                                            
                                            	Receive
                                            	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx>`
                                            
                                            .. attribute:: tx
                                            
                                            	Transmit
                                            	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.rx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx()
                                                self.rx.parent = self
                                                self.tx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx()
                                                self.tx.parent = self


                                            class Tx(object):
                                                """
                                                Transmit
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.count = None
                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec()
                                                    self.last_time_spec.parent = self


                                                class LastTimeSpec(object):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.count is not None:
                                                        return True

                                                    if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx']['meta_info']


                                            class Rx(object):
                                                """
                                                Receive
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.count = None
                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec()
                                                    self.last_time_spec.parent = self


                                                class LastTimeSpec(object):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.count is not None:
                                                        return True

                                                    if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:keepalive'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.rx is not None and self.rx._has_data():
                                                    return True

                                                if self.tx is not None and self.tx._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive']['meta_info']


                                        class RouteRefresh(object):
                                            """
                                            Route refresh
                                            
                                            .. attribute:: rx
                                            
                                            	Receive
                                            	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx>`
                                            
                                            .. attribute:: tx
                                            
                                            	Transmit
                                            	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.rx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx()
                                                self.rx.parent = self
                                                self.tx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx()
                                                self.tx.parent = self


                                            class Tx(object):
                                                """
                                                Transmit
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.count = None
                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec()
                                                    self.last_time_spec.parent = self


                                                class LastTimeSpec(object):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.count is not None:
                                                        return True

                                                    if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx']['meta_info']


                                            class Rx(object):
                                                """
                                                Receive
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.count = None
                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec()
                                                    self.last_time_spec.parent = self


                                                class LastTimeSpec(object):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.count is not None:
                                                        return True

                                                    if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:route-refresh'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.rx is not None and self.rx._has_data():
                                                    return True

                                                if self.tx is not None and self.tx._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh']['meta_info']


                                        class Total(object):
                                            """
                                            Total
                                            
                                            .. attribute:: rx
                                            
                                            	Receive
                                            	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx>`
                                            
                                            .. attribute:: tx
                                            
                                            	Transmit
                                            	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.rx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx()
                                                self.rx.parent = self
                                                self.tx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx()
                                                self.tx.parent = self


                                            class Tx(object):
                                                """
                                                Transmit
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.count = None
                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec()
                                                    self.last_time_spec.parent = self


                                                class LastTimeSpec(object):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.count is not None:
                                                        return True

                                                    if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx']['meta_info']


                                            class Rx(object):
                                                """
                                                Receive
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.count = None
                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec()
                                                    self.last_time_spec.parent = self


                                                class LastTimeSpec(object):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.count is not None:
                                                        return True

                                                    if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:total'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.rx is not None and self.rx._has_data():
                                                    return True

                                                if self.tx is not None and self.tx._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:message-statistics'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.keepalive is not None and self.keepalive._has_data():
                                                return True

                                            if self.notification is not None and self.notification._has_data():
                                                return True

                                            if self.open is not None and self.open._has_data():
                                                return True

                                            if self.route_refresh is not None and self.route_refresh._has_data():
                                                return True

                                            if self.total is not None and self.total._has_data():
                                                return True

                                            if self.update is not None and self.update._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics']['meta_info']


                                    class TcpInitSyncTimeSpec(object):
                                        """
                                        Time When neighbor entered TCP Init Sync
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tcp-init-sync-time-spec'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec']['meta_info']


                                    class TcpInitSyncPhaseTwoTimeSpec(object):
                                        """
                                        Time when neighbor entered TCP Init Sync Phase
                                        Two
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tcp-init-sync-phase-two-time-spec'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec']['meta_info']


                                    class TcpInitSyncDoneTimeSpec(object):
                                        """
                                        Time when neighbor entered TCP Init Sync Done
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tcp-init-sync-done-time-spec'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec']['meta_info']


                                    class GracefulMaintenance(object):
                                        """
                                        Graceful Maintenance
                                        
                                        .. attribute:: gshut_active
                                        
                                        	Graceful Maintenance activated
                                        	**type**\:  bool
                                        
                                        .. attribute:: gshut_exists
                                        
                                        	Graceful Maintenance enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: gshut_local_active
                                        
                                        	Graceful Maintenance locally activated
                                        	**type**\:  bool
                                        
                                        .. attribute:: gshut_locpref
                                        
                                        	Graceful Maintenance Local Preference
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: gshut_locpref_set
                                        
                                        	Graceful Maintenance Local Preference set
                                        	**type**\:  bool
                                        
                                        .. attribute:: gshut_prepends
                                        
                                        	Graceful Maintenance number of AS prepends
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.gshut_active = None
                                            self.gshut_exists = None
                                            self.gshut_local_active = None
                                            self.gshut_locpref = None
                                            self.gshut_locpref_set = None
                                            self.gshut_prepends = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:graceful-maintenance'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.gshut_active is not None:
                                                return True

                                            if self.gshut_exists is not None:
                                                return True

                                            if self.gshut_local_active is not None:
                                                return True

                                            if self.gshut_locpref is not None:
                                                return True

                                            if self.gshut_locpref_set is not None:
                                                return True

                                            if self.gshut_prepends is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance']['meta_info']


                                    class AfData(object):
                                        """
                                        Address family specific neighbor data
                                        
                                        .. attribute:: accept_own_enabled
                                        
                                        	Accept\-Own enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: acked_version
                                        
                                        	Version mapped from acked seqNo
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: address_family_long_lived_time
                                        
                                        	AF specific Long\-lived\-time config
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertise_afi
                                        
                                        	Encode in Advertise AFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_afi_def_vrf_imp_disable
                                        
                                        	Advertise of default VRF import disable
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_afi_disable
                                        
                                        	Encode in Advertise AFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_afi_eo_r_ready
                                        
                                        	EoR Can be sent for Advertise AFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_afi_reorg
                                        
                                        	Encode in Advertise AFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_afi_vrf_re_imp_disable
                                        
                                        	Advertise of VRF re\-import disable
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_evp_nv4afi_def_vrf_imp_disable
                                        
                                        	Advertise of v4 default VRF import disable
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_evp_nv4afi_vrf_re_imp_disable
                                        
                                        	Advertise of v4 VRF re\-import disable
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_evp_nv6afi_def_vrf_imp_disable
                                        
                                        	Advertise of v6 default VRF import disable
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_evp_nv6afi_vrf_re_imp_disable
                                        
                                        	Advertise of v6 VRF re\-import disable
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_local_labeled_route_unicast
                                        
                                        	Advertise routes with local\-label via Unicast SAFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_rt_type
                                        
                                        	Advertise RT type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: advertise_v4_flags
                                        
                                        	Advertise options for VPNV4
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertise_v6_flags
                                        
                                        	Advertise options for VPNV6
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: afrpki_allow_invalid
                                        
                                        	Prefix v. allow invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: afrpki_disable
                                        
                                        	Prefix validation disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: afrpki_signal_ibgp
                                        
                                        	Prefix v. signal ibgp
                                        	**type**\:  bool
                                        
                                        .. attribute:: afrpki_use_validity
                                        
                                        	Prefix v. use validity
                                        	**type**\:  bool
                                        
                                        .. attribute:: allow_as_in_count
                                        
                                        	Allowas\-in count config
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: always_use_next_hop_local
                                        
                                        	Local router always used for next\-hop
                                        	**type**\:  bool
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation type
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: eo_r_received_in_read_only
                                        
                                        	An EoR was received while in read\-only mode
                                        	**type**\:  bool
                                        
                                        .. attribute:: extended_community
                                        
                                        	Extended community attribute
                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity>`
                                        
                                        .. attribute:: extended_community_standby
                                        
                                        	Extended community attribute
                                        	**type**\: list of    :py:class:`ExtendedCommunityStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby>`
                                        
                                        .. attribute:: filter_group_index
                                        
                                        	Filter group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: flowspec_redirect_validation_d_isable
                                        
                                        	Flowspec Redirect Validation Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: flowspec_validation_d_isable
                                        
                                        	Flowspec Validation Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: import_reoriginate
                                        
                                        	Import Reoriginate enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: import_reoriginate_stitching
                                        
                                        	Import Reoriginate Stitching enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: import_stitching
                                        
                                        	Import Stitching enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_add_path_receive_capability_advertised
                                        
                                        	Addpath Receive capability advertised
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_add_path_receive_capability_received
                                        
                                        	Addpath Receive capability received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_add_path_send_capability_advertised
                                        
                                        	Addpath Send capability advertised
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_add_path_send_capability_received
                                        
                                        	Addpath Send capability received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_addpath_receive_operational
                                        
                                        	Addpath is operational on receive\-side
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_addpath_send_operational
                                        
                                        	Addpath is operational on send\-side
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertise_permanent_network
                                        
                                        	Advertise Permanent Network
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertised_graceful_restart
                                        
                                        	Graceful Restart Capability advertised
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertised_orf_receive
                                        
                                        	Prefix based ORF receive mode capability advertised
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertised_orf_send
                                        
                                        	Prefix based ORF send mode capability advertised
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_aigp_set
                                        
                                        	AIGP set 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_allow_as_in_set
                                        
                                        	Allowas\-in set 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_override_set
                                        
                                        	As override set 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_default_originate_sent
                                        
                                        	Default origination update sent
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ext_nh_encoding_capability_received
                                        
                                        	Extended nexthop encoding capability received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ext_nh_encoding_capability_sent
                                        
                                        	Extended nexhop encoding capability Sent
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_state_flag
                                        
                                        	Restart state flag enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_legacy_pe_rt
                                        
                                        	Nbr accepts route from legacy PE for RT\-Constraint AF 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_af_capable
                                        
                                        	Address family capability received from neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_ebgp_without_inbound_policy
                                        
                                        	eBGP neighbor with no configured inbound policy
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_ebgp_without_outbound_policy
                                        
                                        	eBGP neighbor with no configured outbound policy
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_route_reflector_client
                                        
                                        	Nbr is a route reflector client
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_orf_send_scheduled
                                        
                                        	Scheduled to send prefix based ORF
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_orf_sent
                                        
                                        	Outbound route filter sent to neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_orr_root_address_configured
                                        
                                        	ORR Root address configuredfor the neighbor connection
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_peer_orf_capable
                                        
                                        	Peer has outbound route filter capability
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_prefix_orf_present
                                        
                                        	Outbound route filter prefix ORF present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_graceful_restart_capable
                                        
                                        	Graceful Restart Capability received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_orf_receive_capable
                                        
                                        	Prefix based ORF receive mode capability received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_orf_send_capable
                                        
                                        	Prefix based ORF send mode capability received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rt_present
                                        
                                        	RT attribute list present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rt_present_standby
                                        
                                        	RT attribute list present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_send_mcast_attr
                                        
                                        	Send Mcast Attr
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_soft_reconfiguration_inbound_allowed
                                        
                                        	Inbound soft reconfiguration allowed
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_update_deferred
                                        
                                        	Update deferred until ORF/route refresh received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_update_leaving
                                        
                                        	Nbr leaving update\-groupto another
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_update_throttled
                                        
                                        	Updates Throttled becausewrite limit is reached
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_use_soft_reconfiguration_always_on
                                        
                                        	Soft reconf overrides route refresh
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_restart_time
                                        
                                        	Local Restart time (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: long_lived_graceful_restart_capability_received
                                        
                                        	Long\-lived graceful\-restart capability received from the neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: long_lived_graceful_restart_stale_time_accept
                                        
                                        	Maximum long\-lived graceful\-restart stale time acceptable from the neighbor (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: long_lived_graceful_restart_stale_time_configured
                                        
                                        	Long\-lived graceful\-restart stale time is configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: long_lived_graceful_restart_stale_time_received
                                        
                                        	Long\-lived graceful\-restart stale time received from the neighbor (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: long_lived_graceful_restart_stale_time_sent
                                        
                                        	Stale time sent in long\-lived graceful\-restart capability (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: max_prefix_discard_extra_paths
                                        
                                        	Discard extra paths when prefix limit reached
                                        	**type**\:  bool
                                        
                                        .. attribute:: max_prefix_exceed_discard_paths
                                        
                                        	Did we discard extra paths when prefix limit reached
                                        	**type**\:  bool
                                        
                                        .. attribute:: max_prefix_limit
                                        
                                        	Max limit for # of prefixes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: max_prefix_restart_time
                                        
                                        	Time interval (in minutes) after which peering session will be reestablished
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: minute
                                        
                                        .. attribute:: max_prefix_threshold_percent
                                        
                                        	Percentage of maximum no. of prefixes at which to generate warning
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: percentage
                                        
                                        .. attribute:: neighbor_af_performance_statistics
                                        
                                        	Neighbor AF statistics
                                        	**type**\:   :py:class:`NeighborAfPerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics>`
                                        
                                        .. attribute:: neighbor_default_originate
                                        
                                        	Neighbor originates default
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_long_lived_graceful_restart_capable
                                        
                                        	Treat neighbor as long\-lived graceful\-restart capable
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_long_lived_graceful_restart_time_remaining
                                        
                                        	Remaining long\-lived graceful\-restart time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_preserved_forwarding_state
                                        
                                        	Neighbor preserved forwarding state
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_preserved_long_lived_forwarding_state
                                        
                                        	Neighbor preserved long\-lived forwarding state
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_version
                                        
                                        	Neighbor version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: number_of_best_externalpaths
                                        
                                        	No. of best\-external paths from this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: number_of_bestpaths
                                        
                                        	No. of bestpaths from this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: orf_entries_received
                                        
                                        	Number of outbound route filter entries received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: orr_group_index
                                        
                                        	ORR Group Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: orr_group_name
                                        
                                        	ORR Group Name
                                        	**type**\:  str
                                        
                                        .. attribute:: outstanding_version
                                        
                                        	Version mapped from acked seqNo that was synced last
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: outstanding_version_max
                                        
                                        	Version mapped from acked seqNo that was synced last
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_accepted
                                        
                                        	No. of prefixes accepted
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_advertised
                                        
                                        	No. of prefixes advertised
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_be_advertised
                                        
                                        	No BE prefixes advertised
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_denied
                                        
                                        	No. of prefixes denied
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_denied_no_policy
                                        
                                        	No. of prefixes denied because there was no inbound policy
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_denied_non_cumulative
                                        
                                        	No. of prefixes exactly denied (non cumulative)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_denied_orf_policy
                                        
                                        	No. of prefixes denied by prefix based ORF policy
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_denied_policy
                                        
                                        	No. of prefixes denied by inbound policy
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_denied_rt_permit
                                        
                                        	No. of prefixes denied because RT extended community is not imported
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_suppressed
                                        
                                        	No. of prefixes suppressed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_synced
                                        
                                        	Number of prefixes synced to standby
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_withdrawn
                                        
                                        	No. of prefixes withdrawn
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_withdrawn_not_found
                                        
                                        	No. of prefixes withdrawn but not found
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_acked_version
                                        
                                        	Version acked by the peer for refresh updates sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_target_version
                                        
                                        	Target version for refresh update generation
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_version
                                        
                                        	Version till which refresh updates have been generated
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remove_private_as_entire_aspath_from_inbound_updates
                                        
                                        	Private AS numbers removed from updates from this nbr only if the aspath has only private ASes
                                        	**type**\:  bool
                                        
                                        .. attribute:: remove_private_as_entire_aspath_from_updates
                                        
                                        	Private AS numbers removed from updates to thisnbr only if the aspath hasonly private ASes
                                        	**type**\:  bool
                                        
                                        .. attribute:: remove_private_as_from_inbound_updates
                                        
                                        	Private AS numbers removed from updates from this nbr
                                        	**type**\:  bool
                                        
                                        .. attribute:: remove_private_as_from_updates
                                        
                                        	Private AS numbers removed from updates to this nbr
                                        	**type**\:  bool
                                        
                                        .. attribute:: restart_time
                                        
                                        	Restart time advertised (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: rib_purge_timeout_value
                                        
                                        	RIB purge timeout time (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: route_policy_default_originate
                                        
                                        	Default\-originate route policy name
                                        	**type**\:  str
                                        
                                        .. attribute:: route_policy_in
                                        
                                        	Incoming route policy name
                                        	**type**\:  str
                                        
                                        .. attribute:: route_policy_out
                                        
                                        	Outgoing route policy name
                                        	**type**\:  str
                                        
                                        .. attribute:: route_policy_prefix_orf
                                        
                                        	Prefix based ORF for incoming updates
                                        	**type**\:  str
                                        
                                        .. attribute:: route_refreshes_received
                                        
                                        	Number of route refresh requests received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_refreshes_sent
                                        
                                        	Number of route refresh requests sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: selective_multipath_eligible
                                        
                                        	Selective multipath eligible
                                        	**type**\:  bool
                                        
                                        .. attribute:: sent_community_to_neighbor
                                        
                                        	Community attribute sent to neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: sent_extended_community_to_neighbor
                                        
                                        	Extended community attribute sent to neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: sent_gshut_community_to_neighbor
                                        
                                        	GSHUT Community attribute sent to neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: stale_path_timeout
                                        
                                        	Stale path timeout time (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: synced_acked_version
                                        
                                        	Version mapped from acked seqNo that was synced last
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: use_max_prefix_warning_only
                                        
                                        	Warning only when maximum prefix limit reached
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_update_gen_enabled
                                        
                                        	RT Nbr enabled for updategento another
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_update_gen_trigger_enabled
                                        
                                        	RT Nbr enabled for updategento another
                                        	**type**\:  bool
                                        
                                        .. attribute:: weight
                                        
                                        	Weight for this AF
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.accept_own_enabled = None
                                            self.acked_version = None
                                            self.address_family_long_lived_time = None
                                            self.advertise_afi = None
                                            self.advertise_afi_def_vrf_imp_disable = None
                                            self.advertise_afi_disable = None
                                            self.advertise_afi_eo_r_ready = None
                                            self.advertise_afi_reorg = None
                                            self.advertise_afi_vrf_re_imp_disable = None
                                            self.advertise_evp_nv4afi_def_vrf_imp_disable = None
                                            self.advertise_evp_nv4afi_vrf_re_imp_disable = None
                                            self.advertise_evp_nv6afi_def_vrf_imp_disable = None
                                            self.advertise_evp_nv6afi_vrf_re_imp_disable = None
                                            self.advertise_local_labeled_route_unicast = None
                                            self.advertise_rt_type = None
                                            self.advertise_v4_flags = None
                                            self.advertise_v6_flags = None
                                            self.af_name = None
                                            self.afrpki_allow_invalid = None
                                            self.afrpki_disable = None
                                            self.afrpki_signal_ibgp = None
                                            self.afrpki_use_validity = None
                                            self.allow_as_in_count = None
                                            self.always_use_next_hop_local = None
                                            self.encapsulation_type = None
                                            self.eo_r_received_in_read_only = None
                                            self.extended_community = YList()
                                            self.extended_community.parent = self
                                            self.extended_community.name = 'extended_community'
                                            self.extended_community_standby = YList()
                                            self.extended_community_standby.parent = self
                                            self.extended_community_standby.name = 'extended_community_standby'
                                            self.filter_group_index = None
                                            self.flowspec_redirect_validation_d_isable = None
                                            self.flowspec_validation_d_isable = None
                                            self.import_reoriginate = None
                                            self.import_reoriginate_stitching = None
                                            self.import_stitching = None
                                            self.is_add_path_receive_capability_advertised = None
                                            self.is_add_path_receive_capability_received = None
                                            self.is_add_path_send_capability_advertised = None
                                            self.is_add_path_send_capability_received = None
                                            self.is_addpath_receive_operational = None
                                            self.is_addpath_send_operational = None
                                            self.is_advertise_permanent_network = None
                                            self.is_advertised_graceful_restart = None
                                            self.is_advertised_orf_receive = None
                                            self.is_advertised_orf_send = None
                                            self.is_aigp_set = None
                                            self.is_allow_as_in_set = None
                                            self.is_as_override_set = None
                                            self.is_default_originate_sent = None
                                            self.is_ext_nh_encoding_capability_received = None
                                            self.is_ext_nh_encoding_capability_sent = None
                                            self.is_graceful_restart_state_flag = None
                                            self.is_legacy_pe_rt = None
                                            self.is_neighbor_af_capable = None
                                            self.is_neighbor_ebgp_without_inbound_policy = None
                                            self.is_neighbor_ebgp_without_outbound_policy = None
                                            self.is_neighbor_route_reflector_client = None
                                            self.is_orf_send_scheduled = None
                                            self.is_orf_sent = None
                                            self.is_orr_root_address_configured = None
                                            self.is_peer_orf_capable = None
                                            self.is_prefix_orf_present = None
                                            self.is_received_graceful_restart_capable = None
                                            self.is_received_orf_receive_capable = None
                                            self.is_received_orf_send_capable = None
                                            self.is_rt_present = None
                                            self.is_rt_present_standby = None
                                            self.is_send_mcast_attr = None
                                            self.is_soft_reconfiguration_inbound_allowed = None
                                            self.is_update_deferred = None
                                            self.is_update_leaving = None
                                            self.is_update_throttled = None
                                            self.is_use_soft_reconfiguration_always_on = None
                                            self.local_restart_time = None
                                            self.long_lived_graceful_restart_capability_received = None
                                            self.long_lived_graceful_restart_stale_time_accept = None
                                            self.long_lived_graceful_restart_stale_time_configured = None
                                            self.long_lived_graceful_restart_stale_time_received = None
                                            self.long_lived_graceful_restart_stale_time_sent = None
                                            self.max_prefix_discard_extra_paths = None
                                            self.max_prefix_exceed_discard_paths = None
                                            self.max_prefix_limit = None
                                            self.max_prefix_restart_time = None
                                            self.max_prefix_threshold_percent = None
                                            self.neighbor_af_performance_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics()
                                            self.neighbor_af_performance_statistics.parent = self
                                            self.neighbor_default_originate = None
                                            self.neighbor_long_lived_graceful_restart_capable = None
                                            self.neighbor_long_lived_graceful_restart_time_remaining = None
                                            self.neighbor_preserved_forwarding_state = None
                                            self.neighbor_preserved_long_lived_forwarding_state = None
                                            self.neighbor_version = None
                                            self.number_of_best_externalpaths = None
                                            self.number_of_bestpaths = None
                                            self.orf_entries_received = None
                                            self.orr_group_index = None
                                            self.orr_group_name = None
                                            self.outstanding_version = None
                                            self.outstanding_version_max = None
                                            self.prefixes_accepted = None
                                            self.prefixes_advertised = None
                                            self.prefixes_be_advertised = None
                                            self.prefixes_denied = None
                                            self.prefixes_denied_no_policy = None
                                            self.prefixes_denied_non_cumulative = None
                                            self.prefixes_denied_orf_policy = None
                                            self.prefixes_denied_policy = None
                                            self.prefixes_denied_rt_permit = None
                                            self.prefixes_suppressed = None
                                            self.prefixes_synced = None
                                            self.prefixes_withdrawn = None
                                            self.prefixes_withdrawn_not_found = None
                                            self.refresh_acked_version = None
                                            self.refresh_target_version = None
                                            self.refresh_version = None
                                            self.remove_private_as_entire_aspath_from_inbound_updates = None
                                            self.remove_private_as_entire_aspath_from_updates = None
                                            self.remove_private_as_from_inbound_updates = None
                                            self.remove_private_as_from_updates = None
                                            self.restart_time = None
                                            self.rib_purge_timeout_value = None
                                            self.route_policy_default_originate = None
                                            self.route_policy_in = None
                                            self.route_policy_out = None
                                            self.route_policy_prefix_orf = None
                                            self.route_refreshes_received = None
                                            self.route_refreshes_sent = None
                                            self.selective_multipath_eligible = None
                                            self.sent_community_to_neighbor = None
                                            self.sent_extended_community_to_neighbor = None
                                            self.sent_gshut_community_to_neighbor = None
                                            self.stale_path_timeout = None
                                            self.synced_acked_version = None
                                            self.update_group_number = None
                                            self.use_max_prefix_warning_only = None
                                            self.vpn_update_gen_enabled = None
                                            self.vpn_update_gen_trigger_enabled = None
                                            self.weight = None


                                        class NeighborAfPerformanceStatistics(object):
                                            """
                                            Neighbor AF statistics
                                            
                                            .. attribute:: processed_messages
                                            
                                            	Number of messages processed from the neighbor's write queue
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sent_messages
                                            
                                            	Number of messages sent from the neighbor's write queue
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: split_horizon_update_blocked
                                            
                                            	No. of update messages with split\-horizon flag that were blocked
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: split_horizon_update_transmit
                                            
                                            	No. of update messages with split\-horizon flag that were sent out
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: split_horizon_withdraw_blocked
                                            
                                            	No. of withdraw messages with split\-horizon flag that were blocked
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: split_horizon_withdraw_transmit
                                            
                                            	No. of withdraw messages with split\-horizon flag that were sent out
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sub_group_pending_message_count
                                            
                                            	No. of sub\-group messages waiting to be sent out on this neighbor \-\- DEPRECATED \-\- 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.processed_messages = None
                                                self.sent_messages = None
                                                self.split_horizon_update_blocked = None
                                                self.split_horizon_update_transmit = None
                                                self.split_horizon_withdraw_blocked = None
                                                self.split_horizon_withdraw_transmit = None
                                                self.sub_group_pending_message_count = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-af-performance-statistics'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.processed_messages is not None:
                                                    return True

                                                if self.sent_messages is not None:
                                                    return True

                                                if self.split_horizon_update_blocked is not None:
                                                    return True

                                                if self.split_horizon_update_transmit is not None:
                                                    return True

                                                if self.split_horizon_withdraw_blocked is not None:
                                                    return True

                                                if self.split_horizon_withdraw_transmit is not None:
                                                    return True

                                                if self.sub_group_pending_message_count is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics']['meta_info']


                                        class ExtendedCommunity(object):
                                            """
                                            Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity']['meta_info']


                                        class ExtendedCommunityStandby(object):
                                            """
                                            Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community-standby'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af-data'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.accept_own_enabled is not None:
                                                return True

                                            if self.acked_version is not None:
                                                return True

                                            if self.address_family_long_lived_time is not None:
                                                return True

                                            if self.advertise_afi is not None:
                                                return True

                                            if self.advertise_afi_def_vrf_imp_disable is not None:
                                                return True

                                            if self.advertise_afi_disable is not None:
                                                return True

                                            if self.advertise_afi_eo_r_ready is not None:
                                                return True

                                            if self.advertise_afi_reorg is not None:
                                                return True

                                            if self.advertise_afi_vrf_re_imp_disable is not None:
                                                return True

                                            if self.advertise_evp_nv4afi_def_vrf_imp_disable is not None:
                                                return True

                                            if self.advertise_evp_nv4afi_vrf_re_imp_disable is not None:
                                                return True

                                            if self.advertise_evp_nv6afi_def_vrf_imp_disable is not None:
                                                return True

                                            if self.advertise_evp_nv6afi_vrf_re_imp_disable is not None:
                                                return True

                                            if self.advertise_local_labeled_route_unicast is not None:
                                                return True

                                            if self.advertise_rt_type is not None:
                                                return True

                                            if self.advertise_v4_flags is not None:
                                                return True

                                            if self.advertise_v6_flags is not None:
                                                return True

                                            if self.af_name is not None:
                                                return True

                                            if self.afrpki_allow_invalid is not None:
                                                return True

                                            if self.afrpki_disable is not None:
                                                return True

                                            if self.afrpki_signal_ibgp is not None:
                                                return True

                                            if self.afrpki_use_validity is not None:
                                                return True

                                            if self.allow_as_in_count is not None:
                                                return True

                                            if self.always_use_next_hop_local is not None:
                                                return True

                                            if self.encapsulation_type is not None:
                                                return True

                                            if self.eo_r_received_in_read_only is not None:
                                                return True

                                            if self.extended_community is not None:
                                                for child_ref in self.extended_community:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.extended_community_standby is not None:
                                                for child_ref in self.extended_community_standby:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.filter_group_index is not None:
                                                return True

                                            if self.flowspec_redirect_validation_d_isable is not None:
                                                return True

                                            if self.flowspec_validation_d_isable is not None:
                                                return True

                                            if self.import_reoriginate is not None:
                                                return True

                                            if self.import_reoriginate_stitching is not None:
                                                return True

                                            if self.import_stitching is not None:
                                                return True

                                            if self.is_add_path_receive_capability_advertised is not None:
                                                return True

                                            if self.is_add_path_receive_capability_received is not None:
                                                return True

                                            if self.is_add_path_send_capability_advertised is not None:
                                                return True

                                            if self.is_add_path_send_capability_received is not None:
                                                return True

                                            if self.is_addpath_receive_operational is not None:
                                                return True

                                            if self.is_addpath_send_operational is not None:
                                                return True

                                            if self.is_advertise_permanent_network is not None:
                                                return True

                                            if self.is_advertised_graceful_restart is not None:
                                                return True

                                            if self.is_advertised_orf_receive is not None:
                                                return True

                                            if self.is_advertised_orf_send is not None:
                                                return True

                                            if self.is_aigp_set is not None:
                                                return True

                                            if self.is_allow_as_in_set is not None:
                                                return True

                                            if self.is_as_override_set is not None:
                                                return True

                                            if self.is_default_originate_sent is not None:
                                                return True

                                            if self.is_ext_nh_encoding_capability_received is not None:
                                                return True

                                            if self.is_ext_nh_encoding_capability_sent is not None:
                                                return True

                                            if self.is_graceful_restart_state_flag is not None:
                                                return True

                                            if self.is_legacy_pe_rt is not None:
                                                return True

                                            if self.is_neighbor_af_capable is not None:
                                                return True

                                            if self.is_neighbor_ebgp_without_inbound_policy is not None:
                                                return True

                                            if self.is_neighbor_ebgp_without_outbound_policy is not None:
                                                return True

                                            if self.is_neighbor_route_reflector_client is not None:
                                                return True

                                            if self.is_orf_send_scheduled is not None:
                                                return True

                                            if self.is_orf_sent is not None:
                                                return True

                                            if self.is_orr_root_address_configured is not None:
                                                return True

                                            if self.is_peer_orf_capable is not None:
                                                return True

                                            if self.is_prefix_orf_present is not None:
                                                return True

                                            if self.is_received_graceful_restart_capable is not None:
                                                return True

                                            if self.is_received_orf_receive_capable is not None:
                                                return True

                                            if self.is_received_orf_send_capable is not None:
                                                return True

                                            if self.is_rt_present is not None:
                                                return True

                                            if self.is_rt_present_standby is not None:
                                                return True

                                            if self.is_send_mcast_attr is not None:
                                                return True

                                            if self.is_soft_reconfiguration_inbound_allowed is not None:
                                                return True

                                            if self.is_update_deferred is not None:
                                                return True

                                            if self.is_update_leaving is not None:
                                                return True

                                            if self.is_update_throttled is not None:
                                                return True

                                            if self.is_use_soft_reconfiguration_always_on is not None:
                                                return True

                                            if self.local_restart_time is not None:
                                                return True

                                            if self.long_lived_graceful_restart_capability_received is not None:
                                                return True

                                            if self.long_lived_graceful_restart_stale_time_accept is not None:
                                                return True

                                            if self.long_lived_graceful_restart_stale_time_configured is not None:
                                                return True

                                            if self.long_lived_graceful_restart_stale_time_received is not None:
                                                return True

                                            if self.long_lived_graceful_restart_stale_time_sent is not None:
                                                return True

                                            if self.max_prefix_discard_extra_paths is not None:
                                                return True

                                            if self.max_prefix_exceed_discard_paths is not None:
                                                return True

                                            if self.max_prefix_limit is not None:
                                                return True

                                            if self.max_prefix_restart_time is not None:
                                                return True

                                            if self.max_prefix_threshold_percent is not None:
                                                return True

                                            if self.neighbor_af_performance_statistics is not None and self.neighbor_af_performance_statistics._has_data():
                                                return True

                                            if self.neighbor_default_originate is not None:
                                                return True

                                            if self.neighbor_long_lived_graceful_restart_capable is not None:
                                                return True

                                            if self.neighbor_long_lived_graceful_restart_time_remaining is not None:
                                                return True

                                            if self.neighbor_preserved_forwarding_state is not None:
                                                return True

                                            if self.neighbor_preserved_long_lived_forwarding_state is not None:
                                                return True

                                            if self.neighbor_version is not None:
                                                return True

                                            if self.number_of_best_externalpaths is not None:
                                                return True

                                            if self.number_of_bestpaths is not None:
                                                return True

                                            if self.orf_entries_received is not None:
                                                return True

                                            if self.orr_group_index is not None:
                                                return True

                                            if self.orr_group_name is not None:
                                                return True

                                            if self.outstanding_version is not None:
                                                return True

                                            if self.outstanding_version_max is not None:
                                                return True

                                            if self.prefixes_accepted is not None:
                                                return True

                                            if self.prefixes_advertised is not None:
                                                return True

                                            if self.prefixes_be_advertised is not None:
                                                return True

                                            if self.prefixes_denied is not None:
                                                return True

                                            if self.prefixes_denied_no_policy is not None:
                                                return True

                                            if self.prefixes_denied_non_cumulative is not None:
                                                return True

                                            if self.prefixes_denied_orf_policy is not None:
                                                return True

                                            if self.prefixes_denied_policy is not None:
                                                return True

                                            if self.prefixes_denied_rt_permit is not None:
                                                return True

                                            if self.prefixes_suppressed is not None:
                                                return True

                                            if self.prefixes_synced is not None:
                                                return True

                                            if self.prefixes_withdrawn is not None:
                                                return True

                                            if self.prefixes_withdrawn_not_found is not None:
                                                return True

                                            if self.refresh_acked_version is not None:
                                                return True

                                            if self.refresh_target_version is not None:
                                                return True

                                            if self.refresh_version is not None:
                                                return True

                                            if self.remove_private_as_entire_aspath_from_inbound_updates is not None:
                                                return True

                                            if self.remove_private_as_entire_aspath_from_updates is not None:
                                                return True

                                            if self.remove_private_as_from_inbound_updates is not None:
                                                return True

                                            if self.remove_private_as_from_updates is not None:
                                                return True

                                            if self.restart_time is not None:
                                                return True

                                            if self.rib_purge_timeout_value is not None:
                                                return True

                                            if self.route_policy_default_originate is not None:
                                                return True

                                            if self.route_policy_in is not None:
                                                return True

                                            if self.route_policy_out is not None:
                                                return True

                                            if self.route_policy_prefix_orf is not None:
                                                return True

                                            if self.route_refreshes_received is not None:
                                                return True

                                            if self.route_refreshes_sent is not None:
                                                return True

                                            if self.selective_multipath_eligible is not None:
                                                return True

                                            if self.sent_community_to_neighbor is not None:
                                                return True

                                            if self.sent_extended_community_to_neighbor is not None:
                                                return True

                                            if self.sent_gshut_community_to_neighbor is not None:
                                                return True

                                            if self.stale_path_timeout is not None:
                                                return True

                                            if self.synced_acked_version is not None:
                                                return True

                                            if self.update_group_number is not None:
                                                return True

                                            if self.use_max_prefix_warning_only is not None:
                                                return True

                                            if self.vpn_update_gen_enabled is not None:
                                                return True

                                            if self.vpn_update_gen_trigger_enabled is not None:
                                                return True

                                            if self.weight is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.neighbor_address is None:
                                            raise YPYModelError('Key property neighbor_address is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address = ' + str(self.neighbor_address) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.neighbor_address is not None:
                                            return True

                                        if self.active_bmp_servers is not None:
                                            return True

                                        if self.actual_last_write_bytes is not None:
                                            return True

                                        if self.actual_last_write_reset_bytes is not None:
                                            return True

                                        if self.actual_second_last_write_bytes is not None:
                                            return True

                                        if self.actual_second_last_write_reset_bytes is not None:
                                            return True

                                        if self.af_data is not None:
                                            for child_ref in self.af_data:
                                                if child_ref._has_data():
                                                    return True

                                        if self.attempted_last_write_bytes is not None:
                                            return True

                                        if self.attempted_last_write_reset_bytes is not None:
                                            return True

                                        if self.attempted_second_last_write_bytes is not None:
                                            return True

                                        if self.attempted_second_last_write_reset_bytes is not None:
                                            return True

                                        if self.bfd_minintervalval is not None:
                                            return True

                                        if self.bfd_multiplierval is not None:
                                            return True

                                        if self.bfd_session_created_state is not None:
                                            return True

                                        if self.bfd_session_enable_mode is not None:
                                            return True

                                        if self.bfd_session_state is not None:
                                            return True

                                        if self.bfd_state_ts is not None:
                                            return True

                                        if self.bytes_read is not None:
                                            return True

                                        if self.bytes_written is not None:
                                            return True

                                        if self.configured_hold_time is not None:
                                            return True

                                        if self.configured_keepalive is not None:
                                            return True

                                        if self.configured_min_acc_hold_time is not None:
                                            return True

                                        if self.connect_retry_interval is not None:
                                            return True

                                        if self.connection_admin_status is not None:
                                            return True

                                        if self.connection_down_count is not None:
                                            return True

                                        if self.connection_established_time is not None:
                                            return True

                                        if self.connection_local_address is not None and self.connection_local_address._has_data():
                                            return True

                                        if self.connection_local_port is not None:
                                            return True

                                        if self.connection_remote_address is not None and self.connection_remote_address._has_data():
                                            return True

                                        if self.connection_remote_port is not None:
                                            return True

                                        if self.connection_state is not None:
                                            return True

                                        if self.connection_up_count is not None:
                                            return True

                                        if self.count_last_write is not None:
                                            return True

                                        if self.description is not None:
                                            return True

                                        if self.discard_as4_path is not None:
                                            return True

                                        if self.discard_data_bytes is not None:
                                            return True

                                        if self.dmz_link_bandwidth is not None:
                                            return True

                                        if self.dynamic_neighbor is not None:
                                            return True

                                        if self.ebgp_recv_dmz is not None:
                                            return True

                                        if self.ebgp_send_dmz_mode is not None:
                                            return True

                                        if self.ebgp_time_to_live is not None:
                                            return True

                                        if self.egress_peer_engineering_enabled is not None:
                                            return True

                                        if self.error_notifies_received is not None:
                                            return True

                                        if self.error_notifies_sent is not None:
                                            return True

                                        if self.fpbsn_offset is not None:
                                            return True

                                        if self.fssn_offset is not None:
                                            return True

                                        if self.gr_restart_time is not None:
                                            return True

                                        if self.gr_stale_path_time is not None:
                                            return True

                                        if self.graceful_maintenance is not None and self.graceful_maintenance._has_data():
                                            return True

                                        if self.graceful_restart_enabled_nbr is not None:
                                            return True

                                        if self.has_internal_link is not None:
                                            return True

                                        if self.hold_time is not None:
                                            return True

                                        if self.ignore_connected is not None:
                                            return True

                                        if self.internal_vpn_client is not None:
                                            return True

                                        if self.io_armed is not None:
                                            return True

                                        if self.is4_byte_as_capability_received is not None:
                                            return True

                                        if self.is4_byte_as_capability_sent is not None:
                                            return True

                                        if self.is_administratively_shut_down is not None:
                                            return True

                                        if self.is_capability_negotiation_performed is not None:
                                            return True

                                        if self.is_capability_negotiation_suppressed is not None:
                                            return True

                                        if self.is_ebgp_multihop_bgpmpls_forwarding_disabled is not None:
                                            return True

                                        if self.is_ebgp_peer_as_league is not None:
                                            return True

                                        if self.is_ebgp_peer_common_admin is not None:
                                            return True

                                        if self.is_external_neighbor_not_directly_connected is not None:
                                            return True

                                        if self.is_gr_aware is not None:
                                            return True

                                        if self.is_local_address_configured is not None:
                                            return True

                                        if self.is_neighbor_max_prefix_shutdown is not None:
                                            return True

                                        if self.is_out_of_memory_forced_up is not None:
                                            return True

                                        if self.is_out_of_memory_shutdown is not None:
                                            return True

                                        if self.is_passive_close is not None:
                                            return True

                                        if self.is_read_disabled is not None:
                                            return True

                                        if self.is_route_refresh_capability_received is not None:
                                            return True

                                        if self.is_route_refresh_old_capability_received is not None:
                                            return True

                                        if self.keep_alive_time is not None:
                                            return True

                                        if self.last_ackd_seq_no is not None:
                                            return True

                                        if self.last_k_aerror_reset is not None:
                                            return True

                                        if self.last_k_aexpiry_reset is not None:
                                            return True

                                        if self.last_k_anotsent_reset is not None:
                                            return True

                                        if self.last_k_astart_reset is not None:
                                            return True

                                        if self.last_notify_error_code is not None:
                                            return True

                                        if self.last_notify_error_subcode is not None:
                                            return True

                                        if self.last_write_event is not None:
                                            return True

                                        if self.local_as is not None:
                                            return True

                                        if self.local_as_dual_as is not None:
                                            return True

                                        if self.local_as_dual_as_mode_native is not None:
                                            return True

                                        if self.local_as_no_prepend is not None:
                                            return True

                                        if self.local_as_replace_as is not None:
                                            return True

                                        if self.message_statistics is not None and self.message_statistics._has_data():
                                            return True

                                        if self.messages_queued_in is not None:
                                            return True

                                        if self.messages_queued_out is not None:
                                            return True

                                        if self.messages_received is not None:
                                            return True

                                        if self.messages_sent is not None:
                                            return True

                                        if self.min_advertise_interval is not None:
                                            return True

                                        if self.min_advertise_interval_msecs is not None:
                                            return True

                                        if self.min_origination_interval is not None:
                                            return True

                                        if self.msg_log_in is not None:
                                            return True

                                        if self.msg_log_out is not None:
                                            return True

                                        if self.multi_protocol_capability_received is not None:
                                            return True

                                        if self.nbr_cluster_id is not None:
                                            return True

                                        if self.nbr_enforce_first_as is not None:
                                            return True

                                        if self.nbr_in_cluster is not None:
                                            return True

                                        if self.negotiated_protocol_version is not None:
                                            return True

                                        if self.neighbor_interface_handle is not None:
                                            return True

                                        if self.neighbor_local_as is not None:
                                            return True

                                        if self.nsr_enabled is not None:
                                            return True

                                        if self.nsr_state is not None:
                                            return True

                                        if self.open_check_error_code is not None:
                                            return True

                                        if self.peer_error_code is not None:
                                            return True

                                        if self.peer_reset_reason is not None:
                                            return True

                                        if self.performance_statistics is not None and self.performance_statistics._has_data():
                                            return True

                                        if self.previous_connection_state is not None:
                                            return True

                                        if self.read_armed is not None:
                                            return True

                                        if self.received_notification_info is not None and self.received_notification_info._has_data():
                                            return True

                                        if self.remote_as is not None:
                                            return True

                                        if self.remote_as_number is not None:
                                            return True

                                        if self.reset_notification_sent is not None:
                                            return True

                                        if self.reset_reason is not None:
                                            return True

                                        if self.router_id is not None:
                                            return True

                                        if self.rpki_allow_invalid is not None:
                                            return True

                                        if self.rpki_disable is not None:
                                            return True

                                        if self.rpki_signal_ibgp is not None:
                                            return True

                                        if self.rpki_use_validity is not None:
                                            return True

                                        if self.second_last_k_aexpiry_reset is not None:
                                            return True

                                        if self.second_last_k_astart_reset is not None:
                                            return True

                                        if self.second_last_write_event is not None:
                                            return True

                                        if self.send_notification_info is not None and self.send_notification_info._has_data():
                                            return True

                                        if self.socket_read_bytes is not None:
                                            return True

                                        if self.speaker_id is not None:
                                            return True

                                        if self.standby_rp is not None:
                                            return True

                                        if self.suppress4_byte_as is not None:
                                            return True

                                        if self.tcp_init_sync_done_time_spec is not None and self.tcp_init_sync_done_time_spec._has_data():
                                            return True

                                        if self.tcp_init_sync_phase_two_time_spec is not None and self.tcp_init_sync_phase_two_time_spec._has_data():
                                            return True

                                        if self.tcp_init_sync_time_spec is not None and self.tcp_init_sync_time_spec._has_data():
                                            return True

                                        if self.tcp_session_open_mode is not None:
                                            return True

                                        if self.tcpmss is not None:
                                            return True

                                        if self.time_last_cb is not None:
                                            return True

                                        if self.time_last_cb_reset is not None:
                                            return True

                                        if self.time_last_fb is not None:
                                            return True

                                        if self.time_since_connection_last_dropped is not None:
                                            return True

                                        if self.time_since_last_read is not None:
                                            return True

                                        if self.time_since_last_read_reset is not None:
                                            return True

                                        if self.time_since_last_update is not None:
                                            return True

                                        if self.time_since_last_write is not None:
                                            return True

                                        if self.time_since_last_write_reset is not None:
                                            return True

                                        if self.time_since_second_last_write is not None:
                                            return True

                                        if self.time_since_second_last_write_reset is not None:
                                            return True

                                        if self.tos_type is not None:
                                            return True

                                        if self.tos_value is not None:
                                            return True

                                        if self.ttl_security_enabled is not None:
                                            return True

                                        if self.update_bytes_read is not None:
                                            return True

                                        if self.update_messages_in is not None:
                                            return True

                                        if self.update_messages_out is not None:
                                            return True

                                        if self.vrf_name is not None:
                                            return True

                                        if self.write_armed is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-af-table'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.neighbor is not None:
                                        for child_ref in self.neighbor:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable']['meta_info']


                            class NetworkAllRds(object):
                                """
                                The BGP Network Lookup Table
                                
                                .. attribute:: network_all_rd
                                
                                	The BGP Network Lookup table
                                	**type**\: list of    :py:class:`NetworkAllRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.network_all_rd = YList()
                                    self.network_all_rd.parent = self
                                    self.network_all_rd.name = 'network_all_rd'


                                class NetworkAllRd(object):
                                    """
                                    The BGP Network Lookup table
                                    
                                    .. attribute:: network_addr  <key>
                                    
                                    	Network in prefix/length format (address part)
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: network_prefix  <key>
                                    
                                    	Network in prefix/length format (prefix part)
                                    	**type**\:  int
                                    
                                    	**range:** 0..128
                                    
                                    .. attribute:: network_rds
                                    
                                    	The BGP Network Lookup table
                                    	**type**\:   :py:class:`NetworkRds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.network_addr = None
                                        self.network_prefix = None
                                        self.network_rds = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds()
                                        self.network_rds.parent = self


                                    class NetworkRds(object):
                                        """
                                        The BGP Network Lookup table
                                        
                                        .. attribute:: network_rd
                                        
                                        	A BGP Network table entry
                                        	**type**\: list of    :py:class:`NetworkRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.network_rd = YList()
                                            self.network_rd.parent = self
                                            self.network_rd.name = 'network_rd'


                                        class NetworkRd(object):
                                            """
                                            A BGP Network table entry
                                            
                                            .. attribute:: rd  <key>
                                            
                                            	Route Distinguisher value
                                            	**type**\:  str
                                            
                                            .. attribute:: active_path_element
                                            
                                            	Path element list received from Active inst
                                            	**type**\: list of    :py:class:`ActivePathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement>`
                                            
                                            .. attribute:: active_process_instance_path
                                            
                                            	Active's paths for this net 
                                            	**type**\: list of    :py:class:`ActiveProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath>`
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix>`
                                            
                                            .. attribute:: bit
                                            
                                            	Bit
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: flags
                                            
                                            	Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: gateway_array
                                            
                                            	Gateway array ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_inconsistent_paths
                                            
                                            	Net has inconsistent paths
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_lbl_retained
                                            
                                            	Net has label retained
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_label
                                            
                                            	Net has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_net_aggregation_suppressed
                                            
                                            	Net suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_net_ldp_signaled
                                            
                                            	L2VPN Net LDP signaled  aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_network
                                            
                                            	Permanent Network
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_element
                                            
                                            	Local path element list
                                            	**type**\: list of    :py:class:`LocalPathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement>`
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: local_process_instance_path
                                            
                                            	Local (to process instance) paths for this net 
                                            	**type**\: list of    :py:class:`LocalProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath>`
                                            
                                            .. attribute:: net_backup_available
                                            
                                            	Net has backup path
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_backup_label_rewrite_available
                                            
                                            	Net has label rewrite for backup path
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_eibgp_multipath
                                            
                                            	Net has EIBGP multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_extended_flags
                                            
                                            	Net extended flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: net_flags
                                            
                                            	Flags associated with                            net
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: net_local_label
                                            
                                            	Local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: net_local_label_rewrite
                                            
                                            	Net label has rewrite
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_local_label_srgb
                                            
                                            	Net label allocated fromSegment routing global block
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_multipath
                                            
                                            	Net has multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: num_of_path
                                            
                                            	Number of path for this net
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: process_instance_id
                                            
                                            	Process instance ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: resilient_nexthop_set
                                            
                                            	Resilient nexthop set ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	RIB install failed
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: table_brib_version
                                            
                                            	Table version # for updates
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: table_version
                                            
                                            	Table version # for net
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: version
                                            
                                            	Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: version_age
                                            
                                            	Version age
                                            	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionAge>`
                                            
                                            .. attribute:: version_timestamp
                                            
                                            	Version timestamp
                                            	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionTimestamp>`
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.rd = None
                                                self.active_path_element = YList()
                                                self.active_path_element.parent = self
                                                self.active_path_element.name = 'active_path_element'
                                                self.active_process_instance_path = YList()
                                                self.active_process_instance_path.parent = self
                                                self.active_process_instance_path.name = 'active_process_instance_path'
                                                self.add_path_orr_bitfield = YList()
                                                self.add_path_orr_bitfield.parent = self
                                                self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                self.advertisedto_pe = None
                                                self.af_name = None
                                                self.best_path_orr_bitfield = YList()
                                                self.best_path_orr_bitfield.parent = self
                                                self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self.bit = None
                                                self.flags = None
                                                self.gateway_array = None
                                                self.has_inconsistent_paths = None
                                                self.has_lbl_retained = None
                                                self.has_local_label = None
                                                self.is_net_aggregation_suppressed = None
                                                self.is_net_ldp_signaled = None
                                                self.is_permanent_network = None
                                                self.local_path_element = YList()
                                                self.local_path_element.parent = self
                                                self.local_path_element.name = 'local_path_element'
                                                self.local_peers_advertised_to = YList()
                                                self.local_peers_advertised_to.parent = self
                                                self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                self.local_process_instance_path = YList()
                                                self.local_process_instance_path.parent = self
                                                self.local_process_instance_path.name = 'local_process_instance_path'
                                                self.net_backup_available = None
                                                self.net_backup_label_rewrite_available = None
                                                self.net_eibgp_multipath = None
                                                self.net_extended_flags = None
                                                self.net_flags = None
                                                self.net_local_label = None
                                                self.net_local_label_rewrite = None
                                                self.net_local_label_srgb = None
                                                self.net_multipath = None
                                                self.num_of_path = None
                                                self.pe_peers_advertised_to = YList()
                                                self.pe_peers_advertised_to.parent = self
                                                self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                self.process_instance_id = None
                                                self.resilient_nexthop_set = None
                                                self.rib_failed = None
                                                self.route_distinguisher = None
                                                self.table_brib_version = None
                                                self.table_version = None
                                                self.version = None
                                                self.version_age = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionAge()
                                                self.version_age.parent = self
                                                self.version_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionTimestamp()
                                                self.version_timestamp.parent = self
                                                self.vrf_name = None


                                            class BgpPrefix(object):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self.prefix_length = None


                                                class Prefix(object):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.prefix is not None and self.prefix._has_data():
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix']['meta_info']


                                            class VersionTimestamp(object):
                                                """
                                                Version timestamp
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionTimestamp']['meta_info']


                                            class VersionAge(object):
                                                """
                                                Version age
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-age'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionAge']['meta_info']


                                            class LocalPeersAdvertisedTo(object):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo']['meta_info']


                                            class PePeersAdvertisedTo(object):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo']['meta_info']


                                            class BestPathOrrBitfield(object):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield']['meta_info']


                                            class AddPathOrrBitfield(object):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield']['meta_info']


                                            class LocalProcessInstancePath(object):
                                                """
                                                Local (to process instance) paths for this net 
                                                
                                                .. attribute:: af_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: attributes_after_policy_in
                                                
                                                	Attributes after inbound policy applied
                                                	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn>`
                                                
                                                .. attribute:: label_fail
                                                
                                                	LSD label allocation failed 
                                                	**type**\:  bool
                                                
                                                .. attribute:: label_o_or_version
                                                
                                                	Label Version when OOR happens
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_oor
                                                
                                                	LSD label space is exhausted
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address_xr
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr>`
                                                
                                                .. attribute:: no_path
                                                
                                                	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                                	**type**\:  bool
                                                
                                                .. attribute:: path_information
                                                
                                                	Path information
                                                	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation>`
                                                
                                                .. attribute:: prefix_version
                                                
                                                	Version of BGP Prefix Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: process_instance_id
                                                
                                                	Process instance ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: source_route_distinguisher
                                                
                                                	Source Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: source_vrf_name
                                                
                                                	Name of the source VRF
                                                	**type**\:  str
                                                
                                                .. attribute:: srcaf_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: vrf_name
                                                
                                                	Name of the VRF
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.af_name = None
                                                    self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn()
                                                    self.attributes_after_policy_in.parent = self
                                                    self.label_fail = None
                                                    self.label_o_or_version = None
                                                    self.label_oor = None
                                                    self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr()
                                                    self.neighbor_address_xr.parent = self
                                                    self.no_path = None
                                                    self.path_information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation()
                                                    self.path_information.parent = self
                                                    self.prefix_version = None
                                                    self.process_instance_id = None
                                                    self.route_distinguisher = None
                                                    self.source_route_distinguisher = None
                                                    self.source_vrf_name = None
                                                    self.srcaf_name = None
                                                    self.vrf_name = None


                                                class NeighborAddressXr(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr']['meta_info']


                                                class PathInformation(object):
                                                    """
                                                    Path information
                                                    
                                                    .. attribute:: accept_own_path
                                                    
                                                    	Accept Own
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: accept_own_self_originated_p_ath
                                                    
                                                    	Accept\-Own self\-originated
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: add_path_orr_bitfield
                                                    
                                                    	ORR Add path Bitfields
                                                    	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                    
                                                    .. attribute:: advertisedto_pe
                                                    
                                                    	Net could be advertised                          to PE peers
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: aigp_metric
                                                    
                                                    	Total AIGP metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: best_path_comp_stage
                                                    
                                                    	Stage where the path lost to the best path or group best
                                                    	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                                    
                                                    .. attribute:: best_path_comp_winner
                                                    
                                                    	Neighbor address of the path which won best path comparison
                                                    	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                    
                                                    .. attribute:: best_path_id
                                                    
                                                    	Best path ID; DEPRECATED BYLocalPathId
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: best_path_id_comp_winner
                                                    
                                                    	Path ID of the path which won best path comparison
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: best_path_orr_bitfield
                                                    
                                                    	ORR Best path Bitfields
                                                    	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                    
                                                    .. attribute:: bgp_prefix
                                                    
                                                    	BGP prefix
                                                    	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix>`
                                                    
                                                    .. attribute:: dampen_penalty
                                                    
                                                    	Dampening penalty
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Mvpn Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                    
                                                    .. attribute:: fspec_invalid_path
                                                    
                                                    	Is Fspec invalid path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: graceful_shutdown
                                                    
                                                    	Marked for graceful shutdown
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: gw_addr
                                                    
                                                    	Path GW Address
                                                    	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.GwAddr>`
                                                    
                                                    .. attribute:: halflife_time
                                                    
                                                    	Half\-life time for the penalty
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_esi
                                                    
                                                    	Path has EVPN ESI
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_gw_addr
                                                    
                                                    	Path has GW Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_local_net_label
                                                    
                                                    	Path has local label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mdt_group_addr
                                                    
                                                    	Path has MDT Group Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_extcomm
                                                    
                                                    	Path has MVPN EXTCOMM feedback
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_nbr_addr
                                                    
                                                    	Path has Mvpn nbr Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_nexthop_addr
                                                    
                                                    	Path has MVPN nexthop Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_pmsi
                                                    
                                                    	Path has MVPN PMSI feedback
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_rcvd_label
                                                    
                                                    	Path has received label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_second_label
                                                    
                                                    	Path has second received label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ibgp_signaled_validity
                                                    
                                                    	IBGP signalled validation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: igp_metric
                                                    
                                                    	IGP metric to the gateway
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_aggregation_suppressed
                                                    
                                                    	Path suppressed due to aggregation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_best
                                                    
                                                    	Best available path within AS
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_best_path
                                                    
                                                    	Best available path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_import_dampened
                                                    
                                                    	net import dampened
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_import_suspect
                                                    
                                                    	net import suspect
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_internal_path
                                                    
                                                    	Received over an internal link
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_best
                                                    
                                                    	Partial best path within distributed speaker
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_additional_path
                                                    
                                                    	Path is an additional\-path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_advertised_local_as_only
                                                    
                                                    	Not advertised outside local AS
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_af_install_eligible
                                                    
                                                    	Path can be installed in AF RIB
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_backup
                                                    
                                                    	Path is a backup path 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_backup_protect_multipath
                                                    
                                                    	Path is a backup path to protect multipaths
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_best_external
                                                    
                                                    	Path is a best external path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_damped
                                                    
                                                    	Path suppressed due to dampening
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_confederation_peer
                                                    
                                                    	Path received from confederation peer
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_network_command
                                                    
                                                    	Path sourced by network command
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_redistribute_command
                                                    
                                                    	Path sourced by redistribute command
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_route_reflector
                                                    
                                                    	Path received from route reflector
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_history_held
                                                    
                                                    	Path entry held to remember history
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_imp_candidate
                                                    
                                                    	Path is a candidate for multipath import
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_imported
                                                    
                                                    	Path is imported
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_local_aggregate
                                                    
                                                    	Path is a locally created aggregate
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_locally_sourced
                                                    
                                                    	Path sourced locally
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_long_lived_stale
                                                    
                                                    	Long lived stale routes learnt before neighbor restarts
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_multipath
                                                    
                                                    	Path is one of multipath best routes
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_nexthop_discarded
                                                    
                                                    	Path is redirected to Null0
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_not_advertised
                                                    
                                                    	Not advertised to any peer
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_not_advertised_to_ebg_ps
                                                    
                                                    	Not advertised to EBGPs
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_received_only
                                                    
                                                    	Path is received only
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_reoriginated
                                                    
                                                    	Path is reoriginated
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_reoriginated_stitching
                                                    
                                                    	Path is reoriginated with stitching RTs
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_stale
                                                    
                                                    	Stale routes learnt before neighbor restarts
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_synced_with_igp
                                                    
                                                    	Path synchronized with IGP
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_valid
                                                    
                                                    	Path attributes are usable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_vpn_only
                                                    
                                                    	Path is not in the vrf
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_permanent_path
                                                    
                                                    	Path is of type Permanent path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_received_path_not_modified
                                                    
                                                    	Received path used without modification
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_spkr_as_best
                                                    
                                                    	Best available path within AS in speaker
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2vpn_circuit_status_value
                                                    
                                                    	L2VPN Circuit Status Value
                                                    	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                    
                                                    .. attribute:: l2vpn_evpn_esi
                                                    
                                                    	L2VPN EVPN ESI
                                                    	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi>`
                                                    
                                                    .. attribute:: l2vpn_size
                                                    
                                                    	Path block size
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: labeled_unicast_safi_path
                                                    
                                                    	Path was learnt by labeled\-unicast SAFI
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: local_label
                                                    
                                                    	Path local label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_nh
                                                    
                                                    	Path has local nexthop
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: local_path_id
                                                    
                                                    	Local path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_peers_advertised_to
                                                    
                                                    	Local peers that this prefix has been advertised to
                                                    	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                    
                                                    .. attribute:: maximum_suppress_time
                                                    
                                                    	Maximum duration to suppress a stable route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mdt_group_addr
                                                    
                                                    	IPv4 MDT Group Address for the path
                                                    	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                    
                                                    .. attribute:: mvpn_nbr_addr
                                                    
                                                    	Mvpn nbr Address for the path
                                                    	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                    
                                                    .. attribute:: mvpn_nexthop_addr
                                                    
                                                    	Mvpn nexthop Address for the path
                                                    	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                    
                                                    .. attribute:: mvpn_path_flags
                                                    
                                                    	Mvpn path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: mvpn_pmsi_flags
                                                    
                                                    	Mvpn PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: mvpn_pmsi_label
                                                    
                                                    	Mvpn PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mvpn_pmsi_type
                                                    
                                                    	Mvpn PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: mvpn_pmsi_value
                                                    
                                                    	Mvpn PMSI Value
                                                    	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                    
                                                    .. attribute:: mvpn_sfs_path
                                                    
                                                    	Is MVPN single forwarder PE path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress>`
                                                    
                                                    .. attribute:: neighbor_router_id
                                                    
                                                    	Router ID of the neighbor for the path
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: next_hop
                                                    
                                                    	Next hop
                                                    	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop>`
                                                    
                                                    .. attribute:: nhte_tunnel
                                                    
                                                    	NH TE tunnel information
                                                    	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhteTunnel>`
                                                    
                                                    .. attribute:: path_flags
                                                    
                                                    	Flags associated with path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: path_flap_count
                                                    
                                                    	Number of times this route has flapped
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_import_flags
                                                    
                                                    	Path import flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_rt_set_id
                                                    
                                                    	RT\-set id of the path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_rt_set_route_count
                                                    
                                                    	Count in RT\-set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_table_version
                                                    
                                                    	Table version # for pelem
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_weight
                                                    
                                                    	Weight for the path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pe_peers_advertised_to
                                                    
                                                    	PE peers that this prefix has been advertised to
                                                    	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                    
                                                    .. attribute:: rcvd_label
                                                    
                                                    	Path received label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rcvd_path_id
                                                    
                                                    	Received path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: reuse_value
                                                    
                                                    	Value to start reusing a route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rib_failed
                                                    
                                                    	Is net failed installed                          in RIB
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: route_type
                                                    
                                                    	Route Type of path
                                                    	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                                    
                                                    .. attribute:: rpki_origin_as_validation_disabled
                                                    
                                                    	RPKI originAS V. Disabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rt_set_limit_enabled
                                                    
                                                    	Path subject to RT\-set net limit
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_label
                                                    
                                                    	Path second received label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: seconds_since_first_flap
                                                    
                                                    	Seconds since route first flapped
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: show_rpki_origin_as_validity
                                                    
                                                    	Display validity state ?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: sn_rpki_origin_as_validity
                                                    
                                                    	RPKI origin validation state
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: suppress_penalty
                                                    
                                                    	Value to start suppressing a route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: time_to_unsuppress
                                                    
                                                    	Seconds until route is unsuppressed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.accept_own_path = None
                                                        self.accept_own_self_originated_p_ath = None
                                                        self.add_path_orr_bitfield = YList()
                                                        self.add_path_orr_bitfield.parent = self
                                                        self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                        self.advertisedto_pe = None
                                                        self.aigp_metric = None
                                                        self.best_path_comp_stage = None
                                                        self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner()
                                                        self.best_path_comp_winner.parent = self
                                                        self.best_path_id = None
                                                        self.best_path_id_comp_winner = None
                                                        self.best_path_orr_bitfield = YList()
                                                        self.best_path_orr_bitfield.parent = self
                                                        self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                        self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix()
                                                        self.bgp_prefix.parent = self
                                                        self.dampen_penalty = None
                                                        self.extended_community = YList()
                                                        self.extended_community.parent = self
                                                        self.extended_community.name = 'extended_community'
                                                        self.fspec_invalid_path = None
                                                        self.graceful_shutdown = None
                                                        self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.GwAddr()
                                                        self.gw_addr.parent = self
                                                        self.halflife_time = None
                                                        self.has_esi = None
                                                        self.has_gw_addr = None
                                                        self.has_local_net_label = None
                                                        self.has_mdt_group_addr = None
                                                        self.has_mvpn_extcomm = None
                                                        self.has_mvpn_nbr_addr = None
                                                        self.has_mvpn_nexthop_addr = None
                                                        self.has_mvpn_pmsi = None
                                                        self.has_rcvd_label = None
                                                        self.has_second_label = None
                                                        self.ibgp_signaled_validity = None
                                                        self.igp_metric = None
                                                        self.is_aggregation_suppressed = None
                                                        self.is_as_best = None
                                                        self.is_best_path = None
                                                        self.is_import_dampened = None
                                                        self.is_import_suspect = None
                                                        self.is_internal_path = None
                                                        self.is_partial_best = None
                                                        self.is_path_additional_path = None
                                                        self.is_path_advertised_local_as_only = None
                                                        self.is_path_af_install_eligible = None
                                                        self.is_path_backup = None
                                                        self.is_path_backup_protect_multipath = None
                                                        self.is_path_best_external = None
                                                        self.is_path_damped = None
                                                        self.is_path_from_confederation_peer = None
                                                        self.is_path_from_network_command = None
                                                        self.is_path_from_redistribute_command = None
                                                        self.is_path_from_route_reflector = None
                                                        self.is_path_history_held = None
                                                        self.is_path_imp_candidate = None
                                                        self.is_path_imported = None
                                                        self.is_path_local_aggregate = None
                                                        self.is_path_locally_sourced = None
                                                        self.is_path_long_lived_stale = None
                                                        self.is_path_multipath = None
                                                        self.is_path_nexthop_discarded = None
                                                        self.is_path_not_advertised = None
                                                        self.is_path_not_advertised_to_ebg_ps = None
                                                        self.is_path_received_only = None
                                                        self.is_path_reoriginated = None
                                                        self.is_path_reoriginated_stitching = None
                                                        self.is_path_stale = None
                                                        self.is_path_synced_with_igp = None
                                                        self.is_path_valid = None
                                                        self.is_path_vpn_only = None
                                                        self.is_permanent_path = None
                                                        self.is_received_path_not_modified = None
                                                        self.is_spkr_as_best = None
                                                        self.l2vpn_circuit_status_value = YList()
                                                        self.l2vpn_circuit_status_value.parent = self
                                                        self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                        self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi()
                                                        self.l2vpn_evpn_esi.parent = self
                                                        self.l2vpn_size = None
                                                        self.labeled_unicast_safi_path = None
                                                        self.local_label = None
                                                        self.local_nh = None
                                                        self.local_path_id = None
                                                        self.local_peers_advertised_to = YList()
                                                        self.local_peers_advertised_to.parent = self
                                                        self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                        self.maximum_suppress_time = None
                                                        self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr()
                                                        self.mdt_group_addr.parent = self
                                                        self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                        self.mvpn_nbr_addr.parent = self
                                                        self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                        self.mvpn_nexthop_addr.parent = self
                                                        self.mvpn_path_flags = None
                                                        self.mvpn_pmsi_flags = None
                                                        self.mvpn_pmsi_label = None
                                                        self.mvpn_pmsi_type = None
                                                        self.mvpn_pmsi_value = YList()
                                                        self.mvpn_pmsi_value.parent = self
                                                        self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                        self.mvpn_sfs_path = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.neighbor_router_id = None
                                                        self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop()
                                                        self.next_hop.parent = self
                                                        self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhteTunnel()
                                                        self.nhte_tunnel.parent = self
                                                        self.path_flags = None
                                                        self.path_flap_count = None
                                                        self.path_import_flags = None
                                                        self.path_rt_set_id = None
                                                        self.path_rt_set_route_count = None
                                                        self.path_table_version = None
                                                        self.path_weight = None
                                                        self.pe_peers_advertised_to = YList()
                                                        self.pe_peers_advertised_to.parent = self
                                                        self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                        self.rcvd_label = None
                                                        self.rcvd_path_id = None
                                                        self.reuse_value = None
                                                        self.rib_failed = None
                                                        self.route_type = None
                                                        self.rpki_origin_as_validation_disabled = None
                                                        self.rt_set_limit_enabled = None
                                                        self.second_label = None
                                                        self.seconds_since_first_flap = None
                                                        self.show_rpki_origin_as_validity = None
                                                        self.sn_rpki_origin_as_validity = None
                                                        self.suppress_penalty = None
                                                        self.time_to_unsuppress = None


                                                    class BgpPrefix(object):
                                                        """
                                                        BGP prefix
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Prefix
                                                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                            self.prefix.parent = self
                                                            self.prefix_length = None


                                                        class Prefix(object):
                                                            """
                                                            Prefix
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.prefix is not None and self.prefix._has_data():
                                                                return True

                                                            if self.prefix_length is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix']['meta_info']


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress']['meta_info']


                                                    class NextHop(object):
                                                        """
                                                        Next hop
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop']['meta_info']


                                                    class NhteTunnel(object):
                                                        """
                                                        NH TE tunnel information
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	Binding label for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_te_tunnel
                                                        
                                                        	NH TE Tunnel info is present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_info_stale
                                                        
                                                        	Tunnel is stale
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_registered
                                                        
                                                        	Tunnel registered flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_up
                                                        
                                                        	Tunnel Up flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: last_tunnel_update
                                                        
                                                        	Time since the last rib update happened
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_if_handle
                                                        
                                                        	Interface handle for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_name
                                                        
                                                        	tunnel name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        .. attribute:: tunnel_type
                                                        
                                                        	tunnel type
                                                        	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                        
                                                        .. attribute:: tunnel_v6_enabled
                                                        
                                                        	IPv6 enabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_v6_required
                                                        
                                                        	Tunnel need IPv6
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.binding_label = None
                                                            self.has_te_tunnel = None
                                                            self.is_tunnel_info_stale = None
                                                            self.is_tunnel_registered = None
                                                            self.is_tunnel_up = None
                                                            self.last_tunnel_update = None
                                                            self.tunnel_if_handle = None
                                                            self.tunnel_name = None
                                                            self.tunnel_type = None
                                                            self.tunnel_v6_enabled = None
                                                            self.tunnel_v6_required = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.binding_label is not None:
                                                                return True

                                                            if self.has_te_tunnel is not None:
                                                                return True

                                                            if self.is_tunnel_info_stale is not None:
                                                                return True

                                                            if self.is_tunnel_registered is not None:
                                                                return True

                                                            if self.is_tunnel_up is not None:
                                                                return True

                                                            if self.last_tunnel_update is not None:
                                                                return True

                                                            if self.tunnel_if_handle is not None:
                                                                return True

                                                            if self.tunnel_name is not None:
                                                                return True

                                                            if self.tunnel_type is not None:
                                                                return True

                                                            if self.tunnel_v6_enabled is not None:
                                                                return True

                                                            if self.tunnel_v6_required is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhteTunnel']['meta_info']


                                                    class MdtGroupAddr(object):
                                                        """
                                                        IPv4 MDT Group Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr']['meta_info']


                                                    class L2VpnEvpnEsi(object):
                                                        """
                                                        L2VPN EVPN ESI
                                                        
                                                        .. attribute:: esi
                                                        
                                                        	esi
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.esi = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.esi is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi']['meta_info']


                                                    class GwAddr(object):
                                                        """
                                                        Path GW Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_address = None
                                                            self.ipv6_address = None
                                                            self.len = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.len is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.GwAddr']['meta_info']


                                                    class BestPathCompWinner(object):
                                                        """
                                                        Neighbor address of the path which won best path
                                                        comparison
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner']['meta_info']


                                                    class MvpnNbrAddr(object):
                                                        """
                                                        Mvpn nbr Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr']['meta_info']


                                                    class MvpnNexthopAddr(object):
                                                        """
                                                        Mvpn nexthop Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr']['meta_info']


                                                    class L2VpnCircuitStatusValue(object):
                                                        """
                                                        L2VPN Circuit Status Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                                    class MvpnPmsiValue(object):
                                                        """
                                                        Mvpn PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue']['meta_info']


                                                    class ExtendedCommunity(object):
                                                        """
                                                        Mvpn Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity']['meta_info']


                                                    class LocalPeersAdvertisedTo(object):
                                                        """
                                                        Local peers that this prefix has been advertised
                                                        to
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.is_neighbor = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.update_group_number = None


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.is_neighbor is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.update_group_number is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                                    class PePeersAdvertisedTo(object):
                                                        """
                                                        PE peers that this prefix has been advertised to
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.is_neighbor = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.update_group_number = None


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.is_neighbor is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.update_group_number is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo']['meta_info']


                                                    class BestPathOrrBitfield(object):
                                                        """
                                                        ORR Best path Bitfields
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.is_neighbor = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.update_group_number = None


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.is_neighbor is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.update_group_number is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield']['meta_info']


                                                    class AddPathOrrBitfield(object):
                                                        """
                                                        ORR Add path Bitfields
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.is_neighbor = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.update_group_number = None


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.is_neighbor is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.update_group_number is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.accept_own_path is not None:
                                                            return True

                                                        if self.accept_own_self_originated_p_ath is not None:
                                                            return True

                                                        if self.add_path_orr_bitfield is not None:
                                                            for child_ref in self.add_path_orr_bitfield:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.advertisedto_pe is not None:
                                                            return True

                                                        if self.aigp_metric is not None:
                                                            return True

                                                        if self.best_path_comp_stage is not None:
                                                            return True

                                                        if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                            return True

                                                        if self.best_path_id is not None:
                                                            return True

                                                        if self.best_path_id_comp_winner is not None:
                                                            return True

                                                        if self.best_path_orr_bitfield is not None:
                                                            for child_ref in self.best_path_orr_bitfield:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                            return True

                                                        if self.dampen_penalty is not None:
                                                            return True

                                                        if self.extended_community is not None:
                                                            for child_ref in self.extended_community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.fspec_invalid_path is not None:
                                                            return True

                                                        if self.graceful_shutdown is not None:
                                                            return True

                                                        if self.gw_addr is not None and self.gw_addr._has_data():
                                                            return True

                                                        if self.halflife_time is not None:
                                                            return True

                                                        if self.has_esi is not None:
                                                            return True

                                                        if self.has_gw_addr is not None:
                                                            return True

                                                        if self.has_local_net_label is not None:
                                                            return True

                                                        if self.has_mdt_group_addr is not None:
                                                            return True

                                                        if self.has_mvpn_extcomm is not None:
                                                            return True

                                                        if self.has_mvpn_nbr_addr is not None:
                                                            return True

                                                        if self.has_mvpn_nexthop_addr is not None:
                                                            return True

                                                        if self.has_mvpn_pmsi is not None:
                                                            return True

                                                        if self.has_rcvd_label is not None:
                                                            return True

                                                        if self.has_second_label is not None:
                                                            return True

                                                        if self.ibgp_signaled_validity is not None:
                                                            return True

                                                        if self.igp_metric is not None:
                                                            return True

                                                        if self.is_aggregation_suppressed is not None:
                                                            return True

                                                        if self.is_as_best is not None:
                                                            return True

                                                        if self.is_best_path is not None:
                                                            return True

                                                        if self.is_import_dampened is not None:
                                                            return True

                                                        if self.is_import_suspect is not None:
                                                            return True

                                                        if self.is_internal_path is not None:
                                                            return True

                                                        if self.is_partial_best is not None:
                                                            return True

                                                        if self.is_path_additional_path is not None:
                                                            return True

                                                        if self.is_path_advertised_local_as_only is not None:
                                                            return True

                                                        if self.is_path_af_install_eligible is not None:
                                                            return True

                                                        if self.is_path_backup is not None:
                                                            return True

                                                        if self.is_path_backup_protect_multipath is not None:
                                                            return True

                                                        if self.is_path_best_external is not None:
                                                            return True

                                                        if self.is_path_damped is not None:
                                                            return True

                                                        if self.is_path_from_confederation_peer is not None:
                                                            return True

                                                        if self.is_path_from_network_command is not None:
                                                            return True

                                                        if self.is_path_from_redistribute_command is not None:
                                                            return True

                                                        if self.is_path_from_route_reflector is not None:
                                                            return True

                                                        if self.is_path_history_held is not None:
                                                            return True

                                                        if self.is_path_imp_candidate is not None:
                                                            return True

                                                        if self.is_path_imported is not None:
                                                            return True

                                                        if self.is_path_local_aggregate is not None:
                                                            return True

                                                        if self.is_path_locally_sourced is not None:
                                                            return True

                                                        if self.is_path_long_lived_stale is not None:
                                                            return True

                                                        if self.is_path_multipath is not None:
                                                            return True

                                                        if self.is_path_nexthop_discarded is not None:
                                                            return True

                                                        if self.is_path_not_advertised is not None:
                                                            return True

                                                        if self.is_path_not_advertised_to_ebg_ps is not None:
                                                            return True

                                                        if self.is_path_received_only is not None:
                                                            return True

                                                        if self.is_path_reoriginated is not None:
                                                            return True

                                                        if self.is_path_reoriginated_stitching is not None:
                                                            return True

                                                        if self.is_path_stale is not None:
                                                            return True

                                                        if self.is_path_synced_with_igp is not None:
                                                            return True

                                                        if self.is_path_valid is not None:
                                                            return True

                                                        if self.is_path_vpn_only is not None:
                                                            return True

                                                        if self.is_permanent_path is not None:
                                                            return True

                                                        if self.is_received_path_not_modified is not None:
                                                            return True

                                                        if self.is_spkr_as_best is not None:
                                                            return True

                                                        if self.l2vpn_circuit_status_value is not None:
                                                            for child_ref in self.l2vpn_circuit_status_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                            return True

                                                        if self.l2vpn_size is not None:
                                                            return True

                                                        if self.labeled_unicast_safi_path is not None:
                                                            return True

                                                        if self.local_label is not None:
                                                            return True

                                                        if self.local_nh is not None:
                                                            return True

                                                        if self.local_path_id is not None:
                                                            return True

                                                        if self.local_peers_advertised_to is not None:
                                                            for child_ref in self.local_peers_advertised_to:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.maximum_suppress_time is not None:
                                                            return True

                                                        if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                            return True

                                                        if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                            return True

                                                        if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                            return True

                                                        if self.mvpn_path_flags is not None:
                                                            return True

                                                        if self.mvpn_pmsi_flags is not None:
                                                            return True

                                                        if self.mvpn_pmsi_label is not None:
                                                            return True

                                                        if self.mvpn_pmsi_type is not None:
                                                            return True

                                                        if self.mvpn_pmsi_value is not None:
                                                            for child_ref in self.mvpn_pmsi_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.mvpn_sfs_path is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.neighbor_router_id is not None:
                                                            return True

                                                        if self.next_hop is not None and self.next_hop._has_data():
                                                            return True

                                                        if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                            return True

                                                        if self.path_flags is not None:
                                                            return True

                                                        if self.path_flap_count is not None:
                                                            return True

                                                        if self.path_import_flags is not None:
                                                            return True

                                                        if self.path_rt_set_id is not None:
                                                            return True

                                                        if self.path_rt_set_route_count is not None:
                                                            return True

                                                        if self.path_table_version is not None:
                                                            return True

                                                        if self.path_weight is not None:
                                                            return True

                                                        if self.pe_peers_advertised_to is not None:
                                                            for child_ref in self.pe_peers_advertised_to:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.rcvd_label is not None:
                                                            return True

                                                        if self.rcvd_path_id is not None:
                                                            return True

                                                        if self.reuse_value is not None:
                                                            return True

                                                        if self.rib_failed is not None:
                                                            return True

                                                        if self.route_type is not None:
                                                            return True

                                                        if self.rpki_origin_as_validation_disabled is not None:
                                                            return True

                                                        if self.rt_set_limit_enabled is not None:
                                                            return True

                                                        if self.second_label is not None:
                                                            return True

                                                        if self.seconds_since_first_flap is not None:
                                                            return True

                                                        if self.show_rpki_origin_as_validity is not None:
                                                            return True

                                                        if self.sn_rpki_origin_as_validity is not None:
                                                            return True

                                                        if self.suppress_penalty is not None:
                                                            return True

                                                        if self.time_to_unsuppress is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation']['meta_info']


                                                class AttributesAfterPolicyIn(object):
                                                    """
                                                    Attributes after inbound policy applied
                                                    
                                                    .. attribute:: attr_set
                                                    
                                                    	ATTR\_SET attribute
                                                    	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                    
                                                    .. attribute:: attribute_key_number
                                                    
                                                    	Attribute key number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_config
                                                    
                                                    	Attribute reuse ID Configured
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: attribute_reuse_id_current
                                                    
                                                    	Attribute reuse ID current ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_keys
                                                    
                                                    	Attribute reuse ID allocated keys
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_max_id
                                                    
                                                    	Attribute reuse ID maximum ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_node
                                                    
                                                    	Attribute reuse ID nodes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_recover_sec
                                                    
                                                    	Attribute reuse ID timer in seconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: common_attributes
                                                    
                                                    	Common attributes
                                                    	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                    
                                                    .. attribute:: is_application_gateway_present
                                                    
                                                    	Application gateway present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path2_byte
                                                    
                                                    	AS path encoded as 2\-byte
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_attr_set_present
                                                    
                                                    	BGP ATTR\_SET attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ribrnh_present
                                                    
                                                    	RIB RNH Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_rnh_present
                                                    
                                                    	RNH Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ribrnh_encap
                                                    
                                                    	RIB RNH Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ribrnh_ip
                                                    
                                                    	RIB RNH IP Address
                                                    	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                    
                                                    .. attribute:: ribrnh_mac
                                                    
                                                    	RIB RNH MAC Address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    .. attribute:: ribrnh_table
                                                    
                                                    	RIB RNH Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ribrnh_vni
                                                    
                                                    	RIB RNH Vni
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ribrnhip_table
                                                    
                                                    	RIB RNH IP Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rnh_addr
                                                    
                                                    	RNH Address
                                                    	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                    
                                                    .. attribute:: rnh_addr_len
                                                    
                                                    	RNH Address Length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rnh_len
                                                    
                                                    	RNH Length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: rnh_type
                                                    
                                                    	RNH Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: set_aigp_inbound_igp
                                                    
                                                    	AIGP set by policy inbound IGP 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: set_aigp_inbound_metric
                                                    
                                                    	AIGP set by policy inbound metric
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: vpn_distinguisher
                                                    
                                                    	VPN Distinguisher
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                        self.attr_set.parent = self
                                                        self.attribute_key_number = None
                                                        self.attribute_reuse_id_config = None
                                                        self.attribute_reuse_id_current = None
                                                        self.attribute_reuse_id_keys = None
                                                        self.attribute_reuse_id_max_id = None
                                                        self.attribute_reuse_id_node = None
                                                        self.attribute_reuse_id_recover_sec = None
                                                        self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                        self.common_attributes.parent = self
                                                        self.is_application_gateway_present = None
                                                        self.is_as_path2_byte = None
                                                        self.is_attr_set_present = None
                                                        self.is_ribrnh_present = None
                                                        self.is_rnh_present = None
                                                        self.ribrnh_encap = None
                                                        self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                        self.ribrnh_ip.parent = self
                                                        self.ribrnh_mac = None
                                                        self.ribrnh_table = None
                                                        self.ribrnh_vni = None
                                                        self.ribrnhip_table = None
                                                        self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                        self.rnh_addr.parent = self
                                                        self.rnh_addr_len = None
                                                        self.rnh_len = None
                                                        self.rnh_type = None
                                                        self.set_aigp_inbound_igp = None
                                                        self.set_aigp_inbound_metric = None
                                                        self.vpn_distinguisher = None


                                                    class CommonAttributes(object):
                                                        """
                                                        Common attributes
                                                        
                                                        .. attribute:: aggregator_address
                                                        
                                                        	Address where aggregation was performed
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: aggregator_as
                                                        
                                                        	AS where aggregation was last performed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: aigp_metric_value
                                                        
                                                        	AIGP metric value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: as_path
                                                        
                                                        	AS path attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: cluster
                                                        
                                                        	Cluster list attribute
                                                        	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                        
                                                        .. attribute:: community
                                                        
                                                        	Community attribute
                                                        	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                        
                                                        .. attribute:: connector_type
                                                        
                                                        	Connector Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: connector_value
                                                        
                                                        	Connector Value
                                                        	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                        
                                                        .. attribute:: extended_community_flags
                                                        
                                                        	Extended community Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: is_aggregator_present
                                                        
                                                        	Aggregator attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_aigp_present
                                                        
                                                        	AIGP Present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path_present
                                                        
                                                        	AS path attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_atomic_aggregate_present
                                                        
                                                        	Atomic aggregate attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_community_present
                                                        
                                                        	Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_connector_present
                                                        
                                                        	Connector present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_extended_community_present
                                                        
                                                        	Extended community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_label_index_present
                                                        
                                                        	Label Index attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_local_pref_present
                                                        
                                                        	Local Preference attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ls_attribute_present
                                                        
                                                        	BGP LS attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_metric_present
                                                        
                                                        	Metric attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_origin_present
                                                        
                                                        	Origin attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pe_distinguisher_label_present
                                                        
                                                        	PE distinguisher label  attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pmsi_present
                                                        
                                                        	PMSI Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pppmp_present
                                                        
                                                        	PPMP Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ssa_present
                                                        
                                                        	SSA attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_encap_present
                                                        
                                                        	Tunnel Encap attribute present 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2tpv3_cookie
                                                        
                                                        	L2TPv3 Cookie
                                                        	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                        
                                                        .. attribute:: l2tpv3_session_id
                                                        
                                                        	L2TPv3 session id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: label_index_attr
                                                        
                                                        	Label Index attribute
                                                        	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                        
                                                        .. attribute:: local_preference
                                                        
                                                        	Local preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ls_attr
                                                        
                                                        	BGP LS attribute
                                                        	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: neighbor_as
                                                        
                                                        	Neighbor AS number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: origin
                                                        
                                                        	Origin
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: originator
                                                        
                                                        	Originator attribute
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: pe_distinguisher_label
                                                        
                                                        	PE distinguisher label attribute
                                                        	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                        
                                                        .. attribute:: pmsi_flags
                                                        
                                                        	PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pmsi_label
                                                        
                                                        	PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pmsi_type
                                                        
                                                        	PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pmsi_value
                                                        
                                                        	PMSI Value
                                                        	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                        
                                                        .. attribute:: ppm_pvalue
                                                        
                                                        	PPMP Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: sr_policy_allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                        
                                                        .. attribute:: sr_policy_binding_sid
                                                        
                                                        	SR Policy Binding sid
                                                        	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                        
                                                        .. attribute:: sr_policy_explicit_path
                                                        
                                                        	SR Policy Explicit paths
                                                        	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                        
                                                        .. attribute:: sr_policy_preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: sr_tunnel_request_state
                                                        
                                                        	SR Tunnel Request State
                                                        	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                        
                                                        .. attribute:: sr_tunnel_state
                                                        
                                                        	SR Tunnel State
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encap Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: unknown_attribute
                                                        
                                                        	Unknown attributes
                                                        	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.aggregator_address = None
                                                            self.aggregator_as = None
                                                            self.aigp_metric_value = None
                                                            self.as_path = None
                                                            self.cluster = YList()
                                                            self.cluster.parent = self
                                                            self.cluster.name = 'cluster'
                                                            self.community = YList()
                                                            self.community.parent = self
                                                            self.community.name = 'community'
                                                            self.connector_type = None
                                                            self.connector_value = YList()
                                                            self.connector_value.parent = self
                                                            self.connector_value.name = 'connector_value'
                                                            self.extended_community = YList()
                                                            self.extended_community.parent = self
                                                            self.extended_community.name = 'extended_community'
                                                            self.extended_community_flags = None
                                                            self.is_aggregator_present = None
                                                            self.is_aigp_present = None
                                                            self.is_as_path_present = None
                                                            self.is_atomic_aggregate_present = None
                                                            self.is_community_present = None
                                                            self.is_connector_present = None
                                                            self.is_extended_community_present = None
                                                            self.is_label_index_present = None
                                                            self.is_local_pref_present = None
                                                            self.is_ls_attribute_present = None
                                                            self.is_metric_present = None
                                                            self.is_origin_present = None
                                                            self.is_pe_distinguisher_label_present = None
                                                            self.is_pmsi_present = None
                                                            self.is_pppmp_present = None
                                                            self.is_ssa_present = None
                                                            self.is_tunnel_encap_present = None
                                                            self.l2tpv3_cookie = YList()
                                                            self.l2tpv3_cookie.parent = self
                                                            self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                            self.l2tpv3_session_id = None
                                                            self.label_index_attr = YList()
                                                            self.label_index_attr.parent = self
                                                            self.label_index_attr.name = 'label_index_attr'
                                                            self.local_preference = None
                                                            self.ls_attr = YList()
                                                            self.ls_attr.parent = self
                                                            self.ls_attr.name = 'ls_attr'
                                                            self.metric = None
                                                            self.neighbor_as = None
                                                            self.origin = None
                                                            self.originator = None
                                                            self.pe_distinguisher_label = YList()
                                                            self.pe_distinguisher_label.parent = self
                                                            self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                            self.pmsi_flags = None
                                                            self.pmsi_label = None
                                                            self.pmsi_type = None
                                                            self.pmsi_value = YList()
                                                            self.pmsi_value.parent = self
                                                            self.pmsi_value.name = 'pmsi_value'
                                                            self.ppm_pvalue = None
                                                            self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                            self.sr_policy_allocated_binding_sid.parent = self
                                                            self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                            self.sr_policy_binding_sid.parent = self
                                                            self.sr_policy_explicit_path = YList()
                                                            self.sr_policy_explicit_path.parent = self
                                                            self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                            self.sr_policy_preference = None
                                                            self.sr_tunnel_request_state = None
                                                            self.sr_tunnel_state = None
                                                            self.tunnel_encap_type = None
                                                            self.unknown_attribute = YList()
                                                            self.unknown_attribute.parent = self
                                                            self.unknown_attribute.name = 'unknown_attribute'


                                                        class SrPolicyBindingSid(object):
                                                            """
                                                            SR Policy Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_address = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                        class SrPolicyAllocatedBindingSid(object):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_address = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                        class Community(object):
                                                            """
                                                            Community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                        class ExtendedCommunity(object):
                                                            """
                                                            Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                        class UnknownAttribute(object):
                                                            """
                                                            Unknown attributes
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                        class Cluster(object):
                                                            """
                                                            Cluster list attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                        class L2Tpv3Cookie(object):
                                                            """
                                                            L2TPv3 Cookie
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                        class ConnectorValue(object):
                                                            """
                                                            Connector Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                        class PmsiValue(object):
                                                            """
                                                            PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                        class LsAttr(object):
                                                            """
                                                            BGP LS attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                        class LabelIndexAttr(object):
                                                            """
                                                            Label Index attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                        class PeDistinguisherLabel(object):
                                                            """
                                                            PE distinguisher label attribute
                                                            
                                                            .. attribute:: label
                                                            
                                                            	Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pe_address
                                                            
                                                            	 PE address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.label = None
                                                                self.pe_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.label is not None:
                                                                    return True

                                                                if self.pe_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                        class SrPolicyExplicitPath(object):
                                                            """
                                                            SR Policy Explicit paths
                                                            
                                                            .. attribute:: sid
                                                            
                                                            	Sidlist for explicit path
                                                            	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of explicit path
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.sid = YList()
                                                                self.sid.parent = self
                                                                self.sid.name = 'sid'
                                                                self.weight = None


                                                            class Sid(object):
                                                                """
                                                                Sidlist for explicit path
                                                                
                                                                .. attribute:: ipv4
                                                                
                                                                	IP Address sid
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6
                                                                
                                                                	IPv6 address sid
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label sid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Sid Type
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4 = None
                                                                    self.ipv6 = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4 is not None:
                                                                        return True

                                                                    if self.ipv6 is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.sid is not None:
                                                                    for child_ref in self.sid:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.weight is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.aggregator_address is not None:
                                                                return True

                                                            if self.aggregator_as is not None:
                                                                return True

                                                            if self.aigp_metric_value is not None:
                                                                return True

                                                            if self.as_path is not None:
                                                                return True

                                                            if self.cluster is not None:
                                                                for child_ref in self.cluster:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.community is not None:
                                                                for child_ref in self.community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.connector_type is not None:
                                                                return True

                                                            if self.connector_value is not None:
                                                                for child_ref in self.connector_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.extended_community is not None:
                                                                for child_ref in self.extended_community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.extended_community_flags is not None:
                                                                return True

                                                            if self.is_aggregator_present is not None:
                                                                return True

                                                            if self.is_aigp_present is not None:
                                                                return True

                                                            if self.is_as_path_present is not None:
                                                                return True

                                                            if self.is_atomic_aggregate_present is not None:
                                                                return True

                                                            if self.is_community_present is not None:
                                                                return True

                                                            if self.is_connector_present is not None:
                                                                return True

                                                            if self.is_extended_community_present is not None:
                                                                return True

                                                            if self.is_label_index_present is not None:
                                                                return True

                                                            if self.is_local_pref_present is not None:
                                                                return True

                                                            if self.is_ls_attribute_present is not None:
                                                                return True

                                                            if self.is_metric_present is not None:
                                                                return True

                                                            if self.is_origin_present is not None:
                                                                return True

                                                            if self.is_pe_distinguisher_label_present is not None:
                                                                return True

                                                            if self.is_pmsi_present is not None:
                                                                return True

                                                            if self.is_pppmp_present is not None:
                                                                return True

                                                            if self.is_ssa_present is not None:
                                                                return True

                                                            if self.is_tunnel_encap_present is not None:
                                                                return True

                                                            if self.l2tpv3_cookie is not None:
                                                                for child_ref in self.l2tpv3_cookie:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.l2tpv3_session_id is not None:
                                                                return True

                                                            if self.label_index_attr is not None:
                                                                for child_ref in self.label_index_attr:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.local_preference is not None:
                                                                return True

                                                            if self.ls_attr is not None:
                                                                for child_ref in self.ls_attr:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.neighbor_as is not None:
                                                                return True

                                                            if self.origin is not None:
                                                                return True

                                                            if self.originator is not None:
                                                                return True

                                                            if self.pe_distinguisher_label is not None:
                                                                for child_ref in self.pe_distinguisher_label:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.pmsi_flags is not None:
                                                                return True

                                                            if self.pmsi_label is not None:
                                                                return True

                                                            if self.pmsi_type is not None:
                                                                return True

                                                            if self.pmsi_value is not None:
                                                                for child_ref in self.pmsi_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.ppm_pvalue is not None:
                                                                return True

                                                            if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                                return True

                                                            if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                                return True

                                                            if self.sr_policy_explicit_path is not None:
                                                                for child_ref in self.sr_policy_explicit_path:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.sr_policy_preference is not None:
                                                                return True

                                                            if self.sr_tunnel_request_state is not None:
                                                                return True

                                                            if self.sr_tunnel_state is not None:
                                                                return True

                                                            if self.tunnel_encap_type is not None:
                                                                return True

                                                            if self.unknown_attribute is not None:
                                                                for child_ref in self.unknown_attribute:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                                    class AttrSet(object):
                                                        """
                                                        ATTR\_SET attribute
                                                        
                                                        .. attribute:: aggregator_address
                                                        
                                                        	Address where aggregation was performed
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: aggregator_as
                                                        
                                                        	AS where aggregation was last performed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: aigp_metric_value
                                                        
                                                        	AIGP metric value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: as_path
                                                        
                                                        	AS path attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: cluster
                                                        
                                                        	Cluster list attribute
                                                        	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                        
                                                        .. attribute:: community
                                                        
                                                        	Community attribute
                                                        	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                        
                                                        .. attribute:: connector_type
                                                        
                                                        	Connector Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: connector_value
                                                        
                                                        	Connector Value
                                                        	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                        
                                                        .. attribute:: extended_community_flags
                                                        
                                                        	Extended community Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: is_aggregator_present
                                                        
                                                        	Aggregator attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_aigp_present
                                                        
                                                        	AIGP Present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path_present
                                                        
                                                        	AS path attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_atomic_aggregate_present
                                                        
                                                        	Atomic aggregate attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_community_present
                                                        
                                                        	Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_connector_present
                                                        
                                                        	Connector present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_extended_community_present
                                                        
                                                        	Extended community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_label_index_present
                                                        
                                                        	Label Index attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_local_pref_present
                                                        
                                                        	Local Preference attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ls_attribute_present
                                                        
                                                        	BGP LS attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_metric_present
                                                        
                                                        	Metric attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_origin_present
                                                        
                                                        	Origin attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pe_distinguisher_label_present
                                                        
                                                        	PE distinguisher label  attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pmsi_present
                                                        
                                                        	PMSI Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pppmp_present
                                                        
                                                        	PPMP Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ssa_present
                                                        
                                                        	SSA attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_encap_present
                                                        
                                                        	Tunnel Encap attribute present 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2tpv3_cookie
                                                        
                                                        	L2TPv3 Cookie
                                                        	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                        
                                                        .. attribute:: l2tpv3_session_id
                                                        
                                                        	L2TPv3 session id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: label_index_attr
                                                        
                                                        	Label Index attribute
                                                        	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                        
                                                        .. attribute:: local_preference
                                                        
                                                        	Local preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ls_attr
                                                        
                                                        	BGP LS attribute
                                                        	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: neighbor_as
                                                        
                                                        	Neighbor AS number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: origin
                                                        
                                                        	Origin
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: originator
                                                        
                                                        	Originator attribute
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: pe_distinguisher_label
                                                        
                                                        	PE distinguisher label attribute
                                                        	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                        
                                                        .. attribute:: pmsi_flags
                                                        
                                                        	PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pmsi_label
                                                        
                                                        	PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pmsi_type
                                                        
                                                        	PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pmsi_value
                                                        
                                                        	PMSI Value
                                                        	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                        
                                                        .. attribute:: ppm_pvalue
                                                        
                                                        	PPMP Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: sr_policy_allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                        
                                                        .. attribute:: sr_policy_binding_sid
                                                        
                                                        	SR Policy Binding sid
                                                        	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                        
                                                        .. attribute:: sr_policy_explicit_path
                                                        
                                                        	SR Policy Explicit paths
                                                        	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                        
                                                        .. attribute:: sr_policy_preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: sr_tunnel_request_state
                                                        
                                                        	SR Tunnel Request State
                                                        	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                        
                                                        .. attribute:: sr_tunnel_state
                                                        
                                                        	SR Tunnel State
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encap Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: unknown_attribute
                                                        
                                                        	Unknown attributes
                                                        	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.aggregator_address = None
                                                            self.aggregator_as = None
                                                            self.aigp_metric_value = None
                                                            self.as_path = None
                                                            self.cluster = YList()
                                                            self.cluster.parent = self
                                                            self.cluster.name = 'cluster'
                                                            self.community = YList()
                                                            self.community.parent = self
                                                            self.community.name = 'community'
                                                            self.connector_type = None
                                                            self.connector_value = YList()
                                                            self.connector_value.parent = self
                                                            self.connector_value.name = 'connector_value'
                                                            self.extended_community = YList()
                                                            self.extended_community.parent = self
                                                            self.extended_community.name = 'extended_community'
                                                            self.extended_community_flags = None
                                                            self.is_aggregator_present = None
                                                            self.is_aigp_present = None
                                                            self.is_as_path_present = None
                                                            self.is_atomic_aggregate_present = None
                                                            self.is_community_present = None
                                                            self.is_connector_present = None
                                                            self.is_extended_community_present = None
                                                            self.is_label_index_present = None
                                                            self.is_local_pref_present = None
                                                            self.is_ls_attribute_present = None
                                                            self.is_metric_present = None
                                                            self.is_origin_present = None
                                                            self.is_pe_distinguisher_label_present = None
                                                            self.is_pmsi_present = None
                                                            self.is_pppmp_present = None
                                                            self.is_ssa_present = None
                                                            self.is_tunnel_encap_present = None
                                                            self.l2tpv3_cookie = YList()
                                                            self.l2tpv3_cookie.parent = self
                                                            self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                            self.l2tpv3_session_id = None
                                                            self.label_index_attr = YList()
                                                            self.label_index_attr.parent = self
                                                            self.label_index_attr.name = 'label_index_attr'
                                                            self.local_preference = None
                                                            self.ls_attr = YList()
                                                            self.ls_attr.parent = self
                                                            self.ls_attr.name = 'ls_attr'
                                                            self.metric = None
                                                            self.neighbor_as = None
                                                            self.origin = None
                                                            self.originator = None
                                                            self.pe_distinguisher_label = YList()
                                                            self.pe_distinguisher_label.parent = self
                                                            self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                            self.pmsi_flags = None
                                                            self.pmsi_label = None
                                                            self.pmsi_type = None
                                                            self.pmsi_value = YList()
                                                            self.pmsi_value.parent = self
                                                            self.pmsi_value.name = 'pmsi_value'
                                                            self.ppm_pvalue = None
                                                            self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                            self.sr_policy_allocated_binding_sid.parent = self
                                                            self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                            self.sr_policy_binding_sid.parent = self
                                                            self.sr_policy_explicit_path = YList()
                                                            self.sr_policy_explicit_path.parent = self
                                                            self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                            self.sr_policy_preference = None
                                                            self.sr_tunnel_request_state = None
                                                            self.sr_tunnel_state = None
                                                            self.tunnel_encap_type = None
                                                            self.unknown_attribute = YList()
                                                            self.unknown_attribute.parent = self
                                                            self.unknown_attribute.name = 'unknown_attribute'


                                                        class SrPolicyBindingSid(object):
                                                            """
                                                            SR Policy Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_address = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                        class SrPolicyAllocatedBindingSid(object):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_address = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                        class Community(object):
                                                            """
                                                            Community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                        class ExtendedCommunity(object):
                                                            """
                                                            Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                        class UnknownAttribute(object):
                                                            """
                                                            Unknown attributes
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                        class Cluster(object):
                                                            """
                                                            Cluster list attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                        class L2Tpv3Cookie(object):
                                                            """
                                                            L2TPv3 Cookie
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                        class ConnectorValue(object):
                                                            """
                                                            Connector Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                        class PmsiValue(object):
                                                            """
                                                            PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                        class LsAttr(object):
                                                            """
                                                            BGP LS attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                        class LabelIndexAttr(object):
                                                            """
                                                            Label Index attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                        class PeDistinguisherLabel(object):
                                                            """
                                                            PE distinguisher label attribute
                                                            
                                                            .. attribute:: label
                                                            
                                                            	Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pe_address
                                                            
                                                            	 PE address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.label = None
                                                                self.pe_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.label is not None:
                                                                    return True

                                                                if self.pe_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                        class SrPolicyExplicitPath(object):
                                                            """
                                                            SR Policy Explicit paths
                                                            
                                                            .. attribute:: sid
                                                            
                                                            	Sidlist for explicit path
                                                            	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of explicit path
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.sid = YList()
                                                                self.sid.parent = self
                                                                self.sid.name = 'sid'
                                                                self.weight = None


                                                            class Sid(object):
                                                                """
                                                                Sidlist for explicit path
                                                                
                                                                .. attribute:: ipv4
                                                                
                                                                	IP Address sid
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6
                                                                
                                                                	IPv6 address sid
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label sid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Sid Type
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4 = None
                                                                    self.ipv6 = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4 is not None:
                                                                        return True

                                                                    if self.ipv6 is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.sid is not None:
                                                                    for child_ref in self.sid:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.weight is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.aggregator_address is not None:
                                                                return True

                                                            if self.aggregator_as is not None:
                                                                return True

                                                            if self.aigp_metric_value is not None:
                                                                return True

                                                            if self.as_path is not None:
                                                                return True

                                                            if self.cluster is not None:
                                                                for child_ref in self.cluster:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.community is not None:
                                                                for child_ref in self.community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.connector_type is not None:
                                                                return True

                                                            if self.connector_value is not None:
                                                                for child_ref in self.connector_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.extended_community is not None:
                                                                for child_ref in self.extended_community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.extended_community_flags is not None:
                                                                return True

                                                            if self.is_aggregator_present is not None:
                                                                return True

                                                            if self.is_aigp_present is not None:
                                                                return True

                                                            if self.is_as_path_present is not None:
                                                                return True

                                                            if self.is_atomic_aggregate_present is not None:
                                                                return True

                                                            if self.is_community_present is not None:
                                                                return True

                                                            if self.is_connector_present is not None:
                                                                return True

                                                            if self.is_extended_community_present is not None:
                                                                return True

                                                            if self.is_label_index_present is not None:
                                                                return True

                                                            if self.is_local_pref_present is not None:
                                                                return True

                                                            if self.is_ls_attribute_present is not None:
                                                                return True

                                                            if self.is_metric_present is not None:
                                                                return True

                                                            if self.is_origin_present is not None:
                                                                return True

                                                            if self.is_pe_distinguisher_label_present is not None:
                                                                return True

                                                            if self.is_pmsi_present is not None:
                                                                return True

                                                            if self.is_pppmp_present is not None:
                                                                return True

                                                            if self.is_ssa_present is not None:
                                                                return True

                                                            if self.is_tunnel_encap_present is not None:
                                                                return True

                                                            if self.l2tpv3_cookie is not None:
                                                                for child_ref in self.l2tpv3_cookie:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.l2tpv3_session_id is not None:
                                                                return True

                                                            if self.label_index_attr is not None:
                                                                for child_ref in self.label_index_attr:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.local_preference is not None:
                                                                return True

                                                            if self.ls_attr is not None:
                                                                for child_ref in self.ls_attr:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.neighbor_as is not None:
                                                                return True

                                                            if self.origin is not None:
                                                                return True

                                                            if self.originator is not None:
                                                                return True

                                                            if self.pe_distinguisher_label is not None:
                                                                for child_ref in self.pe_distinguisher_label:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.pmsi_flags is not None:
                                                                return True

                                                            if self.pmsi_label is not None:
                                                                return True

                                                            if self.pmsi_type is not None:
                                                                return True

                                                            if self.pmsi_value is not None:
                                                                for child_ref in self.pmsi_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.ppm_pvalue is not None:
                                                                return True

                                                            if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                                return True

                                                            if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                                return True

                                                            if self.sr_policy_explicit_path is not None:
                                                                for child_ref in self.sr_policy_explicit_path:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.sr_policy_preference is not None:
                                                                return True

                                                            if self.sr_tunnel_request_state is not None:
                                                                return True

                                                            if self.sr_tunnel_state is not None:
                                                                return True

                                                            if self.tunnel_encap_type is not None:
                                                                return True

                                                            if self.unknown_attribute is not None:
                                                                for child_ref in self.unknown_attribute:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                                    class RnhAddr(object):
                                                        """
                                                        RNH Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                        
                                                        .. attribute:: mac_address
                                                        
                                                        	MAC Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_address = None
                                                            self.ipv6_address = None
                                                            self.len = None
                                                            self.mac_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.len is not None:
                                                                return True

                                                            if self.mac_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                                    class RibrnhIp(object):
                                                        """
                                                        RIB RNH IP Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.attr_set is not None and self.attr_set._has_data():
                                                            return True

                                                        if self.attribute_key_number is not None:
                                                            return True

                                                        if self.attribute_reuse_id_config is not None:
                                                            return True

                                                        if self.attribute_reuse_id_current is not None:
                                                            return True

                                                        if self.attribute_reuse_id_keys is not None:
                                                            return True

                                                        if self.attribute_reuse_id_max_id is not None:
                                                            return True

                                                        if self.attribute_reuse_id_node is not None:
                                                            return True

                                                        if self.attribute_reuse_id_recover_sec is not None:
                                                            return True

                                                        if self.common_attributes is not None and self.common_attributes._has_data():
                                                            return True

                                                        if self.is_application_gateway_present is not None:
                                                            return True

                                                        if self.is_as_path2_byte is not None:
                                                            return True

                                                        if self.is_attr_set_present is not None:
                                                            return True

                                                        if self.is_ribrnh_present is not None:
                                                            return True

                                                        if self.is_rnh_present is not None:
                                                            return True

                                                        if self.ribrnh_encap is not None:
                                                            return True

                                                        if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                            return True

                                                        if self.ribrnh_mac is not None:
                                                            return True

                                                        if self.ribrnh_table is not None:
                                                            return True

                                                        if self.ribrnh_vni is not None:
                                                            return True

                                                        if self.ribrnhip_table is not None:
                                                            return True

                                                        if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                            return True

                                                        if self.rnh_addr_len is not None:
                                                            return True

                                                        if self.rnh_len is not None:
                                                            return True

                                                        if self.rnh_type is not None:
                                                            return True

                                                        if self.set_aigp_inbound_igp is not None:
                                                            return True

                                                        if self.set_aigp_inbound_metric is not None:
                                                            return True

                                                        if self.vpn_distinguisher is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-process-instance-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.af_name is not None:
                                                        return True

                                                    if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                        return True

                                                    if self.label_fail is not None:
                                                        return True

                                                    if self.label_o_or_version is not None:
                                                        return True

                                                    if self.label_oor is not None:
                                                        return True

                                                    if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                        return True

                                                    if self.no_path is not None:
                                                        return True

                                                    if self.path_information is not None and self.path_information._has_data():
                                                        return True

                                                    if self.prefix_version is not None:
                                                        return True

                                                    if self.process_instance_id is not None:
                                                        return True

                                                    if self.route_distinguisher is not None:
                                                        return True

                                                    if self.source_route_distinguisher is not None:
                                                        return True

                                                    if self.source_vrf_name is not None:
                                                        return True

                                                    if self.srcaf_name is not None:
                                                        return True

                                                    if self.vrf_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath']['meta_info']


                                            class ActiveProcessInstancePath(object):
                                                """
                                                Active's paths for this net 
                                                
                                                .. attribute:: af_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: attributes_after_policy_in
                                                
                                                	Attributes after inbound policy applied
                                                	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn>`
                                                
                                                .. attribute:: label_fail
                                                
                                                	LSD label allocation failed 
                                                	**type**\:  bool
                                                
                                                .. attribute:: label_o_or_version
                                                
                                                	Label Version when OOR happens
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_oor
                                                
                                                	LSD label space is exhausted
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address_xr
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr>`
                                                
                                                .. attribute:: no_path
                                                
                                                	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                                	**type**\:  bool
                                                
                                                .. attribute:: path_information
                                                
                                                	Path information
                                                	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation>`
                                                
                                                .. attribute:: prefix_version
                                                
                                                	Version of BGP Prefix Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: process_instance_id
                                                
                                                	Process instance ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: source_route_distinguisher
                                                
                                                	Source Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: source_vrf_name
                                                
                                                	Name of the source VRF
                                                	**type**\:  str
                                                
                                                .. attribute:: srcaf_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: vrf_name
                                                
                                                	Name of the VRF
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.af_name = None
                                                    self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn()
                                                    self.attributes_after_policy_in.parent = self
                                                    self.label_fail = None
                                                    self.label_o_or_version = None
                                                    self.label_oor = None
                                                    self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr()
                                                    self.neighbor_address_xr.parent = self
                                                    self.no_path = None
                                                    self.path_information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation()
                                                    self.path_information.parent = self
                                                    self.prefix_version = None
                                                    self.process_instance_id = None
                                                    self.route_distinguisher = None
                                                    self.source_route_distinguisher = None
                                                    self.source_vrf_name = None
                                                    self.srcaf_name = None
                                                    self.vrf_name = None


                                                class NeighborAddressXr(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr']['meta_info']


                                                class PathInformation(object):
                                                    """
                                                    Path information
                                                    
                                                    .. attribute:: accept_own_path
                                                    
                                                    	Accept Own
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: accept_own_self_originated_p_ath
                                                    
                                                    	Accept\-Own self\-originated
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: add_path_orr_bitfield
                                                    
                                                    	ORR Add path Bitfields
                                                    	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                    
                                                    .. attribute:: advertisedto_pe
                                                    
                                                    	Net could be advertised                          to PE peers
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: aigp_metric
                                                    
                                                    	Total AIGP metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: best_path_comp_stage
                                                    
                                                    	Stage where the path lost to the best path or group best
                                                    	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                                    
                                                    .. attribute:: best_path_comp_winner
                                                    
                                                    	Neighbor address of the path which won best path comparison
                                                    	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                    
                                                    .. attribute:: best_path_id
                                                    
                                                    	Best path ID; DEPRECATED BYLocalPathId
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: best_path_id_comp_winner
                                                    
                                                    	Path ID of the path which won best path comparison
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: best_path_orr_bitfield
                                                    
                                                    	ORR Best path Bitfields
                                                    	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                    
                                                    .. attribute:: bgp_prefix
                                                    
                                                    	BGP prefix
                                                    	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix>`
                                                    
                                                    .. attribute:: dampen_penalty
                                                    
                                                    	Dampening penalty
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Mvpn Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                    
                                                    .. attribute:: fspec_invalid_path
                                                    
                                                    	Is Fspec invalid path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: graceful_shutdown
                                                    
                                                    	Marked for graceful shutdown
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: gw_addr
                                                    
                                                    	Path GW Address
                                                    	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.GwAddr>`
                                                    
                                                    .. attribute:: halflife_time
                                                    
                                                    	Half\-life time for the penalty
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_esi
                                                    
                                                    	Path has EVPN ESI
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_gw_addr
                                                    
                                                    	Path has GW Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_local_net_label
                                                    
                                                    	Path has local label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mdt_group_addr
                                                    
                                                    	Path has MDT Group Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_extcomm
                                                    
                                                    	Path has MVPN EXTCOMM feedback
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_nbr_addr
                                                    
                                                    	Path has Mvpn nbr Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_nexthop_addr
                                                    
                                                    	Path has MVPN nexthop Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_pmsi
                                                    
                                                    	Path has MVPN PMSI feedback
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_rcvd_label
                                                    
                                                    	Path has received label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_second_label
                                                    
                                                    	Path has second received label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ibgp_signaled_validity
                                                    
                                                    	IBGP signalled validation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: igp_metric
                                                    
                                                    	IGP metric to the gateway
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_aggregation_suppressed
                                                    
                                                    	Path suppressed due to aggregation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_best
                                                    
                                                    	Best available path within AS
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_best_path
                                                    
                                                    	Best available path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_import_dampened
                                                    
                                                    	net import dampened
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_import_suspect
                                                    
                                                    	net import suspect
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_internal_path
                                                    
                                                    	Received over an internal link
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_best
                                                    
                                                    	Partial best path within distributed speaker
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_additional_path
                                                    
                                                    	Path is an additional\-path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_advertised_local_as_only
                                                    
                                                    	Not advertised outside local AS
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_af_install_eligible
                                                    
                                                    	Path can be installed in AF RIB
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_backup
                                                    
                                                    	Path is a backup path 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_backup_protect_multipath
                                                    
                                                    	Path is a backup path to protect multipaths
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_best_external
                                                    
                                                    	Path is a best external path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_damped
                                                    
                                                    	Path suppressed due to dampening
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_confederation_peer
                                                    
                                                    	Path received from confederation peer
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_network_command
                                                    
                                                    	Path sourced by network command
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_redistribute_command
                                                    
                                                    	Path sourced by redistribute command
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_route_reflector
                                                    
                                                    	Path received from route reflector
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_history_held
                                                    
                                                    	Path entry held to remember history
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_imp_candidate
                                                    
                                                    	Path is a candidate for multipath import
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_imported
                                                    
                                                    	Path is imported
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_local_aggregate
                                                    
                                                    	Path is a locally created aggregate
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_locally_sourced
                                                    
                                                    	Path sourced locally
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_long_lived_stale
                                                    
                                                    	Long lived stale routes learnt before neighbor restarts
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_multipath
                                                    
                                                    	Path is one of multipath best routes
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_nexthop_discarded
                                                    
                                                    	Path is redirected to Null0
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_not_advertised
                                                    
                                                    	Not advertised to any peer
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_not_advertised_to_ebg_ps
                                                    
                                                    	Not advertised to EBGPs
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_received_only
                                                    
                                                    	Path is received only
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_reoriginated
                                                    
                                                    	Path is reoriginated
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_reoriginated_stitching
                                                    
                                                    	Path is reoriginated with stitching RTs
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_stale
                                                    
                                                    	Stale routes learnt before neighbor restarts
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_synced_with_igp
                                                    
                                                    	Path synchronized with IGP
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_valid
                                                    
                                                    	Path attributes are usable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_vpn_only
                                                    
                                                    	Path is not in the vrf
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_permanent_path
                                                    
                                                    	Path is of type Permanent path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_received_path_not_modified
                                                    
                                                    	Received path used without modification
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_spkr_as_best
                                                    
                                                    	Best available path within AS in speaker
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2vpn_circuit_status_value
                                                    
                                                    	L2VPN Circuit Status Value
                                                    	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                    
                                                    .. attribute:: l2vpn_evpn_esi
                                                    
                                                    	L2VPN EVPN ESI
                                                    	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi>`
                                                    
                                                    .. attribute:: l2vpn_size
                                                    
                                                    	Path block size
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: labeled_unicast_safi_path
                                                    
                                                    	Path was learnt by labeled\-unicast SAFI
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: local_label
                                                    
                                                    	Path local label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_nh
                                                    
                                                    	Path has local nexthop
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: local_path_id
                                                    
                                                    	Local path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_peers_advertised_to
                                                    
                                                    	Local peers that this prefix has been advertised to
                                                    	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                    
                                                    .. attribute:: maximum_suppress_time
                                                    
                                                    	Maximum duration to suppress a stable route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mdt_group_addr
                                                    
                                                    	IPv4 MDT Group Address for the path
                                                    	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                    
                                                    .. attribute:: mvpn_nbr_addr
                                                    
                                                    	Mvpn nbr Address for the path
                                                    	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                    
                                                    .. attribute:: mvpn_nexthop_addr
                                                    
                                                    	Mvpn nexthop Address for the path
                                                    	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                    
                                                    .. attribute:: mvpn_path_flags
                                                    
                                                    	Mvpn path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: mvpn_pmsi_flags
                                                    
                                                    	Mvpn PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: mvpn_pmsi_label
                                                    
                                                    	Mvpn PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mvpn_pmsi_type
                                                    
                                                    	Mvpn PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: mvpn_pmsi_value
                                                    
                                                    	Mvpn PMSI Value
                                                    	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                    
                                                    .. attribute:: mvpn_sfs_path
                                                    
                                                    	Is MVPN single forwarder PE path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress>`
                                                    
                                                    .. attribute:: neighbor_router_id
                                                    
                                                    	Router ID of the neighbor for the path
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: next_hop
                                                    
                                                    	Next hop
                                                    	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop>`
                                                    
                                                    .. attribute:: nhte_tunnel
                                                    
                                                    	NH TE tunnel information
                                                    	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhteTunnel>`
                                                    
                                                    .. attribute:: path_flags
                                                    
                                                    	Flags associated with path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: path_flap_count
                                                    
                                                    	Number of times this route has flapped
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_import_flags
                                                    
                                                    	Path import flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_rt_set_id
                                                    
                                                    	RT\-set id of the path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_rt_set_route_count
                                                    
                                                    	Count in RT\-set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_table_version
                                                    
                                                    	Table version # for pelem
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_weight
                                                    
                                                    	Weight for the path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pe_peers_advertised_to
                                                    
                                                    	PE peers that this prefix has been advertised to
                                                    	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                    
                                                    .. attribute:: rcvd_label
                                                    
                                                    	Path received label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rcvd_path_id
                                                    
                                                    	Received path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: reuse_value
                                                    
                                                    	Value to start reusing a route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rib_failed
                                                    
                                                    	Is net failed installed                          in RIB
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: route_type
                                                    
                                                    	Route Type of path
                                                    	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                                    
                                                    .. attribute:: rpki_origin_as_validation_disabled
                                                    
                                                    	RPKI originAS V. Disabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rt_set_limit_enabled
                                                    
                                                    	Path subject to RT\-set net limit
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_label
                                                    
                                                    	Path second received label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: seconds_since_first_flap
                                                    
                                                    	Seconds since route first flapped
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: show_rpki_origin_as_validity
                                                    
                                                    	Display validity state ?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: sn_rpki_origin_as_validity
                                                    
                                                    	RPKI origin validation state
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: suppress_penalty
                                                    
                                                    	Value to start suppressing a route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: time_to_unsuppress
                                                    
                                                    	Seconds until route is unsuppressed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.accept_own_path = None
                                                        self.accept_own_self_originated_p_ath = None
                                                        self.add_path_orr_bitfield = YList()
                                                        self.add_path_orr_bitfield.parent = self
                                                        self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                        self.advertisedto_pe = None
                                                        self.aigp_metric = None
                                                        self.best_path_comp_stage = None
                                                        self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner()
                                                        self.best_path_comp_winner.parent = self
                                                        self.best_path_id = None
                                                        self.best_path_id_comp_winner = None
                                                        self.best_path_orr_bitfield = YList()
                                                        self.best_path_orr_bitfield.parent = self
                                                        self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                        self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix()
                                                        self.bgp_prefix.parent = self
                                                        self.dampen_penalty = None
                                                        self.extended_community = YList()
                                                        self.extended_community.parent = self
                                                        self.extended_community.name = 'extended_community'
                                                        self.fspec_invalid_path = None
                                                        self.graceful_shutdown = None
                                                        self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.GwAddr()
                                                        self.gw_addr.parent = self
                                                        self.halflife_time = None
                                                        self.has_esi = None
                                                        self.has_gw_addr = None
                                                        self.has_local_net_label = None
                                                        self.has_mdt_group_addr = None
                                                        self.has_mvpn_extcomm = None
                                                        self.has_mvpn_nbr_addr = None
                                                        self.has_mvpn_nexthop_addr = None
                                                        self.has_mvpn_pmsi = None
                                                        self.has_rcvd_label = None
                                                        self.has_second_label = None
                                                        self.ibgp_signaled_validity = None
                                                        self.igp_metric = None
                                                        self.is_aggregation_suppressed = None
                                                        self.is_as_best = None
                                                        self.is_best_path = None
                                                        self.is_import_dampened = None
                                                        self.is_import_suspect = None
                                                        self.is_internal_path = None
                                                        self.is_partial_best = None
                                                        self.is_path_additional_path = None
                                                        self.is_path_advertised_local_as_only = None
                                                        self.is_path_af_install_eligible = None
                                                        self.is_path_backup = None
                                                        self.is_path_backup_protect_multipath = None
                                                        self.is_path_best_external = None
                                                        self.is_path_damped = None
                                                        self.is_path_from_confederation_peer = None
                                                        self.is_path_from_network_command = None
                                                        self.is_path_from_redistribute_command = None
                                                        self.is_path_from_route_reflector = None
                                                        self.is_path_history_held = None
                                                        self.is_path_imp_candidate = None
                                                        self.is_path_imported = None
                                                        self.is_path_local_aggregate = None
                                                        self.is_path_locally_sourced = None
                                                        self.is_path_long_lived_stale = None
                                                        self.is_path_multipath = None
                                                        self.is_path_nexthop_discarded = None
                                                        self.is_path_not_advertised = None
                                                        self.is_path_not_advertised_to_ebg_ps = None
                                                        self.is_path_received_only = None
                                                        self.is_path_reoriginated = None
                                                        self.is_path_reoriginated_stitching = None
                                                        self.is_path_stale = None
                                                        self.is_path_synced_with_igp = None
                                                        self.is_path_valid = None
                                                        self.is_path_vpn_only = None
                                                        self.is_permanent_path = None
                                                        self.is_received_path_not_modified = None
                                                        self.is_spkr_as_best = None
                                                        self.l2vpn_circuit_status_value = YList()
                                                        self.l2vpn_circuit_status_value.parent = self
                                                        self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                        self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi()
                                                        self.l2vpn_evpn_esi.parent = self
                                                        self.l2vpn_size = None
                                                        self.labeled_unicast_safi_path = None
                                                        self.local_label = None
                                                        self.local_nh = None
                                                        self.local_path_id = None
                                                        self.local_peers_advertised_to = YList()
                                                        self.local_peers_advertised_to.parent = self
                                                        self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                        self.maximum_suppress_time = None
                                                        self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr()
                                                        self.mdt_group_addr.parent = self
                                                        self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                        self.mvpn_nbr_addr.parent = self
                                                        self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                        self.mvpn_nexthop_addr.parent = self
                                                        self.mvpn_path_flags = None
                                                        self.mvpn_pmsi_flags = None
                                                        self.mvpn_pmsi_label = None
                                                        self.mvpn_pmsi_type = None
                                                        self.mvpn_pmsi_value = YList()
                                                        self.mvpn_pmsi_value.parent = self
                                                        self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                        self.mvpn_sfs_path = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.neighbor_router_id = None
                                                        self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop()
                                                        self.next_hop.parent = self
                                                        self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhteTunnel()
                                                        self.nhte_tunnel.parent = self
                                                        self.path_flags = None
                                                        self.path_flap_count = None
                                                        self.path_import_flags = None
                                                        self.path_rt_set_id = None
                                                        self.path_rt_set_route_count = None
                                                        self.path_table_version = None
                                                        self.path_weight = None
                                                        self.pe_peers_advertised_to = YList()
                                                        self.pe_peers_advertised_to.parent = self
                                                        self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                        self.rcvd_label = None
                                                        self.rcvd_path_id = None
                                                        self.reuse_value = None
                                                        self.rib_failed = None
                                                        self.route_type = None
                                                        self.rpki_origin_as_validation_disabled = None
                                                        self.rt_set_limit_enabled = None
                                                        self.second_label = None
                                                        self.seconds_since_first_flap = None
                                                        self.show_rpki_origin_as_validity = None
                                                        self.sn_rpki_origin_as_validity = None
                                                        self.suppress_penalty = None
                                                        self.time_to_unsuppress = None


                                                    class BgpPrefix(object):
                                                        """
                                                        BGP prefix
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Prefix
                                                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                            self.prefix.parent = self
                                                            self.prefix_length = None


                                                        class Prefix(object):
                                                            """
                                                            Prefix
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.prefix is not None and self.prefix._has_data():
                                                                return True

                                                            if self.prefix_length is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix']['meta_info']


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress']['meta_info']


                                                    class NextHop(object):
                                                        """
                                                        Next hop
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop']['meta_info']


                                                    class NhteTunnel(object):
                                                        """
                                                        NH TE tunnel information
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	Binding label for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_te_tunnel
                                                        
                                                        	NH TE Tunnel info is present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_info_stale
                                                        
                                                        	Tunnel is stale
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_registered
                                                        
                                                        	Tunnel registered flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_up
                                                        
                                                        	Tunnel Up flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: last_tunnel_update
                                                        
                                                        	Time since the last rib update happened
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_if_handle
                                                        
                                                        	Interface handle for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_name
                                                        
                                                        	tunnel name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        .. attribute:: tunnel_type
                                                        
                                                        	tunnel type
                                                        	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                        
                                                        .. attribute:: tunnel_v6_enabled
                                                        
                                                        	IPv6 enabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_v6_required
                                                        
                                                        	Tunnel need IPv6
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.binding_label = None
                                                            self.has_te_tunnel = None
                                                            self.is_tunnel_info_stale = None
                                                            self.is_tunnel_registered = None
                                                            self.is_tunnel_up = None
                                                            self.last_tunnel_update = None
                                                            self.tunnel_if_handle = None
                                                            self.tunnel_name = None
                                                            self.tunnel_type = None
                                                            self.tunnel_v6_enabled = None
                                                            self.tunnel_v6_required = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.binding_label is not None:
                                                                return True

                                                            if self.has_te_tunnel is not None:
                                                                return True

                                                            if self.is_tunnel_info_stale is not None:
                                                                return True

                                                            if self.is_tunnel_registered is not None:
                                                                return True

                                                            if self.is_tunnel_up is not None:
                                                                return True

                                                            if self.last_tunnel_update is not None:
                                                                return True

                                                            if self.tunnel_if_handle is not None:
                                                                return True

                                                            if self.tunnel_name is not None:
                                                                return True

                                                            if self.tunnel_type is not None:
                                                                return True

                                                            if self.tunnel_v6_enabled is not None:
                                                                return True

                                                            if self.tunnel_v6_required is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhteTunnel']['meta_info']


                                                    class MdtGroupAddr(object):
                                                        """
                                                        IPv4 MDT Group Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr']['meta_info']


                                                    class L2VpnEvpnEsi(object):
                                                        """
                                                        L2VPN EVPN ESI
                                                        
                                                        .. attribute:: esi
                                                        
                                                        	esi
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.esi = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.esi is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi']['meta_info']


                                                    class GwAddr(object):
                                                        """
                                                        Path GW Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_address = None
                                                            self.ipv6_address = None
                                                            self.len = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.len is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.GwAddr']['meta_info']


                                                    class BestPathCompWinner(object):
                                                        """
                                                        Neighbor address of the path which won best path
                                                        comparison
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner']['meta_info']


                                                    class MvpnNbrAddr(object):
                                                        """
                                                        Mvpn nbr Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr']['meta_info']


                                                    class MvpnNexthopAddr(object):
                                                        """
                                                        Mvpn nexthop Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr']['meta_info']


                                                    class L2VpnCircuitStatusValue(object):
                                                        """
                                                        L2VPN Circuit Status Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                                    class MvpnPmsiValue(object):
                                                        """
                                                        Mvpn PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue']['meta_info']


                                                    class ExtendedCommunity(object):
                                                        """
                                                        Mvpn Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity']['meta_info']


                                                    class LocalPeersAdvertisedTo(object):
                                                        """
                                                        Local peers that this prefix has been advertised
                                                        to
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.is_neighbor = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.update_group_number = None


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.is_neighbor is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.update_group_number is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                                    class PePeersAdvertisedTo(object):
                                                        """
                                                        PE peers that this prefix has been advertised to
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.is_neighbor = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.update_group_number = None


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.is_neighbor is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.update_group_number is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo']['meta_info']


                                                    class BestPathOrrBitfield(object):
                                                        """
                                                        ORR Best path Bitfields
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.is_neighbor = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.update_group_number = None


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.is_neighbor is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.update_group_number is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield']['meta_info']


                                                    class AddPathOrrBitfield(object):
                                                        """
                                                        ORR Add path Bitfields
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.is_neighbor = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.update_group_number = None


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.is_neighbor is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.update_group_number is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.accept_own_path is not None:
                                                            return True

                                                        if self.accept_own_self_originated_p_ath is not None:
                                                            return True

                                                        if self.add_path_orr_bitfield is not None:
                                                            for child_ref in self.add_path_orr_bitfield:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.advertisedto_pe is not None:
                                                            return True

                                                        if self.aigp_metric is not None:
                                                            return True

                                                        if self.best_path_comp_stage is not None:
                                                            return True

                                                        if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                            return True

                                                        if self.best_path_id is not None:
                                                            return True

                                                        if self.best_path_id_comp_winner is not None:
                                                            return True

                                                        if self.best_path_orr_bitfield is not None:
                                                            for child_ref in self.best_path_orr_bitfield:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                            return True

                                                        if self.dampen_penalty is not None:
                                                            return True

                                                        if self.extended_community is not None:
                                                            for child_ref in self.extended_community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.fspec_invalid_path is not None:
                                                            return True

                                                        if self.graceful_shutdown is not None:
                                                            return True

                                                        if self.gw_addr is not None and self.gw_addr._has_data():
                                                            return True

                                                        if self.halflife_time is not None:
                                                            return True

                                                        if self.has_esi is not None:
                                                            return True

                                                        if self.has_gw_addr is not None:
                                                            return True

                                                        if self.has_local_net_label is not None:
                                                            return True

                                                        if self.has_mdt_group_addr is not None:
                                                            return True

                                                        if self.has_mvpn_extcomm is not None:
                                                            return True

                                                        if self.has_mvpn_nbr_addr is not None:
                                                            return True

                                                        if self.has_mvpn_nexthop_addr is not None:
                                                            return True

                                                        if self.has_mvpn_pmsi is not None:
                                                            return True

                                                        if self.has_rcvd_label is not None:
                                                            return True

                                                        if self.has_second_label is not None:
                                                            return True

                                                        if self.ibgp_signaled_validity is not None:
                                                            return True

                                                        if self.igp_metric is not None:
                                                            return True

                                                        if self.is_aggregation_suppressed is not None:
                                                            return True

                                                        if self.is_as_best is not None:
                                                            return True

                                                        if self.is_best_path is not None:
                                                            return True

                                                        if self.is_import_dampened is not None:
                                                            return True

                                                        if self.is_import_suspect is not None:
                                                            return True

                                                        if self.is_internal_path is not None:
                                                            return True

                                                        if self.is_partial_best is not None:
                                                            return True

                                                        if self.is_path_additional_path is not None:
                                                            return True

                                                        if self.is_path_advertised_local_as_only is not None:
                                                            return True

                                                        if self.is_path_af_install_eligible is not None:
                                                            return True

                                                        if self.is_path_backup is not None:
                                                            return True

                                                        if self.is_path_backup_protect_multipath is not None:
                                                            return True

                                                        if self.is_path_best_external is not None:
                                                            return True

                                                        if self.is_path_damped is not None:
                                                            return True

                                                        if self.is_path_from_confederation_peer is not None:
                                                            return True

                                                        if self.is_path_from_network_command is not None:
                                                            return True

                                                        if self.is_path_from_redistribute_command is not None:
                                                            return True

                                                        if self.is_path_from_route_reflector is not None:
                                                            return True

                                                        if self.is_path_history_held is not None:
                                                            return True

                                                        if self.is_path_imp_candidate is not None:
                                                            return True

                                                        if self.is_path_imported is not None:
                                                            return True

                                                        if self.is_path_local_aggregate is not None:
                                                            return True

                                                        if self.is_path_locally_sourced is not None:
                                                            return True

                                                        if self.is_path_long_lived_stale is not None:
                                                            return True

                                                        if self.is_path_multipath is not None:
                                                            return True

                                                        if self.is_path_nexthop_discarded is not None:
                                                            return True

                                                        if self.is_path_not_advertised is not None:
                                                            return True

                                                        if self.is_path_not_advertised_to_ebg_ps is not None:
                                                            return True

                                                        if self.is_path_received_only is not None:
                                                            return True

                                                        if self.is_path_reoriginated is not None:
                                                            return True

                                                        if self.is_path_reoriginated_stitching is not None:
                                                            return True

                                                        if self.is_path_stale is not None:
                                                            return True

                                                        if self.is_path_synced_with_igp is not None:
                                                            return True

                                                        if self.is_path_valid is not None:
                                                            return True

                                                        if self.is_path_vpn_only is not None:
                                                            return True

                                                        if self.is_permanent_path is not None:
                                                            return True

                                                        if self.is_received_path_not_modified is not None:
                                                            return True

                                                        if self.is_spkr_as_best is not None:
                                                            return True

                                                        if self.l2vpn_circuit_status_value is not None:
                                                            for child_ref in self.l2vpn_circuit_status_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                            return True

                                                        if self.l2vpn_size is not None:
                                                            return True

                                                        if self.labeled_unicast_safi_path is not None:
                                                            return True

                                                        if self.local_label is not None:
                                                            return True

                                                        if self.local_nh is not None:
                                                            return True

                                                        if self.local_path_id is not None:
                                                            return True

                                                        if self.local_peers_advertised_to is not None:
                                                            for child_ref in self.local_peers_advertised_to:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.maximum_suppress_time is not None:
                                                            return True

                                                        if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                            return True

                                                        if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                            return True

                                                        if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                            return True

                                                        if self.mvpn_path_flags is not None:
                                                            return True

                                                        if self.mvpn_pmsi_flags is not None:
                                                            return True

                                                        if self.mvpn_pmsi_label is not None:
                                                            return True

                                                        if self.mvpn_pmsi_type is not None:
                                                            return True

                                                        if self.mvpn_pmsi_value is not None:
                                                            for child_ref in self.mvpn_pmsi_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.mvpn_sfs_path is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.neighbor_router_id is not None:
                                                            return True

                                                        if self.next_hop is not None and self.next_hop._has_data():
                                                            return True

                                                        if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                            return True

                                                        if self.path_flags is not None:
                                                            return True

                                                        if self.path_flap_count is not None:
                                                            return True

                                                        if self.path_import_flags is not None:
                                                            return True

                                                        if self.path_rt_set_id is not None:
                                                            return True

                                                        if self.path_rt_set_route_count is not None:
                                                            return True

                                                        if self.path_table_version is not None:
                                                            return True

                                                        if self.path_weight is not None:
                                                            return True

                                                        if self.pe_peers_advertised_to is not None:
                                                            for child_ref in self.pe_peers_advertised_to:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.rcvd_label is not None:
                                                            return True

                                                        if self.rcvd_path_id is not None:
                                                            return True

                                                        if self.reuse_value is not None:
                                                            return True

                                                        if self.rib_failed is not None:
                                                            return True

                                                        if self.route_type is not None:
                                                            return True

                                                        if self.rpki_origin_as_validation_disabled is not None:
                                                            return True

                                                        if self.rt_set_limit_enabled is not None:
                                                            return True

                                                        if self.second_label is not None:
                                                            return True

                                                        if self.seconds_since_first_flap is not None:
                                                            return True

                                                        if self.show_rpki_origin_as_validity is not None:
                                                            return True

                                                        if self.sn_rpki_origin_as_validity is not None:
                                                            return True

                                                        if self.suppress_penalty is not None:
                                                            return True

                                                        if self.time_to_unsuppress is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation']['meta_info']


                                                class AttributesAfterPolicyIn(object):
                                                    """
                                                    Attributes after inbound policy applied
                                                    
                                                    .. attribute:: attr_set
                                                    
                                                    	ATTR\_SET attribute
                                                    	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                    
                                                    .. attribute:: attribute_key_number
                                                    
                                                    	Attribute key number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_config
                                                    
                                                    	Attribute reuse ID Configured
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: attribute_reuse_id_current
                                                    
                                                    	Attribute reuse ID current ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_keys
                                                    
                                                    	Attribute reuse ID allocated keys
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_max_id
                                                    
                                                    	Attribute reuse ID maximum ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_node
                                                    
                                                    	Attribute reuse ID nodes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_recover_sec
                                                    
                                                    	Attribute reuse ID timer in seconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: common_attributes
                                                    
                                                    	Common attributes
                                                    	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                    
                                                    .. attribute:: is_application_gateway_present
                                                    
                                                    	Application gateway present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path2_byte
                                                    
                                                    	AS path encoded as 2\-byte
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_attr_set_present
                                                    
                                                    	BGP ATTR\_SET attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ribrnh_present
                                                    
                                                    	RIB RNH Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_rnh_present
                                                    
                                                    	RNH Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ribrnh_encap
                                                    
                                                    	RIB RNH Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ribrnh_ip
                                                    
                                                    	RIB RNH IP Address
                                                    	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                    
                                                    .. attribute:: ribrnh_mac
                                                    
                                                    	RIB RNH MAC Address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    .. attribute:: ribrnh_table
                                                    
                                                    	RIB RNH Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ribrnh_vni
                                                    
                                                    	RIB RNH Vni
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ribrnhip_table
                                                    
                                                    	RIB RNH IP Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rnh_addr
                                                    
                                                    	RNH Address
                                                    	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                    
                                                    .. attribute:: rnh_addr_len
                                                    
                                                    	RNH Address Length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rnh_len
                                                    
                                                    	RNH Length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: rnh_type
                                                    
                                                    	RNH Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: set_aigp_inbound_igp
                                                    
                                                    	AIGP set by policy inbound IGP 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: set_aigp_inbound_metric
                                                    
                                                    	AIGP set by policy inbound metric
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: vpn_distinguisher
                                                    
                                                    	VPN Distinguisher
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                        self.attr_set.parent = self
                                                        self.attribute_key_number = None
                                                        self.attribute_reuse_id_config = None
                                                        self.attribute_reuse_id_current = None
                                                        self.attribute_reuse_id_keys = None
                                                        self.attribute_reuse_id_max_id = None
                                                        self.attribute_reuse_id_node = None
                                                        self.attribute_reuse_id_recover_sec = None
                                                        self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                        self.common_attributes.parent = self
                                                        self.is_application_gateway_present = None
                                                        self.is_as_path2_byte = None
                                                        self.is_attr_set_present = None
                                                        self.is_ribrnh_present = None
                                                        self.is_rnh_present = None
                                                        self.ribrnh_encap = None
                                                        self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                        self.ribrnh_ip.parent = self
                                                        self.ribrnh_mac = None
                                                        self.ribrnh_table = None
                                                        self.ribrnh_vni = None
                                                        self.ribrnhip_table = None
                                                        self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                        self.rnh_addr.parent = self
                                                        self.rnh_addr_len = None
                                                        self.rnh_len = None
                                                        self.rnh_type = None
                                                        self.set_aigp_inbound_igp = None
                                                        self.set_aigp_inbound_metric = None
                                                        self.vpn_distinguisher = None


                                                    class CommonAttributes(object):
                                                        """
                                                        Common attributes
                                                        
                                                        .. attribute:: aggregator_address
                                                        
                                                        	Address where aggregation was performed
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: aggregator_as
                                                        
                                                        	AS where aggregation was last performed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: aigp_metric_value
                                                        
                                                        	AIGP metric value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: as_path
                                                        
                                                        	AS path attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: cluster
                                                        
                                                        	Cluster list attribute
                                                        	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                        
                                                        .. attribute:: community
                                                        
                                                        	Community attribute
                                                        	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                        
                                                        .. attribute:: connector_type
                                                        
                                                        	Connector Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: connector_value
                                                        
                                                        	Connector Value
                                                        	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                        
                                                        .. attribute:: extended_community_flags
                                                        
                                                        	Extended community Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: is_aggregator_present
                                                        
                                                        	Aggregator attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_aigp_present
                                                        
                                                        	AIGP Present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path_present
                                                        
                                                        	AS path attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_atomic_aggregate_present
                                                        
                                                        	Atomic aggregate attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_community_present
                                                        
                                                        	Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_connector_present
                                                        
                                                        	Connector present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_extended_community_present
                                                        
                                                        	Extended community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_label_index_present
                                                        
                                                        	Label Index attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_local_pref_present
                                                        
                                                        	Local Preference attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ls_attribute_present
                                                        
                                                        	BGP LS attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_metric_present
                                                        
                                                        	Metric attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_origin_present
                                                        
                                                        	Origin attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pe_distinguisher_label_present
                                                        
                                                        	PE distinguisher label  attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pmsi_present
                                                        
                                                        	PMSI Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pppmp_present
                                                        
                                                        	PPMP Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ssa_present
                                                        
                                                        	SSA attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_encap_present
                                                        
                                                        	Tunnel Encap attribute present 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2tpv3_cookie
                                                        
                                                        	L2TPv3 Cookie
                                                        	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                        
                                                        .. attribute:: l2tpv3_session_id
                                                        
                                                        	L2TPv3 session id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: label_index_attr
                                                        
                                                        	Label Index attribute
                                                        	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                        
                                                        .. attribute:: local_preference
                                                        
                                                        	Local preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ls_attr
                                                        
                                                        	BGP LS attribute
                                                        	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: neighbor_as
                                                        
                                                        	Neighbor AS number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: origin
                                                        
                                                        	Origin
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: originator
                                                        
                                                        	Originator attribute
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: pe_distinguisher_label
                                                        
                                                        	PE distinguisher label attribute
                                                        	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                        
                                                        .. attribute:: pmsi_flags
                                                        
                                                        	PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pmsi_label
                                                        
                                                        	PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pmsi_type
                                                        
                                                        	PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pmsi_value
                                                        
                                                        	PMSI Value
                                                        	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                        
                                                        .. attribute:: ppm_pvalue
                                                        
                                                        	PPMP Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: sr_policy_allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                        
                                                        .. attribute:: sr_policy_binding_sid
                                                        
                                                        	SR Policy Binding sid
                                                        	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                        
                                                        .. attribute:: sr_policy_explicit_path
                                                        
                                                        	SR Policy Explicit paths
                                                        	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                        
                                                        .. attribute:: sr_policy_preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: sr_tunnel_request_state
                                                        
                                                        	SR Tunnel Request State
                                                        	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                        
                                                        .. attribute:: sr_tunnel_state
                                                        
                                                        	SR Tunnel State
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encap Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: unknown_attribute
                                                        
                                                        	Unknown attributes
                                                        	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.aggregator_address = None
                                                            self.aggregator_as = None
                                                            self.aigp_metric_value = None
                                                            self.as_path = None
                                                            self.cluster = YList()
                                                            self.cluster.parent = self
                                                            self.cluster.name = 'cluster'
                                                            self.community = YList()
                                                            self.community.parent = self
                                                            self.community.name = 'community'
                                                            self.connector_type = None
                                                            self.connector_value = YList()
                                                            self.connector_value.parent = self
                                                            self.connector_value.name = 'connector_value'
                                                            self.extended_community = YList()
                                                            self.extended_community.parent = self
                                                            self.extended_community.name = 'extended_community'
                                                            self.extended_community_flags = None
                                                            self.is_aggregator_present = None
                                                            self.is_aigp_present = None
                                                            self.is_as_path_present = None
                                                            self.is_atomic_aggregate_present = None
                                                            self.is_community_present = None
                                                            self.is_connector_present = None
                                                            self.is_extended_community_present = None
                                                            self.is_label_index_present = None
                                                            self.is_local_pref_present = None
                                                            self.is_ls_attribute_present = None
                                                            self.is_metric_present = None
                                                            self.is_origin_present = None
                                                            self.is_pe_distinguisher_label_present = None
                                                            self.is_pmsi_present = None
                                                            self.is_pppmp_present = None
                                                            self.is_ssa_present = None
                                                            self.is_tunnel_encap_present = None
                                                            self.l2tpv3_cookie = YList()
                                                            self.l2tpv3_cookie.parent = self
                                                            self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                            self.l2tpv3_session_id = None
                                                            self.label_index_attr = YList()
                                                            self.label_index_attr.parent = self
                                                            self.label_index_attr.name = 'label_index_attr'
                                                            self.local_preference = None
                                                            self.ls_attr = YList()
                                                            self.ls_attr.parent = self
                                                            self.ls_attr.name = 'ls_attr'
                                                            self.metric = None
                                                            self.neighbor_as = None
                                                            self.origin = None
                                                            self.originator = None
                                                            self.pe_distinguisher_label = YList()
                                                            self.pe_distinguisher_label.parent = self
                                                            self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                            self.pmsi_flags = None
                                                            self.pmsi_label = None
                                                            self.pmsi_type = None
                                                            self.pmsi_value = YList()
                                                            self.pmsi_value.parent = self
                                                            self.pmsi_value.name = 'pmsi_value'
                                                            self.ppm_pvalue = None
                                                            self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                            self.sr_policy_allocated_binding_sid.parent = self
                                                            self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                            self.sr_policy_binding_sid.parent = self
                                                            self.sr_policy_explicit_path = YList()
                                                            self.sr_policy_explicit_path.parent = self
                                                            self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                            self.sr_policy_preference = None
                                                            self.sr_tunnel_request_state = None
                                                            self.sr_tunnel_state = None
                                                            self.tunnel_encap_type = None
                                                            self.unknown_attribute = YList()
                                                            self.unknown_attribute.parent = self
                                                            self.unknown_attribute.name = 'unknown_attribute'


                                                        class SrPolicyBindingSid(object):
                                                            """
                                                            SR Policy Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_address = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                        class SrPolicyAllocatedBindingSid(object):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_address = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                        class Community(object):
                                                            """
                                                            Community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                        class ExtendedCommunity(object):
                                                            """
                                                            Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                        class UnknownAttribute(object):
                                                            """
                                                            Unknown attributes
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                        class Cluster(object):
                                                            """
                                                            Cluster list attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                        class L2Tpv3Cookie(object):
                                                            """
                                                            L2TPv3 Cookie
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                        class ConnectorValue(object):
                                                            """
                                                            Connector Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                        class PmsiValue(object):
                                                            """
                                                            PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                        class LsAttr(object):
                                                            """
                                                            BGP LS attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                        class LabelIndexAttr(object):
                                                            """
                                                            Label Index attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                        class PeDistinguisherLabel(object):
                                                            """
                                                            PE distinguisher label attribute
                                                            
                                                            .. attribute:: label
                                                            
                                                            	Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pe_address
                                                            
                                                            	 PE address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.label = None
                                                                self.pe_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.label is not None:
                                                                    return True

                                                                if self.pe_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                        class SrPolicyExplicitPath(object):
                                                            """
                                                            SR Policy Explicit paths
                                                            
                                                            .. attribute:: sid
                                                            
                                                            	Sidlist for explicit path
                                                            	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of explicit path
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.sid = YList()
                                                                self.sid.parent = self
                                                                self.sid.name = 'sid'
                                                                self.weight = None


                                                            class Sid(object):
                                                                """
                                                                Sidlist for explicit path
                                                                
                                                                .. attribute:: ipv4
                                                                
                                                                	IP Address sid
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6
                                                                
                                                                	IPv6 address sid
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label sid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Sid Type
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4 = None
                                                                    self.ipv6 = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4 is not None:
                                                                        return True

                                                                    if self.ipv6 is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.sid is not None:
                                                                    for child_ref in self.sid:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.weight is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.aggregator_address is not None:
                                                                return True

                                                            if self.aggregator_as is not None:
                                                                return True

                                                            if self.aigp_metric_value is not None:
                                                                return True

                                                            if self.as_path is not None:
                                                                return True

                                                            if self.cluster is not None:
                                                                for child_ref in self.cluster:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.community is not None:
                                                                for child_ref in self.community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.connector_type is not None:
                                                                return True

                                                            if self.connector_value is not None:
                                                                for child_ref in self.connector_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.extended_community is not None:
                                                                for child_ref in self.extended_community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.extended_community_flags is not None:
                                                                return True

                                                            if self.is_aggregator_present is not None:
                                                                return True

                                                            if self.is_aigp_present is not None:
                                                                return True

                                                            if self.is_as_path_present is not None:
                                                                return True

                                                            if self.is_atomic_aggregate_present is not None:
                                                                return True

                                                            if self.is_community_present is not None:
                                                                return True

                                                            if self.is_connector_present is not None:
                                                                return True

                                                            if self.is_extended_community_present is not None:
                                                                return True

                                                            if self.is_label_index_present is not None:
                                                                return True

                                                            if self.is_local_pref_present is not None:
                                                                return True

                                                            if self.is_ls_attribute_present is not None:
                                                                return True

                                                            if self.is_metric_present is not None:
                                                                return True

                                                            if self.is_origin_present is not None:
                                                                return True

                                                            if self.is_pe_distinguisher_label_present is not None:
                                                                return True

                                                            if self.is_pmsi_present is not None:
                                                                return True

                                                            if self.is_pppmp_present is not None:
                                                                return True

                                                            if self.is_ssa_present is not None:
                                                                return True

                                                            if self.is_tunnel_encap_present is not None:
                                                                return True

                                                            if self.l2tpv3_cookie is not None:
                                                                for child_ref in self.l2tpv3_cookie:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.l2tpv3_session_id is not None:
                                                                return True

                                                            if self.label_index_attr is not None:
                                                                for child_ref in self.label_index_attr:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.local_preference is not None:
                                                                return True

                                                            if self.ls_attr is not None:
                                                                for child_ref in self.ls_attr:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.neighbor_as is not None:
                                                                return True

                                                            if self.origin is not None:
                                                                return True

                                                            if self.originator is not None:
                                                                return True

                                                            if self.pe_distinguisher_label is not None:
                                                                for child_ref in self.pe_distinguisher_label:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.pmsi_flags is not None:
                                                                return True

                                                            if self.pmsi_label is not None:
                                                                return True

                                                            if self.pmsi_type is not None:
                                                                return True

                                                            if self.pmsi_value is not None:
                                                                for child_ref in self.pmsi_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.ppm_pvalue is not None:
                                                                return True

                                                            if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                                return True

                                                            if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                                return True

                                                            if self.sr_policy_explicit_path is not None:
                                                                for child_ref in self.sr_policy_explicit_path:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.sr_policy_preference is not None:
                                                                return True

                                                            if self.sr_tunnel_request_state is not None:
                                                                return True

                                                            if self.sr_tunnel_state is not None:
                                                                return True

                                                            if self.tunnel_encap_type is not None:
                                                                return True

                                                            if self.unknown_attribute is not None:
                                                                for child_ref in self.unknown_attribute:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                                    class AttrSet(object):
                                                        """
                                                        ATTR\_SET attribute
                                                        
                                                        .. attribute:: aggregator_address
                                                        
                                                        	Address where aggregation was performed
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: aggregator_as
                                                        
                                                        	AS where aggregation was last performed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: aigp_metric_value
                                                        
                                                        	AIGP metric value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: as_path
                                                        
                                                        	AS path attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: cluster
                                                        
                                                        	Cluster list attribute
                                                        	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                        
                                                        .. attribute:: community
                                                        
                                                        	Community attribute
                                                        	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                        
                                                        .. attribute:: connector_type
                                                        
                                                        	Connector Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: connector_value
                                                        
                                                        	Connector Value
                                                        	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                        
                                                        .. attribute:: extended_community_flags
                                                        
                                                        	Extended community Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: is_aggregator_present
                                                        
                                                        	Aggregator attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_aigp_present
                                                        
                                                        	AIGP Present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path_present
                                                        
                                                        	AS path attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_atomic_aggregate_present
                                                        
                                                        	Atomic aggregate attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_community_present
                                                        
                                                        	Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_connector_present
                                                        
                                                        	Connector present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_extended_community_present
                                                        
                                                        	Extended community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_label_index_present
                                                        
                                                        	Label Index attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_local_pref_present
                                                        
                                                        	Local Preference attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ls_attribute_present
                                                        
                                                        	BGP LS attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_metric_present
                                                        
                                                        	Metric attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_origin_present
                                                        
                                                        	Origin attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pe_distinguisher_label_present
                                                        
                                                        	PE distinguisher label  attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pmsi_present
                                                        
                                                        	PMSI Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pppmp_present
                                                        
                                                        	PPMP Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ssa_present
                                                        
                                                        	SSA attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_encap_present
                                                        
                                                        	Tunnel Encap attribute present 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2tpv3_cookie
                                                        
                                                        	L2TPv3 Cookie
                                                        	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                        
                                                        .. attribute:: l2tpv3_session_id
                                                        
                                                        	L2TPv3 session id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: label_index_attr
                                                        
                                                        	Label Index attribute
                                                        	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                        
                                                        .. attribute:: local_preference
                                                        
                                                        	Local preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ls_attr
                                                        
                                                        	BGP LS attribute
                                                        	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: neighbor_as
                                                        
                                                        	Neighbor AS number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: origin
                                                        
                                                        	Origin
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: originator
                                                        
                                                        	Originator attribute
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: pe_distinguisher_label
                                                        
                                                        	PE distinguisher label attribute
                                                        	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                        
                                                        .. attribute:: pmsi_flags
                                                        
                                                        	PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pmsi_label
                                                        
                                                        	PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pmsi_type
                                                        
                                                        	PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pmsi_value
                                                        
                                                        	PMSI Value
                                                        	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                        
                                                        .. attribute:: ppm_pvalue
                                                        
                                                        	PPMP Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: sr_policy_allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                        
                                                        .. attribute:: sr_policy_binding_sid
                                                        
                                                        	SR Policy Binding sid
                                                        	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                        
                                                        .. attribute:: sr_policy_explicit_path
                                                        
                                                        	SR Policy Explicit paths
                                                        	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                        
                                                        .. attribute:: sr_policy_preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: sr_tunnel_request_state
                                                        
                                                        	SR Tunnel Request State
                                                        	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                        
                                                        .. attribute:: sr_tunnel_state
                                                        
                                                        	SR Tunnel State
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encap Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: unknown_attribute
                                                        
                                                        	Unknown attributes
                                                        	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.aggregator_address = None
                                                            self.aggregator_as = None
                                                            self.aigp_metric_value = None
                                                            self.as_path = None
                                                            self.cluster = YList()
                                                            self.cluster.parent = self
                                                            self.cluster.name = 'cluster'
                                                            self.community = YList()
                                                            self.community.parent = self
                                                            self.community.name = 'community'
                                                            self.connector_type = None
                                                            self.connector_value = YList()
                                                            self.connector_value.parent = self
                                                            self.connector_value.name = 'connector_value'
                                                            self.extended_community = YList()
                                                            self.extended_community.parent = self
                                                            self.extended_community.name = 'extended_community'
                                                            self.extended_community_flags = None
                                                            self.is_aggregator_present = None
                                                            self.is_aigp_present = None
                                                            self.is_as_path_present = None
                                                            self.is_atomic_aggregate_present = None
                                                            self.is_community_present = None
                                                            self.is_connector_present = None
                                                            self.is_extended_community_present = None
                                                            self.is_label_index_present = None
                                                            self.is_local_pref_present = None
                                                            self.is_ls_attribute_present = None
                                                            self.is_metric_present = None
                                                            self.is_origin_present = None
                                                            self.is_pe_distinguisher_label_present = None
                                                            self.is_pmsi_present = None
                                                            self.is_pppmp_present = None
                                                            self.is_ssa_present = None
                                                            self.is_tunnel_encap_present = None
                                                            self.l2tpv3_cookie = YList()
                                                            self.l2tpv3_cookie.parent = self
                                                            self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                            self.l2tpv3_session_id = None
                                                            self.label_index_attr = YList()
                                                            self.label_index_attr.parent = self
                                                            self.label_index_attr.name = 'label_index_attr'
                                                            self.local_preference = None
                                                            self.ls_attr = YList()
                                                            self.ls_attr.parent = self
                                                            self.ls_attr.name = 'ls_attr'
                                                            self.metric = None
                                                            self.neighbor_as = None
                                                            self.origin = None
                                                            self.originator = None
                                                            self.pe_distinguisher_label = YList()
                                                            self.pe_distinguisher_label.parent = self
                                                            self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                            self.pmsi_flags = None
                                                            self.pmsi_label = None
                                                            self.pmsi_type = None
                                                            self.pmsi_value = YList()
                                                            self.pmsi_value.parent = self
                                                            self.pmsi_value.name = 'pmsi_value'
                                                            self.ppm_pvalue = None
                                                            self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                            self.sr_policy_allocated_binding_sid.parent = self
                                                            self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                            self.sr_policy_binding_sid.parent = self
                                                            self.sr_policy_explicit_path = YList()
                                                            self.sr_policy_explicit_path.parent = self
                                                            self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                            self.sr_policy_preference = None
                                                            self.sr_tunnel_request_state = None
                                                            self.sr_tunnel_state = None
                                                            self.tunnel_encap_type = None
                                                            self.unknown_attribute = YList()
                                                            self.unknown_attribute.parent = self
                                                            self.unknown_attribute.name = 'unknown_attribute'


                                                        class SrPolicyBindingSid(object):
                                                            """
                                                            SR Policy Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_address = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                        class SrPolicyAllocatedBindingSid(object):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_address = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                        class Community(object):
                                                            """
                                                            Community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                        class ExtendedCommunity(object):
                                                            """
                                                            Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                        class UnknownAttribute(object):
                                                            """
                                                            Unknown attributes
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                        class Cluster(object):
                                                            """
                                                            Cluster list attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                        class L2Tpv3Cookie(object):
                                                            """
                                                            L2TPv3 Cookie
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                        class ConnectorValue(object):
                                                            """
                                                            Connector Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                        class PmsiValue(object):
                                                            """
                                                            PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                        class LsAttr(object):
                                                            """
                                                            BGP LS attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                        class LabelIndexAttr(object):
                                                            """
                                                            Label Index attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                        class PeDistinguisherLabel(object):
                                                            """
                                                            PE distinguisher label attribute
                                                            
                                                            .. attribute:: label
                                                            
                                                            	Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pe_address
                                                            
                                                            	 PE address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.label = None
                                                                self.pe_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.label is not None:
                                                                    return True

                                                                if self.pe_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                        class SrPolicyExplicitPath(object):
                                                            """
                                                            SR Policy Explicit paths
                                                            
                                                            .. attribute:: sid
                                                            
                                                            	Sidlist for explicit path
                                                            	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of explicit path
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.sid = YList()
                                                                self.sid.parent = self
                                                                self.sid.name = 'sid'
                                                                self.weight = None


                                                            class Sid(object):
                                                                """
                                                                Sidlist for explicit path
                                                                
                                                                .. attribute:: ipv4
                                                                
                                                                	IP Address sid
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6
                                                                
                                                                	IPv6 address sid
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label sid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Sid Type
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4 = None
                                                                    self.ipv6 = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4 is not None:
                                                                        return True

                                                                    if self.ipv6 is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.sid is not None:
                                                                    for child_ref in self.sid:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.weight is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.aggregator_address is not None:
                                                                return True

                                                            if self.aggregator_as is not None:
                                                                return True

                                                            if self.aigp_metric_value is not None:
                                                                return True

                                                            if self.as_path is not None:
                                                                return True

                                                            if self.cluster is not None:
                                                                for child_ref in self.cluster:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.community is not None:
                                                                for child_ref in self.community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.connector_type is not None:
                                                                return True

                                                            if self.connector_value is not None:
                                                                for child_ref in self.connector_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.extended_community is not None:
                                                                for child_ref in self.extended_community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.extended_community_flags is not None:
                                                                return True

                                                            if self.is_aggregator_present is not None:
                                                                return True

                                                            if self.is_aigp_present is not None:
                                                                return True

                                                            if self.is_as_path_present is not None:
                                                                return True

                                                            if self.is_atomic_aggregate_present is not None:
                                                                return True

                                                            if self.is_community_present is not None:
                                                                return True

                                                            if self.is_connector_present is not None:
                                                                return True

                                                            if self.is_extended_community_present is not None:
                                                                return True

                                                            if self.is_label_index_present is not None:
                                                                return True

                                                            if self.is_local_pref_present is not None:
                                                                return True

                                                            if self.is_ls_attribute_present is not None:
                                                                return True

                                                            if self.is_metric_present is not None:
                                                                return True

                                                            if self.is_origin_present is not None:
                                                                return True

                                                            if self.is_pe_distinguisher_label_present is not None:
                                                                return True

                                                            if self.is_pmsi_present is not None:
                                                                return True

                                                            if self.is_pppmp_present is not None:
                                                                return True

                                                            if self.is_ssa_present is not None:
                                                                return True

                                                            if self.is_tunnel_encap_present is not None:
                                                                return True

                                                            if self.l2tpv3_cookie is not None:
                                                                for child_ref in self.l2tpv3_cookie:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.l2tpv3_session_id is not None:
                                                                return True

                                                            if self.label_index_attr is not None:
                                                                for child_ref in self.label_index_attr:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.local_preference is not None:
                                                                return True

                                                            if self.ls_attr is not None:
                                                                for child_ref in self.ls_attr:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.neighbor_as is not None:
                                                                return True

                                                            if self.origin is not None:
                                                                return True

                                                            if self.originator is not None:
                                                                return True

                                                            if self.pe_distinguisher_label is not None:
                                                                for child_ref in self.pe_distinguisher_label:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.pmsi_flags is not None:
                                                                return True

                                                            if self.pmsi_label is not None:
                                                                return True

                                                            if self.pmsi_type is not None:
                                                                return True

                                                            if self.pmsi_value is not None:
                                                                for child_ref in self.pmsi_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.ppm_pvalue is not None:
                                                                return True

                                                            if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                                return True

                                                            if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                                return True

                                                            if self.sr_policy_explicit_path is not None:
                                                                for child_ref in self.sr_policy_explicit_path:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.sr_policy_preference is not None:
                                                                return True

                                                            if self.sr_tunnel_request_state is not None:
                                                                return True

                                                            if self.sr_tunnel_state is not None:
                                                                return True

                                                            if self.tunnel_encap_type is not None:
                                                                return True

                                                            if self.unknown_attribute is not None:
                                                                for child_ref in self.unknown_attribute:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                                    class RnhAddr(object):
                                                        """
                                                        RNH Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                        
                                                        .. attribute:: mac_address
                                                        
                                                        	MAC Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_address = None
                                                            self.ipv6_address = None
                                                            self.len = None
                                                            self.mac_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.len is not None:
                                                                return True

                                                            if self.mac_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                                    class RibrnhIp(object):
                                                        """
                                                        RIB RNH IP Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.attr_set is not None and self.attr_set._has_data():
                                                            return True

                                                        if self.attribute_key_number is not None:
                                                            return True

                                                        if self.attribute_reuse_id_config is not None:
                                                            return True

                                                        if self.attribute_reuse_id_current is not None:
                                                            return True

                                                        if self.attribute_reuse_id_keys is not None:
                                                            return True

                                                        if self.attribute_reuse_id_max_id is not None:
                                                            return True

                                                        if self.attribute_reuse_id_node is not None:
                                                            return True

                                                        if self.attribute_reuse_id_recover_sec is not None:
                                                            return True

                                                        if self.common_attributes is not None and self.common_attributes._has_data():
                                                            return True

                                                        if self.is_application_gateway_present is not None:
                                                            return True

                                                        if self.is_as_path2_byte is not None:
                                                            return True

                                                        if self.is_attr_set_present is not None:
                                                            return True

                                                        if self.is_ribrnh_present is not None:
                                                            return True

                                                        if self.is_rnh_present is not None:
                                                            return True

                                                        if self.ribrnh_encap is not None:
                                                            return True

                                                        if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                            return True

                                                        if self.ribrnh_mac is not None:
                                                            return True

                                                        if self.ribrnh_table is not None:
                                                            return True

                                                        if self.ribrnh_vni is not None:
                                                            return True

                                                        if self.ribrnhip_table is not None:
                                                            return True

                                                        if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                            return True

                                                        if self.rnh_addr_len is not None:
                                                            return True

                                                        if self.rnh_len is not None:
                                                            return True

                                                        if self.rnh_type is not None:
                                                            return True

                                                        if self.set_aigp_inbound_igp is not None:
                                                            return True

                                                        if self.set_aigp_inbound_metric is not None:
                                                            return True

                                                        if self.vpn_distinguisher is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-process-instance-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.af_name is not None:
                                                        return True

                                                    if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                        return True

                                                    if self.label_fail is not None:
                                                        return True

                                                    if self.label_o_or_version is not None:
                                                        return True

                                                    if self.label_oor is not None:
                                                        return True

                                                    if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                        return True

                                                    if self.no_path is not None:
                                                        return True

                                                    if self.path_information is not None and self.path_information._has_data():
                                                        return True

                                                    if self.prefix_version is not None:
                                                        return True

                                                    if self.process_instance_id is not None:
                                                        return True

                                                    if self.route_distinguisher is not None:
                                                        return True

                                                    if self.source_route_distinguisher is not None:
                                                        return True

                                                    if self.source_vrf_name is not None:
                                                        return True

                                                    if self.srcaf_name is not None:
                                                        return True

                                                    if self.vrf_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath']['meta_info']


                                            class LocalPathElement(object):
                                                """
                                                Local path element list
                                                
                                                .. attribute:: is_perm_path_pelem
                                                
                                                	Pelem for permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: nhte_tunnel
                                                
                                                	NH TE tunnel information
                                                	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.NhteTunnel>`
                                                
                                                .. attribute:: pelem_flags
                                                
                                                	Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_gw_metric
                                                
                                                	Gateway metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_no_addpath_table_attr_version
                                                
                                                	No\-addpath Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_no_bestpath_table_attr_version
                                                
                                                	No\-bestpath Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_flags
                                                
                                                	Path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pelem_path_id
                                                
                                                	Local Path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_neighbor_addr
                                                
                                                	Path neighbor address
                                                	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr>`
                                                
                                                .. attribute:: pelem_path_nexthop
                                                
                                                	Path nexthop address
                                                	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop>`
                                                
                                                .. attribute:: pelem_path_peer_path_id
                                                
                                                	Path peer path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_table_attr_version
                                                
                                                	Path Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_table_attr_version
                                                
                                                	Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_version
                                                
                                                	Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_perm_path_pelem = None
                                                    self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.NhteTunnel()
                                                    self.nhte_tunnel.parent = self
                                                    self.pelem_flags = None
                                                    self.pelem_gw_metric = None
                                                    self.pelem_no_addpath_table_attr_version = None
                                                    self.pelem_no_bestpath_table_attr_version = None
                                                    self.pelem_path_flags = None
                                                    self.pelem_path_id = None
                                                    self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr()
                                                    self.pelem_path_neighbor_addr.parent = self
                                                    self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop()
                                                    self.pelem_path_nexthop.parent = self
                                                    self.pelem_path_peer_path_id = None
                                                    self.pelem_path_table_attr_version = None
                                                    self.pelem_table_attr_version = None
                                                    self.pelem_version = None


                                                class PelemPathNexthop(object):
                                                    """
                                                    Path nexthop address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-nexthop'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop']['meta_info']


                                                class NhteTunnel(object):
                                                    """
                                                    NH TE tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_te_tunnel
                                                    
                                                    	NH TE Tunnel info is present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last rib update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	tunnel name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	tunnel type
                                                    	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.binding_label = None
                                                        self.has_te_tunnel = None
                                                        self.is_tunnel_info_stale = None
                                                        self.is_tunnel_registered = None
                                                        self.is_tunnel_up = None
                                                        self.last_tunnel_update = None
                                                        self.tunnel_if_handle = None
                                                        self.tunnel_name = None
                                                        self.tunnel_type = None
                                                        self.tunnel_v6_enabled = None
                                                        self.tunnel_v6_required = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.binding_label is not None:
                                                            return True

                                                        if self.has_te_tunnel is not None:
                                                            return True

                                                        if self.is_tunnel_info_stale is not None:
                                                            return True

                                                        if self.is_tunnel_registered is not None:
                                                            return True

                                                        if self.is_tunnel_up is not None:
                                                            return True

                                                        if self.last_tunnel_update is not None:
                                                            return True

                                                        if self.tunnel_if_handle is not None:
                                                            return True

                                                        if self.tunnel_name is not None:
                                                            return True

                                                        if self.tunnel_type is not None:
                                                            return True

                                                        if self.tunnel_v6_enabled is not None:
                                                            return True

                                                        if self.tunnel_v6_required is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.NhteTunnel']['meta_info']


                                                class PelemPathNeighborAddr(object):
                                                    """
                                                    Path neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-neighbor-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-path-element'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_perm_path_pelem is not None:
                                                        return True

                                                    if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                        return True

                                                    if self.pelem_flags is not None:
                                                        return True

                                                    if self.pelem_gw_metric is not None:
                                                        return True

                                                    if self.pelem_no_addpath_table_attr_version is not None:
                                                        return True

                                                    if self.pelem_no_bestpath_table_attr_version is not None:
                                                        return True

                                                    if self.pelem_path_flags is not None:
                                                        return True

                                                    if self.pelem_path_id is not None:
                                                        return True

                                                    if self.pelem_path_neighbor_addr is not None and self.pelem_path_neighbor_addr._has_data():
                                                        return True

                                                    if self.pelem_path_nexthop is not None and self.pelem_path_nexthop._has_data():
                                                        return True

                                                    if self.pelem_path_peer_path_id is not None:
                                                        return True

                                                    if self.pelem_path_table_attr_version is not None:
                                                        return True

                                                    if self.pelem_table_attr_version is not None:
                                                        return True

                                                    if self.pelem_version is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement']['meta_info']


                                            class ActivePathElement(object):
                                                """
                                                Path element list received from Active inst
                                                
                                                .. attribute:: is_perm_path_pelem
                                                
                                                	Pelem for permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: nhte_tunnel
                                                
                                                	NH TE tunnel information
                                                	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.NhteTunnel>`
                                                
                                                .. attribute:: pelem_flags
                                                
                                                	Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_gw_metric
                                                
                                                	Gateway metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_no_addpath_table_attr_version
                                                
                                                	No\-addpath Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_no_bestpath_table_attr_version
                                                
                                                	No\-bestpath Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_flags
                                                
                                                	Path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pelem_path_id
                                                
                                                	Local Path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_neighbor_addr
                                                
                                                	Path neighbor address
                                                	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr>`
                                                
                                                .. attribute:: pelem_path_nexthop
                                                
                                                	Path nexthop address
                                                	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop>`
                                                
                                                .. attribute:: pelem_path_peer_path_id
                                                
                                                	Path peer path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_table_attr_version
                                                
                                                	Path Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_table_attr_version
                                                
                                                	Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_version
                                                
                                                	Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_perm_path_pelem = None
                                                    self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.NhteTunnel()
                                                    self.nhte_tunnel.parent = self
                                                    self.pelem_flags = None
                                                    self.pelem_gw_metric = None
                                                    self.pelem_no_addpath_table_attr_version = None
                                                    self.pelem_no_bestpath_table_attr_version = None
                                                    self.pelem_path_flags = None
                                                    self.pelem_path_id = None
                                                    self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr()
                                                    self.pelem_path_neighbor_addr.parent = self
                                                    self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop()
                                                    self.pelem_path_nexthop.parent = self
                                                    self.pelem_path_peer_path_id = None
                                                    self.pelem_path_table_attr_version = None
                                                    self.pelem_table_attr_version = None
                                                    self.pelem_version = None


                                                class PelemPathNexthop(object):
                                                    """
                                                    Path nexthop address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-nexthop'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop']['meta_info']


                                                class NhteTunnel(object):
                                                    """
                                                    NH TE tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_te_tunnel
                                                    
                                                    	NH TE Tunnel info is present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last rib update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	tunnel name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	tunnel type
                                                    	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.binding_label = None
                                                        self.has_te_tunnel = None
                                                        self.is_tunnel_info_stale = None
                                                        self.is_tunnel_registered = None
                                                        self.is_tunnel_up = None
                                                        self.last_tunnel_update = None
                                                        self.tunnel_if_handle = None
                                                        self.tunnel_name = None
                                                        self.tunnel_type = None
                                                        self.tunnel_v6_enabled = None
                                                        self.tunnel_v6_required = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.binding_label is not None:
                                                            return True

                                                        if self.has_te_tunnel is not None:
                                                            return True

                                                        if self.is_tunnel_info_stale is not None:
                                                            return True

                                                        if self.is_tunnel_registered is not None:
                                                            return True

                                                        if self.is_tunnel_up is not None:
                                                            return True

                                                        if self.last_tunnel_update is not None:
                                                            return True

                                                        if self.tunnel_if_handle is not None:
                                                            return True

                                                        if self.tunnel_name is not None:
                                                            return True

                                                        if self.tunnel_type is not None:
                                                            return True

                                                        if self.tunnel_v6_enabled is not None:
                                                            return True

                                                        if self.tunnel_v6_required is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.NhteTunnel']['meta_info']


                                                class PelemPathNeighborAddr(object):
                                                    """
                                                    Path neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-neighbor-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-path-element'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_perm_path_pelem is not None:
                                                        return True

                                                    if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                        return True

                                                    if self.pelem_flags is not None:
                                                        return True

                                                    if self.pelem_gw_metric is not None:
                                                        return True

                                                    if self.pelem_no_addpath_table_attr_version is not None:
                                                        return True

                                                    if self.pelem_no_bestpath_table_attr_version is not None:
                                                        return True

                                                    if self.pelem_path_flags is not None:
                                                        return True

                                                    if self.pelem_path_id is not None:
                                                        return True

                                                    if self.pelem_path_neighbor_addr is not None and self.pelem_path_neighbor_addr._has_data():
                                                        return True

                                                    if self.pelem_path_nexthop is not None and self.pelem_path_nexthop._has_data():
                                                        return True

                                                    if self.pelem_path_peer_path_id is not None:
                                                        return True

                                                    if self.pelem_path_table_attr_version is not None:
                                                        return True

                                                    if self.pelem_table_attr_version is not None:
                                                        return True

                                                    if self.pelem_version is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.rd is None:
                                                    raise YPYModelError('Key property rd is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-rd[Cisco-IOS-XR-ipv4-bgp-oper:rd = ' + str(self.rd) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.rd is not None:
                                                    return True

                                                if self.active_path_element is not None:
                                                    for child_ref in self.active_path_element:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.active_process_instance_path is not None:
                                                    for child_ref in self.active_process_instance_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.add_path_orr_bitfield is not None:
                                                    for child_ref in self.add_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.advertisedto_pe is not None:
                                                    return True

                                                if self.af_name is not None:
                                                    return True

                                                if self.best_path_orr_bitfield is not None:
                                                    for child_ref in self.best_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                    return True

                                                if self.bit is not None:
                                                    return True

                                                if self.flags is not None:
                                                    return True

                                                if self.gateway_array is not None:
                                                    return True

                                                if self.has_inconsistent_paths is not None:
                                                    return True

                                                if self.has_lbl_retained is not None:
                                                    return True

                                                if self.has_local_label is not None:
                                                    return True

                                                if self.is_net_aggregation_suppressed is not None:
                                                    return True

                                                if self.is_net_ldp_signaled is not None:
                                                    return True

                                                if self.is_permanent_network is not None:
                                                    return True

                                                if self.local_path_element is not None:
                                                    for child_ref in self.local_path_element:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_peers_advertised_to is not None:
                                                    for child_ref in self.local_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_process_instance_path is not None:
                                                    for child_ref in self.local_process_instance_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.net_backup_available is not None:
                                                    return True

                                                if self.net_backup_label_rewrite_available is not None:
                                                    return True

                                                if self.net_eibgp_multipath is not None:
                                                    return True

                                                if self.net_extended_flags is not None:
                                                    return True

                                                if self.net_flags is not None:
                                                    return True

                                                if self.net_local_label is not None:
                                                    return True

                                                if self.net_local_label_rewrite is not None:
                                                    return True

                                                if self.net_local_label_srgb is not None:
                                                    return True

                                                if self.net_multipath is not None:
                                                    return True

                                                if self.num_of_path is not None:
                                                    return True

                                                if self.pe_peers_advertised_to is not None:
                                                    for child_ref in self.pe_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.process_instance_id is not None:
                                                    return True

                                                if self.resilient_nexthop_set is not None:
                                                    return True

                                                if self.rib_failed is not None:
                                                    return True

                                                if self.route_distinguisher is not None:
                                                    return True

                                                if self.table_brib_version is not None:
                                                    return True

                                                if self.table_version is not None:
                                                    return True

                                                if self.version is not None:
                                                    return True

                                                if self.version_age is not None and self.version_age._has_data():
                                                    return True

                                                if self.version_timestamp is not None and self.version_timestamp._has_data():
                                                    return True

                                                if self.vrf_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-rds'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.network_rd is not None:
                                                for child_ref in self.network_rd:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.network_addr is None:
                                            raise YPYModelError('Key property network_addr is None')
                                        if self.network_prefix is None:
                                            raise YPYModelError('Key property network_prefix is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-all-rd[Cisco-IOS-XR-ipv4-bgp-oper:network-addr = ' + str(self.network_addr) + '][Cisco-IOS-XR-ipv4-bgp-oper:network-prefix = ' + str(self.network_prefix) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.network_addr is not None:
                                            return True

                                        if self.network_prefix is not None:
                                            return True

                                        if self.network_rds is not None and self.network_rds._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-all-rds'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.network_all_rd is not None:
                                        for child_ref in self.network_all_rd:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NetworkAllRds']['meta_info']


                            class UpdateGenerationNeighbors(object):
                                """
                                Update generation for all neighbors
                                
                                .. attribute:: update_generation_neighbor
                                
                                	Update generation for neighbor
                                	**type**\: list of    :py:class:`UpdateGenerationNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.update_generation_neighbor = YList()
                                    self.update_generation_neighbor.parent = self
                                    self.update_generation_neighbor.name = 'update_generation_neighbor'


                                class UpdateGenerationNeighbor(object):
                                    """
                                    Update generation for neighbor
                                    
                                    .. attribute:: ack_version
                                    
                                    	Ack version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: current_update_group_af_name
                                    
                                    	Current Update\-group address\-family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: default_originate_internal_context
                                    
                                    	Default\-origination context
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: default_originate_state
                                    
                                    	Default\-origination state
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: filter_group_index
                                    
                                    	Filter\-group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: first_default_originate_timestamp
                                    
                                    	First default\-origination time
                                    	**type**\:   :py:class:`FirstDefaultOriginateTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp>`
                                    
                                    .. attribute:: first_update_queued_timestamp
                                    
                                    	First update queued time
                                    	**type**\:   :py:class:`FirstUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp>`
                                    
                                    .. attribute:: first_update_write_timestamp
                                    
                                    	First update write time
                                    	**type**\:   :py:class:`FirstUpdateWriteTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp>`
                                    
                                    .. attribute:: inbound_refresh_count
                                    
                                    	Refresh Inbound count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_eor_outstanding
                                    
                                    	Number of EORs outstanding
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_update_group_timer_running
                                    
                                    	Is update\-group timer running
                                    	**type**\:  bool
                                    
                                    .. attribute:: last_default_originate_age
                                    
                                    	Time since last default\-origination event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_default_originate_timestamp
                                    
                                    	Last default\-origination time
                                    	**type**\:   :py:class:`LastDefaultOriginateTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp>`
                                    
                                    .. attribute:: last_filter_group_add_timestamp
                                    
                                    	Last added time
                                    	**type**\:   :py:class:`LastFilterGroupAddTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp>`
                                    
                                    .. attribute:: last_filter_group_remove_timestamp
                                    
                                    	Last removed time
                                    	**type**\:   :py:class:`LastFilterGroupRemoveTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp>`
                                    
                                    .. attribute:: last_refresh_update_queued_age
                                    
                                    	Time since last refresh update queued event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_refresh_update_queued_timestamp
                                    
                                    	Last refresh update queued time
                                    	**type**\:   :py:class:`LastRefreshUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp>`
                                    
                                    .. attribute:: last_refresh_update_write_age
                                    
                                    	Time since last refresh update write event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_refresh_update_write_timestamp
                                    
                                    	Last refresh update write time
                                    	**type**\:   :py:class:`LastRefreshUpdateWriteTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp>`
                                    
                                    .. attribute:: last_sub_group_add_timestamp
                                    
                                    	Last added time
                                    	**type**\:   :py:class:`LastSubGroupAddTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp>`
                                    
                                    .. attribute:: last_sub_group_remove_timestamp
                                    
                                    	Last removed time
                                    	**type**\:   :py:class:`LastSubGroupRemoveTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp>`
                                    
                                    .. attribute:: last_update_group_af_name
                                    
                                    	Last Update\-group address\-family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: last_update_group_expiry_timestamp
                                    
                                    	Last update\-group timer expiry
                                    	**type**\:   :py:class:`LastUpdateGroupExpiryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp>`
                                    
                                    .. attribute:: last_update_group_start_timestamp
                                    
                                    	Last update\-group timer start
                                    	**type**\:   :py:class:`LastUpdateGroupStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp>`
                                    
                                    .. attribute:: last_update_queued_age
                                    
                                    	Time since last update queued event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_queued_timestamp
                                    
                                    	Last update queued time
                                    	**type**\:   :py:class:`LastUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp>`
                                    
                                    .. attribute:: last_update_write_age
                                    
                                    	Time since last update write event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_write_timestamp
                                    
                                    	Last update write time
                                    	**type**\:   :py:class:`LastUpdateWriteTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp>`
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: next_resume_version
                                    
                                    	Resume version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: outbound_refresh_count
                                    
                                    	Refresh Outbound count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: outstanding_version_count
                                    
                                    	Outstanding version count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pending_target_version
                                    
                                    	Pending target version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_id
                                    
                                    	ProcessID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_ack_version
                                    
                                    	Refresh Ack version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_filter_group_index
                                    
                                    	Refresh Filter\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_next_resume_version
                                    
                                    	Refresh resume version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_pending_target_version
                                    
                                    	Pending refresh target version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_requested_target_version
                                    
                                    	Requested refresh target version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_id
                                    
                                    	Refresh sub\-group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_index
                                    
                                    	Refresh Sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_update_out_queue_messages
                                    
                                    	Refresh OutQueue messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_update_out_queue_size
                                    
                                    	Refresh OutQueue size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_id
                                    
                                    	Sub\-group ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sub_group_index
                                    
                                    	Sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sub_group_index_xr
                                    
                                    	Sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: synced_ack_version
                                    
                                    	Synced ack version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_filter_group_index
                                    
                                    	Filter\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_filter_group_messages
                                    
                                    	Filter\-group messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_group_af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: update_group_index
                                    
                                    	Update\-group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: update_group_index_xr
                                    
                                    	Update\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_main_table_version
                                    
                                    	Main table version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\:   :py:class:`UpdateNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress>`
                                    
                                    .. attribute:: update_out_queue_messages
                                    
                                    	OutQueue messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_size
                                    
                                    	OutQueue size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_refresh_target_version
                                    
                                    	Refresh target version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_refresh_version
                                    
                                    	Refresh version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_statistics
                                    
                                    	Update statistics
                                    	**type**\:   :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics>`
                                    
                                    .. attribute:: update_vrf_name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    .. attribute:: update_vrf_table_rib_version
                                    
                                    	VRF Table RIB version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version
                                    
                                    	Version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ack_version = None
                                        self.current_update_group_af_name = None
                                        self.default_originate_internal_context = None
                                        self.default_originate_state = None
                                        self.filter_group_index = None
                                        self.first_default_originate_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp()
                                        self.first_default_originate_timestamp.parent = self
                                        self.first_update_queued_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp()
                                        self.first_update_queued_timestamp.parent = self
                                        self.first_update_write_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp()
                                        self.first_update_write_timestamp.parent = self
                                        self.inbound_refresh_count = None
                                        self.is_eor_outstanding = None
                                        self.is_update_group_timer_running = None
                                        self.last_default_originate_age = None
                                        self.last_default_originate_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp()
                                        self.last_default_originate_timestamp.parent = self
                                        self.last_filter_group_add_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp()
                                        self.last_filter_group_add_timestamp.parent = self
                                        self.last_filter_group_remove_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp()
                                        self.last_filter_group_remove_timestamp.parent = self
                                        self.last_refresh_update_queued_age = None
                                        self.last_refresh_update_queued_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp()
                                        self.last_refresh_update_queued_timestamp.parent = self
                                        self.last_refresh_update_write_age = None
                                        self.last_refresh_update_write_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp()
                                        self.last_refresh_update_write_timestamp.parent = self
                                        self.last_sub_group_add_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp()
                                        self.last_sub_group_add_timestamp.parent = self
                                        self.last_sub_group_remove_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp()
                                        self.last_sub_group_remove_timestamp.parent = self
                                        self.last_update_group_af_name = None
                                        self.last_update_group_expiry_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp()
                                        self.last_update_group_expiry_timestamp.parent = self
                                        self.last_update_group_start_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp()
                                        self.last_update_group_start_timestamp.parent = self
                                        self.last_update_queued_age = None
                                        self.last_update_queued_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp()
                                        self.last_update_queued_timestamp.parent = self
                                        self.last_update_write_age = None
                                        self.last_update_write_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp()
                                        self.last_update_write_timestamp.parent = self
                                        self.neighbor_address = None
                                        self.next_resume_version = None
                                        self.outbound_refresh_count = None
                                        self.outstanding_version_count = None
                                        self.pending_target_version = None
                                        self.process_id = None
                                        self.refresh_ack_version = None
                                        self.refresh_filter_group_index = None
                                        self.refresh_next_resume_version = None
                                        self.refresh_pending_target_version = None
                                        self.refresh_requested_target_version = None
                                        self.refresh_sub_group_id = None
                                        self.refresh_sub_group_index = None
                                        self.refresh_update_out_queue_messages = None
                                        self.refresh_update_out_queue_size = None
                                        self.sub_group_id = None
                                        self.sub_group_index = None
                                        self.sub_group_index_xr = None
                                        self.synced_ack_version = None
                                        self.update_filter_group_index = None
                                        self.update_filter_group_messages = None
                                        self.update_group_af_name = None
                                        self.update_group_index = None
                                        self.update_group_index_xr = None
                                        self.update_main_table_version = None
                                        self.update_neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress()
                                        self.update_neighbor_address.parent = self
                                        self.update_out_queue_messages = None
                                        self.update_out_queue_size = None
                                        self.update_refresh_target_version = None
                                        self.update_refresh_version = None
                                        self.update_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics()
                                        self.update_statistics.parent = self
                                        self.update_vrf_name = None
                                        self.update_vrf_table_rib_version = None
                                        self.version = None


                                    class UpdateNeighborAddress(object):
                                        """
                                        Neighbor address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-neighbor-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress']['meta_info']


                                    class LastSubGroupAddTimestamp(object):
                                        """
                                        Last added time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-sub-group-add-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp']['meta_info']


                                    class LastSubGroupRemoveTimestamp(object):
                                        """
                                        Last removed time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-sub-group-remove-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp']['meta_info']


                                    class LastFilterGroupAddTimestamp(object):
                                        """
                                        Last added time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-filter-group-add-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp']['meta_info']


                                    class LastFilterGroupRemoveTimestamp(object):
                                        """
                                        Last removed time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-filter-group-remove-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp']['meta_info']


                                    class FirstDefaultOriginateTimestamp(object):
                                        """
                                        First default\-origination time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-default-originate-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp']['meta_info']


                                    class LastDefaultOriginateTimestamp(object):
                                        """
                                        Last default\-origination time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-default-originate-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp']['meta_info']


                                    class LastUpdateGroupStartTimestamp(object):
                                        """
                                        Last update\-group timer start
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-group-start-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp']['meta_info']


                                    class LastUpdateGroupExpiryTimestamp(object):
                                        """
                                        Last update\-group timer expiry
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-group-expiry-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp']['meta_info']


                                    class FirstUpdateQueuedTimestamp(object):
                                        """
                                        First update queued time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-update-queued-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp']['meta_info']


                                    class LastUpdateQueuedTimestamp(object):
                                        """
                                        Last update queued time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-queued-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp']['meta_info']


                                    class LastRefreshUpdateQueuedTimestamp(object):
                                        """
                                        Last refresh update queued time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-refresh-update-queued-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp']['meta_info']


                                    class FirstUpdateWriteTimestamp(object):
                                        """
                                        First update write time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-update-write-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp']['meta_info']


                                    class LastUpdateWriteTimestamp(object):
                                        """
                                        Last update write time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-write-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp']['meta_info']


                                    class LastRefreshUpdateWriteTimestamp(object):
                                        """
                                        Last refresh update write time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-refresh-update-write-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp']['meta_info']


                                    class UpdateStatistics(object):
                                        """
                                        Update statistics
                                        
                                        .. attribute:: last_update_cleard_age
                                        
                                        	Time since last Clear event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_cleared_timestamp
                                        
                                        	Last Cleared time
                                        	**type**\:   :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp>`
                                        
                                        .. attribute:: last_update_discard_age
                                        
                                        	Time since last Discard event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_discard_timestamp
                                        
                                        	Last Discarded time
                                        	**type**\:   :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                        
                                        .. attribute:: last_update_memory_allocation_fail_age
                                        
                                        	Time since last memory allocation failure event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_memory_allocation_fail_timestamp
                                        
                                        	Memory allocation failure time
                                        	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                        
                                        .. attribute:: last_update_recovery_age
                                        
                                        	Time since last Recovery event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_recovery_timestamp
                                        
                                        	Last Recovery time
                                        	**type**\:   :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                        
                                        .. attribute:: last_update_throttle_age
                                        
                                        	Time since last Throttle event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_throttle_timestamp
                                        
                                        	Last Throttled time
                                        	**type**\:   :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                        
                                        .. attribute:: update_memory_allocation_fail_count
                                        
                                        	Memory allocation failure count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cleared
                                        
                                        	OutQueue Cleared Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cumulative
                                        
                                        	OutQueue Cumulative Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_discarded
                                        
                                        	OutQueue Discarded Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_high
                                        
                                        	OutQueue High Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size_cleared
                                        
                                        	OutQueue Cleared Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_cumulative
                                        
                                        	OutQueue Cumulative Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_discarded
                                        
                                        	OutQueue Discarded Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_high
                                        
                                        	OutQueue Hi Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_recovery_count
                                        
                                        	Recovery Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_throttle_count
                                        
                                        	Throttle Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.last_update_cleard_age = None
                                            self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp()
                                            self.last_update_cleared_timestamp.parent = self
                                            self.last_update_discard_age = None
                                            self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp()
                                            self.last_update_discard_timestamp.parent = self
                                            self.last_update_memory_allocation_fail_age = None
                                            self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                            self.last_update_memory_allocation_fail_timestamp.parent = self
                                            self.last_update_recovery_age = None
                                            self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                            self.last_update_recovery_timestamp.parent = self
                                            self.last_update_throttle_age = None
                                            self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp()
                                            self.last_update_throttle_timestamp.parent = self
                                            self.update_memory_allocation_fail_count = None
                                            self.update_out_queue_messages_cleared = None
                                            self.update_out_queue_messages_cumulative = None
                                            self.update_out_queue_messages_discarded = None
                                            self.update_out_queue_messages_high = None
                                            self.update_out_queue_size_cleared = None
                                            self.update_out_queue_size_cumulative = None
                                            self.update_out_queue_size_discarded = None
                                            self.update_out_queue_size_high = None
                                            self.update_recovery_count = None
                                            self.update_throttle_count = None


                                        class LastUpdateDiscardTimestamp(object):
                                            """
                                            Last Discarded time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-discard-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp']['meta_info']


                                        class LastUpdateClearedTimestamp(object):
                                            """
                                            Last Cleared time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-cleared-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp']['meta_info']


                                        class LastUpdateThrottleTimestamp(object):
                                            """
                                            Last Throttled time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-throttle-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp']['meta_info']


                                        class LastUpdateRecoveryTimestamp(object):
                                            """
                                            Last Recovery time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-recovery-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp']['meta_info']


                                        class LastUpdateMemoryAllocationFailTimestamp(object):
                                            """
                                            Memory allocation failure time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-memory-allocation-fail-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-statistics'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.last_update_cleard_age is not None:
                                                return True

                                            if self.last_update_cleared_timestamp is not None and self.last_update_cleared_timestamp._has_data():
                                                return True

                                            if self.last_update_discard_age is not None:
                                                return True

                                            if self.last_update_discard_timestamp is not None and self.last_update_discard_timestamp._has_data():
                                                return True

                                            if self.last_update_memory_allocation_fail_age is not None:
                                                return True

                                            if self.last_update_memory_allocation_fail_timestamp is not None and self.last_update_memory_allocation_fail_timestamp._has_data():
                                                return True

                                            if self.last_update_recovery_age is not None:
                                                return True

                                            if self.last_update_recovery_timestamp is not None and self.last_update_recovery_timestamp._has_data():
                                                return True

                                            if self.last_update_throttle_age is not None:
                                                return True

                                            if self.last_update_throttle_timestamp is not None and self.last_update_throttle_timestamp._has_data():
                                                return True

                                            if self.update_memory_allocation_fail_count is not None:
                                                return True

                                            if self.update_out_queue_messages_cleared is not None:
                                                return True

                                            if self.update_out_queue_messages_cumulative is not None:
                                                return True

                                            if self.update_out_queue_messages_discarded is not None:
                                                return True

                                            if self.update_out_queue_messages_high is not None:
                                                return True

                                            if self.update_out_queue_size_cleared is not None:
                                                return True

                                            if self.update_out_queue_size_cumulative is not None:
                                                return True

                                            if self.update_out_queue_size_discarded is not None:
                                                return True

                                            if self.update_out_queue_size_high is not None:
                                                return True

                                            if self.update_recovery_count is not None:
                                                return True

                                            if self.update_throttle_count is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-neighbor'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ack_version is not None:
                                            return True

                                        if self.current_update_group_af_name is not None:
                                            return True

                                        if self.default_originate_internal_context is not None:
                                            return True

                                        if self.default_originate_state is not None:
                                            return True

                                        if self.filter_group_index is not None:
                                            return True

                                        if self.first_default_originate_timestamp is not None and self.first_default_originate_timestamp._has_data():
                                            return True

                                        if self.first_update_queued_timestamp is not None and self.first_update_queued_timestamp._has_data():
                                            return True

                                        if self.first_update_write_timestamp is not None and self.first_update_write_timestamp._has_data():
                                            return True

                                        if self.inbound_refresh_count is not None:
                                            return True

                                        if self.is_eor_outstanding is not None:
                                            return True

                                        if self.is_update_group_timer_running is not None:
                                            return True

                                        if self.last_default_originate_age is not None:
                                            return True

                                        if self.last_default_originate_timestamp is not None and self.last_default_originate_timestamp._has_data():
                                            return True

                                        if self.last_filter_group_add_timestamp is not None and self.last_filter_group_add_timestamp._has_data():
                                            return True

                                        if self.last_filter_group_remove_timestamp is not None and self.last_filter_group_remove_timestamp._has_data():
                                            return True

                                        if self.last_refresh_update_queued_age is not None:
                                            return True

                                        if self.last_refresh_update_queued_timestamp is not None and self.last_refresh_update_queued_timestamp._has_data():
                                            return True

                                        if self.last_refresh_update_write_age is not None:
                                            return True

                                        if self.last_refresh_update_write_timestamp is not None and self.last_refresh_update_write_timestamp._has_data():
                                            return True

                                        if self.last_sub_group_add_timestamp is not None and self.last_sub_group_add_timestamp._has_data():
                                            return True

                                        if self.last_sub_group_remove_timestamp is not None and self.last_sub_group_remove_timestamp._has_data():
                                            return True

                                        if self.last_update_group_af_name is not None:
                                            return True

                                        if self.last_update_group_expiry_timestamp is not None and self.last_update_group_expiry_timestamp._has_data():
                                            return True

                                        if self.last_update_group_start_timestamp is not None and self.last_update_group_start_timestamp._has_data():
                                            return True

                                        if self.last_update_queued_age is not None:
                                            return True

                                        if self.last_update_queued_timestamp is not None and self.last_update_queued_timestamp._has_data():
                                            return True

                                        if self.last_update_write_age is not None:
                                            return True

                                        if self.last_update_write_timestamp is not None and self.last_update_write_timestamp._has_data():
                                            return True

                                        if self.neighbor_address is not None:
                                            return True

                                        if self.next_resume_version is not None:
                                            return True

                                        if self.outbound_refresh_count is not None:
                                            return True

                                        if self.outstanding_version_count is not None:
                                            return True

                                        if self.pending_target_version is not None:
                                            return True

                                        if self.process_id is not None:
                                            return True

                                        if self.refresh_ack_version is not None:
                                            return True

                                        if self.refresh_filter_group_index is not None:
                                            return True

                                        if self.refresh_next_resume_version is not None:
                                            return True

                                        if self.refresh_pending_target_version is not None:
                                            return True

                                        if self.refresh_requested_target_version is not None:
                                            return True

                                        if self.refresh_sub_group_id is not None:
                                            return True

                                        if self.refresh_sub_group_index is not None:
                                            return True

                                        if self.refresh_update_out_queue_messages is not None:
                                            return True

                                        if self.refresh_update_out_queue_size is not None:
                                            return True

                                        if self.sub_group_id is not None:
                                            return True

                                        if self.sub_group_index is not None:
                                            return True

                                        if self.sub_group_index_xr is not None:
                                            return True

                                        if self.synced_ack_version is not None:
                                            return True

                                        if self.update_filter_group_index is not None:
                                            return True

                                        if self.update_filter_group_messages is not None:
                                            return True

                                        if self.update_group_af_name is not None:
                                            return True

                                        if self.update_group_index is not None:
                                            return True

                                        if self.update_group_index_xr is not None:
                                            return True

                                        if self.update_main_table_version is not None:
                                            return True

                                        if self.update_neighbor_address is not None and self.update_neighbor_address._has_data():
                                            return True

                                        if self.update_out_queue_messages is not None:
                                            return True

                                        if self.update_out_queue_size is not None:
                                            return True

                                        if self.update_refresh_target_version is not None:
                                            return True

                                        if self.update_refresh_version is not None:
                                            return True

                                        if self.update_statistics is not None and self.update_statistics._has_data():
                                            return True

                                        if self.update_vrf_name is not None:
                                            return True

                                        if self.update_vrf_table_rib_version is not None:
                                            return True

                                        if self.version is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-neighbors'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.update_generation_neighbor is not None:
                                        for child_ref in self.update_generation_neighbor:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors']['meta_info']


                            class UpdateGenerationAddressFamily(object):
                                """
                                Update generation for address\-family
                                
                                .. attribute:: configured_update_limit_af
                                
                                	Configured AF update limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: configured_update_limit_sub_group_ibgp
                                
                                	Configured IBGP sub\-group update limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: configured_update_limit_subgrp_ebgp
                                
                                	Configured EBGP sub\-group update limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: current_update_limit_af
                                
                                	Current AF update limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: current_update_limit_sub_group_ibgp
                                
                                	Current IBGP sub\-group update limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: current_update_limit_subgrp_ebgp
                                
                                	Current EBGP sub\-group update limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: filter_group_count
                                
                                	Filter\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_count
                                
                                	Neighbor count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: refresh_sub_group_count
                                
                                	Refresh sub\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: refresh_sub_group_throttled_count
                                
                                	Throttled refresh sub\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sub_group_throttled_count
                                
                                	Throttled sub\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: table_neighbor_count
                                
                                	VRF Table neighbor count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: table_refresh_sub_group_count
                                
                                	VRF Table refresh sub\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: table_refresh_sub_group_throttled_count
                                
                                	VRF Table throttled refresh sub\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: table_sub_group_throttled_count
                                
                                	VRF Table throttled sub\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: table_update_group_count
                                
                                	VRF Table update\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_group_af_name
                                
                                	Address family identifier
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: update_main_table_version
                                
                                	Main table version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_min_neighbor_version
                                
                                	Minimum Neighbor version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_out_queue_messages
                                
                                	OutQueue messsages
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_out_queue_size
                                
                                	OutQueue size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_rib_version
                                
                                	RIB version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_statistics
                                
                                	Upate statistics
                                	**type**\:   :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics>`
                                
                                .. attribute:: update_sub_group_count
                                
                                	Sub\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_table_filter_group_count
                                
                                	VRF Table filter\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_table_sub_group_count
                                
                                	VRF Table sub\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_table_vrf_name
                                
                                	VRF Name
                                	**type**\:  str
                                
                                .. attribute:: update_throttled
                                
                                	Is Update throttled
                                	**type**\:  bool
                                
                                .. attribute:: update_update_group_count
                                
                                	Update\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_vrf_rd_version
                                
                                	RD Version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_vrf_table_rib_version
                                
                                	VRF Table RIB version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_vrfaf_name
                                
                                	Address family identifier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.configured_update_limit_af = None
                                    self.configured_update_limit_sub_group_ibgp = None
                                    self.configured_update_limit_subgrp_ebgp = None
                                    self.current_update_limit_af = None
                                    self.current_update_limit_sub_group_ibgp = None
                                    self.current_update_limit_subgrp_ebgp = None
                                    self.filter_group_count = None
                                    self.neighbor_count = None
                                    self.refresh_sub_group_count = None
                                    self.refresh_sub_group_throttled_count = None
                                    self.sub_group_throttled_count = None
                                    self.table_neighbor_count = None
                                    self.table_refresh_sub_group_count = None
                                    self.table_refresh_sub_group_throttled_count = None
                                    self.table_sub_group_throttled_count = None
                                    self.table_update_group_count = None
                                    self.update_group_af_name = None
                                    self.update_main_table_version = None
                                    self.update_min_neighbor_version = None
                                    self.update_out_queue_messages = None
                                    self.update_out_queue_size = None
                                    self.update_rib_version = None
                                    self.update_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics()
                                    self.update_statistics.parent = self
                                    self.update_sub_group_count = None
                                    self.update_table_filter_group_count = None
                                    self.update_table_sub_group_count = None
                                    self.update_table_vrf_name = None
                                    self.update_throttled = None
                                    self.update_update_group_count = None
                                    self.update_vrf_rd_version = None
                                    self.update_vrf_table_rib_version = None
                                    self.update_vrfaf_name = None


                                class UpdateStatistics(object):
                                    """
                                    Upate statistics
                                    
                                    .. attribute:: last_update_cleard_age
                                    
                                    	Time since last Clear event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_cleared_timestamp
                                    
                                    	Last Cleared time
                                    	**type**\:   :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp>`
                                    
                                    .. attribute:: last_update_discard_age
                                    
                                    	Time since last Discard event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_discard_timestamp
                                    
                                    	Last Discarded time
                                    	**type**\:   :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                    
                                    .. attribute:: last_update_memory_allocation_fail_age
                                    
                                    	Time since last memory allocation failure event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_memory_allocation_fail_timestamp
                                    
                                    	Memory allocation failure time
                                    	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                    
                                    .. attribute:: last_update_recovery_age
                                    
                                    	Time since last Recovery event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_recovery_timestamp
                                    
                                    	Last Recovery time
                                    	**type**\:   :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                    
                                    .. attribute:: last_update_throttle_age
                                    
                                    	Time since last Throttle event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_throttle_timestamp
                                    
                                    	Last Throttled time
                                    	**type**\:   :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                    
                                    .. attribute:: update_memory_allocation_fail_count
                                    
                                    	Memory allocation failure count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages_cleared
                                    
                                    	OutQueue Cleared Messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages_cumulative
                                    
                                    	OutQueue Cumulative Messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages_discarded
                                    
                                    	OutQueue Discarded Messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages_high
                                    
                                    	OutQueue High Messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_size_cleared
                                    
                                    	OutQueue Cleared Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: update_out_queue_size_cumulative
                                    
                                    	OutQueue Cumulative Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: update_out_queue_size_discarded
                                    
                                    	OutQueue Discarded Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: update_out_queue_size_high
                                    
                                    	OutQueue Hi Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_recovery_count
                                    
                                    	Recovery Count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_throttle_count
                                    
                                    	Throttle Count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.last_update_cleard_age = None
                                        self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp()
                                        self.last_update_cleared_timestamp.parent = self
                                        self.last_update_discard_age = None
                                        self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp()
                                        self.last_update_discard_timestamp.parent = self
                                        self.last_update_memory_allocation_fail_age = None
                                        self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                        self.last_update_memory_allocation_fail_timestamp.parent = self
                                        self.last_update_recovery_age = None
                                        self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                        self.last_update_recovery_timestamp.parent = self
                                        self.last_update_throttle_age = None
                                        self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp()
                                        self.last_update_throttle_timestamp.parent = self
                                        self.update_memory_allocation_fail_count = None
                                        self.update_out_queue_messages_cleared = None
                                        self.update_out_queue_messages_cumulative = None
                                        self.update_out_queue_messages_discarded = None
                                        self.update_out_queue_messages_high = None
                                        self.update_out_queue_size_cleared = None
                                        self.update_out_queue_size_cumulative = None
                                        self.update_out_queue_size_discarded = None
                                        self.update_out_queue_size_high = None
                                        self.update_recovery_count = None
                                        self.update_throttle_count = None


                                    class LastUpdateDiscardTimestamp(object):
                                        """
                                        Last Discarded time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-discard-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp']['meta_info']


                                    class LastUpdateClearedTimestamp(object):
                                        """
                                        Last Cleared time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-cleared-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp']['meta_info']


                                    class LastUpdateThrottleTimestamp(object):
                                        """
                                        Last Throttled time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-throttle-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp']['meta_info']


                                    class LastUpdateRecoveryTimestamp(object):
                                        """
                                        Last Recovery time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-recovery-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp']['meta_info']


                                    class LastUpdateMemoryAllocationFailTimestamp(object):
                                        """
                                        Memory allocation failure time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-memory-allocation-fail-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-statistics'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.last_update_cleard_age is not None:
                                            return True

                                        if self.last_update_cleared_timestamp is not None and self.last_update_cleared_timestamp._has_data():
                                            return True

                                        if self.last_update_discard_age is not None:
                                            return True

                                        if self.last_update_discard_timestamp is not None and self.last_update_discard_timestamp._has_data():
                                            return True

                                        if self.last_update_memory_allocation_fail_age is not None:
                                            return True

                                        if self.last_update_memory_allocation_fail_timestamp is not None and self.last_update_memory_allocation_fail_timestamp._has_data():
                                            return True

                                        if self.last_update_recovery_age is not None:
                                            return True

                                        if self.last_update_recovery_timestamp is not None and self.last_update_recovery_timestamp._has_data():
                                            return True

                                        if self.last_update_throttle_age is not None:
                                            return True

                                        if self.last_update_throttle_timestamp is not None and self.last_update_throttle_timestamp._has_data():
                                            return True

                                        if self.update_memory_allocation_fail_count is not None:
                                            return True

                                        if self.update_out_queue_messages_cleared is not None:
                                            return True

                                        if self.update_out_queue_messages_cumulative is not None:
                                            return True

                                        if self.update_out_queue_messages_discarded is not None:
                                            return True

                                        if self.update_out_queue_messages_high is not None:
                                            return True

                                        if self.update_out_queue_size_cleared is not None:
                                            return True

                                        if self.update_out_queue_size_cumulative is not None:
                                            return True

                                        if self.update_out_queue_size_discarded is not None:
                                            return True

                                        if self.update_out_queue_size_high is not None:
                                            return True

                                        if self.update_recovery_count is not None:
                                            return True

                                        if self.update_throttle_count is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-address-family'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.configured_update_limit_af is not None:
                                        return True

                                    if self.configured_update_limit_sub_group_ibgp is not None:
                                        return True

                                    if self.configured_update_limit_subgrp_ebgp is not None:
                                        return True

                                    if self.current_update_limit_af is not None:
                                        return True

                                    if self.current_update_limit_sub_group_ibgp is not None:
                                        return True

                                    if self.current_update_limit_subgrp_ebgp is not None:
                                        return True

                                    if self.filter_group_count is not None:
                                        return True

                                    if self.neighbor_count is not None:
                                        return True

                                    if self.refresh_sub_group_count is not None:
                                        return True

                                    if self.refresh_sub_group_throttled_count is not None:
                                        return True

                                    if self.sub_group_throttled_count is not None:
                                        return True

                                    if self.table_neighbor_count is not None:
                                        return True

                                    if self.table_refresh_sub_group_count is not None:
                                        return True

                                    if self.table_refresh_sub_group_throttled_count is not None:
                                        return True

                                    if self.table_sub_group_throttled_count is not None:
                                        return True

                                    if self.table_update_group_count is not None:
                                        return True

                                    if self.update_group_af_name is not None:
                                        return True

                                    if self.update_main_table_version is not None:
                                        return True

                                    if self.update_min_neighbor_version is not None:
                                        return True

                                    if self.update_out_queue_messages is not None:
                                        return True

                                    if self.update_out_queue_size is not None:
                                        return True

                                    if self.update_rib_version is not None:
                                        return True

                                    if self.update_statistics is not None and self.update_statistics._has_data():
                                        return True

                                    if self.update_sub_group_count is not None:
                                        return True

                                    if self.update_table_filter_group_count is not None:
                                        return True

                                    if self.update_table_sub_group_count is not None:
                                        return True

                                    if self.update_table_vrf_name is not None:
                                        return True

                                    if self.update_throttled is not None:
                                        return True

                                    if self.update_update_group_count is not None:
                                        return True

                                    if self.update_vrf_rd_version is not None:
                                        return True

                                    if self.update_vrf_table_rib_version is not None:
                                        return True

                                    if self.update_vrfaf_name is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily']['meta_info']


                            class Dampenings(object):
                                """
                                The BGP Dampening table
                                
                                .. attribute:: dampening
                                
                                	A BGP Dampening table entry
                                	**type**\: list of    :py:class:`Dampening <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.dampening = YList()
                                    self.dampening.parent = self
                                    self.dampening.name = 'dampening'


                                class Dampening(object):
                                    """
                                    A BGP Dampening table entry
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: attributes_after_policy_in
                                    
                                    	Attributes after inbound policy applied
                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn>`
                                    
                                    .. attribute:: label_fail
                                    
                                    	LSD label allocation failed 
                                    	**type**\:  bool
                                    
                                    .. attribute:: label_o_or_version
                                    
                                    	Label Version when OOR happens
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_oor
                                    
                                    	LSD label space is exhausted
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr>`
                                    
                                    .. attribute:: network
                                    
                                    	Network in prefix/length format
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    
                                    ----
                                    .. attribute:: no_path
                                    
                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_id
                                    
                                    	Received Path ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: path_information
                                    
                                    	Path information
                                    	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation>`
                                    
                                    .. attribute:: prefix_version
                                    
                                    	Version of BGP Prefix Table
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: reuse
                                    
                                    	Reuse array index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_rd
                                    
                                    	Source Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: source_route_distinguisher
                                    
                                    	Source Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_vrf_name
                                    
                                    	Name of the source VRF
                                    	**type**\:  str
                                    
                                    .. attribute:: srcaf_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: version
                                    
                                    	Version number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn()
                                        self.attributes_after_policy_in.parent = self
                                        self.label_fail = None
                                        self.label_o_or_version = None
                                        self.label_oor = None
                                        self.neighbor_address = None
                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr()
                                        self.neighbor_address_xr.parent = self
                                        self.network = None
                                        self.no_path = None
                                        self.path_id = None
                                        self.path_information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation()
                                        self.path_information.parent = self
                                        self.prefix_version = None
                                        self.process_instance_id = None
                                        self.rd = None
                                        self.reuse = None
                                        self.route_distinguisher = None
                                        self.source_rd = None
                                        self.source_route_distinguisher = None
                                        self.source_vrf_name = None
                                        self.srcaf_name = None
                                        self.version = None
                                        self.vrf_name = None


                                    class NeighborAddressXr(object):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr']['meta_info']


                                    class PathInformation(object):
                                        """
                                        Path information
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_own_self_originated_p_ath
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\:  bool
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield>`
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner>`
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix>`
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity>`
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\:  bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\:  bool
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr>`
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_esi
                                        
                                        	Path has EVPN ESI
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_rcvd_label
                                        
                                        	Path has received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\:  bool
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebg_ps
                                        
                                        	Not advertised to EBGPs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.L2VpnCircuitStatusValue>`
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.L2VpnEvpnEsi>`
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr>`
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue>`
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress>`
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop>`
                                        
                                        .. attribute:: nhte_tunnel
                                        
                                        	NH TE tunnel information
                                        	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhteTunnel>`
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\:  bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.accept_own_path = None
                                            self.accept_own_self_originated_p_ath = None
                                            self.add_path_orr_bitfield = YList()
                                            self.add_path_orr_bitfield.parent = self
                                            self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                            self.advertisedto_pe = None
                                            self.aigp_metric = None
                                            self.best_path_comp_stage = None
                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self.best_path_id = None
                                            self.best_path_id_comp_winner = None
                                            self.best_path_orr_bitfield = YList()
                                            self.best_path_orr_bitfield.parent = self
                                            self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self.dampen_penalty = None
                                            self.extended_community = YList()
                                            self.extended_community.parent = self
                                            self.extended_community.name = 'extended_community'
                                            self.fspec_invalid_path = None
                                            self.graceful_shutdown = None
                                            self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr()
                                            self.gw_addr.parent = self
                                            self.halflife_time = None
                                            self.has_esi = None
                                            self.has_gw_addr = None
                                            self.has_local_net_label = None
                                            self.has_mdt_group_addr = None
                                            self.has_mvpn_extcomm = None
                                            self.has_mvpn_nbr_addr = None
                                            self.has_mvpn_nexthop_addr = None
                                            self.has_mvpn_pmsi = None
                                            self.has_rcvd_label = None
                                            self.has_second_label = None
                                            self.ibgp_signaled_validity = None
                                            self.igp_metric = None
                                            self.is_aggregation_suppressed = None
                                            self.is_as_best = None
                                            self.is_best_path = None
                                            self.is_import_dampened = None
                                            self.is_import_suspect = None
                                            self.is_internal_path = None
                                            self.is_partial_best = None
                                            self.is_path_additional_path = None
                                            self.is_path_advertised_local_as_only = None
                                            self.is_path_af_install_eligible = None
                                            self.is_path_backup = None
                                            self.is_path_backup_protect_multipath = None
                                            self.is_path_best_external = None
                                            self.is_path_damped = None
                                            self.is_path_from_confederation_peer = None
                                            self.is_path_from_network_command = None
                                            self.is_path_from_redistribute_command = None
                                            self.is_path_from_route_reflector = None
                                            self.is_path_history_held = None
                                            self.is_path_imp_candidate = None
                                            self.is_path_imported = None
                                            self.is_path_local_aggregate = None
                                            self.is_path_locally_sourced = None
                                            self.is_path_long_lived_stale = None
                                            self.is_path_multipath = None
                                            self.is_path_nexthop_discarded = None
                                            self.is_path_not_advertised = None
                                            self.is_path_not_advertised_to_ebg_ps = None
                                            self.is_path_received_only = None
                                            self.is_path_reoriginated = None
                                            self.is_path_reoriginated_stitching = None
                                            self.is_path_stale = None
                                            self.is_path_synced_with_igp = None
                                            self.is_path_valid = None
                                            self.is_path_vpn_only = None
                                            self.is_permanent_path = None
                                            self.is_received_path_not_modified = None
                                            self.is_spkr_as_best = None
                                            self.l2vpn_circuit_status_value = YList()
                                            self.l2vpn_circuit_status_value.parent = self
                                            self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                            self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.L2VpnEvpnEsi()
                                            self.l2vpn_evpn_esi.parent = self
                                            self.l2vpn_size = None
                                            self.labeled_unicast_safi_path = None
                                            self.local_label = None
                                            self.local_nh = None
                                            self.local_path_id = None
                                            self.local_peers_advertised_to = YList()
                                            self.local_peers_advertised_to.parent = self
                                            self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                            self.maximum_suppress_time = None
                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self.mvpn_path_flags = None
                                            self.mvpn_pmsi_flags = None
                                            self.mvpn_pmsi_label = None
                                            self.mvpn_pmsi_type = None
                                            self.mvpn_pmsi_value = YList()
                                            self.mvpn_pmsi_value.parent = self
                                            self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                            self.mvpn_sfs_path = None
                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self.neighbor_router_id = None
                                            self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop()
                                            self.next_hop.parent = self
                                            self.nhte_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhteTunnel()
                                            self.nhte_tunnel.parent = self
                                            self.path_flags = None
                                            self.path_flap_count = None
                                            self.path_import_flags = None
                                            self.path_rt_set_id = None
                                            self.path_rt_set_route_count = None
                                            self.path_table_version = None
                                            self.path_weight = None
                                            self.pe_peers_advertised_to = YList()
                                            self.pe_peers_advertised_to.parent = self
                                            self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                            self.rcvd_label = None
                                            self.rcvd_path_id = None
                                            self.reuse_value = None
                                            self.rib_failed = None
                                            self.route_type = None
                                            self.rpki_origin_as_validation_disabled = None
                                            self.rt_set_limit_enabled = None
                                            self.second_label = None
                                            self.seconds_since_first_flap = None
                                            self.show_rpki_origin_as_validity = None
                                            self.sn_rpki_origin_as_validity = None
                                            self.suppress_penalty = None
                                            self.time_to_unsuppress = None


                                        class BgpPrefix(object):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self.prefix_length = None


                                            class Prefix(object):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.prefix is not None and self.prefix._has_data():
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix']['meta_info']


                                        class NeighborAddress(object):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress']['meta_info']


                                        class NextHop(object):
                                            """
                                            Next hop
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop']['meta_info']


                                        class NhteTunnel(object):
                                            """
                                            NH TE tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_te_tunnel
                                            
                                            	NH TE Tunnel info is present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last rib update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	tunnel name
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	tunnel type
                                            	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.binding_label = None
                                                self.has_te_tunnel = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.is_tunnel_up = None
                                                self.last_tunnel_update = None
                                                self.tunnel_if_handle = None
                                                self.tunnel_name = None
                                                self.tunnel_type = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_v6_required = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.binding_label is not None:
                                                    return True

                                                if self.has_te_tunnel is not None:
                                                    return True

                                                if self.is_tunnel_info_stale is not None:
                                                    return True

                                                if self.is_tunnel_registered is not None:
                                                    return True

                                                if self.is_tunnel_up is not None:
                                                    return True

                                                if self.last_tunnel_update is not None:
                                                    return True

                                                if self.tunnel_if_handle is not None:
                                                    return True

                                                if self.tunnel_name is not None:
                                                    return True

                                                if self.tunnel_type is not None:
                                                    return True

                                                if self.tunnel_v6_enabled is not None:
                                                    return True

                                                if self.tunnel_v6_required is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhteTunnel']['meta_info']


                                        class MdtGroupAddr(object):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr']['meta_info']


                                        class L2VpnEvpnEsi(object):
                                            """
                                            L2VPN EVPN ESI
                                            
                                            .. attribute:: esi
                                            
                                            	esi
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.esi = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.esi is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.L2VpnEvpnEsi']['meta_info']


                                        class GwAddr(object):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.len = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.len is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr']['meta_info']


                                        class BestPathCompWinner(object):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner']['meta_info']


                                        class MvpnNbrAddr(object):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr']['meta_info']


                                        class MvpnNexthopAddr(object):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr']['meta_info']


                                        class L2VpnCircuitStatusValue(object):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                        class MvpnPmsiValue(object):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue']['meta_info']


                                        class ExtendedCommunity(object):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity']['meta_info']


                                        class LocalPeersAdvertisedTo(object):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                        class PePeersAdvertisedTo(object):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo']['meta_info']


                                        class BestPathOrrBitfield(object):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield']['meta_info']


                                        class AddPathOrrBitfield(object):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.accept_own_path is not None:
                                                return True

                                            if self.accept_own_self_originated_p_ath is not None:
                                                return True

                                            if self.add_path_orr_bitfield is not None:
                                                for child_ref in self.add_path_orr_bitfield:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.advertisedto_pe is not None:
                                                return True

                                            if self.aigp_metric is not None:
                                                return True

                                            if self.best_path_comp_stage is not None:
                                                return True

                                            if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                return True

                                            if self.best_path_id is not None:
                                                return True

                                            if self.best_path_id_comp_winner is not None:
                                                return True

                                            if self.best_path_orr_bitfield is not None:
                                                for child_ref in self.best_path_orr_bitfield:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                return True

                                            if self.dampen_penalty is not None:
                                                return True

                                            if self.extended_community is not None:
                                                for child_ref in self.extended_community:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.fspec_invalid_path is not None:
                                                return True

                                            if self.graceful_shutdown is not None:
                                                return True

                                            if self.gw_addr is not None and self.gw_addr._has_data():
                                                return True

                                            if self.halflife_time is not None:
                                                return True

                                            if self.has_esi is not None:
                                                return True

                                            if self.has_gw_addr is not None:
                                                return True

                                            if self.has_local_net_label is not None:
                                                return True

                                            if self.has_mdt_group_addr is not None:
                                                return True

                                            if self.has_mvpn_extcomm is not None:
                                                return True

                                            if self.has_mvpn_nbr_addr is not None:
                                                return True

                                            if self.has_mvpn_nexthop_addr is not None:
                                                return True

                                            if self.has_mvpn_pmsi is not None:
                                                return True

                                            if self.has_rcvd_label is not None:
                                                return True

                                            if self.has_second_label is not None:
                                                return True

                                            if self.ibgp_signaled_validity is not None:
                                                return True

                                            if self.igp_metric is not None:
                                                return True

                                            if self.is_aggregation_suppressed is not None:
                                                return True

                                            if self.is_as_best is not None:
                                                return True

                                            if self.is_best_path is not None:
                                                return True

                                            if self.is_import_dampened is not None:
                                                return True

                                            if self.is_import_suspect is not None:
                                                return True

                                            if self.is_internal_path is not None:
                                                return True

                                            if self.is_partial_best is not None:
                                                return True

                                            if self.is_path_additional_path is not None:
                                                return True

                                            if self.is_path_advertised_local_as_only is not None:
                                                return True

                                            if self.is_path_af_install_eligible is not None:
                                                return True

                                            if self.is_path_backup is not None:
                                                return True

                                            if self.is_path_backup_protect_multipath is not None:
                                                return True

                                            if self.is_path_best_external is not None:
                                                return True

                                            if self.is_path_damped is not None:
                                                return True

                                            if self.is_path_from_confederation_peer is not None:
                                                return True

                                            if self.is_path_from_network_command is not None:
                                                return True

                                            if self.is_path_from_redistribute_command is not None:
                                                return True

                                            if self.is_path_from_route_reflector is not None:
                                                return True

                                            if self.is_path_history_held is not None:
                                                return True

                                            if self.is_path_imp_candidate is not None:
                                                return True

                                            if self.is_path_imported is not None:
                                                return True

                                            if self.is_path_local_aggregate is not None:
                                                return True

                                            if self.is_path_locally_sourced is not None:
                                                return True

                                            if self.is_path_long_lived_stale is not None:
                                                return True

                                            if self.is_path_multipath is not None:
                                                return True

                                            if self.is_path_nexthop_discarded is not None:
                                                return True

                                            if self.is_path_not_advertised is not None:
                                                return True

                                            if self.is_path_not_advertised_to_ebg_ps is not None:
                                                return True

                                            if self.is_path_received_only is not None:
                                                return True

                                            if self.is_path_reoriginated is not None:
                                                return True

                                            if self.is_path_reoriginated_stitching is not None:
                                                return True

                                            if self.is_path_stale is not None:
                                                return True

                                            if self.is_path_synced_with_igp is not None:
                                                return True

                                            if self.is_path_valid is not None:
                                                return True

                                            if self.is_path_vpn_only is not None:
                                                return True

                                            if self.is_permanent_path is not None:
                                                return True

                                            if self.is_received_path_not_modified is not None:
                                                return True

                                            if self.is_spkr_as_best is not None:
                                                return True

                                            if self.l2vpn_circuit_status_value is not None:
                                                for child_ref in self.l2vpn_circuit_status_value:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                return True

                                            if self.l2vpn_size is not None:
                                                return True

                                            if self.labeled_unicast_safi_path is not None:
                                                return True

                                            if self.local_label is not None:
                                                return True

                                            if self.local_nh is not None:
                                                return True

                                            if self.local_path_id is not None:
                                                return True

                                            if self.local_peers_advertised_to is not None:
                                                for child_ref in self.local_peers_advertised_to:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.maximum_suppress_time is not None:
                                                return True

                                            if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                return True

                                            if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                return True

                                            if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                return True

                                            if self.mvpn_path_flags is not None:
                                                return True

                                            if self.mvpn_pmsi_flags is not None:
                                                return True

                                            if self.mvpn_pmsi_label is not None:
                                                return True

                                            if self.mvpn_pmsi_type is not None:
                                                return True

                                            if self.mvpn_pmsi_value is not None:
                                                for child_ref in self.mvpn_pmsi_value:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.mvpn_sfs_path is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            if self.neighbor_router_id is not None:
                                                return True

                                            if self.next_hop is not None and self.next_hop._has_data():
                                                return True

                                            if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                return True

                                            if self.path_flags is not None:
                                                return True

                                            if self.path_flap_count is not None:
                                                return True

                                            if self.path_import_flags is not None:
                                                return True

                                            if self.path_rt_set_id is not None:
                                                return True

                                            if self.path_rt_set_route_count is not None:
                                                return True

                                            if self.path_table_version is not None:
                                                return True

                                            if self.path_weight is not None:
                                                return True

                                            if self.pe_peers_advertised_to is not None:
                                                for child_ref in self.pe_peers_advertised_to:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.rcvd_label is not None:
                                                return True

                                            if self.rcvd_path_id is not None:
                                                return True

                                            if self.reuse_value is not None:
                                                return True

                                            if self.rib_failed is not None:
                                                return True

                                            if self.route_type is not None:
                                                return True

                                            if self.rpki_origin_as_validation_disabled is not None:
                                                return True

                                            if self.rt_set_limit_enabled is not None:
                                                return True

                                            if self.second_label is not None:
                                                return True

                                            if self.seconds_since_first_flap is not None:
                                                return True

                                            if self.show_rpki_origin_as_validity is not None:
                                                return True

                                            if self.sn_rpki_origin_as_validity is not None:
                                                return True

                                            if self.suppress_penalty is not None:
                                                return True

                                            if self.time_to_unsuppress is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation']['meta_info']


                                    class AttributesAfterPolicyIn(object):
                                        """
                                        Attributes after inbound policy applied
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet>`
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes>`
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp>`
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr>`
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\:  bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet()
                                            self.attr_set.parent = self
                                            self.attribute_key_number = None
                                            self.attribute_reuse_id_config = None
                                            self.attribute_reuse_id_current = None
                                            self.attribute_reuse_id_keys = None
                                            self.attribute_reuse_id_max_id = None
                                            self.attribute_reuse_id_node = None
                                            self.attribute_reuse_id_recover_sec = None
                                            self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self.is_application_gateway_present = None
                                            self.is_as_path2_byte = None
                                            self.is_attr_set_present = None
                                            self.is_ribrnh_present = None
                                            self.is_rnh_present = None
                                            self.ribrnh_encap = None
                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self.ribrnh_mac = None
                                            self.ribrnh_table = None
                                            self.ribrnh_vni = None
                                            self.ribrnhip_table = None
                                            self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self.rnh_addr_len = None
                                            self.rnh_len = None
                                            self.rnh_type = None
                                            self.set_aigp_inbound_igp = None
                                            self.set_aigp_inbound_metric = None
                                            self.vpn_distinguisher = None


                                        class CommonAttributes(object):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_encap_present
                                            
                                            	Tunnel Encap attribute present 
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_policy_allocated_binding_sid
                                            
                                            	SR Policy allocated Binding sid by the router
                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                            
                                            .. attribute:: sr_policy_binding_sid
                                            
                                            	SR Policy Binding sid
                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                            
                                            .. attribute:: sr_policy_explicit_path
                                            
                                            	SR Policy Explicit paths
                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                            
                                            .. attribute:: sr_policy_preference
                                            
                                            	SR Policy Preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_tunnel_request_state
                                            
                                            	SR Tunnel Request State
                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                            
                                            .. attribute:: sr_tunnel_state
                                            
                                            	SR Tunnel State
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap_type
                                            
                                            	Tunnel Encap Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.aggregator_address = None
                                                self.aggregator_as = None
                                                self.aigp_metric_value = None
                                                self.as_path = None
                                                self.cluster = YList()
                                                self.cluster.parent = self
                                                self.cluster.name = 'cluster'
                                                self.community = YList()
                                                self.community.parent = self
                                                self.community.name = 'community'
                                                self.connector_type = None
                                                self.connector_value = YList()
                                                self.connector_value.parent = self
                                                self.connector_value.name = 'connector_value'
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.extended_community_flags = None
                                                self.is_aggregator_present = None
                                                self.is_aigp_present = None
                                                self.is_as_path_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_community_present = None
                                                self.is_connector_present = None
                                                self.is_extended_community_present = None
                                                self.is_label_index_present = None
                                                self.is_local_pref_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_metric_present = None
                                                self.is_origin_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_ssa_present = None
                                                self.is_tunnel_encap_present = None
                                                self.l2tpv3_cookie = YList()
                                                self.l2tpv3_cookie.parent = self
                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                self.l2tpv3_session_id = None
                                                self.label_index_attr = YList()
                                                self.label_index_attr.parent = self
                                                self.label_index_attr.name = 'label_index_attr'
                                                self.local_preference = None
                                                self.ls_attr = YList()
                                                self.ls_attr.parent = self
                                                self.ls_attr.name = 'ls_attr'
                                                self.metric = None
                                                self.neighbor_as = None
                                                self.origin = None
                                                self.originator = None
                                                self.pe_distinguisher_label = YList()
                                                self.pe_distinguisher_label.parent = self
                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.pmsi_type = None
                                                self.pmsi_value = YList()
                                                self.pmsi_value.parent = self
                                                self.pmsi_value.name = 'pmsi_value'
                                                self.ppm_pvalue = None
                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                self.sr_policy_allocated_binding_sid.parent = self
                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                self.sr_policy_binding_sid.parent = self
                                                self.sr_policy_explicit_path = YList()
                                                self.sr_policy_explicit_path.parent = self
                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                self.sr_policy_preference = None
                                                self.sr_tunnel_request_state = None
                                                self.sr_tunnel_state = None
                                                self.tunnel_encap_type = None
                                                self.unknown_attribute = YList()
                                                self.unknown_attribute.parent = self
                                                self.unknown_attribute.name = 'unknown_attribute'


                                            class SrPolicyBindingSid(object):
                                                """
                                                SR Policy Binding sid
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                            class SrPolicyAllocatedBindingSid(object):
                                                """
                                                SR Policy allocated Binding sid by the router
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                            class Community(object):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                            class UnknownAttribute(object):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                            class Cluster(object):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                            class L2Tpv3Cookie(object):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                            class ConnectorValue(object):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                            class PmsiValue(object):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                            class LsAttr(object):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                            class LabelIndexAttr(object):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                            class PeDistinguisherLabel(object):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.label = None
                                                    self.pe_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.label is not None:
                                                        return True

                                                    if self.pe_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                            class SrPolicyExplicitPath(object):
                                                """
                                                SR Policy Explicit paths
                                                
                                                .. attribute:: sid
                                                
                                                	Sidlist for explicit path
                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                
                                                .. attribute:: weight
                                                
                                                	Weight of explicit path
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.sid = YList()
                                                    self.sid.parent = self
                                                    self.sid.name = 'sid'
                                                    self.weight = None


                                                class Sid(object):
                                                    """
                                                    Sidlist for explicit path
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IP Address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label sid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Sid Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4 is not None:
                                                            return True

                                                        if self.ipv6 is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.sid is not None:
                                                        for child_ref in self.sid:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.weight is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.aggregator_address is not None:
                                                    return True

                                                if self.aggregator_as is not None:
                                                    return True

                                                if self.aigp_metric_value is not None:
                                                    return True

                                                if self.as_path is not None:
                                                    return True

                                                if self.cluster is not None:
                                                    for child_ref in self.cluster:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.community is not None:
                                                    for child_ref in self.community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.connector_type is not None:
                                                    return True

                                                if self.connector_value is not None:
                                                    for child_ref in self.connector_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community_flags is not None:
                                                    return True

                                                if self.is_aggregator_present is not None:
                                                    return True

                                                if self.is_aigp_present is not None:
                                                    return True

                                                if self.is_as_path_present is not None:
                                                    return True

                                                if self.is_atomic_aggregate_present is not None:
                                                    return True

                                                if self.is_community_present is not None:
                                                    return True

                                                if self.is_connector_present is not None:
                                                    return True

                                                if self.is_extended_community_present is not None:
                                                    return True

                                                if self.is_label_index_present is not None:
                                                    return True

                                                if self.is_local_pref_present is not None:
                                                    return True

                                                if self.is_ls_attribute_present is not None:
                                                    return True

                                                if self.is_metric_present is not None:
                                                    return True

                                                if self.is_origin_present is not None:
                                                    return True

                                                if self.is_pe_distinguisher_label_present is not None:
                                                    return True

                                                if self.is_pmsi_present is not None:
                                                    return True

                                                if self.is_pppmp_present is not None:
                                                    return True

                                                if self.is_ssa_present is not None:
                                                    return True

                                                if self.is_tunnel_encap_present is not None:
                                                    return True

                                                if self.l2tpv3_cookie is not None:
                                                    for child_ref in self.l2tpv3_cookie:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2tpv3_session_id is not None:
                                                    return True

                                                if self.label_index_attr is not None:
                                                    for child_ref in self.label_index_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_preference is not None:
                                                    return True

                                                if self.ls_attr is not None:
                                                    for child_ref in self.ls_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.metric is not None:
                                                    return True

                                                if self.neighbor_as is not None:
                                                    return True

                                                if self.origin is not None:
                                                    return True

                                                if self.originator is not None:
                                                    return True

                                                if self.pe_distinguisher_label is not None:
                                                    for child_ref in self.pe_distinguisher_label:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.pmsi_flags is not None:
                                                    return True

                                                if self.pmsi_label is not None:
                                                    return True

                                                if self.pmsi_type is not None:
                                                    return True

                                                if self.pmsi_value is not None:
                                                    for child_ref in self.pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.ppm_pvalue is not None:
                                                    return True

                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_explicit_path is not None:
                                                    for child_ref in self.sr_policy_explicit_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.sr_policy_preference is not None:
                                                    return True

                                                if self.sr_tunnel_request_state is not None:
                                                    return True

                                                if self.sr_tunnel_state is not None:
                                                    return True

                                                if self.tunnel_encap_type is not None:
                                                    return True

                                                if self.unknown_attribute is not None:
                                                    for child_ref in self.unknown_attribute:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                        class AttrSet(object):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_encap_present
                                            
                                            	Tunnel Encap attribute present 
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_policy_allocated_binding_sid
                                            
                                            	SR Policy allocated Binding sid by the router
                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                            
                                            .. attribute:: sr_policy_binding_sid
                                            
                                            	SR Policy Binding sid
                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                            
                                            .. attribute:: sr_policy_explicit_path
                                            
                                            	SR Policy Explicit paths
                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                            
                                            .. attribute:: sr_policy_preference
                                            
                                            	SR Policy Preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_tunnel_request_state
                                            
                                            	SR Tunnel Request State
                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                            
                                            .. attribute:: sr_tunnel_state
                                            
                                            	SR Tunnel State
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap_type
                                            
                                            	Tunnel Encap Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.aggregator_address = None
                                                self.aggregator_as = None
                                                self.aigp_metric_value = None
                                                self.as_path = None
                                                self.cluster = YList()
                                                self.cluster.parent = self
                                                self.cluster.name = 'cluster'
                                                self.community = YList()
                                                self.community.parent = self
                                                self.community.name = 'community'
                                                self.connector_type = None
                                                self.connector_value = YList()
                                                self.connector_value.parent = self
                                                self.connector_value.name = 'connector_value'
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.extended_community_flags = None
                                                self.is_aggregator_present = None
                                                self.is_aigp_present = None
                                                self.is_as_path_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_community_present = None
                                                self.is_connector_present = None
                                                self.is_extended_community_present = None
                                                self.is_label_index_present = None
                                                self.is_local_pref_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_metric_present = None
                                                self.is_origin_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_ssa_present = None
                                                self.is_tunnel_encap_present = None
                                                self.l2tpv3_cookie = YList()
                                                self.l2tpv3_cookie.parent = self
                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                self.l2tpv3_session_id = None
                                                self.label_index_attr = YList()
                                                self.label_index_attr.parent = self
                                                self.label_index_attr.name = 'label_index_attr'
                                                self.local_preference = None
                                                self.ls_attr = YList()
                                                self.ls_attr.parent = self
                                                self.ls_attr.name = 'ls_attr'
                                                self.metric = None
                                                self.neighbor_as = None
                                                self.origin = None
                                                self.originator = None
                                                self.pe_distinguisher_label = YList()
                                                self.pe_distinguisher_label.parent = self
                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.pmsi_type = None
                                                self.pmsi_value = YList()
                                                self.pmsi_value.parent = self
                                                self.pmsi_value.name = 'pmsi_value'
                                                self.ppm_pvalue = None
                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                self.sr_policy_allocated_binding_sid.parent = self
                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                self.sr_policy_binding_sid.parent = self
                                                self.sr_policy_explicit_path = YList()
                                                self.sr_policy_explicit_path.parent = self
                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                self.sr_policy_preference = None
                                                self.sr_tunnel_request_state = None
                                                self.sr_tunnel_state = None
                                                self.tunnel_encap_type = None
                                                self.unknown_attribute = YList()
                                                self.unknown_attribute.parent = self
                                                self.unknown_attribute.name = 'unknown_attribute'


                                            class SrPolicyBindingSid(object):
                                                """
                                                SR Policy Binding sid
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                            class SrPolicyAllocatedBindingSid(object):
                                                """
                                                SR Policy allocated Binding sid by the router
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                            class Community(object):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                            class UnknownAttribute(object):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                            class Cluster(object):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                            class L2Tpv3Cookie(object):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                            class ConnectorValue(object):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                            class PmsiValue(object):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                            class LsAttr(object):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                            class LabelIndexAttr(object):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                            class PeDistinguisherLabel(object):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.label = None
                                                    self.pe_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.label is not None:
                                                        return True

                                                    if self.pe_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                            class SrPolicyExplicitPath(object):
                                                """
                                                SR Policy Explicit paths
                                                
                                                .. attribute:: sid
                                                
                                                	Sidlist for explicit path
                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                
                                                .. attribute:: weight
                                                
                                                	Weight of explicit path
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.sid = YList()
                                                    self.sid.parent = self
                                                    self.sid.name = 'sid'
                                                    self.weight = None


                                                class Sid(object):
                                                    """
                                                    Sidlist for explicit path
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IP Address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label sid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Sid Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4 is not None:
                                                            return True

                                                        if self.ipv6 is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.sid is not None:
                                                        for child_ref in self.sid:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.weight is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.aggregator_address is not None:
                                                    return True

                                                if self.aggregator_as is not None:
                                                    return True

                                                if self.aigp_metric_value is not None:
                                                    return True

                                                if self.as_path is not None:
                                                    return True

                                                if self.cluster is not None:
                                                    for child_ref in self.cluster:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.community is not None:
                                                    for child_ref in self.community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.connector_type is not None:
                                                    return True

                                                if self.connector_value is not None:
                                                    for child_ref in self.connector_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community_flags is not None:
                                                    return True

                                                if self.is_aggregator_present is not None:
                                                    return True

                                                if self.is_aigp_present is not None:
                                                    return True

                                                if self.is_as_path_present is not None:
                                                    return True

                                                if self.is_atomic_aggregate_present is not None:
                                                    return True

                                                if self.is_community_present is not None:
                                                    return True

                                                if self.is_connector_present is not None:
                                                    return True

                                                if self.is_extended_community_present is not None:
                                                    return True

                                                if self.is_label_index_present is not None:
                                                    return True

                                                if self.is_local_pref_present is not None:
                                                    return True

                                                if self.is_ls_attribute_present is not None:
                                                    return True

                                                if self.is_metric_present is not None:
                                                    return True

                                                if self.is_origin_present is not None:
                                                    return True

                                                if self.is_pe_distinguisher_label_present is not None:
                                                    return True

                                                if self.is_pmsi_present is not None:
                                                    return True

                                                if self.is_pppmp_present is not None:
                                                    return True

                                                if self.is_ssa_present is not None:
                                                    return True

                                                if self.is_tunnel_encap_present is not None:
                                                    return True

                                                if self.l2tpv3_cookie is not None:
                                                    for child_ref in self.l2tpv3_cookie:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2tpv3_session_id is not None:
                                                    return True

                                                if self.label_index_attr is not None:
                                                    for child_ref in self.label_index_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_preference is not None:
                                                    return True

                                                if self.ls_attr is not None:
                                                    for child_ref in self.ls_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.metric is not None:
                                                    return True

                                                if self.neighbor_as is not None:
                                                    return True

                                                if self.origin is not None:
                                                    return True

                                                if self.originator is not None:
                                                    return True

                                                if self.pe_distinguisher_label is not None:
                                                    for child_ref in self.pe_distinguisher_label:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.pmsi_flags is not None:
                                                    return True

                                                if self.pmsi_label is not None:
                                                    return True

                                                if self.pmsi_type is not None:
                                                    return True

                                                if self.pmsi_value is not None:
                                                    for child_ref in self.pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.ppm_pvalue is not None:
                                                    return True

                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_explicit_path is not None:
                                                    for child_ref in self.sr_policy_explicit_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.sr_policy_preference is not None:
                                                    return True

                                                if self.sr_tunnel_request_state is not None:
                                                    return True

                                                if self.sr_tunnel_state is not None:
                                                    return True

                                                if self.tunnel_encap_type is not None:
                                                    return True

                                                if self.unknown_attribute is not None:
                                                    for child_ref in self.unknown_attribute:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                        class RnhAddr(object):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.len = None
                                                self.mac_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.len is not None:
                                                    return True

                                                if self.mac_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                        class RibrnhIp(object):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.attr_set is not None and self.attr_set._has_data():
                                                return True

                                            if self.attribute_key_number is not None:
                                                return True

                                            if self.attribute_reuse_id_config is not None:
                                                return True

                                            if self.attribute_reuse_id_current is not None:
                                                return True

                                            if self.attribute_reuse_id_keys is not None:
                                                return True

                                            if self.attribute_reuse_id_max_id is not None:
                                                return True

                                            if self.attribute_reuse_id_node is not None:
                                                return True

                                            if self.attribute_reuse_id_recover_sec is not None:
                                                return True

                                            if self.common_attributes is not None and self.common_attributes._has_data():
                                                return True

                                            if self.is_application_gateway_present is not None:
                                                return True

                                            if self.is_as_path2_byte is not None:
                                                return True

                                            if self.is_attr_set_present is not None:
                                                return True

                                            if self.is_ribrnh_present is not None:
                                                return True

                                            if self.is_rnh_present is not None:
                                                return True

                                            if self.ribrnh_encap is not None:
                                                return True

                                            if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                return True

                                            if self.ribrnh_mac is not None:
                                                return True

                                            if self.ribrnh_table is not None:
                                                return True

                                            if self.ribrnh_vni is not None:
                                                return True

                                            if self.ribrnhip_table is not None:
                                                return True

                                            if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                return True

                                            if self.rnh_addr_len is not None:
                                                return True

                                            if self.rnh_len is not None:
                                                return True

                                            if self.rnh_type is not None:
                                                return True

                                            if self.set_aigp_inbound_igp is not None:
                                                return True

                                            if self.set_aigp_inbound_metric is not None:
                                                return True

                                            if self.vpn_distinguisher is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:dampening'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                            return True

                                        if self.label_fail is not None:
                                            return True

                                        if self.label_o_or_version is not None:
                                            return True

                                        if self.label_oor is not None:
                                            return True

                                        if self.neighbor_address is not None:
                                            return True

                                        if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                            return True

                                        if self.network is not None:
                                            return True

                                        if self.no_path is not None:
                                            return True

                                        if self.path_id is not None:
                                            return True

                                        if self.path_information is not None and self.path_information._has_data():
                                            return True

                                        if self.prefix_version is not None:
                                            return True

                                        if self.process_instance_id is not None:
                                            return True

                                        if self.rd is not None:
                                            return True

                                        if self.reuse is not None:
                                            return True

                                        if self.route_distinguisher is not None:
                                            return True

                                        if self.source_rd is not None:
                                            return True

                                        if self.source_route_distinguisher is not None:
                                            return True

                                        if self.source_vrf_name is not None:
                                            return True

                                        if self.srcaf_name is not None:
                                            return True

                                        if self.version is not None:
                                            return True

                                        if self.vrf_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:dampenings'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dampening is not None:
                                        for child_ref in self.dampening:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings']['meta_info']


                            class PrefixFilters(object):
                                """
                                The BGP Prefix Filter table
                                
                                .. attribute:: prefix_filter
                                
                                	A BGP prefix filter table entry
                                	**type**\: list of    :py:class:`PrefixFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.prefix_filter = YList()
                                    self.prefix_filter.parent = self
                                    self.prefix_filter.name = 'prefix_filter'


                                class PrefixFilter(object):
                                    """
                                    A BGP prefix filter table entry
                                    
                                    .. attribute:: neighbor_address  <key>
                                    
                                    	Neighbor address
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: af_name
                                    
                                    	Address family identfier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr>`
                                    
                                    .. attribute:: prefix_list_info
                                    
                                    	Prefix list
                                    	**type**\:   :py:class:`PrefixListInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.neighbor_address = None
                                        self.af_name = None
                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr()
                                        self.neighbor_address_xr.parent = self
                                        self.prefix_list_info = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo()
                                        self.prefix_list_info.parent = self


                                    class NeighborAddressXr(object):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr']['meta_info']


                                    class PrefixListInfo(object):
                                        """
                                        Prefix list
                                        
                                        .. attribute:: bgp_pfxlst
                                        
                                        	bgp pfxlst
                                        	**type**\: list of    :py:class:`BgpPfxlst <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_pfxlst = YList()
                                            self.bgp_pfxlst.parent = self
                                            self.bgp_pfxlst.name = 'bgp_pfxlst'


                                        class BgpPfxlst(object):
                                            """
                                            bgp pfxlst
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix>`
                                            
                                            .. attribute:: is_prefix_grant
                                            
                                            	TRUE = permit, FALSE = deny
                                            	**type**\:  bool
                                            
                                            .. attribute:: max_prefix_length
                                            
                                            	Maximum prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: min_prefix_length
                                            
                                            	Minimum prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self.is_prefix_grant = None
                                                self.max_prefix_length = None
                                                self.min_prefix_length = None
                                                self.sequence_number = None


                                            class BgpPrefix(object):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self.prefix_length = None


                                                class Prefix(object):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.prefix is not None and self.prefix._has_data():
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-pfxlst'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                    return True

                                                if self.is_prefix_grant is not None:
                                                    return True

                                                if self.max_prefix_length is not None:
                                                    return True

                                                if self.min_prefix_length is not None:
                                                    return True

                                                if self.sequence_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix-list-info'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_pfxlst is not None:
                                                for child_ref in self.bgp_pfxlst:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.neighbor_address is None:
                                            raise YPYModelError('Key property neighbor_address is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix-filter[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address = ' + str(self.neighbor_address) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.neighbor_address is not None:
                                            return True

                                        if self.af_name is not None:
                                            return True

                                        if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                            return True

                                        if self.prefix_list_info is not None and self.prefix_list_info._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix-filters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.prefix_filter is not None:
                                        for child_ref in self.prefix_filter:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters']['meta_info']


                            class Attributes(object):
                                """
                                The BGP Attribute table
                                
                                .. attribute:: attribute
                                
                                	A BGP Attribute table entry
                                	**type**\: list of    :py:class:`Attribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.attribute = YList()
                                    self.attribute.parent = self
                                    self.attribute.name = 'attribute'


                                class Attribute(object):
                                    """
                                    A BGP Attribute table entry
                                    
                                    .. attribute:: attribute_cache_bucket
                                    
                                    	Attribute cache bucket
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: attribute_cache_id
                                    
                                    	Attribute cache ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: attribute_iid
                                    
                                    	Attribute IID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: attribute_info
                                    
                                    	Attributes
                                    	**type**\:   :py:class:`AttributeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo>`
                                    
                                    .. attribute:: attribute_instance_id
                                    
                                    	Attribute Instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: attribute_structure_hash_value
                                    
                                    	Hash value for attribute structure
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: attribute_structure_id
                                    
                                    	ID of attribute structure
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: reference_count
                                    
                                    	Number of paths which use this attribute structure
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.attribute_cache_bucket = None
                                        self.attribute_cache_id = None
                                        self.attribute_iid = None
                                        self.attribute_info = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo()
                                        self.attribute_info.parent = self
                                        self.attribute_instance_id = None
                                        self.attribute_structure_hash_value = None
                                        self.attribute_structure_id = None
                                        self.process_instance_id = None
                                        self.reference_count = None


                                    class AttributeInfo(object):
                                        """
                                        Attributes
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet>`
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes>`
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp>`
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr>`
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\:  bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet()
                                            self.attr_set.parent = self
                                            self.attribute_key_number = None
                                            self.attribute_reuse_id_config = None
                                            self.attribute_reuse_id_current = None
                                            self.attribute_reuse_id_keys = None
                                            self.attribute_reuse_id_max_id = None
                                            self.attribute_reuse_id_node = None
                                            self.attribute_reuse_id_recover_sec = None
                                            self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self.is_application_gateway_present = None
                                            self.is_as_path2_byte = None
                                            self.is_attr_set_present = None
                                            self.is_ribrnh_present = None
                                            self.is_rnh_present = None
                                            self.ribrnh_encap = None
                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self.ribrnh_mac = None
                                            self.ribrnh_table = None
                                            self.ribrnh_vni = None
                                            self.ribrnhip_table = None
                                            self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self.rnh_addr_len = None
                                            self.rnh_len = None
                                            self.rnh_type = None
                                            self.set_aigp_inbound_igp = None
                                            self.set_aigp_inbound_metric = None
                                            self.vpn_distinguisher = None


                                        class CommonAttributes(object):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_encap_present
                                            
                                            	Tunnel Encap attribute present 
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LabelIndexAttr>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_policy_allocated_binding_sid
                                            
                                            	SR Policy allocated Binding sid by the router
                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                            
                                            .. attribute:: sr_policy_binding_sid
                                            
                                            	SR Policy Binding sid
                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyBindingSid>`
                                            
                                            .. attribute:: sr_policy_explicit_path
                                            
                                            	SR Policy Explicit paths
                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyExplicitPath>`
                                            
                                            .. attribute:: sr_policy_preference
                                            
                                            	SR Policy Preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_tunnel_request_state
                                            
                                            	SR Tunnel Request State
                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                            
                                            .. attribute:: sr_tunnel_state
                                            
                                            	SR Tunnel State
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap_type
                                            
                                            	Tunnel Encap Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.aggregator_address = None
                                                self.aggregator_as = None
                                                self.aigp_metric_value = None
                                                self.as_path = None
                                                self.cluster = YList()
                                                self.cluster.parent = self
                                                self.cluster.name = 'cluster'
                                                self.community = YList()
                                                self.community.parent = self
                                                self.community.name = 'community'
                                                self.connector_type = None
                                                self.connector_value = YList()
                                                self.connector_value.parent = self
                                                self.connector_value.name = 'connector_value'
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.extended_community_flags = None
                                                self.is_aggregator_present = None
                                                self.is_aigp_present = None
                                                self.is_as_path_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_community_present = None
                                                self.is_connector_present = None
                                                self.is_extended_community_present = None
                                                self.is_label_index_present = None
                                                self.is_local_pref_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_metric_present = None
                                                self.is_origin_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_ssa_present = None
                                                self.is_tunnel_encap_present = None
                                                self.l2tpv3_cookie = YList()
                                                self.l2tpv3_cookie.parent = self
                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                self.l2tpv3_session_id = None
                                                self.label_index_attr = YList()
                                                self.label_index_attr.parent = self
                                                self.label_index_attr.name = 'label_index_attr'
                                                self.local_preference = None
                                                self.ls_attr = YList()
                                                self.ls_attr.parent = self
                                                self.ls_attr.name = 'ls_attr'
                                                self.metric = None
                                                self.neighbor_as = None
                                                self.origin = None
                                                self.originator = None
                                                self.pe_distinguisher_label = YList()
                                                self.pe_distinguisher_label.parent = self
                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.pmsi_type = None
                                                self.pmsi_value = YList()
                                                self.pmsi_value.parent = self
                                                self.pmsi_value.name = 'pmsi_value'
                                                self.ppm_pvalue = None
                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                self.sr_policy_allocated_binding_sid.parent = self
                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyBindingSid()
                                                self.sr_policy_binding_sid.parent = self
                                                self.sr_policy_explicit_path = YList()
                                                self.sr_policy_explicit_path.parent = self
                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                self.sr_policy_preference = None
                                                self.sr_tunnel_request_state = None
                                                self.sr_tunnel_state = None
                                                self.tunnel_encap_type = None
                                                self.unknown_attribute = YList()
                                                self.unknown_attribute.parent = self
                                                self.unknown_attribute.name = 'unknown_attribute'


                                            class SrPolicyBindingSid(object):
                                                """
                                                SR Policy Binding sid
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                            class SrPolicyAllocatedBindingSid(object):
                                                """
                                                SR Policy allocated Binding sid by the router
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                            class Community(object):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity']['meta_info']


                                            class UnknownAttribute(object):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute']['meta_info']


                                            class Cluster(object):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster']['meta_info']


                                            class L2Tpv3Cookie(object):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                            class ConnectorValue(object):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue']['meta_info']


                                            class PmsiValue(object):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue']['meta_info']


                                            class LsAttr(object):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr']['meta_info']


                                            class LabelIndexAttr(object):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LabelIndexAttr']['meta_info']


                                            class PeDistinguisherLabel(object):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.label = None
                                                    self.pe_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.label is not None:
                                                        return True

                                                    if self.pe_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                            class SrPolicyExplicitPath(object):
                                                """
                                                SR Policy Explicit paths
                                                
                                                .. attribute:: sid
                                                
                                                	Sidlist for explicit path
                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                
                                                .. attribute:: weight
                                                
                                                	Weight of explicit path
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.sid = YList()
                                                    self.sid.parent = self
                                                    self.sid.name = 'sid'
                                                    self.weight = None


                                                class Sid(object):
                                                    """
                                                    Sidlist for explicit path
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IP Address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label sid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Sid Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4 is not None:
                                                            return True

                                                        if self.ipv6 is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.sid is not None:
                                                        for child_ref in self.sid:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.weight is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.aggregator_address is not None:
                                                    return True

                                                if self.aggregator_as is not None:
                                                    return True

                                                if self.aigp_metric_value is not None:
                                                    return True

                                                if self.as_path is not None:
                                                    return True

                                                if self.cluster is not None:
                                                    for child_ref in self.cluster:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.community is not None:
                                                    for child_ref in self.community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.connector_type is not None:
                                                    return True

                                                if self.connector_value is not None:
                                                    for child_ref in self.connector_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community_flags is not None:
                                                    return True

                                                if self.is_aggregator_present is not None:
                                                    return True

                                                if self.is_aigp_present is not None:
                                                    return True

                                                if self.is_as_path_present is not None:
                                                    return True

                                                if self.is_atomic_aggregate_present is not None:
                                                    return True

                                                if self.is_community_present is not None:
                                                    return True

                                                if self.is_connector_present is not None:
                                                    return True

                                                if self.is_extended_community_present is not None:
                                                    return True

                                                if self.is_label_index_present is not None:
                                                    return True

                                                if self.is_local_pref_present is not None:
                                                    return True

                                                if self.is_ls_attribute_present is not None:
                                                    return True

                                                if self.is_metric_present is not None:
                                                    return True

                                                if self.is_origin_present is not None:
                                                    return True

                                                if self.is_pe_distinguisher_label_present is not None:
                                                    return True

                                                if self.is_pmsi_present is not None:
                                                    return True

                                                if self.is_pppmp_present is not None:
                                                    return True

                                                if self.is_ssa_present is not None:
                                                    return True

                                                if self.is_tunnel_encap_present is not None:
                                                    return True

                                                if self.l2tpv3_cookie is not None:
                                                    for child_ref in self.l2tpv3_cookie:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2tpv3_session_id is not None:
                                                    return True

                                                if self.label_index_attr is not None:
                                                    for child_ref in self.label_index_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_preference is not None:
                                                    return True

                                                if self.ls_attr is not None:
                                                    for child_ref in self.ls_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.metric is not None:
                                                    return True

                                                if self.neighbor_as is not None:
                                                    return True

                                                if self.origin is not None:
                                                    return True

                                                if self.originator is not None:
                                                    return True

                                                if self.pe_distinguisher_label is not None:
                                                    for child_ref in self.pe_distinguisher_label:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.pmsi_flags is not None:
                                                    return True

                                                if self.pmsi_label is not None:
                                                    return True

                                                if self.pmsi_type is not None:
                                                    return True

                                                if self.pmsi_value is not None:
                                                    for child_ref in self.pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.ppm_pvalue is not None:
                                                    return True

                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_explicit_path is not None:
                                                    for child_ref in self.sr_policy_explicit_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.sr_policy_preference is not None:
                                                    return True

                                                if self.sr_tunnel_request_state is not None:
                                                    return True

                                                if self.sr_tunnel_state is not None:
                                                    return True

                                                if self.tunnel_encap_type is not None:
                                                    return True

                                                if self.unknown_attribute is not None:
                                                    for child_ref in self.unknown_attribute:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes']['meta_info']


                                        class AttrSet(object):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_encap_present
                                            
                                            	Tunnel Encap attribute present 
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LabelIndexAttr>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_policy_allocated_binding_sid
                                            
                                            	SR Policy allocated Binding sid by the router
                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyAllocatedBindingSid>`
                                            
                                            .. attribute:: sr_policy_binding_sid
                                            
                                            	SR Policy Binding sid
                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyBindingSid>`
                                            
                                            .. attribute:: sr_policy_explicit_path
                                            
                                            	SR Policy Explicit paths
                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyExplicitPath>`
                                            
                                            .. attribute:: sr_policy_preference
                                            
                                            	SR Policy Preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_tunnel_request_state
                                            
                                            	SR Tunnel Request State
                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                            
                                            .. attribute:: sr_tunnel_state
                                            
                                            	SR Tunnel State
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap_type
                                            
                                            	Tunnel Encap Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.aggregator_address = None
                                                self.aggregator_as = None
                                                self.aigp_metric_value = None
                                                self.as_path = None
                                                self.cluster = YList()
                                                self.cluster.parent = self
                                                self.cluster.name = 'cluster'
                                                self.community = YList()
                                                self.community.parent = self
                                                self.community.name = 'community'
                                                self.connector_type = None
                                                self.connector_value = YList()
                                                self.connector_value.parent = self
                                                self.connector_value.name = 'connector_value'
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.extended_community_flags = None
                                                self.is_aggregator_present = None
                                                self.is_aigp_present = None
                                                self.is_as_path_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_community_present = None
                                                self.is_connector_present = None
                                                self.is_extended_community_present = None
                                                self.is_label_index_present = None
                                                self.is_local_pref_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_metric_present = None
                                                self.is_origin_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_ssa_present = None
                                                self.is_tunnel_encap_present = None
                                                self.l2tpv3_cookie = YList()
                                                self.l2tpv3_cookie.parent = self
                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                self.l2tpv3_session_id = None
                                                self.label_index_attr = YList()
                                                self.label_index_attr.parent = self
                                                self.label_index_attr.name = 'label_index_attr'
                                                self.local_preference = None
                                                self.ls_attr = YList()
                                                self.ls_attr.parent = self
                                                self.ls_attr.name = 'ls_attr'
                                                self.metric = None
                                                self.neighbor_as = None
                                                self.origin = None
                                                self.originator = None
                                                self.pe_distinguisher_label = YList()
                                                self.pe_distinguisher_label.parent = self
                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.pmsi_type = None
                                                self.pmsi_value = YList()
                                                self.pmsi_value.parent = self
                                                self.pmsi_value.name = 'pmsi_value'
                                                self.ppm_pvalue = None
                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyAllocatedBindingSid()
                                                self.sr_policy_allocated_binding_sid.parent = self
                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyBindingSid()
                                                self.sr_policy_binding_sid.parent = self
                                                self.sr_policy_explicit_path = YList()
                                                self.sr_policy_explicit_path.parent = self
                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                self.sr_policy_preference = None
                                                self.sr_tunnel_request_state = None
                                                self.sr_tunnel_state = None
                                                self.tunnel_encap_type = None
                                                self.unknown_attribute = YList()
                                                self.unknown_attribute.parent = self
                                                self.unknown_attribute.name = 'unknown_attribute'


                                            class SrPolicyBindingSid(object):
                                                """
                                                SR Policy Binding sid
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyBindingSid']['meta_info']


                                            class SrPolicyAllocatedBindingSid(object):
                                                """
                                                SR Policy allocated Binding sid by the router
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                            class Community(object):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity']['meta_info']


                                            class UnknownAttribute(object):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute']['meta_info']


                                            class Cluster(object):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster']['meta_info']


                                            class L2Tpv3Cookie(object):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2Tpv3Cookie']['meta_info']


                                            class ConnectorValue(object):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue']['meta_info']


                                            class PmsiValue(object):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue']['meta_info']


                                            class LsAttr(object):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr']['meta_info']


                                            class LabelIndexAttr(object):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LabelIndexAttr']['meta_info']


                                            class PeDistinguisherLabel(object):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.label = None
                                                    self.pe_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.label is not None:
                                                        return True

                                                    if self.pe_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel']['meta_info']


                                            class SrPolicyExplicitPath(object):
                                                """
                                                SR Policy Explicit paths
                                                
                                                .. attribute:: sid
                                                
                                                	Sidlist for explicit path
                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyExplicitPath.Sid>`
                                                
                                                .. attribute:: weight
                                                
                                                	Weight of explicit path
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.sid = YList()
                                                    self.sid.parent = self
                                                    self.sid.name = 'sid'
                                                    self.weight = None


                                                class Sid(object):
                                                    """
                                                    Sidlist for explicit path
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IP Address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label sid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Sid Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4 is not None:
                                                            return True

                                                        if self.ipv6 is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.sid is not None:
                                                        for child_ref in self.sid:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.weight is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyExplicitPath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.aggregator_address is not None:
                                                    return True

                                                if self.aggregator_as is not None:
                                                    return True

                                                if self.aigp_metric_value is not None:
                                                    return True

                                                if self.as_path is not None:
                                                    return True

                                                if self.cluster is not None:
                                                    for child_ref in self.cluster:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.community is not None:
                                                    for child_ref in self.community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.connector_type is not None:
                                                    return True

                                                if self.connector_value is not None:
                                                    for child_ref in self.connector_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community_flags is not None:
                                                    return True

                                                if self.is_aggregator_present is not None:
                                                    return True

                                                if self.is_aigp_present is not None:
                                                    return True

                                                if self.is_as_path_present is not None:
                                                    return True

                                                if self.is_atomic_aggregate_present is not None:
                                                    return True

                                                if self.is_community_present is not None:
                                                    return True

                                                if self.is_connector_present is not None:
                                                    return True

                                                if self.is_extended_community_present is not None:
                                                    return True

                                                if self.is_label_index_present is not None:
                                                    return True

                                                if self.is_local_pref_present is not None:
                                                    return True

                                                if self.is_ls_attribute_present is not None:
                                                    return True

                                                if self.is_metric_present is not None:
                                                    return True

                                                if self.is_origin_present is not None:
                                                    return True

                                                if self.is_pe_distinguisher_label_present is not None:
                                                    return True

                                                if self.is_pmsi_present is not None:
                                                    return True

                                                if self.is_pppmp_present is not None:
                                                    return True

                                                if self.is_ssa_present is not None:
                                                    return True

                                                if self.is_tunnel_encap_present is not None:
                                                    return True

                                                if self.l2tpv3_cookie is not None:
                                                    for child_ref in self.l2tpv3_cookie:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2tpv3_session_id is not None:
                                                    return True

                                                if self.label_index_attr is not None:
                                                    for child_ref in self.label_index_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_preference is not None:
                                                    return True

                                                if self.ls_attr is not None:
                                                    for child_ref in self.ls_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.metric is not None:
                                                    return True

                                                if self.neighbor_as is not None:
                                                    return True

                                                if self.origin is not None:
                                                    return True

                                                if self.originator is not None:
                                                    return True

                                                if self.pe_distinguisher_label is not None:
                                                    for child_ref in self.pe_distinguisher_label:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.pmsi_flags is not None:
                                                    return True

                                                if self.pmsi_label is not None:
                                                    return True

                                                if self.pmsi_type is not None:
                                                    return True

                                                if self.pmsi_value is not None:
                                                    for child_ref in self.pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.ppm_pvalue is not None:
                                                    return True

                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_explicit_path is not None:
                                                    for child_ref in self.sr_policy_explicit_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.sr_policy_preference is not None:
                                                    return True

                                                if self.sr_tunnel_request_state is not None:
                                                    return True

                                                if self.sr_tunnel_state is not None:
                                                    return True

                                                if self.tunnel_encap_type is not None:
                                                    return True

                                                if self.unknown_attribute is not None:
                                                    for child_ref in self.unknown_attribute:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet']['meta_info']


                                        class RnhAddr(object):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.len = None
                                                self.mac_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.len is not None:
                                                    return True

                                                if self.mac_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr']['meta_info']


                                        class RibrnhIp(object):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attribute-info'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.attr_set is not None and self.attr_set._has_data():
                                                return True

                                            if self.attribute_key_number is not None:
                                                return True

                                            if self.attribute_reuse_id_config is not None:
                                                return True

                                            if self.attribute_reuse_id_current is not None:
                                                return True

                                            if self.attribute_reuse_id_keys is not None:
                                                return True

                                            if self.attribute_reuse_id_max_id is not None:
                                                return True

                                            if self.attribute_reuse_id_node is not None:
                                                return True

                                            if self.attribute_reuse_id_recover_sec is not None:
                                                return True

                                            if self.common_attributes is not None and self.common_attributes._has_data():
                                                return True

                                            if self.is_application_gateway_present is not None:
                                                return True

                                            if self.is_as_path2_byte is not None:
                                                return True

                                            if self.is_attr_set_present is not None:
                                                return True

                                            if self.is_ribrnh_present is not None:
                                                return True

                                            if self.is_rnh_present is not None:
                                                return True

                                            if self.ribrnh_encap is not None:
                                                return True

                                            if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                return True

                                            if self.ribrnh_mac is not None:
                                                return True

                                            if self.ribrnh_table is not None:
                                                return True

                                            if self.ribrnh_vni is not None:
                                                return True

                                            if self.ribrnhip_table is not None:
                                                return True

                                            if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                return True

                                            if self.rnh_addr_len is not None:
                                                return True

                                            if self.rnh_len is not None:
                                                return True

                                            if self.rnh_type is not None:
                                                return True

                                            if self.set_aigp_inbound_igp is not None:
                                                return True

                                            if self.set_aigp_inbound_metric is not None:
                                                return True

                                            if self.vpn_distinguisher is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attribute'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.attribute_cache_bucket is not None:
                                            return True

                                        if self.attribute_cache_id is not None:
                                            return True

                                        if self.attribute_iid is not None:
                                            return True

                                        if self.attribute_info is not None and self.attribute_info._has_data():
                                            return True

                                        if self.attribute_instance_id is not None:
                                            return True

                                        if self.attribute_structure_hash_value is not None:
                                            return True

                                        if self.attribute_structure_id is not None:
                                            return True

                                        if self.process_instance_id is not None:
                                            return True

                                        if self.reference_count is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.attribute is not None:
                                        for child_ref in self.attribute:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.af_name is None:
                                    raise YPYModelError('Key property af_name is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af[Cisco-IOS-XR-ipv4-bgp-oper:af-name = ' + str(self.af_name) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.advertised_path_counts is not None and self.advertised_path_counts._has_data():
                                    return True

                                if self.advertised_path_xr is not None and self.advertised_path_xr._has_data():
                                    return True

                                if self.advertised_paths is not None and self.advertised_paths._has_data():
                                    return True

                                if self.af_process_info is not None and self.af_process_info._has_data():
                                    return True

                                if self.attributes is not None and self.attributes._has_data():
                                    return True

                                if self.bmp_paths is not None and self.bmp_paths._has_data():
                                    return True

                                if self.convergence is not None and self.convergence._has_data():
                                    return True

                                if self.dampenings is not None and self.dampenings._has_data():
                                    return True

                                if self.epes is not None and self.epes._has_data():
                                    return True

                                if self.global_af_process_info is not None and self.global_af_process_info._has_data():
                                    return True

                                if self.neighbor_af_table is not None and self.neighbor_af_table._has_data():
                                    return True

                                if self.network_all_rds is not None and self.network_all_rds._has_data():
                                    return True

                                if self.network_lookup_all_rds is not None and self.network_lookup_all_rds._has_data():
                                    return True

                                if self.network_prefixes is not None and self.network_prefixes._has_data():
                                    return True

                                if self.networks is not None and self.networks._has_data():
                                    return True

                                if self.next_hop_address_families is not None and self.next_hop_address_families._has_data():
                                    return True

                                if self.path_labeled_table is not None and self.path_labeled_table._has_data():
                                    return True

                                if self.path_table is not None and self.path_table._has_data():
                                    return True

                                if self.path_used_table is not None and self.path_used_table._has_data():
                                    return True

                                if self.policies is not None and self.policies._has_data():
                                    return True

                                if self.prefix_filters is not None and self.prefix_filters._has_data():
                                    return True

                                if self.rpc_sets is not None and self.rpc_sets._has_data():
                                    return True

                                if self.rt_set_counters is not None and self.rt_set_counters._has_data():
                                    return True

                                if self.sourced_networks is not None and self.sourced_networks._has_data():
                                    return True

                                if self.update_generation_address_family is not None and self.update_generation_address_family._has_data():
                                    return True

                                if self.update_generation_filter_groups is not None and self.update_generation_filter_groups._has_data():
                                    return True

                                if self.update_generation_neighbors is not None and self.update_generation_neighbors._has_data():
                                    return True

                                if self.update_generation_sub_groups is not None and self.update_generation_sub_groups._has_data():
                                    return True

                                if self.update_generation_update_groups is not None and self.update_generation_update_groups._has_data():
                                    return True

                                if self.update_groups is not None and self.update_groups._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:afs'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af is not None:
                                for child_ref in self.af:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs']['meta_info']


                    class Information(object):
                        """
                        Meta data for VRF
                        
                        .. attribute:: route_distinguisher
                        
                        	Route Distinguisher
                        	**type**\:  str
                        
                        	**pattern:** [a\-fA\-F0\-9]{16}
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.route_distinguisher = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.route_distinguisher is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Information']['meta_info']


                    class UpdateInboundFilterVrf(object):
                        """
                        Update inbound filtering information for the VRF
                        
                        .. attribute:: last_update_filtered_age
                        
                        	Time since last filtered messages received event (in seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: last_update_filtered_timestamp
                        
                        	Last Filtered messages received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                        	**type**\:   :py:class:`LastUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp>`
                        
                        .. attribute:: update_filtered_message_count
                        
                        	Filtered messages count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_filtered_neighbor_count
                        
                        	Count of neighbors that received filtered messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_vrf_name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.last_update_filtered_age = None
                            self.last_update_filtered_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp()
                            self.last_update_filtered_timestamp.parent = self
                            self.update_filtered_message_count = None
                            self.update_filtered_neighbor_count = None
                            self.update_vrf_name = None


                        class LastUpdateFilteredTimestamp(object):
                            """
                            Last Filtered messages received time\: time
                            elapsed since 00\:00\:00 UTC, January 1, 1970
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.nanoseconds = None
                                self.seconds = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-filtered-timestamp'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.nanoseconds is not None:
                                    return True

                                if self.seconds is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-inbound-filter-vrf'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.last_update_filtered_age is not None:
                                return True

                            if self.last_update_filtered_timestamp is not None and self.last_update_filtered_timestamp._has_data():
                                return True

                            if self.update_filtered_message_count is not None:
                                return True

                            if self.update_filtered_neighbor_count is not None:
                                return True

                            if self.update_vrf_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterVrf']['meta_info']


                    class Postits(object):
                        """
                        The BGP Neighbor table
                        
                        .. attribute:: postit
                        
                        	A BGP Postit table entry
                        	**type**\: list of    :py:class:`Postit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.postit = YList()
                            self.postit.parent = self
                            self.postit.name = 'postit'


                        class Postit(object):
                            """
                            A BGP Postit table entry
                            
                            .. attribute:: neighbor_address  <key>
                            
                            	Neighbor address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: connect_state
                            
                            	State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_af
                            
                            	Neighbor Afi
                            	**type**\: list of    :py:class:`NeighborAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborAf>`
                            
                            .. attribute:: neighbors_address
                            
                            	Neighbor Addr
                            	**type**\:   :py:class:`NeighborsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress>`
                            
                            .. attribute:: nsr_state
                            
                            	NSR state
                            	**type**\:   :py:class:`BgpSyncNbrNsrStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrStateEnum>`
                            
                            .. attribute:: postit_info
                            
                            	Postit Info
                            	**type**\: list of    :py:class:`PostitInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.PostitInfo>`
                            
                            .. attribute:: start_time
                            
                            	StartTime
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vrf_name
                            
                            	VRF Name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.neighbor_address = None
                                self.connect_state = None
                                self.neighbor_af = YList()
                                self.neighbor_af.parent = self
                                self.neighbor_af.name = 'neighbor_af'
                                self.neighbors_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress()
                                self.neighbors_address.parent = self
                                self.nsr_state = None
                                self.postit_info = YList()
                                self.postit_info.parent = self
                                self.postit_info.name = 'postit_info'
                                self.start_time = None
                                self.vrf_name = None


                            class NeighborsAddress(object):
                                """
                                Neighbor Addr
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpnvpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.L2VpnvplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4mdt_address = None
                                    self.ipv4mvpn_address = None
                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress()
                                    self.ipv4sr_policy_address.parent = self
                                    self.ipv4vpn_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress()
                                    self.ipv6sr_policy_address.parent = self
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_flowspec_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.l2vpn_evpn_address = None
                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.L2VpnvplsAddress()
                                    self.l2vpnvpls_address.parent = self
                                    self.ls_ls_address = None
                                    self.rt_constraint_address = None


                                class L2VpnvplsAddress(object):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.L2VpnvplsAddress']['meta_info']


                                class L2VpnMspwAddress(object):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.L2VpnMspwAddress']['meta_info']


                                class Ipv4SrPolicyAddress(object):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress']['meta_info']


                                class Ipv6SrPolicyAddress(object):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv6_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv6_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbors-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.afi is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv4_flowspec_address is not None:
                                        return True

                                    if self.ipv4_label_address is not None:
                                        return True

                                    if self.ipv4_mcast_address is not None:
                                        return True

                                    if self.ipv4_tunnel_address is not None:
                                        return True

                                    if self.ipv4mdt_address is not None:
                                        return True

                                    if self.ipv4mvpn_address is not None:
                                        return True

                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                        return True

                                    if self.ipv4vpn_address is not None:
                                        return True

                                    if self.ipv4vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv4vpna_mcastddress is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    if self.ipv6_flowspec_address is not None:
                                        return True

                                    if self.ipv6_label_address is not None:
                                        return True

                                    if self.ipv6_mcast_address is not None:
                                        return True

                                    if self.ipv6mvpn_address is not None:
                                        return True

                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                        return True

                                    if self.ipv6vpn_address is not None:
                                        return True

                                    if self.ipv6vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv6vpn_mcast_address is not None:
                                        return True

                                    if self.l2vpn_evpn_address is not None:
                                        return True

                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                        return True

                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                        return True

                                    if self.ls_ls_address is not None:
                                        return True

                                    if self.rt_constraint_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress']['meta_info']


                            class NeighborAf(object):
                                """
                                Neighbor Afi
                                
                                .. attribute:: entry
                                
                                	Array entry
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.entry = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-af'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.entry is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborAf']['meta_info']


                            class PostitInfo(object):
                                """
                                Postit Info
                                
                                .. attribute:: peer_id
                                
                                	Peer ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: postit_af_name
                                
                                	Postit Afi
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: postit_direction
                                
                                	Postit Direction
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: postit_flags
                                
                                	Postit Flags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: postit_id
                                
                                	Postit ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: postit_notification
                                
                                	Postit notification
                                	**type**\:   :py:class:`PostitNotification <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification>`
                                
                                .. attribute:: postit_policy
                                
                                	Policy
                                	**type**\:  str
                                
                                .. attribute:: postit_reset
                                
                                	Reset
                                	**type**\:   :py:class:`BgpResetReasonIndexEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndexEnum>`
                                
                                .. attribute:: postit_subtype
                                
                                	Postit Subtype
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: postit_ts
                                
                                	Postit TS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: postit_type
                                
                                	Postit Type
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.peer_id = None
                                    self.postit_af_name = None
                                    self.postit_direction = None
                                    self.postit_flags = None
                                    self.postit_id = None
                                    self.postit_notification = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification()
                                    self.postit_notification.parent = self
                                    self.postit_policy = None
                                    self.postit_reset = None
                                    self.postit_subtype = None
                                    self.postit_ts = None
                                    self.postit_type = None


                                class PostitNotification(object):
                                    """
                                    Postit notification
                                    
                                    .. attribute:: last_notification_data
                                    
                                    	Message data in last notification
                                    	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData>`
                                    
                                    .. attribute:: notification_error_code
                                    
                                    	Error code in last notification
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: notification_error_subcode
                                    
                                    	Error subcode in last notification
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: time_since_last_notification
                                    
                                    	Time since the last notification was sent or received (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.last_notification_data = YList()
                                        self.last_notification_data.parent = self
                                        self.last_notification_data.name = 'last_notification_data'
                                        self.notification_error_code = None
                                        self.notification_error_subcode = None
                                        self.time_since_last_notification = None


                                    class LastNotificationData(object):
                                        """
                                        Message data in last notification
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.entry = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-notification-data'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.entry is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:postit-notification'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.last_notification_data is not None:
                                            for child_ref in self.last_notification_data:
                                                if child_ref._has_data():
                                                    return True

                                        if self.notification_error_code is not None:
                                            return True

                                        if self.notification_error_subcode is not None:
                                            return True

                                        if self.time_since_last_notification is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:postit-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.peer_id is not None:
                                        return True

                                    if self.postit_af_name is not None:
                                        return True

                                    if self.postit_direction is not None:
                                        return True

                                    if self.postit_flags is not None:
                                        return True

                                    if self.postit_id is not None:
                                        return True

                                    if self.postit_notification is not None and self.postit_notification._has_data():
                                        return True

                                    if self.postit_policy is not None:
                                        return True

                                    if self.postit_reset is not None:
                                        return True

                                    if self.postit_subtype is not None:
                                        return True

                                    if self.postit_ts is not None:
                                        return True

                                    if self.postit_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.PostitInfo']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.neighbor_address is None:
                                    raise YPYModelError('Key property neighbor_address is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:postit[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address = ' + str(self.neighbor_address) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.neighbor_address is not None:
                                    return True

                                if self.connect_state is not None:
                                    return True

                                if self.neighbor_af is not None:
                                    for child_ref in self.neighbor_af:
                                        if child_ref._has_data():
                                            return True

                                if self.neighbors_address is not None and self.neighbors_address._has_data():
                                    return True

                                if self.nsr_state is not None:
                                    return True

                                if self.postit_info is not None:
                                    for child_ref in self.postit_info:
                                        if child_ref._has_data():
                                            return True

                                if self.start_time is not None:
                                    return True

                                if self.vrf_name is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:postits'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.postit is not None:
                                for child_ref in self.postit:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits']['meta_info']


                    class GlobalProcessInfo(object):
                        """
                        The Global Process information table
                        
                        .. attribute:: global_
                        
                        	Global information
                        	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Global_>`
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Vrf>`
                        
                        .. attribute:: vrf_name
                        
                        	Name of the VRF
                        	**type**\:  str
                        
                        .. attribute:: vrfid
                        
                        	VRF ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.global_ = Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Global_()
                            self.global_.parent = self
                            self.vrf = Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Vrf()
                            self.vrf.parent = self
                            self.vrf_name = None
                            self.vrfid = None


                        class Global_(object):
                            """
                            Global information
                            
                            .. attribute:: asn_format
                            
                            	BGP AS Number Format
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bmp_current_buffer_size
                            
                            	Current value for BMP buffer 
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bmp_default_buffer_size
                            
                            	Default value for BMP buffer limit when a value is not configured
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bmp_maximum_buffer_size
                            
                            	Maximum limit user can configure for max\-buffer\-size command under bmp\-server
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: cluster_id
                            
                            	Cluster ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: cluster_id_entry
                            
                            	All configured Cluster IDs
                            	**type**\: list of    :py:class:`ClusterIdEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Global_.ClusterIdEntry>`
                            
                            .. attribute:: confederation_id
                            
                            	Confederation ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: configured_cluster_id
                            
                            	Configured cluster ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: generic_scan_period
                            
                            	Period (in seconds) of generic scanner runs
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: graceful_maint_all_nbrs
                            
                            	Graceful Maintenance also for neighbors without GM configuration
                            	**type**\:  bool
                            
                            .. attribute:: graceful_maint_retain_routes
                            
                            	Retaining routes in RIB when BGP process stops while in Graceful Maintenance
                            	**type**\:  bool
                            
                            .. attribute:: graceful_maintenance
                            
                            	Graceful Maintenance
                            	**type**\:  bool
                            
                            .. attribute:: in_standalone_mode
                            
                            	Standalone or Distributed mode
                            	**type**\:  bool
                            
                            .. attribute:: instance_name
                            
                            	Name of BGP instance
                            	**type**\:  str
                            
                            .. attribute:: is_cluster_id_specified_as_ip
                            
                            	Cluster ID specified as an IP address
                            	**type**\:  bool
                            
                            .. attribute:: local_as
                            
                            	Local autonomous system number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: process_rlimit
                            
                            	Platform RLIMIT max for the process
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: restart_count
                            
                            	No of times BGP has started
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: srgb_end
                            
                            	In use Segment\-routing Global Block end value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: srgb_end_configured
                            
                            	Configured segment\-routing Global Block end value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: srgb_start
                            
                            	In use segment\-routing Global Block start value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: srgb_start_configured
                            
                            	Configured segment\-routing Global Block start value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_delay
                            
                            	Update delay timeout time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.asn_format = None
                                self.bmp_current_buffer_size = None
                                self.bmp_default_buffer_size = None
                                self.bmp_maximum_buffer_size = None
                                self.cluster_id = None
                                self.cluster_id_entry = YList()
                                self.cluster_id_entry.parent = self
                                self.cluster_id_entry.name = 'cluster_id_entry'
                                self.confederation_id = None
                                self.configured_cluster_id = None
                                self.generic_scan_period = None
                                self.graceful_maint_all_nbrs = None
                                self.graceful_maint_retain_routes = None
                                self.graceful_maintenance = None
                                self.in_standalone_mode = None
                                self.instance_name = None
                                self.is_cluster_id_specified_as_ip = None
                                self.local_as = None
                                self.process_rlimit = None
                                self.restart_count = None
                                self.srgb_end = None
                                self.srgb_end_configured = None
                                self.srgb_start = None
                                self.srgb_start_configured = None
                                self.update_delay = None


                            class ClusterIdEntry(object):
                                """
                                All configured Cluster IDs
                                
                                .. attribute:: cluster_id_type
                                
                                	Cluster ID type\: number or IPv4 address
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: cluster_id_val
                                
                                	Cluster ID 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.cluster_id_type = None
                                    self.cluster_id_val = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster-id-entry'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.cluster_id_type is not None:
                                        return True

                                    if self.cluster_id_val is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Global_.ClusterIdEntry']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:global'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.asn_format is not None:
                                    return True

                                if self.bmp_current_buffer_size is not None:
                                    return True

                                if self.bmp_default_buffer_size is not None:
                                    return True

                                if self.bmp_maximum_buffer_size is not None:
                                    return True

                                if self.cluster_id is not None:
                                    return True

                                if self.cluster_id_entry is not None:
                                    for child_ref in self.cluster_id_entry:
                                        if child_ref._has_data():
                                            return True

                                if self.confederation_id is not None:
                                    return True

                                if self.configured_cluster_id is not None:
                                    return True

                                if self.generic_scan_period is not None:
                                    return True

                                if self.graceful_maint_all_nbrs is not None:
                                    return True

                                if self.graceful_maint_retain_routes is not None:
                                    return True

                                if self.graceful_maintenance is not None:
                                    return True

                                if self.in_standalone_mode is not None:
                                    return True

                                if self.instance_name is not None:
                                    return True

                                if self.is_cluster_id_specified_as_ip is not None:
                                    return True

                                if self.local_as is not None:
                                    return True

                                if self.process_rlimit is not None:
                                    return True

                                if self.restart_count is not None:
                                    return True

                                if self.srgb_end is not None:
                                    return True

                                if self.srgb_end_configured is not None:
                                    return True

                                if self.srgb_start is not None:
                                    return True

                                if self.srgb_start_configured is not None:
                                    return True

                                if self.update_delay is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Global_']['meta_info']


                        class Vrf(object):
                            """
                            VRF information
                            
                            .. attribute:: configured_router_id
                            
                            	Configured router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: default_local_preference
                            
                            	Default local preference
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: default_metric
                            
                            	Default metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: hold_time
                            
                            	Default hold timer (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: is_bestpath_aigp_ignore_enabled
                            
                            	Bestpath\: Ignore AIGP unless both paths have AIGP attribute
                            	**type**\:  bool
                            
                            .. attribute:: is_bestpath_always_compare_med_enabled
                            
                            	Bestpath\: Always compare MED
                            	**type**\:  bool
                            
                            .. attribute:: is_bestpath_as_path_mpath_relax_enabled
                            
                            	Bestpath\: Relax AS path for mpath
                            	**type**\:  bool
                            
                            .. attribute:: is_bestpath_compare_med_from_confed_peer_enabled
                            
                            	Bestpath\: Compare MED from confed peer
                            	**type**\:  bool
                            
                            .. attribute:: is_bestpath_compare_router_id_for_ebgp_peers_enabled
                            
                            	Bestpath\: Compare routerID for eBGP peers
                            	**type**\:  bool
                            
                            .. attribute:: is_bestpath_ignore_as_path_enabled
                            
                            	Bestpath\: Ignore AS path
                            	**type**\:  bool
                            
                            .. attribute:: is_bestpath_missing_med_is_worst_enabled
                            
                            	Bestpath\: Treat missing MED as worst
                            	**type**\:  bool
                            
                            .. attribute:: is_default_metric_configured
                            
                            	Default metric configured
                            	**type**\:  bool
                            
                            .. attribute:: is_default_originate_configured
                            
                            	Default route originate configured
                            	**type**\:  bool
                            
                            .. attribute:: is_enforce_first_as_enabled
                            
                            	Enforce first AS
                            	**type**\:  bool
                            
                            .. attribute:: is_fast_external_fallover_enabled
                            
                            	Fast external fallover enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_graceful_restart
                            
                            	Graceful restart enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_multipath_as_path_ignore_onwards_enabled
                            
                            	Multipath\: Ignore everything AS path onwards for mpath
                            	**type**\:  bool
                            
                            .. attribute:: is_neighbor_logging
                            
                            	Neighbor logging enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_nsr
                            
                            	Non\-stop routing enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_redistribute_ibgp_to_ig_ps_enabled
                            
                            	Redistribute iBGP into IGPs enabled
                            	**type**\:  bool
                            
                            .. attribute:: keep_alive_time
                            
                            	Default keepalive timer (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: min_acceptable_hold_time
                            
                            	Default min acceptable hold time from neighbor(seconds)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: restart_time
                            
                            	Restart time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: rib_purge_timeout
                            
                            	RIB purge timeout time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: route_distinguisher
                            
                            	Route Distinguisher
                            	**type**\:  str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: router_id
                            
                            	Router ID for the VRF
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: stale_path_time
                            
                            	Stale path timeout time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: vrf_is_active
                            
                            	VRF state
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.configured_router_id = None
                                self.default_local_preference = None
                                self.default_metric = None
                                self.hold_time = None
                                self.is_bestpath_aigp_ignore_enabled = None
                                self.is_bestpath_always_compare_med_enabled = None
                                self.is_bestpath_as_path_mpath_relax_enabled = None
                                self.is_bestpath_compare_med_from_confed_peer_enabled = None
                                self.is_bestpath_compare_router_id_for_ebgp_peers_enabled = None
                                self.is_bestpath_ignore_as_path_enabled = None
                                self.is_bestpath_missing_med_is_worst_enabled = None
                                self.is_default_metric_configured = None
                                self.is_default_originate_configured = None
                                self.is_enforce_first_as_enabled = None
                                self.is_fast_external_fallover_enabled = None
                                self.is_graceful_restart = None
                                self.is_multipath_as_path_ignore_onwards_enabled = None
                                self.is_neighbor_logging = None
                                self.is_nsr = None
                                self.is_redistribute_ibgp_to_ig_ps_enabled = None
                                self.keep_alive_time = None
                                self.min_acceptable_hold_time = None
                                self.restart_time = None
                                self.rib_purge_timeout = None
                                self.route_distinguisher = None
                                self.router_id = None
                                self.stale_path_time = None
                                self.vrf_is_active = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:vrf'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.configured_router_id is not None:
                                    return True

                                if self.default_local_preference is not None:
                                    return True

                                if self.default_metric is not None:
                                    return True

                                if self.hold_time is not None:
                                    return True

                                if self.is_bestpath_aigp_ignore_enabled is not None:
                                    return True

                                if self.is_bestpath_always_compare_med_enabled is not None:
                                    return True

                                if self.is_bestpath_as_path_mpath_relax_enabled is not None:
                                    return True

                                if self.is_bestpath_compare_med_from_confed_peer_enabled is not None:
                                    return True

                                if self.is_bestpath_compare_router_id_for_ebgp_peers_enabled is not None:
                                    return True

                                if self.is_bestpath_ignore_as_path_enabled is not None:
                                    return True

                                if self.is_bestpath_missing_med_is_worst_enabled is not None:
                                    return True

                                if self.is_default_metric_configured is not None:
                                    return True

                                if self.is_default_originate_configured is not None:
                                    return True

                                if self.is_enforce_first_as_enabled is not None:
                                    return True

                                if self.is_fast_external_fallover_enabled is not None:
                                    return True

                                if self.is_graceful_restart is not None:
                                    return True

                                if self.is_multipath_as_path_ignore_onwards_enabled is not None:
                                    return True

                                if self.is_neighbor_logging is not None:
                                    return True

                                if self.is_nsr is not None:
                                    return True

                                if self.is_redistribute_ibgp_to_ig_ps_enabled is not None:
                                    return True

                                if self.keep_alive_time is not None:
                                    return True

                                if self.min_acceptable_hold_time is not None:
                                    return True

                                if self.restart_time is not None:
                                    return True

                                if self.rib_purge_timeout is not None:
                                    return True

                                if self.route_distinguisher is not None:
                                    return True

                                if self.router_id is not None:
                                    return True

                                if self.stale_path_time is not None:
                                    return True

                                if self.vrf_is_active is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Vrf']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:global-process-info'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.global_ is not None and self.global_._has_data():
                                return True

                            if self.vrf is not None and self.vrf._has_data():
                                return True

                            if self.vrf_name is not None:
                                return True

                            if self.vrfid is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo']['meta_info']


                    class UpdateInboundErrorNeighbors(object):
                        """
                        Update inbound error information for all
                        neighbors
                        
                        .. attribute:: update_inbound_error_neighbor
                        
                        	Update inbound error information for neighbor
                        	**type**\: list of    :py:class:`UpdateInboundErrorNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.update_inbound_error_neighbor = YList()
                            self.update_inbound_error_neighbor.parent = self
                            self.update_inbound_error_neighbor.name = 'update_inbound_error_neighbor'


                        class UpdateInboundErrorNeighbor(object):
                            """
                            Update inbound error information for neighbor
                            
                            .. attribute:: neighbor_address  <key>
                            
                            	Neighbor address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: establishment_action_count
                            
                            	Number of occurence of each action type since  session establishment
                            	**type**\: list of    :py:class:`EstablishmentActionCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount>`
                            
                            .. attribute:: establishment_total_update_message_count
                            
                            	Total update messages count since session establishment
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: first_update_error_handling_reset_timestamp
                            
                            	First error\-handling reset time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`FirstUpdateErrorHandlingResetTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp>`
                            
                            .. attribute:: first_update_malformed_timestamp
                            
                            	First malformed message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`FirstUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp>`
                            
                            .. attribute:: first_update_memory_allocation_fail_timestamp
                            
                            	First memory allocation failure time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`FirstUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp>`
                            
                            .. attribute:: last_error_handling_reset_age
                            
                            	Time since last error\-handling reset event (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_error_handling_reset_timestamp
                            
                            	Last error\-handling reset time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`LastErrorHandlingResetTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp>`
                            
                            .. attribute:: last_update_malformed_age
                            
                            	Time since last malformed message received event (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_update_malformed_timestamp
                            
                            	Last malformed message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`LastUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp>`
                            
                            .. attribute:: last_update_memory_allocation_fail_age
                            
                            	Time since last memory allocation failure event (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_update_memory_allocation_fail_timestamp
                            
                            	Last memory allocation failure time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp>`
                            
                            .. attribute:: total_update_message_count
                            
                            	Total update messages count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_attribute_discard_count
                            
                            	Discarded attribute count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_error_handling_avoid_reset
                            
                            	Configure error\-handling to avoid resets
                            	**type**\:  bool
                            
                            .. attribute:: update_error_handling_reset_count
                            
                            	Error\-handling reset count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_error_message
                            
                            	List of malformed messages
                            	**type**\: list of    :py:class:`UpdateErrorMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage>`
                            
                            .. attribute:: update_error_message_list_count
                            
                            	Malformed messages list count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_malformed_message_count
                            
                            	Malformed messages count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_memory_allocation_fail_count
                            
                            	Memory allocation failure count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_neighbor_address
                            
                            	Neighbor address
                            	**type**\:   :py:class:`UpdateNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress>`
                            
                            .. attribute:: update_vrf_name
                            
                            	VRF Name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.neighbor_address = None
                                self.establishment_action_count = YList()
                                self.establishment_action_count.parent = self
                                self.establishment_action_count.name = 'establishment_action_count'
                                self.establishment_total_update_message_count = None
                                self.first_update_error_handling_reset_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp()
                                self.first_update_error_handling_reset_timestamp.parent = self
                                self.first_update_malformed_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp()
                                self.first_update_malformed_timestamp.parent = self
                                self.first_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp()
                                self.first_update_memory_allocation_fail_timestamp.parent = self
                                self.last_error_handling_reset_age = None
                                self.last_error_handling_reset_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp()
                                self.last_error_handling_reset_timestamp.parent = self
                                self.last_update_malformed_age = None
                                self.last_update_malformed_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp()
                                self.last_update_malformed_timestamp.parent = self
                                self.last_update_memory_allocation_fail_age = None
                                self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp()
                                self.last_update_memory_allocation_fail_timestamp.parent = self
                                self.total_update_message_count = None
                                self.update_attribute_discard_count = None
                                self.update_error_handling_avoid_reset = None
                                self.update_error_handling_reset_count = None
                                self.update_error_message = YList()
                                self.update_error_message.parent = self
                                self.update_error_message.name = 'update_error_message'
                                self.update_error_message_list_count = None
                                self.update_malformed_message_count = None
                                self.update_memory_allocation_fail_count = None
                                self.update_neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress()
                                self.update_neighbor_address.parent = self
                                self.update_vrf_name = None


                            class UpdateNeighborAddress(object):
                                """
                                Neighbor address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpnvpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnvplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4mdt_address = None
                                    self.ipv4mvpn_address = None
                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress()
                                    self.ipv4sr_policy_address.parent = self
                                    self.ipv4vpn_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress()
                                    self.ipv6sr_policy_address.parent = self
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_flowspec_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.l2vpn_evpn_address = None
                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnvplsAddress()
                                    self.l2vpnvpls_address.parent = self
                                    self.ls_ls_address = None
                                    self.rt_constraint_address = None


                                class L2VpnvplsAddress(object):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnvplsAddress']['meta_info']


                                class L2VpnMspwAddress(object):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnMspwAddress']['meta_info']


                                class Ipv4SrPolicyAddress(object):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                class Ipv6SrPolicyAddress(object):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv6_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv6_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-neighbor-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.afi is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv4_flowspec_address is not None:
                                        return True

                                    if self.ipv4_label_address is not None:
                                        return True

                                    if self.ipv4_mcast_address is not None:
                                        return True

                                    if self.ipv4_tunnel_address is not None:
                                        return True

                                    if self.ipv4mdt_address is not None:
                                        return True

                                    if self.ipv4mvpn_address is not None:
                                        return True

                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                        return True

                                    if self.ipv4vpn_address is not None:
                                        return True

                                    if self.ipv4vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv4vpna_mcastddress is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    if self.ipv6_flowspec_address is not None:
                                        return True

                                    if self.ipv6_label_address is not None:
                                        return True

                                    if self.ipv6_mcast_address is not None:
                                        return True

                                    if self.ipv6mvpn_address is not None:
                                        return True

                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                        return True

                                    if self.ipv6vpn_address is not None:
                                        return True

                                    if self.ipv6vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv6vpn_mcast_address is not None:
                                        return True

                                    if self.l2vpn_evpn_address is not None:
                                        return True

                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                        return True

                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                        return True

                                    if self.ls_ls_address is not None:
                                        return True

                                    if self.rt_constraint_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress']['meta_info']


                            class FirstUpdateMalformedTimestamp(object):
                                """
                                First malformed message received time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.nanoseconds = None
                                    self.seconds = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-update-malformed-timestamp'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.nanoseconds is not None:
                                        return True

                                    if self.seconds is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp']['meta_info']


                            class LastUpdateMalformedTimestamp(object):
                                """
                                Last malformed message received time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.nanoseconds = None
                                    self.seconds = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-malformed-timestamp'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.nanoseconds is not None:
                                        return True

                                    if self.seconds is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp']['meta_info']


                            class FirstUpdateMemoryAllocationFailTimestamp(object):
                                """
                                First memory allocation failure time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.nanoseconds = None
                                    self.seconds = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-update-memory-allocation-fail-timestamp'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.nanoseconds is not None:
                                        return True

                                    if self.seconds is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp']['meta_info']


                            class LastUpdateMemoryAllocationFailTimestamp(object):
                                """
                                Last memory allocation failure time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.nanoseconds = None
                                    self.seconds = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-memory-allocation-fail-timestamp'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.nanoseconds is not None:
                                        return True

                                    if self.seconds is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp']['meta_info']


                            class FirstUpdateErrorHandlingResetTimestamp(object):
                                """
                                First error\-handling reset time\: time elapsed
                                since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.nanoseconds = None
                                    self.seconds = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-update-error-handling-reset-timestamp'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.nanoseconds is not None:
                                        return True

                                    if self.seconds is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp']['meta_info']


                            class LastErrorHandlingResetTimestamp(object):
                                """
                                Last error\-handling reset time\: time elapsed
                                since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.nanoseconds = None
                                    self.seconds = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-error-handling-reset-timestamp'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.nanoseconds is not None:
                                        return True

                                    if self.seconds is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp']['meta_info']


                            class EstablishmentActionCount(object):
                                """
                                Number of occurence of each action type since
                                
                                session establishment
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.entry = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:establishment-action-count'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.entry is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount']['meta_info']


                            class UpdateErrorMessage(object):
                                """
                                List of malformed messages
                                
                                .. attribute:: update_attribute_discard_count
                                
                                	Discarded attribute count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_error_element
                                
                                	Error element list
                                	**type**\: list of    :py:class:`UpdateErrorElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement>`
                                
                                .. attribute:: update_error_final_action
                                
                                	Error final action
                                	**type**\:   :py:class:`BgpBagUpdErrActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdErrActionEnum>`
                                
                                .. attribute:: update_error_nlri_address_family
                                
                                	NLRI address\-family
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: update_error_nlri_string
                                
                                	List of NLRIs in string format
                                	**type**\:  str
                                
                                .. attribute:: update_error_nlri_string_truncated
                                
                                	Indicates whether NLRI string was truncated due to lack of space
                                	**type**\:  bool
                                
                                .. attribute:: update_message_data
                                
                                	Raw Message data in binary format
                                	**type**\: list of    :py:class:`UpdateMessageData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData>`
                                
                                .. attribute:: update_message_reset_data
                                
                                	Reset data
                                	**type**\:   :py:class:`UpdateMessageResetData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData>`
                                
                                .. attribute:: update_message_timestamp
                                
                                	Message timestamp\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`UpdateMessageTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.update_attribute_discard_count = None
                                    self.update_error_element = YList()
                                    self.update_error_element.parent = self
                                    self.update_error_element.name = 'update_error_element'
                                    self.update_error_final_action = None
                                    self.update_error_nlri_address_family = None
                                    self.update_error_nlri_string = None
                                    self.update_error_nlri_string_truncated = None
                                    self.update_message_data = YList()
                                    self.update_message_data.parent = self
                                    self.update_message_data.name = 'update_message_data'
                                    self.update_message_reset_data = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData()
                                    self.update_message_reset_data.parent = self
                                    self.update_message_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp()
                                    self.update_message_timestamp.parent = self


                                class UpdateMessageTimestamp(object):
                                    """
                                    Message timestamp\: time elapsed since 00\:00\:00
                                    UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-message-timestamp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp']['meta_info']


                                class UpdateMessageResetData(object):
                                    """
                                    Reset data
                                    
                                    .. attribute:: update_error_reset_notification_code
                                    
                                    	Notification code
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_error_reset_notification_data
                                    
                                    	Notification data
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: update_error_reset_notification_data_length
                                    
                                    	Notification data length
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: update_error_reset_notification_sub_code
                                    
                                    	Notification sub code
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: update_error_reset_reason
                                    
                                    	Reset Reason
                                    	**type**\:   :py:class:`BgpResetReasonIndexEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndexEnum>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.update_error_reset_notification_code = None
                                        self.update_error_reset_notification_data = None
                                        self.update_error_reset_notification_data_length = None
                                        self.update_error_reset_notification_sub_code = None
                                        self.update_error_reset_reason = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-message-reset-data'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.update_error_reset_notification_code is not None:
                                            return True

                                        if self.update_error_reset_notification_data is not None:
                                            return True

                                        if self.update_error_reset_notification_data_length is not None:
                                            return True

                                        if self.update_error_reset_notification_sub_code is not None:
                                            return True

                                        if self.update_error_reset_reason is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData']['meta_info']


                                class UpdateMessageData(object):
                                    """
                                    Raw Message data in binary format
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-message-data'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData']['meta_info']


                                class UpdateErrorElement(object):
                                    """
                                    Error element list
                                    
                                    .. attribute:: update_attribute_code
                                    
                                    	Attribute code [RFC4271\: BGP4]
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_attribute_flags
                                    
                                    	Attribute Flags [RFC4271\: BGP4]
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_attribute_length
                                    
                                    	Attribute Length [RFC4271\: BGP4]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: update_error_action
                                    
                                    	Error action
                                    	**type**\:   :py:class:`BgpBagUpdErrActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdErrActionEnum>`
                                    
                                    .. attribute:: update_error_data
                                    
                                    	Error data
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: update_error_data_length
                                    
                                    	Error data length
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.update_attribute_code = None
                                        self.update_attribute_flags = None
                                        self.update_attribute_length = None
                                        self.update_error_action = None
                                        self.update_error_data = None
                                        self.update_error_data_length = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-error-element'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.update_attribute_code is not None:
                                            return True

                                        if self.update_attribute_flags is not None:
                                            return True

                                        if self.update_attribute_length is not None:
                                            return True

                                        if self.update_error_action is not None:
                                            return True

                                        if self.update_error_data is not None:
                                            return True

                                        if self.update_error_data_length is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-error-message'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.update_attribute_discard_count is not None:
                                        return True

                                    if self.update_error_element is not None:
                                        for child_ref in self.update_error_element:
                                            if child_ref._has_data():
                                                return True

                                    if self.update_error_final_action is not None:
                                        return True

                                    if self.update_error_nlri_address_family is not None:
                                        return True

                                    if self.update_error_nlri_string is not None:
                                        return True

                                    if self.update_error_nlri_string_truncated is not None:
                                        return True

                                    if self.update_message_data is not None:
                                        for child_ref in self.update_message_data:
                                            if child_ref._has_data():
                                                return True

                                    if self.update_message_reset_data is not None and self.update_message_reset_data._has_data():
                                        return True

                                    if self.update_message_timestamp is not None and self.update_message_timestamp._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.neighbor_address is None:
                                    raise YPYModelError('Key property neighbor_address is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-inbound-error-neighbor[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address = ' + str(self.neighbor_address) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.neighbor_address is not None:
                                    return True

                                if self.establishment_action_count is not None:
                                    for child_ref in self.establishment_action_count:
                                        if child_ref._has_data():
                                            return True

                                if self.establishment_total_update_message_count is not None:
                                    return True

                                if self.first_update_error_handling_reset_timestamp is not None and self.first_update_error_handling_reset_timestamp._has_data():
                                    return True

                                if self.first_update_malformed_timestamp is not None and self.first_update_malformed_timestamp._has_data():
                                    return True

                                if self.first_update_memory_allocation_fail_timestamp is not None and self.first_update_memory_allocation_fail_timestamp._has_data():
                                    return True

                                if self.last_error_handling_reset_age is not None:
                                    return True

                                if self.last_error_handling_reset_timestamp is not None and self.last_error_handling_reset_timestamp._has_data():
                                    return True

                                if self.last_update_malformed_age is not None:
                                    return True

                                if self.last_update_malformed_timestamp is not None and self.last_update_malformed_timestamp._has_data():
                                    return True

                                if self.last_update_memory_allocation_fail_age is not None:
                                    return True

                                if self.last_update_memory_allocation_fail_timestamp is not None and self.last_update_memory_allocation_fail_timestamp._has_data():
                                    return True

                                if self.total_update_message_count is not None:
                                    return True

                                if self.update_attribute_discard_count is not None:
                                    return True

                                if self.update_error_handling_avoid_reset is not None:
                                    return True

                                if self.update_error_handling_reset_count is not None:
                                    return True

                                if self.update_error_message is not None:
                                    for child_ref in self.update_error_message:
                                        if child_ref._has_data():
                                            return True

                                if self.update_error_message_list_count is not None:
                                    return True

                                if self.update_malformed_message_count is not None:
                                    return True

                                if self.update_memory_allocation_fail_count is not None:
                                    return True

                                if self.update_neighbor_address is not None and self.update_neighbor_address._has_data():
                                    return True

                                if self.update_vrf_name is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-inbound-error-neighbors'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.update_inbound_error_neighbor is not None:
                                for child_ref in self.update_inbound_error_neighbor:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors']['meta_info']


                    class UpdateInboundFilterNeighbors(object):
                        """
                        Update inbound filtering information for all
                        neighbors
                        
                        .. attribute:: update_inbound_filter_neighbor
                        
                        	Update inbound filtering information for neighbor
                        	**type**\: list of    :py:class:`UpdateInboundFilterNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.update_inbound_filter_neighbor = YList()
                            self.update_inbound_filter_neighbor.parent = self
                            self.update_inbound_filter_neighbor.name = 'update_inbound_filter_neighbor'


                        class UpdateInboundFilterNeighbor(object):
                            """
                            Update inbound filtering information for
                            neighbor
                            
                            .. attribute:: neighbor_address  <key>
                            
                            	Neighbor address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: configured_update_filter_message_buffer_count
                            
                            	Configured Filtered message buffer count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: establishment_total_filter_update_message_count
                            
                            	Total update messages count since session establishment
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: establishment_update_filtered_message_count
                            
                            	Filtered messages count since session establishment
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: first_update_filtered_timestamp
                            
                            	First filtered message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`FirstUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp>`
                            
                            .. attribute:: last_update_filtered_age
                            
                            	Time since last filtered message received event (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_update_filtered_timestamp
                            
                            	Last filtered message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`LastUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp>`
                            
                            .. attribute:: message_update_attribute_filtering_enabled
                            
                            	Attribute filtering is enabled for the current message being parsed
                            	**type**\:  bool
                            
                            .. attribute:: operational_update_attribute_filtering_enabled
                            
                            	Attribute filtering is enabled
                            	**type**\:  bool
                            
                            .. attribute:: operational_update_filter_message_buffer_count
                            
                            	Operational Filtered messages buffer count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total_filter_update_message_count
                            
                            	Total update messages count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_attribute_filter_attributes
                            
                            	List of attributes that can be filtered
                            	**type**\: list of    :py:class:`UpdateAttributeFilterAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes>`
                            
                            .. attribute:: update_attribute_filter_group_name
                            
                            	Update attribute\-filter group name
                            	**type**\:  str
                            
                            .. attribute:: update_filter_logging_enabled
                            
                            	Logging is enabled
                            	**type**\:  bool
                            
                            .. attribute:: update_filter_message
                            
                            	List of filtered messages
                            	**type**\: list of    :py:class:`UpdateFilterMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage>`
                            
                            .. attribute:: update_filter_message_buffer_circular
                            
                            	Indicates if the message buffers are circular
                            	**type**\:  bool
                            
                            .. attribute:: update_filter_message_list_count
                            
                            	Filtered messages list count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_filtered_message_count
                            
                            	Filtered messages count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_neighbor_address
                            
                            	Neighbor address
                            	**type**\:   :py:class:`UpdateNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress>`
                            
                            .. attribute:: update_vrf_name
                            
                            	VRF Name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.neighbor_address = None
                                self.configured_update_filter_message_buffer_count = None
                                self.establishment_total_filter_update_message_count = None
                                self.establishment_update_filtered_message_count = None
                                self.first_update_filtered_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp()
                                self.first_update_filtered_timestamp.parent = self
                                self.last_update_filtered_age = None
                                self.last_update_filtered_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp()
                                self.last_update_filtered_timestamp.parent = self
                                self.message_update_attribute_filtering_enabled = None
                                self.operational_update_attribute_filtering_enabled = None
                                self.operational_update_filter_message_buffer_count = None
                                self.total_filter_update_message_count = None
                                self.update_attribute_filter_attributes = YList()
                                self.update_attribute_filter_attributes.parent = self
                                self.update_attribute_filter_attributes.name = 'update_attribute_filter_attributes'
                                self.update_attribute_filter_group_name = None
                                self.update_filter_logging_enabled = None
                                self.update_filter_message = YList()
                                self.update_filter_message.parent = self
                                self.update_filter_message.name = 'update_filter_message'
                                self.update_filter_message_buffer_circular = None
                                self.update_filter_message_list_count = None
                                self.update_filtered_message_count = None
                                self.update_neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress()
                                self.update_neighbor_address.parent = self
                                self.update_vrf_name = None


                            class UpdateNeighborAddress(object):
                                """
                                Neighbor address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpnvpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnvplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4mdt_address = None
                                    self.ipv4mvpn_address = None
                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress()
                                    self.ipv4sr_policy_address.parent = self
                                    self.ipv4vpn_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress()
                                    self.ipv6sr_policy_address.parent = self
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_flowspec_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.l2vpn_evpn_address = None
                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnvplsAddress()
                                    self.l2vpnvpls_address.parent = self
                                    self.ls_ls_address = None
                                    self.rt_constraint_address = None


                                class L2VpnvplsAddress(object):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnvplsAddress']['meta_info']


                                class L2VpnMspwAddress(object):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnMspwAddress']['meta_info']


                                class Ipv4SrPolicyAddress(object):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                class Ipv6SrPolicyAddress(object):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv6_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv6_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-neighbor-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.afi is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv4_flowspec_address is not None:
                                        return True

                                    if self.ipv4_label_address is not None:
                                        return True

                                    if self.ipv4_mcast_address is not None:
                                        return True

                                    if self.ipv4_tunnel_address is not None:
                                        return True

                                    if self.ipv4mdt_address is not None:
                                        return True

                                    if self.ipv4mvpn_address is not None:
                                        return True

                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                        return True

                                    if self.ipv4vpn_address is not None:
                                        return True

                                    if self.ipv4vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv4vpna_mcastddress is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    if self.ipv6_flowspec_address is not None:
                                        return True

                                    if self.ipv6_label_address is not None:
                                        return True

                                    if self.ipv6_mcast_address is not None:
                                        return True

                                    if self.ipv6mvpn_address is not None:
                                        return True

                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                        return True

                                    if self.ipv6vpn_address is not None:
                                        return True

                                    if self.ipv6vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv6vpn_mcast_address is not None:
                                        return True

                                    if self.l2vpn_evpn_address is not None:
                                        return True

                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                        return True

                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                        return True

                                    if self.ls_ls_address is not None:
                                        return True

                                    if self.rt_constraint_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress']['meta_info']


                            class FirstUpdateFilteredTimestamp(object):
                                """
                                First filtered message received time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.nanoseconds = None
                                    self.seconds = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-update-filtered-timestamp'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.nanoseconds is not None:
                                        return True

                                    if self.seconds is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp']['meta_info']


                            class LastUpdateFilteredTimestamp(object):
                                """
                                Last filtered message received time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.nanoseconds = None
                                    self.seconds = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-filtered-timestamp'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.nanoseconds is not None:
                                        return True

                                    if self.seconds is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp']['meta_info']


                            class UpdateAttributeFilterAttributes(object):
                                """
                                List of attributes that can be filtered
                                
                                .. attribute:: establishment_update_filter_match_count
                                
                                	Filter match counter since last session establishment
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_update_filter_match_age
                                
                                	Time since this attribute was last filtered (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_update_filter_match_timestamp
                                
                                	Last attribute filtered time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`LastUpdateFilterMatchTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp>`
                                
                                .. attribute:: update_filter_action
                                
                                	Filtering action
                                	**type**\:   :py:class:`BgpBagUpdFilterActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterActionEnum>`
                                
                                .. attribute:: update_filter_match_count
                                
                                	Filter match counter
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_internal_attribute_code
                                
                                	Internal attribute code [RFC4271\: BGP4]
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.establishment_update_filter_match_count = None
                                    self.last_update_filter_match_age = None
                                    self.last_update_filter_match_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp()
                                    self.last_update_filter_match_timestamp.parent = self
                                    self.update_filter_action = None
                                    self.update_filter_match_count = None
                                    self.update_internal_attribute_code = None


                                class LastUpdateFilterMatchTimestamp(object):
                                    """
                                    Last attribute filtered time\: time elapsed since
                                    00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-filter-match-timestamp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-attribute-filter-attributes'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.establishment_update_filter_match_count is not None:
                                        return True

                                    if self.last_update_filter_match_age is not None:
                                        return True

                                    if self.last_update_filter_match_timestamp is not None and self.last_update_filter_match_timestamp._has_data():
                                        return True

                                    if self.update_filter_action is not None:
                                        return True

                                    if self.update_filter_match_count is not None:
                                        return True

                                    if self.update_internal_attribute_code is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes']['meta_info']


                            class UpdateFilterMessage(object):
                                """
                                List of filtered messages
                                
                                .. attribute:: update_filter_element
                                
                                	Filtering element list
                                	**type**\: list of    :py:class:`UpdateFilterElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement>`
                                
                                .. attribute:: update_filter_final_action
                                
                                	Filtering final action
                                	**type**\:   :py:class:`BgpBagUpdFilterActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterActionEnum>`
                                
                                .. attribute:: update_filter_message_data
                                
                                	Raw Message data in binary format
                                	**type**\: list of    :py:class:`UpdateFilterMessageData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData>`
                                
                                .. attribute:: update_filter_message_timestamp
                                
                                	Message timestamp\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`UpdateFilterMessageTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp>`
                                
                                .. attribute:: update_filter_nlri_address_family
                                
                                	NLRI address\-family
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: update_filter_nlri_string
                                
                                	List of NLRIs in string format
                                	**type**\:  str
                                
                                .. attribute:: update_filter_nlri_string_truncated
                                
                                	Indicates whether NLRI string was truncated due to lack of space
                                	**type**\:  bool
                                
                                .. attribute:: update_filtered_attribute_count
                                
                                	Filtered attributes count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.update_filter_element = YList()
                                    self.update_filter_element.parent = self
                                    self.update_filter_element.name = 'update_filter_element'
                                    self.update_filter_final_action = None
                                    self.update_filter_message_data = YList()
                                    self.update_filter_message_data.parent = self
                                    self.update_filter_message_data.name = 'update_filter_message_data'
                                    self.update_filter_message_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp()
                                    self.update_filter_message_timestamp.parent = self
                                    self.update_filter_nlri_address_family = None
                                    self.update_filter_nlri_string = None
                                    self.update_filter_nlri_string_truncated = None
                                    self.update_filtered_attribute_count = None


                                class UpdateFilterMessageTimestamp(object):
                                    """
                                    Message timestamp\: time elapsed since 00\:00\:00
                                    UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-filter-message-timestamp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp']['meta_info']


                                class UpdateFilterMessageData(object):
                                    """
                                    Raw Message data in binary format
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-filter-message-data'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData']['meta_info']


                                class UpdateFilterElement(object):
                                    """
                                    Filtering element list
                                    
                                    .. attribute:: update_attribute_code
                                    
                                    	Attribute code [RFC4271\: BGP4]
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_attribute_flags
                                    
                                    	Attribute Flags [RFC4271\: BGP4]
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_filter_action
                                    
                                    	Filtering action
                                    	**type**\:   :py:class:`BgpBagUpdFilterActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterActionEnum>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.update_attribute_code = None
                                        self.update_attribute_flags = None
                                        self.update_filter_action = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-filter-element'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.update_attribute_code is not None:
                                            return True

                                        if self.update_attribute_flags is not None:
                                            return True

                                        if self.update_filter_action is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-filter-message'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.update_filter_element is not None:
                                        for child_ref in self.update_filter_element:
                                            if child_ref._has_data():
                                                return True

                                    if self.update_filter_final_action is not None:
                                        return True

                                    if self.update_filter_message_data is not None:
                                        for child_ref in self.update_filter_message_data:
                                            if child_ref._has_data():
                                                return True

                                    if self.update_filter_message_timestamp is not None and self.update_filter_message_timestamp._has_data():
                                        return True

                                    if self.update_filter_nlri_address_family is not None:
                                        return True

                                    if self.update_filter_nlri_string is not None:
                                        return True

                                    if self.update_filter_nlri_string_truncated is not None:
                                        return True

                                    if self.update_filtered_attribute_count is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.neighbor_address is None:
                                    raise YPYModelError('Key property neighbor_address is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-inbound-filter-neighbor[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address = ' + str(self.neighbor_address) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.neighbor_address is not None:
                                    return True

                                if self.configured_update_filter_message_buffer_count is not None:
                                    return True

                                if self.establishment_total_filter_update_message_count is not None:
                                    return True

                                if self.establishment_update_filtered_message_count is not None:
                                    return True

                                if self.first_update_filtered_timestamp is not None and self.first_update_filtered_timestamp._has_data():
                                    return True

                                if self.last_update_filtered_age is not None:
                                    return True

                                if self.last_update_filtered_timestamp is not None and self.last_update_filtered_timestamp._has_data():
                                    return True

                                if self.message_update_attribute_filtering_enabled is not None:
                                    return True

                                if self.operational_update_attribute_filtering_enabled is not None:
                                    return True

                                if self.operational_update_filter_message_buffer_count is not None:
                                    return True

                                if self.total_filter_update_message_count is not None:
                                    return True

                                if self.update_attribute_filter_attributes is not None:
                                    for child_ref in self.update_attribute_filter_attributes:
                                        if child_ref._has_data():
                                            return True

                                if self.update_attribute_filter_group_name is not None:
                                    return True

                                if self.update_filter_logging_enabled is not None:
                                    return True

                                if self.update_filter_message is not None:
                                    for child_ref in self.update_filter_message:
                                        if child_ref._has_data():
                                            return True

                                if self.update_filter_message_buffer_circular is not None:
                                    return True

                                if self.update_filter_message_list_count is not None:
                                    return True

                                if self.update_filtered_message_count is not None:
                                    return True

                                if self.update_neighbor_address is not None and self.update_neighbor_address._has_data():
                                    return True

                                if self.update_vrf_name is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-inbound-filter-neighbors'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.update_inbound_filter_neighbor is not None:
                                for child_ref in self.update_inbound_filter_neighbor:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors']['meta_info']


                    class Bmp(object):
                        """
                        BMP related Operational Data
                        
                        .. attribute:: server_neighbors
                        
                        	Table of Neighbors for a BMP Server
                        	**type**\:   :py:class:`ServerNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors>`
                        
                        .. attribute:: server_summaries
                        
                        	Table of BMP Servers
                        	**type**\:   :py:class:`ServerSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.server_neighbors = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors()
                            self.server_neighbors.parent = self
                            self.server_summaries = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries()
                            self.server_summaries.parent = self


                        class ServerSummaries(object):
                            """
                            Table of BMP Servers
                            
                            .. attribute:: server_summary
                            
                            	Summary Information about BMP server
                            	**type**\: list of    :py:class:`ServerSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.server_summary = YList()
                                self.server_summary.parent = self
                                self.server_summary.name = 'server_summary'


                            class ServerSummary(object):
                                """
                                Summary Information about BMP server
                                
                                .. attribute:: server_id  <key>
                                
                                	BMP Server ID
                                	**type**\:  int
                                
                                	**range:** 1..8
                                
                                .. attribute:: bmp_bytes_written_tcp
                                
                                	Total bytes sent to TCP
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: bmp_init_msg_count
                                
                                	Number of Initiation Msgs sent by this BMP Server
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_messages_wdraw_discarded
                                
                                	Total bmpQ wdraw msgs discarded because of peer down
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_peer_msg_drop_count
                                
                                	Total number of messages dropped
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_peer_msg_pending_count
                                
                                	Total number of bmpQ msgs pending
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_peer_msg_pending_count_hwts
                                
                                	Total bmpQ msgs pending max time
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmp_peer_msg_pending_count_max
                                
                                	Total bmpQ msgs pending max
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_per_peer_msg_count
                                
                                	Total number of per peer messages sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_per_peer_msg_route_mon_count
                                
                                	Total number of per peer route mon messages sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_pfx_wdraw_discarded
                                
                                	Total bmpQ wdraw pfxes discarded because of peer down
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_send_version
                                
                                	Table Version that this BMP server has caught  upto
                                	**type**\: list of    :py:class:`BmpSendVersion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpSendVersion>`
                                
                                .. attribute:: bmp_server_host_name
                                
                                	BMP Server Hostname
                                	**type**\:  str
                                
                                .. attribute:: bmp_server_id
                                
                                	BMP Server ID
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: bmp_server_is_flapping
                                
                                	Connection to the BMP server Flapping
                                	**type**\:  bool
                                
                                .. attribute:: bmp_server_last_discon_time
                                
                                	Timespec of Last Disconnect event received from BMP server
                                	**type**\:   :py:class:`BmpServerLastDisconTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime>`
                                
                                .. attribute:: bmp_server_nbr_count
                                
                                	Neighbor count for the BMP Server
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_server_port
                                
                                	BMP Server Port Number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_server_state
                                
                                	Connection state of the BMP server
                                	**type**\:   :py:class:`BgpBmpStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBmpStateEnum>`
                                
                                .. attribute:: bmp_server_state_age
                                
                                	Age of current state of BMP Server
                                	**type**\:   :py:class:`BmpServerStateAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge>`
                                
                                .. attribute:: bmp_server_state_time_spec
                                
                                	Timespec of current state of BMP Server
                                	**type**\:   :py:class:`BmpServerStateTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec>`
                                
                                .. attribute:: bmp_status_report_count
                                
                                	Number of Status ReportMessages sent by this BMP Server
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_termination_msg_count
                                
                                	Number of Termination Messages sent by this BMP Server
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_update_mode
                                
                                	Update sending mode configured for this BMP server
                                	**type**\:   :py:class:`BgpBmpUpdModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBmpUpdModeEnum>`
                                
                                .. attribute:: bmp_vrf_id
                                
                                	VRF ID for the vrf name configured
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_vrf_name
                                
                                	VRF Name configured
                                	**type**\:  str
                                
                                .. attribute:: bmpq_last_all_write_pulse_sent_time
                                
                                	Last BMPQ write pulse Sent for all BMP servers 
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmpq_last_write_pulse_cb_time
                                
                                	Last BMPQ write pulse callback time
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmpq_last_write_pulse_sent_time
                                
                                	Last BMPQ write pulse Sent time
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmpr_mon_upd_messages
                                
                                	Total bmpQ update msgs 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmpr_mon_update_gen_time
                                
                                	Time spent in update generation(milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: bmpr_mon_wdraw_messages
                                
                                	Total bmpQ withdraw msgs 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_update_count
                                
                                	Number of path update sent 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_update_drop
                                
                                	Number of path update drop 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_withdraw_count
                                
                                	Number of path wdraw sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_withdraw_drop
                                
                                	Number of path wdraw drop 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tcp_keep_alive_interval
                                
                                	TCP Keep alive interval configured
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tcp_last_write_cb_time
                                
                                	Last TCP Write CB time
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: tcp_last_write_result
                                
                                	Last TCP Socket write status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tcp_last_write_time
                                
                                	Last TCP Write time
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: tcp_maximum_segment_size
                                
                                	TCP Maximum Segments size configured
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tcp_write_cb_pending
                                
                                	Are we waiting for TCP write callback ?
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tcp_write_time
                                
                                	Time spent processing sending msg to TCP(milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: tos_type
                                
                                	Precedence (0) or DSCP (1) type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_value
                                
                                	Precedence or DSCP value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: update_source_address
                                
                                	Address of Interface configured as Update Source
                                	**type**\:   :py:class:`UpdateSourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress>`
                                
                                .. attribute:: update_source_interface_name
                                
                                	Interface configured as Update Source
                                	**type**\:  str
                                
                                .. attribute:: update_source_vrf_id
                                
                                	VRF ID of interface configured as Update Source
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.server_id = None
                                    self.bmp_bytes_written_tcp = None
                                    self.bmp_init_msg_count = None
                                    self.bmp_messages_wdraw_discarded = None
                                    self.bmp_peer_msg_drop_count = None
                                    self.bmp_peer_msg_pending_count = None
                                    self.bmp_peer_msg_pending_count_hwts = None
                                    self.bmp_peer_msg_pending_count_max = None
                                    self.bmp_per_peer_msg_count = None
                                    self.bmp_per_peer_msg_route_mon_count = None
                                    self.bmp_pfx_wdraw_discarded = None
                                    self.bmp_send_version = YList()
                                    self.bmp_send_version.parent = self
                                    self.bmp_send_version.name = 'bmp_send_version'
                                    self.bmp_server_host_name = None
                                    self.bmp_server_id = None
                                    self.bmp_server_is_flapping = None
                                    self.bmp_server_last_discon_time = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime()
                                    self.bmp_server_last_discon_time.parent = self
                                    self.bmp_server_nbr_count = None
                                    self.bmp_server_port = None
                                    self.bmp_server_state = None
                                    self.bmp_server_state_age = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge()
                                    self.bmp_server_state_age.parent = self
                                    self.bmp_server_state_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec()
                                    self.bmp_server_state_time_spec.parent = self
                                    self.bmp_status_report_count = None
                                    self.bmp_termination_msg_count = None
                                    self.bmp_update_mode = None
                                    self.bmp_vrf_id = None
                                    self.bmp_vrf_name = None
                                    self.bmpq_last_all_write_pulse_sent_time = None
                                    self.bmpq_last_write_pulse_cb_time = None
                                    self.bmpq_last_write_pulse_sent_time = None
                                    self.bmpr_mon_upd_messages = None
                                    self.bmpr_mon_update_gen_time = None
                                    self.bmpr_mon_wdraw_messages = None
                                    self.path_update_count = None
                                    self.path_update_drop = None
                                    self.path_withdraw_count = None
                                    self.path_withdraw_drop = None
                                    self.tcp_keep_alive_interval = None
                                    self.tcp_last_write_cb_time = None
                                    self.tcp_last_write_result = None
                                    self.tcp_last_write_time = None
                                    self.tcp_maximum_segment_size = None
                                    self.tcp_write_cb_pending = None
                                    self.tcp_write_time = None
                                    self.tos_type = None
                                    self.tos_value = None
                                    self.update_source_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress()
                                    self.update_source_address.parent = self
                                    self.update_source_interface_name = None
                                    self.update_source_vrf_id = None


                                class BmpServerStateAge(object):
                                    """
                                    Age of current state of BMP Server
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-server-state-age'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge']['meta_info']


                                class BmpServerStateTimeSpec(object):
                                    """
                                    Timespec of current state of BMP Server
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-server-state-time-spec'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec']['meta_info']


                                class BmpServerLastDisconTime(object):
                                    """
                                    Timespec of Last Disconnect event received from
                                    BMP server
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-server-last-discon-time'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime']['meta_info']


                                class UpdateSourceAddress(object):
                                    """
                                    Address of Interface configured as Update Source
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpnvpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnvplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4mdt_address = None
                                        self.ipv4mvpn_address = None
                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress()
                                        self.ipv4sr_policy_address.parent = self
                                        self.ipv4vpn_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress()
                                        self.ipv6sr_policy_address.parent = self
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_flowspec_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.l2vpn_evpn_address = None
                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnvplsAddress()
                                        self.l2vpnvpls_address.parent = self
                                        self.ls_ls_address = None
                                        self.rt_constraint_address = None


                                    class L2VpnvplsAddress(object):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnvplsAddress']['meta_info']


                                    class L2VpnMspwAddress(object):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnMspwAddress']['meta_info']


                                    class Ipv4SrPolicyAddress(object):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress']['meta_info']


                                    class Ipv6SrPolicyAddress(object):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv6_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv6_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-source-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.afi is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv4_flowspec_address is not None:
                                            return True

                                        if self.ipv4_label_address is not None:
                                            return True

                                        if self.ipv4_mcast_address is not None:
                                            return True

                                        if self.ipv4_tunnel_address is not None:
                                            return True

                                        if self.ipv4mdt_address is not None:
                                            return True

                                        if self.ipv4mvpn_address is not None:
                                            return True

                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                            return True

                                        if self.ipv4vpn_address is not None:
                                            return True

                                        if self.ipv4vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv4vpna_mcastddress is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        if self.ipv6_flowspec_address is not None:
                                            return True

                                        if self.ipv6_label_address is not None:
                                            return True

                                        if self.ipv6_mcast_address is not None:
                                            return True

                                        if self.ipv6mvpn_address is not None:
                                            return True

                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                            return True

                                        if self.ipv6vpn_address is not None:
                                            return True

                                        if self.ipv6vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv6vpn_mcast_address is not None:
                                            return True

                                        if self.l2vpn_evpn_address is not None:
                                            return True

                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                            return True

                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                            return True

                                        if self.ls_ls_address is not None:
                                            return True

                                        if self.rt_constraint_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress']['meta_info']


                                class BmpSendVersion(object):
                                    """
                                    Table Version that this BMP server has caught
                                    
                                    upto
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-send-version'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpSendVersion']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.server_id is None:
                                        raise YPYModelError('Key property server_id is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:server-summary[Cisco-IOS-XR-ipv4-bgp-oper:server-id = ' + str(self.server_id) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.server_id is not None:
                                        return True

                                    if self.bmp_bytes_written_tcp is not None:
                                        return True

                                    if self.bmp_init_msg_count is not None:
                                        return True

                                    if self.bmp_messages_wdraw_discarded is not None:
                                        return True

                                    if self.bmp_peer_msg_drop_count is not None:
                                        return True

                                    if self.bmp_peer_msg_pending_count is not None:
                                        return True

                                    if self.bmp_peer_msg_pending_count_hwts is not None:
                                        return True

                                    if self.bmp_peer_msg_pending_count_max is not None:
                                        return True

                                    if self.bmp_per_peer_msg_count is not None:
                                        return True

                                    if self.bmp_per_peer_msg_route_mon_count is not None:
                                        return True

                                    if self.bmp_pfx_wdraw_discarded is not None:
                                        return True

                                    if self.bmp_send_version is not None:
                                        for child_ref in self.bmp_send_version:
                                            if child_ref._has_data():
                                                return True

                                    if self.bmp_server_host_name is not None:
                                        return True

                                    if self.bmp_server_id is not None:
                                        return True

                                    if self.bmp_server_is_flapping is not None:
                                        return True

                                    if self.bmp_server_last_discon_time is not None and self.bmp_server_last_discon_time._has_data():
                                        return True

                                    if self.bmp_server_nbr_count is not None:
                                        return True

                                    if self.bmp_server_port is not None:
                                        return True

                                    if self.bmp_server_state is not None:
                                        return True

                                    if self.bmp_server_state_age is not None and self.bmp_server_state_age._has_data():
                                        return True

                                    if self.bmp_server_state_time_spec is not None and self.bmp_server_state_time_spec._has_data():
                                        return True

                                    if self.bmp_status_report_count is not None:
                                        return True

                                    if self.bmp_termination_msg_count is not None:
                                        return True

                                    if self.bmp_update_mode is not None:
                                        return True

                                    if self.bmp_vrf_id is not None:
                                        return True

                                    if self.bmp_vrf_name is not None:
                                        return True

                                    if self.bmpq_last_all_write_pulse_sent_time is not None:
                                        return True

                                    if self.bmpq_last_write_pulse_cb_time is not None:
                                        return True

                                    if self.bmpq_last_write_pulse_sent_time is not None:
                                        return True

                                    if self.bmpr_mon_upd_messages is not None:
                                        return True

                                    if self.bmpr_mon_update_gen_time is not None:
                                        return True

                                    if self.bmpr_mon_wdraw_messages is not None:
                                        return True

                                    if self.path_update_count is not None:
                                        return True

                                    if self.path_update_drop is not None:
                                        return True

                                    if self.path_withdraw_count is not None:
                                        return True

                                    if self.path_withdraw_drop is not None:
                                        return True

                                    if self.tcp_keep_alive_interval is not None:
                                        return True

                                    if self.tcp_last_write_cb_time is not None:
                                        return True

                                    if self.tcp_last_write_result is not None:
                                        return True

                                    if self.tcp_last_write_time is not None:
                                        return True

                                    if self.tcp_maximum_segment_size is not None:
                                        return True

                                    if self.tcp_write_cb_pending is not None:
                                        return True

                                    if self.tcp_write_time is not None:
                                        return True

                                    if self.tos_type is not None:
                                        return True

                                    if self.tos_value is not None:
                                        return True

                                    if self.update_source_address is not None and self.update_source_address._has_data():
                                        return True

                                    if self.update_source_interface_name is not None:
                                        return True

                                    if self.update_source_vrf_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:server-summaries'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.server_summary is not None:
                                    for child_ref in self.server_summary:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries']['meta_info']


                        class ServerNeighbors(object):
                            """
                            Table of Neighbors for a BMP Server
                            
                            .. attribute:: server_neighbor
                            
                            	BMP Server under which neighbor info are needed
                            	**type**\: list of    :py:class:`ServerNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.server_neighbor = YList()
                                self.server_neighbor.parent = self
                                self.server_neighbor.name = 'server_neighbor'


                            class ServerNeighbor(object):
                                """
                                BMP Server under which neighbor info are
                                needed
                                
                                .. attribute:: server_id  <key>
                                
                                	BMP Server ID
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: monitored_neighbors
                                
                                	List of Neighbors under which BMP Server is confgiured
                                	**type**\:   :py:class:`MonitoredNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.server_id = None
                                    self.monitored_neighbors = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors()
                                    self.monitored_neighbors.parent = self


                                class MonitoredNeighbors(object):
                                    """
                                    List of Neighbors under which BMP Server is
                                    confgiured
                                    
                                    .. attribute:: monitored_neighbor
                                    
                                    	Information about a neighbor monitored by BMP server
                                    	**type**\: list of    :py:class:`MonitoredNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.monitored_neighbor = YList()
                                        self.monitored_neighbor.parent = self
                                        self.monitored_neighbor.name = 'monitored_neighbor'


                                    class MonitoredNeighbor(object):
                                        """
                                        Information about a neighbor monitored by
                                        BMP server
                                        
                                        .. attribute:: neighbor_address  <key>
                                        
                                        	Neighbor address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: bmp_neighbor_address
                                        
                                        	Address of Nbr that logs to BMP server
                                        	**type**\:   :py:class:`BmpNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress>`
                                        
                                        .. attribute:: bmp_neighbor_msg_dropped
                                        
                                        	Number of messages dropped sent from this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_msg_pending
                                        
                                        	Number of messages pending to be sent to BMP Server from this Neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_path_update_drop
                                        
                                        	Number of path update drop 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_path_update_sent
                                        
                                        	Number of Path UpdateMessages sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_path_withdraw_drop
                                        
                                        	Number of path wdraw drop 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_path_withdraw_sent
                                        
                                        	Number of Path WithdrawMessages sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_peer_down_sent
                                        
                                        	Number of Peer DOWN Messages sent from this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_peer_up_sent
                                        
                                        	Number of Peer UP Messages sent from this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_route_monitor_sent
                                        
                                        	Number of Route Monitor Messages sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_upd_msg_sent
                                        
                                        	Number of update message sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_wdraw_msg_sent
                                        
                                        	Number of withdraw message sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.neighbor_address = None
                                            self.bmp_neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress()
                                            self.bmp_neighbor_address.parent = self
                                            self.bmp_neighbor_msg_dropped = None
                                            self.bmp_neighbor_msg_pending = None
                                            self.bmp_neighbor_path_update_drop = None
                                            self.bmp_neighbor_path_update_sent = None
                                            self.bmp_neighbor_path_withdraw_drop = None
                                            self.bmp_neighbor_path_withdraw_sent = None
                                            self.bmp_neighbor_peer_down_sent = None
                                            self.bmp_neighbor_peer_up_sent = None
                                            self.bmp_neighbor_route_monitor_sent = None
                                            self.bmp_neighbor_upd_msg_sent = None
                                            self.bmp_neighbor_wdraw_msg_sent = None


                                        class BmpNeighborAddress(object):
                                            """
                                            Address of Nbr that logs to BMP server
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')
                                            if self.neighbor_address is None:
                                                raise YPYModelError('Key property neighbor_address is None')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:monitored-neighbor[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address = ' + str(self.neighbor_address) + ']'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.neighbor_address is not None:
                                                return True

                                            if self.bmp_neighbor_address is not None and self.bmp_neighbor_address._has_data():
                                                return True

                                            if self.bmp_neighbor_msg_dropped is not None:
                                                return True

                                            if self.bmp_neighbor_msg_pending is not None:
                                                return True

                                            if self.bmp_neighbor_path_update_drop is not None:
                                                return True

                                            if self.bmp_neighbor_path_update_sent is not None:
                                                return True

                                            if self.bmp_neighbor_path_withdraw_drop is not None:
                                                return True

                                            if self.bmp_neighbor_path_withdraw_sent is not None:
                                                return True

                                            if self.bmp_neighbor_peer_down_sent is not None:
                                                return True

                                            if self.bmp_neighbor_peer_up_sent is not None:
                                                return True

                                            if self.bmp_neighbor_route_monitor_sent is not None:
                                                return True

                                            if self.bmp_neighbor_upd_msg_sent is not None:
                                                return True

                                            if self.bmp_neighbor_wdraw_msg_sent is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:monitored-neighbors'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.monitored_neighbor is not None:
                                            for child_ref in self.monitored_neighbor:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.server_id is None:
                                        raise YPYModelError('Key property server_id is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:server-neighbor[Cisco-IOS-XR-ipv4-bgp-oper:server-id = ' + str(self.server_id) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.server_id is not None:
                                        return True

                                    if self.monitored_neighbors is not None and self.monitored_neighbors._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:server-neighbors'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.server_neighbor is not None:
                                    for child_ref in self.server_neighbor:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.server_neighbors is not None and self.server_neighbors._has_data():
                                return True

                            if self.server_summaries is not None and self.server_summaries._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp']['meta_info']


                    class ProcessInfo(object):
                        """
                        A Process instance table entry
                        
                        .. attribute:: global_
                        
                        	Global information
                        	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_>`
                        
                        .. attribute:: performance_statistics
                        
                        	Performance statistics
                        	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics>`
                        
                        .. attribute:: process_instance
                        
                        	ID for the BGP process instance
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Vrf>`
                        
                        .. attribute:: vrf_name
                        
                        	Name of the VRF
                        	**type**\:  str
                        
                        .. attribute:: vrf_totals
                        
                        	per VRF counts aggregated across all VRFs
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.global_ = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_()
                            self.global_.parent = self
                            self.performance_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics()
                            self.performance_statistics.parent = self
                            self.process_instance = None
                            self.vrf = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Vrf()
                            self.vrf.parent = self
                            self.vrf_name = None
                            self.vrf_totals = None


                        class Global_(object):
                            """
                            Global information
                            
                            .. attribute:: as_path_entries_memory
                            
                            	Memory (in bytes) used by AS\-path entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: as_path_entry_count
                            
                            	Number of AS\-path entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attr_set_entry_count
                            
                            	Number of ATTRSET entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attr_set_memory
                            
                            	Memory (in bytes) used by ATTRSET entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: bmp_pool_alloc_count
                            
                            	bmp pool alloc count
                            	**type**\: list of    :py:class:`BmpPoolAllocCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.BmpPoolAllocCount>`
                            
                            .. attribute:: bmp_pool_free_count
                            
                            	bmp pool free count
                            	**type**\: list of    :py:class:`BmpPoolFreeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.BmpPoolFreeCount>`
                            
                            .. attribute:: bmp_pool_size
                            
                            	bmp pool size
                            	**type**\: list of    :py:class:`BmpPoolSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.BmpPoolSize>`
                            
                            .. attribute:: community_entry_count
                            
                            	Number of community entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: community_memory
                            
                            	Memory (in bytes) used by community entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: established_neighbors_count_total
                            
                            	Total umber of established neighbors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: extended_community_entry_count
                            
                            	Number of extended community entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: extended_community_memory
                            
                            	Memory (in bytes) used by extended community entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: lindex_entry_count
                            
                            	Number of LINDEX entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lindex_memory
                            
                            	Memory (in bytes) used by LINDEX entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: local_as
                            
                            	Local autonomous system number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsattr_entry_count
                            
                            	Number of LASATTR entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsattr_memory
                            
                            	Memory (in bytes) used by LSATTR entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: msg_log_pool_alloc_count
                            
                            	msg log pool alloc count
                            	**type**\: list of    :py:class:`MsgLogPoolAllocCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.MsgLogPoolAllocCount>`
                            
                            .. attribute:: msg_log_pool_free_count
                            
                            	msg log pool free count
                            	**type**\: list of    :py:class:`MsgLogPoolFreeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.MsgLogPoolFreeCount>`
                            
                            .. attribute:: msg_log_pool_size
                            
                            	msg log pool size
                            	**type**\: list of    :py:class:`MsgLogPoolSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.MsgLogPoolSize>`
                            
                            .. attribute:: neighbors_count_total
                            
                            	Total number of neighbors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nexthop_count
                            
                            	Number of nexthop attribute info entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nexthop_memory
                            
                            	Memory (in bytes) used by nexthop attribute info entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: path_attribute_memory
                            
                            	Memory (bytes) used by path attribute entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: path_attributes_entry_count
                            
                            	No. of path attribute entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pe_distinguisher_label_entry_count
                            
                            	Number of PE distinguisher label entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pe_distinguisher_label_memory
                            
                            	Memory (in bytes) used by PE distinguisher labels entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: pool_alloc_count
                            
                            	pool alloc count
                            	**type**\: list of    :py:class:`PoolAllocCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.PoolAllocCount>`
                            
                            .. attribute:: pool_free_count
                            
                            	pool free count
                            	**type**\: list of    :py:class:`PoolFreeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.PoolFreeCount>`
                            
                            .. attribute:: pool_size
                            
                            	pool size
                            	**type**\: list of    :py:class:`PoolSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.PoolSize>`
                            
                            .. attribute:: ppmp_entry_count
                            
                            	Number of PPMP entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ppmp_memory
                            
                            	Memory (in bytes) used by PPMP entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: process_instance_node
                            
                            	Node the process instance is on
                            	**type**\:  str
                            
                            .. attribute:: pta_entry_count
                            
                            	Number of PTA entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pta_memory
                            
                            	Memory (in bytes) used by PTA entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: restart_count
                            
                            	No. of times BGP has started
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ribrnh_entry_count
                            
                            	Number of RIBRNH entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ribrnh_memory
                            
                            	Memory (in bytes) used by RIBRNH entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: route_reflector_memory
                            
                            	Memory (in bytes) used by route reflector info entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: route_reflectors
                            
                            	Number of route reflector info entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sn_num_non_dflt_vrf_nbrs
                            
                            	sn num non dflt vrf nbrs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sn_num_non_dflt_vrf_nbrs_estab
                            
                            	sn num non dflt vrf nbrs estab
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total_vrf_count
                            
                            	total vrf count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tunnel_encap_entry_count
                            
                            	Number of Tunnel encap entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tunnel_encap_memory
                            
                            	Memory (in bytes) used by tunnel encap entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.as_path_entries_memory = None
                                self.as_path_entry_count = None
                                self.attr_set_entry_count = None
                                self.attr_set_memory = None
                                self.bmp_pool_alloc_count = YList()
                                self.bmp_pool_alloc_count.parent = self
                                self.bmp_pool_alloc_count.name = 'bmp_pool_alloc_count'
                                self.bmp_pool_free_count = YList()
                                self.bmp_pool_free_count.parent = self
                                self.bmp_pool_free_count.name = 'bmp_pool_free_count'
                                self.bmp_pool_size = YList()
                                self.bmp_pool_size.parent = self
                                self.bmp_pool_size.name = 'bmp_pool_size'
                                self.community_entry_count = None
                                self.community_memory = None
                                self.established_neighbors_count_total = None
                                self.extended_community_entry_count = None
                                self.extended_community_memory = None
                                self.lindex_entry_count = None
                                self.lindex_memory = None
                                self.local_as = None
                                self.lsattr_entry_count = None
                                self.lsattr_memory = None
                                self.msg_log_pool_alloc_count = YList()
                                self.msg_log_pool_alloc_count.parent = self
                                self.msg_log_pool_alloc_count.name = 'msg_log_pool_alloc_count'
                                self.msg_log_pool_free_count = YList()
                                self.msg_log_pool_free_count.parent = self
                                self.msg_log_pool_free_count.name = 'msg_log_pool_free_count'
                                self.msg_log_pool_size = YList()
                                self.msg_log_pool_size.parent = self
                                self.msg_log_pool_size.name = 'msg_log_pool_size'
                                self.neighbors_count_total = None
                                self.nexthop_count = None
                                self.nexthop_memory = None
                                self.path_attribute_memory = None
                                self.path_attributes_entry_count = None
                                self.pe_distinguisher_label_entry_count = None
                                self.pe_distinguisher_label_memory = None
                                self.pool_alloc_count = YList()
                                self.pool_alloc_count.parent = self
                                self.pool_alloc_count.name = 'pool_alloc_count'
                                self.pool_free_count = YList()
                                self.pool_free_count.parent = self
                                self.pool_free_count.name = 'pool_free_count'
                                self.pool_size = YList()
                                self.pool_size.parent = self
                                self.pool_size.name = 'pool_size'
                                self.ppmp_entry_count = None
                                self.ppmp_memory = None
                                self.process_instance_node = None
                                self.pta_entry_count = None
                                self.pta_memory = None
                                self.restart_count = None
                                self.ribrnh_entry_count = None
                                self.ribrnh_memory = None
                                self.route_reflector_memory = None
                                self.route_reflectors = None
                                self.sn_num_non_dflt_vrf_nbrs = None
                                self.sn_num_non_dflt_vrf_nbrs_estab = None
                                self.total_vrf_count = None
                                self.tunnel_encap_entry_count = None
                                self.tunnel_encap_memory = None


                            class PoolSize(object):
                                """
                                pool size
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.entry = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pool-size'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.entry is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.PoolSize']['meta_info']


                            class PoolAllocCount(object):
                                """
                                pool alloc count
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.entry = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pool-alloc-count'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.entry is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.PoolAllocCount']['meta_info']


                            class PoolFreeCount(object):
                                """
                                pool free count
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.entry = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pool-free-count'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.entry is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.PoolFreeCount']['meta_info']


                            class MsgLogPoolSize(object):
                                """
                                msg log pool size
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.entry = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:msg-log-pool-size'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.entry is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.MsgLogPoolSize']['meta_info']


                            class MsgLogPoolAllocCount(object):
                                """
                                msg log pool alloc count
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.entry = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:msg-log-pool-alloc-count'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.entry is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.MsgLogPoolAllocCount']['meta_info']


                            class MsgLogPoolFreeCount(object):
                                """
                                msg log pool free count
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.entry = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:msg-log-pool-free-count'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.entry is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.MsgLogPoolFreeCount']['meta_info']


                            class BmpPoolSize(object):
                                """
                                bmp pool size
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.entry = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-pool-size'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.entry is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.BmpPoolSize']['meta_info']


                            class BmpPoolAllocCount(object):
                                """
                                bmp pool alloc count
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.entry = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-pool-alloc-count'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.entry is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.BmpPoolAllocCount']['meta_info']


                            class BmpPoolFreeCount(object):
                                """
                                bmp pool free count
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.entry = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-pool-free-count'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.entry is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_.BmpPoolFreeCount']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:global'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.as_path_entries_memory is not None:
                                    return True

                                if self.as_path_entry_count is not None:
                                    return True

                                if self.attr_set_entry_count is not None:
                                    return True

                                if self.attr_set_memory is not None:
                                    return True

                                if self.bmp_pool_alloc_count is not None:
                                    for child_ref in self.bmp_pool_alloc_count:
                                        if child_ref._has_data():
                                            return True

                                if self.bmp_pool_free_count is not None:
                                    for child_ref in self.bmp_pool_free_count:
                                        if child_ref._has_data():
                                            return True

                                if self.bmp_pool_size is not None:
                                    for child_ref in self.bmp_pool_size:
                                        if child_ref._has_data():
                                            return True

                                if self.community_entry_count is not None:
                                    return True

                                if self.community_memory is not None:
                                    return True

                                if self.established_neighbors_count_total is not None:
                                    return True

                                if self.extended_community_entry_count is not None:
                                    return True

                                if self.extended_community_memory is not None:
                                    return True

                                if self.lindex_entry_count is not None:
                                    return True

                                if self.lindex_memory is not None:
                                    return True

                                if self.local_as is not None:
                                    return True

                                if self.lsattr_entry_count is not None:
                                    return True

                                if self.lsattr_memory is not None:
                                    return True

                                if self.msg_log_pool_alloc_count is not None:
                                    for child_ref in self.msg_log_pool_alloc_count:
                                        if child_ref._has_data():
                                            return True

                                if self.msg_log_pool_free_count is not None:
                                    for child_ref in self.msg_log_pool_free_count:
                                        if child_ref._has_data():
                                            return True

                                if self.msg_log_pool_size is not None:
                                    for child_ref in self.msg_log_pool_size:
                                        if child_ref._has_data():
                                            return True

                                if self.neighbors_count_total is not None:
                                    return True

                                if self.nexthop_count is not None:
                                    return True

                                if self.nexthop_memory is not None:
                                    return True

                                if self.path_attribute_memory is not None:
                                    return True

                                if self.path_attributes_entry_count is not None:
                                    return True

                                if self.pe_distinguisher_label_entry_count is not None:
                                    return True

                                if self.pe_distinguisher_label_memory is not None:
                                    return True

                                if self.pool_alloc_count is not None:
                                    for child_ref in self.pool_alloc_count:
                                        if child_ref._has_data():
                                            return True

                                if self.pool_free_count is not None:
                                    for child_ref in self.pool_free_count:
                                        if child_ref._has_data():
                                            return True

                                if self.pool_size is not None:
                                    for child_ref in self.pool_size:
                                        if child_ref._has_data():
                                            return True

                                if self.ppmp_entry_count is not None:
                                    return True

                                if self.ppmp_memory is not None:
                                    return True

                                if self.process_instance_node is not None:
                                    return True

                                if self.pta_entry_count is not None:
                                    return True

                                if self.pta_memory is not None:
                                    return True

                                if self.restart_count is not None:
                                    return True

                                if self.ribrnh_entry_count is not None:
                                    return True

                                if self.ribrnh_memory is not None:
                                    return True

                                if self.route_reflector_memory is not None:
                                    return True

                                if self.route_reflectors is not None:
                                    return True

                                if self.sn_num_non_dflt_vrf_nbrs is not None:
                                    return True

                                if self.sn_num_non_dflt_vrf_nbrs_estab is not None:
                                    return True

                                if self.total_vrf_count is not None:
                                    return True

                                if self.tunnel_encap_entry_count is not None:
                                    return True

                                if self.tunnel_encap_memory is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global_']['meta_info']


                        class Vrf(object):
                            """
                            VRF information
                            
                            .. attribute:: established_neighbors_count
                            
                            	Number of established neighbors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbors_count
                            
                            	Number of neighbors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: network_count
                            
                            	Number of networks
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: notifications_received
                            
                            	No. of notifications received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: notifications_sent
                            
                            	No. of notifications sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: path_count
                            
                            	Number of paths
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_messages_received
                            
                            	Number of update messages received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_messages_sent
                            
                            	No. of update messages sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.established_neighbors_count = None
                                self.neighbors_count = None
                                self.network_count = None
                                self.notifications_received = None
                                self.notifications_sent = None
                                self.path_count = None
                                self.update_messages_received = None
                                self.update_messages_sent = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:vrf'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.established_neighbors_count is not None:
                                    return True

                                if self.neighbors_count is not None:
                                    return True

                                if self.network_count is not None:
                                    return True

                                if self.notifications_received is not None:
                                    return True

                                if self.notifications_sent is not None:
                                    return True

                                if self.path_count is not None:
                                    return True

                                if self.update_messages_received is not None:
                                    return True

                                if self.update_messages_sent is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Vrf']['meta_info']


                        class PerformanceStatistics(object):
                            """
                            Performance statistics
                            
                            .. attribute:: global_
                            
                            	Global information
                            	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_>`
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Vrf>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.global_ = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_()
                                self.global_.parent = self
                                self.vrf = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Vrf()
                                self.vrf.parent = self


                            class Global_(object):
                                """
                                Global information
                                
                                .. attribute:: active_nsr_mode_enter_time
                                
                                	Time that each mode was entered (seconds since  Jan 1 1970)
                                	**type**\: list of    :py:class:`ActiveNsrModeEnterTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrModeEnterTime>`
                                
                                .. attribute:: active_nsr_state
                                
                                	Current Active BGP nsrstate
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: active_nsrfo_time
                                
                                	Time that each thread isdone with its  go\-activeprocessing (seconds since Jan 1 1970)
                                	**type**\: list of    :py:class:`ActiveNsrfoTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrfoTime>`
                                
                                .. attribute:: active_nsrtcp_phase_two_enter_time
                                
                                	Time that NSR TCP Init Sync Phase Two entered on active (seconds since Jan 1 1970)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: bgp_te_infra_tunnel_type
                                
                                	BGP TE infra tunnel type
                                	**type**\:   :py:class:`BgpTeInfraTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTeInfraTunnelEnum>`
                                
                                .. attribute:: brib_api_input_bytes
                                
                                	bRIB API input bytes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: brib_api_input_messages
                                
                                	bRIB API input messages
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_input_prefixes_received
                                
                                	bRIB API input advertised prefixes received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_input_processing_time
                                
                                	Time spent processing input from bRIB API (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: brib_api_input_withdrawn_prefixes
                                
                                	bRIB API input withdrawn prefixes received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_output_bytes_generated
                                
                                	bRIB API output bytes generated
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: brib_api_output_bytes_sent
                                
                                	bRIB API output bytes sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: brib_api_output_calls
                                
                                	bRIB API calls to generate output
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_output_generation_time
                                
                                	Time spent generating output for bRIB API (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: brib_api_output_messages_sent
                                
                                	bRIB API output messages sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_output_prefixes_advertised
                                
                                	bRIB API output prefixes advertised
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_output_prefixes_withdrawn
                                
                                	bRIB API output prefixes withdrawn
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_output_sending_time
                                
                                	Time spent sending output to bRIB API (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: configuration_items_processed
                                
                                	Number of config items processed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: configuration_processing_time
                                
                                	Time spent processing config (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: current_clock_time
                                
                                	Current time
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ds_npl
                                
                                	NSR related DS and NPL information
                                	**type**\:   :py:class:`DsNpl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl>`
                                
                                .. attribute:: edm_processing_time
                                
                                	Time spent processing EDM requests (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: edm_requests_count
                                
                                	Number of EDM requests processed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: in_event_attach_calls
                                
                                	event\_file\_attach  calls for input
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: in_out_event_attach_calls
                                
                                	event\_file\_attach calls for input
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: initial_sync_sessions_added
                                
                                	If true, BGP has at least one established session when NSR initial synchronization is started
                                	**type**\:  bool
                                
                                .. attribute:: instance_node_role
                                
                                	Node role \- active/passive
                                	**type**\:  bool
                                
                                .. attribute:: io_handler_tm
                                
                                	Timestamp when IO timer handler got called
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: io_timer_id
                                
                                	IO master timer ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: io_tree_timer_expiry
                                
                                	Time as per tree\->mtexptime
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: io_tree_timer_left
                                
                                	Time left before the QNX timer would expire
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ipv4rib_server
                                
                                	IPv4 RIB server global info
                                	**type**\:   :py:class:`Ipv4RibServer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer>`
                                
                                .. attribute:: ipv6rib_server
                                
                                	IPv6 RIB server global info
                                	**type**\:   :py:class:`Ipv6RibServer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer>`
                                
                                .. attribute:: issu_milestone
                                
                                	ISSU Milestones
                                	**type**\: list of    :py:class:`IssuMilestone <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.IssuMilestone>`
                                
                                .. attribute:: issu_milestone_packed
                                
                                	Flag to indicate ISSU Milestones packed
                                	**type**\:  bool
                                
                                .. attribute:: lsd_connection
                                
                                	MPLS LSD server connection info
                                	**type**\:   :py:class:`LsdConnection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection>`
                                
                                .. attribute:: nsr_last_reset_reason
                                
                                	Reason for last nsr state  machine reset
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: out_event_attach_calls
                                
                                	event\_file\_attach  calls for output
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: postit_count_info
                                
                                	List of neighbors and their postit counts
                                	**type**\: list of    :py:class:`PostitCountInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo>`
                                
                                .. attribute:: proc_scoped_sync_state
                                
                                	BGP scoped sync state
                                	**type**\:   :py:class:`BgpScopedSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpScopedSyncStateEnum>`
                                
                                .. attribute:: qad_ac_ks_failure
                                
                                	Ack failure on QAD 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_ac_ks_received
                                
                                	Acks received on QAD 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_init_drops
                                
                                	Packets dropped on standby during initialization
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_messages_received
                                
                                	Messages received on QAD 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_messages_sent
                                
                                	Messages sent on QAD 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_processed
                                
                                	Messages processed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_recv_drops
                                
                                	Received packet dropped due to null peer 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_resumes
                                
                                	QAD send resume 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_send_drops
                                
                                	Send packets dropped due to null peer 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_send_failure
                                
                                	Send failure on QAD 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_suspends
                                
                                	QAD send suspend
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_timeout_received
                                
                                	Timeouts received on QAD 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_timeout_recvd
                                
                                	Number of packet send timeouts 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qadack_sent
                                
                                	Acks sent on QAD 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qadoos_drops
                                
                                	Packets dropped due to  out of sequence packetreceived
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: redcon_nsr_ready
                                
                                	NSR state conveyed to Redcon  by bgp \- nsr ready/unready
                                	**type**\:  bool
                                
                                .. attribute:: redcon_state_time
                                
                                	Time when nsr state wasconveyed to Redcon last
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sec_active_nsr_state
                                
                                	Current Sec Active BGP nsrstate
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sec_active_nsrtcp_phase_two_enter_time
                                
                                	Time that NSR TCP Init Sync Phase Two entered on active (seconds since Jan 1 1970)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: standby_nsr_mode_enter_time
                                
                                	Time that each mode was entered (seconds since  Jan 1 1970)
                                	**type**\: list of    :py:class:`StandbyNsrModeEnterTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.StandbyNsrModeEnterTime>`
                                
                                .. attribute:: te_connection
                                
                                	MPLS TE server connection info
                                	**type**\:   :py:class:`TeConnection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection>`
                                
                                .. attribute:: tep2p_auto_tunnel_enabled
                                
                                	TE support for P2P auto tunnel
                                	**type**\:  bool
                                
                                .. attribute:: total_neighbors_with_pending_postits
                                
                                	Total nbrs with pending postits
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_outstanding_postits
                                
                                	Total outstanding postits across all neighbors
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: updgen_handler_tm
                                
                                	Timestamp when updgen timer handler got called
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: updgen_timer_id
                                
                                	Updgen master timer ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: updgen_tree_timer_expiry
                                
                                	Time as per tree\->mtexptime
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: updgen_tree_timer_left
                                
                                	Time left before the QNX timer would expire
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.active_nsr_mode_enter_time = YList()
                                    self.active_nsr_mode_enter_time.parent = self
                                    self.active_nsr_mode_enter_time.name = 'active_nsr_mode_enter_time'
                                    self.active_nsr_state = None
                                    self.active_nsrfo_time = YList()
                                    self.active_nsrfo_time.parent = self
                                    self.active_nsrfo_time.name = 'active_nsrfo_time'
                                    self.active_nsrtcp_phase_two_enter_time = None
                                    self.bgp_te_infra_tunnel_type = None
                                    self.brib_api_input_bytes = None
                                    self.brib_api_input_messages = None
                                    self.brib_api_input_prefixes_received = None
                                    self.brib_api_input_processing_time = None
                                    self.brib_api_input_withdrawn_prefixes = None
                                    self.brib_api_output_bytes_generated = None
                                    self.brib_api_output_bytes_sent = None
                                    self.brib_api_output_calls = None
                                    self.brib_api_output_generation_time = None
                                    self.brib_api_output_messages_sent = None
                                    self.brib_api_output_prefixes_advertised = None
                                    self.brib_api_output_prefixes_withdrawn = None
                                    self.brib_api_output_sending_time = None
                                    self.configuration_items_processed = None
                                    self.configuration_processing_time = None
                                    self.current_clock_time = None
                                    self.ds_npl = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl()
                                    self.ds_npl.parent = self
                                    self.edm_processing_time = None
                                    self.edm_requests_count = None
                                    self.in_event_attach_calls = None
                                    self.in_out_event_attach_calls = None
                                    self.initial_sync_sessions_added = None
                                    self.instance_node_role = None
                                    self.io_handler_tm = None
                                    self.io_timer_id = None
                                    self.io_tree_timer_expiry = None
                                    self.io_tree_timer_left = None
                                    self.ipv4rib_server = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer()
                                    self.ipv4rib_server.parent = self
                                    self.ipv6rib_server = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer()
                                    self.ipv6rib_server.parent = self
                                    self.issu_milestone = YList()
                                    self.issu_milestone.parent = self
                                    self.issu_milestone.name = 'issu_milestone'
                                    self.issu_milestone_packed = None
                                    self.lsd_connection = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection()
                                    self.lsd_connection.parent = self
                                    self.nsr_last_reset_reason = None
                                    self.out_event_attach_calls = None
                                    self.postit_count_info = YList()
                                    self.postit_count_info.parent = self
                                    self.postit_count_info.name = 'postit_count_info'
                                    self.proc_scoped_sync_state = None
                                    self.qad_ac_ks_failure = None
                                    self.qad_ac_ks_received = None
                                    self.qad_init_drops = None
                                    self.qad_messages_received = None
                                    self.qad_messages_sent = None
                                    self.qad_processed = None
                                    self.qad_recv_drops = None
                                    self.qad_resumes = None
                                    self.qad_send_drops = None
                                    self.qad_send_failure = None
                                    self.qad_suspends = None
                                    self.qad_timeout_received = None
                                    self.qad_timeout_recvd = None
                                    self.qadack_sent = None
                                    self.qadoos_drops = None
                                    self.redcon_nsr_ready = None
                                    self.redcon_state_time = None
                                    self.sec_active_nsr_state = None
                                    self.sec_active_nsrtcp_phase_two_enter_time = None
                                    self.standby_nsr_mode_enter_time = YList()
                                    self.standby_nsr_mode_enter_time.parent = self
                                    self.standby_nsr_mode_enter_time.name = 'standby_nsr_mode_enter_time'
                                    self.te_connection = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection()
                                    self.te_connection.parent = self
                                    self.tep2p_auto_tunnel_enabled = None
                                    self.total_neighbors_with_pending_postits = None
                                    self.total_outstanding_postits = None
                                    self.updgen_handler_tm = None
                                    self.updgen_timer_id = None
                                    self.updgen_tree_timer_expiry = None
                                    self.updgen_tree_timer_left = None


                                class Ipv4RibServer(object):
                                    """
                                    IPv4 RIB server global info
                                    
                                    .. attribute:: first_rib_connection_down_timestamp
                                    
                                    	First RIB connection Down event timestamp
                                    	**type**\:   :py:class:`FirstRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionDownTimestamp>`
                                    
                                    .. attribute:: first_rib_connection_up_timestamp
                                    
                                    	First RIB connection Up event timestamp
                                    	**type**\:   :py:class:`FirstRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionUpTimestamp>`
                                    
                                    .. attribute:: is_rib_connection_up
                                    
                                    	Is RIB Connection Up?
                                    	**type**\:  bool
                                    
                                    .. attribute:: last_rib_connection_down_age
                                    
                                    	Time since last RIB connection Down event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_rib_connection_down_timestamp
                                    
                                    	Last RIB connection Down event timestamp
                                    	**type**\:   :py:class:`LastRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionDownTimestamp>`
                                    
                                    .. attribute:: last_rib_connection_up_age
                                    
                                    	Time since last RIB connection Up event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_rib_connection_up_timestamp
                                    
                                    	Last RIB connection Up event timestamp
                                    	**type**\:   :py:class:`LastRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionUpTimestamp>`
                                    
                                    .. attribute:: rib_connection_down_count
                                    
                                    	Number of RIB connection Down events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_connection_up_count
                                    
                                    	Number of RIB connection Up events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.first_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionDownTimestamp()
                                        self.first_rib_connection_down_timestamp.parent = self
                                        self.first_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionUpTimestamp()
                                        self.first_rib_connection_up_timestamp.parent = self
                                        self.is_rib_connection_up = None
                                        self.last_rib_connection_down_age = None
                                        self.last_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionDownTimestamp()
                                        self.last_rib_connection_down_timestamp.parent = self
                                        self.last_rib_connection_up_age = None
                                        self.last_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionUpTimestamp()
                                        self.last_rib_connection_up_timestamp.parent = self
                                        self.rib_connection_down_count = None
                                        self.rib_connection_up_count = None


                                    class FirstRibConnectionUpTimestamp(object):
                                        """
                                        First RIB connection Up event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-rib-connection-up-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionUpTimestamp']['meta_info']


                                    class LastRibConnectionUpTimestamp(object):
                                        """
                                        Last RIB connection Up event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-rib-connection-up-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionUpTimestamp']['meta_info']


                                    class FirstRibConnectionDownTimestamp(object):
                                        """
                                        First RIB connection Down event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-rib-connection-down-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionDownTimestamp']['meta_info']


                                    class LastRibConnectionDownTimestamp(object):
                                        """
                                        Last RIB connection Down event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-rib-connection-down-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionDownTimestamp']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4rib-server'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.first_rib_connection_down_timestamp is not None and self.first_rib_connection_down_timestamp._has_data():
                                            return True

                                        if self.first_rib_connection_up_timestamp is not None and self.first_rib_connection_up_timestamp._has_data():
                                            return True

                                        if self.is_rib_connection_up is not None:
                                            return True

                                        if self.last_rib_connection_down_age is not None:
                                            return True

                                        if self.last_rib_connection_down_timestamp is not None and self.last_rib_connection_down_timestamp._has_data():
                                            return True

                                        if self.last_rib_connection_up_age is not None:
                                            return True

                                        if self.last_rib_connection_up_timestamp is not None and self.last_rib_connection_up_timestamp._has_data():
                                            return True

                                        if self.rib_connection_down_count is not None:
                                            return True

                                        if self.rib_connection_up_count is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer']['meta_info']


                                class Ipv6RibServer(object):
                                    """
                                    IPv6 RIB server global info
                                    
                                    .. attribute:: first_rib_connection_down_timestamp
                                    
                                    	First RIB connection Down event timestamp
                                    	**type**\:   :py:class:`FirstRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionDownTimestamp>`
                                    
                                    .. attribute:: first_rib_connection_up_timestamp
                                    
                                    	First RIB connection Up event timestamp
                                    	**type**\:   :py:class:`FirstRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionUpTimestamp>`
                                    
                                    .. attribute:: is_rib_connection_up
                                    
                                    	Is RIB Connection Up?
                                    	**type**\:  bool
                                    
                                    .. attribute:: last_rib_connection_down_age
                                    
                                    	Time since last RIB connection Down event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_rib_connection_down_timestamp
                                    
                                    	Last RIB connection Down event timestamp
                                    	**type**\:   :py:class:`LastRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionDownTimestamp>`
                                    
                                    .. attribute:: last_rib_connection_up_age
                                    
                                    	Time since last RIB connection Up event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_rib_connection_up_timestamp
                                    
                                    	Last RIB connection Up event timestamp
                                    	**type**\:   :py:class:`LastRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionUpTimestamp>`
                                    
                                    .. attribute:: rib_connection_down_count
                                    
                                    	Number of RIB connection Down events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_connection_up_count
                                    
                                    	Number of RIB connection Up events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.first_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionDownTimestamp()
                                        self.first_rib_connection_down_timestamp.parent = self
                                        self.first_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionUpTimestamp()
                                        self.first_rib_connection_up_timestamp.parent = self
                                        self.is_rib_connection_up = None
                                        self.last_rib_connection_down_age = None
                                        self.last_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionDownTimestamp()
                                        self.last_rib_connection_down_timestamp.parent = self
                                        self.last_rib_connection_up_age = None
                                        self.last_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionUpTimestamp()
                                        self.last_rib_connection_up_timestamp.parent = self
                                        self.rib_connection_down_count = None
                                        self.rib_connection_up_count = None


                                    class FirstRibConnectionUpTimestamp(object):
                                        """
                                        First RIB connection Up event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-rib-connection-up-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionUpTimestamp']['meta_info']


                                    class LastRibConnectionUpTimestamp(object):
                                        """
                                        Last RIB connection Up event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-rib-connection-up-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionUpTimestamp']['meta_info']


                                    class FirstRibConnectionDownTimestamp(object):
                                        """
                                        First RIB connection Down event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-rib-connection-down-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionDownTimestamp']['meta_info']


                                    class LastRibConnectionDownTimestamp(object):
                                        """
                                        Last RIB connection Down event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-rib-connection-down-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionDownTimestamp']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6rib-server'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.first_rib_connection_down_timestamp is not None and self.first_rib_connection_down_timestamp._has_data():
                                            return True

                                        if self.first_rib_connection_up_timestamp is not None and self.first_rib_connection_up_timestamp._has_data():
                                            return True

                                        if self.is_rib_connection_up is not None:
                                            return True

                                        if self.last_rib_connection_down_age is not None:
                                            return True

                                        if self.last_rib_connection_down_timestamp is not None and self.last_rib_connection_down_timestamp._has_data():
                                            return True

                                        if self.last_rib_connection_up_age is not None:
                                            return True

                                        if self.last_rib_connection_up_timestamp is not None and self.last_rib_connection_up_timestamp._has_data():
                                            return True

                                        if self.rib_connection_down_count is not None:
                                            return True

                                        if self.rib_connection_up_count is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer']['meta_info']


                                class TeConnection(object):
                                    """
                                    MPLS TE server connection info
                                    
                                    .. attribute:: connection_down_count
                                    
                                    	Number of connection down events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: connection_up_count
                                    
                                    	Number of connection Up events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: first_connection_down_timestamp
                                    
                                    	First connection Down event timestamp
                                    	**type**\:   :py:class:`FirstConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionDownTimestamp>`
                                    
                                    .. attribute:: first_connection_up_timestamp
                                    
                                    	First connection Up event timestamp
                                    	**type**\:   :py:class:`FirstConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionUpTimestamp>`
                                    
                                    .. attribute:: is_connection_up
                                    
                                    	Is Connection Up?
                                    	**type**\:  bool
                                    
                                    .. attribute:: last_connection_down_age
                                    
                                    	Time since last connection Down event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_connection_down_timestamp
                                    
                                    	Last connection Down event timestamp
                                    	**type**\:   :py:class:`LastConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionDownTimestamp>`
                                    
                                    .. attribute:: last_connection_up_age
                                    
                                    	Time since last connection Up event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_connection_up_timestamp
                                    
                                    	Last connection Up event timestamp
                                    	**type**\:   :py:class:`LastConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionUpTimestamp>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.connection_down_count = None
                                        self.connection_up_count = None
                                        self.first_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionDownTimestamp()
                                        self.first_connection_down_timestamp.parent = self
                                        self.first_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionUpTimestamp()
                                        self.first_connection_up_timestamp.parent = self
                                        self.is_connection_up = None
                                        self.last_connection_down_age = None
                                        self.last_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionDownTimestamp()
                                        self.last_connection_down_timestamp.parent = self
                                        self.last_connection_up_age = None
                                        self.last_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionUpTimestamp()
                                        self.last_connection_up_timestamp.parent = self


                                    class FirstConnectionUpTimestamp(object):
                                        """
                                        First connection Up event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-connection-up-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionUpTimestamp']['meta_info']


                                    class LastConnectionUpTimestamp(object):
                                        """
                                        Last connection Up event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-connection-up-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionUpTimestamp']['meta_info']


                                    class FirstConnectionDownTimestamp(object):
                                        """
                                        First connection Down event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-connection-down-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionDownTimestamp']['meta_info']


                                    class LastConnectionDownTimestamp(object):
                                        """
                                        Last connection Down event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-connection-down-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionDownTimestamp']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:te-connection'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.connection_down_count is not None:
                                            return True

                                        if self.connection_up_count is not None:
                                            return True

                                        if self.first_connection_down_timestamp is not None and self.first_connection_down_timestamp._has_data():
                                            return True

                                        if self.first_connection_up_timestamp is not None and self.first_connection_up_timestamp._has_data():
                                            return True

                                        if self.is_connection_up is not None:
                                            return True

                                        if self.last_connection_down_age is not None:
                                            return True

                                        if self.last_connection_down_timestamp is not None and self.last_connection_down_timestamp._has_data():
                                            return True

                                        if self.last_connection_up_age is not None:
                                            return True

                                        if self.last_connection_up_timestamp is not None and self.last_connection_up_timestamp._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection']['meta_info']


                                class LsdConnection(object):
                                    """
                                    MPLS LSD server connection info
                                    
                                    .. attribute:: connection_down_count
                                    
                                    	Number of connection down events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: connection_up_count
                                    
                                    	Number of connection Up events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: first_connection_down_timestamp
                                    
                                    	First connection Down event timestamp
                                    	**type**\:   :py:class:`FirstConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionDownTimestamp>`
                                    
                                    .. attribute:: first_connection_up_timestamp
                                    
                                    	First connection Up event timestamp
                                    	**type**\:   :py:class:`FirstConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionUpTimestamp>`
                                    
                                    .. attribute:: is_connection_up
                                    
                                    	Is Connection Up?
                                    	**type**\:  bool
                                    
                                    .. attribute:: last_connection_down_age
                                    
                                    	Time since last connection Down event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_connection_down_timestamp
                                    
                                    	Last connection Down event timestamp
                                    	**type**\:   :py:class:`LastConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionDownTimestamp>`
                                    
                                    .. attribute:: last_connection_up_age
                                    
                                    	Time since last connection Up event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_connection_up_timestamp
                                    
                                    	Last connection Up event timestamp
                                    	**type**\:   :py:class:`LastConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionUpTimestamp>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.connection_down_count = None
                                        self.connection_up_count = None
                                        self.first_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionDownTimestamp()
                                        self.first_connection_down_timestamp.parent = self
                                        self.first_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionUpTimestamp()
                                        self.first_connection_up_timestamp.parent = self
                                        self.is_connection_up = None
                                        self.last_connection_down_age = None
                                        self.last_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionDownTimestamp()
                                        self.last_connection_down_timestamp.parent = self
                                        self.last_connection_up_age = None
                                        self.last_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionUpTimestamp()
                                        self.last_connection_up_timestamp.parent = self


                                    class FirstConnectionUpTimestamp(object):
                                        """
                                        First connection Up event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-connection-up-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionUpTimestamp']['meta_info']


                                    class LastConnectionUpTimestamp(object):
                                        """
                                        Last connection Up event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-connection-up-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionUpTimestamp']['meta_info']


                                    class FirstConnectionDownTimestamp(object):
                                        """
                                        First connection Down event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-connection-down-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionDownTimestamp']['meta_info']


                                    class LastConnectionDownTimestamp(object):
                                        """
                                        Last connection Down event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-connection-down-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionDownTimestamp']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:lsd-connection'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.connection_down_count is not None:
                                            return True

                                        if self.connection_up_count is not None:
                                            return True

                                        if self.first_connection_down_timestamp is not None and self.first_connection_down_timestamp._has_data():
                                            return True

                                        if self.first_connection_up_timestamp is not None and self.first_connection_up_timestamp._has_data():
                                            return True

                                        if self.is_connection_up is not None:
                                            return True

                                        if self.last_connection_down_age is not None:
                                            return True

                                        if self.last_connection_down_timestamp is not None and self.last_connection_down_timestamp._has_data():
                                            return True

                                        if self.last_connection_up_age is not None:
                                            return True

                                        if self.last_connection_up_timestamp is not None and self.last_connection_up_timestamp._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection']['meta_info']


                                class DsNpl(object):
                                    """
                                    NSR related DS and NPL information
                                    
                                    .. attribute:: dir_service_conn_state
                                    
                                    	Current Directory Service connectionstate
                                    	**type**\:   :py:class:`BgpDsConnStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpDsConnStateEnum>`
                                    
                                    .. attribute:: dsissu_status_flag
                                    
                                    	DS ISSU status flag
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: issu_mgr_conn_state
                                    
                                    	Current ISSU Mgr connection state
                                    	**type**\:   :py:class:`BgpIsmConnStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpIsmConnStateEnum>`
                                    
                                    .. attribute:: issu_phase
                                    
                                    	Current ISSU Phase
                                    	**type**\:  str
                                    
                                    .. attribute:: issu_type_ng
                                    
                                    	ISSU type is Next Gen
                                    	**type**\:  bool
                                    
                                    .. attribute:: issuha_option
                                    
                                    	Current ISSU HA option
                                    	**type**\:  str
                                    
                                    .. attribute:: local_ds_handle
                                    
                                    	Local Directory Service handle
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: npl_endpoint
                                    
                                    	NPL endpoint information
                                    	**type**\: list of    :py:class:`NplEndpoint <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint>`
                                    
                                    .. attribute:: npl_priority_statistic
                                    
                                    	NPL priority statistics
                                    	**type**\: list of    :py:class:`NplPriorityStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic>`
                                    
                                    .. attribute:: service_name
                                    
                                    	Local DS service name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.dir_service_conn_state = None
                                        self.dsissu_status_flag = None
                                        self.issu_mgr_conn_state = None
                                        self.issu_phase = None
                                        self.issu_type_ng = None
                                        self.issuha_option = None
                                        self.local_ds_handle = None
                                        self.npl_endpoint = YList()
                                        self.npl_endpoint.parent = self
                                        self.npl_endpoint.name = 'npl_endpoint'
                                        self.npl_priority_statistic = YList()
                                        self.npl_priority_statistic.parent = self
                                        self.npl_priority_statistic.name = 'npl_priority_statistic'
                                        self.service_name = None


                                    class NplPriorityStatistic(object):
                                        """
                                        NPL priority statistics
                                        
                                        .. attribute:: num_recv
                                        
                                        	Total recvd
                                        	**type**\: list of    :py:class:`NumRecv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecv>`
                                        
                                        .. attribute:: num_recv_drop
                                        
                                        	Recv Errors/drops
                                        	**type**\: list of    :py:class:`NumRecvDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop>`
                                        
                                        .. attribute:: num_sent
                                        
                                        	Total sent
                                        	**type**\: list of    :py:class:`NumSent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSent>`
                                        
                                        .. attribute:: num_sent_drop
                                        
                                        	Sent Error/drops
                                        	**type**\: list of    :py:class:`NumSentDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.num_recv = YList()
                                            self.num_recv.parent = self
                                            self.num_recv.name = 'num_recv'
                                            self.num_recv_drop = YList()
                                            self.num_recv_drop.parent = self
                                            self.num_recv_drop.name = 'num_recv_drop'
                                            self.num_sent = YList()
                                            self.num_sent.parent = self
                                            self.num_sent.name = 'num_sent'
                                            self.num_sent_drop = YList()
                                            self.num_sent_drop.parent = self
                                            self.num_sent_drop.name = 'num_sent_drop'


                                        class NumSent(object):
                                            """
                                            Total sent
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:num-sent'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSent']['meta_info']


                                        class NumRecv(object):
                                            """
                                            Total recvd
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:num-recv'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecv']['meta_info']


                                        class NumSentDrop(object):
                                            """
                                            Sent Error/drops
                                            
                                            .. attribute:: nsr_pl_send_drop_array
                                            
                                            	nsr pl send drop array
                                            	**type**\: list of    :py:class:`NsrPlSendDropArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nsr_pl_send_drop_array = YList()
                                                self.nsr_pl_send_drop_array.parent = self
                                                self.nsr_pl_send_drop_array.name = 'nsr_pl_send_drop_array'


                                            class NsrPlSendDropArray(object):
                                                """
                                                nsr pl send drop array
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nsr-pl-send-drop-array'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:num-sent-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nsr_pl_send_drop_array is not None:
                                                    for child_ref in self.nsr_pl_send_drop_array:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop']['meta_info']


                                        class NumRecvDrop(object):
                                            """
                                            Recv Errors/drops
                                            
                                            .. attribute:: nsr_pl_recv_drop_array
                                            
                                            	nsr pl recv drop array
                                            	**type**\: list of    :py:class:`NsrPlRecvDropArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nsr_pl_recv_drop_array = YList()
                                                self.nsr_pl_recv_drop_array.parent = self
                                                self.nsr_pl_recv_drop_array.name = 'nsr_pl_recv_drop_array'


                                            class NsrPlRecvDropArray(object):
                                                """
                                                nsr pl recv drop array
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nsr-pl-recv-drop-array'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:num-recv-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nsr_pl_recv_drop_array is not None:
                                                    for child_ref in self.nsr_pl_recv_drop_array:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:npl-priority-statistic'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.num_recv is not None:
                                                for child_ref in self.num_recv:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.num_recv_drop is not None:
                                                for child_ref in self.num_recv_drop:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.num_sent is not None:
                                                for child_ref in self.num_sent:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.num_sent_drop is not None:
                                                for child_ref in self.num_sent_drop:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic']['meta_info']


                                    class NplEndpoint(object):
                                        """
                                        NPL endpoint information
                                        
                                        .. attribute:: endpoint
                                        
                                        	NCD endpoint bytestream
                                        	**type**\: list of    :py:class:`Endpoint <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint.Endpoint>`
                                        
                                        .. attribute:: endpoint_active_flag
                                        
                                        	Endpoint active flag
                                        	**type**\:  bool
                                        
                                        .. attribute:: endpoint_handle
                                        
                                        	NCD endpoint handle
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: endpoint_issu_role
                                        
                                        	Endpoint's ISSU Role. Values are 'Primary', 'Secondary' and 'Tertiary'
                                        	**type**\:  str
                                        
                                        .. attribute:: endpoint_name
                                        
                                        	Endpoint name
                                        	**type**\:  str
                                        
                                        .. attribute:: endpoint_stale_flag
                                        
                                        	Endpoint stale flag
                                        	**type**\:  bool
                                        
                                        .. attribute:: expected_sequence_num
                                        
                                        	Expected sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: msg_size
                                        
                                        	Message size for this entity
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: node_id
                                        
                                        	Node ID
                                        	**type**\:  str
                                        
                                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                                        
                                        .. attribute:: sync_group_name
                                        
                                        	Syncgroup associated with this endpoint
                                        	**type**\:  str
                                        
                                        .. attribute:: wheel_id
                                        
                                        	Wheel ID for this endpoint
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.endpoint = YList()
                                            self.endpoint.parent = self
                                            self.endpoint.name = 'endpoint'
                                            self.endpoint_active_flag = None
                                            self.endpoint_handle = None
                                            self.endpoint_issu_role = None
                                            self.endpoint_name = None
                                            self.endpoint_stale_flag = None
                                            self.expected_sequence_num = None
                                            self.msg_size = None
                                            self.node_id = None
                                            self.sync_group_name = None
                                            self.wheel_id = None


                                        class Endpoint(object):
                                            """
                                            NCD endpoint bytestream
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:endpoint'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint.Endpoint']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:npl-endpoint'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.endpoint is not None:
                                                for child_ref in self.endpoint:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.endpoint_active_flag is not None:
                                                return True

                                            if self.endpoint_handle is not None:
                                                return True

                                            if self.endpoint_issu_role is not None:
                                                return True

                                            if self.endpoint_name is not None:
                                                return True

                                            if self.endpoint_stale_flag is not None:
                                                return True

                                            if self.expected_sequence_num is not None:
                                                return True

                                            if self.msg_size is not None:
                                                return True

                                            if self.node_id is not None:
                                                return True

                                            if self.sync_group_name is not None:
                                                return True

                                            if self.wheel_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ds-npl'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dir_service_conn_state is not None:
                                            return True

                                        if self.dsissu_status_flag is not None:
                                            return True

                                        if self.issu_mgr_conn_state is not None:
                                            return True

                                        if self.issu_phase is not None:
                                            return True

                                        if self.issu_type_ng is not None:
                                            return True

                                        if self.issuha_option is not None:
                                            return True

                                        if self.local_ds_handle is not None:
                                            return True

                                        if self.npl_endpoint is not None:
                                            for child_ref in self.npl_endpoint:
                                                if child_ref._has_data():
                                                    return True

                                        if self.npl_priority_statistic is not None:
                                            for child_ref in self.npl_priority_statistic:
                                                if child_ref._has_data():
                                                    return True

                                        if self.service_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl']['meta_info']


                                class ActiveNsrModeEnterTime(object):
                                    """
                                    Time that each mode was entered (seconds since
                                    
                                    Jan 1 1970)
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-nsr-mode-enter-time'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrModeEnterTime']['meta_info']


                                class StandbyNsrModeEnterTime(object):
                                    """
                                    Time that each mode was entered (seconds since
                                    
                                    Jan 1 1970)
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:standby-nsr-mode-enter-time'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.StandbyNsrModeEnterTime']['meta_info']


                                class ActiveNsrfoTime(object):
                                    """
                                    Time that each thread isdone with its
                                    
                                    go\-activeprocessing (seconds since Jan 1 1970)
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-nsrfo-time'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrfoTime']['meta_info']


                                class PostitCountInfo(object):
                                    """
                                    List of neighbors and their postit counts
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress>`
                                    
                                    .. attribute:: postit_count
                                    
                                    	Count of the number of postits for this nbr
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress()
                                        self.neighbor_address.parent = self
                                        self.postit_count = None
                                        self.vrf_name = None


                                    class NeighborAddress(object):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:postit-count-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                            return True

                                        if self.postit_count is not None:
                                            return True

                                        if self.vrf_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo']['meta_info']


                                class IssuMilestone(object):
                                    """
                                    ISSU Milestones
                                    
                                    .. attribute:: milestone_met_timestamp
                                    
                                    	Milestone met timestamp
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: milestone_name
                                    
                                    	Milestone name
                                    	**type**\:  str
                                    
                                    	**length:** 0..64
                                    
                                    .. attribute:: milestone_start_timestamp
                                    
                                    	Milestone start timestamp
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.milestone_met_timestamp = None
                                        self.milestone_name = None
                                        self.milestone_start_timestamp = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:issu-milestone'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.milestone_met_timestamp is not None:
                                            return True

                                        if self.milestone_name is not None:
                                            return True

                                        if self.milestone_start_timestamp is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.IssuMilestone']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:global'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.active_nsr_mode_enter_time is not None:
                                        for child_ref in self.active_nsr_mode_enter_time:
                                            if child_ref._has_data():
                                                return True

                                    if self.active_nsr_state is not None:
                                        return True

                                    if self.active_nsrfo_time is not None:
                                        for child_ref in self.active_nsrfo_time:
                                            if child_ref._has_data():
                                                return True

                                    if self.active_nsrtcp_phase_two_enter_time is not None:
                                        return True

                                    if self.bgp_te_infra_tunnel_type is not None:
                                        return True

                                    if self.brib_api_input_bytes is not None:
                                        return True

                                    if self.brib_api_input_messages is not None:
                                        return True

                                    if self.brib_api_input_prefixes_received is not None:
                                        return True

                                    if self.brib_api_input_processing_time is not None:
                                        return True

                                    if self.brib_api_input_withdrawn_prefixes is not None:
                                        return True

                                    if self.brib_api_output_bytes_generated is not None:
                                        return True

                                    if self.brib_api_output_bytes_sent is not None:
                                        return True

                                    if self.brib_api_output_calls is not None:
                                        return True

                                    if self.brib_api_output_generation_time is not None:
                                        return True

                                    if self.brib_api_output_messages_sent is not None:
                                        return True

                                    if self.brib_api_output_prefixes_advertised is not None:
                                        return True

                                    if self.brib_api_output_prefixes_withdrawn is not None:
                                        return True

                                    if self.brib_api_output_sending_time is not None:
                                        return True

                                    if self.configuration_items_processed is not None:
                                        return True

                                    if self.configuration_processing_time is not None:
                                        return True

                                    if self.current_clock_time is not None:
                                        return True

                                    if self.ds_npl is not None and self.ds_npl._has_data():
                                        return True

                                    if self.edm_processing_time is not None:
                                        return True

                                    if self.edm_requests_count is not None:
                                        return True

                                    if self.in_event_attach_calls is not None:
                                        return True

                                    if self.in_out_event_attach_calls is not None:
                                        return True

                                    if self.initial_sync_sessions_added is not None:
                                        return True

                                    if self.instance_node_role is not None:
                                        return True

                                    if self.io_handler_tm is not None:
                                        return True

                                    if self.io_timer_id is not None:
                                        return True

                                    if self.io_tree_timer_expiry is not None:
                                        return True

                                    if self.io_tree_timer_left is not None:
                                        return True

                                    if self.ipv4rib_server is not None and self.ipv4rib_server._has_data():
                                        return True

                                    if self.ipv6rib_server is not None and self.ipv6rib_server._has_data():
                                        return True

                                    if self.issu_milestone is not None:
                                        for child_ref in self.issu_milestone:
                                            if child_ref._has_data():
                                                return True

                                    if self.issu_milestone_packed is not None:
                                        return True

                                    if self.lsd_connection is not None and self.lsd_connection._has_data():
                                        return True

                                    if self.nsr_last_reset_reason is not None:
                                        return True

                                    if self.out_event_attach_calls is not None:
                                        return True

                                    if self.postit_count_info is not None:
                                        for child_ref in self.postit_count_info:
                                            if child_ref._has_data():
                                                return True

                                    if self.proc_scoped_sync_state is not None:
                                        return True

                                    if self.qad_ac_ks_failure is not None:
                                        return True

                                    if self.qad_ac_ks_received is not None:
                                        return True

                                    if self.qad_init_drops is not None:
                                        return True

                                    if self.qad_messages_received is not None:
                                        return True

                                    if self.qad_messages_sent is not None:
                                        return True

                                    if self.qad_processed is not None:
                                        return True

                                    if self.qad_recv_drops is not None:
                                        return True

                                    if self.qad_resumes is not None:
                                        return True

                                    if self.qad_send_drops is not None:
                                        return True

                                    if self.qad_send_failure is not None:
                                        return True

                                    if self.qad_suspends is not None:
                                        return True

                                    if self.qad_timeout_received is not None:
                                        return True

                                    if self.qad_timeout_recvd is not None:
                                        return True

                                    if self.qadack_sent is not None:
                                        return True

                                    if self.qadoos_drops is not None:
                                        return True

                                    if self.redcon_nsr_ready is not None:
                                        return True

                                    if self.redcon_state_time is not None:
                                        return True

                                    if self.sec_active_nsr_state is not None:
                                        return True

                                    if self.sec_active_nsrtcp_phase_two_enter_time is not None:
                                        return True

                                    if self.standby_nsr_mode_enter_time is not None:
                                        for child_ref in self.standby_nsr_mode_enter_time:
                                            if child_ref._has_data():
                                                return True

                                    if self.te_connection is not None and self.te_connection._has_data():
                                        return True

                                    if self.tep2p_auto_tunnel_enabled is not None:
                                        return True

                                    if self.total_neighbors_with_pending_postits is not None:
                                        return True

                                    if self.total_outstanding_postits is not None:
                                        return True

                                    if self.updgen_handler_tm is not None:
                                        return True

                                    if self.updgen_timer_id is not None:
                                        return True

                                    if self.updgen_tree_timer_expiry is not None:
                                        return True

                                    if self.updgen_tree_timer_left is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_']['meta_info']


                            class Vrf(object):
                                """
                                VRF information
                                
                                .. attribute:: data_bytes_read
                                
                                	No. of bytes of data read
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: data_bytes_written
                                
                                	Number of bytes of data written
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: high_throttled_read_count
                                
                                	Number of socket reads for nbrs above high threshold
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: inbound_update_messages
                                
                                	Number of inbound update messages processed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: inbound_update_messages_time
                                
                                	Time spent processing imbound update messages (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: io_read_time
                                
                                	Time spent reading inbound data (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: io_write_time
                                
                                	Time spent writing outbound data (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low_throttled_read_count
                                
                                	Number of socket reads for nbrs above low threshold
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lpts_calls
                                
                                	Number of times LPTS socket opt set up
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lpts_set_up_time
                                
                                	Time spent setting up LPTS socket opt (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: read_calls_count
                                
                                	No. of calls to function to read inbound data
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: read_messages_count
                                
                                	Number of BGP messages read
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: read_throttles_count
                                
                                	Number of partial read throttles
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: subgroup_list_time
                                
                                	Time spent processing sub\-group message list (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: write_calls_count
                                
                                	No. of calls to function to write outbound data
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_queue_calls_count
                                
                                	No. of Calls to function to process write queue
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_queue_messages_count
                                
                                	Number of write queue messages processed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_queue_time
                                
                                	Time spent processing write queue (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_subgroup_calls_count
                                
                                	No. of calls to to funvction to process sub\-group message list
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_subgroup_messages_count
                                
                                	Number of sub\-group messages processed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.data_bytes_read = None
                                    self.data_bytes_written = None
                                    self.high_throttled_read_count = None
                                    self.inbound_update_messages = None
                                    self.inbound_update_messages_time = None
                                    self.io_read_time = None
                                    self.io_write_time = None
                                    self.low_throttled_read_count = None
                                    self.lpts_calls = None
                                    self.lpts_set_up_time = None
                                    self.read_calls_count = None
                                    self.read_messages_count = None
                                    self.read_throttles_count = None
                                    self.subgroup_list_time = None
                                    self.write_calls_count = None
                                    self.write_queue_calls_count = None
                                    self.write_queue_messages_count = None
                                    self.write_queue_time = None
                                    self.write_subgroup_calls_count = None
                                    self.write_subgroup_messages_count = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:vrf'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.data_bytes_read is not None:
                                        return True

                                    if self.data_bytes_written is not None:
                                        return True

                                    if self.high_throttled_read_count is not None:
                                        return True

                                    if self.inbound_update_messages is not None:
                                        return True

                                    if self.inbound_update_messages_time is not None:
                                        return True

                                    if self.io_read_time is not None:
                                        return True

                                    if self.io_write_time is not None:
                                        return True

                                    if self.low_throttled_read_count is not None:
                                        return True

                                    if self.lpts_calls is not None:
                                        return True

                                    if self.lpts_set_up_time is not None:
                                        return True

                                    if self.read_calls_count is not None:
                                        return True

                                    if self.read_messages_count is not None:
                                        return True

                                    if self.read_throttles_count is not None:
                                        return True

                                    if self.subgroup_list_time is not None:
                                        return True

                                    if self.write_calls_count is not None:
                                        return True

                                    if self.write_queue_calls_count is not None:
                                        return True

                                    if self.write_queue_messages_count is not None:
                                        return True

                                    if self.write_queue_time is not None:
                                        return True

                                    if self.write_subgroup_calls_count is not None:
                                        return True

                                    if self.write_subgroup_messages_count is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Vrf']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:performance-statistics'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.global_ is not None and self.global_._has_data():
                                    return True

                                if self.vrf is not None and self.vrf._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:process-info'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.global_ is not None and self.global_._has_data():
                                return True

                            if self.performance_statistics is not None and self.performance_statistics._has_data():
                                return True

                            if self.process_instance is not None:
                                return True

                            if self.vrf is not None and self.vrf._has_data():
                                return True

                            if self.vrf_name is not None:
                                return True

                            if self.vrf_totals is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo']['meta_info']


                    class Sessions(object):
                        """
                        The BGP session table
                        
                        .. attribute:: session
                        
                        	A BGP session table entry
                        	**type**\: list of    :py:class:`Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.session = YList()
                            self.session.parent = self
                            self.session.name = 'session'


                        class Session(object):
                            """
                            A BGP session table entry
                            
                            .. attribute:: neighbor_address  <key>
                            
                            	Neighbor address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: connection_local_address
                            
                            	Local address for the connection
                            	**type**\:   :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress>`
                            
                            .. attribute:: connection_remote_address
                            
                            	Remote address for the connection
                            	**type**\:   :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress>`
                            
                            .. attribute:: connection_state
                            
                            	State of connection
                            	**type**\:   :py:class:`BgpConnStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnStateEnum>`
                            
                            .. attribute:: description
                            
                            	Description
                            	**type**\:  str
                            
                            .. attribute:: is_local_address_configured
                            
                            	Local address configured for the neighbor connection
                            	**type**\:  bool
                            
                            .. attribute:: local_as
                            
                            	Local AS number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: messages_queued_in
                            
                            	No. of msgs on receive queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: messages_queued_out
                            
                            	No. of messages on send queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_enabled
                            
                            	Neighbor supports NSR
                            	**type**\:  bool
                            
                            .. attribute:: nsr_state
                            
                            	NSR state
                            	**type**\:   :py:class:`BgpSyncNbrNsrStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrStateEnum>`
                            
                            .. attribute:: postit_pending
                            
                            	Nbr has postits pending
                            	**type**\:  bool
                            
                            .. attribute:: remote_as
                            
                            	Remote AS number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: speaker_id
                            
                            	Speaker this neighbor is allocated to
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: vrf_name
                            
                            	Name of the VRF
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.neighbor_address = None
                                self.connection_local_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress()
                                self.connection_local_address.parent = self
                                self.connection_remote_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress()
                                self.connection_remote_address.parent = self
                                self.connection_state = None
                                self.description = None
                                self.is_local_address_configured = None
                                self.local_as = None
                                self.messages_queued_in = None
                                self.messages_queued_out = None
                                self.nsr_enabled = None
                                self.nsr_state = None
                                self.postit_pending = None
                                self.remote_as = None
                                self.speaker_id = None
                                self.vrf_name = None


                            class ConnectionLocalAddress(object):
                                """
                                Local address for the connection
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpnvpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2VpnvplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4mdt_address = None
                                    self.ipv4mvpn_address = None
                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                    self.ipv4sr_policy_address.parent = self
                                    self.ipv4vpn_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                    self.ipv6sr_policy_address.parent = self
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_flowspec_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.l2vpn_evpn_address = None
                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2VpnvplsAddress()
                                    self.l2vpnvpls_address.parent = self
                                    self.ls_ls_address = None
                                    self.rt_constraint_address = None


                                class L2VpnvplsAddress(object):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2VpnvplsAddress']['meta_info']


                                class L2VpnMspwAddress(object):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2VpnMspwAddress']['meta_info']


                                class Ipv4SrPolicyAddress(object):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress']['meta_info']


                                class Ipv6SrPolicyAddress(object):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv6_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv6_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connection-local-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.afi is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv4_flowspec_address is not None:
                                        return True

                                    if self.ipv4_label_address is not None:
                                        return True

                                    if self.ipv4_mcast_address is not None:
                                        return True

                                    if self.ipv4_tunnel_address is not None:
                                        return True

                                    if self.ipv4mdt_address is not None:
                                        return True

                                    if self.ipv4mvpn_address is not None:
                                        return True

                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                        return True

                                    if self.ipv4vpn_address is not None:
                                        return True

                                    if self.ipv4vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv4vpna_mcastddress is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    if self.ipv6_flowspec_address is not None:
                                        return True

                                    if self.ipv6_label_address is not None:
                                        return True

                                    if self.ipv6_mcast_address is not None:
                                        return True

                                    if self.ipv6mvpn_address is not None:
                                        return True

                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                        return True

                                    if self.ipv6vpn_address is not None:
                                        return True

                                    if self.ipv6vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv6vpn_mcast_address is not None:
                                        return True

                                    if self.l2vpn_evpn_address is not None:
                                        return True

                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                        return True

                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                        return True

                                    if self.ls_ls_address is not None:
                                        return True

                                    if self.rt_constraint_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress']['meta_info']


                            class ConnectionRemoteAddress(object):
                                """
                                Remote address for the connection
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpnvpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2VpnvplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4mdt_address = None
                                    self.ipv4mvpn_address = None
                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                    self.ipv4sr_policy_address.parent = self
                                    self.ipv4vpn_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                    self.ipv6sr_policy_address.parent = self
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_flowspec_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.l2vpn_evpn_address = None
                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2VpnvplsAddress()
                                    self.l2vpnvpls_address.parent = self
                                    self.ls_ls_address = None
                                    self.rt_constraint_address = None


                                class L2VpnvplsAddress(object):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2VpnvplsAddress']['meta_info']


                                class L2VpnMspwAddress(object):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2VpnMspwAddress']['meta_info']


                                class Ipv4SrPolicyAddress(object):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress']['meta_info']


                                class Ipv6SrPolicyAddress(object):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv6_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv6_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connection-remote-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.afi is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv4_flowspec_address is not None:
                                        return True

                                    if self.ipv4_label_address is not None:
                                        return True

                                    if self.ipv4_mcast_address is not None:
                                        return True

                                    if self.ipv4_tunnel_address is not None:
                                        return True

                                    if self.ipv4mdt_address is not None:
                                        return True

                                    if self.ipv4mvpn_address is not None:
                                        return True

                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                        return True

                                    if self.ipv4vpn_address is not None:
                                        return True

                                    if self.ipv4vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv4vpna_mcastddress is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    if self.ipv6_flowspec_address is not None:
                                        return True

                                    if self.ipv6_label_address is not None:
                                        return True

                                    if self.ipv6_mcast_address is not None:
                                        return True

                                    if self.ipv6mvpn_address is not None:
                                        return True

                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                        return True

                                    if self.ipv6vpn_address is not None:
                                        return True

                                    if self.ipv6vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv6vpn_mcast_address is not None:
                                        return True

                                    if self.l2vpn_evpn_address is not None:
                                        return True

                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                        return True

                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                        return True

                                    if self.ls_ls_address is not None:
                                        return True

                                    if self.rt_constraint_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.neighbor_address is None:
                                    raise YPYModelError('Key property neighbor_address is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:session[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address = ' + str(self.neighbor_address) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.neighbor_address is not None:
                                    return True

                                if self.connection_local_address is not None and self.connection_local_address._has_data():
                                    return True

                                if self.connection_remote_address is not None and self.connection_remote_address._has_data():
                                    return True

                                if self.connection_state is not None:
                                    return True

                                if self.description is not None:
                                    return True

                                if self.is_local_address_configured is not None:
                                    return True

                                if self.local_as is not None:
                                    return True

                                if self.messages_queued_in is not None:
                                    return True

                                if self.messages_queued_out is not None:
                                    return True

                                if self.nsr_enabled is not None:
                                    return True

                                if self.nsr_state is not None:
                                    return True

                                if self.postit_pending is not None:
                                    return True

                                if self.remote_as is not None:
                                    return True

                                if self.speaker_id is not None:
                                    return True

                                if self.vrf_name is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sessions'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.session is not None:
                                for child_ref in self.session:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions']['meta_info']


                    class Neighbors(object):
                        """
                        The BGP Neighbor table
                        
                        .. attribute:: neighbor
                        
                        	A BGP Neighbor table entry
                        	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.neighbor = YList()
                            self.neighbor.parent = self
                            self.neighbor.name = 'neighbor'


                        class Neighbor(object):
                            """
                            A BGP Neighbor table entry
                            
                            .. attribute:: neighbor_address  <key>
                            
                            	Neighbor address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: active_bmp_servers
                            
                            	BMP Servers to which the neighbor sends logs
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: actual_last_write_bytes
                            
                            	Actual size of last write
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: actual_last_write_reset_bytes
                            
                            	Actual size of last write before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: actual_second_last_write_bytes
                            
                            	Actual size of second last write
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: actual_second_last_write_reset_bytes
                            
                            	Actual size of second last write before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: af_data
                            
                            	Address family specific neighbor data
                            	**type**\: list of    :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData>`
                            
                            .. attribute:: attempted_last_write_bytes
                            
                            	Attempted size of last write
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attempted_last_write_reset_bytes
                            
                            	Attempted size of last write before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attempted_second_last_write_bytes
                            
                            	Attempted size of second last write
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attempted_second_last_write_reset_bytes
                            
                            	Attempted size of second last write before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_minintervalval
                            
                            	BFD Mininterval for this peer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_multiplierval
                            
                            	BFD Multiplier for this peer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_session_created_state
                            
                            	BFD state for this peer
                            	**type**\:   :py:class:`BgpBfdStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdStateEnum>`
                            
                            .. attribute:: bfd_session_enable_mode
                            
                            	BFD enable mode for this peer
                            	**type**\:   :py:class:`BgpBfdEnableModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdEnableModeEnum>`
                            
                            .. attribute:: bfd_session_state
                            
                            	BFD state for this peer
                            	**type**\:   :py:class:`BgpBfdStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdStateEnum>`
                            
                            .. attribute:: bfd_state_ts
                            
                            	Timestamp since when nbr is in this bfd state
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bytes_read
                            
                            	Total bytes read
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: bytes_written
                            
                            	Total bytes written by write thread
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: configured_hold_time
                            
                            	Hold time (in secs) configured for this connection
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: configured_keepalive
                            
                            	Keepalive time (in secs) configured for this connection
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: configured_min_acc_hold_time
                            
                            	Minimum acceptable hold time from neighbor (in secs) configured for this connection
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: connect_retry_interval
                            
                            	Time (in secs) for connect retry timer
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: connection_admin_status
                            
                            	Administrative status of connection
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: connection_down_count
                            
                            	Number of times connection was dropped
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: connection_established_time
                            
                            	Time (in secs) that the connection has been established
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: connection_local_address
                            
                            	Local address for the connection
                            	**type**\:   :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress>`
                            
                            .. attribute:: connection_local_port
                            
                            	Local port for the connection
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: connection_remote_address
                            
                            	Remote address for the connection
                            	**type**\:   :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress>`
                            
                            .. attribute:: connection_remote_port
                            
                            	Remote port for the connection
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: connection_state
                            
                            	State of connection
                            	**type**\:   :py:class:`BgpConnStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnStateEnum>`
                            
                            .. attribute:: connection_up_count
                            
                            	Number of times the connection was established
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: count_last_write
                            
                            	Count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: description
                            
                            	Description
                            	**type**\:  str
                            
                            .. attribute:: discard_as4_path
                            
                            	Discard AS4\_PATH in case there is a discrepancy in merging AS\_PATH and AS4\_PATH,retain ASPATH
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: discard_data_bytes
                            
                            	Remaining discard data (bytes) on Standby
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: dmz_link_bandwidth
                            
                            	Bandwidth of link to single\-hop eBGP peer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: dynamic_neighbor
                            
                            	Dynamic neighbor
                            	**type**\:  bool
                            
                            .. attribute:: ebgp_recv_dmz
                            
                            	Receive Bandwidth of link to single\-hop eBGP peer
                            	**type**\:  bool
                            
                            .. attribute:: ebgp_send_dmz_mode
                            
                            	Ebgp send dmz link bw mode
                            	**type**\:   :py:class:`BgpEbgpSendDmzEnableModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableModeEnum>`
                            
                            .. attribute:: ebgp_time_to_live
                            
                            	Maximum number of hops for external BGP neighbor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: egress_peer_engineering_enabled
                            
                            	Indicates if Egress Peer Engineering is enabled
                            	**type**\:  bool
                            
                            .. attribute:: error_notifies_received
                            
                            	Number of error notifications received on the connection
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: error_notifies_sent
                            
                            	Number of error notifications sent on the connection
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fpbsn_offset
                            
                            	First standby PDU boundary SeqNo offset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fssn_offset
                            
                            	First standby SeqNo offset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: gr_restart_time
                            
                            	Neighbor restart time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: gr_stale_path_time
                            
                            	Neighbor stale\-path time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: graceful_maintenance
                            
                            	Graceful Maintenance
                            	**type**\:   :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.GracefulMaintenance>`
                            
                            .. attribute:: graceful_restart_enabled_nbr
                            
                            	Neighbor supports graceful\-restart
                            	**type**\:  bool
                            
                            .. attribute:: has_internal_link
                            
                            	Internal link to neighbor
                            	**type**\:  bool
                            
                            .. attribute:: hold_time
                            
                            	Hold time (in secs) negotiated for this connection
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: ignore_connected
                            
                            	If true, the VPN client isan IBGP CE peer
                            	**type**\:  bool
                            
                            .. attribute:: internal_vpn_client
                            
                            	If true, don't do NHconnected check for nbr
                            	**type**\:  bool
                            
                            .. attribute:: io_armed
                            
                            	If true, socket has beenauto\-armed for io control
                            	**type**\:  bool
                            
                            .. attribute:: is4_byte_as_capability_received
                            
                            	4\-byte AScapability received
                            	**type**\:  bool
                            
                            .. attribute:: is4_byte_as_capability_sent
                            
                            	4\-byte AScapability Snt
                            	**type**\:  bool
                            
                            .. attribute:: is_administratively_shut_down
                            
                            	Neighbor is administratively shut down
                            	**type**\:  bool
                            
                            .. attribute:: is_capability_negotiation_performed
                            
                            	Capability negotiation performed
                            	**type**\:  bool
                            
                            .. attribute:: is_capability_negotiation_suppressed
                            
                            	Capability negotiation suppressed
                            	**type**\:  bool
                            
                            .. attribute:: is_ebgp_multihop_bgpmpls_forwarding_disabled
                            
                            	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_ebgp_peer_as_league
                            
                            	EBGP peer belongs to AS League
                            	**type**\:  bool
                            
                            .. attribute:: is_ebgp_peer_common_admin
                            
                            	EBGP peer with common administation
                            	**type**\:  bool
                            
                            .. attribute:: is_external_neighbor_not_directly_connected
                            
                            	External neighbor not directly connected
                            	**type**\:  bool
                            
                            .. attribute:: is_gr_aware
                            
                            	GR awareness received
                            	**type**\:  bool
                            
                            .. attribute:: is_local_address_configured
                            
                            	Local address configured for the neighbor connection
                            	**type**\:  bool
                            
                            .. attribute:: is_neighbor_max_prefix_shutdown
                            
                            	Neighbor shut down because it exceeded max prfx count
                            	**type**\:  bool
                            
                            .. attribute:: is_out_of_memory_forced_up
                            
                            	Neighbor forced up during a low memory condition
                            	**type**\:  bool
                            
                            .. attribute:: is_out_of_memory_shutdown
                            
                            	Neighbor shut down during a SEVERE low memory condition
                            	**type**\:  bool
                            
                            .. attribute:: is_passive_close
                            
                            	If true, active socket canbe closed if passive openis received for a GRcapable neighbor
                            	**type**\:  bool
                            
                            .. attribute:: is_read_disabled
                            
                            	If true, socket read isdisabled
                            	**type**\:  bool
                            
                            .. attribute:: is_route_refresh_capability_received
                            
                            	Route refresh capability received
                            	**type**\:  bool
                            
                            .. attribute:: is_route_refresh_old_capability_received
                            
                            	Route refresh old capability received
                            	**type**\:  bool
                            
                            .. attribute:: keep_alive_time
                            
                            	Keepalive time (in secs) negotiated for this connection
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: last_ackd_seq_no
                            
                            	SeqNo of the last Ackd byte
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_k_aerror_reset
                            
                            	Duration (in secs) since last time that an error was encountered after KA expiry
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_k_aexpiry_reset
                            
                            	Time (in secs) since last KA timer expiry before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_k_anotsent_reset
                            
                            	Duration (in secs) since last time that KA was not sent before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_k_astart_reset
                            
                            	Time (in secs) since the last KA timer start before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_notify_error_code
                            
                            	Code for the last error notification seen on the connection
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: last_notify_error_subcode
                            
                            	Error subcode of the last error notification seen on the connection
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: last_write_event
                            
                            	Time (in secs) since last write thread event
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: local_as
                            
                            	Local AS number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_as_dual_as
                            
                            	Local AS Dual\-AS option
                            	**type**\:  bool
                            
                            .. attribute:: local_as_dual_as_mode_native
                            
                            	Applies only if Local AS Dual\-AS option is enabled. Indicates if Dual\-AS mode is native
                            	**type**\:  bool
                            
                            .. attribute:: local_as_no_prepend
                            
                            	Option to not prepend the Local AS to announcements
                            	**type**\:  bool
                            
                            .. attribute:: local_as_replace_as
                            
                            	Local AS Replace\-AS option
                            	**type**\:  bool
                            
                            .. attribute:: message_statistics
                            
                            	Message statistics
                            	**type**\:   :py:class:`MessageStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics>`
                            
                            .. attribute:: messages_queued_in
                            
                            	No. of msgs on receive queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: messages_queued_out
                            
                            	No. of messages on send queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: messages_received
                            
                            	Number of messages received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: messages_sent
                            
                            	Number of messages sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: min_advertise_interval
                            
                            	Minimum advertisement interval, secs part
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: min_advertise_interval_msecs
                            
                            	Minimum advertisement interval, msecs part
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: millisecond
                            
                            .. attribute:: min_origination_interval
                            
                            	Minimum origination interval (in secs)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: msg_log_in
                            
                            	Message in log count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msg_log_out
                            
                            	Message out log count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: multi_protocol_capability_received
                            
                            	Multi\-protocol capability has been received
                            	**type**\:  bool
                            
                            .. attribute:: nbr_cluster_id
                            
                            	Cluster id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nbr_enforce_first_as
                            
                            	Neighbor enforce first AS
                            	**type**\:  bool
                            
                            .. attribute:: nbr_in_cluster
                            
                            	Type of cluster\_id\:undefined/number/Ip address
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: negotiated_protocol_version
                            
                            	Negotiated protocol version
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: neighbor_interface_handle
                            
                            	Interface Handle of Neighbor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_local_as
                            
                            	Local AS configured on the neighbor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_enabled
                            
                            	Neighbor supports NSR
                            	**type**\:  bool
                            
                            .. attribute:: nsr_state
                            
                            	NSR state
                            	**type**\:   :py:class:`BgpSyncNbrNsrStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrStateEnum>`
                            
                            .. attribute:: open_check_error_code
                            
                            	Open check error code
                            	**type**\:   :py:class:`BgpOpenCheckErrEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpOpenCheckErrEnum>`
                            
                            .. attribute:: peer_error_code
                            
                            	If peer closed, error received from transport
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: peer_reset_reason
                            
                            	Reason for last peer close event
                            	**type**\:   :py:class:`BgpPeerResetReasonIndexEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPeerResetReasonIndexEnum>`
                            
                            .. attribute:: performance_statistics
                            
                            	Performance statistics
                            	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.PerformanceStatistics>`
                            
                            .. attribute:: previous_connection_state
                            
                            	Previous state of connection
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: read_armed
                            
                            	If true, socket has beenauto\-armed for read
                            	**type**\:  bool
                            
                            .. attribute:: received_notification_info
                            
                            	Information on the last notification received
                            	**type**\:   :py:class:`ReceivedNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo>`
                            
                            .. attribute:: remote_as
                            
                            	Remote AS number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_as_number
                            
                            	Remote AS number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reset_notification_sent
                            
                            	Notification was sent during last reset
                            	**type**\:  bool
                            
                            .. attribute:: reset_reason
                            
                            	Reason for last connection reset
                            	**type**\:   :py:class:`BgpResetReasonIndexEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndexEnum>`
                            
                            .. attribute:: router_id
                            
                            	Router ID for the neighbor
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: rpki_allow_invalid
                            
                            	Prefix v. allow invalid
                            	**type**\:  bool
                            
                            .. attribute:: rpki_disable
                            
                            	Prefix validation disabled
                            	**type**\:  bool
                            
                            .. attribute:: rpki_signal_ibgp
                            
                            	Prefix v. signal ibgp
                            	**type**\:  bool
                            
                            .. attribute:: rpki_use_validity
                            
                            	Prefix v. use validity
                            	**type**\:  bool
                            
                            .. attribute:: second_last_k_aexpiry_reset
                            
                            	Time (in secs) since second last KA timer expiry before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: second_last_k_astart_reset
                            
                            	Time (in secs) since the second last KA timer start before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: second_last_write_event
                            
                            	Time (in secs) since second last write thread event
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: send_notification_info
                            
                            	Information on the last notification sent
                            	**type**\:   :py:class:`SendNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo>`
                            
                            .. attribute:: socket_read_bytes
                            
                            	Total read bytes value insocket\-lib
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: speaker_id
                            
                            	Speaker this neighbor is allocated to
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: standby_rp
                            
                            	Standby RP socket inited for Active Open
                            	**type**\:  bool
                            
                            .. attribute:: suppress4_byte_as
                            
                            	Suppress 4byteas capability
                            	**type**\:  bool
                            
                            .. attribute:: tcp_init_sync_done_time_spec
                            
                            	Time when neighbor entered TCP Init Sync Done
                            	**type**\:   :py:class:`TcpInitSyncDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec>`
                            
                            .. attribute:: tcp_init_sync_phase_two_time_spec
                            
                            	Time when neighbor entered TCP Init Sync Phase Two
                            	**type**\:   :py:class:`TcpInitSyncPhaseTwoTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec>`
                            
                            .. attribute:: tcp_init_sync_time_spec
                            
                            	Time When neighbor entered TCP Init Sync
                            	**type**\:   :py:class:`TcpInitSyncTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncTimeSpec>`
                            
                            .. attribute:: tcp_session_open_mode
                            
                            	The TCP mode to be used to set up BGP session with the neighbor
                            	**type**\:   :py:class:`BgpTcpModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpModeEnum>`
                            
                            .. attribute:: tcpmss
                            
                            	Neighbor TCP Maximum Segment                     size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_last_cb
                            
                            	CB
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: time_last_cb_reset
                            
                            	Last CB before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_last_fb
                            
                            	FB
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: time_since_connection_last_dropped
                            
                            	Time since the connection last went down (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: time_since_last_read
                            
                            	Time (in secs) since last read
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: time_since_last_read_reset
                            
                            	Time (in secs) since last read before last reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: time_since_last_update
                            
                            	Time (in secs) since last update message was received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: time_since_last_write
                            
                            	Time (in secs) since last write
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: time_since_last_write_reset
                            
                            	Time (in secs) since last write before last reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: time_since_second_last_write
                            
                            	Time (in secs) since second  last write
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: time_since_second_last_write_reset
                            
                            	Time (in secs) since last write before last reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: tos_type
                            
                            	Precedence or DSCP type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tos_value
                            
                            	Precedence or DSCP value
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ttl_security_enabled
                            
                            	TTL Security enabled
                            	**type**\:  bool
                            
                            .. attribute:: update_bytes_read
                            
                            	Total update bytes read
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: update_messages_in
                            
                            	No. of update msgs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_messages_out
                            
                            	No. of update messages sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vrf_name
                            
                            	Name of the VRF
                            	**type**\:  str
                            
                            .. attribute:: write_armed
                            
                            	If true, socket has beenauto\-armed for write
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.neighbor_address = None
                                self.active_bmp_servers = None
                                self.actual_last_write_bytes = None
                                self.actual_last_write_reset_bytes = None
                                self.actual_second_last_write_bytes = None
                                self.actual_second_last_write_reset_bytes = None
                                self.af_data = YList()
                                self.af_data.parent = self
                                self.af_data.name = 'af_data'
                                self.attempted_last_write_bytes = None
                                self.attempted_last_write_reset_bytes = None
                                self.attempted_second_last_write_bytes = None
                                self.attempted_second_last_write_reset_bytes = None
                                self.bfd_minintervalval = None
                                self.bfd_multiplierval = None
                                self.bfd_session_created_state = None
                                self.bfd_session_enable_mode = None
                                self.bfd_session_state = None
                                self.bfd_state_ts = None
                                self.bytes_read = None
                                self.bytes_written = None
                                self.configured_hold_time = None
                                self.configured_keepalive = None
                                self.configured_min_acc_hold_time = None
                                self.connect_retry_interval = None
                                self.connection_admin_status = None
                                self.connection_down_count = None
                                self.connection_established_time = None
                                self.connection_local_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress()
                                self.connection_local_address.parent = self
                                self.connection_local_port = None
                                self.connection_remote_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress()
                                self.connection_remote_address.parent = self
                                self.connection_remote_port = None
                                self.connection_state = None
                                self.connection_up_count = None
                                self.count_last_write = None
                                self.description = None
                                self.discard_as4_path = None
                                self.discard_data_bytes = None
                                self.dmz_link_bandwidth = None
                                self.dynamic_neighbor = None
                                self.ebgp_recv_dmz = None
                                self.ebgp_send_dmz_mode = None
                                self.ebgp_time_to_live = None
                                self.egress_peer_engineering_enabled = None
                                self.error_notifies_received = None
                                self.error_notifies_sent = None
                                self.fpbsn_offset = None
                                self.fssn_offset = None
                                self.gr_restart_time = None
                                self.gr_stale_path_time = None
                                self.graceful_maintenance = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.GracefulMaintenance()
                                self.graceful_maintenance.parent = self
                                self.graceful_restart_enabled_nbr = None
                                self.has_internal_link = None
                                self.hold_time = None
                                self.ignore_connected = None
                                self.internal_vpn_client = None
                                self.io_armed = None
                                self.is4_byte_as_capability_received = None
                                self.is4_byte_as_capability_sent = None
                                self.is_administratively_shut_down = None
                                self.is_capability_negotiation_performed = None
                                self.is_capability_negotiation_suppressed = None
                                self.is_ebgp_multihop_bgpmpls_forwarding_disabled = None
                                self.is_ebgp_peer_as_league = None
                                self.is_ebgp_peer_common_admin = None
                                self.is_external_neighbor_not_directly_connected = None
                                self.is_gr_aware = None
                                self.is_local_address_configured = None
                                self.is_neighbor_max_prefix_shutdown = None
                                self.is_out_of_memory_forced_up = None
                                self.is_out_of_memory_shutdown = None
                                self.is_passive_close = None
                                self.is_read_disabled = None
                                self.is_route_refresh_capability_received = None
                                self.is_route_refresh_old_capability_received = None
                                self.keep_alive_time = None
                                self.last_ackd_seq_no = None
                                self.last_k_aerror_reset = None
                                self.last_k_aexpiry_reset = None
                                self.last_k_anotsent_reset = None
                                self.last_k_astart_reset = None
                                self.last_notify_error_code = None
                                self.last_notify_error_subcode = None
                                self.last_write_event = None
                                self.local_as = None
                                self.local_as_dual_as = None
                                self.local_as_dual_as_mode_native = None
                                self.local_as_no_prepend = None
                                self.local_as_replace_as = None
                                self.message_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics()
                                self.message_statistics.parent = self
                                self.messages_queued_in = None
                                self.messages_queued_out = None
                                self.messages_received = None
                                self.messages_sent = None
                                self.min_advertise_interval = None
                                self.min_advertise_interval_msecs = None
                                self.min_origination_interval = None
                                self.msg_log_in = None
                                self.msg_log_out = None
                                self.multi_protocol_capability_received = None
                                self.nbr_cluster_id = None
                                self.nbr_enforce_first_as = None
                                self.nbr_in_cluster = None
                                self.negotiated_protocol_version = None
                                self.neighbor_interface_handle = None
                                self.neighbor_local_as = None
                                self.nsr_enabled = None
                                self.nsr_state = None
                                self.open_check_error_code = None
                                self.peer_error_code = None
                                self.peer_reset_reason = None
                                self.performance_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.PerformanceStatistics()
                                self.performance_statistics.parent = self
                                self.previous_connection_state = None
                                self.read_armed = None
                                self.received_notification_info = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo()
                                self.received_notification_info.parent = self
                                self.remote_as = None
                                self.remote_as_number = None
                                self.reset_notification_sent = None
                                self.reset_reason = None
                                self.router_id = None
                                self.rpki_allow_invalid = None
                                self.rpki_disable = None
                                self.rpki_signal_ibgp = None
                                self.rpki_use_validity = None
                                self.second_last_k_aexpiry_reset = None
                                self.second_last_k_astart_reset = None
                                self.second_last_write_event = None
                                self.send_notification_info = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo()
                                self.send_notification_info.parent = self
                                self.socket_read_bytes = None
                                self.speaker_id = None
                                self.standby_rp = None
                                self.suppress4_byte_as = None
                                self.tcp_init_sync_done_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec()
                                self.tcp_init_sync_done_time_spec.parent = self
                                self.tcp_init_sync_phase_two_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec()
                                self.tcp_init_sync_phase_two_time_spec.parent = self
                                self.tcp_init_sync_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncTimeSpec()
                                self.tcp_init_sync_time_spec.parent = self
                                self.tcp_session_open_mode = None
                                self.tcpmss = None
                                self.time_last_cb = None
                                self.time_last_cb_reset = None
                                self.time_last_fb = None
                                self.time_since_connection_last_dropped = None
                                self.time_since_last_read = None
                                self.time_since_last_read_reset = None
                                self.time_since_last_update = None
                                self.time_since_last_write = None
                                self.time_since_last_write_reset = None
                                self.time_since_second_last_write = None
                                self.time_since_second_last_write_reset = None
                                self.tos_type = None
                                self.tos_value = None
                                self.ttl_security_enabled = None
                                self.update_bytes_read = None
                                self.update_messages_in = None
                                self.update_messages_out = None
                                self.vrf_name = None
                                self.write_armed = None


                            class ConnectionLocalAddress(object):
                                """
                                Local address for the connection
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpnvpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnvplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4mdt_address = None
                                    self.ipv4mvpn_address = None
                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                    self.ipv4sr_policy_address.parent = self
                                    self.ipv4vpn_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                    self.ipv6sr_policy_address.parent = self
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_flowspec_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.l2vpn_evpn_address = None
                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnvplsAddress()
                                    self.l2vpnvpls_address.parent = self
                                    self.ls_ls_address = None
                                    self.rt_constraint_address = None


                                class L2VpnvplsAddress(object):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnvplsAddress']['meta_info']


                                class L2VpnMspwAddress(object):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress']['meta_info']


                                class Ipv4SrPolicyAddress(object):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress']['meta_info']


                                class Ipv6SrPolicyAddress(object):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv6_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv6_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connection-local-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.afi is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv4_flowspec_address is not None:
                                        return True

                                    if self.ipv4_label_address is not None:
                                        return True

                                    if self.ipv4_mcast_address is not None:
                                        return True

                                    if self.ipv4_tunnel_address is not None:
                                        return True

                                    if self.ipv4mdt_address is not None:
                                        return True

                                    if self.ipv4mvpn_address is not None:
                                        return True

                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                        return True

                                    if self.ipv4vpn_address is not None:
                                        return True

                                    if self.ipv4vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv4vpna_mcastddress is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    if self.ipv6_flowspec_address is not None:
                                        return True

                                    if self.ipv6_label_address is not None:
                                        return True

                                    if self.ipv6_mcast_address is not None:
                                        return True

                                    if self.ipv6mvpn_address is not None:
                                        return True

                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                        return True

                                    if self.ipv6vpn_address is not None:
                                        return True

                                    if self.ipv6vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv6vpn_mcast_address is not None:
                                        return True

                                    if self.l2vpn_evpn_address is not None:
                                        return True

                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                        return True

                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                        return True

                                    if self.ls_ls_address is not None:
                                        return True

                                    if self.rt_constraint_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress']['meta_info']


                            class ConnectionRemoteAddress(object):
                                """
                                Remote address for the connection
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpnvpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnvplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4mdt_address = None
                                    self.ipv4mvpn_address = None
                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                    self.ipv4sr_policy_address.parent = self
                                    self.ipv4vpn_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                    self.ipv6sr_policy_address.parent = self
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_flowspec_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.l2vpn_evpn_address = None
                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnvplsAddress()
                                    self.l2vpnvpls_address.parent = self
                                    self.ls_ls_address = None
                                    self.rt_constraint_address = None


                                class L2VpnvplsAddress(object):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnvplsAddress']['meta_info']


                                class L2VpnMspwAddress(object):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress']['meta_info']


                                class Ipv4SrPolicyAddress(object):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress']['meta_info']


                                class Ipv6SrPolicyAddress(object):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv6_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv6_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connection-remote-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.afi is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv4_flowspec_address is not None:
                                        return True

                                    if self.ipv4_label_address is not None:
                                        return True

                                    if self.ipv4_mcast_address is not None:
                                        return True

                                    if self.ipv4_tunnel_address is not None:
                                        return True

                                    if self.ipv4mdt_address is not None:
                                        return True

                                    if self.ipv4mvpn_address is not None:
                                        return True

                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                        return True

                                    if self.ipv4vpn_address is not None:
                                        return True

                                    if self.ipv4vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv4vpna_mcastddress is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    if self.ipv6_flowspec_address is not None:
                                        return True

                                    if self.ipv6_label_address is not None:
                                        return True

                                    if self.ipv6_mcast_address is not None:
                                        return True

                                    if self.ipv6mvpn_address is not None:
                                        return True

                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                        return True

                                    if self.ipv6vpn_address is not None:
                                        return True

                                    if self.ipv6vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv6vpn_mcast_address is not None:
                                        return True

                                    if self.l2vpn_evpn_address is not None:
                                        return True

                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                        return True

                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                        return True

                                    if self.ls_ls_address is not None:
                                        return True

                                    if self.rt_constraint_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress']['meta_info']


                            class SendNotificationInfo(object):
                                """
                                Information on the last notification sent
                                
                                .. attribute:: last_notification_data
                                
                                	Message data in last notification
                                	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData>`
                                
                                .. attribute:: notification_error_code
                                
                                	Error code in last notification
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: notification_error_subcode
                                
                                	Error subcode in last notification
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: time_since_last_notification
                                
                                	Time since the last notification was sent or received (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.last_notification_data = YList()
                                    self.last_notification_data.parent = self
                                    self.last_notification_data.name = 'last_notification_data'
                                    self.notification_error_code = None
                                    self.notification_error_subcode = None
                                    self.time_since_last_notification = None


                                class LastNotificationData(object):
                                    """
                                    Message data in last notification
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-notification-data'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:send-notification-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.last_notification_data is not None:
                                        for child_ref in self.last_notification_data:
                                            if child_ref._has_data():
                                                return True

                                    if self.notification_error_code is not None:
                                        return True

                                    if self.notification_error_subcode is not None:
                                        return True

                                    if self.time_since_last_notification is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo']['meta_info']


                            class ReceivedNotificationInfo(object):
                                """
                                Information on the last notification received
                                
                                .. attribute:: last_notification_data
                                
                                	Message data in last notification
                                	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData>`
                                
                                .. attribute:: notification_error_code
                                
                                	Error code in last notification
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: notification_error_subcode
                                
                                	Error subcode in last notification
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: time_since_last_notification
                                
                                	Time since the last notification was sent or received (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.last_notification_data = YList()
                                    self.last_notification_data.parent = self
                                    self.last_notification_data.name = 'last_notification_data'
                                    self.notification_error_code = None
                                    self.notification_error_subcode = None
                                    self.time_since_last_notification = None


                                class LastNotificationData(object):
                                    """
                                    Message data in last notification
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-notification-data'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:received-notification-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.last_notification_data is not None:
                                        for child_ref in self.last_notification_data:
                                            if child_ref._has_data():
                                                return True

                                    if self.notification_error_code is not None:
                                        return True

                                    if self.notification_error_subcode is not None:
                                        return True

                                    if self.time_since_last_notification is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo']['meta_info']


                            class PerformanceStatistics(object):
                                """
                                Performance statistics
                                
                                .. attribute:: active_collision
                                
                                	Number of Closed Active connections for this neighbor due to collision 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: actives
                                
                                	Number of retried Active opens for this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: control_to_read_thread_trigger
                                
                                	Number of times io\-control thread trigger read thread
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: control_to_write_thread_trigger
                                
                                	Number of times io\-control thread trigger write thread
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: data_bytes_read
                                
                                	No. of bytes of data read
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: data_bytes_written
                                
                                	No. of data bytes written
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: failed_post_actives
                                
                                	Number of Active Opens that failed in the Post Active State for this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: high_throttled_read
                                
                                	Num of socket reads after nbr crossed high threshold
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: inbound_update_messages
                                
                                	Number of inbound update messages processed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: inbound_update_messages_time
                                
                                	Time spent processing inbound update messages (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: io_read_time
                                
                                	Time spent reading inbound data (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: io_write_time
                                
                                	Time spent writing outbound data (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: last_nsr_scoped_sync
                                
                                	Last time NSR scoped syncwas done for the neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_sent_seq_no
                                
                                	Seq No of the last sent byte
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low_throttled_read
                                
                                	Num socket reads after nbrs crossed low threshold
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_read_size
                                
                                	Size of largest socket (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: nbr_fd
                                
                                	Primary FD, per nbr
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: nbr_flags
                                
                                	Nbr flags, per thread
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: network_status
                                
                                	Socket status, TRUE if socket closed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_oper_down_count
                                
                                	Number of times NSR scoped sync has been done
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: passive_collision
                                
                                	Number of Closed Remote opens for this neighborneighbor due to collision 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: passives
                                
                                	Number of retried Passive opens for this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: read_calls_count
                                
                                	No. of calls to function to read inbound data
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: read_messages_count
                                
                                	Number of BGP messages read
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: read_throttles
                                
                                	Number of partial read throttles
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rejected_passives
                                
                                	Number of rejected Passive opens for this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reset_flags
                                
                                	Reset flags, per thread
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reset_retries
                                
                                	Reset Retries, per nbr
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: subgroup_list_time
                                
                                	Time spent processing sub\-group message list  (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: sync_flags
                                
                                	Sync flags, per nbr
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_since_last_throttled_read
                                
                                	Time (in secs) since last read after being throttled
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: write_calls_count
                                
                                	No. of calls to function to write outbound data
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_queue_calls_count
                                
                                	No. of calls to function to process write queue
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_queue_messages_count
                                
                                	Number of write queue messages processed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_queue_time
                                
                                	Time spent processing write queue (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: write_subgroup_calls_count
                                
                                	No. of calls to function to process sub\-group message list
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_subgroup_messages_count
                                
                                	Number of sub\-group msgs processed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.active_collision = None
                                    self.actives = None
                                    self.control_to_read_thread_trigger = None
                                    self.control_to_write_thread_trigger = None
                                    self.data_bytes_read = None
                                    self.data_bytes_written = None
                                    self.failed_post_actives = None
                                    self.high_throttled_read = None
                                    self.inbound_update_messages = None
                                    self.inbound_update_messages_time = None
                                    self.io_read_time = None
                                    self.io_write_time = None
                                    self.last_nsr_scoped_sync = None
                                    self.last_sent_seq_no = None
                                    self.low_throttled_read = None
                                    self.maximum_read_size = None
                                    self.nbr_fd = None
                                    self.nbr_flags = None
                                    self.network_status = None
                                    self.nsr_oper_down_count = None
                                    self.passive_collision = None
                                    self.passives = None
                                    self.read_calls_count = None
                                    self.read_messages_count = None
                                    self.read_throttles = None
                                    self.rejected_passives = None
                                    self.reset_flags = None
                                    self.reset_retries = None
                                    self.subgroup_list_time = None
                                    self.sync_flags = None
                                    self.time_since_last_throttled_read = None
                                    self.write_calls_count = None
                                    self.write_queue_calls_count = None
                                    self.write_queue_messages_count = None
                                    self.write_queue_time = None
                                    self.write_subgroup_calls_count = None
                                    self.write_subgroup_messages_count = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:performance-statistics'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.active_collision is not None:
                                        return True

                                    if self.actives is not None:
                                        return True

                                    if self.control_to_read_thread_trigger is not None:
                                        return True

                                    if self.control_to_write_thread_trigger is not None:
                                        return True

                                    if self.data_bytes_read is not None:
                                        return True

                                    if self.data_bytes_written is not None:
                                        return True

                                    if self.failed_post_actives is not None:
                                        return True

                                    if self.high_throttled_read is not None:
                                        return True

                                    if self.inbound_update_messages is not None:
                                        return True

                                    if self.inbound_update_messages_time is not None:
                                        return True

                                    if self.io_read_time is not None:
                                        return True

                                    if self.io_write_time is not None:
                                        return True

                                    if self.last_nsr_scoped_sync is not None:
                                        return True

                                    if self.last_sent_seq_no is not None:
                                        return True

                                    if self.low_throttled_read is not None:
                                        return True

                                    if self.maximum_read_size is not None:
                                        return True

                                    if self.nbr_fd is not None:
                                        return True

                                    if self.nbr_flags is not None:
                                        return True

                                    if self.network_status is not None:
                                        return True

                                    if self.nsr_oper_down_count is not None:
                                        return True

                                    if self.passive_collision is not None:
                                        return True

                                    if self.passives is not None:
                                        return True

                                    if self.read_calls_count is not None:
                                        return True

                                    if self.read_messages_count is not None:
                                        return True

                                    if self.read_throttles is not None:
                                        return True

                                    if self.rejected_passives is not None:
                                        return True

                                    if self.reset_flags is not None:
                                        return True

                                    if self.reset_retries is not None:
                                        return True

                                    if self.subgroup_list_time is not None:
                                        return True

                                    if self.sync_flags is not None:
                                        return True

                                    if self.time_since_last_throttled_read is not None:
                                        return True

                                    if self.write_calls_count is not None:
                                        return True

                                    if self.write_queue_calls_count is not None:
                                        return True

                                    if self.write_queue_messages_count is not None:
                                        return True

                                    if self.write_queue_time is not None:
                                        return True

                                    if self.write_subgroup_calls_count is not None:
                                        return True

                                    if self.write_subgroup_messages_count is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.PerformanceStatistics']['meta_info']


                            class MessageStatistics(object):
                                """
                                Message statistics
                                
                                .. attribute:: keepalive
                                
                                	Keepalive
                                	**type**\:   :py:class:`Keepalive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive>`
                                
                                .. attribute:: notification
                                
                                	Notification
                                	**type**\:   :py:class:`Notification <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification>`
                                
                                .. attribute:: open
                                
                                	Open
                                	**type**\:   :py:class:`Open <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open>`
                                
                                .. attribute:: route_refresh
                                
                                	Route refresh
                                	**type**\:   :py:class:`RouteRefresh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh>`
                                
                                .. attribute:: total
                                
                                	Total
                                	**type**\:   :py:class:`Total <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total>`
                                
                                .. attribute:: update
                                
                                	Update
                                	**type**\:   :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.keepalive = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive()
                                    self.keepalive.parent = self
                                    self.notification = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification()
                                    self.notification.parent = self
                                    self.open = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open()
                                    self.open.parent = self
                                    self.route_refresh = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh()
                                    self.route_refresh.parent = self
                                    self.total = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total()
                                    self.total.parent = self
                                    self.update = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update()
                                    self.update.parent = self


                                class Open(object):
                                    """
                                    Open
                                    
                                    .. attribute:: rx
                                    
                                    	Receive
                                    	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx>`
                                    
                                    .. attribute:: tx
                                    
                                    	Transmit
                                    	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.rx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx()
                                        self.rx.parent = self
                                        self.tx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx()
                                        self.tx.parent = self


                                    class Tx(object):
                                        """
                                        Transmit
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.count = None
                                            self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec()
                                            self.last_time_spec.parent = self


                                        class LastTimeSpec(object):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.count is not None:
                                                return True

                                            if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx']['meta_info']


                                    class Rx(object):
                                        """
                                        Receive
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.count = None
                                            self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec()
                                            self.last_time_spec.parent = self


                                        class LastTimeSpec(object):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.count is not None:
                                                return True

                                            if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:open'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.rx is not None and self.rx._has_data():
                                            return True

                                        if self.tx is not None and self.tx._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open']['meta_info']


                                class Notification(object):
                                    """
                                    Notification
                                    
                                    .. attribute:: rx
                                    
                                    	Receive
                                    	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx>`
                                    
                                    .. attribute:: tx
                                    
                                    	Transmit
                                    	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.rx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx()
                                        self.rx.parent = self
                                        self.tx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx()
                                        self.tx.parent = self


                                    class Tx(object):
                                        """
                                        Transmit
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.count = None
                                            self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec()
                                            self.last_time_spec.parent = self


                                        class LastTimeSpec(object):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.count is not None:
                                                return True

                                            if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx']['meta_info']


                                    class Rx(object):
                                        """
                                        Receive
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.count = None
                                            self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec()
                                            self.last_time_spec.parent = self


                                        class LastTimeSpec(object):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.count is not None:
                                                return True

                                            if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:notification'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.rx is not None and self.rx._has_data():
                                            return True

                                        if self.tx is not None and self.tx._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification']['meta_info']


                                class Update(object):
                                    """
                                    Update
                                    
                                    .. attribute:: rx
                                    
                                    	Receive
                                    	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx>`
                                    
                                    .. attribute:: tx
                                    
                                    	Transmit
                                    	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.rx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx()
                                        self.rx.parent = self
                                        self.tx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx()
                                        self.tx.parent = self


                                    class Tx(object):
                                        """
                                        Transmit
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.count = None
                                            self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec()
                                            self.last_time_spec.parent = self


                                        class LastTimeSpec(object):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.count is not None:
                                                return True

                                            if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx']['meta_info']


                                    class Rx(object):
                                        """
                                        Receive
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.count = None
                                            self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec()
                                            self.last_time_spec.parent = self


                                        class LastTimeSpec(object):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.count is not None:
                                                return True

                                            if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.rx is not None and self.rx._has_data():
                                            return True

                                        if self.tx is not None and self.tx._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update']['meta_info']


                                class Keepalive(object):
                                    """
                                    Keepalive
                                    
                                    .. attribute:: rx
                                    
                                    	Receive
                                    	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx>`
                                    
                                    .. attribute:: tx
                                    
                                    	Transmit
                                    	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.rx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx()
                                        self.rx.parent = self
                                        self.tx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx()
                                        self.tx.parent = self


                                    class Tx(object):
                                        """
                                        Transmit
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.count = None
                                            self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec()
                                            self.last_time_spec.parent = self


                                        class LastTimeSpec(object):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.count is not None:
                                                return True

                                            if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx']['meta_info']


                                    class Rx(object):
                                        """
                                        Receive
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.count = None
                                            self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec()
                                            self.last_time_spec.parent = self


                                        class LastTimeSpec(object):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.count is not None:
                                                return True

                                            if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:keepalive'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.rx is not None and self.rx._has_data():
                                            return True

                                        if self.tx is not None and self.tx._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive']['meta_info']


                                class RouteRefresh(object):
                                    """
                                    Route refresh
                                    
                                    .. attribute:: rx
                                    
                                    	Receive
                                    	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx>`
                                    
                                    .. attribute:: tx
                                    
                                    	Transmit
                                    	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.rx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx()
                                        self.rx.parent = self
                                        self.tx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx()
                                        self.tx.parent = self


                                    class Tx(object):
                                        """
                                        Transmit
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.count = None
                                            self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec()
                                            self.last_time_spec.parent = self


                                        class LastTimeSpec(object):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.count is not None:
                                                return True

                                            if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx']['meta_info']


                                    class Rx(object):
                                        """
                                        Receive
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.count = None
                                            self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec()
                                            self.last_time_spec.parent = self


                                        class LastTimeSpec(object):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.count is not None:
                                                return True

                                            if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:route-refresh'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.rx is not None and self.rx._has_data():
                                            return True

                                        if self.tx is not None and self.tx._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh']['meta_info']


                                class Total(object):
                                    """
                                    Total
                                    
                                    .. attribute:: rx
                                    
                                    	Receive
                                    	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx>`
                                    
                                    .. attribute:: tx
                                    
                                    	Transmit
                                    	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.rx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx()
                                        self.rx.parent = self
                                        self.tx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx()
                                        self.tx.parent = self


                                    class Tx(object):
                                        """
                                        Transmit
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.count = None
                                            self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec()
                                            self.last_time_spec.parent = self


                                        class LastTimeSpec(object):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.count is not None:
                                                return True

                                            if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx']['meta_info']


                                    class Rx(object):
                                        """
                                        Receive
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.count = None
                                            self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec()
                                            self.last_time_spec.parent = self


                                        class LastTimeSpec(object):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.count is not None:
                                                return True

                                            if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:total'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.rx is not None and self.rx._has_data():
                                            return True

                                        if self.tx is not None and self.tx._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:message-statistics'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.keepalive is not None and self.keepalive._has_data():
                                        return True

                                    if self.notification is not None and self.notification._has_data():
                                        return True

                                    if self.open is not None and self.open._has_data():
                                        return True

                                    if self.route_refresh is not None and self.route_refresh._has_data():
                                        return True

                                    if self.total is not None and self.total._has_data():
                                        return True

                                    if self.update is not None and self.update._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics']['meta_info']


                            class TcpInitSyncTimeSpec(object):
                                """
                                Time When neighbor entered TCP Init Sync
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.nanoseconds = None
                                    self.seconds = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tcp-init-sync-time-spec'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.nanoseconds is not None:
                                        return True

                                    if self.seconds is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncTimeSpec']['meta_info']


                            class TcpInitSyncPhaseTwoTimeSpec(object):
                                """
                                Time when neighbor entered TCP Init Sync Phase
                                Two
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.nanoseconds = None
                                    self.seconds = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tcp-init-sync-phase-two-time-spec'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.nanoseconds is not None:
                                        return True

                                    if self.seconds is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec']['meta_info']


                            class TcpInitSyncDoneTimeSpec(object):
                                """
                                Time when neighbor entered TCP Init Sync Done
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.nanoseconds = None
                                    self.seconds = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tcp-init-sync-done-time-spec'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.nanoseconds is not None:
                                        return True

                                    if self.seconds is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec']['meta_info']


                            class GracefulMaintenance(object):
                                """
                                Graceful Maintenance
                                
                                .. attribute:: gshut_active
                                
                                	Graceful Maintenance activated
                                	**type**\:  bool
                                
                                .. attribute:: gshut_exists
                                
                                	Graceful Maintenance enabled
                                	**type**\:  bool
                                
                                .. attribute:: gshut_local_active
                                
                                	Graceful Maintenance locally activated
                                	**type**\:  bool
                                
                                .. attribute:: gshut_locpref
                                
                                	Graceful Maintenance Local Preference
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: gshut_locpref_set
                                
                                	Graceful Maintenance Local Preference set
                                	**type**\:  bool
                                
                                .. attribute:: gshut_prepends
                                
                                	Graceful Maintenance number of AS prepends
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.gshut_active = None
                                    self.gshut_exists = None
                                    self.gshut_local_active = None
                                    self.gshut_locpref = None
                                    self.gshut_locpref_set = None
                                    self.gshut_prepends = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:graceful-maintenance'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.gshut_active is not None:
                                        return True

                                    if self.gshut_exists is not None:
                                        return True

                                    if self.gshut_local_active is not None:
                                        return True

                                    if self.gshut_locpref is not None:
                                        return True

                                    if self.gshut_locpref_set is not None:
                                        return True

                                    if self.gshut_prepends is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.GracefulMaintenance']['meta_info']


                            class AfData(object):
                                """
                                Address family specific neighbor data
                                
                                .. attribute:: accept_own_enabled
                                
                                	Accept\-Own enabled
                                	**type**\:  bool
                                
                                .. attribute:: acked_version
                                
                                	Version mapped from acked seqNo
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: address_family_long_lived_time
                                
                                	AF specific Long\-lived\-time config
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: advertise_afi
                                
                                	Encode in Advertise AFI
                                	**type**\:  bool
                                
                                .. attribute:: advertise_afi_def_vrf_imp_disable
                                
                                	Advertise of default VRF import disable
                                	**type**\:  bool
                                
                                .. attribute:: advertise_afi_disable
                                
                                	Encode in Advertise AFI
                                	**type**\:  bool
                                
                                .. attribute:: advertise_afi_eo_r_ready
                                
                                	EoR Can be sent for Advertise AFI
                                	**type**\:  bool
                                
                                .. attribute:: advertise_afi_reorg
                                
                                	Encode in Advertise AFI
                                	**type**\:  bool
                                
                                .. attribute:: advertise_afi_vrf_re_imp_disable
                                
                                	Advertise of VRF re\-import disable
                                	**type**\:  bool
                                
                                .. attribute:: advertise_evp_nv4afi_def_vrf_imp_disable
                                
                                	Advertise of v4 default VRF import disable
                                	**type**\:  bool
                                
                                .. attribute:: advertise_evp_nv4afi_vrf_re_imp_disable
                                
                                	Advertise of v4 VRF re\-import disable
                                	**type**\:  bool
                                
                                .. attribute:: advertise_evp_nv6afi_def_vrf_imp_disable
                                
                                	Advertise of v6 default VRF import disable
                                	**type**\:  bool
                                
                                .. attribute:: advertise_evp_nv6afi_vrf_re_imp_disable
                                
                                	Advertise of v6 VRF re\-import disable
                                	**type**\:  bool
                                
                                .. attribute:: advertise_local_labeled_route_unicast
                                
                                	Advertise routes with local\-label via Unicast SAFI
                                	**type**\:  bool
                                
                                .. attribute:: advertise_rt_type
                                
                                	Advertise RT type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: advertise_v4_flags
                                
                                	Advertise options for VPNV4
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: advertise_v6_flags
                                
                                	Advertise options for VPNV6
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: af_name
                                
                                	Address family identifier
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: afrpki_allow_invalid
                                
                                	Prefix v. allow invalid
                                	**type**\:  bool
                                
                                .. attribute:: afrpki_disable
                                
                                	Prefix validation disabled
                                	**type**\:  bool
                                
                                .. attribute:: afrpki_signal_ibgp
                                
                                	Prefix v. signal ibgp
                                	**type**\:  bool
                                
                                .. attribute:: afrpki_use_validity
                                
                                	Prefix v. use validity
                                	**type**\:  bool
                                
                                .. attribute:: allow_as_in_count
                                
                                	Allowas\-in count config
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: always_use_next_hop_local
                                
                                	Local router always used for next\-hop
                                	**type**\:  bool
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation type
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: eo_r_received_in_read_only
                                
                                	An EoR was received while in read\-only mode
                                	**type**\:  bool
                                
                                .. attribute:: extended_community
                                
                                	Extended community attribute
                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunity>`
                                
                                .. attribute:: extended_community_standby
                                
                                	Extended community attribute
                                	**type**\: list of    :py:class:`ExtendedCommunityStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby>`
                                
                                .. attribute:: filter_group_index
                                
                                	Filter group index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: flowspec_redirect_validation_d_isable
                                
                                	Flowspec Redirect Validation Disabled
                                	**type**\:  bool
                                
                                .. attribute:: flowspec_validation_d_isable
                                
                                	Flowspec Validation Disabled
                                	**type**\:  bool
                                
                                .. attribute:: import_reoriginate
                                
                                	Import Reoriginate enabled
                                	**type**\:  bool
                                
                                .. attribute:: import_reoriginate_stitching
                                
                                	Import Reoriginate Stitching enabled
                                	**type**\:  bool
                                
                                .. attribute:: import_stitching
                                
                                	Import Stitching enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_add_path_receive_capability_advertised
                                
                                	Addpath Receive capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_add_path_receive_capability_received
                                
                                	Addpath Receive capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_add_path_send_capability_advertised
                                
                                	Addpath Send capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_add_path_send_capability_received
                                
                                	Addpath Send capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_addpath_receive_operational
                                
                                	Addpath is operational on receive\-side
                                	**type**\:  bool
                                
                                .. attribute:: is_addpath_send_operational
                                
                                	Addpath is operational on send\-side
                                	**type**\:  bool
                                
                                .. attribute:: is_advertise_permanent_network
                                
                                	Advertise Permanent Network
                                	**type**\:  bool
                                
                                .. attribute:: is_advertised_graceful_restart
                                
                                	Graceful Restart Capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_advertised_orf_receive
                                
                                	Prefix based ORF receive mode capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_advertised_orf_send
                                
                                	Prefix based ORF send mode capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_aigp_set
                                
                                	AIGP set 
                                	**type**\:  bool
                                
                                .. attribute:: is_allow_as_in_set
                                
                                	Allowas\-in set 
                                	**type**\:  bool
                                
                                .. attribute:: is_as_override_set
                                
                                	As override set 
                                	**type**\:  bool
                                
                                .. attribute:: is_default_originate_sent
                                
                                	Default origination update sent
                                	**type**\:  bool
                                
                                .. attribute:: is_ext_nh_encoding_capability_received
                                
                                	Extended nexthop encoding capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_ext_nh_encoding_capability_sent
                                
                                	Extended nexhop encoding capability Sent
                                	**type**\:  bool
                                
                                .. attribute:: is_graceful_restart_state_flag
                                
                                	Restart state flag enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_legacy_pe_rt
                                
                                	Nbr accepts route from legacy PE for RT\-Constraint AF 
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_af_capable
                                
                                	Address family capability received from neighbor
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_ebgp_without_inbound_policy
                                
                                	eBGP neighbor with no configured inbound policy
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_ebgp_without_outbound_policy
                                
                                	eBGP neighbor with no configured outbound policy
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_route_reflector_client
                                
                                	Nbr is a route reflector client
                                	**type**\:  bool
                                
                                .. attribute:: is_orf_send_scheduled
                                
                                	Scheduled to send prefix based ORF
                                	**type**\:  bool
                                
                                .. attribute:: is_orf_sent
                                
                                	Outbound route filter sent to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: is_orr_root_address_configured
                                
                                	ORR Root address configuredfor the neighbor connection
                                	**type**\:  bool
                                
                                .. attribute:: is_peer_orf_capable
                                
                                	Peer has outbound route filter capability
                                	**type**\:  bool
                                
                                .. attribute:: is_prefix_orf_present
                                
                                	Outbound route filter prefix ORF present
                                	**type**\:  bool
                                
                                .. attribute:: is_received_graceful_restart_capable
                                
                                	Graceful Restart Capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_received_orf_receive_capable
                                
                                	Prefix based ORF receive mode capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_received_orf_send_capable
                                
                                	Prefix based ORF send mode capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_rt_present
                                
                                	RT attribute list present
                                	**type**\:  bool
                                
                                .. attribute:: is_rt_present_standby
                                
                                	RT attribute list present
                                	**type**\:  bool
                                
                                .. attribute:: is_send_mcast_attr
                                
                                	Send Mcast Attr
                                	**type**\:  bool
                                
                                .. attribute:: is_soft_reconfiguration_inbound_allowed
                                
                                	Inbound soft reconfiguration allowed
                                	**type**\:  bool
                                
                                .. attribute:: is_update_deferred
                                
                                	Update deferred until ORF/route refresh received
                                	**type**\:  bool
                                
                                .. attribute:: is_update_leaving
                                
                                	Nbr leaving update\-groupto another
                                	**type**\:  bool
                                
                                .. attribute:: is_update_throttled
                                
                                	Updates Throttled becausewrite limit is reached
                                	**type**\:  bool
                                
                                .. attribute:: is_use_soft_reconfiguration_always_on
                                
                                	Soft reconf overrides route refresh
                                	**type**\:  bool
                                
                                .. attribute:: local_restart_time
                                
                                	Local Restart time (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: long_lived_graceful_restart_capability_received
                                
                                	Long\-lived graceful\-restart capability received from the neighbor
                                	**type**\:  bool
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_accept
                                
                                	Maximum long\-lived graceful\-restart stale time acceptable from the neighbor (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_configured
                                
                                	Long\-lived graceful\-restart stale time is configured
                                	**type**\:  bool
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_received
                                
                                	Long\-lived graceful\-restart stale time received from the neighbor (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_sent
                                
                                	Stale time sent in long\-lived graceful\-restart capability (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: max_prefix_discard_extra_paths
                                
                                	Discard extra paths when prefix limit reached
                                	**type**\:  bool
                                
                                .. attribute:: max_prefix_exceed_discard_paths
                                
                                	Did we discard extra paths when prefix limit reached
                                	**type**\:  bool
                                
                                .. attribute:: max_prefix_limit
                                
                                	Max limit for # of prefixes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max_prefix_restart_time
                                
                                	Time interval (in minutes) after which peering session will be reestablished
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: minute
                                
                                .. attribute:: max_prefix_threshold_percent
                                
                                	Percentage of maximum no. of prefixes at which to generate warning
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: percentage
                                
                                .. attribute:: neighbor_af_performance_statistics
                                
                                	Neighbor AF statistics
                                	**type**\:   :py:class:`NeighborAfPerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics>`
                                
                                .. attribute:: neighbor_default_originate
                                
                                	Neighbor originates default
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_long_lived_graceful_restart_capable
                                
                                	Treat neighbor as long\-lived graceful\-restart capable
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_long_lived_graceful_restart_time_remaining
                                
                                	Remaining long\-lived graceful\-restart time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_preserved_forwarding_state
                                
                                	Neighbor preserved forwarding state
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_preserved_long_lived_forwarding_state
                                
                                	Neighbor preserved long\-lived forwarding state
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_version
                                
                                	Neighbor version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: number_of_best_externalpaths
                                
                                	No. of best\-external paths from this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: number_of_bestpaths
                                
                                	No. of bestpaths from this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: orf_entries_received
                                
                                	Number of outbound route filter entries received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: orr_group_index
                                
                                	ORR Group Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: orr_group_name
                                
                                	ORR Group Name
                                	**type**\:  str
                                
                                .. attribute:: outstanding_version
                                
                                	Version mapped from acked seqNo that was synced last
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: outstanding_version_max
                                
                                	Version mapped from acked seqNo that was synced last
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_accepted
                                
                                	No. of prefixes accepted
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_advertised
                                
                                	No. of prefixes advertised
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_be_advertised
                                
                                	No BE prefixes advertised
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_denied
                                
                                	No. of prefixes denied
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_denied_no_policy
                                
                                	No. of prefixes denied because there was no inbound policy
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_denied_non_cumulative
                                
                                	No. of prefixes exactly denied (non cumulative)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_denied_orf_policy
                                
                                	No. of prefixes denied by prefix based ORF policy
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_denied_policy
                                
                                	No. of prefixes denied by inbound policy
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_denied_rt_permit
                                
                                	No. of prefixes denied because RT extended community is not imported
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_suppressed
                                
                                	No. of prefixes suppressed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_synced
                                
                                	Number of prefixes synced to standby
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_withdrawn
                                
                                	No. of prefixes withdrawn
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_withdrawn_not_found
                                
                                	No. of prefixes withdrawn but not found
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: refresh_acked_version
                                
                                	Version acked by the peer for refresh updates sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: refresh_target_version
                                
                                	Target version for refresh update generation
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: refresh_version
                                
                                	Version till which refresh updates have been generated
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remove_private_as_entire_aspath_from_inbound_updates
                                
                                	Private AS numbers removed from updates from this nbr only if the aspath has only private ASes
                                	**type**\:  bool
                                
                                .. attribute:: remove_private_as_entire_aspath_from_updates
                                
                                	Private AS numbers removed from updates to thisnbr only if the aspath hasonly private ASes
                                	**type**\:  bool
                                
                                .. attribute:: remove_private_as_from_inbound_updates
                                
                                	Private AS numbers removed from updates from this nbr
                                	**type**\:  bool
                                
                                .. attribute:: remove_private_as_from_updates
                                
                                	Private AS numbers removed from updates to this nbr
                                	**type**\:  bool
                                
                                .. attribute:: restart_time
                                
                                	Restart time advertised (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: rib_purge_timeout_value
                                
                                	RIB purge timeout time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: route_policy_default_originate
                                
                                	Default\-originate route policy name
                                	**type**\:  str
                                
                                .. attribute:: route_policy_in
                                
                                	Incoming route policy name
                                	**type**\:  str
                                
                                .. attribute:: route_policy_out
                                
                                	Outgoing route policy name
                                	**type**\:  str
                                
                                .. attribute:: route_policy_prefix_orf
                                
                                	Prefix based ORF for incoming updates
                                	**type**\:  str
                                
                                .. attribute:: route_refreshes_received
                                
                                	Number of route refresh requests received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_refreshes_sent
                                
                                	Number of route refresh requests sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: selective_multipath_eligible
                                
                                	Selective multipath eligible
                                	**type**\:  bool
                                
                                .. attribute:: sent_community_to_neighbor
                                
                                	Community attribute sent to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: sent_extended_community_to_neighbor
                                
                                	Extended community attribute sent to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: sent_gshut_community_to_neighbor
                                
                                	GSHUT Community attribute sent to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: stale_path_timeout
                                
                                	Stale path timeout time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: synced_acked_version
                                
                                	Version mapped from acked seqNo that was synced last
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_group_number
                                
                                	Update group index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: use_max_prefix_warning_only
                                
                                	Warning only when maximum prefix limit reached
                                	**type**\:  bool
                                
                                .. attribute:: vpn_update_gen_enabled
                                
                                	RT Nbr enabled for updategento another
                                	**type**\:  bool
                                
                                .. attribute:: vpn_update_gen_trigger_enabled
                                
                                	RT Nbr enabled for updategento another
                                	**type**\:  bool
                                
                                .. attribute:: weight
                                
                                	Weight for this AF
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.accept_own_enabled = None
                                    self.acked_version = None
                                    self.address_family_long_lived_time = None
                                    self.advertise_afi = None
                                    self.advertise_afi_def_vrf_imp_disable = None
                                    self.advertise_afi_disable = None
                                    self.advertise_afi_eo_r_ready = None
                                    self.advertise_afi_reorg = None
                                    self.advertise_afi_vrf_re_imp_disable = None
                                    self.advertise_evp_nv4afi_def_vrf_imp_disable = None
                                    self.advertise_evp_nv4afi_vrf_re_imp_disable = None
                                    self.advertise_evp_nv6afi_def_vrf_imp_disable = None
                                    self.advertise_evp_nv6afi_vrf_re_imp_disable = None
                                    self.advertise_local_labeled_route_unicast = None
                                    self.advertise_rt_type = None
                                    self.advertise_v4_flags = None
                                    self.advertise_v6_flags = None
                                    self.af_name = None
                                    self.afrpki_allow_invalid = None
                                    self.afrpki_disable = None
                                    self.afrpki_signal_ibgp = None
                                    self.afrpki_use_validity = None
                                    self.allow_as_in_count = None
                                    self.always_use_next_hop_local = None
                                    self.encapsulation_type = None
                                    self.eo_r_received_in_read_only = None
                                    self.extended_community = YList()
                                    self.extended_community.parent = self
                                    self.extended_community.name = 'extended_community'
                                    self.extended_community_standby = YList()
                                    self.extended_community_standby.parent = self
                                    self.extended_community_standby.name = 'extended_community_standby'
                                    self.filter_group_index = None
                                    self.flowspec_redirect_validation_d_isable = None
                                    self.flowspec_validation_d_isable = None
                                    self.import_reoriginate = None
                                    self.import_reoriginate_stitching = None
                                    self.import_stitching = None
                                    self.is_add_path_receive_capability_advertised = None
                                    self.is_add_path_receive_capability_received = None
                                    self.is_add_path_send_capability_advertised = None
                                    self.is_add_path_send_capability_received = None
                                    self.is_addpath_receive_operational = None
                                    self.is_addpath_send_operational = None
                                    self.is_advertise_permanent_network = None
                                    self.is_advertised_graceful_restart = None
                                    self.is_advertised_orf_receive = None
                                    self.is_advertised_orf_send = None
                                    self.is_aigp_set = None
                                    self.is_allow_as_in_set = None
                                    self.is_as_override_set = None
                                    self.is_default_originate_sent = None
                                    self.is_ext_nh_encoding_capability_received = None
                                    self.is_ext_nh_encoding_capability_sent = None
                                    self.is_graceful_restart_state_flag = None
                                    self.is_legacy_pe_rt = None
                                    self.is_neighbor_af_capable = None
                                    self.is_neighbor_ebgp_without_inbound_policy = None
                                    self.is_neighbor_ebgp_without_outbound_policy = None
                                    self.is_neighbor_route_reflector_client = None
                                    self.is_orf_send_scheduled = None
                                    self.is_orf_sent = None
                                    self.is_orr_root_address_configured = None
                                    self.is_peer_orf_capable = None
                                    self.is_prefix_orf_present = None
                                    self.is_received_graceful_restart_capable = None
                                    self.is_received_orf_receive_capable = None
                                    self.is_received_orf_send_capable = None
                                    self.is_rt_present = None
                                    self.is_rt_present_standby = None
                                    self.is_send_mcast_attr = None
                                    self.is_soft_reconfiguration_inbound_allowed = None
                                    self.is_update_deferred = None
                                    self.is_update_leaving = None
                                    self.is_update_throttled = None
                                    self.is_use_soft_reconfiguration_always_on = None
                                    self.local_restart_time = None
                                    self.long_lived_graceful_restart_capability_received = None
                                    self.long_lived_graceful_restart_stale_time_accept = None
                                    self.long_lived_graceful_restart_stale_time_configured = None
                                    self.long_lived_graceful_restart_stale_time_received = None
                                    self.long_lived_graceful_restart_stale_time_sent = None
                                    self.max_prefix_discard_extra_paths = None
                                    self.max_prefix_exceed_discard_paths = None
                                    self.max_prefix_limit = None
                                    self.max_prefix_restart_time = None
                                    self.max_prefix_threshold_percent = None
                                    self.neighbor_af_performance_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics()
                                    self.neighbor_af_performance_statistics.parent = self
                                    self.neighbor_default_originate = None
                                    self.neighbor_long_lived_graceful_restart_capable = None
                                    self.neighbor_long_lived_graceful_restart_time_remaining = None
                                    self.neighbor_preserved_forwarding_state = None
                                    self.neighbor_preserved_long_lived_forwarding_state = None
                                    self.neighbor_version = None
                                    self.number_of_best_externalpaths = None
                                    self.number_of_bestpaths = None
                                    self.orf_entries_received = None
                                    self.orr_group_index = None
                                    self.orr_group_name = None
                                    self.outstanding_version = None
                                    self.outstanding_version_max = None
                                    self.prefixes_accepted = None
                                    self.prefixes_advertised = None
                                    self.prefixes_be_advertised = None
                                    self.prefixes_denied = None
                                    self.prefixes_denied_no_policy = None
                                    self.prefixes_denied_non_cumulative = None
                                    self.prefixes_denied_orf_policy = None
                                    self.prefixes_denied_policy = None
                                    self.prefixes_denied_rt_permit = None
                                    self.prefixes_suppressed = None
                                    self.prefixes_synced = None
                                    self.prefixes_withdrawn = None
                                    self.prefixes_withdrawn_not_found = None
                                    self.refresh_acked_version = None
                                    self.refresh_target_version = None
                                    self.refresh_version = None
                                    self.remove_private_as_entire_aspath_from_inbound_updates = None
                                    self.remove_private_as_entire_aspath_from_updates = None
                                    self.remove_private_as_from_inbound_updates = None
                                    self.remove_private_as_from_updates = None
                                    self.restart_time = None
                                    self.rib_purge_timeout_value = None
                                    self.route_policy_default_originate = None
                                    self.route_policy_in = None
                                    self.route_policy_out = None
                                    self.route_policy_prefix_orf = None
                                    self.route_refreshes_received = None
                                    self.route_refreshes_sent = None
                                    self.selective_multipath_eligible = None
                                    self.sent_community_to_neighbor = None
                                    self.sent_extended_community_to_neighbor = None
                                    self.sent_gshut_community_to_neighbor = None
                                    self.stale_path_timeout = None
                                    self.synced_acked_version = None
                                    self.update_group_number = None
                                    self.use_max_prefix_warning_only = None
                                    self.vpn_update_gen_enabled = None
                                    self.vpn_update_gen_trigger_enabled = None
                                    self.weight = None


                                class NeighborAfPerformanceStatistics(object):
                                    """
                                    Neighbor AF statistics
                                    
                                    .. attribute:: processed_messages
                                    
                                    	Number of messages processed from the neighbor's write queue
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sent_messages
                                    
                                    	Number of messages sent from the neighbor's write queue
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: split_horizon_update_blocked
                                    
                                    	No. of update messages with split\-horizon flag that were blocked
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: split_horizon_update_transmit
                                    
                                    	No. of update messages with split\-horizon flag that were sent out
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: split_horizon_withdraw_blocked
                                    
                                    	No. of withdraw messages with split\-horizon flag that were blocked
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: split_horizon_withdraw_transmit
                                    
                                    	No. of withdraw messages with split\-horizon flag that were sent out
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_pending_message_count
                                    
                                    	No. of sub\-group messages waiting to be sent out on this neighbor \-\- DEPRECATED \-\- 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.processed_messages = None
                                        self.sent_messages = None
                                        self.split_horizon_update_blocked = None
                                        self.split_horizon_update_transmit = None
                                        self.split_horizon_withdraw_blocked = None
                                        self.split_horizon_withdraw_transmit = None
                                        self.sub_group_pending_message_count = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-af-performance-statistics'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.processed_messages is not None:
                                            return True

                                        if self.sent_messages is not None:
                                            return True

                                        if self.split_horizon_update_blocked is not None:
                                            return True

                                        if self.split_horizon_update_transmit is not None:
                                            return True

                                        if self.split_horizon_withdraw_blocked is not None:
                                            return True

                                        if self.split_horizon_withdraw_transmit is not None:
                                            return True

                                        if self.sub_group_pending_message_count is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics']['meta_info']


                                class ExtendedCommunity(object):
                                    """
                                    Extended community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunity']['meta_info']


                                class ExtendedCommunityStandby(object):
                                    """
                                    Extended community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community-standby'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af-data'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.accept_own_enabled is not None:
                                        return True

                                    if self.acked_version is not None:
                                        return True

                                    if self.address_family_long_lived_time is not None:
                                        return True

                                    if self.advertise_afi is not None:
                                        return True

                                    if self.advertise_afi_def_vrf_imp_disable is not None:
                                        return True

                                    if self.advertise_afi_disable is not None:
                                        return True

                                    if self.advertise_afi_eo_r_ready is not None:
                                        return True

                                    if self.advertise_afi_reorg is not None:
                                        return True

                                    if self.advertise_afi_vrf_re_imp_disable is not None:
                                        return True

                                    if self.advertise_evp_nv4afi_def_vrf_imp_disable is not None:
                                        return True

                                    if self.advertise_evp_nv4afi_vrf_re_imp_disable is not None:
                                        return True

                                    if self.advertise_evp_nv6afi_def_vrf_imp_disable is not None:
                                        return True

                                    if self.advertise_evp_nv6afi_vrf_re_imp_disable is not None:
                                        return True

                                    if self.advertise_local_labeled_route_unicast is not None:
                                        return True

                                    if self.advertise_rt_type is not None:
                                        return True

                                    if self.advertise_v4_flags is not None:
                                        return True

                                    if self.advertise_v6_flags is not None:
                                        return True

                                    if self.af_name is not None:
                                        return True

                                    if self.afrpki_allow_invalid is not None:
                                        return True

                                    if self.afrpki_disable is not None:
                                        return True

                                    if self.afrpki_signal_ibgp is not None:
                                        return True

                                    if self.afrpki_use_validity is not None:
                                        return True

                                    if self.allow_as_in_count is not None:
                                        return True

                                    if self.always_use_next_hop_local is not None:
                                        return True

                                    if self.encapsulation_type is not None:
                                        return True

                                    if self.eo_r_received_in_read_only is not None:
                                        return True

                                    if self.extended_community is not None:
                                        for child_ref in self.extended_community:
                                            if child_ref._has_data():
                                                return True

                                    if self.extended_community_standby is not None:
                                        for child_ref in self.extended_community_standby:
                                            if child_ref._has_data():
                                                return True

                                    if self.filter_group_index is not None:
                                        return True

                                    if self.flowspec_redirect_validation_d_isable is not None:
                                        return True

                                    if self.flowspec_validation_d_isable is not None:
                                        return True

                                    if self.import_reoriginate is not None:
                                        return True

                                    if self.import_reoriginate_stitching is not None:
                                        return True

                                    if self.import_stitching is not None:
                                        return True

                                    if self.is_add_path_receive_capability_advertised is not None:
                                        return True

                                    if self.is_add_path_receive_capability_received is not None:
                                        return True

                                    if self.is_add_path_send_capability_advertised is not None:
                                        return True

                                    if self.is_add_path_send_capability_received is not None:
                                        return True

                                    if self.is_addpath_receive_operational is not None:
                                        return True

                                    if self.is_addpath_send_operational is not None:
                                        return True

                                    if self.is_advertise_permanent_network is not None:
                                        return True

                                    if self.is_advertised_graceful_restart is not None:
                                        return True

                                    if self.is_advertised_orf_receive is not None:
                                        return True

                                    if self.is_advertised_orf_send is not None:
                                        return True

                                    if self.is_aigp_set is not None:
                                        return True

                                    if self.is_allow_as_in_set is not None:
                                        return True

                                    if self.is_as_override_set is not None:
                                        return True

                                    if self.is_default_originate_sent is not None:
                                        return True

                                    if self.is_ext_nh_encoding_capability_received is not None:
                                        return True

                                    if self.is_ext_nh_encoding_capability_sent is not None:
                                        return True

                                    if self.is_graceful_restart_state_flag is not None:
                                        return True

                                    if self.is_legacy_pe_rt is not None:
                                        return True

                                    if self.is_neighbor_af_capable is not None:
                                        return True

                                    if self.is_neighbor_ebgp_without_inbound_policy is not None:
                                        return True

                                    if self.is_neighbor_ebgp_without_outbound_policy is not None:
                                        return True

                                    if self.is_neighbor_route_reflector_client is not None:
                                        return True

                                    if self.is_orf_send_scheduled is not None:
                                        return True

                                    if self.is_orf_sent is not None:
                                        return True

                                    if self.is_orr_root_address_configured is not None:
                                        return True

                                    if self.is_peer_orf_capable is not None:
                                        return True

                                    if self.is_prefix_orf_present is not None:
                                        return True

                                    if self.is_received_graceful_restart_capable is not None:
                                        return True

                                    if self.is_received_orf_receive_capable is not None:
                                        return True

                                    if self.is_received_orf_send_capable is not None:
                                        return True

                                    if self.is_rt_present is not None:
                                        return True

                                    if self.is_rt_present_standby is not None:
                                        return True

                                    if self.is_send_mcast_attr is not None:
                                        return True

                                    if self.is_soft_reconfiguration_inbound_allowed is not None:
                                        return True

                                    if self.is_update_deferred is not None:
                                        return True

                                    if self.is_update_leaving is not None:
                                        return True

                                    if self.is_update_throttled is not None:
                                        return True

                                    if self.is_use_soft_reconfiguration_always_on is not None:
                                        return True

                                    if self.local_restart_time is not None:
                                        return True

                                    if self.long_lived_graceful_restart_capability_received is not None:
                                        return True

                                    if self.long_lived_graceful_restart_stale_time_accept is not None:
                                        return True

                                    if self.long_lived_graceful_restart_stale_time_configured is not None:
                                        return True

                                    if self.long_lived_graceful_restart_stale_time_received is not None:
                                        return True

                                    if self.long_lived_graceful_restart_stale_time_sent is not None:
                                        return True

                                    if self.max_prefix_discard_extra_paths is not None:
                                        return True

                                    if self.max_prefix_exceed_discard_paths is not None:
                                        return True

                                    if self.max_prefix_limit is not None:
                                        return True

                                    if self.max_prefix_restart_time is not None:
                                        return True

                                    if self.max_prefix_threshold_percent is not None:
                                        return True

                                    if self.neighbor_af_performance_statistics is not None and self.neighbor_af_performance_statistics._has_data():
                                        return True

                                    if self.neighbor_default_originate is not None:
                                        return True

                                    if self.neighbor_long_lived_graceful_restart_capable is not None:
                                        return True

                                    if self.neighbor_long_lived_graceful_restart_time_remaining is not None:
                                        return True

                                    if self.neighbor_preserved_forwarding_state is not None:
                                        return True

                                    if self.neighbor_preserved_long_lived_forwarding_state is not None:
                                        return True

                                    if self.neighbor_version is not None:
                                        return True

                                    if self.number_of_best_externalpaths is not None:
                                        return True

                                    if self.number_of_bestpaths is not None:
                                        return True

                                    if self.orf_entries_received is not None:
                                        return True

                                    if self.orr_group_index is not None:
                                        return True

                                    if self.orr_group_name is not None:
                                        return True

                                    if self.outstanding_version is not None:
                                        return True

                                    if self.outstanding_version_max is not None:
                                        return True

                                    if self.prefixes_accepted is not None:
                                        return True

                                    if self.prefixes_advertised is not None:
                                        return True

                                    if self.prefixes_be_advertised is not None:
                                        return True

                                    if self.prefixes_denied is not None:
                                        return True

                                    if self.prefixes_denied_no_policy is not None:
                                        return True

                                    if self.prefixes_denied_non_cumulative is not None:
                                        return True

                                    if self.prefixes_denied_orf_policy is not None:
                                        return True

                                    if self.prefixes_denied_policy is not None:
                                        return True

                                    if self.prefixes_denied_rt_permit is not None:
                                        return True

                                    if self.prefixes_suppressed is not None:
                                        return True

                                    if self.prefixes_synced is not None:
                                        return True

                                    if self.prefixes_withdrawn is not None:
                                        return True

                                    if self.prefixes_withdrawn_not_found is not None:
                                        return True

                                    if self.refresh_acked_version is not None:
                                        return True

                                    if self.refresh_target_version is not None:
                                        return True

                                    if self.refresh_version is not None:
                                        return True

                                    if self.remove_private_as_entire_aspath_from_inbound_updates is not None:
                                        return True

                                    if self.remove_private_as_entire_aspath_from_updates is not None:
                                        return True

                                    if self.remove_private_as_from_inbound_updates is not None:
                                        return True

                                    if self.remove_private_as_from_updates is not None:
                                        return True

                                    if self.restart_time is not None:
                                        return True

                                    if self.rib_purge_timeout_value is not None:
                                        return True

                                    if self.route_policy_default_originate is not None:
                                        return True

                                    if self.route_policy_in is not None:
                                        return True

                                    if self.route_policy_out is not None:
                                        return True

                                    if self.route_policy_prefix_orf is not None:
                                        return True

                                    if self.route_refreshes_received is not None:
                                        return True

                                    if self.route_refreshes_sent is not None:
                                        return True

                                    if self.selective_multipath_eligible is not None:
                                        return True

                                    if self.sent_community_to_neighbor is not None:
                                        return True

                                    if self.sent_extended_community_to_neighbor is not None:
                                        return True

                                    if self.sent_gshut_community_to_neighbor is not None:
                                        return True

                                    if self.stale_path_timeout is not None:
                                        return True

                                    if self.synced_acked_version is not None:
                                        return True

                                    if self.update_group_number is not None:
                                        return True

                                    if self.use_max_prefix_warning_only is not None:
                                        return True

                                    if self.vpn_update_gen_enabled is not None:
                                        return True

                                    if self.vpn_update_gen_trigger_enabled is not None:
                                        return True

                                    if self.weight is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.neighbor_address is None:
                                    raise YPYModelError('Key property neighbor_address is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address = ' + str(self.neighbor_address) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.neighbor_address is not None:
                                    return True

                                if self.active_bmp_servers is not None:
                                    return True

                                if self.actual_last_write_bytes is not None:
                                    return True

                                if self.actual_last_write_reset_bytes is not None:
                                    return True

                                if self.actual_second_last_write_bytes is not None:
                                    return True

                                if self.actual_second_last_write_reset_bytes is not None:
                                    return True

                                if self.af_data is not None:
                                    for child_ref in self.af_data:
                                        if child_ref._has_data():
                                            return True

                                if self.attempted_last_write_bytes is not None:
                                    return True

                                if self.attempted_last_write_reset_bytes is not None:
                                    return True

                                if self.attempted_second_last_write_bytes is not None:
                                    return True

                                if self.attempted_second_last_write_reset_bytes is not None:
                                    return True

                                if self.bfd_minintervalval is not None:
                                    return True

                                if self.bfd_multiplierval is not None:
                                    return True

                                if self.bfd_session_created_state is not None:
                                    return True

                                if self.bfd_session_enable_mode is not None:
                                    return True

                                if self.bfd_session_state is not None:
                                    return True

                                if self.bfd_state_ts is not None:
                                    return True

                                if self.bytes_read is not None:
                                    return True

                                if self.bytes_written is not None:
                                    return True

                                if self.configured_hold_time is not None:
                                    return True

                                if self.configured_keepalive is not None:
                                    return True

                                if self.configured_min_acc_hold_time is not None:
                                    return True

                                if self.connect_retry_interval is not None:
                                    return True

                                if self.connection_admin_status is not None:
                                    return True

                                if self.connection_down_count is not None:
                                    return True

                                if self.connection_established_time is not None:
                                    return True

                                if self.connection_local_address is not None and self.connection_local_address._has_data():
                                    return True

                                if self.connection_local_port is not None:
                                    return True

                                if self.connection_remote_address is not None and self.connection_remote_address._has_data():
                                    return True

                                if self.connection_remote_port is not None:
                                    return True

                                if self.connection_state is not None:
                                    return True

                                if self.connection_up_count is not None:
                                    return True

                                if self.count_last_write is not None:
                                    return True

                                if self.description is not None:
                                    return True

                                if self.discard_as4_path is not None:
                                    return True

                                if self.discard_data_bytes is not None:
                                    return True

                                if self.dmz_link_bandwidth is not None:
                                    return True

                                if self.dynamic_neighbor is not None:
                                    return True

                                if self.ebgp_recv_dmz is not None:
                                    return True

                                if self.ebgp_send_dmz_mode is not None:
                                    return True

                                if self.ebgp_time_to_live is not None:
                                    return True

                                if self.egress_peer_engineering_enabled is not None:
                                    return True

                                if self.error_notifies_received is not None:
                                    return True

                                if self.error_notifies_sent is not None:
                                    return True

                                if self.fpbsn_offset is not None:
                                    return True

                                if self.fssn_offset is not None:
                                    return True

                                if self.gr_restart_time is not None:
                                    return True

                                if self.gr_stale_path_time is not None:
                                    return True

                                if self.graceful_maintenance is not None and self.graceful_maintenance._has_data():
                                    return True

                                if self.graceful_restart_enabled_nbr is not None:
                                    return True

                                if self.has_internal_link is not None:
                                    return True

                                if self.hold_time is not None:
                                    return True

                                if self.ignore_connected is not None:
                                    return True

                                if self.internal_vpn_client is not None:
                                    return True

                                if self.io_armed is not None:
                                    return True

                                if self.is4_byte_as_capability_received is not None:
                                    return True

                                if self.is4_byte_as_capability_sent is not None:
                                    return True

                                if self.is_administratively_shut_down is not None:
                                    return True

                                if self.is_capability_negotiation_performed is not None:
                                    return True

                                if self.is_capability_negotiation_suppressed is not None:
                                    return True

                                if self.is_ebgp_multihop_bgpmpls_forwarding_disabled is not None:
                                    return True

                                if self.is_ebgp_peer_as_league is not None:
                                    return True

                                if self.is_ebgp_peer_common_admin is not None:
                                    return True

                                if self.is_external_neighbor_not_directly_connected is not None:
                                    return True

                                if self.is_gr_aware is not None:
                                    return True

                                if self.is_local_address_configured is not None:
                                    return True

                                if self.is_neighbor_max_prefix_shutdown is not None:
                                    return True

                                if self.is_out_of_memory_forced_up is not None:
                                    return True

                                if self.is_out_of_memory_shutdown is not None:
                                    return True

                                if self.is_passive_close is not None:
                                    return True

                                if self.is_read_disabled is not None:
                                    return True

                                if self.is_route_refresh_capability_received is not None:
                                    return True

                                if self.is_route_refresh_old_capability_received is not None:
                                    return True

                                if self.keep_alive_time is not None:
                                    return True

                                if self.last_ackd_seq_no is not None:
                                    return True

                                if self.last_k_aerror_reset is not None:
                                    return True

                                if self.last_k_aexpiry_reset is not None:
                                    return True

                                if self.last_k_anotsent_reset is not None:
                                    return True

                                if self.last_k_astart_reset is not None:
                                    return True

                                if self.last_notify_error_code is not None:
                                    return True

                                if self.last_notify_error_subcode is not None:
                                    return True

                                if self.last_write_event is not None:
                                    return True

                                if self.local_as is not None:
                                    return True

                                if self.local_as_dual_as is not None:
                                    return True

                                if self.local_as_dual_as_mode_native is not None:
                                    return True

                                if self.local_as_no_prepend is not None:
                                    return True

                                if self.local_as_replace_as is not None:
                                    return True

                                if self.message_statistics is not None and self.message_statistics._has_data():
                                    return True

                                if self.messages_queued_in is not None:
                                    return True

                                if self.messages_queued_out is not None:
                                    return True

                                if self.messages_received is not None:
                                    return True

                                if self.messages_sent is not None:
                                    return True

                                if self.min_advertise_interval is not None:
                                    return True

                                if self.min_advertise_interval_msecs is not None:
                                    return True

                                if self.min_origination_interval is not None:
                                    return True

                                if self.msg_log_in is not None:
                                    return True

                                if self.msg_log_out is not None:
                                    return True

                                if self.multi_protocol_capability_received is not None:
                                    return True

                                if self.nbr_cluster_id is not None:
                                    return True

                                if self.nbr_enforce_first_as is not None:
                                    return True

                                if self.nbr_in_cluster is not None:
                                    return True

                                if self.negotiated_protocol_version is not None:
                                    return True

                                if self.neighbor_interface_handle is not None:
                                    return True

                                if self.neighbor_local_as is not None:
                                    return True

                                if self.nsr_enabled is not None:
                                    return True

                                if self.nsr_state is not None:
                                    return True

                                if self.open_check_error_code is not None:
                                    return True

                                if self.peer_error_code is not None:
                                    return True

                                if self.peer_reset_reason is not None:
                                    return True

                                if self.performance_statistics is not None and self.performance_statistics._has_data():
                                    return True

                                if self.previous_connection_state is not None:
                                    return True

                                if self.read_armed is not None:
                                    return True

                                if self.received_notification_info is not None and self.received_notification_info._has_data():
                                    return True

                                if self.remote_as is not None:
                                    return True

                                if self.remote_as_number is not None:
                                    return True

                                if self.reset_notification_sent is not None:
                                    return True

                                if self.reset_reason is not None:
                                    return True

                                if self.router_id is not None:
                                    return True

                                if self.rpki_allow_invalid is not None:
                                    return True

                                if self.rpki_disable is not None:
                                    return True

                                if self.rpki_signal_ibgp is not None:
                                    return True

                                if self.rpki_use_validity is not None:
                                    return True

                                if self.second_last_k_aexpiry_reset is not None:
                                    return True

                                if self.second_last_k_astart_reset is not None:
                                    return True

                                if self.second_last_write_event is not None:
                                    return True

                                if self.send_notification_info is not None and self.send_notification_info._has_data():
                                    return True

                                if self.socket_read_bytes is not None:
                                    return True

                                if self.speaker_id is not None:
                                    return True

                                if self.standby_rp is not None:
                                    return True

                                if self.suppress4_byte_as is not None:
                                    return True

                                if self.tcp_init_sync_done_time_spec is not None and self.tcp_init_sync_done_time_spec._has_data():
                                    return True

                                if self.tcp_init_sync_phase_two_time_spec is not None and self.tcp_init_sync_phase_two_time_spec._has_data():
                                    return True

                                if self.tcp_init_sync_time_spec is not None and self.tcp_init_sync_time_spec._has_data():
                                    return True

                                if self.tcp_session_open_mode is not None:
                                    return True

                                if self.tcpmss is not None:
                                    return True

                                if self.time_last_cb is not None:
                                    return True

                                if self.time_last_cb_reset is not None:
                                    return True

                                if self.time_last_fb is not None:
                                    return True

                                if self.time_since_connection_last_dropped is not None:
                                    return True

                                if self.time_since_last_read is not None:
                                    return True

                                if self.time_since_last_read_reset is not None:
                                    return True

                                if self.time_since_last_update is not None:
                                    return True

                                if self.time_since_last_write is not None:
                                    return True

                                if self.time_since_last_write_reset is not None:
                                    return True

                                if self.time_since_second_last_write is not None:
                                    return True

                                if self.time_since_second_last_write_reset is not None:
                                    return True

                                if self.tos_type is not None:
                                    return True

                                if self.tos_value is not None:
                                    return True

                                if self.ttl_security_enabled is not None:
                                    return True

                                if self.update_bytes_read is not None:
                                    return True

                                if self.update_messages_in is not None:
                                    return True

                                if self.update_messages_out is not None:
                                    return True

                                if self.vrf_name is not None:
                                    return True

                                if self.write_armed is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbors'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.neighbor is not None:
                                for child_ref in self.neighbor:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors']['meta_info']


                    class NextHopVrf(object):
                        """
                        A BGP Next\-hop VRF table entry
                        
                        .. attribute:: last_notification_processing_time
                        
                        	Processing time for the last notification
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_notificationication_time
                        
                        	Time since the last notification was received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_notification_bestpath_changes
                        
                        	Number of bestpath changes caused by notification which resulted in maximum processing
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_notification_bestpath_deletes
                        
                        	Number of bestpath deletes caused by notification which resulted in maximum processing
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_proc_notification_time
                        
                        	How long since the maximum processing time notifcation was received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: maximum_processing_time
                        
                        	Maximum time spent procesing a single batch notification
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_processing_time
                        
                        	Total time spent in processing
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.last_notification_processing_time = None
                            self.last_notificationication_time = None
                            self.max_notification_bestpath_changes = None
                            self.max_notification_bestpath_deletes = None
                            self.max_proc_notification_time = None
                            self.maximum_processing_time = None
                            self.total_processing_time = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop-vrf'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.last_notification_processing_time is not None:
                                return True

                            if self.last_notificationication_time is not None:
                                return True

                            if self.max_notification_bestpath_changes is not None:
                                return True

                            if self.max_notification_bestpath_deletes is not None:
                                return True

                            if self.max_proc_notification_time is not None:
                                return True

                            if self.maximum_processing_time is not None:
                                return True

                            if self.total_processing_time is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.NextHopVrf']['meta_info']


                    class NeighborRanges(object):
                        """
                        The BGP Dynamic Neighbor Range table
                        
                        .. attribute:: neighbor_range
                        
                        	A BGP Neighbor Range table entry
                        	**type**\: list of    :py:class:`NeighborRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.neighbor_range = YList()
                            self.neighbor_range.parent = self
                            self.neighbor_range.name = 'neighbor_range'


                        class NeighborRange(object):
                            """
                            A BGP Neighbor Range table entry
                            
                            .. attribute:: neighbor_range_address  <key>
                            
                            	Neighbor Range prefix
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            
                            ----
                            .. attribute:: active_bmp_servers
                            
                            	BMP Servers to which the neighbor sends logs
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: addpath_receive_disable
                            
                            	Addpath Receive Disabled
                            	**type**\:  bool
                            
                            .. attribute:: addpath_receive_enable
                            
                            	Addpath Receive enable
                            	**type**\:  bool
                            
                            .. attribute:: addpath_send_disable
                            
                            	Addpath Send Disabled
                            	**type**\:  bool
                            
                            .. attribute:: addpath_send_enable
                            
                            	Addpath Send enabled
                            	**type**\:  bool
                            
                            .. attribute:: af_data
                            
                            	Address family specific neighbor data
                            	**type**\: list of    :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.AfData>`
                            
                            .. attribute:: attrf_group_name
                            
                            	Attrf Group Name
                            	**type**\:  str
                            
                            .. attribute:: bfd_minintervalval
                            
                            	BFD Mininterval for this peer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_multiplierval
                            
                            	BFD Multiplier for this peer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_session_enable_mode
                            
                            	BFD enable mode for this peer
                            	**type**\:   :py:class:`BgpBfdEnableModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdEnableModeEnum>`
                            
                            .. attribute:: cfg_local_address
                            
                            	Configured local address
                            	**type**\:   :py:class:`CfgLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress>`
                            
                            .. attribute:: configured_hold_time
                            
                            	Hold time (in secs) configured for this connection
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: configured_keepalive
                            
                            	Keepalive time (in secs) configured for this connection
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: configured_min_acc_hold_time
                            
                            	Minimum acceptable hold time from neighbor (in secs) configured for this connection
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: connection_local_address
                            
                            	Local address for the connection
                            	**type**\:   :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress>`
                            
                            .. attribute:: connection_remote_address
                            
                            	Remote address for the connection
                            	**type**\:   :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress>`
                            
                            .. attribute:: current_peers
                            
                            	Current Dynamic nbrs in range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: description
                            
                            	Description
                            	**type**\:  str
                            
                            .. attribute:: discard_as4_path
                            
                            	Discard AS4\_PATH in case there is a discrepancy in merging AS\_PATH and AS4\_PATH,retain ASPATH
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: dmz_link_bandwidth
                            
                            	Bandwidth of link to single\-hop eBGP peer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ebgp_recv_dmz
                            
                            	Receive Bandwidth of link to single\-hop eBGP peer
                            	**type**\:  bool
                            
                            .. attribute:: ebgp_send_dmz_mode
                            
                            	Ebgp send dmz link bw mode
                            	**type**\:   :py:class:`BgpEbgpSendDmzEnableModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableModeEnum>`
                            
                            .. attribute:: ebgp_time_to_live
                            
                            	Maximum number of hops for external BGP neighbor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: egress_peer_engineering_enabled
                            
                            	Indicates if Egress Peer Engineering is enabled
                            	**type**\:  bool
                            
                            .. attribute:: gr_restart_time
                            
                            	Neighbor restart time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: gr_stale_path_time
                            
                            	Neighbor stale\-path time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: graceful_maintenance
                            
                            	Graceful Maintenance
                            	**type**\:   :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.GracefulMaintenance>`
                            
                            .. attribute:: graceful_restart_enabled_nbr
                            
                            	Neighbor supports graceful\-restart
                            	**type**\:  bool
                            
                            .. attribute:: has_internal_link
                            
                            	Internal link to neighbor
                            	**type**\:  bool
                            
                            .. attribute:: idle_watch_time
                            
                            	Dynamic Neighbor idle\-watch time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: ignore_connected
                            
                            	If true, the VPN client isan IBGP CE peer
                            	**type**\:  bool
                            
                            .. attribute:: instance
                            
                            	Dynamic Neighbor Instance List
                            	**type**\: list of    :py:class:`Instance_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_>`
                            
                            .. attribute:: internal_vpn_client
                            
                            	If true, don't do NHconnected check for nbr
                            	**type**\:  bool
                            
                            .. attribute:: is_administratively_shut_down
                            
                            	Neighbor is administratively shut down
                            	**type**\:  bool
                            
                            .. attribute:: is_capability_negotiation_performed
                            
                            	Capability negotiation performed
                            	**type**\:  bool
                            
                            .. attribute:: is_ebgp_multihop_bgpmpls_forwarding_disabled
                            
                            	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_local_address_configured
                            
                            	Local address configured for the neighbor connection
                            	**type**\:  bool
                            
                            .. attribute:: is_neighbor_max_prefix_shutdown
                            
                            	Neighbor shut down because it exceeded max prfx count
                            	**type**\:  bool
                            
                            .. attribute:: is_out_of_memory_forced_up
                            
                            	Neighbor forced up during a low memory condition
                            	**type**\:  bool
                            
                            .. attribute:: is_passive_close
                            
                            	If true, active socket canbe closed if passive openis received for a GRcapable neighbor
                            	**type**\:  bool
                            
                            .. attribute:: islocal_address_cfg
                            
                            	Local address configured
                            	**type**\:  bool
                            
                            .. attribute:: local_as
                            
                            	Local AS number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_as_dual_as
                            
                            	Local AS Dual\-AS option
                            	**type**\:  bool
                            
                            .. attribute:: local_as_dual_as_mode_native
                            
                            	Applies only if Local AS Dual\-AS option is enabled. Indicates if Dual\-AS mode is native
                            	**type**\:  bool
                            
                            .. attribute:: local_as_no_prepend
                            
                            	Option to not prepend the Local AS to announcements
                            	**type**\:  bool
                            
                            .. attribute:: local_as_replace_as
                            
                            	Local AS Replace\-AS option
                            	**type**\:  bool
                            
                            .. attribute:: max_peers
                            
                            	Max Dynamic nbrs in range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: min_advertise_interval
                            
                            	Minimum advertisement interval, secs part
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: min_advertise_interval_msecs
                            
                            	Minimum advertisement interval, msecs part
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: millisecond
                            
                            .. attribute:: min_origination_interval
                            
                            	Minimum origination interval (in secs)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: msg_buf_count
                            
                            	Message Buf Count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msg_bug_circular
                            
                            	Message Buf Circular
                            	**type**\:  bool
                            
                            .. attribute:: msg_log_in
                            
                            	Message in log count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msg_log_out
                            
                            	Message out log count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nbr_cluster_id
                            
                            	Cluster id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nbr_enforce_first_as
                            
                            	Neighbor enforce first AS
                            	**type**\:  bool
                            
                            .. attribute:: nbr_in_cluster
                            
                            	Type of cluster\_id\:undefined/number/Ip address
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: nbr_rcv_size
                            
                            	Nbr Receive Size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nbr_send_size
                            
                            	Nbr Send Size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_local_as
                            
                            	Local AS configured on the neighbor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_range_prefix_length
                            
                            	Neighbor Range Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: nsr_enabled
                            
                            	Neighbor supports NSR
                            	**type**\:  bool
                            
                            .. attribute:: oper_attrf_enable
                            
                            	Oper attrf Enable
                            	**type**\:  bool
                            
                            .. attribute:: range_inst_error
                            
                            	Error during instance creation
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: range_max_drop
                            
                            	open drop due to max peers
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: range_open_accepted
                            
                            	open accepted
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: range_open_match
                            
                            	Passive open matching range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_as
                            
                            	Remote AS number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_as_list_name
                            
                            	Remote AS List Name
                            	**type**\:  str
                            
                            .. attribute:: remote_as_number
                            
                            	Remote AS number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rpki_allow_invalid
                            
                            	Prefix v. allow invalid
                            	**type**\:  bool
                            
                            .. attribute:: rpki_disable
                            
                            	Prefix validation disabled
                            	**type**\:  bool
                            
                            .. attribute:: rpki_signal_ibgp
                            
                            	Prefix v. signal ibgp
                            	**type**\:  bool
                            
                            .. attribute:: rpki_use_validity
                            
                            	Prefix v. use validity
                            	**type**\:  bool
                            
                            .. attribute:: speaker_id
                            
                            	Speaker this neighbor is allocated to
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: standby_rp
                            
                            	Standby RP socket inited for Active Open
                            	**type**\:  bool
                            
                            .. attribute:: suppress4_byte_as
                            
                            	Suppress 4byteas capability
                            	**type**\:  bool
                            
                            .. attribute:: syslog_enable
                            
                            	syslog enable
                            	**type**\:  bool
                            
                            .. attribute:: tcp_session_open_mode
                            
                            	The TCP mode to be used to set up BGP session with the neighbor
                            	**type**\:   :py:class:`BgpTcpModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpModeEnum>`
                            
                            .. attribute:: tcpmss
                            
                            	Neighbor TCP Maximum Segment                     size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tos_type
                            
                            	Precedence or DSCP type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tos_value
                            
                            	Precedence or DSCP value
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ttl_security_enabled
                            
                            	TTL Security enabled
                            	**type**\:  bool
                            
                            .. attribute:: upd_errh_noreset
                            
                            	Update errh noreset
                            	**type**\:  bool
                            
                            .. attribute:: update_source
                            
                            	Update Source
                            	**type**\:  str
                            
                            .. attribute:: vrf_name
                            
                            	Name of the VRF
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.neighbor_range_address = None
                                self.active_bmp_servers = None
                                self.addpath_receive_disable = None
                                self.addpath_receive_enable = None
                                self.addpath_send_disable = None
                                self.addpath_send_enable = None
                                self.af_data = YList()
                                self.af_data.parent = self
                                self.af_data.name = 'af_data'
                                self.attrf_group_name = None
                                self.bfd_minintervalval = None
                                self.bfd_multiplierval = None
                                self.bfd_session_enable_mode = None
                                self.cfg_local_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress()
                                self.cfg_local_address.parent = self
                                self.configured_hold_time = None
                                self.configured_keepalive = None
                                self.configured_min_acc_hold_time = None
                                self.connection_local_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress()
                                self.connection_local_address.parent = self
                                self.connection_remote_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress()
                                self.connection_remote_address.parent = self
                                self.current_peers = None
                                self.description = None
                                self.discard_as4_path = None
                                self.dmz_link_bandwidth = None
                                self.ebgp_recv_dmz = None
                                self.ebgp_send_dmz_mode = None
                                self.ebgp_time_to_live = None
                                self.egress_peer_engineering_enabled = None
                                self.gr_restart_time = None
                                self.gr_stale_path_time = None
                                self.graceful_maintenance = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.GracefulMaintenance()
                                self.graceful_maintenance.parent = self
                                self.graceful_restart_enabled_nbr = None
                                self.has_internal_link = None
                                self.idle_watch_time = None
                                self.ignore_connected = None
                                self.instance = YList()
                                self.instance.parent = self
                                self.instance.name = 'instance'
                                self.internal_vpn_client = None
                                self.is_administratively_shut_down = None
                                self.is_capability_negotiation_performed = None
                                self.is_ebgp_multihop_bgpmpls_forwarding_disabled = None
                                self.is_local_address_configured = None
                                self.is_neighbor_max_prefix_shutdown = None
                                self.is_out_of_memory_forced_up = None
                                self.is_passive_close = None
                                self.islocal_address_cfg = None
                                self.local_as = None
                                self.local_as_dual_as = None
                                self.local_as_dual_as_mode_native = None
                                self.local_as_no_prepend = None
                                self.local_as_replace_as = None
                                self.max_peers = None
                                self.min_advertise_interval = None
                                self.min_advertise_interval_msecs = None
                                self.min_origination_interval = None
                                self.msg_buf_count = None
                                self.msg_bug_circular = None
                                self.msg_log_in = None
                                self.msg_log_out = None
                                self.nbr_cluster_id = None
                                self.nbr_enforce_first_as = None
                                self.nbr_in_cluster = None
                                self.nbr_rcv_size = None
                                self.nbr_send_size = None
                                self.neighbor_local_as = None
                                self.neighbor_range_prefix_length = None
                                self.nsr_enabled = None
                                self.oper_attrf_enable = None
                                self.range_inst_error = None
                                self.range_max_drop = None
                                self.range_open_accepted = None
                                self.range_open_match = None
                                self.remote_as = None
                                self.remote_as_list_name = None
                                self.remote_as_number = None
                                self.rpki_allow_invalid = None
                                self.rpki_disable = None
                                self.rpki_signal_ibgp = None
                                self.rpki_use_validity = None
                                self.speaker_id = None
                                self.standby_rp = None
                                self.suppress4_byte_as = None
                                self.syslog_enable = None
                                self.tcp_session_open_mode = None
                                self.tcpmss = None
                                self.tos_type = None
                                self.tos_value = None
                                self.ttl_security_enabled = None
                                self.upd_errh_noreset = None
                                self.update_source = None
                                self.vrf_name = None


                            class ConnectionLocalAddress(object):
                                """
                                Local address for the connection
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpnvpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnvplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4mdt_address = None
                                    self.ipv4mvpn_address = None
                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                    self.ipv4sr_policy_address.parent = self
                                    self.ipv4vpn_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                    self.ipv6sr_policy_address.parent = self
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_flowspec_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.l2vpn_evpn_address = None
                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnvplsAddress()
                                    self.l2vpnvpls_address.parent = self
                                    self.ls_ls_address = None
                                    self.rt_constraint_address = None


                                class L2VpnvplsAddress(object):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnvplsAddress']['meta_info']


                                class L2VpnMspwAddress(object):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnMspwAddress']['meta_info']


                                class Ipv4SrPolicyAddress(object):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress']['meta_info']


                                class Ipv6SrPolicyAddress(object):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv6_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv6_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connection-local-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.afi is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv4_flowspec_address is not None:
                                        return True

                                    if self.ipv4_label_address is not None:
                                        return True

                                    if self.ipv4_mcast_address is not None:
                                        return True

                                    if self.ipv4_tunnel_address is not None:
                                        return True

                                    if self.ipv4mdt_address is not None:
                                        return True

                                    if self.ipv4mvpn_address is not None:
                                        return True

                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                        return True

                                    if self.ipv4vpn_address is not None:
                                        return True

                                    if self.ipv4vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv4vpna_mcastddress is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    if self.ipv6_flowspec_address is not None:
                                        return True

                                    if self.ipv6_label_address is not None:
                                        return True

                                    if self.ipv6_mcast_address is not None:
                                        return True

                                    if self.ipv6mvpn_address is not None:
                                        return True

                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                        return True

                                    if self.ipv6vpn_address is not None:
                                        return True

                                    if self.ipv6vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv6vpn_mcast_address is not None:
                                        return True

                                    if self.l2vpn_evpn_address is not None:
                                        return True

                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                        return True

                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                        return True

                                    if self.ls_ls_address is not None:
                                        return True

                                    if self.rt_constraint_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress']['meta_info']


                            class ConnectionRemoteAddress(object):
                                """
                                Remote address for the connection
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpnvpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnvplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4mdt_address = None
                                    self.ipv4mvpn_address = None
                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                    self.ipv4sr_policy_address.parent = self
                                    self.ipv4vpn_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                    self.ipv6sr_policy_address.parent = self
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_flowspec_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.l2vpn_evpn_address = None
                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnvplsAddress()
                                    self.l2vpnvpls_address.parent = self
                                    self.ls_ls_address = None
                                    self.rt_constraint_address = None


                                class L2VpnvplsAddress(object):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnvplsAddress']['meta_info']


                                class L2VpnMspwAddress(object):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnMspwAddress']['meta_info']


                                class Ipv4SrPolicyAddress(object):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress']['meta_info']


                                class Ipv6SrPolicyAddress(object):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv6_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv6_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connection-remote-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.afi is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv4_flowspec_address is not None:
                                        return True

                                    if self.ipv4_label_address is not None:
                                        return True

                                    if self.ipv4_mcast_address is not None:
                                        return True

                                    if self.ipv4_tunnel_address is not None:
                                        return True

                                    if self.ipv4mdt_address is not None:
                                        return True

                                    if self.ipv4mvpn_address is not None:
                                        return True

                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                        return True

                                    if self.ipv4vpn_address is not None:
                                        return True

                                    if self.ipv4vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv4vpna_mcastddress is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    if self.ipv6_flowspec_address is not None:
                                        return True

                                    if self.ipv6_label_address is not None:
                                        return True

                                    if self.ipv6_mcast_address is not None:
                                        return True

                                    if self.ipv6mvpn_address is not None:
                                        return True

                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                        return True

                                    if self.ipv6vpn_address is not None:
                                        return True

                                    if self.ipv6vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv6vpn_mcast_address is not None:
                                        return True

                                    if self.l2vpn_evpn_address is not None:
                                        return True

                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                        return True

                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                        return True

                                    if self.ls_ls_address is not None:
                                        return True

                                    if self.rt_constraint_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress']['meta_info']


                            class GracefulMaintenance(object):
                                """
                                Graceful Maintenance
                                
                                .. attribute:: gshut_active
                                
                                	Graceful Maintenance activated
                                	**type**\:  bool
                                
                                .. attribute:: gshut_exists
                                
                                	Graceful Maintenance enabled
                                	**type**\:  bool
                                
                                .. attribute:: gshut_local_active
                                
                                	Graceful Maintenance locally activated
                                	**type**\:  bool
                                
                                .. attribute:: gshut_locpref
                                
                                	Graceful Maintenance Local Preference
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: gshut_locpref_set
                                
                                	Graceful Maintenance Local Preference set
                                	**type**\:  bool
                                
                                .. attribute:: gshut_prepends
                                
                                	Graceful Maintenance number of AS prepends
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.gshut_active = None
                                    self.gshut_exists = None
                                    self.gshut_local_active = None
                                    self.gshut_locpref = None
                                    self.gshut_locpref_set = None
                                    self.gshut_prepends = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:graceful-maintenance'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.gshut_active is not None:
                                        return True

                                    if self.gshut_exists is not None:
                                        return True

                                    if self.gshut_local_active is not None:
                                        return True

                                    if self.gshut_locpref is not None:
                                        return True

                                    if self.gshut_locpref_set is not None:
                                        return True

                                    if self.gshut_prepends is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.GracefulMaintenance']['meta_info']


                            class CfgLocalAddress(object):
                                """
                                Configured local address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpnvpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnvplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4mdt_address = None
                                    self.ipv4mvpn_address = None
                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress()
                                    self.ipv4sr_policy_address.parent = self
                                    self.ipv4vpn_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress()
                                    self.ipv6sr_policy_address.parent = self
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_flowspec_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.l2vpn_evpn_address = None
                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnvplsAddress()
                                    self.l2vpnvpls_address.parent = self
                                    self.ls_ls_address = None
                                    self.rt_constraint_address = None


                                class L2VpnvplsAddress(object):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnvplsAddress']['meta_info']


                                class L2VpnMspwAddress(object):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnMspwAddress']['meta_info']


                                class Ipv4SrPolicyAddress(object):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress']['meta_info']


                                class Ipv6SrPolicyAddress(object):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv6_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv6_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cfg-local-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.afi is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv4_flowspec_address is not None:
                                        return True

                                    if self.ipv4_label_address is not None:
                                        return True

                                    if self.ipv4_mcast_address is not None:
                                        return True

                                    if self.ipv4_tunnel_address is not None:
                                        return True

                                    if self.ipv4mdt_address is not None:
                                        return True

                                    if self.ipv4mvpn_address is not None:
                                        return True

                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                        return True

                                    if self.ipv4vpn_address is not None:
                                        return True

                                    if self.ipv4vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv4vpna_mcastddress is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    if self.ipv6_flowspec_address is not None:
                                        return True

                                    if self.ipv6_label_address is not None:
                                        return True

                                    if self.ipv6_mcast_address is not None:
                                        return True

                                    if self.ipv6mvpn_address is not None:
                                        return True

                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                        return True

                                    if self.ipv6vpn_address is not None:
                                        return True

                                    if self.ipv6vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv6vpn_mcast_address is not None:
                                        return True

                                    if self.l2vpn_evpn_address is not None:
                                        return True

                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                        return True

                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                        return True

                                    if self.ls_ls_address is not None:
                                        return True

                                    if self.rt_constraint_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress']['meta_info']


                            class AfData(object):
                                """
                                Address family specific neighbor data
                                
                                .. attribute:: accept_own_enabled
                                
                                	Accept\-Own enabled
                                	**type**\:  bool
                                
                                .. attribute:: address_family_long_lived_time
                                
                                	AF specific Long\-lived\-time config
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: advertise_afi
                                
                                	Encode in Advertise AFI
                                	**type**\:  bool
                                
                                .. attribute:: advertise_afi_disable
                                
                                	Encode in Advertise AFI
                                	**type**\:  bool
                                
                                .. attribute:: advertise_afi_local
                                
                                	Encode in Advertise AFI
                                	**type**\:  bool
                                
                                .. attribute:: advertise_afi_reorg
                                
                                	Encode in Advertise AFI
                                	**type**\:  bool
                                
                                .. attribute:: advertise_v4_flags
                                
                                	Advertise options for VPNV4
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: advertise_v6_flags
                                
                                	Advertise options for VPNV6
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: af_name
                                
                                	Address family identifier
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: afrpki_allow_invalid
                                
                                	Prefix v. allow invalid
                                	**type**\:  bool
                                
                                .. attribute:: afrpki_disable
                                
                                	Prefix validation disabled
                                	**type**\:  bool
                                
                                .. attribute:: afrpki_signal_ibgp
                                
                                	Prefix v. signal ibgp
                                	**type**\:  bool
                                
                                .. attribute:: afrpki_use_validity
                                
                                	Prefix v. use validity
                                	**type**\:  bool
                                
                                .. attribute:: allow_as_in_count
                                
                                	Allowas\-in count config
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: always_use_next_hop_local
                                
                                	Local router always used for next\-hop
                                	**type**\:  bool
                                
                                .. attribute:: extended_community
                                
                                	Extended community attribute
                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity>`
                                
                                .. attribute:: extended_community_standby
                                
                                	Extended community attribute
                                	**type**\: list of    :py:class:`ExtendedCommunityStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby>`
                                
                                .. attribute:: flowspec_redirect_validation_d_isable
                                
                                	Flowspec Redirect Validation Disabled
                                	**type**\:  bool
                                
                                .. attribute:: flowspec_validation_d_isable
                                
                                	Flowspec Validation Disabled
                                	**type**\:  bool
                                
                                .. attribute:: import_reoriginate
                                
                                	Import Reoriginate enabled
                                	**type**\:  bool
                                
                                .. attribute:: import_reoriginate_stitching
                                
                                	Import Reoriginate Stitching enabled
                                	**type**\:  bool
                                
                                .. attribute:: import_stitching
                                
                                	Import Stitching enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_add_path_receive_capability_advertised
                                
                                	Addpath Receive capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_add_path_receive_capability_received
                                
                                	Addpath Receive capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_add_path_send_capability_advertised
                                
                                	Addpath Send capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_add_path_send_capability_received
                                
                                	Addpath Send capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_addpath_receive_operational
                                
                                	Addpath is operational on receive\-side
                                	**type**\:  bool
                                
                                .. attribute:: is_addpath_send_operational
                                
                                	Addpath is operational on send\-side
                                	**type**\:  bool
                                
                                .. attribute:: is_advertise_permanent_network
                                
                                	Advertise Permanent Network
                                	**type**\:  bool
                                
                                .. attribute:: is_advertised_graceful_restart
                                
                                	Graceful Restart Capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_advertised_orf_receive
                                
                                	Prefix based ORF receive mode capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_advertised_orf_send
                                
                                	Prefix based ORF send mode capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_aigp_set
                                
                                	AIGP set 
                                	**type**\:  bool
                                
                                .. attribute:: is_allow_as_in_set
                                
                                	Allowas\-in set 
                                	**type**\:  bool
                                
                                .. attribute:: is_as_override_set
                                
                                	As override set 
                                	**type**\:  bool
                                
                                .. attribute:: is_graceful_restart_state_flag
                                
                                	Restart state flag enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_legacy_pe_rt
                                
                                	Nbr accepts route from legacy PE for RT\-Constraint AF 
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_af_capable
                                
                                	Address family capability received from neighbor
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_ebgp_without_inbound_policy
                                
                                	eBGP neighbor with no configured inbound policy
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_ebgp_without_outbound_policy
                                
                                	eBGP neighbor with no configured outbound policy
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_route_reflector_client
                                
                                	Nbr is a route reflector client
                                	**type**\:  bool
                                
                                .. attribute:: is_orf_send_scheduled
                                
                                	Scheduled to send prefix based ORF
                                	**type**\:  bool
                                
                                .. attribute:: is_orf_sent
                                
                                	Outbound route filter sent to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: is_orr_root_address_configured
                                
                                	ORR Root address configuredfor the neighbor connection
                                	**type**\:  bool
                                
                                .. attribute:: is_peer_orf_capable
                                
                                	Peer has outbound route filter capability
                                	**type**\:  bool
                                
                                .. attribute:: is_prefix_orf_present
                                
                                	Outbound route filter prefix ORF present
                                	**type**\:  bool
                                
                                .. attribute:: is_received_graceful_restart_capable
                                
                                	Graceful Restart Capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_received_orf_receive_capable
                                
                                	Prefix based ORF receive mode capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_received_orf_send_capable
                                
                                	Prefix based ORF send mode capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_rt_present
                                
                                	RT attribute list present
                                	**type**\:  bool
                                
                                .. attribute:: is_rt_present_standby
                                
                                	RT attribute list present
                                	**type**\:  bool
                                
                                .. attribute:: is_send_mcast_attr
                                
                                	Send Mcast Attr
                                	**type**\:  bool
                                
                                .. attribute:: is_soft_reconfiguration_inbound_allowed
                                
                                	Inbound soft reconfiguration allowed
                                	**type**\:  bool
                                
                                .. attribute:: is_update_deferred
                                
                                	Update deferred until ORF/route refresh received
                                	**type**\:  bool
                                
                                .. attribute:: is_use_soft_reconfiguration_always_on
                                
                                	Soft reconf overrides route refresh
                                	**type**\:  bool
                                
                                .. attribute:: local_restart_time
                                
                                	Local Restart time (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: long_lived_graceful_restart_capability_received
                                
                                	Long\-lived graceful\-restart capability received from the neighbor
                                	**type**\:  bool
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_accept
                                
                                	Maximum long\-lived graceful\-restart stale time acceptable from the neighbor (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_configured
                                
                                	Long\-lived graceful\-restart stale time is configured
                                	**type**\:  bool
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_received
                                
                                	Long\-lived graceful\-restart stale time received from the neighbor (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_sent
                                
                                	Stale time sent in long\-lived graceful\-restart capability (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: max_prefix_discard_extra_paths
                                
                                	Discard extra paths when prefix limit reached
                                	**type**\:  bool
                                
                                .. attribute:: max_prefix_exceed_discard_paths
                                
                                	Did we discard extra paths when prefix limit reached
                                	**type**\:  bool
                                
                                .. attribute:: max_prefix_limit
                                
                                	Max limit for # of prefixes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max_prefix_restart_time
                                
                                	Time interval (in minutes) after which peering session will be reestablished
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: minute
                                
                                .. attribute:: max_prefix_threshold_percent
                                
                                	Percentage of maximum no. of prefixes at which to generate warning
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: percentage
                                
                                .. attribute:: neighbor_default_originate
                                
                                	Neighbor originates default
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_long_lived_graceful_restart_capable
                                
                                	Treat neighbor as long\-lived graceful\-restart capable
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_long_lived_graceful_restart_time_remaining
                                
                                	Remaining long\-lived graceful\-restart time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_preserved_forwarding_state
                                
                                	Neighbor preserved forwarding state
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_preserved_long_lived_forwarding_state
                                
                                	Neighbor preserved long\-lived forwarding state
                                	**type**\:  bool
                                
                                .. attribute:: next_hop_unchanged
                                
                                	router does not change next\-hop
                                	**type**\:  bool
                                
                                .. attribute:: orf_entries_received
                                
                                	Number of outbound route filter entries received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: orr_group_index
                                
                                	ORR Group Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: orr_group_name
                                
                                	ORR Group Name
                                	**type**\:  str
                                
                                .. attribute:: remove_private_as_entire_aspath_from_inbound_updates
                                
                                	Private AS numbers removed from updates from this nbr only if the aspath has only private ASes
                                	**type**\:  bool
                                
                                .. attribute:: remove_private_as_entire_aspath_from_updates
                                
                                	Private AS numbers removed from updates to thisnbr only if the aspath hasonly private ASes
                                	**type**\:  bool
                                
                                .. attribute:: remove_private_as_from_inbound_updates
                                
                                	Private AS numbers removed from updates from this nbr
                                	**type**\:  bool
                                
                                .. attribute:: remove_private_as_from_updates
                                
                                	Private AS numbers removed from updates to this nbr
                                	**type**\:  bool
                                
                                .. attribute:: restart_time
                                
                                	Restart time advertised (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: rib_purge_timeout_value
                                
                                	RIB purge timeout time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: route_policy_default_originate
                                
                                	Default\-originate route policy name
                                	**type**\:  str
                                
                                .. attribute:: route_policy_in
                                
                                	Incoming route policy name
                                	**type**\:  str
                                
                                .. attribute:: route_policy_out
                                
                                	Outgoing route policy name
                                	**type**\:  str
                                
                                .. attribute:: route_policy_prefix_orf
                                
                                	Prefix based ORF for incoming updates
                                	**type**\:  str
                                
                                .. attribute:: selective_multipath_eligible
                                
                                	Selective multipath eligible
                                	**type**\:  bool
                                
                                .. attribute:: sent_community_to_neighbor
                                
                                	Community attribute sent to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: sent_extended_community_to_neighbor
                                
                                	Extended community attribute sent to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: sent_gshut_community_to_neighbor
                                
                                	GSHUT Community attribute sent to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: stale_path_timeout
                                
                                	Stale path timeout time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: use_max_prefix_warning_only
                                
                                	Warning only when maximum prefix limit reached
                                	**type**\:  bool
                                
                                .. attribute:: vpn_update_gen_enabled
                                
                                	RT Nbr enabled for updategento another
                                	**type**\:  bool
                                
                                .. attribute:: vpn_update_gen_trigger_enabled
                                
                                	RT Nbr enabled for updategento another
                                	**type**\:  bool
                                
                                .. attribute:: weight
                                
                                	Weight for this AF
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.accept_own_enabled = None
                                    self.address_family_long_lived_time = None
                                    self.advertise_afi = None
                                    self.advertise_afi_disable = None
                                    self.advertise_afi_local = None
                                    self.advertise_afi_reorg = None
                                    self.advertise_v4_flags = None
                                    self.advertise_v6_flags = None
                                    self.af_name = None
                                    self.afrpki_allow_invalid = None
                                    self.afrpki_disable = None
                                    self.afrpki_signal_ibgp = None
                                    self.afrpki_use_validity = None
                                    self.allow_as_in_count = None
                                    self.always_use_next_hop_local = None
                                    self.extended_community = YList()
                                    self.extended_community.parent = self
                                    self.extended_community.name = 'extended_community'
                                    self.extended_community_standby = YList()
                                    self.extended_community_standby.parent = self
                                    self.extended_community_standby.name = 'extended_community_standby'
                                    self.flowspec_redirect_validation_d_isable = None
                                    self.flowspec_validation_d_isable = None
                                    self.import_reoriginate = None
                                    self.import_reoriginate_stitching = None
                                    self.import_stitching = None
                                    self.is_add_path_receive_capability_advertised = None
                                    self.is_add_path_receive_capability_received = None
                                    self.is_add_path_send_capability_advertised = None
                                    self.is_add_path_send_capability_received = None
                                    self.is_addpath_receive_operational = None
                                    self.is_addpath_send_operational = None
                                    self.is_advertise_permanent_network = None
                                    self.is_advertised_graceful_restart = None
                                    self.is_advertised_orf_receive = None
                                    self.is_advertised_orf_send = None
                                    self.is_aigp_set = None
                                    self.is_allow_as_in_set = None
                                    self.is_as_override_set = None
                                    self.is_graceful_restart_state_flag = None
                                    self.is_legacy_pe_rt = None
                                    self.is_neighbor_af_capable = None
                                    self.is_neighbor_ebgp_without_inbound_policy = None
                                    self.is_neighbor_ebgp_without_outbound_policy = None
                                    self.is_neighbor_route_reflector_client = None
                                    self.is_orf_send_scheduled = None
                                    self.is_orf_sent = None
                                    self.is_orr_root_address_configured = None
                                    self.is_peer_orf_capable = None
                                    self.is_prefix_orf_present = None
                                    self.is_received_graceful_restart_capable = None
                                    self.is_received_orf_receive_capable = None
                                    self.is_received_orf_send_capable = None
                                    self.is_rt_present = None
                                    self.is_rt_present_standby = None
                                    self.is_send_mcast_attr = None
                                    self.is_soft_reconfiguration_inbound_allowed = None
                                    self.is_update_deferred = None
                                    self.is_use_soft_reconfiguration_always_on = None
                                    self.local_restart_time = None
                                    self.long_lived_graceful_restart_capability_received = None
                                    self.long_lived_graceful_restart_stale_time_accept = None
                                    self.long_lived_graceful_restart_stale_time_configured = None
                                    self.long_lived_graceful_restart_stale_time_received = None
                                    self.long_lived_graceful_restart_stale_time_sent = None
                                    self.max_prefix_discard_extra_paths = None
                                    self.max_prefix_exceed_discard_paths = None
                                    self.max_prefix_limit = None
                                    self.max_prefix_restart_time = None
                                    self.max_prefix_threshold_percent = None
                                    self.neighbor_default_originate = None
                                    self.neighbor_long_lived_graceful_restart_capable = None
                                    self.neighbor_long_lived_graceful_restart_time_remaining = None
                                    self.neighbor_preserved_forwarding_state = None
                                    self.neighbor_preserved_long_lived_forwarding_state = None
                                    self.next_hop_unchanged = None
                                    self.orf_entries_received = None
                                    self.orr_group_index = None
                                    self.orr_group_name = None
                                    self.remove_private_as_entire_aspath_from_inbound_updates = None
                                    self.remove_private_as_entire_aspath_from_updates = None
                                    self.remove_private_as_from_inbound_updates = None
                                    self.remove_private_as_from_updates = None
                                    self.restart_time = None
                                    self.rib_purge_timeout_value = None
                                    self.route_policy_default_originate = None
                                    self.route_policy_in = None
                                    self.route_policy_out = None
                                    self.route_policy_prefix_orf = None
                                    self.selective_multipath_eligible = None
                                    self.sent_community_to_neighbor = None
                                    self.sent_extended_community_to_neighbor = None
                                    self.sent_gshut_community_to_neighbor = None
                                    self.stale_path_timeout = None
                                    self.use_max_prefix_warning_only = None
                                    self.vpn_update_gen_enabled = None
                                    self.vpn_update_gen_trigger_enabled = None
                                    self.weight = None


                                class ExtendedCommunity(object):
                                    """
                                    Extended community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity']['meta_info']


                                class ExtendedCommunityStandby(object):
                                    """
                                    Extended community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community-standby'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af-data'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.accept_own_enabled is not None:
                                        return True

                                    if self.address_family_long_lived_time is not None:
                                        return True

                                    if self.advertise_afi is not None:
                                        return True

                                    if self.advertise_afi_disable is not None:
                                        return True

                                    if self.advertise_afi_local is not None:
                                        return True

                                    if self.advertise_afi_reorg is not None:
                                        return True

                                    if self.advertise_v4_flags is not None:
                                        return True

                                    if self.advertise_v6_flags is not None:
                                        return True

                                    if self.af_name is not None:
                                        return True

                                    if self.afrpki_allow_invalid is not None:
                                        return True

                                    if self.afrpki_disable is not None:
                                        return True

                                    if self.afrpki_signal_ibgp is not None:
                                        return True

                                    if self.afrpki_use_validity is not None:
                                        return True

                                    if self.allow_as_in_count is not None:
                                        return True

                                    if self.always_use_next_hop_local is not None:
                                        return True

                                    if self.extended_community is not None:
                                        for child_ref in self.extended_community:
                                            if child_ref._has_data():
                                                return True

                                    if self.extended_community_standby is not None:
                                        for child_ref in self.extended_community_standby:
                                            if child_ref._has_data():
                                                return True

                                    if self.flowspec_redirect_validation_d_isable is not None:
                                        return True

                                    if self.flowspec_validation_d_isable is not None:
                                        return True

                                    if self.import_reoriginate is not None:
                                        return True

                                    if self.import_reoriginate_stitching is not None:
                                        return True

                                    if self.import_stitching is not None:
                                        return True

                                    if self.is_add_path_receive_capability_advertised is not None:
                                        return True

                                    if self.is_add_path_receive_capability_received is not None:
                                        return True

                                    if self.is_add_path_send_capability_advertised is not None:
                                        return True

                                    if self.is_add_path_send_capability_received is not None:
                                        return True

                                    if self.is_addpath_receive_operational is not None:
                                        return True

                                    if self.is_addpath_send_operational is not None:
                                        return True

                                    if self.is_advertise_permanent_network is not None:
                                        return True

                                    if self.is_advertised_graceful_restart is not None:
                                        return True

                                    if self.is_advertised_orf_receive is not None:
                                        return True

                                    if self.is_advertised_orf_send is not None:
                                        return True

                                    if self.is_aigp_set is not None:
                                        return True

                                    if self.is_allow_as_in_set is not None:
                                        return True

                                    if self.is_as_override_set is not None:
                                        return True

                                    if self.is_graceful_restart_state_flag is not None:
                                        return True

                                    if self.is_legacy_pe_rt is not None:
                                        return True

                                    if self.is_neighbor_af_capable is not None:
                                        return True

                                    if self.is_neighbor_ebgp_without_inbound_policy is not None:
                                        return True

                                    if self.is_neighbor_ebgp_without_outbound_policy is not None:
                                        return True

                                    if self.is_neighbor_route_reflector_client is not None:
                                        return True

                                    if self.is_orf_send_scheduled is not None:
                                        return True

                                    if self.is_orf_sent is not None:
                                        return True

                                    if self.is_orr_root_address_configured is not None:
                                        return True

                                    if self.is_peer_orf_capable is not None:
                                        return True

                                    if self.is_prefix_orf_present is not None:
                                        return True

                                    if self.is_received_graceful_restart_capable is not None:
                                        return True

                                    if self.is_received_orf_receive_capable is not None:
                                        return True

                                    if self.is_received_orf_send_capable is not None:
                                        return True

                                    if self.is_rt_present is not None:
                                        return True

                                    if self.is_rt_present_standby is not None:
                                        return True

                                    if self.is_send_mcast_attr is not None:
                                        return True

                                    if self.is_soft_reconfiguration_inbound_allowed is not None:
                                        return True

                                    if self.is_update_deferred is not None:
                                        return True

                                    if self.is_use_soft_reconfiguration_always_on is not None:
                                        return True

                                    if self.local_restart_time is not None:
                                        return True

                                    if self.long_lived_graceful_restart_capability_received is not None:
                                        return True

                                    if self.long_lived_graceful_restart_stale_time_accept is not None:
                                        return True

                                    if self.long_lived_graceful_restart_stale_time_configured is not None:
                                        return True

                                    if self.long_lived_graceful_restart_stale_time_received is not None:
                                        return True

                                    if self.long_lived_graceful_restart_stale_time_sent is not None:
                                        return True

                                    if self.max_prefix_discard_extra_paths is not None:
                                        return True

                                    if self.max_prefix_exceed_discard_paths is not None:
                                        return True

                                    if self.max_prefix_limit is not None:
                                        return True

                                    if self.max_prefix_restart_time is not None:
                                        return True

                                    if self.max_prefix_threshold_percent is not None:
                                        return True

                                    if self.neighbor_default_originate is not None:
                                        return True

                                    if self.neighbor_long_lived_graceful_restart_capable is not None:
                                        return True

                                    if self.neighbor_long_lived_graceful_restart_time_remaining is not None:
                                        return True

                                    if self.neighbor_preserved_forwarding_state is not None:
                                        return True

                                    if self.neighbor_preserved_long_lived_forwarding_state is not None:
                                        return True

                                    if self.next_hop_unchanged is not None:
                                        return True

                                    if self.orf_entries_received is not None:
                                        return True

                                    if self.orr_group_index is not None:
                                        return True

                                    if self.orr_group_name is not None:
                                        return True

                                    if self.remove_private_as_entire_aspath_from_inbound_updates is not None:
                                        return True

                                    if self.remove_private_as_entire_aspath_from_updates is not None:
                                        return True

                                    if self.remove_private_as_from_inbound_updates is not None:
                                        return True

                                    if self.remove_private_as_from_updates is not None:
                                        return True

                                    if self.restart_time is not None:
                                        return True

                                    if self.rib_purge_timeout_value is not None:
                                        return True

                                    if self.route_policy_default_originate is not None:
                                        return True

                                    if self.route_policy_in is not None:
                                        return True

                                    if self.route_policy_out is not None:
                                        return True

                                    if self.route_policy_prefix_orf is not None:
                                        return True

                                    if self.selective_multipath_eligible is not None:
                                        return True

                                    if self.sent_community_to_neighbor is not None:
                                        return True

                                    if self.sent_extended_community_to_neighbor is not None:
                                        return True

                                    if self.sent_gshut_community_to_neighbor is not None:
                                        return True

                                    if self.stale_path_timeout is not None:
                                        return True

                                    if self.use_max_prefix_warning_only is not None:
                                        return True

                                    if self.vpn_update_gen_enabled is not None:
                                        return True

                                    if self.vpn_update_gen_trigger_enabled is not None:
                                        return True

                                    if self.weight is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.AfData']['meta_info']


                            class Instance_(object):
                                """
                                Dynamic Neighbor Instance List
                                
                                .. attribute:: connection_state
                                
                                	State of connection
                                	**type**\:   :py:class:`BgpConnStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnStateEnum>`
                                
                                .. attribute:: idle_watch_timer_remaining_value
                                
                                	Idle watch timer remaining time
                                	**type**\:   :py:class:`IdleWatchTimerRemainingValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.IdleWatchTimerRemainingValue>`
                                
                                .. attribute:: is_idle_watch_timer_running
                                
                                	Is idle watch timer running
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_address
                                
                                	Dynamic Neighbor address
                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress>`
                                
                                .. attribute:: neighbor_age
                                
                                	Neighbor age
                                	**type**\:   :py:class:`NeighborAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAge>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.connection_state = None
                                    self.idle_watch_timer_remaining_value = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.IdleWatchTimerRemainingValue()
                                    self.idle_watch_timer_remaining_value.parent = self
                                    self.is_idle_watch_timer_running = None
                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress()
                                    self.neighbor_address.parent = self
                                    self.neighbor_age = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAge()
                                    self.neighbor_age.parent = self


                                class NeighborAddress(object):
                                    """
                                    Dynamic Neighbor address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpnvpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2VpnvplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4mdt_address = None
                                        self.ipv4mvpn_address = None
                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv4SrPolicyAddress()
                                        self.ipv4sr_policy_address.parent = self
                                        self.ipv4vpn_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv6SrPolicyAddress()
                                        self.ipv6sr_policy_address.parent = self
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_flowspec_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.l2vpn_evpn_address = None
                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2VpnvplsAddress()
                                        self.l2vpnvpls_address.parent = self
                                        self.ls_ls_address = None
                                        self.rt_constraint_address = None


                                    class L2VpnvplsAddress(object):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                    class L2VpnMspwAddress(object):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                    class Ipv4SrPolicyAddress(object):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                    class Ipv6SrPolicyAddress(object):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv6_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv6_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.afi is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv4_flowspec_address is not None:
                                            return True

                                        if self.ipv4_label_address is not None:
                                            return True

                                        if self.ipv4_mcast_address is not None:
                                            return True

                                        if self.ipv4_tunnel_address is not None:
                                            return True

                                        if self.ipv4mdt_address is not None:
                                            return True

                                        if self.ipv4mvpn_address is not None:
                                            return True

                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                            return True

                                        if self.ipv4vpn_address is not None:
                                            return True

                                        if self.ipv4vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv4vpna_mcastddress is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        if self.ipv6_flowspec_address is not None:
                                            return True

                                        if self.ipv6_label_address is not None:
                                            return True

                                        if self.ipv6_mcast_address is not None:
                                            return True

                                        if self.ipv6mvpn_address is not None:
                                            return True

                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                            return True

                                        if self.ipv6vpn_address is not None:
                                            return True

                                        if self.ipv6vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv6vpn_mcast_address is not None:
                                            return True

                                        if self.l2vpn_evpn_address is not None:
                                            return True

                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                            return True

                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                            return True

                                        if self.ls_ls_address is not None:
                                            return True

                                        if self.rt_constraint_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress']['meta_info']


                                class NeighborAge(object):
                                    """
                                    Neighbor age
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-age'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAge']['meta_info']


                                class IdleWatchTimerRemainingValue(object):
                                    """
                                    Idle watch timer remaining time
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:idle-watch-timer-remaining-value'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.IdleWatchTimerRemainingValue']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:instance'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.connection_state is not None:
                                        return True

                                    if self.idle_watch_timer_remaining_value is not None and self.idle_watch_timer_remaining_value._has_data():
                                        return True

                                    if self.is_idle_watch_timer_running is not None:
                                        return True

                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                        return True

                                    if self.neighbor_age is not None and self.neighbor_age._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.neighbor_range_address is None:
                                    raise YPYModelError('Key property neighbor_range_address is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-range[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-range-address = ' + str(self.neighbor_range_address) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.neighbor_range_address is not None:
                                    return True

                                if self.active_bmp_servers is not None:
                                    return True

                                if self.addpath_receive_disable is not None:
                                    return True

                                if self.addpath_receive_enable is not None:
                                    return True

                                if self.addpath_send_disable is not None:
                                    return True

                                if self.addpath_send_enable is not None:
                                    return True

                                if self.af_data is not None:
                                    for child_ref in self.af_data:
                                        if child_ref._has_data():
                                            return True

                                if self.attrf_group_name is not None:
                                    return True

                                if self.bfd_minintervalval is not None:
                                    return True

                                if self.bfd_multiplierval is not None:
                                    return True

                                if self.bfd_session_enable_mode is not None:
                                    return True

                                if self.cfg_local_address is not None and self.cfg_local_address._has_data():
                                    return True

                                if self.configured_hold_time is not None:
                                    return True

                                if self.configured_keepalive is not None:
                                    return True

                                if self.configured_min_acc_hold_time is not None:
                                    return True

                                if self.connection_local_address is not None and self.connection_local_address._has_data():
                                    return True

                                if self.connection_remote_address is not None and self.connection_remote_address._has_data():
                                    return True

                                if self.current_peers is not None:
                                    return True

                                if self.description is not None:
                                    return True

                                if self.discard_as4_path is not None:
                                    return True

                                if self.dmz_link_bandwidth is not None:
                                    return True

                                if self.ebgp_recv_dmz is not None:
                                    return True

                                if self.ebgp_send_dmz_mode is not None:
                                    return True

                                if self.ebgp_time_to_live is not None:
                                    return True

                                if self.egress_peer_engineering_enabled is not None:
                                    return True

                                if self.gr_restart_time is not None:
                                    return True

                                if self.gr_stale_path_time is not None:
                                    return True

                                if self.graceful_maintenance is not None and self.graceful_maintenance._has_data():
                                    return True

                                if self.graceful_restart_enabled_nbr is not None:
                                    return True

                                if self.has_internal_link is not None:
                                    return True

                                if self.idle_watch_time is not None:
                                    return True

                                if self.ignore_connected is not None:
                                    return True

                                if self.instance is not None:
                                    for child_ref in self.instance:
                                        if child_ref._has_data():
                                            return True

                                if self.internal_vpn_client is not None:
                                    return True

                                if self.is_administratively_shut_down is not None:
                                    return True

                                if self.is_capability_negotiation_performed is not None:
                                    return True

                                if self.is_ebgp_multihop_bgpmpls_forwarding_disabled is not None:
                                    return True

                                if self.is_local_address_configured is not None:
                                    return True

                                if self.is_neighbor_max_prefix_shutdown is not None:
                                    return True

                                if self.is_out_of_memory_forced_up is not None:
                                    return True

                                if self.is_passive_close is not None:
                                    return True

                                if self.islocal_address_cfg is not None:
                                    return True

                                if self.local_as is not None:
                                    return True

                                if self.local_as_dual_as is not None:
                                    return True

                                if self.local_as_dual_as_mode_native is not None:
                                    return True

                                if self.local_as_no_prepend is not None:
                                    return True

                                if self.local_as_replace_as is not None:
                                    return True

                                if self.max_peers is not None:
                                    return True

                                if self.min_advertise_interval is not None:
                                    return True

                                if self.min_advertise_interval_msecs is not None:
                                    return True

                                if self.min_origination_interval is not None:
                                    return True

                                if self.msg_buf_count is not None:
                                    return True

                                if self.msg_bug_circular is not None:
                                    return True

                                if self.msg_log_in is not None:
                                    return True

                                if self.msg_log_out is not None:
                                    return True

                                if self.nbr_cluster_id is not None:
                                    return True

                                if self.nbr_enforce_first_as is not None:
                                    return True

                                if self.nbr_in_cluster is not None:
                                    return True

                                if self.nbr_rcv_size is not None:
                                    return True

                                if self.nbr_send_size is not None:
                                    return True

                                if self.neighbor_local_as is not None:
                                    return True

                                if self.neighbor_range_prefix_length is not None:
                                    return True

                                if self.nsr_enabled is not None:
                                    return True

                                if self.oper_attrf_enable is not None:
                                    return True

                                if self.range_inst_error is not None:
                                    return True

                                if self.range_max_drop is not None:
                                    return True

                                if self.range_open_accepted is not None:
                                    return True

                                if self.range_open_match is not None:
                                    return True

                                if self.remote_as is not None:
                                    return True

                                if self.remote_as_list_name is not None:
                                    return True

                                if self.remote_as_number is not None:
                                    return True

                                if self.rpki_allow_invalid is not None:
                                    return True

                                if self.rpki_disable is not None:
                                    return True

                                if self.rpki_signal_ibgp is not None:
                                    return True

                                if self.rpki_use_validity is not None:
                                    return True

                                if self.speaker_id is not None:
                                    return True

                                if self.standby_rp is not None:
                                    return True

                                if self.suppress4_byte_as is not None:
                                    return True

                                if self.syslog_enable is not None:
                                    return True

                                if self.tcp_session_open_mode is not None:
                                    return True

                                if self.tcpmss is not None:
                                    return True

                                if self.tos_type is not None:
                                    return True

                                if self.tos_value is not None:
                                    return True

                                if self.ttl_security_enabled is not None:
                                    return True

                                if self.upd_errh_noreset is not None:
                                    return True

                                if self.update_source is not None:
                                    return True

                                if self.vrf_name is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-ranges'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.neighbor_range is not None:
                                for child_ref in self.neighbor_range:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges']['meta_info']


                    class MessageLogs(object):
                        """
                        The BGP Neighbor Message table
                        
                        .. attribute:: message_log
                        
                        	A BGP Message log entry
                        	**type**\: list of    :py:class:`MessageLog <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.message_log = YList()
                            self.message_log.parent = self
                            self.message_log.name = 'message_log'


                        class MessageLog(object):
                            """
                            A BGP Message log entry
                            
                            .. attribute:: direction
                            
                            	Direction
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: neighbor_address
                            
                            	Neighbor address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: neighbor_message
                            
                            	Array of Neighbor Messages in one direction
                            	**type**\: list of    :py:class:`NeighborMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog.NeighborMessage>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.direction = None
                                self.neighbor_address = None
                                self.neighbor_message = YList()
                                self.neighbor_message.parent = self
                                self.neighbor_message.name = 'neighbor_message'


                            class NeighborMessage(object):
                                """
                                Array of Neighbor Messages in one direction
                                
                                .. attribute:: logged_message_data
                                
                                	Raw Message data in binary format
                                	**type**\: list of    :py:class:`LoggedMessageData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData>`
                                
                                .. attribute:: message_data_length
                                
                                	Message data length
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: message_timestamp
                                
                                	message received time\: time elapsed since 00\:00 \:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`MessageTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp>`
                                
                                .. attribute:: message_type_received
                                
                                	Type of messages Received
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: total_logged_message_count
                                
                                	Total logged messages count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.logged_message_data = YList()
                                    self.logged_message_data.parent = self
                                    self.logged_message_data.name = 'logged_message_data'
                                    self.message_data_length = None
                                    self.message_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp()
                                    self.message_timestamp.parent = self
                                    self.message_type_received = None
                                    self.total_logged_message_count = None


                                class MessageTimestamp(object):
                                    """
                                    message received time\: time elapsed since 00\:00
                                    \:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:message-timestamp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp']['meta_info']


                                class LoggedMessageData(object):
                                    """
                                    Raw Message data in binary format
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:logged-message-data'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-message'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.logged_message_data is not None:
                                        for child_ref in self.logged_message_data:
                                            if child_ref._has_data():
                                                return True

                                    if self.message_data_length is not None:
                                        return True

                                    if self.message_timestamp is not None and self.message_timestamp._has_data():
                                        return True

                                    if self.message_type_received is not None:
                                        return True

                                    if self.total_logged_message_count is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog.NeighborMessage']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:message-log'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.direction is not None:
                                    return True

                                if self.neighbor_address is not None:
                                    return True

                                if self.neighbor_message is not None:
                                    for child_ref in self.neighbor_message:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:message-logs'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.message_log is not None:
                                for child_ref in self.message_log:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:default-vrf'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.afs is not None and self.afs._has_data():
                            return True

                        if self.bmp is not None and self.bmp._has_data():
                            return True

                        if self.global_process_info is not None and self.global_process_info._has_data():
                            return True

                        if self.information is not None and self.information._has_data():
                            return True

                        if self.message_logs is not None and self.message_logs._has_data():
                            return True

                        if self.neighbor_ranges is not None and self.neighbor_ranges._has_data():
                            return True

                        if self.neighbors is not None and self.neighbors._has_data():
                            return True

                        if self.next_hop_vrf is not None and self.next_hop_vrf._has_data():
                            return True

                        if self.postits is not None and self.postits._has_data():
                            return True

                        if self.process_info is not None and self.process_info._has_data():
                            return True

                        if self.sessions is not None and self.sessions._has_data():
                            return True

                        if self.update_inbound_error_neighbors is not None and self.update_inbound_error_neighbors._has_data():
                            return True

                        if self.update_inbound_error_vrf is not None and self.update_inbound_error_vrf._has_data():
                            return True

                        if self.update_inbound_filter_neighbors is not None and self.update_inbound_filter_neighbors._has_data():
                            return True

                        if self.update_inbound_filter_vrf is not None and self.update_inbound_filter_vrf._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.DefaultVrf']['meta_info']


                class UpdateInboundFilterProcess(object):
                    """
                    Update inbound filtering information for the
                    process
                    
                    .. attribute:: last_update_filtered_age
                    
                    	Time since last filtered messages received event (in seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: last_update_filtered_timestamp
                    
                    	Last filtered messages received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                    	**type**\:   :py:class:`LastUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.UpdateInboundFilterProcess.LastUpdateFilteredTimestamp>`
                    
                    .. attribute:: update_filtered_message_count
                    
                    	Filtered messages count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update_filtered_neighbor_count
                    
                    	Count of neighbors that received filtered messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2015-08-27'

                    def __init__(self):
                        self.parent = None
                        self.last_update_filtered_age = None
                        self.last_update_filtered_timestamp = Bgp.Instances.Instance.InstanceActive.UpdateInboundFilterProcess.LastUpdateFilteredTimestamp()
                        self.last_update_filtered_timestamp.parent = self
                        self.update_filtered_message_count = None
                        self.update_filtered_neighbor_count = None


                    class LastUpdateFilteredTimestamp(object):
                        """
                        Last filtered messages received time\: time
                        elapsed since 00\:00\:00 UTC, January 1, 1970
                        
                        .. attribute:: nanoseconds
                        
                        	Nanoseconds part of time value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: seconds
                        
                        	Seconds part of time value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.nanoseconds = None
                            self.seconds = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-filtered-timestamp'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.nanoseconds is not None:
                                return True

                            if self.seconds is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.UpdateInboundFilterProcess.LastUpdateFilteredTimestamp']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-inbound-filter-process'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.last_update_filtered_age is not None:
                            return True

                        if self.last_update_filtered_timestamp is not None and self.last_update_filtered_timestamp._has_data():
                            return True

                        if self.update_filtered_message_count is not None:
                            return True

                        if self.update_filtered_neighbor_count is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.UpdateInboundFilterProcess']['meta_info']


                class Attributes(object):
                    """
                    The BGP Attribute table
                    
                    .. attribute:: attribute
                    
                    	A BGP Attribute table entry
                    	**type**\: list of    :py:class:`Attribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2015-08-27'

                    def __init__(self):
                        self.parent = None
                        self.attribute = YList()
                        self.attribute.parent = self
                        self.attribute.name = 'attribute'


                    class Attribute(object):
                        """
                        A BGP Attribute table entry
                        
                        .. attribute:: attribute_cache_bucket
                        
                        	Attribute cache bucket
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: attribute_cache_id
                        
                        	Attribute cache ID
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: attribute_iid
                        
                        	Attribute IID
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: attribute_info
                        
                        	Attributes
                        	**type**\:   :py:class:`AttributeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo>`
                        
                        .. attribute:: attribute_instance_id
                        
                        	Attribute Instance ID
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: attribute_structure_hash_value
                        
                        	Hash value for attribute structure
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: attribute_structure_id
                        
                        	ID of attribute structure
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: process_instance_id
                        
                        	Process instance ID
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: reference_count
                        
                        	Number of paths which use this attribute structure
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.attribute_cache_bucket = None
                            self.attribute_cache_id = None
                            self.attribute_iid = None
                            self.attribute_info = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo()
                            self.attribute_info.parent = self
                            self.attribute_instance_id = None
                            self.attribute_structure_hash_value = None
                            self.attribute_structure_id = None
                            self.process_instance_id = None
                            self.reference_count = None


                        class AttributeInfo(object):
                            """
                            Attributes
                            
                            .. attribute:: attr_set
                            
                            	ATTR\_SET attribute
                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet>`
                            
                            .. attribute:: attribute_key_number
                            
                            	Attribute key number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_reuse_id_config
                            
                            	Attribute reuse ID Configured
                            	**type**\:  bool
                            
                            .. attribute:: attribute_reuse_id_current
                            
                            	Attribute reuse ID current ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_reuse_id_keys
                            
                            	Attribute reuse ID allocated keys
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_reuse_id_max_id
                            
                            	Attribute reuse ID maximum ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_reuse_id_node
                            
                            	Attribute reuse ID nodes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_reuse_id_recover_sec
                            
                            	Attribute reuse ID timer in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: common_attributes
                            
                            	Common attributes
                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes>`
                            
                            .. attribute:: is_application_gateway_present
                            
                            	Application gateway present
                            	**type**\:  bool
                            
                            .. attribute:: is_as_path2_byte
                            
                            	AS path encoded as 2\-byte
                            	**type**\:  bool
                            
                            .. attribute:: is_attr_set_present
                            
                            	BGP ATTR\_SET attribute present
                            	**type**\:  bool
                            
                            .. attribute:: is_ribrnh_present
                            
                            	RIB RNH Attribute  present
                            	**type**\:  bool
                            
                            .. attribute:: is_rnh_present
                            
                            	RNH Attribute  present
                            	**type**\:  bool
                            
                            .. attribute:: ribrnh_encap
                            
                            	RIB RNH Encapsulation Type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ribrnh_ip
                            
                            	RIB RNH IP Address
                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp>`
                            
                            .. attribute:: ribrnh_mac
                            
                            	RIB RNH MAC Address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: ribrnh_table
                            
                            	RIB RNH Table
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ribrnh_vni
                            
                            	RIB RNH Vni
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ribrnhip_table
                            
                            	RIB RNH IP Table
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rnh_addr
                            
                            	RNH Address
                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RnhAddr>`
                            
                            .. attribute:: rnh_addr_len
                            
                            	RNH Address Length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rnh_len
                            
                            	RNH Length
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: rnh_type
                            
                            	RNH Type
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: set_aigp_inbound_igp
                            
                            	AIGP set by policy inbound IGP 
                            	**type**\:  bool
                            
                            .. attribute:: set_aigp_inbound_metric
                            
                            	AIGP set by policy inbound metric
                            	**type**\:  bool
                            
                            .. attribute:: vpn_distinguisher
                            
                            	VPN Distinguisher
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.attr_set = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet()
                                self.attr_set.parent = self
                                self.attribute_key_number = None
                                self.attribute_reuse_id_config = None
                                self.attribute_reuse_id_current = None
                                self.attribute_reuse_id_keys = None
                                self.attribute_reuse_id_max_id = None
                                self.attribute_reuse_id_node = None
                                self.attribute_reuse_id_recover_sec = None
                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes()
                                self.common_attributes.parent = self
                                self.is_application_gateway_present = None
                                self.is_as_path2_byte = None
                                self.is_attr_set_present = None
                                self.is_ribrnh_present = None
                                self.is_rnh_present = None
                                self.ribrnh_encap = None
                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp()
                                self.ribrnh_ip.parent = self
                                self.ribrnh_mac = None
                                self.ribrnh_table = None
                                self.ribrnh_vni = None
                                self.ribrnhip_table = None
                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RnhAddr()
                                self.rnh_addr.parent = self
                                self.rnh_addr_len = None
                                self.rnh_len = None
                                self.rnh_type = None
                                self.set_aigp_inbound_igp = None
                                self.set_aigp_inbound_metric = None
                                self.vpn_distinguisher = None


                            class CommonAttributes(object):
                                """
                                Common attributes
                                
                                .. attribute:: aggregator_address
                                
                                	Address where aggregation was performed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: aggregator_as
                                
                                	AS where aggregation was last performed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: aigp_metric_value
                                
                                	AIGP metric value
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: as_path
                                
                                	AS path attribute
                                	**type**\:  str
                                
                                .. attribute:: cluster
                                
                                	Cluster list attribute
                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster>`
                                
                                .. attribute:: community
                                
                                	Community attribute
                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.Community>`
                                
                                .. attribute:: connector_type
                                
                                	Connector Type
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: connector_value
                                
                                	Connector Value
                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue>`
                                
                                .. attribute:: extended_community
                                
                                	Extended community attribute
                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity>`
                                
                                .. attribute:: extended_community_flags
                                
                                	Extended community Flags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: is_aggregator_present
                                
                                	Aggregator attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_aigp_present
                                
                                	AIGP Present
                                	**type**\:  bool
                                
                                .. attribute:: is_as_path_present
                                
                                	AS path attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_atomic_aggregate_present
                                
                                	Atomic aggregate attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_community_present
                                
                                	Community attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_connector_present
                                
                                	Connector present
                                	**type**\:  bool
                                
                                .. attribute:: is_extended_community_present
                                
                                	Extended community attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_label_index_present
                                
                                	Label Index attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_local_pref_present
                                
                                	Local Preference attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_ls_attribute_present
                                
                                	BGP LS attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_metric_present
                                
                                	Metric attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_origin_present
                                
                                	Origin attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_pe_distinguisher_label_present
                                
                                	PE distinguisher label  attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_pmsi_present
                                
                                	PMSI Attribute  present
                                	**type**\:  bool
                                
                                .. attribute:: is_pppmp_present
                                
                                	PPMP Attribute  present
                                	**type**\:  bool
                                
                                .. attribute:: is_ssa_present
                                
                                	SSA attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_tunnel_encap_present
                                
                                	Tunnel Encap attribute present 
                                	**type**\:  bool
                                
                                .. attribute:: l2tpv3_cookie
                                
                                	L2TPv3 Cookie
                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.L2Tpv3Cookie>`
                                
                                .. attribute:: l2tpv3_session_id
                                
                                	L2TPv3 session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_index_attr
                                
                                	Label Index attribute
                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.LabelIndexAttr>`
                                
                                .. attribute:: local_preference
                                
                                	Local preference
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ls_attr
                                
                                	BGP LS attribute
                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr>`
                                
                                .. attribute:: metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_as
                                
                                	Neighbor AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: origin
                                
                                	Origin
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: originator
                                
                                	Originator attribute
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pe_distinguisher_label
                                
                                	PE distinguisher label attribute
                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel>`
                                
                                .. attribute:: pmsi_flags
                                
                                	PMSI Value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: pmsi_label
                                
                                	PMSI label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pmsi_type
                                
                                	PMSI Type
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: pmsi_value
                                
                                	PMSI Value
                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue>`
                                
                                .. attribute:: ppm_pvalue
                                
                                	PPMP Value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sr_policy_allocated_binding_sid
                                
                                	SR Policy allocated Binding sid by the router
                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                
                                .. attribute:: sr_policy_binding_sid
                                
                                	SR Policy Binding sid
                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyBindingSid>`
                                
                                .. attribute:: sr_policy_explicit_path
                                
                                	SR Policy Explicit paths
                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyExplicitPath>`
                                
                                .. attribute:: sr_policy_preference
                                
                                	SR Policy Preference
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sr_tunnel_request_state
                                
                                	SR Tunnel Request State
                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                
                                .. attribute:: sr_tunnel_state
                                
                                	SR Tunnel State
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tunnel_encap_type
                                
                                	Tunnel Encap Type
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: unknown_attribute
                                
                                	Unknown attributes
                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.aggregator_address = None
                                    self.aggregator_as = None
                                    self.aigp_metric_value = None
                                    self.as_path = None
                                    self.cluster = YList()
                                    self.cluster.parent = self
                                    self.cluster.name = 'cluster'
                                    self.community = YList()
                                    self.community.parent = self
                                    self.community.name = 'community'
                                    self.connector_type = None
                                    self.connector_value = YList()
                                    self.connector_value.parent = self
                                    self.connector_value.name = 'connector_value'
                                    self.extended_community = YList()
                                    self.extended_community.parent = self
                                    self.extended_community.name = 'extended_community'
                                    self.extended_community_flags = None
                                    self.is_aggregator_present = None
                                    self.is_aigp_present = None
                                    self.is_as_path_present = None
                                    self.is_atomic_aggregate_present = None
                                    self.is_community_present = None
                                    self.is_connector_present = None
                                    self.is_extended_community_present = None
                                    self.is_label_index_present = None
                                    self.is_local_pref_present = None
                                    self.is_ls_attribute_present = None
                                    self.is_metric_present = None
                                    self.is_origin_present = None
                                    self.is_pe_distinguisher_label_present = None
                                    self.is_pmsi_present = None
                                    self.is_pppmp_present = None
                                    self.is_ssa_present = None
                                    self.is_tunnel_encap_present = None
                                    self.l2tpv3_cookie = YList()
                                    self.l2tpv3_cookie.parent = self
                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                    self.l2tpv3_session_id = None
                                    self.label_index_attr = YList()
                                    self.label_index_attr.parent = self
                                    self.label_index_attr.name = 'label_index_attr'
                                    self.local_preference = None
                                    self.ls_attr = YList()
                                    self.ls_attr.parent = self
                                    self.ls_attr.name = 'ls_attr'
                                    self.metric = None
                                    self.neighbor_as = None
                                    self.origin = None
                                    self.originator = None
                                    self.pe_distinguisher_label = YList()
                                    self.pe_distinguisher_label.parent = self
                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                    self.pmsi_flags = None
                                    self.pmsi_label = None
                                    self.pmsi_type = None
                                    self.pmsi_value = YList()
                                    self.pmsi_value.parent = self
                                    self.pmsi_value.name = 'pmsi_value'
                                    self.ppm_pvalue = None
                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyAllocatedBindingSid()
                                    self.sr_policy_allocated_binding_sid.parent = self
                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyBindingSid()
                                    self.sr_policy_binding_sid.parent = self
                                    self.sr_policy_explicit_path = YList()
                                    self.sr_policy_explicit_path.parent = self
                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                    self.sr_policy_preference = None
                                    self.sr_tunnel_request_state = None
                                    self.sr_tunnel_state = None
                                    self.tunnel_encap_type = None
                                    self.unknown_attribute = YList()
                                    self.unknown_attribute.parent = self
                                    self.unknown_attribute.name = 'unknown_attribute'


                                class SrPolicyBindingSid(object):
                                    """
                                    SR Policy Binding sid
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPv6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: label
                                    
                                    	MPLS Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv6_address = None
                                        self.label = None
                                        self.type = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv6_address is not None:
                                            return True

                                        if self.label is not None:
                                            return True

                                        if self.type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                class SrPolicyAllocatedBindingSid(object):
                                    """
                                    SR Policy allocated Binding sid by the router
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPv6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: label
                                    
                                    	MPLS Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv6_address = None
                                        self.label = None
                                        self.type = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv6_address is not None:
                                            return True

                                        if self.label is not None:
                                            return True

                                        if self.type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                class Community(object):
                                    """
                                    Community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.Community']['meta_info']


                                class ExtendedCommunity(object):
                                    """
                                    Extended community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity']['meta_info']


                                class UnknownAttribute(object):
                                    """
                                    Unknown attributes
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute']['meta_info']


                                class Cluster(object):
                                    """
                                    Cluster list attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster']['meta_info']


                                class L2Tpv3Cookie(object):
                                    """
                                    L2TPv3 Cookie
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                class ConnectorValue(object):
                                    """
                                    Connector Value
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue']['meta_info']


                                class PmsiValue(object):
                                    """
                                    PMSI Value
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue']['meta_info']


                                class LsAttr(object):
                                    """
                                    BGP LS attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr']['meta_info']


                                class LabelIndexAttr(object):
                                    """
                                    Label Index attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.LabelIndexAttr']['meta_info']


                                class PeDistinguisherLabel(object):
                                    """
                                    PE distinguisher label attribute
                                    
                                    .. attribute:: label
                                    
                                    	Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pe_address
                                    
                                    	 PE address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.label = None
                                        self.pe_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.label is not None:
                                            return True

                                        if self.pe_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                class SrPolicyExplicitPath(object):
                                    """
                                    SR Policy Explicit paths
                                    
                                    .. attribute:: sid
                                    
                                    	Sidlist for explicit path
                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                    
                                    .. attribute:: weight
                                    
                                    	Weight of explicit path
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.sid = YList()
                                        self.sid.parent = self
                                        self.sid.name = 'sid'
                                        self.weight = None


                                    class Sid(object):
                                        """
                                        Sidlist for explicit path
                                        
                                        .. attribute:: ipv4
                                        
                                        	IP Address sid
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address sid
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: label
                                        
                                        	MPLS Label sid
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: type
                                        
                                        	Sid Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self.label = None
                                            self.type = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4 is not None:
                                                return True

                                            if self.ipv6 is not None:
                                                return True

                                            if self.label is not None:
                                                return True

                                            if self.type is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.sid is not None:
                                            for child_ref in self.sid:
                                                if child_ref._has_data():
                                                    return True

                                        if self.weight is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.aggregator_address is not None:
                                        return True

                                    if self.aggregator_as is not None:
                                        return True

                                    if self.aigp_metric_value is not None:
                                        return True

                                    if self.as_path is not None:
                                        return True

                                    if self.cluster is not None:
                                        for child_ref in self.cluster:
                                            if child_ref._has_data():
                                                return True

                                    if self.community is not None:
                                        for child_ref in self.community:
                                            if child_ref._has_data():
                                                return True

                                    if self.connector_type is not None:
                                        return True

                                    if self.connector_value is not None:
                                        for child_ref in self.connector_value:
                                            if child_ref._has_data():
                                                return True

                                    if self.extended_community is not None:
                                        for child_ref in self.extended_community:
                                            if child_ref._has_data():
                                                return True

                                    if self.extended_community_flags is not None:
                                        return True

                                    if self.is_aggregator_present is not None:
                                        return True

                                    if self.is_aigp_present is not None:
                                        return True

                                    if self.is_as_path_present is not None:
                                        return True

                                    if self.is_atomic_aggregate_present is not None:
                                        return True

                                    if self.is_community_present is not None:
                                        return True

                                    if self.is_connector_present is not None:
                                        return True

                                    if self.is_extended_community_present is not None:
                                        return True

                                    if self.is_label_index_present is not None:
                                        return True

                                    if self.is_local_pref_present is not None:
                                        return True

                                    if self.is_ls_attribute_present is not None:
                                        return True

                                    if self.is_metric_present is not None:
                                        return True

                                    if self.is_origin_present is not None:
                                        return True

                                    if self.is_pe_distinguisher_label_present is not None:
                                        return True

                                    if self.is_pmsi_present is not None:
                                        return True

                                    if self.is_pppmp_present is not None:
                                        return True

                                    if self.is_ssa_present is not None:
                                        return True

                                    if self.is_tunnel_encap_present is not None:
                                        return True

                                    if self.l2tpv3_cookie is not None:
                                        for child_ref in self.l2tpv3_cookie:
                                            if child_ref._has_data():
                                                return True

                                    if self.l2tpv3_session_id is not None:
                                        return True

                                    if self.label_index_attr is not None:
                                        for child_ref in self.label_index_attr:
                                            if child_ref._has_data():
                                                return True

                                    if self.local_preference is not None:
                                        return True

                                    if self.ls_attr is not None:
                                        for child_ref in self.ls_attr:
                                            if child_ref._has_data():
                                                return True

                                    if self.metric is not None:
                                        return True

                                    if self.neighbor_as is not None:
                                        return True

                                    if self.origin is not None:
                                        return True

                                    if self.originator is not None:
                                        return True

                                    if self.pe_distinguisher_label is not None:
                                        for child_ref in self.pe_distinguisher_label:
                                            if child_ref._has_data():
                                                return True

                                    if self.pmsi_flags is not None:
                                        return True

                                    if self.pmsi_label is not None:
                                        return True

                                    if self.pmsi_type is not None:
                                        return True

                                    if self.pmsi_value is not None:
                                        for child_ref in self.pmsi_value:
                                            if child_ref._has_data():
                                                return True

                                    if self.ppm_pvalue is not None:
                                        return True

                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                        return True

                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                        return True

                                    if self.sr_policy_explicit_path is not None:
                                        for child_ref in self.sr_policy_explicit_path:
                                            if child_ref._has_data():
                                                return True

                                    if self.sr_policy_preference is not None:
                                        return True

                                    if self.sr_tunnel_request_state is not None:
                                        return True

                                    if self.sr_tunnel_state is not None:
                                        return True

                                    if self.tunnel_encap_type is not None:
                                        return True

                                    if self.unknown_attribute is not None:
                                        for child_ref in self.unknown_attribute:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes']['meta_info']


                            class AttrSet(object):
                                """
                                ATTR\_SET attribute
                                
                                .. attribute:: aggregator_address
                                
                                	Address where aggregation was performed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: aggregator_as
                                
                                	AS where aggregation was last performed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: aigp_metric_value
                                
                                	AIGP metric value
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: as_path
                                
                                	AS path attribute
                                	**type**\:  str
                                
                                .. attribute:: cluster
                                
                                	Cluster list attribute
                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.Cluster>`
                                
                                .. attribute:: community
                                
                                	Community attribute
                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.Community>`
                                
                                .. attribute:: connector_type
                                
                                	Connector Type
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: connector_value
                                
                                	Connector Value
                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue>`
                                
                                .. attribute:: extended_community
                                
                                	Extended community attribute
                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity>`
                                
                                .. attribute:: extended_community_flags
                                
                                	Extended community Flags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: is_aggregator_present
                                
                                	Aggregator attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_aigp_present
                                
                                	AIGP Present
                                	**type**\:  bool
                                
                                .. attribute:: is_as_path_present
                                
                                	AS path attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_atomic_aggregate_present
                                
                                	Atomic aggregate attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_community_present
                                
                                	Community attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_connector_present
                                
                                	Connector present
                                	**type**\:  bool
                                
                                .. attribute:: is_extended_community_present
                                
                                	Extended community attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_label_index_present
                                
                                	Label Index attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_local_pref_present
                                
                                	Local Preference attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_ls_attribute_present
                                
                                	BGP LS attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_metric_present
                                
                                	Metric attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_origin_present
                                
                                	Origin attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_pe_distinguisher_label_present
                                
                                	PE distinguisher label  attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_pmsi_present
                                
                                	PMSI Attribute  present
                                	**type**\:  bool
                                
                                .. attribute:: is_pppmp_present
                                
                                	PPMP Attribute  present
                                	**type**\:  bool
                                
                                .. attribute:: is_ssa_present
                                
                                	SSA attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_tunnel_encap_present
                                
                                	Tunnel Encap attribute present 
                                	**type**\:  bool
                                
                                .. attribute:: l2tpv3_cookie
                                
                                	L2TPv3 Cookie
                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.L2Tpv3Cookie>`
                                
                                .. attribute:: l2tpv3_session_id
                                
                                	L2TPv3 session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_index_attr
                                
                                	Label Index attribute
                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.LabelIndexAttr>`
                                
                                .. attribute:: local_preference
                                
                                	Local preference
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ls_attr
                                
                                	BGP LS attribute
                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr>`
                                
                                .. attribute:: metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_as
                                
                                	Neighbor AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: origin
                                
                                	Origin
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: originator
                                
                                	Originator attribute
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pe_distinguisher_label
                                
                                	PE distinguisher label attribute
                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel>`
                                
                                .. attribute:: pmsi_flags
                                
                                	PMSI Value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: pmsi_label
                                
                                	PMSI label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pmsi_type
                                
                                	PMSI Type
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: pmsi_value
                                
                                	PMSI Value
                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue>`
                                
                                .. attribute:: ppm_pvalue
                                
                                	PPMP Value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sr_policy_allocated_binding_sid
                                
                                	SR Policy allocated Binding sid by the router
                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyAllocatedBindingSid>`
                                
                                .. attribute:: sr_policy_binding_sid
                                
                                	SR Policy Binding sid
                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyBindingSid>`
                                
                                .. attribute:: sr_policy_explicit_path
                                
                                	SR Policy Explicit paths
                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyExplicitPath>`
                                
                                .. attribute:: sr_policy_preference
                                
                                	SR Policy Preference
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sr_tunnel_request_state
                                
                                	SR Tunnel Request State
                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                
                                .. attribute:: sr_tunnel_state
                                
                                	SR Tunnel State
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tunnel_encap_type
                                
                                	Tunnel Encap Type
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: unknown_attribute
                                
                                	Unknown attributes
                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.aggregator_address = None
                                    self.aggregator_as = None
                                    self.aigp_metric_value = None
                                    self.as_path = None
                                    self.cluster = YList()
                                    self.cluster.parent = self
                                    self.cluster.name = 'cluster'
                                    self.community = YList()
                                    self.community.parent = self
                                    self.community.name = 'community'
                                    self.connector_type = None
                                    self.connector_value = YList()
                                    self.connector_value.parent = self
                                    self.connector_value.name = 'connector_value'
                                    self.extended_community = YList()
                                    self.extended_community.parent = self
                                    self.extended_community.name = 'extended_community'
                                    self.extended_community_flags = None
                                    self.is_aggregator_present = None
                                    self.is_aigp_present = None
                                    self.is_as_path_present = None
                                    self.is_atomic_aggregate_present = None
                                    self.is_community_present = None
                                    self.is_connector_present = None
                                    self.is_extended_community_present = None
                                    self.is_label_index_present = None
                                    self.is_local_pref_present = None
                                    self.is_ls_attribute_present = None
                                    self.is_metric_present = None
                                    self.is_origin_present = None
                                    self.is_pe_distinguisher_label_present = None
                                    self.is_pmsi_present = None
                                    self.is_pppmp_present = None
                                    self.is_ssa_present = None
                                    self.is_tunnel_encap_present = None
                                    self.l2tpv3_cookie = YList()
                                    self.l2tpv3_cookie.parent = self
                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                    self.l2tpv3_session_id = None
                                    self.label_index_attr = YList()
                                    self.label_index_attr.parent = self
                                    self.label_index_attr.name = 'label_index_attr'
                                    self.local_preference = None
                                    self.ls_attr = YList()
                                    self.ls_attr.parent = self
                                    self.ls_attr.name = 'ls_attr'
                                    self.metric = None
                                    self.neighbor_as = None
                                    self.origin = None
                                    self.originator = None
                                    self.pe_distinguisher_label = YList()
                                    self.pe_distinguisher_label.parent = self
                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                    self.pmsi_flags = None
                                    self.pmsi_label = None
                                    self.pmsi_type = None
                                    self.pmsi_value = YList()
                                    self.pmsi_value.parent = self
                                    self.pmsi_value.name = 'pmsi_value'
                                    self.ppm_pvalue = None
                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyAllocatedBindingSid()
                                    self.sr_policy_allocated_binding_sid.parent = self
                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyBindingSid()
                                    self.sr_policy_binding_sid.parent = self
                                    self.sr_policy_explicit_path = YList()
                                    self.sr_policy_explicit_path.parent = self
                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                    self.sr_policy_preference = None
                                    self.sr_tunnel_request_state = None
                                    self.sr_tunnel_state = None
                                    self.tunnel_encap_type = None
                                    self.unknown_attribute = YList()
                                    self.unknown_attribute.parent = self
                                    self.unknown_attribute.name = 'unknown_attribute'


                                class SrPolicyBindingSid(object):
                                    """
                                    SR Policy Binding sid
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPv6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: label
                                    
                                    	MPLS Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv6_address = None
                                        self.label = None
                                        self.type = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv6_address is not None:
                                            return True

                                        if self.label is not None:
                                            return True

                                        if self.type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyBindingSid']['meta_info']


                                class SrPolicyAllocatedBindingSid(object):
                                    """
                                    SR Policy allocated Binding sid by the router
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPv6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: label
                                    
                                    	MPLS Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv6_address = None
                                        self.label = None
                                        self.type = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv6_address is not None:
                                            return True

                                        if self.label is not None:
                                            return True

                                        if self.type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                class Community(object):
                                    """
                                    Community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.Community']['meta_info']


                                class ExtendedCommunity(object):
                                    """
                                    Extended community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity']['meta_info']


                                class UnknownAttribute(object):
                                    """
                                    Unknown attributes
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute']['meta_info']


                                class Cluster(object):
                                    """
                                    Cluster list attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.Cluster']['meta_info']


                                class L2Tpv3Cookie(object):
                                    """
                                    L2TPv3 Cookie
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.L2Tpv3Cookie']['meta_info']


                                class ConnectorValue(object):
                                    """
                                    Connector Value
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue']['meta_info']


                                class PmsiValue(object):
                                    """
                                    PMSI Value
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue']['meta_info']


                                class LsAttr(object):
                                    """
                                    BGP LS attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr']['meta_info']


                                class LabelIndexAttr(object):
                                    """
                                    Label Index attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.LabelIndexAttr']['meta_info']


                                class PeDistinguisherLabel(object):
                                    """
                                    PE distinguisher label attribute
                                    
                                    .. attribute:: label
                                    
                                    	Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pe_address
                                    
                                    	 PE address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.label = None
                                        self.pe_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.label is not None:
                                            return True

                                        if self.pe_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel']['meta_info']


                                class SrPolicyExplicitPath(object):
                                    """
                                    SR Policy Explicit paths
                                    
                                    .. attribute:: sid
                                    
                                    	Sidlist for explicit path
                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyExplicitPath.Sid>`
                                    
                                    .. attribute:: weight
                                    
                                    	Weight of explicit path
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.sid = YList()
                                        self.sid.parent = self
                                        self.sid.name = 'sid'
                                        self.weight = None


                                    class Sid(object):
                                        """
                                        Sidlist for explicit path
                                        
                                        .. attribute:: ipv4
                                        
                                        	IP Address sid
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address sid
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: label
                                        
                                        	MPLS Label sid
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: type
                                        
                                        	Sid Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self.label = None
                                            self.type = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4 is not None:
                                                return True

                                            if self.ipv6 is not None:
                                                return True

                                            if self.label is not None:
                                                return True

                                            if self.type is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.sid is not None:
                                            for child_ref in self.sid:
                                                if child_ref._has_data():
                                                    return True

                                        if self.weight is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyExplicitPath']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.aggregator_address is not None:
                                        return True

                                    if self.aggregator_as is not None:
                                        return True

                                    if self.aigp_metric_value is not None:
                                        return True

                                    if self.as_path is not None:
                                        return True

                                    if self.cluster is not None:
                                        for child_ref in self.cluster:
                                            if child_ref._has_data():
                                                return True

                                    if self.community is not None:
                                        for child_ref in self.community:
                                            if child_ref._has_data():
                                                return True

                                    if self.connector_type is not None:
                                        return True

                                    if self.connector_value is not None:
                                        for child_ref in self.connector_value:
                                            if child_ref._has_data():
                                                return True

                                    if self.extended_community is not None:
                                        for child_ref in self.extended_community:
                                            if child_ref._has_data():
                                                return True

                                    if self.extended_community_flags is not None:
                                        return True

                                    if self.is_aggregator_present is not None:
                                        return True

                                    if self.is_aigp_present is not None:
                                        return True

                                    if self.is_as_path_present is not None:
                                        return True

                                    if self.is_atomic_aggregate_present is not None:
                                        return True

                                    if self.is_community_present is not None:
                                        return True

                                    if self.is_connector_present is not None:
                                        return True

                                    if self.is_extended_community_present is not None:
                                        return True

                                    if self.is_label_index_present is not None:
                                        return True

                                    if self.is_local_pref_present is not None:
                                        return True

                                    if self.is_ls_attribute_present is not None:
                                        return True

                                    if self.is_metric_present is not None:
                                        return True

                                    if self.is_origin_present is not None:
                                        return True

                                    if self.is_pe_distinguisher_label_present is not None:
                                        return True

                                    if self.is_pmsi_present is not None:
                                        return True

                                    if self.is_pppmp_present is not None:
                                        return True

                                    if self.is_ssa_present is not None:
                                        return True

                                    if self.is_tunnel_encap_present is not None:
                                        return True

                                    if self.l2tpv3_cookie is not None:
                                        for child_ref in self.l2tpv3_cookie:
                                            if child_ref._has_data():
                                                return True

                                    if self.l2tpv3_session_id is not None:
                                        return True

                                    if self.label_index_attr is not None:
                                        for child_ref in self.label_index_attr:
                                            if child_ref._has_data():
                                                return True

                                    if self.local_preference is not None:
                                        return True

                                    if self.ls_attr is not None:
                                        for child_ref in self.ls_attr:
                                            if child_ref._has_data():
                                                return True

                                    if self.metric is not None:
                                        return True

                                    if self.neighbor_as is not None:
                                        return True

                                    if self.origin is not None:
                                        return True

                                    if self.originator is not None:
                                        return True

                                    if self.pe_distinguisher_label is not None:
                                        for child_ref in self.pe_distinguisher_label:
                                            if child_ref._has_data():
                                                return True

                                    if self.pmsi_flags is not None:
                                        return True

                                    if self.pmsi_label is not None:
                                        return True

                                    if self.pmsi_type is not None:
                                        return True

                                    if self.pmsi_value is not None:
                                        for child_ref in self.pmsi_value:
                                            if child_ref._has_data():
                                                return True

                                    if self.ppm_pvalue is not None:
                                        return True

                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                        return True

                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                        return True

                                    if self.sr_policy_explicit_path is not None:
                                        for child_ref in self.sr_policy_explicit_path:
                                            if child_ref._has_data():
                                                return True

                                    if self.sr_policy_preference is not None:
                                        return True

                                    if self.sr_tunnel_request_state is not None:
                                        return True

                                    if self.sr_tunnel_state is not None:
                                        return True

                                    if self.tunnel_encap_type is not None:
                                        return True

                                    if self.unknown_attribute is not None:
                                        for child_ref in self.unknown_attribute:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet']['meta_info']


                            class RnhAddr(object):
                                """
                                RNH Address
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPv6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: len
                                
                                	len
                                	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                
                                .. attribute:: mac_address
                                
                                	MAC Addr
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self.len = None
                                    self.mac_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    if self.len is not None:
                                        return True

                                    if self.mac_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RnhAddr']['meta_info']


                            class RibrnhIp(object):
                                """
                                RIB RNH IP Address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpnvpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnvplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4mdt_address = None
                                    self.ipv4mvpn_address = None
                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress()
                                    self.ipv4sr_policy_address.parent = self
                                    self.ipv4vpn_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress()
                                    self.ipv6sr_policy_address.parent = self
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_flowspec_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.l2vpn_evpn_address = None
                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnvplsAddress()
                                    self.l2vpnvpls_address.parent = self
                                    self.ls_ls_address = None
                                    self.rt_constraint_address = None


                                class L2VpnvplsAddress(object):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                class L2VpnMspwAddress(object):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                class Ipv4SrPolicyAddress(object):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                class Ipv6SrPolicyAddress(object):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv6_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv6_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.afi is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv4_flowspec_address is not None:
                                        return True

                                    if self.ipv4_label_address is not None:
                                        return True

                                    if self.ipv4_mcast_address is not None:
                                        return True

                                    if self.ipv4_tunnel_address is not None:
                                        return True

                                    if self.ipv4mdt_address is not None:
                                        return True

                                    if self.ipv4mvpn_address is not None:
                                        return True

                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                        return True

                                    if self.ipv4vpn_address is not None:
                                        return True

                                    if self.ipv4vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv4vpna_mcastddress is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    if self.ipv6_flowspec_address is not None:
                                        return True

                                    if self.ipv6_label_address is not None:
                                        return True

                                    if self.ipv6_mcast_address is not None:
                                        return True

                                    if self.ipv6mvpn_address is not None:
                                        return True

                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                        return True

                                    if self.ipv6vpn_address is not None:
                                        return True

                                    if self.ipv6vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv6vpn_mcast_address is not None:
                                        return True

                                    if self.l2vpn_evpn_address is not None:
                                        return True

                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                        return True

                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                        return True

                                    if self.ls_ls_address is not None:
                                        return True

                                    if self.rt_constraint_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attribute-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.attr_set is not None and self.attr_set._has_data():
                                    return True

                                if self.attribute_key_number is not None:
                                    return True

                                if self.attribute_reuse_id_config is not None:
                                    return True

                                if self.attribute_reuse_id_current is not None:
                                    return True

                                if self.attribute_reuse_id_keys is not None:
                                    return True

                                if self.attribute_reuse_id_max_id is not None:
                                    return True

                                if self.attribute_reuse_id_node is not None:
                                    return True

                                if self.attribute_reuse_id_recover_sec is not None:
                                    return True

                                if self.common_attributes is not None and self.common_attributes._has_data():
                                    return True

                                if self.is_application_gateway_present is not None:
                                    return True

                                if self.is_as_path2_byte is not None:
                                    return True

                                if self.is_attr_set_present is not None:
                                    return True

                                if self.is_ribrnh_present is not None:
                                    return True

                                if self.is_rnh_present is not None:
                                    return True

                                if self.ribrnh_encap is not None:
                                    return True

                                if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                    return True

                                if self.ribrnh_mac is not None:
                                    return True

                                if self.ribrnh_table is not None:
                                    return True

                                if self.ribrnh_vni is not None:
                                    return True

                                if self.ribrnhip_table is not None:
                                    return True

                                if self.rnh_addr is not None and self.rnh_addr._has_data():
                                    return True

                                if self.rnh_addr_len is not None:
                                    return True

                                if self.rnh_len is not None:
                                    return True

                                if self.rnh_type is not None:
                                    return True

                                if self.set_aigp_inbound_igp is not None:
                                    return True

                                if self.set_aigp_inbound_metric is not None:
                                    return True

                                if self.vpn_distinguisher is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attribute'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.attribute_cache_bucket is not None:
                                return True

                            if self.attribute_cache_id is not None:
                                return True

                            if self.attribute_iid is not None:
                                return True

                            if self.attribute_info is not None and self.attribute_info._has_data():
                                return True

                            if self.attribute_instance_id is not None:
                                return True

                            if self.attribute_structure_hash_value is not None:
                                return True

                            if self.attribute_structure_id is not None:
                                return True

                            if self.process_instance_id is not None:
                                return True

                            if self.reference_count is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes.Attribute']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.attribute is not None:
                            for child_ref in self.attribute:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.Attributes']['meta_info']


                class RtEntries(object):
                    """
                    BGP Route Target Sets Table
                    
                    .. attribute:: rt_entry
                    
                    	BGP Route Target Set Entry
                    	**type**\: list of    :py:class:`RtEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.RtEntries.RtEntry>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2015-08-27'

                    def __init__(self):
                        self.parent = None
                        self.rt_entry = YList()
                        self.rt_entry.parent = self
                        self.rt_entry.name = 'rt_entry'


                    class RtEntry(object):
                        """
                        BGP Route Target Set Entry
                        
                        .. attribute:: af_name
                        
                        	Address family
                        	**type**\:   :py:class:`BgpAddressFamilyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamilyEnum>`
                        
                        .. attribute:: afs
                        
                        	afs
                        	**type**\:  str
                        
                        .. attribute:: request_id
                        
                        	Random Request ID
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: route_target_lower_bytes
                        
                        	Lower 4 bytes of RT
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: route_target_upper_bytes
                        
                        	Upper 4 bytes of RT
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: rt
                        
                        	rt
                        	**type**\:   :py:class:`Rt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.RtEntries.RtEntry.Rt>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.afs = None
                            self.request_id = None
                            self.route_target_lower_bytes = None
                            self.route_target_upper_bytes = None
                            self.rt = Bgp.Instances.Instance.InstanceActive.RtEntries.RtEntry.Rt()
                            self.rt.parent = self


                        class Rt(object):
                            """
                            rt
                            
                            .. attribute:: route_target
                            
                            	route target
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.route_target = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rt'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.route_target is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.RtEntries.RtEntry.Rt']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rt-entry'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.afs is not None:
                                return True

                            if self.request_id is not None:
                                return True

                            if self.route_target_lower_bytes is not None:
                                return True

                            if self.route_target_upper_bytes is not None:
                                return True

                            if self.rt is not None and self.rt._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.RtEntries.RtEntry']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rt-entries'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.rt_entry is not None:
                            for child_ref in self.rt_entry:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.RtEntries']['meta_info']


                class AttributeFilterGroups(object):
                    """
                    All attribute\-filter groups in this instance
                    
                    .. attribute:: attribute_filter_group
                    
                    	Attribute\-filter group
                    	**type**\: list of    :py:class:`AttributeFilterGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.AttributeFilterGroups.AttributeFilterGroup>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2015-08-27'

                    def __init__(self):
                        self.parent = None
                        self.attribute_filter_group = YList()
                        self.attribute_filter_group.parent = self
                        self.attribute_filter_group.name = 'attribute_filter_group'


                    class AttributeFilterGroup(object):
                        """
                        Attribute\-filter group
                        
                        .. attribute:: group_name  <key>
                        
                        	Attribute\-filter group name
                        	**type**\:  str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: attribute_filter_entry
                        
                        	List of attriute\-filter entries
                        	**type**\: list of    :py:class:`AttributeFilterEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.AttributeFilterGroups.AttributeFilterGroup.AttributeFilterEntry>`
                        
                        .. attribute:: attribute_filter_group_name
                        
                        	Attribute\-filter group name
                        	**type**\:  str
                        
                        .. attribute:: attribute_filter_total_group_count
                        
                        	Total number of attriute\-filter groups
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.group_name = None
                            self.attribute_filter_entry = YList()
                            self.attribute_filter_entry.parent = self
                            self.attribute_filter_entry.name = 'attribute_filter_entry'
                            self.attribute_filter_group_name = None
                            self.attribute_filter_total_group_count = None


                        class AttributeFilterEntry(object):
                            """
                            List of attriute\-filter entries
                            
                            .. attribute:: attribute_filter_entry_range_end
                            
                            	End of attribute range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_filter_entry_range_start
                            
                            	Start of attribute range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_filter_entry_requested_action
                            
                            	Requested filtering action
                            	**type**\:   :py:class:`BgpBagUpdFilterActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterActionEnum>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.attribute_filter_entry_range_end = None
                                self.attribute_filter_entry_range_start = None
                                self.attribute_filter_entry_requested_action = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attribute-filter-entry'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.attribute_filter_entry_range_end is not None:
                                    return True

                                if self.attribute_filter_entry_range_start is not None:
                                    return True

                                if self.attribute_filter_entry_requested_action is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.AttributeFilterGroups.AttributeFilterGroup.AttributeFilterEntry']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.group_name is None:
                                raise YPYModelError('Key property group_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attribute-filter-group[Cisco-IOS-XR-ipv4-bgp-oper:group-name = ' + str(self.group_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.group_name is not None:
                                return True

                            if self.attribute_filter_entry is not None:
                                for child_ref in self.attribute_filter_entry:
                                    if child_ref._has_data():
                                        return True

                            if self.attribute_filter_group_name is not None:
                                return True

                            if self.attribute_filter_total_group_count is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.AttributeFilterGroups.AttributeFilterGroup']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attribute-filter-groups'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.attribute_filter_group is not None:
                            for child_ref in self.attribute_filter_group:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.AttributeFilterGroups']['meta_info']


                class RpkiServerList(object):
                    """
                    RPKI Server Table
                    
                    .. attribute:: rpki_server
                    
                    	Array of RPKI servers
                    	**type**\: list of    :py:class:`RpkiServer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.RpkiServerList.RpkiServer>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2015-08-27'

                    def __init__(self):
                        self.parent = None
                        self.rpki_server = YList()
                        self.rpki_server.parent = self
                        self.rpki_server.name = 'rpki_server'


                    class RpkiServer(object):
                        """
                        Array of RPKI servers
                        
                        .. attribute:: close_reason
                        
                        	Server close reason
                        	**type**\:   :py:class:`BgpRpkiCreasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiCreasonEnum>`
                        
                        .. attribute:: close_time
                        
                        	Server close elapsed time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: close_time_real
                        
                        	Server close real timestamp (unix time)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv4roa
                        
                        	Total IPv4 ROAs currently recv'd from server
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv4roa_announce
                        
                        	Total IPv4 ROAs announced by the server
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv4roa_withdraw
                        
                        	Total IPv4 ROAs withdrawn by the server
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv6roa
                        
                        	Total IPv6 ROAs currently recv'd from server
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv6roa_announce
                        
                        	Total IPv6 ROAs announced by the server
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv6roa_withdraw
                        
                        	Total IPv6 ROAs withdrawn by the server
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	Server Name
                        	**type**\:  str
                        
                        .. attribute:: nonce
                        
                        	Server nonce
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: password
                        
                        	Server SSH password
                        	**type**\:  str
                        
                        .. attribute:: port
                        
                        	Server TCP Port number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: preference
                        
                        	Server Preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proto_error
                        
                        	Protocol Error Reason
                        	**type**\:   :py:class:`BgpRpkiPerrorEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiPerrorEnum>`
                        
                        .. attribute:: proto_state
                        
                        	Server Protocol state
                        	**type**\:   :py:class:`BgpRpkiPstateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiPstateEnum>`
                        
                        .. attribute:: proto_state_time
                        
                        	Server Protocol state timestamp (unix time)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: purge_time
                        
                        	Server purge time (seconds)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: read_bytes
                        
                        	Number of bytes read from the server
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: refresh_time
                        
                        	Server refresh time (seconds)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: response_time
                        
                        	Server response time (seconds)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: retries
                        
                        	Number of connection retries
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: serial
                        
                        	Server serial number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: shutdown
                        
                        	Server Shutdown
                        	**type**\:  bool
                        
                        .. attribute:: sshpid
                        
                        	Server SSH process ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Server Internal State
                        	**type**\:   :py:class:`BgpRpkiStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiStateEnum>`
                        
                        .. attribute:: state_time
                        
                        	Server Internal State timestamp (unix time)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: transport
                        
                        	Server transport type
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: username
                        
                        	Server SSH username
                        	**type**\:  str
                        
                        .. attribute:: write_bytes
                        
                        	Number of bytes written to the server
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.close_reason = None
                            self.close_time = None
                            self.close_time_real = None
                            self.ipv4roa = None
                            self.ipv4roa_announce = None
                            self.ipv4roa_withdraw = None
                            self.ipv6roa = None
                            self.ipv6roa_announce = None
                            self.ipv6roa_withdraw = None
                            self.name = None
                            self.nonce = None
                            self.password = None
                            self.port = None
                            self.preference = None
                            self.proto_error = None
                            self.proto_state = None
                            self.proto_state_time = None
                            self.purge_time = None
                            self.read_bytes = None
                            self.refresh_time = None
                            self.response_time = None
                            self.retries = None
                            self.serial = None
                            self.shutdown = None
                            self.sshpid = None
                            self.state = None
                            self.state_time = None
                            self.transport = None
                            self.username = None
                            self.write_bytes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rpki-server'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.close_reason is not None:
                                return True

                            if self.close_time is not None:
                                return True

                            if self.close_time_real is not None:
                                return True

                            if self.ipv4roa is not None:
                                return True

                            if self.ipv4roa_announce is not None:
                                return True

                            if self.ipv4roa_withdraw is not None:
                                return True

                            if self.ipv6roa is not None:
                                return True

                            if self.ipv6roa_announce is not None:
                                return True

                            if self.ipv6roa_withdraw is not None:
                                return True

                            if self.name is not None:
                                return True

                            if self.nonce is not None:
                                return True

                            if self.password is not None:
                                return True

                            if self.port is not None:
                                return True

                            if self.preference is not None:
                                return True

                            if self.proto_error is not None:
                                return True

                            if self.proto_state is not None:
                                return True

                            if self.proto_state_time is not None:
                                return True

                            if self.purge_time is not None:
                                return True

                            if self.read_bytes is not None:
                                return True

                            if self.refresh_time is not None:
                                return True

                            if self.response_time is not None:
                                return True

                            if self.retries is not None:
                                return True

                            if self.serial is not None:
                                return True

                            if self.shutdown is not None:
                                return True

                            if self.sshpid is not None:
                                return True

                            if self.state is not None:
                                return True

                            if self.state_time is not None:
                                return True

                            if self.transport is not None:
                                return True

                            if self.username is not None:
                                return True

                            if self.write_bytes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.RpkiServerList.RpkiServer']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rpki-server-list'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.rpki_server is not None:
                            for child_ref in self.rpki_server:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.RpkiServerList']['meta_info']


                class RpkiRoutes(object):
                    """
                    BGP RPKI ROA table
                    
                    .. attribute:: rpki_route
                    
                    	RPKI Path Group
                    	**type**\: list of    :py:class:`RpkiRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.RpkiRoutes.RpkiRoute>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2015-08-27'

                    def __init__(self):
                        self.parent = None
                        self.rpki_route = YList()
                        self.rpki_route.parent = self
                        self.rpki_route.name = 'rpki_route'


                    class RpkiRoute(object):
                        """
                        RPKI Path Group
                        
                        .. attribute:: address
                        
                        	Route Address (IPv4 / IPv6)
                        	**type**\:  str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: af_name
                        
                        	Address family
                        	**type**\:   :py:class:`BgpRpkiEdmAfEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiEdmAfEnum>`
                        
                        .. attribute:: maximum
                        
                        	Maximum Prefix Length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: minimum
                        
                        	Minimum Prefix Length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: rpki_route
                        
                        	Array or RPKI routes
                        	**type**\: list of    :py:class:`RpkiRoute_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.RpkiRoutes.RpkiRoute.RpkiRoute_>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.address = None
                            self.af_name = None
                            self.maximum = None
                            self.minimum = None
                            self.rpki_route = YList()
                            self.rpki_route.parent = self
                            self.rpki_route.name = 'rpki_route'


                        class RpkiRoute_(object):
                            """
                            Array or RPKI routes
                            
                            .. attribute:: address
                            
                            	Address Prefix
                            	**type**\:  str
                            
                            .. attribute:: af_name
                            
                            	Address Family
                            	**type**\:   :py:class:`BgpRpkiAfEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiAfEnum>`
                            
                            .. attribute:: as_
                            
                            	AS number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_prefix_len
                            
                            	Maximum Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: min_prefix_len
                            
                            	Minimum Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: refcount
                            
                            	Refcount
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: server
                            
                            	Source Server
                            	**type**\:  str
                            
                            .. attribute:: stale
                            
                            	ROA is stale
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.address = None
                                self.af_name = None
                                self.as_ = None
                                self.max_prefix_len = None
                                self.min_prefix_len = None
                                self.refcount = None
                                self.server = None
                                self.stale = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rpki-route'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.address is not None:
                                    return True

                                if self.af_name is not None:
                                    return True

                                if self.as_ is not None:
                                    return True

                                if self.max_prefix_len is not None:
                                    return True

                                if self.min_prefix_len is not None:
                                    return True

                                if self.refcount is not None:
                                    return True

                                if self.server is not None:
                                    return True

                                if self.stale is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceActive.RpkiRoutes.RpkiRoute.RpkiRoute_']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rpki-route'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.address is not None:
                                return True

                            if self.af_name is not None:
                                return True

                            if self.maximum is not None:
                                return True

                            if self.minimum is not None:
                                return True

                            if self.rpki_route is not None:
                                for child_ref in self.rpki_route:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.RpkiRoutes.RpkiRoute']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rpki-routes'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.rpki_route is not None:
                            for child_ref in self.rpki_route:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.RpkiRoutes']['meta_info']


                class UpdateInboundErrorProcess(object):
                    """
                    Update inbound error information for the process
                    
                    .. attribute:: last_update_malformed_age
                    
                    	Time since last malformed messages received event (in seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: last_update_malformed_timestamp
                    
                    	Last malformed messages received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                    	**type**\:   :py:class:`LastUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.UpdateInboundErrorProcess.LastUpdateMalformedTimestamp>`
                    
                    .. attribute:: update_error_handling_basic_ebgp
                    
                    	Is basic error\-handling for EBGP enabled
                    	**type**\:  bool
                    
                    .. attribute:: update_error_handling_basic_ibgp
                    
                    	Is basic error\-handling for IBGP enabled
                    	**type**\:  bool
                    
                    .. attribute:: update_error_handling_extended_ebgp
                    
                    	Is extended error\-handling for EBGP enabled
                    	**type**\:  bool
                    
                    .. attribute:: update_error_handling_extended_ibgp
                    
                    	Is extended error\-handling for IBGP enabled
                    	**type**\:  bool
                    
                    .. attribute:: update_malformed_message_count
                    
                    	Malformed messages count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update_malformed_neighbor_count
                    
                    	Count of neighbors that received malformed messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2015-08-27'

                    def __init__(self):
                        self.parent = None
                        self.last_update_malformed_age = None
                        self.last_update_malformed_timestamp = Bgp.Instances.Instance.InstanceActive.UpdateInboundErrorProcess.LastUpdateMalformedTimestamp()
                        self.last_update_malformed_timestamp.parent = self
                        self.update_error_handling_basic_ebgp = None
                        self.update_error_handling_basic_ibgp = None
                        self.update_error_handling_extended_ebgp = None
                        self.update_error_handling_extended_ibgp = None
                        self.update_malformed_message_count = None
                        self.update_malformed_neighbor_count = None


                    class LastUpdateMalformedTimestamp(object):
                        """
                        Last malformed messages received time\: time
                        elapsed since 00\:00\:00 UTC, January 1, 1970
                        
                        .. attribute:: nanoseconds
                        
                        	Nanoseconds part of time value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: seconds
                        
                        	Seconds part of time value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.nanoseconds = None
                            self.seconds = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-malformed-timestamp'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.nanoseconds is not None:
                                return True

                            if self.seconds is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceActive.UpdateInboundErrorProcess.LastUpdateMalformedTimestamp']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-inbound-error-process'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.last_update_malformed_age is not None:
                            return True

                        if self.last_update_malformed_timestamp is not None and self.last_update_malformed_timestamp._has_data():
                            return True

                        if self.update_error_handling_basic_ebgp is not None:
                            return True

                        if self.update_error_handling_basic_ibgp is not None:
                            return True

                        if self.update_error_handling_extended_ebgp is not None:
                            return True

                        if self.update_error_handling_extended_ibgp is not None:
                            return True

                        if self.update_malformed_message_count is not None:
                            return True

                        if self.update_malformed_neighbor_count is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.UpdateInboundErrorProcess']['meta_info']


                class RpkiSummary(object):
                    """
                    RPKI Summary Info
                    
                    .. attribute:: ipv4roa_nets
                    
                    	Number of IPv4 ROA Nets
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ipv4roa_paths
                    
                    	Number of IPv4 ROA Paths
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ipv6roa_nets
                    
                    	Number of IPv6 ROA Nets
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ipv6roa_paths
                    
                    	Number of IPv6 ROA Paths
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpki_allow_invalid
                    
                    	Allow invalid paths
                    	**type**\:  bool
                    
                    .. attribute:: rpki_disabled
                    
                    	RPKI Knob disabled
                    	**type**\:  bool
                    
                    .. attribute:: rpki_signal_ibgp
                    
                    	Signal RPKI validity to iBGP peers
                    	**type**\:  bool
                    
                    .. attribute:: rpki_use_validity
                    
                    	Use RPKI validity for bestpath calculation
                    	**type**\:  bool
                    
                    .. attribute:: servers
                    
                    	Number of RPKI Servers configured
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2015-08-27'

                    def __init__(self):
                        self.parent = None
                        self.ipv4roa_nets = None
                        self.ipv4roa_paths = None
                        self.ipv6roa_nets = None
                        self.ipv6roa_paths = None
                        self.rpki_allow_invalid = None
                        self.rpki_disabled = None
                        self.rpki_signal_ibgp = None
                        self.rpki_use_validity = None
                        self.servers = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rpki-summary'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ipv4roa_nets is not None:
                            return True

                        if self.ipv4roa_paths is not None:
                            return True

                        if self.ipv6roa_nets is not None:
                            return True

                        if self.ipv6roa_paths is not None:
                            return True

                        if self.rpki_allow_invalid is not None:
                            return True

                        if self.rpki_disabled is not None:
                            return True

                        if self.rpki_signal_ibgp is not None:
                            return True

                        if self.rpki_use_validity is not None:
                            return True

                        if self.servers is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                        return meta._meta_table['Bgp.Instances.Instance.InstanceActive.RpkiSummary']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:instance-active'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.attribute_filter_groups is not None and self.attribute_filter_groups._has_data():
                        return True

                    if self.attributes is not None and self.attributes._has_data():
                        return True

                    if self.default_vrf is not None and self.default_vrf._has_data():
                        return True

                    if self.label_entries is not None and self.label_entries._has_data():
                        return True

                    if self.label_rpf_entries is not None and self.label_rpf_entries._has_data():
                        return True

                    if self.label_summary is not None and self.label_summary._has_data():
                        return True

                    if self.rpki_refresh_afs is not None and self.rpki_refresh_afs._has_data():
                        return True

                    if self.rpki_routes is not None and self.rpki_routes._has_data():
                        return True

                    if self.rpki_server_list is not None and self.rpki_server_list._has_data():
                        return True

                    if self.rpki_summary is not None and self.rpki_summary._has_data():
                        return True

                    if self.rt_entries is not None and self.rt_entries._has_data():
                        return True

                    if self.update_generation_process is not None and self.update_generation_process._has_data():
                        return True

                    if self.update_inbound_error_process is not None and self.update_inbound_error_process._has_data():
                        return True

                    if self.update_inbound_filter_process is not None and self.update_inbound_filter_process._has_data():
                        return True

                    if self.vrfs is not None and self.vrfs._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                    return meta._meta_table['Bgp.Instances.Instance.InstanceActive']['meta_info']


            class InstanceStandby(object):
                """
                Standby BGP operational data
                
                .. attribute:: attribute_filter_groups
                
                	All attribute\-filter groups in this instance
                	**type**\:   :py:class:`AttributeFilterGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.AttributeFilterGroups>`
                
                .. attribute:: attributes
                
                	The BGP Attribute table
                	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes>`
                
                .. attribute:: default_vrf
                
                	Default VRF related operational data
                	**type**\:   :py:class:`DefaultVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf>`
                
                .. attribute:: rpki_refresh_afs
                
                	RPKI Refresh Table (per AF)
                	**type**\:   :py:class:`RpkiRefreshAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.RpkiRefreshAfs>`
                
                .. attribute:: rpki_routes
                
                	BGP RPKI ROA table
                	**type**\:   :py:class:`RpkiRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.RpkiRoutes>`
                
                .. attribute:: rpki_server_list
                
                	RPKI Server Table
                	**type**\:   :py:class:`RpkiServerList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.RpkiServerList>`
                
                .. attribute:: rpki_summary
                
                	RPKI Summary Info
                	**type**\:   :py:class:`RpkiSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.RpkiSummary>`
                
                .. attribute:: rt_entries
                
                	BGP Route Target Sets Table
                	**type**\:   :py:class:`RtEntries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.RtEntries>`
                
                .. attribute:: update_generation_process
                
                	Update generation for the process
                	**type**\:   :py:class:`UpdateGenerationProcess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess>`
                
                .. attribute:: update_inbound_error_process
                
                	Update inbound error information for the process
                	**type**\:   :py:class:`UpdateInboundErrorProcess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.UpdateInboundErrorProcess>`
                
                .. attribute:: update_inbound_filter_process
                
                	Update inbound filtering information for the process
                	**type**\:   :py:class:`UpdateInboundFilterProcess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.UpdateInboundFilterProcess>`
                
                .. attribute:: vrfs
                
                	VRF related operational data
                	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs>`
                
                

                """

                _prefix = 'ipv4-bgp-oper'
                _revision = '2015-08-27'

                def __init__(self):
                    self.parent = None
                    self.attribute_filter_groups = Bgp.Instances.Instance.InstanceStandby.AttributeFilterGroups()
                    self.attribute_filter_groups.parent = self
                    self.attributes = Bgp.Instances.Instance.InstanceStandby.Attributes()
                    self.attributes.parent = self
                    self.default_vrf = Bgp.Instances.Instance.InstanceStandby.DefaultVrf()
                    self.default_vrf.parent = self
                    self.rpki_refresh_afs = Bgp.Instances.Instance.InstanceStandby.RpkiRefreshAfs()
                    self.rpki_refresh_afs.parent = self
                    self.rpki_routes = Bgp.Instances.Instance.InstanceStandby.RpkiRoutes()
                    self.rpki_routes.parent = self
                    self.rpki_server_list = Bgp.Instances.Instance.InstanceStandby.RpkiServerList()
                    self.rpki_server_list.parent = self
                    self.rpki_summary = Bgp.Instances.Instance.InstanceStandby.RpkiSummary()
                    self.rpki_summary.parent = self
                    self.rt_entries = Bgp.Instances.Instance.InstanceStandby.RtEntries()
                    self.rt_entries.parent = self
                    self.update_generation_process = Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess()
                    self.update_generation_process.parent = self
                    self.update_inbound_error_process = Bgp.Instances.Instance.InstanceStandby.UpdateInboundErrorProcess()
                    self.update_inbound_error_process.parent = self
                    self.update_inbound_filter_process = Bgp.Instances.Instance.InstanceStandby.UpdateInboundFilterProcess()
                    self.update_inbound_filter_process.parent = self
                    self.vrfs = Bgp.Instances.Instance.InstanceStandby.Vrfs()
                    self.vrfs.parent = self


                class UpdateGenerationProcess(object):
                    """
                    Update generation for the process
                    
                    .. attribute:: configured_update_limit_process
                    
                    	Configured Process update limit
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: current_update_limit_process
                    
                    	Current Process update limit
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update_address_family
                    
                    	List of address\-families
                    	**type**\: list of    :py:class:`UpdateAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateAddressFamily>`
                    
                    .. attribute:: update_out_logging
                    
                    	Enable syslog messages for update generation events
                    	**type**\:  bool
                    
                    .. attribute:: update_out_queue_messages
                    
                    	OutQueue messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update_out_queue_size
                    
                    	OutQueue size
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update_statistics
                    
                    	Update statistics
                    	**type**\:   :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics>`
                    
                    .. attribute:: update_throttled
                    
                    	Is update throttled
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2015-08-27'

                    def __init__(self):
                        self.parent = None
                        self.configured_update_limit_process = None
                        self.current_update_limit_process = None
                        self.update_address_family = YList()
                        self.update_address_family.parent = self
                        self.update_address_family.name = 'update_address_family'
                        self.update_out_logging = None
                        self.update_out_queue_messages = None
                        self.update_out_queue_size = None
                        self.update_statistics = Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics()
                        self.update_statistics.parent = self
                        self.update_throttled = None


                    class UpdateStatistics(object):
                        """
                        Update statistics
                        
                        .. attribute:: last_update_cleard_age
                        
                        	Time since last Clear event (in seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: last_update_cleared_timestamp
                        
                        	Last Cleared time
                        	**type**\:   :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateClearedTimestamp>`
                        
                        .. attribute:: last_update_discard_age
                        
                        	Time since last Discard event (in seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: last_update_discard_timestamp
                        
                        	Last Discarded time
                        	**type**\:   :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateDiscardTimestamp>`
                        
                        .. attribute:: last_update_memory_allocation_fail_age
                        
                        	Time since last memory allocation failure event (in seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: last_update_memory_allocation_fail_timestamp
                        
                        	Memory allocation failure time
                        	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                        
                        .. attribute:: last_update_recovery_age
                        
                        	Time since last Recovery event (in seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: last_update_recovery_timestamp
                        
                        	Last Recovery time
                        	**type**\:   :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                        
                        .. attribute:: last_update_throttle_age
                        
                        	Time since last Throttle event (in seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: last_update_throttle_timestamp
                        
                        	Last Throttled time
                        	**type**\:   :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateThrottleTimestamp>`
                        
                        .. attribute:: update_memory_allocation_fail_count
                        
                        	Memory allocation failure count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_messages_cleared
                        
                        	OutQueue Cleared Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_messages_cumulative
                        
                        	OutQueue Cumulative Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_messages_discarded
                        
                        	OutQueue Discarded Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_messages_high
                        
                        	OutQueue High Messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_size_cleared
                        
                        	OutQueue Cleared Size
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: update_out_queue_size_cumulative
                        
                        	OutQueue Cumulative Size
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: update_out_queue_size_discarded
                        
                        	OutQueue Discarded Size
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: update_out_queue_size_high
                        
                        	OutQueue Hi Size
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_recovery_count
                        
                        	Recovery Count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_throttle_count
                        
                        	Throttle Count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.last_update_cleard_age = None
                            self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateClearedTimestamp()
                            self.last_update_cleared_timestamp.parent = self
                            self.last_update_discard_age = None
                            self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateDiscardTimestamp()
                            self.last_update_discard_timestamp.parent = self
                            self.last_update_memory_allocation_fail_age = None
                            self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                            self.last_update_memory_allocation_fail_timestamp.parent = self
                            self.last_update_recovery_age = None
                            self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateRecoveryTimestamp()
                            self.last_update_recovery_timestamp.parent = self
                            self.last_update_throttle_age = None
                            self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateThrottleTimestamp()
                            self.last_update_throttle_timestamp.parent = self
                            self.update_memory_allocation_fail_count = None
                            self.update_out_queue_messages_cleared = None
                            self.update_out_queue_messages_cumulative = None
                            self.update_out_queue_messages_discarded = None
                            self.update_out_queue_messages_high = None
                            self.update_out_queue_size_cleared = None
                            self.update_out_queue_size_cumulative = None
                            self.update_out_queue_size_discarded = None
                            self.update_out_queue_size_high = None
                            self.update_recovery_count = None
                            self.update_throttle_count = None


                        class LastUpdateDiscardTimestamp(object):
                            """
                            Last Discarded time
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.nanoseconds = None
                                self.seconds = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-discard-timestamp'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.nanoseconds is not None:
                                    return True

                                if self.seconds is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateDiscardTimestamp']['meta_info']


                        class LastUpdateClearedTimestamp(object):
                            """
                            Last Cleared time
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.nanoseconds = None
                                self.seconds = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-cleared-timestamp'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.nanoseconds is not None:
                                    return True

                                if self.seconds is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateClearedTimestamp']['meta_info']


                        class LastUpdateThrottleTimestamp(object):
                            """
                            Last Throttled time
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.nanoseconds = None
                                self.seconds = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-throttle-timestamp'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.nanoseconds is not None:
                                    return True

                                if self.seconds is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateThrottleTimestamp']['meta_info']


                        class LastUpdateRecoveryTimestamp(object):
                            """
                            Last Recovery time
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.nanoseconds = None
                                self.seconds = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-recovery-timestamp'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.nanoseconds is not None:
                                    return True

                                if self.seconds is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateRecoveryTimestamp']['meta_info']


                        class LastUpdateMemoryAllocationFailTimestamp(object):
                            """
                            Memory allocation failure time
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.nanoseconds = None
                                self.seconds = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-memory-allocation-fail-timestamp'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.nanoseconds is not None:
                                    return True

                                if self.seconds is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-statistics'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.last_update_cleard_age is not None:
                                return True

                            if self.last_update_cleared_timestamp is not None and self.last_update_cleared_timestamp._has_data():
                                return True

                            if self.last_update_discard_age is not None:
                                return True

                            if self.last_update_discard_timestamp is not None and self.last_update_discard_timestamp._has_data():
                                return True

                            if self.last_update_memory_allocation_fail_age is not None:
                                return True

                            if self.last_update_memory_allocation_fail_timestamp is not None and self.last_update_memory_allocation_fail_timestamp._has_data():
                                return True

                            if self.last_update_recovery_age is not None:
                                return True

                            if self.last_update_recovery_timestamp is not None and self.last_update_recovery_timestamp._has_data():
                                return True

                            if self.last_update_throttle_age is not None:
                                return True

                            if self.last_update_throttle_timestamp is not None and self.last_update_throttle_timestamp._has_data():
                                return True

                            if self.update_memory_allocation_fail_count is not None:
                                return True

                            if self.update_out_queue_messages_cleared is not None:
                                return True

                            if self.update_out_queue_messages_cumulative is not None:
                                return True

                            if self.update_out_queue_messages_discarded is not None:
                                return True

                            if self.update_out_queue_messages_high is not None:
                                return True

                            if self.update_out_queue_size_cleared is not None:
                                return True

                            if self.update_out_queue_size_cumulative is not None:
                                return True

                            if self.update_out_queue_size_discarded is not None:
                                return True

                            if self.update_out_queue_size_high is not None:
                                return True

                            if self.update_recovery_count is not None:
                                return True

                            if self.update_throttle_count is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics']['meta_info']


                    class UpdateAddressFamily(object):
                        """
                        List of address\-families
                        
                        .. attribute:: current_update_limit_af
                        
                        	Current AF update limit
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: filter_group_count
                        
                        	Filter\-group count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: neighbor_count
                        
                        	Neighbor count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: refresh_sub_group_count
                        
                        	Refresh sub\-group count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: refresh_sub_group_throttled_count
                        
                        	Throttled refresh sub\-group count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sub_group_throttled_count
                        
                        	Throttled sub\-group count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_group_af_name
                        
                        	Address family identifier
                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                        
                        .. attribute:: update_out_queue_messages
                        
                        	OutQueue messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_size
                        
                        	OutQueue size
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_sub_group_count
                        
                        	Sub\-group count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_throttled
                        
                        	Is update throttled
                        	**type**\:  bool
                        
                        .. attribute:: update_update_group_count
                        
                        	Update\-group count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.current_update_limit_af = None
                            self.filter_group_count = None
                            self.neighbor_count = None
                            self.refresh_sub_group_count = None
                            self.refresh_sub_group_throttled_count = None
                            self.sub_group_throttled_count = None
                            self.update_group_af_name = None
                            self.update_out_queue_messages = None
                            self.update_out_queue_size = None
                            self.update_sub_group_count = None
                            self.update_throttled = None
                            self.update_update_group_count = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-address-family'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.current_update_limit_af is not None:
                                return True

                            if self.filter_group_count is not None:
                                return True

                            if self.neighbor_count is not None:
                                return True

                            if self.refresh_sub_group_count is not None:
                                return True

                            if self.refresh_sub_group_throttled_count is not None:
                                return True

                            if self.sub_group_throttled_count is not None:
                                return True

                            if self.update_group_af_name is not None:
                                return True

                            if self.update_out_queue_messages is not None:
                                return True

                            if self.update_out_queue_size is not None:
                                return True

                            if self.update_sub_group_count is not None:
                                return True

                            if self.update_throttled is not None:
                                return True

                            if self.update_update_group_count is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateAddressFamily']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-process'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.configured_update_limit_process is not None:
                            return True

                        if self.current_update_limit_process is not None:
                            return True

                        if self.update_address_family is not None:
                            for child_ref in self.update_address_family:
                                if child_ref._has_data():
                                    return True

                        if self.update_out_logging is not None:
                            return True

                        if self.update_out_queue_messages is not None:
                            return True

                        if self.update_out_queue_size is not None:
                            return True

                        if self.update_statistics is not None and self.update_statistics._has_data():
                            return True

                        if self.update_throttled is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess']['meta_info']


                class RpkiRefreshAfs(object):
                    """
                    RPKI Refresh Table (per AF)
                    
                    .. attribute:: rpki_refresh_af
                    
                    	RPKI Refresh List
                    	**type**\: list of    :py:class:`RpkiRefreshAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.RpkiRefreshAfs.RpkiRefreshAf>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2015-08-27'

                    def __init__(self):
                        self.parent = None
                        self.rpki_refresh_af = YList()
                        self.rpki_refresh_af.parent = self
                        self.rpki_refresh_af.name = 'rpki_refresh_af'


                    class RpkiRefreshAf(object):
                        """
                        RPKI Refresh List
                        
                        .. attribute:: af_name  <key>
                        
                        	Adress family
                        	**type**\:   :py:class:`BgpRpkiEdmAfEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiEdmAfEnum>`
                        
                        .. attribute:: refresh_entry
                        
                        	Array of refresh entries
                        	**type**\: list of    :py:class:`RefreshEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.RpkiRefreshAfs.RpkiRefreshAf.RefreshEntry>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.refresh_entry = YList()
                            self.refresh_entry.parent = self
                            self.refresh_entry.name = 'refresh_entry'


                        class RefreshEntry(object):
                            """
                            Array of refresh entries
                            
                            .. attribute:: af_name
                            
                            	Address Family
                            	**type**\:   :py:class:`BgpRpkiAfEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiAfEnum>`
                            
                            .. attribute:: drop
                            
                            	BGP paths were dropped
                            	**type**\:  bool
                            
                            .. attribute:: neighbor
                            
                            	BGP neighbor
                            	**type**\:  str
                            
                            .. attribute:: paths
                            
                            	Number of BGP paths modified or dropped
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: policy
                            
                            	Route Policy
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.drop = None
                                self.neighbor = None
                                self.paths = None
                                self.policy = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:refresh-entry'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.drop is not None:
                                    return True

                                if self.neighbor is not None:
                                    return True

                                if self.paths is not None:
                                    return True

                                if self.policy is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.RpkiRefreshAfs.RpkiRefreshAf.RefreshEntry']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.af_name is None:
                                raise YPYModelError('Key property af_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rpki-refresh-af[Cisco-IOS-XR-ipv4-bgp-oper:af-name = ' + str(self.af_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.refresh_entry is not None:
                                for child_ref in self.refresh_entry:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.RpkiRefreshAfs.RpkiRefreshAf']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rpki-refresh-afs'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.rpki_refresh_af is not None:
                            for child_ref in self.rpki_refresh_af:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.RpkiRefreshAfs']['meta_info']


                class Vrfs(object):
                    """
                    VRF related operational data
                    
                    .. attribute:: vrf
                    
                    	Operational data for a particular VRF
                    	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2015-08-27'

                    def __init__(self):
                        self.parent = None
                        self.vrf = YList()
                        self.vrf.parent = self
                        self.vrf.name = 'vrf'


                    class Vrf(object):
                        """
                        Operational data for a particular VRF
                        
                        .. attribute:: vrf_name  <key>
                        
                        	Name of the VRF
                        	**type**\:  str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: afs
                        
                        	BGP address family table
                        	**type**\:   :py:class:`Afs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs>`
                        
                        .. attribute:: bmp
                        
                        	BMP related Operational Data
                        	**type**\:   :py:class:`Bmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp>`
                        
                        .. attribute:: global_process_info
                        
                        	The Global Process information table
                        	**type**\:   :py:class:`GlobalProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo>`
                        
                        .. attribute:: information
                        
                        	Meta data for VRF
                        	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Information>`
                        
                        .. attribute:: message_logs
                        
                        	The BGP Neighbor Message table
                        	**type**\:   :py:class:`MessageLogs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs>`
                        
                        .. attribute:: neighbor_ranges
                        
                        	The BGP Dynamic Neighbor Range table
                        	**type**\:   :py:class:`NeighborRanges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges>`
                        
                        .. attribute:: neighbors
                        
                        	The BGP Neighbor table
                        	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors>`
                        
                        .. attribute:: next_hop_vrf
                        
                        	A BGP Next\-hop VRF table entry
                        	**type**\:   :py:class:`NextHopVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NextHopVrf>`
                        
                        .. attribute:: postits
                        
                        	The BGP Neighbor table
                        	**type**\:   :py:class:`Postits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits>`
                        
                        .. attribute:: process_info
                        
                        	A Process instance table entry
                        	**type**\:   :py:class:`ProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo>`
                        
                        .. attribute:: sessions
                        
                        	The BGP session table
                        	**type**\:   :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions>`
                        
                        .. attribute:: update_inbound_error_neighbors
                        
                        	Update inbound error information for all neighbors
                        	**type**\:   :py:class:`UpdateInboundErrorNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors>`
                        
                        .. attribute:: update_inbound_error_vrf
                        
                        	Update inbound error information for the VRF
                        	**type**\:   :py:class:`UpdateInboundErrorVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorVrf>`
                        
                        .. attribute:: update_inbound_filter_neighbors
                        
                        	Update inbound filtering information for all neighbors
                        	**type**\:   :py:class:`UpdateInboundFilterNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors>`
                        
                        .. attribute:: update_inbound_filter_vrf
                        
                        	Update inbound filtering information for the VRF
                        	**type**\:   :py:class:`UpdateInboundFilterVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterVrf>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.vrf_name = None
                            self.afs = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs()
                            self.afs.parent = self
                            self.bmp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp()
                            self.bmp.parent = self
                            self.global_process_info = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo()
                            self.global_process_info.parent = self
                            self.information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Information()
                            self.information.parent = self
                            self.message_logs = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs()
                            self.message_logs.parent = self
                            self.neighbor_ranges = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges()
                            self.neighbor_ranges.parent = self
                            self.neighbors = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors()
                            self.neighbors.parent = self
                            self.next_hop_vrf = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NextHopVrf()
                            self.next_hop_vrf.parent = self
                            self.postits = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits()
                            self.postits.parent = self
                            self.process_info = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo()
                            self.process_info.parent = self
                            self.sessions = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions()
                            self.sessions.parent = self
                            self.update_inbound_error_neighbors = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors()
                            self.update_inbound_error_neighbors.parent = self
                            self.update_inbound_error_vrf = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorVrf()
                            self.update_inbound_error_vrf.parent = self
                            self.update_inbound_filter_neighbors = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors()
                            self.update_inbound_filter_neighbors.parent = self
                            self.update_inbound_filter_vrf = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterVrf()
                            self.update_inbound_filter_vrf.parent = self


                        class UpdateInboundErrorVrf(object):
                            """
                            Update inbound error information for the VRF
                            
                            .. attribute:: last_update_malformed_age
                            
                            	Time since last malformed messages received event (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_update_malformed_timestamp
                            
                            	Last malformed messages received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`LastUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp>`
                            
                            .. attribute:: update_malformed_message_count
                            
                            	Malformed messages count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_malformed_neighbor_count
                            
                            	Count of neighbors that received malformed messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_vrf_name
                            
                            	VRF Name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.last_update_malformed_age = None
                                self.last_update_malformed_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp()
                                self.last_update_malformed_timestamp.parent = self
                                self.update_malformed_message_count = None
                                self.update_malformed_neighbor_count = None
                                self.update_vrf_name = None


                            class LastUpdateMalformedTimestamp(object):
                                """
                                Last malformed messages received time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.nanoseconds = None
                                    self.seconds = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-malformed-timestamp'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.nanoseconds is not None:
                                        return True

                                    if self.seconds is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-inbound-error-vrf'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.last_update_malformed_age is not None:
                                    return True

                                if self.last_update_malformed_timestamp is not None and self.last_update_malformed_timestamp._has_data():
                                    return True

                                if self.update_malformed_message_count is not None:
                                    return True

                                if self.update_malformed_neighbor_count is not None:
                                    return True

                                if self.update_vrf_name is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorVrf']['meta_info']


                        class Afs(object):
                            """
                            BGP address family table
                            
                            .. attribute:: af
                            
                            	A particular address family
                            	**type**\: list of    :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.af = YList()
                                self.af.parent = self
                                self.af.name = 'af'


                            class Af(object):
                                """
                                A particular address family
                                
                                .. attribute:: af_name  <key>
                                
                                	Address family
                                	**type**\:   :py:class:`BgpAddressFamilyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamilyEnum>`
                                
                                .. attribute:: advertised_path_counts
                                
                                	The BGP Advertised paths table (bestpath)
                                	**type**\:   :py:class:`AdvertisedPathCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts>`
                                
                                .. attribute:: advertised_path_xr
                                
                                	The BGP Advertised path table (bestpath)
                                	**type**\:   :py:class:`AdvertisedPathXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr>`
                                
                                .. attribute:: advertised_paths
                                
                                	The BGP Advertised paths table (add\-paths)
                                	**type**\:   :py:class:`AdvertisedPaths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths>`
                                
                                .. attribute:: af_process_info
                                
                                	A BGP Process address family table entry
                                	**type**\:   :py:class:`AfProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo>`
                                
                                .. attribute:: attributes
                                
                                	The BGP Attribute table
                                	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes>`
                                
                                .. attribute:: bmp_paths
                                
                                	The paths in BMP Table
                                	**type**\:   :py:class:`BmpPaths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths>`
                                
                                .. attribute:: convergence
                                
                                	A BGP Convergence table entry
                                	**type**\:   :py:class:`Convergence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Convergence>`
                                
                                .. attribute:: dampenings
                                
                                	The BGP Dampening table
                                	**type**\:   :py:class:`Dampenings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings>`
                                
                                .. attribute:: epes
                                
                                	The BGP Egress Engineering table
                                	**type**\:   :py:class:`Epes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes>`
                                
                                .. attribute:: global_af_process_info
                                
                                	The Global Address Family Process information table
                                	**type**\:   :py:class:`GlobalAfProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo>`
                                
                                .. attribute:: neighbor_af_table
                                
                                	The BGP Neighbor AF table
                                	**type**\:   :py:class:`NeighborAfTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable>`
                                
                                .. attribute:: network_all_rds
                                
                                	The BGP Network Lookup Table
                                	**type**\:   :py:class:`NetworkAllRds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds>`
                                
                                .. attribute:: network_lookup_all_rds
                                
                                	The BGP Network Lookup Table
                                	**type**\:   :py:class:`NetworkLookupAllRds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds>`
                                
                                .. attribute:: network_prefixes
                                
                                	The BGP Network Lookup table
                                	**type**\:   :py:class:`NetworkPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes>`
                                
                                .. attribute:: networks
                                
                                	The BGP Network Table
                                	**type**\:   :py:class:`Networks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks>`
                                
                                .. attribute:: next_hop_address_families
                                
                                	Address family of nexthop table
                                	**type**\:   :py:class:`NextHopAddressFamilies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies>`
                                
                                .. attribute:: path_labeled_table
                                
                                	The BGP Path Labeled Table
                                	**type**\:   :py:class:`PathLabeledTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable>`
                                
                                .. attribute:: path_table
                                
                                	The BGP Path Table
                                	**type**\:   :py:class:`PathTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable>`
                                
                                .. attribute:: path_used_table
                                
                                	The BGP Path Used Table
                                	**type**\:   :py:class:`PathUsedTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable>`
                                
                                .. attribute:: policies
                                
                                	The BGP Policy Table
                                	**type**\:   :py:class:`Policies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies>`
                                
                                .. attribute:: prefix_filters
                                
                                	The BGP Prefix Filter table
                                	**type**\:   :py:class:`PrefixFilters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters>`
                                
                                .. attribute:: rpc_sets
                                
                                	BGP next\-hop set table
                                	**type**\:   :py:class:`RpcSets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets>`
                                
                                .. attribute:: rt_set_counters
                                
                                	The RT\-set counter table
                                	**type**\:   :py:class:`RtSetCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters>`
                                
                                .. attribute:: sourced_networks
                                
                                	The BGP Convergence table
                                	**type**\:   :py:class:`SourcedNetworks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks>`
                                
                                .. attribute:: update_generation_address_family
                                
                                	Update generation for address\-family
                                	**type**\:   :py:class:`UpdateGenerationAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily>`
                                
                                .. attribute:: update_generation_filter_groups
                                
                                	Update generation for all filter\-groups under a sub\-group
                                	**type**\:   :py:class:`UpdateGenerationFilterGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups>`
                                
                                .. attribute:: update_generation_neighbors
                                
                                	Update generation for all neighbors
                                	**type**\:   :py:class:`UpdateGenerationNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors>`
                                
                                .. attribute:: update_generation_sub_groups
                                
                                	Update generation for all sub\-groups
                                	**type**\:   :py:class:`UpdateGenerationSubGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups>`
                                
                                .. attribute:: update_generation_update_groups
                                
                                	Update generation for all update\-groups
                                	**type**\:   :py:class:`UpdateGenerationUpdateGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups>`
                                
                                .. attribute:: update_groups
                                
                                	The BGP Update group table
                                	**type**\:   :py:class:`UpdateGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.advertised_path_counts = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts()
                                    self.advertised_path_counts.parent = self
                                    self.advertised_path_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr()
                                    self.advertised_path_xr.parent = self
                                    self.advertised_paths = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths()
                                    self.advertised_paths.parent = self
                                    self.af_process_info = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo()
                                    self.af_process_info.parent = self
                                    self.attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes()
                                    self.attributes.parent = self
                                    self.bmp_paths = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths()
                                    self.bmp_paths.parent = self
                                    self.convergence = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Convergence()
                                    self.convergence.parent = self
                                    self.dampenings = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings()
                                    self.dampenings.parent = self
                                    self.epes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes()
                                    self.epes.parent = self
                                    self.global_af_process_info = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo()
                                    self.global_af_process_info.parent = self
                                    self.neighbor_af_table = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable()
                                    self.neighbor_af_table.parent = self
                                    self.network_all_rds = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds()
                                    self.network_all_rds.parent = self
                                    self.network_lookup_all_rds = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds()
                                    self.network_lookup_all_rds.parent = self
                                    self.network_prefixes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes()
                                    self.network_prefixes.parent = self
                                    self.networks = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks()
                                    self.networks.parent = self
                                    self.next_hop_address_families = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies()
                                    self.next_hop_address_families.parent = self
                                    self.path_labeled_table = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable()
                                    self.path_labeled_table.parent = self
                                    self.path_table = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable()
                                    self.path_table.parent = self
                                    self.path_used_table = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable()
                                    self.path_used_table.parent = self
                                    self.policies = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies()
                                    self.policies.parent = self
                                    self.prefix_filters = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters()
                                    self.prefix_filters.parent = self
                                    self.rpc_sets = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets()
                                    self.rpc_sets.parent = self
                                    self.rt_set_counters = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters()
                                    self.rt_set_counters.parent = self
                                    self.sourced_networks = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks()
                                    self.sourced_networks.parent = self
                                    self.update_generation_address_family = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily()
                                    self.update_generation_address_family.parent = self
                                    self.update_generation_filter_groups = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups()
                                    self.update_generation_filter_groups.parent = self
                                    self.update_generation_neighbors = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors()
                                    self.update_generation_neighbors.parent = self
                                    self.update_generation_sub_groups = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups()
                                    self.update_generation_sub_groups.parent = self
                                    self.update_generation_update_groups = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups()
                                    self.update_generation_update_groups.parent = self
                                    self.update_groups = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups()
                                    self.update_groups.parent = self


                                class NetworkLookupAllRds(object):
                                    """
                                    The BGP Network Lookup Table
                                    
                                    .. attribute:: network_lookup_all_rd
                                    
                                    	The BGP Network Lookup table
                                    	**type**\: list of    :py:class:`NetworkLookupAllRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.network_lookup_all_rd = YList()
                                        self.network_lookup_all_rd.parent = self
                                        self.network_lookup_all_rd.name = 'network_lookup_all_rd'


                                    class NetworkLookupAllRd(object):
                                        """
                                        The BGP Network Lookup table
                                        
                                        .. attribute:: network_prefix  <key>
                                        
                                        	Network 
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: network_lookup_rds
                                        
                                        	The BGP Network Lookup table
                                        	**type**\:   :py:class:`NetworkLookupRds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.network_prefix = None
                                            self.network_lookup_rds = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds()
                                            self.network_lookup_rds.parent = self


                                        class NetworkLookupRds(object):
                                            """
                                            The BGP Network Lookup table
                                            
                                            .. attribute:: network_lookup_rd
                                            
                                            	A BGP Network table entry
                                            	**type**\: list of    :py:class:`NetworkLookupRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.network_lookup_rd = YList()
                                                self.network_lookup_rd.parent = self
                                                self.network_lookup_rd.name = 'network_lookup_rd'


                                            class NetworkLookupRd(object):
                                                """
                                                A BGP Network table entry
                                                
                                                .. attribute:: rd  <key>
                                                
                                                	Route Distinguisher value
                                                	**type**\:  str
                                                
                                                .. attribute:: active_path_element
                                                
                                                	Path element list received from Active inst
                                                	**type**\: list of    :py:class:`ActivePathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement>`
                                                
                                                .. attribute:: active_process_instance_path
                                                
                                                	Active's paths for this net 
                                                	**type**\: list of    :py:class:`ActiveProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath>`
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield>`
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\:  bool
                                                
                                                .. attribute:: af_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield>`
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix>`
                                                
                                                .. attribute:: bit
                                                
                                                	Bit
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: flags
                                                
                                                	Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: gateway_array
                                                
                                                	Gateway array ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_inconsistent_paths
                                                
                                                	Net has inconsistent paths
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_lbl_retained
                                                
                                                	Net has label retained
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_local_label
                                                
                                                	Net has local label
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_net_aggregation_suppressed
                                                
                                                	Net suppressed due to aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_net_ldp_signaled
                                                
                                                	L2VPN Net LDP signaled  aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_permanent_network
                                                
                                                	Permanent Network
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_path_element
                                                
                                                	Local path element list
                                                	**type**\: list of    :py:class:`LocalPathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement>`
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: local_process_instance_path
                                                
                                                	Local (to process instance) paths for this net 
                                                	**type**\: list of    :py:class:`LocalProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath>`
                                                
                                                .. attribute:: net_backup_available
                                                
                                                	Net has backup path
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_backup_label_rewrite_available
                                                
                                                	Net has label rewrite for backup path
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_eibgp_multipath
                                                
                                                	Net has EIBGP multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_extended_flags
                                                
                                                	Net extended flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: net_flags
                                                
                                                	Flags associated with                            net
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: net_local_label
                                                
                                                	Local label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: net_local_label_rewrite
                                                
                                                	Net label has rewrite
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_local_label_srgb
                                                
                                                	Net label allocated fromSegment routing global block
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_multipath
                                                
                                                	Net has multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: num_of_path
                                                
                                                	Number of path for this net
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: process_instance_id
                                                
                                                	Process instance ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: resilient_nexthop_set
                                                
                                                	Resilient nexthop set ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_failed
                                                
                                                	RIB install failed
                                                	**type**\:  bool
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: table_brib_version
                                                
                                                	Table version # for updates
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: table_version
                                                
                                                	Table version # for net
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: version
                                                
                                                	Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: version_age
                                                
                                                	Version age
                                                	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionAge>`
                                                
                                                .. attribute:: version_timestamp
                                                
                                                	Version timestamp
                                                	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionTimestamp>`
                                                
                                                .. attribute:: vrf_name
                                                
                                                	Name of the VRF
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.rd = None
                                                    self.active_path_element = YList()
                                                    self.active_path_element.parent = self
                                                    self.active_path_element.name = 'active_path_element'
                                                    self.active_process_instance_path = YList()
                                                    self.active_process_instance_path.parent = self
                                                    self.active_process_instance_path.name = 'active_process_instance_path'
                                                    self.add_path_orr_bitfield = YList()
                                                    self.add_path_orr_bitfield.parent = self
                                                    self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                    self.advertisedto_pe = None
                                                    self.af_name = None
                                                    self.best_path_orr_bitfield = YList()
                                                    self.best_path_orr_bitfield.parent = self
                                                    self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self.bit = None
                                                    self.flags = None
                                                    self.gateway_array = None
                                                    self.has_inconsistent_paths = None
                                                    self.has_lbl_retained = None
                                                    self.has_local_label = None
                                                    self.is_net_aggregation_suppressed = None
                                                    self.is_net_ldp_signaled = None
                                                    self.is_permanent_network = None
                                                    self.local_path_element = YList()
                                                    self.local_path_element.parent = self
                                                    self.local_path_element.name = 'local_path_element'
                                                    self.local_peers_advertised_to = YList()
                                                    self.local_peers_advertised_to.parent = self
                                                    self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                    self.local_process_instance_path = YList()
                                                    self.local_process_instance_path.parent = self
                                                    self.local_process_instance_path.name = 'local_process_instance_path'
                                                    self.net_backup_available = None
                                                    self.net_backup_label_rewrite_available = None
                                                    self.net_eibgp_multipath = None
                                                    self.net_extended_flags = None
                                                    self.net_flags = None
                                                    self.net_local_label = None
                                                    self.net_local_label_rewrite = None
                                                    self.net_local_label_srgb = None
                                                    self.net_multipath = None
                                                    self.num_of_path = None
                                                    self.pe_peers_advertised_to = YList()
                                                    self.pe_peers_advertised_to.parent = self
                                                    self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                    self.process_instance_id = None
                                                    self.resilient_nexthop_set = None
                                                    self.rib_failed = None
                                                    self.route_distinguisher = None
                                                    self.table_brib_version = None
                                                    self.table_version = None
                                                    self.version = None
                                                    self.version_age = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionAge()
                                                    self.version_age.parent = self
                                                    self.version_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionTimestamp()
                                                    self.version_timestamp.parent = self
                                                    self.vrf_name = None


                                                class BgpPrefix(object):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self.prefix_length = None


                                                    class Prefix(object):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.prefix is not None and self.prefix._has_data():
                                                            return True

                                                        if self.prefix_length is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix']['meta_info']


                                                class VersionTimestamp(object):
                                                    """
                                                    Version timestamp
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-timestamp'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionTimestamp']['meta_info']


                                                class VersionAge(object):
                                                    """
                                                    Version age
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-age'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionAge']['meta_info']


                                                class LocalPeersAdvertisedTo(object):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo']['meta_info']


                                                class PePeersAdvertisedTo(object):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo']['meta_info']


                                                class BestPathOrrBitfield(object):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield']['meta_info']


                                                class AddPathOrrBitfield(object):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield']['meta_info']


                                                class LocalProcessInstancePath(object):
                                                    """
                                                    Local (to process instance) paths for this net 
                                                    
                                                    .. attribute:: af_name
                                                    
                                                    	Address family identifier
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: attributes_after_policy_in
                                                    
                                                    	Attributes after inbound policy applied
                                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn>`
                                                    
                                                    .. attribute:: label_fail
                                                    
                                                    	LSD label allocation failed 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: label_o_or_version
                                                    
                                                    	Label Version when OOR happens
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_oor
                                                    
                                                    	LSD label space is exhausted
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address_xr
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr>`
                                                    
                                                    .. attribute:: no_path
                                                    
                                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: path_information
                                                    
                                                    	Path information
                                                    	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation>`
                                                    
                                                    .. attribute:: prefix_version
                                                    
                                                    	Version of BGP Prefix Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: process_instance_id
                                                    
                                                    	Process instance ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: route_distinguisher
                                                    
                                                    	Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: source_route_distinguisher
                                                    
                                                    	Source Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: source_vrf_name
                                                    
                                                    	Name of the source VRF
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: srcaf_name
                                                    
                                                    	Address family identifier
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: vrf_name
                                                    
                                                    	Name of the VRF
                                                    	**type**\:  str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.af_name = None
                                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn()
                                                        self.attributes_after_policy_in.parent = self
                                                        self.label_fail = None
                                                        self.label_o_or_version = None
                                                        self.label_oor = None
                                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr()
                                                        self.neighbor_address_xr.parent = self
                                                        self.no_path = None
                                                        self.path_information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation()
                                                        self.path_information.parent = self
                                                        self.prefix_version = None
                                                        self.process_instance_id = None
                                                        self.route_distinguisher = None
                                                        self.source_route_distinguisher = None
                                                        self.source_vrf_name = None
                                                        self.srcaf_name = None
                                                        self.vrf_name = None


                                                    class NeighborAddressXr(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr']['meta_info']


                                                    class PathInformation(object):
                                                        """
                                                        Path information
                                                        
                                                        .. attribute:: accept_own_path
                                                        
                                                        	Accept Own
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: accept_own_self_originated_p_ath
                                                        
                                                        	Accept\-Own self\-originated
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: add_path_orr_bitfield
                                                        
                                                        	ORR Add path Bitfields
                                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                        
                                                        .. attribute:: advertisedto_pe
                                                        
                                                        	Net could be advertised                          to PE peers
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: aigp_metric
                                                        
                                                        	Total AIGP metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: best_path_comp_stage
                                                        
                                                        	Stage where the path lost to the best path or group best
                                                        	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                                        
                                                        .. attribute:: best_path_comp_winner
                                                        
                                                        	Neighbor address of the path which won best path comparison
                                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                        
                                                        .. attribute:: best_path_id
                                                        
                                                        	Best path ID; DEPRECATED BYLocalPathId
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: best_path_id_comp_winner
                                                        
                                                        	Path ID of the path which won best path comparison
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: best_path_orr_bitfield
                                                        
                                                        	ORR Best path Bitfields
                                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                        
                                                        .. attribute:: bgp_prefix
                                                        
                                                        	BGP prefix
                                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix>`
                                                        
                                                        .. attribute:: dampen_penalty
                                                        
                                                        	Dampening penalty
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Mvpn Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                        
                                                        .. attribute:: fspec_invalid_path
                                                        
                                                        	Is Fspec invalid path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: graceful_shutdown
                                                        
                                                        	Marked for graceful shutdown
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: gw_addr
                                                        
                                                        	Path GW Address
                                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.GwAddr>`
                                                        
                                                        .. attribute:: halflife_time
                                                        
                                                        	Half\-life time for the penalty
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_esi
                                                        
                                                        	Path has EVPN ESI
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_gw_addr
                                                        
                                                        	Path has GW Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_local_net_label
                                                        
                                                        	Path has local label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mdt_group_addr
                                                        
                                                        	Path has MDT Group Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_extcomm
                                                        
                                                        	Path has MVPN EXTCOMM feedback
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_nbr_addr
                                                        
                                                        	Path has Mvpn nbr Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_nexthop_addr
                                                        
                                                        	Path has MVPN nexthop Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_pmsi
                                                        
                                                        	Path has MVPN PMSI feedback
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_rcvd_label
                                                        
                                                        	Path has received label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_second_label
                                                        
                                                        	Path has second received label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: ibgp_signaled_validity
                                                        
                                                        	IBGP signalled validation
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: igp_metric
                                                        
                                                        	IGP metric to the gateway
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: is_aggregation_suppressed
                                                        
                                                        	Path suppressed due to aggregation
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_best
                                                        
                                                        	Best available path within AS
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_best_path
                                                        
                                                        	Best available path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_import_dampened
                                                        
                                                        	net import dampened
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_import_suspect
                                                        
                                                        	net import suspect
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_internal_path
                                                        
                                                        	Received over an internal link
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_partial_best
                                                        
                                                        	Partial best path within distributed speaker
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_additional_path
                                                        
                                                        	Path is an additional\-path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_advertised_local_as_only
                                                        
                                                        	Not advertised outside local AS
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_af_install_eligible
                                                        
                                                        	Path can be installed in AF RIB
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_backup
                                                        
                                                        	Path is a backup path 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_backup_protect_multipath
                                                        
                                                        	Path is a backup path to protect multipaths
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_best_external
                                                        
                                                        	Path is a best external path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_damped
                                                        
                                                        	Path suppressed due to dampening
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_confederation_peer
                                                        
                                                        	Path received from confederation peer
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_network_command
                                                        
                                                        	Path sourced by network command
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_redistribute_command
                                                        
                                                        	Path sourced by redistribute command
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_route_reflector
                                                        
                                                        	Path received from route reflector
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_history_held
                                                        
                                                        	Path entry held to remember history
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_imp_candidate
                                                        
                                                        	Path is a candidate for multipath import
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_imported
                                                        
                                                        	Path is imported
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_local_aggregate
                                                        
                                                        	Path is a locally created aggregate
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_locally_sourced
                                                        
                                                        	Path sourced locally
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_long_lived_stale
                                                        
                                                        	Long lived stale routes learnt before neighbor restarts
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_multipath
                                                        
                                                        	Path is one of multipath best routes
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_nexthop_discarded
                                                        
                                                        	Path is redirected to Null0
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_not_advertised
                                                        
                                                        	Not advertised to any peer
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_not_advertised_to_ebg_ps
                                                        
                                                        	Not advertised to EBGPs
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_received_only
                                                        
                                                        	Path is received only
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_reoriginated
                                                        
                                                        	Path is reoriginated
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_reoriginated_stitching
                                                        
                                                        	Path is reoriginated with stitching RTs
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_stale
                                                        
                                                        	Stale routes learnt before neighbor restarts
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_synced_with_igp
                                                        
                                                        	Path synchronized with IGP
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_valid
                                                        
                                                        	Path attributes are usable
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_vpn_only
                                                        
                                                        	Path is not in the vrf
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_permanent_path
                                                        
                                                        	Path is of type Permanent path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_received_path_not_modified
                                                        
                                                        	Received path used without modification
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_spkr_as_best
                                                        
                                                        	Best available path within AS in speaker
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2vpn_circuit_status_value
                                                        
                                                        	L2VPN Circuit Status Value
                                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                        
                                                        .. attribute:: l2vpn_evpn_esi
                                                        
                                                        	L2VPN EVPN ESI
                                                        	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi>`
                                                        
                                                        .. attribute:: l2vpn_size
                                                        
                                                        	Path block size
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: labeled_unicast_safi_path
                                                        
                                                        	Path was learnt by labeled\-unicast SAFI
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: local_label
                                                        
                                                        	Path local label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_nh
                                                        
                                                        	Path has local nexthop
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: local_path_id
                                                        
                                                        	Local path ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_peers_advertised_to
                                                        
                                                        	Local peers that this prefix has been advertised to
                                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                        
                                                        .. attribute:: maximum_suppress_time
                                                        
                                                        	Maximum duration to suppress a stable route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mdt_group_addr
                                                        
                                                        	IPv4 MDT Group Address for the path
                                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                        
                                                        .. attribute:: mvpn_nbr_addr
                                                        
                                                        	Mvpn nbr Address for the path
                                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                        
                                                        .. attribute:: mvpn_nexthop_addr
                                                        
                                                        	Mvpn nexthop Address for the path
                                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                        
                                                        .. attribute:: mvpn_path_flags
                                                        
                                                        	Mvpn path flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: mvpn_pmsi_flags
                                                        
                                                        	Mvpn PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: mvpn_pmsi_label
                                                        
                                                        	Mvpn PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mvpn_pmsi_type
                                                        
                                                        	Mvpn PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: mvpn_pmsi_value
                                                        
                                                        	Mvpn PMSI Value
                                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                        
                                                        .. attribute:: mvpn_sfs_path
                                                        
                                                        	Is MVPN single forwarder PE path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress>`
                                                        
                                                        .. attribute:: neighbor_router_id
                                                        
                                                        	Router ID of the neighbor for the path
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: next_hop
                                                        
                                                        	Next hop
                                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop>`
                                                        
                                                        .. attribute:: nhte_tunnel
                                                        
                                                        	NH TE tunnel information
                                                        	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhteTunnel>`
                                                        
                                                        .. attribute:: path_flags
                                                        
                                                        	Flags associated with path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: path_flap_count
                                                        
                                                        	Number of times this route has flapped
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_import_flags
                                                        
                                                        	Path import flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_rt_set_id
                                                        
                                                        	RT\-set id of the path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_rt_set_route_count
                                                        
                                                        	Count in RT\-set
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_table_version
                                                        
                                                        	Table version # for pelem
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_weight
                                                        
                                                        	Weight for the path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pe_peers_advertised_to
                                                        
                                                        	PE peers that this prefix has been advertised to
                                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                        
                                                        .. attribute:: rcvd_label
                                                        
                                                        	Path received label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rcvd_path_id
                                                        
                                                        	Received path ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: reuse_value
                                                        
                                                        	Value to start reusing a route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rib_failed
                                                        
                                                        	Is net failed installed                          in RIB
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route Type of path
                                                        	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                                        
                                                        .. attribute:: rpki_origin_as_validation_disabled
                                                        
                                                        	RPKI originAS V. Disabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: rt_set_limit_enabled
                                                        
                                                        	Path subject to RT\-set net limit
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: second_label
                                                        
                                                        	Path second received label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: seconds_since_first_flap
                                                        
                                                        	Seconds since route first flapped
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: show_rpki_origin_as_validity
                                                        
                                                        	Display validity state ?
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: sn_rpki_origin_as_validity
                                                        
                                                        	RPKI origin validation state
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: suppress_penalty
                                                        
                                                        	Value to start suppressing a route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: time_to_unsuppress
                                                        
                                                        	Seconds until route is unsuppressed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.accept_own_path = None
                                                            self.accept_own_self_originated_p_ath = None
                                                            self.add_path_orr_bitfield = YList()
                                                            self.add_path_orr_bitfield.parent = self
                                                            self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                            self.advertisedto_pe = None
                                                            self.aigp_metric = None
                                                            self.best_path_comp_stage = None
                                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner()
                                                            self.best_path_comp_winner.parent = self
                                                            self.best_path_id = None
                                                            self.best_path_id_comp_winner = None
                                                            self.best_path_orr_bitfield = YList()
                                                            self.best_path_orr_bitfield.parent = self
                                                            self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix()
                                                            self.bgp_prefix.parent = self
                                                            self.dampen_penalty = None
                                                            self.extended_community = YList()
                                                            self.extended_community.parent = self
                                                            self.extended_community.name = 'extended_community'
                                                            self.fspec_invalid_path = None
                                                            self.graceful_shutdown = None
                                                            self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.GwAddr()
                                                            self.gw_addr.parent = self
                                                            self.halflife_time = None
                                                            self.has_esi = None
                                                            self.has_gw_addr = None
                                                            self.has_local_net_label = None
                                                            self.has_mdt_group_addr = None
                                                            self.has_mvpn_extcomm = None
                                                            self.has_mvpn_nbr_addr = None
                                                            self.has_mvpn_nexthop_addr = None
                                                            self.has_mvpn_pmsi = None
                                                            self.has_rcvd_label = None
                                                            self.has_second_label = None
                                                            self.ibgp_signaled_validity = None
                                                            self.igp_metric = None
                                                            self.is_aggregation_suppressed = None
                                                            self.is_as_best = None
                                                            self.is_best_path = None
                                                            self.is_import_dampened = None
                                                            self.is_import_suspect = None
                                                            self.is_internal_path = None
                                                            self.is_partial_best = None
                                                            self.is_path_additional_path = None
                                                            self.is_path_advertised_local_as_only = None
                                                            self.is_path_af_install_eligible = None
                                                            self.is_path_backup = None
                                                            self.is_path_backup_protect_multipath = None
                                                            self.is_path_best_external = None
                                                            self.is_path_damped = None
                                                            self.is_path_from_confederation_peer = None
                                                            self.is_path_from_network_command = None
                                                            self.is_path_from_redistribute_command = None
                                                            self.is_path_from_route_reflector = None
                                                            self.is_path_history_held = None
                                                            self.is_path_imp_candidate = None
                                                            self.is_path_imported = None
                                                            self.is_path_local_aggregate = None
                                                            self.is_path_locally_sourced = None
                                                            self.is_path_long_lived_stale = None
                                                            self.is_path_multipath = None
                                                            self.is_path_nexthop_discarded = None
                                                            self.is_path_not_advertised = None
                                                            self.is_path_not_advertised_to_ebg_ps = None
                                                            self.is_path_received_only = None
                                                            self.is_path_reoriginated = None
                                                            self.is_path_reoriginated_stitching = None
                                                            self.is_path_stale = None
                                                            self.is_path_synced_with_igp = None
                                                            self.is_path_valid = None
                                                            self.is_path_vpn_only = None
                                                            self.is_permanent_path = None
                                                            self.is_received_path_not_modified = None
                                                            self.is_spkr_as_best = None
                                                            self.l2vpn_circuit_status_value = YList()
                                                            self.l2vpn_circuit_status_value.parent = self
                                                            self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                            self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi()
                                                            self.l2vpn_evpn_esi.parent = self
                                                            self.l2vpn_size = None
                                                            self.labeled_unicast_safi_path = None
                                                            self.local_label = None
                                                            self.local_nh = None
                                                            self.local_path_id = None
                                                            self.local_peers_advertised_to = YList()
                                                            self.local_peers_advertised_to.parent = self
                                                            self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                            self.maximum_suppress_time = None
                                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr()
                                                            self.mdt_group_addr.parent = self
                                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                            self.mvpn_nbr_addr.parent = self
                                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                            self.mvpn_nexthop_addr.parent = self
                                                            self.mvpn_path_flags = None
                                                            self.mvpn_pmsi_flags = None
                                                            self.mvpn_pmsi_label = None
                                                            self.mvpn_pmsi_type = None
                                                            self.mvpn_pmsi_value = YList()
                                                            self.mvpn_pmsi_value.parent = self
                                                            self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                            self.mvpn_sfs_path = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.neighbor_router_id = None
                                                            self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop()
                                                            self.next_hop.parent = self
                                                            self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhteTunnel()
                                                            self.nhte_tunnel.parent = self
                                                            self.path_flags = None
                                                            self.path_flap_count = None
                                                            self.path_import_flags = None
                                                            self.path_rt_set_id = None
                                                            self.path_rt_set_route_count = None
                                                            self.path_table_version = None
                                                            self.path_weight = None
                                                            self.pe_peers_advertised_to = YList()
                                                            self.pe_peers_advertised_to.parent = self
                                                            self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                            self.rcvd_label = None
                                                            self.rcvd_path_id = None
                                                            self.reuse_value = None
                                                            self.rib_failed = None
                                                            self.route_type = None
                                                            self.rpki_origin_as_validation_disabled = None
                                                            self.rt_set_limit_enabled = None
                                                            self.second_label = None
                                                            self.seconds_since_first_flap = None
                                                            self.show_rpki_origin_as_validity = None
                                                            self.sn_rpki_origin_as_validity = None
                                                            self.suppress_penalty = None
                                                            self.time_to_unsuppress = None


                                                        class BgpPrefix(object):
                                                            """
                                                            BGP prefix
                                                            
                                                            .. attribute:: prefix
                                                            
                                                            	Prefix
                                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                            
                                                            .. attribute:: prefix_length
                                                            
                                                            	Prefix length
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                                self.prefix.parent = self
                                                                self.prefix_length = None


                                                            class Prefix(object):
                                                                """
                                                                Prefix
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.prefix is not None and self.prefix._has_data():
                                                                    return True

                                                                if self.prefix_length is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix']['meta_info']


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress']['meta_info']


                                                        class NextHop(object):
                                                            """
                                                            Next hop
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop']['meta_info']


                                                        class NhteTunnel(object):
                                                            """
                                                            NH TE tunnel information
                                                            
                                                            .. attribute:: binding_label
                                                            
                                                            	Binding label for the tunnel
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: has_te_tunnel
                                                            
                                                            	NH TE Tunnel info is present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_info_stale
                                                            
                                                            	Tunnel is stale
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_registered
                                                            
                                                            	Tunnel registered flag
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_up
                                                            
                                                            	Tunnel Up flag
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: last_tunnel_update
                                                            
                                                            	Time since the last rib update happened
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_if_handle
                                                            
                                                            	Interface handle for the tunnel
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_name
                                                            
                                                            	tunnel name
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            .. attribute:: tunnel_type
                                                            
                                                            	tunnel type
                                                            	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                            
                                                            .. attribute:: tunnel_v6_enabled
                                                            
                                                            	IPv6 enabled
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_v6_required
                                                            
                                                            	Tunnel need IPv6
                                                            	**type**\:  bool
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.binding_label = None
                                                                self.has_te_tunnel = None
                                                                self.is_tunnel_info_stale = None
                                                                self.is_tunnel_registered = None
                                                                self.is_tunnel_up = None
                                                                self.last_tunnel_update = None
                                                                self.tunnel_if_handle = None
                                                                self.tunnel_name = None
                                                                self.tunnel_type = None
                                                                self.tunnel_v6_enabled = None
                                                                self.tunnel_v6_required = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.binding_label is not None:
                                                                    return True

                                                                if self.has_te_tunnel is not None:
                                                                    return True

                                                                if self.is_tunnel_info_stale is not None:
                                                                    return True

                                                                if self.is_tunnel_registered is not None:
                                                                    return True

                                                                if self.is_tunnel_up is not None:
                                                                    return True

                                                                if self.last_tunnel_update is not None:
                                                                    return True

                                                                if self.tunnel_if_handle is not None:
                                                                    return True

                                                                if self.tunnel_name is not None:
                                                                    return True

                                                                if self.tunnel_type is not None:
                                                                    return True

                                                                if self.tunnel_v6_enabled is not None:
                                                                    return True

                                                                if self.tunnel_v6_required is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhteTunnel']['meta_info']


                                                        class MdtGroupAddr(object):
                                                            """
                                                            IPv4 MDT Group Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr']['meta_info']


                                                        class L2VpnEvpnEsi(object):
                                                            """
                                                            L2VPN EVPN ESI
                                                            
                                                            .. attribute:: esi
                                                            
                                                            	esi
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.esi = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.esi is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi']['meta_info']


                                                        class GwAddr(object):
                                                            """
                                                            Path GW Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self.len = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.len is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.GwAddr']['meta_info']


                                                        class BestPathCompWinner(object):
                                                            """
                                                            Neighbor address of the path which won best path
                                                            comparison
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner']['meta_info']


                                                        class MvpnNbrAddr(object):
                                                            """
                                                            Mvpn nbr Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr']['meta_info']


                                                        class MvpnNexthopAddr(object):
                                                            """
                                                            Mvpn nexthop Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr']['meta_info']


                                                        class L2VpnCircuitStatusValue(object):
                                                            """
                                                            L2VPN Circuit Status Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                                        class MvpnPmsiValue(object):
                                                            """
                                                            Mvpn PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue']['meta_info']


                                                        class ExtendedCommunity(object):
                                                            """
                                                            Mvpn Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity']['meta_info']


                                                        class LocalPeersAdvertisedTo(object):
                                                            """
                                                            Local peers that this prefix has been advertised
                                                            to
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.is_neighbor = None
                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self.update_group_number = None


                                                            class NeighborAddress(object):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.is_neighbor is not None:
                                                                    return True

                                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                    return True

                                                                if self.update_group_number is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                                        class PePeersAdvertisedTo(object):
                                                            """
                                                            PE peers that this prefix has been advertised to
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.is_neighbor = None
                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self.update_group_number = None


                                                            class NeighborAddress(object):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.is_neighbor is not None:
                                                                    return True

                                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                    return True

                                                                if self.update_group_number is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo']['meta_info']


                                                        class BestPathOrrBitfield(object):
                                                            """
                                                            ORR Best path Bitfields
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.is_neighbor = None
                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self.update_group_number = None


                                                            class NeighborAddress(object):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.is_neighbor is not None:
                                                                    return True

                                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                    return True

                                                                if self.update_group_number is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield']['meta_info']


                                                        class AddPathOrrBitfield(object):
                                                            """
                                                            ORR Add path Bitfields
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.is_neighbor = None
                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self.update_group_number = None


                                                            class NeighborAddress(object):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.is_neighbor is not None:
                                                                    return True

                                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                    return True

                                                                if self.update_group_number is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.accept_own_path is not None:
                                                                return True

                                                            if self.accept_own_self_originated_p_ath is not None:
                                                                return True

                                                            if self.add_path_orr_bitfield is not None:
                                                                for child_ref in self.add_path_orr_bitfield:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.advertisedto_pe is not None:
                                                                return True

                                                            if self.aigp_metric is not None:
                                                                return True

                                                            if self.best_path_comp_stage is not None:
                                                                return True

                                                            if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                                return True

                                                            if self.best_path_id is not None:
                                                                return True

                                                            if self.best_path_id_comp_winner is not None:
                                                                return True

                                                            if self.best_path_orr_bitfield is not None:
                                                                for child_ref in self.best_path_orr_bitfield:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                                return True

                                                            if self.dampen_penalty is not None:
                                                                return True

                                                            if self.extended_community is not None:
                                                                for child_ref in self.extended_community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.fspec_invalid_path is not None:
                                                                return True

                                                            if self.graceful_shutdown is not None:
                                                                return True

                                                            if self.gw_addr is not None and self.gw_addr._has_data():
                                                                return True

                                                            if self.halflife_time is not None:
                                                                return True

                                                            if self.has_esi is not None:
                                                                return True

                                                            if self.has_gw_addr is not None:
                                                                return True

                                                            if self.has_local_net_label is not None:
                                                                return True

                                                            if self.has_mdt_group_addr is not None:
                                                                return True

                                                            if self.has_mvpn_extcomm is not None:
                                                                return True

                                                            if self.has_mvpn_nbr_addr is not None:
                                                                return True

                                                            if self.has_mvpn_nexthop_addr is not None:
                                                                return True

                                                            if self.has_mvpn_pmsi is not None:
                                                                return True

                                                            if self.has_rcvd_label is not None:
                                                                return True

                                                            if self.has_second_label is not None:
                                                                return True

                                                            if self.ibgp_signaled_validity is not None:
                                                                return True

                                                            if self.igp_metric is not None:
                                                                return True

                                                            if self.is_aggregation_suppressed is not None:
                                                                return True

                                                            if self.is_as_best is not None:
                                                                return True

                                                            if self.is_best_path is not None:
                                                                return True

                                                            if self.is_import_dampened is not None:
                                                                return True

                                                            if self.is_import_suspect is not None:
                                                                return True

                                                            if self.is_internal_path is not None:
                                                                return True

                                                            if self.is_partial_best is not None:
                                                                return True

                                                            if self.is_path_additional_path is not None:
                                                                return True

                                                            if self.is_path_advertised_local_as_only is not None:
                                                                return True

                                                            if self.is_path_af_install_eligible is not None:
                                                                return True

                                                            if self.is_path_backup is not None:
                                                                return True

                                                            if self.is_path_backup_protect_multipath is not None:
                                                                return True

                                                            if self.is_path_best_external is not None:
                                                                return True

                                                            if self.is_path_damped is not None:
                                                                return True

                                                            if self.is_path_from_confederation_peer is not None:
                                                                return True

                                                            if self.is_path_from_network_command is not None:
                                                                return True

                                                            if self.is_path_from_redistribute_command is not None:
                                                                return True

                                                            if self.is_path_from_route_reflector is not None:
                                                                return True

                                                            if self.is_path_history_held is not None:
                                                                return True

                                                            if self.is_path_imp_candidate is not None:
                                                                return True

                                                            if self.is_path_imported is not None:
                                                                return True

                                                            if self.is_path_local_aggregate is not None:
                                                                return True

                                                            if self.is_path_locally_sourced is not None:
                                                                return True

                                                            if self.is_path_long_lived_stale is not None:
                                                                return True

                                                            if self.is_path_multipath is not None:
                                                                return True

                                                            if self.is_path_nexthop_discarded is not None:
                                                                return True

                                                            if self.is_path_not_advertised is not None:
                                                                return True

                                                            if self.is_path_not_advertised_to_ebg_ps is not None:
                                                                return True

                                                            if self.is_path_received_only is not None:
                                                                return True

                                                            if self.is_path_reoriginated is not None:
                                                                return True

                                                            if self.is_path_reoriginated_stitching is not None:
                                                                return True

                                                            if self.is_path_stale is not None:
                                                                return True

                                                            if self.is_path_synced_with_igp is not None:
                                                                return True

                                                            if self.is_path_valid is not None:
                                                                return True

                                                            if self.is_path_vpn_only is not None:
                                                                return True

                                                            if self.is_permanent_path is not None:
                                                                return True

                                                            if self.is_received_path_not_modified is not None:
                                                                return True

                                                            if self.is_spkr_as_best is not None:
                                                                return True

                                                            if self.l2vpn_circuit_status_value is not None:
                                                                for child_ref in self.l2vpn_circuit_status_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                                return True

                                                            if self.l2vpn_size is not None:
                                                                return True

                                                            if self.labeled_unicast_safi_path is not None:
                                                                return True

                                                            if self.local_label is not None:
                                                                return True

                                                            if self.local_nh is not None:
                                                                return True

                                                            if self.local_path_id is not None:
                                                                return True

                                                            if self.local_peers_advertised_to is not None:
                                                                for child_ref in self.local_peers_advertised_to:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.maximum_suppress_time is not None:
                                                                return True

                                                            if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                                return True

                                                            if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                                return True

                                                            if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                                return True

                                                            if self.mvpn_path_flags is not None:
                                                                return True

                                                            if self.mvpn_pmsi_flags is not None:
                                                                return True

                                                            if self.mvpn_pmsi_label is not None:
                                                                return True

                                                            if self.mvpn_pmsi_type is not None:
                                                                return True

                                                            if self.mvpn_pmsi_value is not None:
                                                                for child_ref in self.mvpn_pmsi_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.mvpn_sfs_path is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.neighbor_router_id is not None:
                                                                return True

                                                            if self.next_hop is not None and self.next_hop._has_data():
                                                                return True

                                                            if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                                return True

                                                            if self.path_flags is not None:
                                                                return True

                                                            if self.path_flap_count is not None:
                                                                return True

                                                            if self.path_import_flags is not None:
                                                                return True

                                                            if self.path_rt_set_id is not None:
                                                                return True

                                                            if self.path_rt_set_route_count is not None:
                                                                return True

                                                            if self.path_table_version is not None:
                                                                return True

                                                            if self.path_weight is not None:
                                                                return True

                                                            if self.pe_peers_advertised_to is not None:
                                                                for child_ref in self.pe_peers_advertised_to:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.rcvd_label is not None:
                                                                return True

                                                            if self.rcvd_path_id is not None:
                                                                return True

                                                            if self.reuse_value is not None:
                                                                return True

                                                            if self.rib_failed is not None:
                                                                return True

                                                            if self.route_type is not None:
                                                                return True

                                                            if self.rpki_origin_as_validation_disabled is not None:
                                                                return True

                                                            if self.rt_set_limit_enabled is not None:
                                                                return True

                                                            if self.second_label is not None:
                                                                return True

                                                            if self.seconds_since_first_flap is not None:
                                                                return True

                                                            if self.show_rpki_origin_as_validity is not None:
                                                                return True

                                                            if self.sn_rpki_origin_as_validity is not None:
                                                                return True

                                                            if self.suppress_penalty is not None:
                                                                return True

                                                            if self.time_to_unsuppress is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation']['meta_info']


                                                    class AttributesAfterPolicyIn(object):
                                                        """
                                                        Attributes after inbound policy applied
                                                        
                                                        .. attribute:: attr_set
                                                        
                                                        	ATTR\_SET attribute
                                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                        
                                                        .. attribute:: attribute_key_number
                                                        
                                                        	Attribute key number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_config
                                                        
                                                        	Attribute reuse ID Configured
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: attribute_reuse_id_current
                                                        
                                                        	Attribute reuse ID current ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_keys
                                                        
                                                        	Attribute reuse ID allocated keys
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_max_id
                                                        
                                                        	Attribute reuse ID maximum ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_node
                                                        
                                                        	Attribute reuse ID nodes
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_recover_sec
                                                        
                                                        	Attribute reuse ID timer in seconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: common_attributes
                                                        
                                                        	Common attributes
                                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                        
                                                        .. attribute:: is_application_gateway_present
                                                        
                                                        	Application gateway present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path2_byte
                                                        
                                                        	AS path encoded as 2\-byte
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_attr_set_present
                                                        
                                                        	BGP ATTR\_SET attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ribrnh_present
                                                        
                                                        	RIB RNH Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_rnh_present
                                                        
                                                        	RNH Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: ribrnh_encap
                                                        
                                                        	RIB RNH Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ribrnh_ip
                                                        
                                                        	RIB RNH IP Address
                                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                        
                                                        .. attribute:: ribrnh_mac
                                                        
                                                        	RIB RNH MAC Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                        
                                                        .. attribute:: ribrnh_table
                                                        
                                                        	RIB RNH Table
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ribrnh_vni
                                                        
                                                        	RIB RNH Vni
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ribrnhip_table
                                                        
                                                        	RIB RNH IP Table
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rnh_addr
                                                        
                                                        	RNH Address
                                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                        
                                                        .. attribute:: rnh_addr_len
                                                        
                                                        	RNH Address Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rnh_len
                                                        
                                                        	RNH Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: rnh_type
                                                        
                                                        	RNH Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: set_aigp_inbound_igp
                                                        
                                                        	AIGP set by policy inbound IGP 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: set_aigp_inbound_metric
                                                        
                                                        	AIGP set by policy inbound metric
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: vpn_distinguisher
                                                        
                                                        	VPN Distinguisher
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                            self.attr_set.parent = self
                                                            self.attribute_key_number = None
                                                            self.attribute_reuse_id_config = None
                                                            self.attribute_reuse_id_current = None
                                                            self.attribute_reuse_id_keys = None
                                                            self.attribute_reuse_id_max_id = None
                                                            self.attribute_reuse_id_node = None
                                                            self.attribute_reuse_id_recover_sec = None
                                                            self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                            self.common_attributes.parent = self
                                                            self.is_application_gateway_present = None
                                                            self.is_as_path2_byte = None
                                                            self.is_attr_set_present = None
                                                            self.is_ribrnh_present = None
                                                            self.is_rnh_present = None
                                                            self.ribrnh_encap = None
                                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                            self.ribrnh_ip.parent = self
                                                            self.ribrnh_mac = None
                                                            self.ribrnh_table = None
                                                            self.ribrnh_vni = None
                                                            self.ribrnhip_table = None
                                                            self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                            self.rnh_addr.parent = self
                                                            self.rnh_addr_len = None
                                                            self.rnh_len = None
                                                            self.rnh_type = None
                                                            self.set_aigp_inbound_igp = None
                                                            self.set_aigp_inbound_metric = None
                                                            self.vpn_distinguisher = None


                                                        class CommonAttributes(object):
                                                            """
                                                            Common attributes
                                                            
                                                            .. attribute:: aggregator_address
                                                            
                                                            	Address where aggregation was performed
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: aggregator_as
                                                            
                                                            	AS where aggregation was last performed
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: aigp_metric_value
                                                            
                                                            	AIGP metric value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..18446744073709551615
                                                            
                                                            .. attribute:: as_path
                                                            
                                                            	AS path attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: cluster
                                                            
                                                            	Cluster list attribute
                                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                            
                                                            .. attribute:: community
                                                            
                                                            	Community attribute
                                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                            
                                                            .. attribute:: connector_type
                                                            
                                                            	Connector Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: connector_value
                                                            
                                                            	Connector Value
                                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                            
                                                            .. attribute:: extended_community
                                                            
                                                            	Extended community attribute
                                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                            
                                                            .. attribute:: extended_community_flags
                                                            
                                                            	Extended community Flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: is_aggregator_present
                                                            
                                                            	Aggregator attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_aigp_present
                                                            
                                                            	AIGP Present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_as_path_present
                                                            
                                                            	AS path attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_atomic_aggregate_present
                                                            
                                                            	Atomic aggregate attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_community_present
                                                            
                                                            	Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_connector_present
                                                            
                                                            	Connector present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_extended_community_present
                                                            
                                                            	Extended community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_label_index_present
                                                            
                                                            	Label Index attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_local_pref_present
                                                            
                                                            	Local Preference attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ls_attribute_present
                                                            
                                                            	BGP LS attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_metric_present
                                                            
                                                            	Metric attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_origin_present
                                                            
                                                            	Origin attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pe_distinguisher_label_present
                                                            
                                                            	PE distinguisher label  attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pmsi_present
                                                            
                                                            	PMSI Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pppmp_present
                                                            
                                                            	PPMP Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ssa_present
                                                            
                                                            	SSA attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_encap_present
                                                            
                                                            	Tunnel Encap attribute present 
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: l2tpv3_cookie
                                                            
                                                            	L2TPv3 Cookie
                                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                            
                                                            .. attribute:: l2tpv3_session_id
                                                            
                                                            	L2TPv3 session id
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: label_index_attr
                                                            
                                                            	Label Index attribute
                                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                            
                                                            .. attribute:: local_preference
                                                            
                                                            	Local preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ls_attr
                                                            
                                                            	BGP LS attribute
                                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	Metric
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: neighbor_as
                                                            
                                                            	Neighbor AS number
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: origin
                                                            
                                                            	Origin
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: originator
                                                            
                                                            	Originator attribute
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: pe_distinguisher_label
                                                            
                                                            	PE distinguisher label attribute
                                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                            
                                                            .. attribute:: pmsi_flags
                                                            
                                                            	PMSI Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pmsi_label
                                                            
                                                            	PMSI label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pmsi_type
                                                            
                                                            	PMSI Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: pmsi_value
                                                            
                                                            	PMSI Value
                                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                            
                                                            .. attribute:: ppm_pvalue
                                                            
                                                            	PPMP Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: sr_policy_allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                            
                                                            .. attribute:: sr_policy_binding_sid
                                                            
                                                            	SR Policy Binding sid
                                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                            
                                                            .. attribute:: sr_policy_explicit_path
                                                            
                                                            	SR Policy Explicit paths
                                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                            
                                                            .. attribute:: sr_policy_preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: sr_tunnel_request_state
                                                            
                                                            	SR Tunnel Request State
                                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                            
                                                            .. attribute:: sr_tunnel_state
                                                            
                                                            	SR Tunnel State
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encap Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: unknown_attribute
                                                            
                                                            	Unknown attributes
                                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.aggregator_address = None
                                                                self.aggregator_as = None
                                                                self.aigp_metric_value = None
                                                                self.as_path = None
                                                                self.cluster = YList()
                                                                self.cluster.parent = self
                                                                self.cluster.name = 'cluster'
                                                                self.community = YList()
                                                                self.community.parent = self
                                                                self.community.name = 'community'
                                                                self.connector_type = None
                                                                self.connector_value = YList()
                                                                self.connector_value.parent = self
                                                                self.connector_value.name = 'connector_value'
                                                                self.extended_community = YList()
                                                                self.extended_community.parent = self
                                                                self.extended_community.name = 'extended_community'
                                                                self.extended_community_flags = None
                                                                self.is_aggregator_present = None
                                                                self.is_aigp_present = None
                                                                self.is_as_path_present = None
                                                                self.is_atomic_aggregate_present = None
                                                                self.is_community_present = None
                                                                self.is_connector_present = None
                                                                self.is_extended_community_present = None
                                                                self.is_label_index_present = None
                                                                self.is_local_pref_present = None
                                                                self.is_ls_attribute_present = None
                                                                self.is_metric_present = None
                                                                self.is_origin_present = None
                                                                self.is_pe_distinguisher_label_present = None
                                                                self.is_pmsi_present = None
                                                                self.is_pppmp_present = None
                                                                self.is_ssa_present = None
                                                                self.is_tunnel_encap_present = None
                                                                self.l2tpv3_cookie = YList()
                                                                self.l2tpv3_cookie.parent = self
                                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                                self.l2tpv3_session_id = None
                                                                self.label_index_attr = YList()
                                                                self.label_index_attr.parent = self
                                                                self.label_index_attr.name = 'label_index_attr'
                                                                self.local_preference = None
                                                                self.ls_attr = YList()
                                                                self.ls_attr.parent = self
                                                                self.ls_attr.name = 'ls_attr'
                                                                self.metric = None
                                                                self.neighbor_as = None
                                                                self.origin = None
                                                                self.originator = None
                                                                self.pe_distinguisher_label = YList()
                                                                self.pe_distinguisher_label.parent = self
                                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                                self.pmsi_flags = None
                                                                self.pmsi_label = None
                                                                self.pmsi_type = None
                                                                self.pmsi_value = YList()
                                                                self.pmsi_value.parent = self
                                                                self.pmsi_value.name = 'pmsi_value'
                                                                self.ppm_pvalue = None
                                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                                self.sr_policy_allocated_binding_sid.parent = self
                                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                                self.sr_policy_binding_sid.parent = self
                                                                self.sr_policy_explicit_path = YList()
                                                                self.sr_policy_explicit_path.parent = self
                                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                                self.sr_policy_preference = None
                                                                self.sr_tunnel_request_state = None
                                                                self.sr_tunnel_state = None
                                                                self.tunnel_encap_type = None
                                                                self.unknown_attribute = YList()
                                                                self.unknown_attribute.parent = self
                                                                self.unknown_attribute.name = 'unknown_attribute'


                                                            class SrPolicyBindingSid(object):
                                                                """
                                                                SR Policy Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_address = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                            class SrPolicyAllocatedBindingSid(object):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_address = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                            class Community(object):
                                                                """
                                                                Community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                            class ExtendedCommunity(object):
                                                                """
                                                                Extended community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                            class UnknownAttribute(object):
                                                                """
                                                                Unknown attributes
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                            class Cluster(object):
                                                                """
                                                                Cluster list attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                            class L2Tpv3Cookie(object):
                                                                """
                                                                L2TPv3 Cookie
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                            class ConnectorValue(object):
                                                                """
                                                                Connector Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                            class PmsiValue(object):
                                                                """
                                                                PMSI Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                            class LsAttr(object):
                                                                """
                                                                BGP LS attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                            class LabelIndexAttr(object):
                                                                """
                                                                Label Index attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                            class PeDistinguisherLabel(object):
                                                                """
                                                                PE distinguisher label attribute
                                                                
                                                                .. attribute:: label
                                                                
                                                                	Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pe_address
                                                                
                                                                	 PE address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.label = None
                                                                    self.pe_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.pe_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                            class SrPolicyExplicitPath(object):
                                                                """
                                                                SR Policy Explicit paths
                                                                
                                                                .. attribute:: sid
                                                                
                                                                	Sidlist for explicit path
                                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of explicit path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.sid = YList()
                                                                    self.sid.parent = self
                                                                    self.sid.name = 'sid'
                                                                    self.weight = None


                                                                class Sid(object):
                                                                    """
                                                                    Sidlist for explicit path
                                                                    
                                                                    .. attribute:: ipv4
                                                                    
                                                                    	IP Address sid
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6
                                                                    
                                                                    	IPv6 address sid
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label sid
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Sid Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4 = None
                                                                        self.ipv6 = None
                                                                        self.label = None
                                                                        self.type = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4 is not None:
                                                                            return True

                                                                        if self.ipv6 is not None:
                                                                            return True

                                                                        if self.label is not None:
                                                                            return True

                                                                        if self.type is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.sid is not None:
                                                                        for child_ref in self.sid:
                                                                            if child_ref._has_data():
                                                                                return True

                                                                    if self.weight is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.aggregator_address is not None:
                                                                    return True

                                                                if self.aggregator_as is not None:
                                                                    return True

                                                                if self.aigp_metric_value is not None:
                                                                    return True

                                                                if self.as_path is not None:
                                                                    return True

                                                                if self.cluster is not None:
                                                                    for child_ref in self.cluster:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.community is not None:
                                                                    for child_ref in self.community:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.connector_type is not None:
                                                                    return True

                                                                if self.connector_value is not None:
                                                                    for child_ref in self.connector_value:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.extended_community is not None:
                                                                    for child_ref in self.extended_community:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.extended_community_flags is not None:
                                                                    return True

                                                                if self.is_aggregator_present is not None:
                                                                    return True

                                                                if self.is_aigp_present is not None:
                                                                    return True

                                                                if self.is_as_path_present is not None:
                                                                    return True

                                                                if self.is_atomic_aggregate_present is not None:
                                                                    return True

                                                                if self.is_community_present is not None:
                                                                    return True

                                                                if self.is_connector_present is not None:
                                                                    return True

                                                                if self.is_extended_community_present is not None:
                                                                    return True

                                                                if self.is_label_index_present is not None:
                                                                    return True

                                                                if self.is_local_pref_present is not None:
                                                                    return True

                                                                if self.is_ls_attribute_present is not None:
                                                                    return True

                                                                if self.is_metric_present is not None:
                                                                    return True

                                                                if self.is_origin_present is not None:
                                                                    return True

                                                                if self.is_pe_distinguisher_label_present is not None:
                                                                    return True

                                                                if self.is_pmsi_present is not None:
                                                                    return True

                                                                if self.is_pppmp_present is not None:
                                                                    return True

                                                                if self.is_ssa_present is not None:
                                                                    return True

                                                                if self.is_tunnel_encap_present is not None:
                                                                    return True

                                                                if self.l2tpv3_cookie is not None:
                                                                    for child_ref in self.l2tpv3_cookie:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.l2tpv3_session_id is not None:
                                                                    return True

                                                                if self.label_index_attr is not None:
                                                                    for child_ref in self.label_index_attr:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.local_preference is not None:
                                                                    return True

                                                                if self.ls_attr is not None:
                                                                    for child_ref in self.ls_attr:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.metric is not None:
                                                                    return True

                                                                if self.neighbor_as is not None:
                                                                    return True

                                                                if self.origin is not None:
                                                                    return True

                                                                if self.originator is not None:
                                                                    return True

                                                                if self.pe_distinguisher_label is not None:
                                                                    for child_ref in self.pe_distinguisher_label:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.pmsi_flags is not None:
                                                                    return True

                                                                if self.pmsi_label is not None:
                                                                    return True

                                                                if self.pmsi_type is not None:
                                                                    return True

                                                                if self.pmsi_value is not None:
                                                                    for child_ref in self.pmsi_value:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.ppm_pvalue is not None:
                                                                    return True

                                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                                    return True

                                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                                    return True

                                                                if self.sr_policy_explicit_path is not None:
                                                                    for child_ref in self.sr_policy_explicit_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.sr_policy_preference is not None:
                                                                    return True

                                                                if self.sr_tunnel_request_state is not None:
                                                                    return True

                                                                if self.sr_tunnel_state is not None:
                                                                    return True

                                                                if self.tunnel_encap_type is not None:
                                                                    return True

                                                                if self.unknown_attribute is not None:
                                                                    for child_ref in self.unknown_attribute:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                                        class AttrSet(object):
                                                            """
                                                            ATTR\_SET attribute
                                                            
                                                            .. attribute:: aggregator_address
                                                            
                                                            	Address where aggregation was performed
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: aggregator_as
                                                            
                                                            	AS where aggregation was last performed
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: aigp_metric_value
                                                            
                                                            	AIGP metric value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..18446744073709551615
                                                            
                                                            .. attribute:: as_path
                                                            
                                                            	AS path attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: cluster
                                                            
                                                            	Cluster list attribute
                                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                            
                                                            .. attribute:: community
                                                            
                                                            	Community attribute
                                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                            
                                                            .. attribute:: connector_type
                                                            
                                                            	Connector Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: connector_value
                                                            
                                                            	Connector Value
                                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                            
                                                            .. attribute:: extended_community
                                                            
                                                            	Extended community attribute
                                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                            
                                                            .. attribute:: extended_community_flags
                                                            
                                                            	Extended community Flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: is_aggregator_present
                                                            
                                                            	Aggregator attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_aigp_present
                                                            
                                                            	AIGP Present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_as_path_present
                                                            
                                                            	AS path attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_atomic_aggregate_present
                                                            
                                                            	Atomic aggregate attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_community_present
                                                            
                                                            	Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_connector_present
                                                            
                                                            	Connector present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_extended_community_present
                                                            
                                                            	Extended community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_label_index_present
                                                            
                                                            	Label Index attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_local_pref_present
                                                            
                                                            	Local Preference attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ls_attribute_present
                                                            
                                                            	BGP LS attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_metric_present
                                                            
                                                            	Metric attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_origin_present
                                                            
                                                            	Origin attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pe_distinguisher_label_present
                                                            
                                                            	PE distinguisher label  attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pmsi_present
                                                            
                                                            	PMSI Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pppmp_present
                                                            
                                                            	PPMP Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ssa_present
                                                            
                                                            	SSA attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_encap_present
                                                            
                                                            	Tunnel Encap attribute present 
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: l2tpv3_cookie
                                                            
                                                            	L2TPv3 Cookie
                                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                            
                                                            .. attribute:: l2tpv3_session_id
                                                            
                                                            	L2TPv3 session id
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: label_index_attr
                                                            
                                                            	Label Index attribute
                                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                            
                                                            .. attribute:: local_preference
                                                            
                                                            	Local preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ls_attr
                                                            
                                                            	BGP LS attribute
                                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	Metric
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: neighbor_as
                                                            
                                                            	Neighbor AS number
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: origin
                                                            
                                                            	Origin
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: originator
                                                            
                                                            	Originator attribute
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: pe_distinguisher_label
                                                            
                                                            	PE distinguisher label attribute
                                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                            
                                                            .. attribute:: pmsi_flags
                                                            
                                                            	PMSI Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pmsi_label
                                                            
                                                            	PMSI label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pmsi_type
                                                            
                                                            	PMSI Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: pmsi_value
                                                            
                                                            	PMSI Value
                                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                            
                                                            .. attribute:: ppm_pvalue
                                                            
                                                            	PPMP Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: sr_policy_allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                            
                                                            .. attribute:: sr_policy_binding_sid
                                                            
                                                            	SR Policy Binding sid
                                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                            
                                                            .. attribute:: sr_policy_explicit_path
                                                            
                                                            	SR Policy Explicit paths
                                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                            
                                                            .. attribute:: sr_policy_preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: sr_tunnel_request_state
                                                            
                                                            	SR Tunnel Request State
                                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                            
                                                            .. attribute:: sr_tunnel_state
                                                            
                                                            	SR Tunnel State
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encap Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: unknown_attribute
                                                            
                                                            	Unknown attributes
                                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.aggregator_address = None
                                                                self.aggregator_as = None
                                                                self.aigp_metric_value = None
                                                                self.as_path = None
                                                                self.cluster = YList()
                                                                self.cluster.parent = self
                                                                self.cluster.name = 'cluster'
                                                                self.community = YList()
                                                                self.community.parent = self
                                                                self.community.name = 'community'
                                                                self.connector_type = None
                                                                self.connector_value = YList()
                                                                self.connector_value.parent = self
                                                                self.connector_value.name = 'connector_value'
                                                                self.extended_community = YList()
                                                                self.extended_community.parent = self
                                                                self.extended_community.name = 'extended_community'
                                                                self.extended_community_flags = None
                                                                self.is_aggregator_present = None
                                                                self.is_aigp_present = None
                                                                self.is_as_path_present = None
                                                                self.is_atomic_aggregate_present = None
                                                                self.is_community_present = None
                                                                self.is_connector_present = None
                                                                self.is_extended_community_present = None
                                                                self.is_label_index_present = None
                                                                self.is_local_pref_present = None
                                                                self.is_ls_attribute_present = None
                                                                self.is_metric_present = None
                                                                self.is_origin_present = None
                                                                self.is_pe_distinguisher_label_present = None
                                                                self.is_pmsi_present = None
                                                                self.is_pppmp_present = None
                                                                self.is_ssa_present = None
                                                                self.is_tunnel_encap_present = None
                                                                self.l2tpv3_cookie = YList()
                                                                self.l2tpv3_cookie.parent = self
                                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                                self.l2tpv3_session_id = None
                                                                self.label_index_attr = YList()
                                                                self.label_index_attr.parent = self
                                                                self.label_index_attr.name = 'label_index_attr'
                                                                self.local_preference = None
                                                                self.ls_attr = YList()
                                                                self.ls_attr.parent = self
                                                                self.ls_attr.name = 'ls_attr'
                                                                self.metric = None
                                                                self.neighbor_as = None
                                                                self.origin = None
                                                                self.originator = None
                                                                self.pe_distinguisher_label = YList()
                                                                self.pe_distinguisher_label.parent = self
                                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                                self.pmsi_flags = None
                                                                self.pmsi_label = None
                                                                self.pmsi_type = None
                                                                self.pmsi_value = YList()
                                                                self.pmsi_value.parent = self
                                                                self.pmsi_value.name = 'pmsi_value'
                                                                self.ppm_pvalue = None
                                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                                self.sr_policy_allocated_binding_sid.parent = self
                                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                                self.sr_policy_binding_sid.parent = self
                                                                self.sr_policy_explicit_path = YList()
                                                                self.sr_policy_explicit_path.parent = self
                                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                                self.sr_policy_preference = None
                                                                self.sr_tunnel_request_state = None
                                                                self.sr_tunnel_state = None
                                                                self.tunnel_encap_type = None
                                                                self.unknown_attribute = YList()
                                                                self.unknown_attribute.parent = self
                                                                self.unknown_attribute.name = 'unknown_attribute'


                                                            class SrPolicyBindingSid(object):
                                                                """
                                                                SR Policy Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_address = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                            class SrPolicyAllocatedBindingSid(object):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_address = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                            class Community(object):
                                                                """
                                                                Community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                            class ExtendedCommunity(object):
                                                                """
                                                                Extended community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                            class UnknownAttribute(object):
                                                                """
                                                                Unknown attributes
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                            class Cluster(object):
                                                                """
                                                                Cluster list attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                            class L2Tpv3Cookie(object):
                                                                """
                                                                L2TPv3 Cookie
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                            class ConnectorValue(object):
                                                                """
                                                                Connector Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                            class PmsiValue(object):
                                                                """
                                                                PMSI Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                            class LsAttr(object):
                                                                """
                                                                BGP LS attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                            class LabelIndexAttr(object):
                                                                """
                                                                Label Index attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                            class PeDistinguisherLabel(object):
                                                                """
                                                                PE distinguisher label attribute
                                                                
                                                                .. attribute:: label
                                                                
                                                                	Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pe_address
                                                                
                                                                	 PE address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.label = None
                                                                    self.pe_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.pe_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                            class SrPolicyExplicitPath(object):
                                                                """
                                                                SR Policy Explicit paths
                                                                
                                                                .. attribute:: sid
                                                                
                                                                	Sidlist for explicit path
                                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of explicit path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.sid = YList()
                                                                    self.sid.parent = self
                                                                    self.sid.name = 'sid'
                                                                    self.weight = None


                                                                class Sid(object):
                                                                    """
                                                                    Sidlist for explicit path
                                                                    
                                                                    .. attribute:: ipv4
                                                                    
                                                                    	IP Address sid
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6
                                                                    
                                                                    	IPv6 address sid
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label sid
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Sid Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4 = None
                                                                        self.ipv6 = None
                                                                        self.label = None
                                                                        self.type = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4 is not None:
                                                                            return True

                                                                        if self.ipv6 is not None:
                                                                            return True

                                                                        if self.label is not None:
                                                                            return True

                                                                        if self.type is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.sid is not None:
                                                                        for child_ref in self.sid:
                                                                            if child_ref._has_data():
                                                                                return True

                                                                    if self.weight is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.aggregator_address is not None:
                                                                    return True

                                                                if self.aggregator_as is not None:
                                                                    return True

                                                                if self.aigp_metric_value is not None:
                                                                    return True

                                                                if self.as_path is not None:
                                                                    return True

                                                                if self.cluster is not None:
                                                                    for child_ref in self.cluster:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.community is not None:
                                                                    for child_ref in self.community:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.connector_type is not None:
                                                                    return True

                                                                if self.connector_value is not None:
                                                                    for child_ref in self.connector_value:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.extended_community is not None:
                                                                    for child_ref in self.extended_community:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.extended_community_flags is not None:
                                                                    return True

                                                                if self.is_aggregator_present is not None:
                                                                    return True

                                                                if self.is_aigp_present is not None:
                                                                    return True

                                                                if self.is_as_path_present is not None:
                                                                    return True

                                                                if self.is_atomic_aggregate_present is not None:
                                                                    return True

                                                                if self.is_community_present is not None:
                                                                    return True

                                                                if self.is_connector_present is not None:
                                                                    return True

                                                                if self.is_extended_community_present is not None:
                                                                    return True

                                                                if self.is_label_index_present is not None:
                                                                    return True

                                                                if self.is_local_pref_present is not None:
                                                                    return True

                                                                if self.is_ls_attribute_present is not None:
                                                                    return True

                                                                if self.is_metric_present is not None:
                                                                    return True

                                                                if self.is_origin_present is not None:
                                                                    return True

                                                                if self.is_pe_distinguisher_label_present is not None:
                                                                    return True

                                                                if self.is_pmsi_present is not None:
                                                                    return True

                                                                if self.is_pppmp_present is not None:
                                                                    return True

                                                                if self.is_ssa_present is not None:
                                                                    return True

                                                                if self.is_tunnel_encap_present is not None:
                                                                    return True

                                                                if self.l2tpv3_cookie is not None:
                                                                    for child_ref in self.l2tpv3_cookie:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.l2tpv3_session_id is not None:
                                                                    return True

                                                                if self.label_index_attr is not None:
                                                                    for child_ref in self.label_index_attr:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.local_preference is not None:
                                                                    return True

                                                                if self.ls_attr is not None:
                                                                    for child_ref in self.ls_attr:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.metric is not None:
                                                                    return True

                                                                if self.neighbor_as is not None:
                                                                    return True

                                                                if self.origin is not None:
                                                                    return True

                                                                if self.originator is not None:
                                                                    return True

                                                                if self.pe_distinguisher_label is not None:
                                                                    for child_ref in self.pe_distinguisher_label:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.pmsi_flags is not None:
                                                                    return True

                                                                if self.pmsi_label is not None:
                                                                    return True

                                                                if self.pmsi_type is not None:
                                                                    return True

                                                                if self.pmsi_value is not None:
                                                                    for child_ref in self.pmsi_value:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.ppm_pvalue is not None:
                                                                    return True

                                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                                    return True

                                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                                    return True

                                                                if self.sr_policy_explicit_path is not None:
                                                                    for child_ref in self.sr_policy_explicit_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.sr_policy_preference is not None:
                                                                    return True

                                                                if self.sr_tunnel_request_state is not None:
                                                                    return True

                                                                if self.sr_tunnel_state is not None:
                                                                    return True

                                                                if self.tunnel_encap_type is not None:
                                                                    return True

                                                                if self.unknown_attribute is not None:
                                                                    for child_ref in self.unknown_attribute:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                                        class RnhAddr(object):
                                                            """
                                                            RNH Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                            
                                                            .. attribute:: mac_address
                                                            
                                                            	MAC Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self.len = None
                                                                self.mac_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.len is not None:
                                                                    return True

                                                                if self.mac_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                                        class RibrnhIp(object):
                                                            """
                                                            RIB RNH IP Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.attr_set is not None and self.attr_set._has_data():
                                                                return True

                                                            if self.attribute_key_number is not None:
                                                                return True

                                                            if self.attribute_reuse_id_config is not None:
                                                                return True

                                                            if self.attribute_reuse_id_current is not None:
                                                                return True

                                                            if self.attribute_reuse_id_keys is not None:
                                                                return True

                                                            if self.attribute_reuse_id_max_id is not None:
                                                                return True

                                                            if self.attribute_reuse_id_node is not None:
                                                                return True

                                                            if self.attribute_reuse_id_recover_sec is not None:
                                                                return True

                                                            if self.common_attributes is not None and self.common_attributes._has_data():
                                                                return True

                                                            if self.is_application_gateway_present is not None:
                                                                return True

                                                            if self.is_as_path2_byte is not None:
                                                                return True

                                                            if self.is_attr_set_present is not None:
                                                                return True

                                                            if self.is_ribrnh_present is not None:
                                                                return True

                                                            if self.is_rnh_present is not None:
                                                                return True

                                                            if self.ribrnh_encap is not None:
                                                                return True

                                                            if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                                return True

                                                            if self.ribrnh_mac is not None:
                                                                return True

                                                            if self.ribrnh_table is not None:
                                                                return True

                                                            if self.ribrnh_vni is not None:
                                                                return True

                                                            if self.ribrnhip_table is not None:
                                                                return True

                                                            if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                                return True

                                                            if self.rnh_addr_len is not None:
                                                                return True

                                                            if self.rnh_len is not None:
                                                                return True

                                                            if self.rnh_type is not None:
                                                                return True

                                                            if self.set_aigp_inbound_igp is not None:
                                                                return True

                                                            if self.set_aigp_inbound_metric is not None:
                                                                return True

                                                            if self.vpn_distinguisher is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-process-instance-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.af_name is not None:
                                                            return True

                                                        if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                            return True

                                                        if self.label_fail is not None:
                                                            return True

                                                        if self.label_o_or_version is not None:
                                                            return True

                                                        if self.label_oor is not None:
                                                            return True

                                                        if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                            return True

                                                        if self.no_path is not None:
                                                            return True

                                                        if self.path_information is not None and self.path_information._has_data():
                                                            return True

                                                        if self.prefix_version is not None:
                                                            return True

                                                        if self.process_instance_id is not None:
                                                            return True

                                                        if self.route_distinguisher is not None:
                                                            return True

                                                        if self.source_route_distinguisher is not None:
                                                            return True

                                                        if self.source_vrf_name is not None:
                                                            return True

                                                        if self.srcaf_name is not None:
                                                            return True

                                                        if self.vrf_name is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath']['meta_info']


                                                class ActiveProcessInstancePath(object):
                                                    """
                                                    Active's paths for this net 
                                                    
                                                    .. attribute:: af_name
                                                    
                                                    	Address family identifier
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: attributes_after_policy_in
                                                    
                                                    	Attributes after inbound policy applied
                                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn>`
                                                    
                                                    .. attribute:: label_fail
                                                    
                                                    	LSD label allocation failed 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: label_o_or_version
                                                    
                                                    	Label Version when OOR happens
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_oor
                                                    
                                                    	LSD label space is exhausted
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address_xr
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr>`
                                                    
                                                    .. attribute:: no_path
                                                    
                                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: path_information
                                                    
                                                    	Path information
                                                    	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation>`
                                                    
                                                    .. attribute:: prefix_version
                                                    
                                                    	Version of BGP Prefix Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: process_instance_id
                                                    
                                                    	Process instance ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: route_distinguisher
                                                    
                                                    	Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: source_route_distinguisher
                                                    
                                                    	Source Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: source_vrf_name
                                                    
                                                    	Name of the source VRF
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: srcaf_name
                                                    
                                                    	Address family identifier
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: vrf_name
                                                    
                                                    	Name of the VRF
                                                    	**type**\:  str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.af_name = None
                                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn()
                                                        self.attributes_after_policy_in.parent = self
                                                        self.label_fail = None
                                                        self.label_o_or_version = None
                                                        self.label_oor = None
                                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr()
                                                        self.neighbor_address_xr.parent = self
                                                        self.no_path = None
                                                        self.path_information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation()
                                                        self.path_information.parent = self
                                                        self.prefix_version = None
                                                        self.process_instance_id = None
                                                        self.route_distinguisher = None
                                                        self.source_route_distinguisher = None
                                                        self.source_vrf_name = None
                                                        self.srcaf_name = None
                                                        self.vrf_name = None


                                                    class NeighborAddressXr(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr']['meta_info']


                                                    class PathInformation(object):
                                                        """
                                                        Path information
                                                        
                                                        .. attribute:: accept_own_path
                                                        
                                                        	Accept Own
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: accept_own_self_originated_p_ath
                                                        
                                                        	Accept\-Own self\-originated
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: add_path_orr_bitfield
                                                        
                                                        	ORR Add path Bitfields
                                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                        
                                                        .. attribute:: advertisedto_pe
                                                        
                                                        	Net could be advertised                          to PE peers
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: aigp_metric
                                                        
                                                        	Total AIGP metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: best_path_comp_stage
                                                        
                                                        	Stage where the path lost to the best path or group best
                                                        	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                                        
                                                        .. attribute:: best_path_comp_winner
                                                        
                                                        	Neighbor address of the path which won best path comparison
                                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                        
                                                        .. attribute:: best_path_id
                                                        
                                                        	Best path ID; DEPRECATED BYLocalPathId
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: best_path_id_comp_winner
                                                        
                                                        	Path ID of the path which won best path comparison
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: best_path_orr_bitfield
                                                        
                                                        	ORR Best path Bitfields
                                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                        
                                                        .. attribute:: bgp_prefix
                                                        
                                                        	BGP prefix
                                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix>`
                                                        
                                                        .. attribute:: dampen_penalty
                                                        
                                                        	Dampening penalty
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Mvpn Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                        
                                                        .. attribute:: fspec_invalid_path
                                                        
                                                        	Is Fspec invalid path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: graceful_shutdown
                                                        
                                                        	Marked for graceful shutdown
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: gw_addr
                                                        
                                                        	Path GW Address
                                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.GwAddr>`
                                                        
                                                        .. attribute:: halflife_time
                                                        
                                                        	Half\-life time for the penalty
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_esi
                                                        
                                                        	Path has EVPN ESI
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_gw_addr
                                                        
                                                        	Path has GW Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_local_net_label
                                                        
                                                        	Path has local label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mdt_group_addr
                                                        
                                                        	Path has MDT Group Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_extcomm
                                                        
                                                        	Path has MVPN EXTCOMM feedback
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_nbr_addr
                                                        
                                                        	Path has Mvpn nbr Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_nexthop_addr
                                                        
                                                        	Path has MVPN nexthop Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_pmsi
                                                        
                                                        	Path has MVPN PMSI feedback
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_rcvd_label
                                                        
                                                        	Path has received label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_second_label
                                                        
                                                        	Path has second received label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: ibgp_signaled_validity
                                                        
                                                        	IBGP signalled validation
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: igp_metric
                                                        
                                                        	IGP metric to the gateway
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: is_aggregation_suppressed
                                                        
                                                        	Path suppressed due to aggregation
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_best
                                                        
                                                        	Best available path within AS
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_best_path
                                                        
                                                        	Best available path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_import_dampened
                                                        
                                                        	net import dampened
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_import_suspect
                                                        
                                                        	net import suspect
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_internal_path
                                                        
                                                        	Received over an internal link
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_partial_best
                                                        
                                                        	Partial best path within distributed speaker
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_additional_path
                                                        
                                                        	Path is an additional\-path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_advertised_local_as_only
                                                        
                                                        	Not advertised outside local AS
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_af_install_eligible
                                                        
                                                        	Path can be installed in AF RIB
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_backup
                                                        
                                                        	Path is a backup path 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_backup_protect_multipath
                                                        
                                                        	Path is a backup path to protect multipaths
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_best_external
                                                        
                                                        	Path is a best external path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_damped
                                                        
                                                        	Path suppressed due to dampening
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_confederation_peer
                                                        
                                                        	Path received from confederation peer
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_network_command
                                                        
                                                        	Path sourced by network command
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_redistribute_command
                                                        
                                                        	Path sourced by redistribute command
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_route_reflector
                                                        
                                                        	Path received from route reflector
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_history_held
                                                        
                                                        	Path entry held to remember history
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_imp_candidate
                                                        
                                                        	Path is a candidate for multipath import
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_imported
                                                        
                                                        	Path is imported
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_local_aggregate
                                                        
                                                        	Path is a locally created aggregate
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_locally_sourced
                                                        
                                                        	Path sourced locally
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_long_lived_stale
                                                        
                                                        	Long lived stale routes learnt before neighbor restarts
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_multipath
                                                        
                                                        	Path is one of multipath best routes
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_nexthop_discarded
                                                        
                                                        	Path is redirected to Null0
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_not_advertised
                                                        
                                                        	Not advertised to any peer
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_not_advertised_to_ebg_ps
                                                        
                                                        	Not advertised to EBGPs
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_received_only
                                                        
                                                        	Path is received only
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_reoriginated
                                                        
                                                        	Path is reoriginated
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_reoriginated_stitching
                                                        
                                                        	Path is reoriginated with stitching RTs
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_stale
                                                        
                                                        	Stale routes learnt before neighbor restarts
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_synced_with_igp
                                                        
                                                        	Path synchronized with IGP
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_valid
                                                        
                                                        	Path attributes are usable
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_vpn_only
                                                        
                                                        	Path is not in the vrf
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_permanent_path
                                                        
                                                        	Path is of type Permanent path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_received_path_not_modified
                                                        
                                                        	Received path used without modification
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_spkr_as_best
                                                        
                                                        	Best available path within AS in speaker
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2vpn_circuit_status_value
                                                        
                                                        	L2VPN Circuit Status Value
                                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                        
                                                        .. attribute:: l2vpn_evpn_esi
                                                        
                                                        	L2VPN EVPN ESI
                                                        	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi>`
                                                        
                                                        .. attribute:: l2vpn_size
                                                        
                                                        	Path block size
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: labeled_unicast_safi_path
                                                        
                                                        	Path was learnt by labeled\-unicast SAFI
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: local_label
                                                        
                                                        	Path local label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_nh
                                                        
                                                        	Path has local nexthop
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: local_path_id
                                                        
                                                        	Local path ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_peers_advertised_to
                                                        
                                                        	Local peers that this prefix has been advertised to
                                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                        
                                                        .. attribute:: maximum_suppress_time
                                                        
                                                        	Maximum duration to suppress a stable route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mdt_group_addr
                                                        
                                                        	IPv4 MDT Group Address for the path
                                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                        
                                                        .. attribute:: mvpn_nbr_addr
                                                        
                                                        	Mvpn nbr Address for the path
                                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                        
                                                        .. attribute:: mvpn_nexthop_addr
                                                        
                                                        	Mvpn nexthop Address for the path
                                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                        
                                                        .. attribute:: mvpn_path_flags
                                                        
                                                        	Mvpn path flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: mvpn_pmsi_flags
                                                        
                                                        	Mvpn PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: mvpn_pmsi_label
                                                        
                                                        	Mvpn PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mvpn_pmsi_type
                                                        
                                                        	Mvpn PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: mvpn_pmsi_value
                                                        
                                                        	Mvpn PMSI Value
                                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                        
                                                        .. attribute:: mvpn_sfs_path
                                                        
                                                        	Is MVPN single forwarder PE path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress>`
                                                        
                                                        .. attribute:: neighbor_router_id
                                                        
                                                        	Router ID of the neighbor for the path
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: next_hop
                                                        
                                                        	Next hop
                                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop>`
                                                        
                                                        .. attribute:: nhte_tunnel
                                                        
                                                        	NH TE tunnel information
                                                        	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhteTunnel>`
                                                        
                                                        .. attribute:: path_flags
                                                        
                                                        	Flags associated with path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: path_flap_count
                                                        
                                                        	Number of times this route has flapped
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_import_flags
                                                        
                                                        	Path import flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_rt_set_id
                                                        
                                                        	RT\-set id of the path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_rt_set_route_count
                                                        
                                                        	Count in RT\-set
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_table_version
                                                        
                                                        	Table version # for pelem
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_weight
                                                        
                                                        	Weight for the path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pe_peers_advertised_to
                                                        
                                                        	PE peers that this prefix has been advertised to
                                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                        
                                                        .. attribute:: rcvd_label
                                                        
                                                        	Path received label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rcvd_path_id
                                                        
                                                        	Received path ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: reuse_value
                                                        
                                                        	Value to start reusing a route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rib_failed
                                                        
                                                        	Is net failed installed                          in RIB
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route Type of path
                                                        	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                                        
                                                        .. attribute:: rpki_origin_as_validation_disabled
                                                        
                                                        	RPKI originAS V. Disabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: rt_set_limit_enabled
                                                        
                                                        	Path subject to RT\-set net limit
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: second_label
                                                        
                                                        	Path second received label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: seconds_since_first_flap
                                                        
                                                        	Seconds since route first flapped
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: show_rpki_origin_as_validity
                                                        
                                                        	Display validity state ?
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: sn_rpki_origin_as_validity
                                                        
                                                        	RPKI origin validation state
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: suppress_penalty
                                                        
                                                        	Value to start suppressing a route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: time_to_unsuppress
                                                        
                                                        	Seconds until route is unsuppressed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.accept_own_path = None
                                                            self.accept_own_self_originated_p_ath = None
                                                            self.add_path_orr_bitfield = YList()
                                                            self.add_path_orr_bitfield.parent = self
                                                            self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                            self.advertisedto_pe = None
                                                            self.aigp_metric = None
                                                            self.best_path_comp_stage = None
                                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner()
                                                            self.best_path_comp_winner.parent = self
                                                            self.best_path_id = None
                                                            self.best_path_id_comp_winner = None
                                                            self.best_path_orr_bitfield = YList()
                                                            self.best_path_orr_bitfield.parent = self
                                                            self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix()
                                                            self.bgp_prefix.parent = self
                                                            self.dampen_penalty = None
                                                            self.extended_community = YList()
                                                            self.extended_community.parent = self
                                                            self.extended_community.name = 'extended_community'
                                                            self.fspec_invalid_path = None
                                                            self.graceful_shutdown = None
                                                            self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.GwAddr()
                                                            self.gw_addr.parent = self
                                                            self.halflife_time = None
                                                            self.has_esi = None
                                                            self.has_gw_addr = None
                                                            self.has_local_net_label = None
                                                            self.has_mdt_group_addr = None
                                                            self.has_mvpn_extcomm = None
                                                            self.has_mvpn_nbr_addr = None
                                                            self.has_mvpn_nexthop_addr = None
                                                            self.has_mvpn_pmsi = None
                                                            self.has_rcvd_label = None
                                                            self.has_second_label = None
                                                            self.ibgp_signaled_validity = None
                                                            self.igp_metric = None
                                                            self.is_aggregation_suppressed = None
                                                            self.is_as_best = None
                                                            self.is_best_path = None
                                                            self.is_import_dampened = None
                                                            self.is_import_suspect = None
                                                            self.is_internal_path = None
                                                            self.is_partial_best = None
                                                            self.is_path_additional_path = None
                                                            self.is_path_advertised_local_as_only = None
                                                            self.is_path_af_install_eligible = None
                                                            self.is_path_backup = None
                                                            self.is_path_backup_protect_multipath = None
                                                            self.is_path_best_external = None
                                                            self.is_path_damped = None
                                                            self.is_path_from_confederation_peer = None
                                                            self.is_path_from_network_command = None
                                                            self.is_path_from_redistribute_command = None
                                                            self.is_path_from_route_reflector = None
                                                            self.is_path_history_held = None
                                                            self.is_path_imp_candidate = None
                                                            self.is_path_imported = None
                                                            self.is_path_local_aggregate = None
                                                            self.is_path_locally_sourced = None
                                                            self.is_path_long_lived_stale = None
                                                            self.is_path_multipath = None
                                                            self.is_path_nexthop_discarded = None
                                                            self.is_path_not_advertised = None
                                                            self.is_path_not_advertised_to_ebg_ps = None
                                                            self.is_path_received_only = None
                                                            self.is_path_reoriginated = None
                                                            self.is_path_reoriginated_stitching = None
                                                            self.is_path_stale = None
                                                            self.is_path_synced_with_igp = None
                                                            self.is_path_valid = None
                                                            self.is_path_vpn_only = None
                                                            self.is_permanent_path = None
                                                            self.is_received_path_not_modified = None
                                                            self.is_spkr_as_best = None
                                                            self.l2vpn_circuit_status_value = YList()
                                                            self.l2vpn_circuit_status_value.parent = self
                                                            self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                            self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi()
                                                            self.l2vpn_evpn_esi.parent = self
                                                            self.l2vpn_size = None
                                                            self.labeled_unicast_safi_path = None
                                                            self.local_label = None
                                                            self.local_nh = None
                                                            self.local_path_id = None
                                                            self.local_peers_advertised_to = YList()
                                                            self.local_peers_advertised_to.parent = self
                                                            self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                            self.maximum_suppress_time = None
                                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr()
                                                            self.mdt_group_addr.parent = self
                                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                            self.mvpn_nbr_addr.parent = self
                                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                            self.mvpn_nexthop_addr.parent = self
                                                            self.mvpn_path_flags = None
                                                            self.mvpn_pmsi_flags = None
                                                            self.mvpn_pmsi_label = None
                                                            self.mvpn_pmsi_type = None
                                                            self.mvpn_pmsi_value = YList()
                                                            self.mvpn_pmsi_value.parent = self
                                                            self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                            self.mvpn_sfs_path = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.neighbor_router_id = None
                                                            self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop()
                                                            self.next_hop.parent = self
                                                            self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhteTunnel()
                                                            self.nhte_tunnel.parent = self
                                                            self.path_flags = None
                                                            self.path_flap_count = None
                                                            self.path_import_flags = None
                                                            self.path_rt_set_id = None
                                                            self.path_rt_set_route_count = None
                                                            self.path_table_version = None
                                                            self.path_weight = None
                                                            self.pe_peers_advertised_to = YList()
                                                            self.pe_peers_advertised_to.parent = self
                                                            self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                            self.rcvd_label = None
                                                            self.rcvd_path_id = None
                                                            self.reuse_value = None
                                                            self.rib_failed = None
                                                            self.route_type = None
                                                            self.rpki_origin_as_validation_disabled = None
                                                            self.rt_set_limit_enabled = None
                                                            self.second_label = None
                                                            self.seconds_since_first_flap = None
                                                            self.show_rpki_origin_as_validity = None
                                                            self.sn_rpki_origin_as_validity = None
                                                            self.suppress_penalty = None
                                                            self.time_to_unsuppress = None


                                                        class BgpPrefix(object):
                                                            """
                                                            BGP prefix
                                                            
                                                            .. attribute:: prefix
                                                            
                                                            	Prefix
                                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                            
                                                            .. attribute:: prefix_length
                                                            
                                                            	Prefix length
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                                self.prefix.parent = self
                                                                self.prefix_length = None


                                                            class Prefix(object):
                                                                """
                                                                Prefix
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.prefix is not None and self.prefix._has_data():
                                                                    return True

                                                                if self.prefix_length is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix']['meta_info']


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress']['meta_info']


                                                        class NextHop(object):
                                                            """
                                                            Next hop
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop']['meta_info']


                                                        class NhteTunnel(object):
                                                            """
                                                            NH TE tunnel information
                                                            
                                                            .. attribute:: binding_label
                                                            
                                                            	Binding label for the tunnel
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: has_te_tunnel
                                                            
                                                            	NH TE Tunnel info is present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_info_stale
                                                            
                                                            	Tunnel is stale
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_registered
                                                            
                                                            	Tunnel registered flag
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_up
                                                            
                                                            	Tunnel Up flag
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: last_tunnel_update
                                                            
                                                            	Time since the last rib update happened
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_if_handle
                                                            
                                                            	Interface handle for the tunnel
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_name
                                                            
                                                            	tunnel name
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            .. attribute:: tunnel_type
                                                            
                                                            	tunnel type
                                                            	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                            
                                                            .. attribute:: tunnel_v6_enabled
                                                            
                                                            	IPv6 enabled
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_v6_required
                                                            
                                                            	Tunnel need IPv6
                                                            	**type**\:  bool
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.binding_label = None
                                                                self.has_te_tunnel = None
                                                                self.is_tunnel_info_stale = None
                                                                self.is_tunnel_registered = None
                                                                self.is_tunnel_up = None
                                                                self.last_tunnel_update = None
                                                                self.tunnel_if_handle = None
                                                                self.tunnel_name = None
                                                                self.tunnel_type = None
                                                                self.tunnel_v6_enabled = None
                                                                self.tunnel_v6_required = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.binding_label is not None:
                                                                    return True

                                                                if self.has_te_tunnel is not None:
                                                                    return True

                                                                if self.is_tunnel_info_stale is not None:
                                                                    return True

                                                                if self.is_tunnel_registered is not None:
                                                                    return True

                                                                if self.is_tunnel_up is not None:
                                                                    return True

                                                                if self.last_tunnel_update is not None:
                                                                    return True

                                                                if self.tunnel_if_handle is not None:
                                                                    return True

                                                                if self.tunnel_name is not None:
                                                                    return True

                                                                if self.tunnel_type is not None:
                                                                    return True

                                                                if self.tunnel_v6_enabled is not None:
                                                                    return True

                                                                if self.tunnel_v6_required is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhteTunnel']['meta_info']


                                                        class MdtGroupAddr(object):
                                                            """
                                                            IPv4 MDT Group Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr']['meta_info']


                                                        class L2VpnEvpnEsi(object):
                                                            """
                                                            L2VPN EVPN ESI
                                                            
                                                            .. attribute:: esi
                                                            
                                                            	esi
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.esi = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.esi is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi']['meta_info']


                                                        class GwAddr(object):
                                                            """
                                                            Path GW Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self.len = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.len is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.GwAddr']['meta_info']


                                                        class BestPathCompWinner(object):
                                                            """
                                                            Neighbor address of the path which won best path
                                                            comparison
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner']['meta_info']


                                                        class MvpnNbrAddr(object):
                                                            """
                                                            Mvpn nbr Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr']['meta_info']


                                                        class MvpnNexthopAddr(object):
                                                            """
                                                            Mvpn nexthop Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr']['meta_info']


                                                        class L2VpnCircuitStatusValue(object):
                                                            """
                                                            L2VPN Circuit Status Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                                        class MvpnPmsiValue(object):
                                                            """
                                                            Mvpn PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue']['meta_info']


                                                        class ExtendedCommunity(object):
                                                            """
                                                            Mvpn Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity']['meta_info']


                                                        class LocalPeersAdvertisedTo(object):
                                                            """
                                                            Local peers that this prefix has been advertised
                                                            to
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.is_neighbor = None
                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self.update_group_number = None


                                                            class NeighborAddress(object):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.is_neighbor is not None:
                                                                    return True

                                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                    return True

                                                                if self.update_group_number is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                                        class PePeersAdvertisedTo(object):
                                                            """
                                                            PE peers that this prefix has been advertised to
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.is_neighbor = None
                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self.update_group_number = None


                                                            class NeighborAddress(object):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.is_neighbor is not None:
                                                                    return True

                                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                    return True

                                                                if self.update_group_number is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo']['meta_info']


                                                        class BestPathOrrBitfield(object):
                                                            """
                                                            ORR Best path Bitfields
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.is_neighbor = None
                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self.update_group_number = None


                                                            class NeighborAddress(object):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.is_neighbor is not None:
                                                                    return True

                                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                    return True

                                                                if self.update_group_number is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield']['meta_info']


                                                        class AddPathOrrBitfield(object):
                                                            """
                                                            ORR Add path Bitfields
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.is_neighbor = None
                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self.update_group_number = None


                                                            class NeighborAddress(object):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.is_neighbor is not None:
                                                                    return True

                                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                    return True

                                                                if self.update_group_number is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.accept_own_path is not None:
                                                                return True

                                                            if self.accept_own_self_originated_p_ath is not None:
                                                                return True

                                                            if self.add_path_orr_bitfield is not None:
                                                                for child_ref in self.add_path_orr_bitfield:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.advertisedto_pe is not None:
                                                                return True

                                                            if self.aigp_metric is not None:
                                                                return True

                                                            if self.best_path_comp_stage is not None:
                                                                return True

                                                            if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                                return True

                                                            if self.best_path_id is not None:
                                                                return True

                                                            if self.best_path_id_comp_winner is not None:
                                                                return True

                                                            if self.best_path_orr_bitfield is not None:
                                                                for child_ref in self.best_path_orr_bitfield:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                                return True

                                                            if self.dampen_penalty is not None:
                                                                return True

                                                            if self.extended_community is not None:
                                                                for child_ref in self.extended_community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.fspec_invalid_path is not None:
                                                                return True

                                                            if self.graceful_shutdown is not None:
                                                                return True

                                                            if self.gw_addr is not None and self.gw_addr._has_data():
                                                                return True

                                                            if self.halflife_time is not None:
                                                                return True

                                                            if self.has_esi is not None:
                                                                return True

                                                            if self.has_gw_addr is not None:
                                                                return True

                                                            if self.has_local_net_label is not None:
                                                                return True

                                                            if self.has_mdt_group_addr is not None:
                                                                return True

                                                            if self.has_mvpn_extcomm is not None:
                                                                return True

                                                            if self.has_mvpn_nbr_addr is not None:
                                                                return True

                                                            if self.has_mvpn_nexthop_addr is not None:
                                                                return True

                                                            if self.has_mvpn_pmsi is not None:
                                                                return True

                                                            if self.has_rcvd_label is not None:
                                                                return True

                                                            if self.has_second_label is not None:
                                                                return True

                                                            if self.ibgp_signaled_validity is not None:
                                                                return True

                                                            if self.igp_metric is not None:
                                                                return True

                                                            if self.is_aggregation_suppressed is not None:
                                                                return True

                                                            if self.is_as_best is not None:
                                                                return True

                                                            if self.is_best_path is not None:
                                                                return True

                                                            if self.is_import_dampened is not None:
                                                                return True

                                                            if self.is_import_suspect is not None:
                                                                return True

                                                            if self.is_internal_path is not None:
                                                                return True

                                                            if self.is_partial_best is not None:
                                                                return True

                                                            if self.is_path_additional_path is not None:
                                                                return True

                                                            if self.is_path_advertised_local_as_only is not None:
                                                                return True

                                                            if self.is_path_af_install_eligible is not None:
                                                                return True

                                                            if self.is_path_backup is not None:
                                                                return True

                                                            if self.is_path_backup_protect_multipath is not None:
                                                                return True

                                                            if self.is_path_best_external is not None:
                                                                return True

                                                            if self.is_path_damped is not None:
                                                                return True

                                                            if self.is_path_from_confederation_peer is not None:
                                                                return True

                                                            if self.is_path_from_network_command is not None:
                                                                return True

                                                            if self.is_path_from_redistribute_command is not None:
                                                                return True

                                                            if self.is_path_from_route_reflector is not None:
                                                                return True

                                                            if self.is_path_history_held is not None:
                                                                return True

                                                            if self.is_path_imp_candidate is not None:
                                                                return True

                                                            if self.is_path_imported is not None:
                                                                return True

                                                            if self.is_path_local_aggregate is not None:
                                                                return True

                                                            if self.is_path_locally_sourced is not None:
                                                                return True

                                                            if self.is_path_long_lived_stale is not None:
                                                                return True

                                                            if self.is_path_multipath is not None:
                                                                return True

                                                            if self.is_path_nexthop_discarded is not None:
                                                                return True

                                                            if self.is_path_not_advertised is not None:
                                                                return True

                                                            if self.is_path_not_advertised_to_ebg_ps is not None:
                                                                return True

                                                            if self.is_path_received_only is not None:
                                                                return True

                                                            if self.is_path_reoriginated is not None:
                                                                return True

                                                            if self.is_path_reoriginated_stitching is not None:
                                                                return True

                                                            if self.is_path_stale is not None:
                                                                return True

                                                            if self.is_path_synced_with_igp is not None:
                                                                return True

                                                            if self.is_path_valid is not None:
                                                                return True

                                                            if self.is_path_vpn_only is not None:
                                                                return True

                                                            if self.is_permanent_path is not None:
                                                                return True

                                                            if self.is_received_path_not_modified is not None:
                                                                return True

                                                            if self.is_spkr_as_best is not None:
                                                                return True

                                                            if self.l2vpn_circuit_status_value is not None:
                                                                for child_ref in self.l2vpn_circuit_status_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                                return True

                                                            if self.l2vpn_size is not None:
                                                                return True

                                                            if self.labeled_unicast_safi_path is not None:
                                                                return True

                                                            if self.local_label is not None:
                                                                return True

                                                            if self.local_nh is not None:
                                                                return True

                                                            if self.local_path_id is not None:
                                                                return True

                                                            if self.local_peers_advertised_to is not None:
                                                                for child_ref in self.local_peers_advertised_to:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.maximum_suppress_time is not None:
                                                                return True

                                                            if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                                return True

                                                            if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                                return True

                                                            if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                                return True

                                                            if self.mvpn_path_flags is not None:
                                                                return True

                                                            if self.mvpn_pmsi_flags is not None:
                                                                return True

                                                            if self.mvpn_pmsi_label is not None:
                                                                return True

                                                            if self.mvpn_pmsi_type is not None:
                                                                return True

                                                            if self.mvpn_pmsi_value is not None:
                                                                for child_ref in self.mvpn_pmsi_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.mvpn_sfs_path is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.neighbor_router_id is not None:
                                                                return True

                                                            if self.next_hop is not None and self.next_hop._has_data():
                                                                return True

                                                            if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                                return True

                                                            if self.path_flags is not None:
                                                                return True

                                                            if self.path_flap_count is not None:
                                                                return True

                                                            if self.path_import_flags is not None:
                                                                return True

                                                            if self.path_rt_set_id is not None:
                                                                return True

                                                            if self.path_rt_set_route_count is not None:
                                                                return True

                                                            if self.path_table_version is not None:
                                                                return True

                                                            if self.path_weight is not None:
                                                                return True

                                                            if self.pe_peers_advertised_to is not None:
                                                                for child_ref in self.pe_peers_advertised_to:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.rcvd_label is not None:
                                                                return True

                                                            if self.rcvd_path_id is not None:
                                                                return True

                                                            if self.reuse_value is not None:
                                                                return True

                                                            if self.rib_failed is not None:
                                                                return True

                                                            if self.route_type is not None:
                                                                return True

                                                            if self.rpki_origin_as_validation_disabled is not None:
                                                                return True

                                                            if self.rt_set_limit_enabled is not None:
                                                                return True

                                                            if self.second_label is not None:
                                                                return True

                                                            if self.seconds_since_first_flap is not None:
                                                                return True

                                                            if self.show_rpki_origin_as_validity is not None:
                                                                return True

                                                            if self.sn_rpki_origin_as_validity is not None:
                                                                return True

                                                            if self.suppress_penalty is not None:
                                                                return True

                                                            if self.time_to_unsuppress is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation']['meta_info']


                                                    class AttributesAfterPolicyIn(object):
                                                        """
                                                        Attributes after inbound policy applied
                                                        
                                                        .. attribute:: attr_set
                                                        
                                                        	ATTR\_SET attribute
                                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                        
                                                        .. attribute:: attribute_key_number
                                                        
                                                        	Attribute key number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_config
                                                        
                                                        	Attribute reuse ID Configured
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: attribute_reuse_id_current
                                                        
                                                        	Attribute reuse ID current ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_keys
                                                        
                                                        	Attribute reuse ID allocated keys
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_max_id
                                                        
                                                        	Attribute reuse ID maximum ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_node
                                                        
                                                        	Attribute reuse ID nodes
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_recover_sec
                                                        
                                                        	Attribute reuse ID timer in seconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: common_attributes
                                                        
                                                        	Common attributes
                                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                        
                                                        .. attribute:: is_application_gateway_present
                                                        
                                                        	Application gateway present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path2_byte
                                                        
                                                        	AS path encoded as 2\-byte
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_attr_set_present
                                                        
                                                        	BGP ATTR\_SET attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ribrnh_present
                                                        
                                                        	RIB RNH Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_rnh_present
                                                        
                                                        	RNH Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: ribrnh_encap
                                                        
                                                        	RIB RNH Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ribrnh_ip
                                                        
                                                        	RIB RNH IP Address
                                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                        
                                                        .. attribute:: ribrnh_mac
                                                        
                                                        	RIB RNH MAC Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                        
                                                        .. attribute:: ribrnh_table
                                                        
                                                        	RIB RNH Table
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ribrnh_vni
                                                        
                                                        	RIB RNH Vni
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ribrnhip_table
                                                        
                                                        	RIB RNH IP Table
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rnh_addr
                                                        
                                                        	RNH Address
                                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                        
                                                        .. attribute:: rnh_addr_len
                                                        
                                                        	RNH Address Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rnh_len
                                                        
                                                        	RNH Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: rnh_type
                                                        
                                                        	RNH Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: set_aigp_inbound_igp
                                                        
                                                        	AIGP set by policy inbound IGP 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: set_aigp_inbound_metric
                                                        
                                                        	AIGP set by policy inbound metric
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: vpn_distinguisher
                                                        
                                                        	VPN Distinguisher
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                            self.attr_set.parent = self
                                                            self.attribute_key_number = None
                                                            self.attribute_reuse_id_config = None
                                                            self.attribute_reuse_id_current = None
                                                            self.attribute_reuse_id_keys = None
                                                            self.attribute_reuse_id_max_id = None
                                                            self.attribute_reuse_id_node = None
                                                            self.attribute_reuse_id_recover_sec = None
                                                            self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                            self.common_attributes.parent = self
                                                            self.is_application_gateway_present = None
                                                            self.is_as_path2_byte = None
                                                            self.is_attr_set_present = None
                                                            self.is_ribrnh_present = None
                                                            self.is_rnh_present = None
                                                            self.ribrnh_encap = None
                                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                            self.ribrnh_ip.parent = self
                                                            self.ribrnh_mac = None
                                                            self.ribrnh_table = None
                                                            self.ribrnh_vni = None
                                                            self.ribrnhip_table = None
                                                            self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                            self.rnh_addr.parent = self
                                                            self.rnh_addr_len = None
                                                            self.rnh_len = None
                                                            self.rnh_type = None
                                                            self.set_aigp_inbound_igp = None
                                                            self.set_aigp_inbound_metric = None
                                                            self.vpn_distinguisher = None


                                                        class CommonAttributes(object):
                                                            """
                                                            Common attributes
                                                            
                                                            .. attribute:: aggregator_address
                                                            
                                                            	Address where aggregation was performed
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: aggregator_as
                                                            
                                                            	AS where aggregation was last performed
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: aigp_metric_value
                                                            
                                                            	AIGP metric value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..18446744073709551615
                                                            
                                                            .. attribute:: as_path
                                                            
                                                            	AS path attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: cluster
                                                            
                                                            	Cluster list attribute
                                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                            
                                                            .. attribute:: community
                                                            
                                                            	Community attribute
                                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                            
                                                            .. attribute:: connector_type
                                                            
                                                            	Connector Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: connector_value
                                                            
                                                            	Connector Value
                                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                            
                                                            .. attribute:: extended_community
                                                            
                                                            	Extended community attribute
                                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                            
                                                            .. attribute:: extended_community_flags
                                                            
                                                            	Extended community Flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: is_aggregator_present
                                                            
                                                            	Aggregator attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_aigp_present
                                                            
                                                            	AIGP Present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_as_path_present
                                                            
                                                            	AS path attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_atomic_aggregate_present
                                                            
                                                            	Atomic aggregate attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_community_present
                                                            
                                                            	Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_connector_present
                                                            
                                                            	Connector present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_extended_community_present
                                                            
                                                            	Extended community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_label_index_present
                                                            
                                                            	Label Index attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_local_pref_present
                                                            
                                                            	Local Preference attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ls_attribute_present
                                                            
                                                            	BGP LS attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_metric_present
                                                            
                                                            	Metric attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_origin_present
                                                            
                                                            	Origin attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pe_distinguisher_label_present
                                                            
                                                            	PE distinguisher label  attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pmsi_present
                                                            
                                                            	PMSI Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pppmp_present
                                                            
                                                            	PPMP Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ssa_present
                                                            
                                                            	SSA attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_encap_present
                                                            
                                                            	Tunnel Encap attribute present 
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: l2tpv3_cookie
                                                            
                                                            	L2TPv3 Cookie
                                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                            
                                                            .. attribute:: l2tpv3_session_id
                                                            
                                                            	L2TPv3 session id
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: label_index_attr
                                                            
                                                            	Label Index attribute
                                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                            
                                                            .. attribute:: local_preference
                                                            
                                                            	Local preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ls_attr
                                                            
                                                            	BGP LS attribute
                                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	Metric
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: neighbor_as
                                                            
                                                            	Neighbor AS number
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: origin
                                                            
                                                            	Origin
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: originator
                                                            
                                                            	Originator attribute
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: pe_distinguisher_label
                                                            
                                                            	PE distinguisher label attribute
                                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                            
                                                            .. attribute:: pmsi_flags
                                                            
                                                            	PMSI Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pmsi_label
                                                            
                                                            	PMSI label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pmsi_type
                                                            
                                                            	PMSI Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: pmsi_value
                                                            
                                                            	PMSI Value
                                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                            
                                                            .. attribute:: ppm_pvalue
                                                            
                                                            	PPMP Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: sr_policy_allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                            
                                                            .. attribute:: sr_policy_binding_sid
                                                            
                                                            	SR Policy Binding sid
                                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                            
                                                            .. attribute:: sr_policy_explicit_path
                                                            
                                                            	SR Policy Explicit paths
                                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                            
                                                            .. attribute:: sr_policy_preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: sr_tunnel_request_state
                                                            
                                                            	SR Tunnel Request State
                                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                            
                                                            .. attribute:: sr_tunnel_state
                                                            
                                                            	SR Tunnel State
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encap Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: unknown_attribute
                                                            
                                                            	Unknown attributes
                                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.aggregator_address = None
                                                                self.aggregator_as = None
                                                                self.aigp_metric_value = None
                                                                self.as_path = None
                                                                self.cluster = YList()
                                                                self.cluster.parent = self
                                                                self.cluster.name = 'cluster'
                                                                self.community = YList()
                                                                self.community.parent = self
                                                                self.community.name = 'community'
                                                                self.connector_type = None
                                                                self.connector_value = YList()
                                                                self.connector_value.parent = self
                                                                self.connector_value.name = 'connector_value'
                                                                self.extended_community = YList()
                                                                self.extended_community.parent = self
                                                                self.extended_community.name = 'extended_community'
                                                                self.extended_community_flags = None
                                                                self.is_aggregator_present = None
                                                                self.is_aigp_present = None
                                                                self.is_as_path_present = None
                                                                self.is_atomic_aggregate_present = None
                                                                self.is_community_present = None
                                                                self.is_connector_present = None
                                                                self.is_extended_community_present = None
                                                                self.is_label_index_present = None
                                                                self.is_local_pref_present = None
                                                                self.is_ls_attribute_present = None
                                                                self.is_metric_present = None
                                                                self.is_origin_present = None
                                                                self.is_pe_distinguisher_label_present = None
                                                                self.is_pmsi_present = None
                                                                self.is_pppmp_present = None
                                                                self.is_ssa_present = None
                                                                self.is_tunnel_encap_present = None
                                                                self.l2tpv3_cookie = YList()
                                                                self.l2tpv3_cookie.parent = self
                                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                                self.l2tpv3_session_id = None
                                                                self.label_index_attr = YList()
                                                                self.label_index_attr.parent = self
                                                                self.label_index_attr.name = 'label_index_attr'
                                                                self.local_preference = None
                                                                self.ls_attr = YList()
                                                                self.ls_attr.parent = self
                                                                self.ls_attr.name = 'ls_attr'
                                                                self.metric = None
                                                                self.neighbor_as = None
                                                                self.origin = None
                                                                self.originator = None
                                                                self.pe_distinguisher_label = YList()
                                                                self.pe_distinguisher_label.parent = self
                                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                                self.pmsi_flags = None
                                                                self.pmsi_label = None
                                                                self.pmsi_type = None
                                                                self.pmsi_value = YList()
                                                                self.pmsi_value.parent = self
                                                                self.pmsi_value.name = 'pmsi_value'
                                                                self.ppm_pvalue = None
                                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                                self.sr_policy_allocated_binding_sid.parent = self
                                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                                self.sr_policy_binding_sid.parent = self
                                                                self.sr_policy_explicit_path = YList()
                                                                self.sr_policy_explicit_path.parent = self
                                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                                self.sr_policy_preference = None
                                                                self.sr_tunnel_request_state = None
                                                                self.sr_tunnel_state = None
                                                                self.tunnel_encap_type = None
                                                                self.unknown_attribute = YList()
                                                                self.unknown_attribute.parent = self
                                                                self.unknown_attribute.name = 'unknown_attribute'


                                                            class SrPolicyBindingSid(object):
                                                                """
                                                                SR Policy Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_address = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                            class SrPolicyAllocatedBindingSid(object):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_address = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                            class Community(object):
                                                                """
                                                                Community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                            class ExtendedCommunity(object):
                                                                """
                                                                Extended community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                            class UnknownAttribute(object):
                                                                """
                                                                Unknown attributes
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                            class Cluster(object):
                                                                """
                                                                Cluster list attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                            class L2Tpv3Cookie(object):
                                                                """
                                                                L2TPv3 Cookie
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                            class ConnectorValue(object):
                                                                """
                                                                Connector Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                            class PmsiValue(object):
                                                                """
                                                                PMSI Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                            class LsAttr(object):
                                                                """
                                                                BGP LS attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                            class LabelIndexAttr(object):
                                                                """
                                                                Label Index attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                            class PeDistinguisherLabel(object):
                                                                """
                                                                PE distinguisher label attribute
                                                                
                                                                .. attribute:: label
                                                                
                                                                	Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pe_address
                                                                
                                                                	 PE address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.label = None
                                                                    self.pe_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.pe_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                            class SrPolicyExplicitPath(object):
                                                                """
                                                                SR Policy Explicit paths
                                                                
                                                                .. attribute:: sid
                                                                
                                                                	Sidlist for explicit path
                                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of explicit path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.sid = YList()
                                                                    self.sid.parent = self
                                                                    self.sid.name = 'sid'
                                                                    self.weight = None


                                                                class Sid(object):
                                                                    """
                                                                    Sidlist for explicit path
                                                                    
                                                                    .. attribute:: ipv4
                                                                    
                                                                    	IP Address sid
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6
                                                                    
                                                                    	IPv6 address sid
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label sid
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Sid Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4 = None
                                                                        self.ipv6 = None
                                                                        self.label = None
                                                                        self.type = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4 is not None:
                                                                            return True

                                                                        if self.ipv6 is not None:
                                                                            return True

                                                                        if self.label is not None:
                                                                            return True

                                                                        if self.type is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.sid is not None:
                                                                        for child_ref in self.sid:
                                                                            if child_ref._has_data():
                                                                                return True

                                                                    if self.weight is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.aggregator_address is not None:
                                                                    return True

                                                                if self.aggregator_as is not None:
                                                                    return True

                                                                if self.aigp_metric_value is not None:
                                                                    return True

                                                                if self.as_path is not None:
                                                                    return True

                                                                if self.cluster is not None:
                                                                    for child_ref in self.cluster:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.community is not None:
                                                                    for child_ref in self.community:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.connector_type is not None:
                                                                    return True

                                                                if self.connector_value is not None:
                                                                    for child_ref in self.connector_value:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.extended_community is not None:
                                                                    for child_ref in self.extended_community:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.extended_community_flags is not None:
                                                                    return True

                                                                if self.is_aggregator_present is not None:
                                                                    return True

                                                                if self.is_aigp_present is not None:
                                                                    return True

                                                                if self.is_as_path_present is not None:
                                                                    return True

                                                                if self.is_atomic_aggregate_present is not None:
                                                                    return True

                                                                if self.is_community_present is not None:
                                                                    return True

                                                                if self.is_connector_present is not None:
                                                                    return True

                                                                if self.is_extended_community_present is not None:
                                                                    return True

                                                                if self.is_label_index_present is not None:
                                                                    return True

                                                                if self.is_local_pref_present is not None:
                                                                    return True

                                                                if self.is_ls_attribute_present is not None:
                                                                    return True

                                                                if self.is_metric_present is not None:
                                                                    return True

                                                                if self.is_origin_present is not None:
                                                                    return True

                                                                if self.is_pe_distinguisher_label_present is not None:
                                                                    return True

                                                                if self.is_pmsi_present is not None:
                                                                    return True

                                                                if self.is_pppmp_present is not None:
                                                                    return True

                                                                if self.is_ssa_present is not None:
                                                                    return True

                                                                if self.is_tunnel_encap_present is not None:
                                                                    return True

                                                                if self.l2tpv3_cookie is not None:
                                                                    for child_ref in self.l2tpv3_cookie:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.l2tpv3_session_id is not None:
                                                                    return True

                                                                if self.label_index_attr is not None:
                                                                    for child_ref in self.label_index_attr:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.local_preference is not None:
                                                                    return True

                                                                if self.ls_attr is not None:
                                                                    for child_ref in self.ls_attr:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.metric is not None:
                                                                    return True

                                                                if self.neighbor_as is not None:
                                                                    return True

                                                                if self.origin is not None:
                                                                    return True

                                                                if self.originator is not None:
                                                                    return True

                                                                if self.pe_distinguisher_label is not None:
                                                                    for child_ref in self.pe_distinguisher_label:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.pmsi_flags is not None:
                                                                    return True

                                                                if self.pmsi_label is not None:
                                                                    return True

                                                                if self.pmsi_type is not None:
                                                                    return True

                                                                if self.pmsi_value is not None:
                                                                    for child_ref in self.pmsi_value:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.ppm_pvalue is not None:
                                                                    return True

                                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                                    return True

                                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                                    return True

                                                                if self.sr_policy_explicit_path is not None:
                                                                    for child_ref in self.sr_policy_explicit_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.sr_policy_preference is not None:
                                                                    return True

                                                                if self.sr_tunnel_request_state is not None:
                                                                    return True

                                                                if self.sr_tunnel_state is not None:
                                                                    return True

                                                                if self.tunnel_encap_type is not None:
                                                                    return True

                                                                if self.unknown_attribute is not None:
                                                                    for child_ref in self.unknown_attribute:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                                        class AttrSet(object):
                                                            """
                                                            ATTR\_SET attribute
                                                            
                                                            .. attribute:: aggregator_address
                                                            
                                                            	Address where aggregation was performed
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: aggregator_as
                                                            
                                                            	AS where aggregation was last performed
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: aigp_metric_value
                                                            
                                                            	AIGP metric value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..18446744073709551615
                                                            
                                                            .. attribute:: as_path
                                                            
                                                            	AS path attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: cluster
                                                            
                                                            	Cluster list attribute
                                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                            
                                                            .. attribute:: community
                                                            
                                                            	Community attribute
                                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                            
                                                            .. attribute:: connector_type
                                                            
                                                            	Connector Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: connector_value
                                                            
                                                            	Connector Value
                                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                            
                                                            .. attribute:: extended_community
                                                            
                                                            	Extended community attribute
                                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                            
                                                            .. attribute:: extended_community_flags
                                                            
                                                            	Extended community Flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: is_aggregator_present
                                                            
                                                            	Aggregator attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_aigp_present
                                                            
                                                            	AIGP Present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_as_path_present
                                                            
                                                            	AS path attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_atomic_aggregate_present
                                                            
                                                            	Atomic aggregate attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_community_present
                                                            
                                                            	Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_connector_present
                                                            
                                                            	Connector present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_extended_community_present
                                                            
                                                            	Extended community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_label_index_present
                                                            
                                                            	Label Index attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_local_pref_present
                                                            
                                                            	Local Preference attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ls_attribute_present
                                                            
                                                            	BGP LS attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_metric_present
                                                            
                                                            	Metric attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_origin_present
                                                            
                                                            	Origin attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pe_distinguisher_label_present
                                                            
                                                            	PE distinguisher label  attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pmsi_present
                                                            
                                                            	PMSI Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pppmp_present
                                                            
                                                            	PPMP Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ssa_present
                                                            
                                                            	SSA attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_encap_present
                                                            
                                                            	Tunnel Encap attribute present 
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: l2tpv3_cookie
                                                            
                                                            	L2TPv3 Cookie
                                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                            
                                                            .. attribute:: l2tpv3_session_id
                                                            
                                                            	L2TPv3 session id
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: label_index_attr
                                                            
                                                            	Label Index attribute
                                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                            
                                                            .. attribute:: local_preference
                                                            
                                                            	Local preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ls_attr
                                                            
                                                            	BGP LS attribute
                                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	Metric
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: neighbor_as
                                                            
                                                            	Neighbor AS number
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: origin
                                                            
                                                            	Origin
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: originator
                                                            
                                                            	Originator attribute
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: pe_distinguisher_label
                                                            
                                                            	PE distinguisher label attribute
                                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                            
                                                            .. attribute:: pmsi_flags
                                                            
                                                            	PMSI Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pmsi_label
                                                            
                                                            	PMSI label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pmsi_type
                                                            
                                                            	PMSI Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: pmsi_value
                                                            
                                                            	PMSI Value
                                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                            
                                                            .. attribute:: ppm_pvalue
                                                            
                                                            	PPMP Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: sr_policy_allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                            
                                                            .. attribute:: sr_policy_binding_sid
                                                            
                                                            	SR Policy Binding sid
                                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                            
                                                            .. attribute:: sr_policy_explicit_path
                                                            
                                                            	SR Policy Explicit paths
                                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                            
                                                            .. attribute:: sr_policy_preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: sr_tunnel_request_state
                                                            
                                                            	SR Tunnel Request State
                                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                            
                                                            .. attribute:: sr_tunnel_state
                                                            
                                                            	SR Tunnel State
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encap Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: unknown_attribute
                                                            
                                                            	Unknown attributes
                                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.aggregator_address = None
                                                                self.aggregator_as = None
                                                                self.aigp_metric_value = None
                                                                self.as_path = None
                                                                self.cluster = YList()
                                                                self.cluster.parent = self
                                                                self.cluster.name = 'cluster'
                                                                self.community = YList()
                                                                self.community.parent = self
                                                                self.community.name = 'community'
                                                                self.connector_type = None
                                                                self.connector_value = YList()
                                                                self.connector_value.parent = self
                                                                self.connector_value.name = 'connector_value'
                                                                self.extended_community = YList()
                                                                self.extended_community.parent = self
                                                                self.extended_community.name = 'extended_community'
                                                                self.extended_community_flags = None
                                                                self.is_aggregator_present = None
                                                                self.is_aigp_present = None
                                                                self.is_as_path_present = None
                                                                self.is_atomic_aggregate_present = None
                                                                self.is_community_present = None
                                                                self.is_connector_present = None
                                                                self.is_extended_community_present = None
                                                                self.is_label_index_present = None
                                                                self.is_local_pref_present = None
                                                                self.is_ls_attribute_present = None
                                                                self.is_metric_present = None
                                                                self.is_origin_present = None
                                                                self.is_pe_distinguisher_label_present = None
                                                                self.is_pmsi_present = None
                                                                self.is_pppmp_present = None
                                                                self.is_ssa_present = None
                                                                self.is_tunnel_encap_present = None
                                                                self.l2tpv3_cookie = YList()
                                                                self.l2tpv3_cookie.parent = self
                                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                                self.l2tpv3_session_id = None
                                                                self.label_index_attr = YList()
                                                                self.label_index_attr.parent = self
                                                                self.label_index_attr.name = 'label_index_attr'
                                                                self.local_preference = None
                                                                self.ls_attr = YList()
                                                                self.ls_attr.parent = self
                                                                self.ls_attr.name = 'ls_attr'
                                                                self.metric = None
                                                                self.neighbor_as = None
                                                                self.origin = None
                                                                self.originator = None
                                                                self.pe_distinguisher_label = YList()
                                                                self.pe_distinguisher_label.parent = self
                                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                                self.pmsi_flags = None
                                                                self.pmsi_label = None
                                                                self.pmsi_type = None
                                                                self.pmsi_value = YList()
                                                                self.pmsi_value.parent = self
                                                                self.pmsi_value.name = 'pmsi_value'
                                                                self.ppm_pvalue = None
                                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                                self.sr_policy_allocated_binding_sid.parent = self
                                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                                self.sr_policy_binding_sid.parent = self
                                                                self.sr_policy_explicit_path = YList()
                                                                self.sr_policy_explicit_path.parent = self
                                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                                self.sr_policy_preference = None
                                                                self.sr_tunnel_request_state = None
                                                                self.sr_tunnel_state = None
                                                                self.tunnel_encap_type = None
                                                                self.unknown_attribute = YList()
                                                                self.unknown_attribute.parent = self
                                                                self.unknown_attribute.name = 'unknown_attribute'


                                                            class SrPolicyBindingSid(object):
                                                                """
                                                                SR Policy Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_address = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                            class SrPolicyAllocatedBindingSid(object):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_address = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                            class Community(object):
                                                                """
                                                                Community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                            class ExtendedCommunity(object):
                                                                """
                                                                Extended community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                            class UnknownAttribute(object):
                                                                """
                                                                Unknown attributes
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                            class Cluster(object):
                                                                """
                                                                Cluster list attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                            class L2Tpv3Cookie(object):
                                                                """
                                                                L2TPv3 Cookie
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                            class ConnectorValue(object):
                                                                """
                                                                Connector Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                            class PmsiValue(object):
                                                                """
                                                                PMSI Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                            class LsAttr(object):
                                                                """
                                                                BGP LS attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                            class LabelIndexAttr(object):
                                                                """
                                                                Label Index attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                            class PeDistinguisherLabel(object):
                                                                """
                                                                PE distinguisher label attribute
                                                                
                                                                .. attribute:: label
                                                                
                                                                	Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pe_address
                                                                
                                                                	 PE address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.label = None
                                                                    self.pe_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.pe_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                            class SrPolicyExplicitPath(object):
                                                                """
                                                                SR Policy Explicit paths
                                                                
                                                                .. attribute:: sid
                                                                
                                                                	Sidlist for explicit path
                                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of explicit path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.sid = YList()
                                                                    self.sid.parent = self
                                                                    self.sid.name = 'sid'
                                                                    self.weight = None


                                                                class Sid(object):
                                                                    """
                                                                    Sidlist for explicit path
                                                                    
                                                                    .. attribute:: ipv4
                                                                    
                                                                    	IP Address sid
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6
                                                                    
                                                                    	IPv6 address sid
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label sid
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Sid Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4 = None
                                                                        self.ipv6 = None
                                                                        self.label = None
                                                                        self.type = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4 is not None:
                                                                            return True

                                                                        if self.ipv6 is not None:
                                                                            return True

                                                                        if self.label is not None:
                                                                            return True

                                                                        if self.type is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.sid is not None:
                                                                        for child_ref in self.sid:
                                                                            if child_ref._has_data():
                                                                                return True

                                                                    if self.weight is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.aggregator_address is not None:
                                                                    return True

                                                                if self.aggregator_as is not None:
                                                                    return True

                                                                if self.aigp_metric_value is not None:
                                                                    return True

                                                                if self.as_path is not None:
                                                                    return True

                                                                if self.cluster is not None:
                                                                    for child_ref in self.cluster:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.community is not None:
                                                                    for child_ref in self.community:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.connector_type is not None:
                                                                    return True

                                                                if self.connector_value is not None:
                                                                    for child_ref in self.connector_value:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.extended_community is not None:
                                                                    for child_ref in self.extended_community:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.extended_community_flags is not None:
                                                                    return True

                                                                if self.is_aggregator_present is not None:
                                                                    return True

                                                                if self.is_aigp_present is not None:
                                                                    return True

                                                                if self.is_as_path_present is not None:
                                                                    return True

                                                                if self.is_atomic_aggregate_present is not None:
                                                                    return True

                                                                if self.is_community_present is not None:
                                                                    return True

                                                                if self.is_connector_present is not None:
                                                                    return True

                                                                if self.is_extended_community_present is not None:
                                                                    return True

                                                                if self.is_label_index_present is not None:
                                                                    return True

                                                                if self.is_local_pref_present is not None:
                                                                    return True

                                                                if self.is_ls_attribute_present is not None:
                                                                    return True

                                                                if self.is_metric_present is not None:
                                                                    return True

                                                                if self.is_origin_present is not None:
                                                                    return True

                                                                if self.is_pe_distinguisher_label_present is not None:
                                                                    return True

                                                                if self.is_pmsi_present is not None:
                                                                    return True

                                                                if self.is_pppmp_present is not None:
                                                                    return True

                                                                if self.is_ssa_present is not None:
                                                                    return True

                                                                if self.is_tunnel_encap_present is not None:
                                                                    return True

                                                                if self.l2tpv3_cookie is not None:
                                                                    for child_ref in self.l2tpv3_cookie:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.l2tpv3_session_id is not None:
                                                                    return True

                                                                if self.label_index_attr is not None:
                                                                    for child_ref in self.label_index_attr:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.local_preference is not None:
                                                                    return True

                                                                if self.ls_attr is not None:
                                                                    for child_ref in self.ls_attr:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.metric is not None:
                                                                    return True

                                                                if self.neighbor_as is not None:
                                                                    return True

                                                                if self.origin is not None:
                                                                    return True

                                                                if self.originator is not None:
                                                                    return True

                                                                if self.pe_distinguisher_label is not None:
                                                                    for child_ref in self.pe_distinguisher_label:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.pmsi_flags is not None:
                                                                    return True

                                                                if self.pmsi_label is not None:
                                                                    return True

                                                                if self.pmsi_type is not None:
                                                                    return True

                                                                if self.pmsi_value is not None:
                                                                    for child_ref in self.pmsi_value:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.ppm_pvalue is not None:
                                                                    return True

                                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                                    return True

                                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                                    return True

                                                                if self.sr_policy_explicit_path is not None:
                                                                    for child_ref in self.sr_policy_explicit_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.sr_policy_preference is not None:
                                                                    return True

                                                                if self.sr_tunnel_request_state is not None:
                                                                    return True

                                                                if self.sr_tunnel_state is not None:
                                                                    return True

                                                                if self.tunnel_encap_type is not None:
                                                                    return True

                                                                if self.unknown_attribute is not None:
                                                                    for child_ref in self.unknown_attribute:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                                        class RnhAddr(object):
                                                            """
                                                            RNH Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                            
                                                            .. attribute:: mac_address
                                                            
                                                            	MAC Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self.len = None
                                                                self.mac_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.len is not None:
                                                                    return True

                                                                if self.mac_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                                        class RibrnhIp(object):
                                                            """
                                                            RIB RNH IP Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.attr_set is not None and self.attr_set._has_data():
                                                                return True

                                                            if self.attribute_key_number is not None:
                                                                return True

                                                            if self.attribute_reuse_id_config is not None:
                                                                return True

                                                            if self.attribute_reuse_id_current is not None:
                                                                return True

                                                            if self.attribute_reuse_id_keys is not None:
                                                                return True

                                                            if self.attribute_reuse_id_max_id is not None:
                                                                return True

                                                            if self.attribute_reuse_id_node is not None:
                                                                return True

                                                            if self.attribute_reuse_id_recover_sec is not None:
                                                                return True

                                                            if self.common_attributes is not None and self.common_attributes._has_data():
                                                                return True

                                                            if self.is_application_gateway_present is not None:
                                                                return True

                                                            if self.is_as_path2_byte is not None:
                                                                return True

                                                            if self.is_attr_set_present is not None:
                                                                return True

                                                            if self.is_ribrnh_present is not None:
                                                                return True

                                                            if self.is_rnh_present is not None:
                                                                return True

                                                            if self.ribrnh_encap is not None:
                                                                return True

                                                            if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                                return True

                                                            if self.ribrnh_mac is not None:
                                                                return True

                                                            if self.ribrnh_table is not None:
                                                                return True

                                                            if self.ribrnh_vni is not None:
                                                                return True

                                                            if self.ribrnhip_table is not None:
                                                                return True

                                                            if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                                return True

                                                            if self.rnh_addr_len is not None:
                                                                return True

                                                            if self.rnh_len is not None:
                                                                return True

                                                            if self.rnh_type is not None:
                                                                return True

                                                            if self.set_aigp_inbound_igp is not None:
                                                                return True

                                                            if self.set_aigp_inbound_metric is not None:
                                                                return True

                                                            if self.vpn_distinguisher is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-process-instance-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.af_name is not None:
                                                            return True

                                                        if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                            return True

                                                        if self.label_fail is not None:
                                                            return True

                                                        if self.label_o_or_version is not None:
                                                            return True

                                                        if self.label_oor is not None:
                                                            return True

                                                        if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                            return True

                                                        if self.no_path is not None:
                                                            return True

                                                        if self.path_information is not None and self.path_information._has_data():
                                                            return True

                                                        if self.prefix_version is not None:
                                                            return True

                                                        if self.process_instance_id is not None:
                                                            return True

                                                        if self.route_distinguisher is not None:
                                                            return True

                                                        if self.source_route_distinguisher is not None:
                                                            return True

                                                        if self.source_vrf_name is not None:
                                                            return True

                                                        if self.srcaf_name is not None:
                                                            return True

                                                        if self.vrf_name is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath']['meta_info']


                                                class LocalPathElement(object):
                                                    """
                                                    Local path element list
                                                    
                                                    .. attribute:: is_perm_path_pelem
                                                    
                                                    	Pelem for permanent path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: nhte_tunnel
                                                    
                                                    	NH TE tunnel information
                                                    	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.NhteTunnel>`
                                                    
                                                    .. attribute:: pelem_flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_gw_metric
                                                    
                                                    	Gateway metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_no_addpath_table_attr_version
                                                    
                                                    	No\-addpath Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_no_bestpath_table_attr_version
                                                    
                                                    	No\-bestpath Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_flags
                                                    
                                                    	Path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: pelem_path_id
                                                    
                                                    	Local Path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_neighbor_addr
                                                    
                                                    	Path neighbor address
                                                    	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr>`
                                                    
                                                    .. attribute:: pelem_path_nexthop
                                                    
                                                    	Path nexthop address
                                                    	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop>`
                                                    
                                                    .. attribute:: pelem_path_peer_path_id
                                                    
                                                    	Path peer path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_table_attr_version
                                                    
                                                    	Path Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_table_attr_version
                                                    
                                                    	Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_version
                                                    
                                                    	Version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_perm_path_pelem = None
                                                        self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.NhteTunnel()
                                                        self.nhte_tunnel.parent = self
                                                        self.pelem_flags = None
                                                        self.pelem_gw_metric = None
                                                        self.pelem_no_addpath_table_attr_version = None
                                                        self.pelem_no_bestpath_table_attr_version = None
                                                        self.pelem_path_flags = None
                                                        self.pelem_path_id = None
                                                        self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr()
                                                        self.pelem_path_neighbor_addr.parent = self
                                                        self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop()
                                                        self.pelem_path_nexthop.parent = self
                                                        self.pelem_path_peer_path_id = None
                                                        self.pelem_path_table_attr_version = None
                                                        self.pelem_table_attr_version = None
                                                        self.pelem_version = None


                                                    class PelemPathNexthop(object):
                                                        """
                                                        Path nexthop address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-nexthop'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop']['meta_info']


                                                    class NhteTunnel(object):
                                                        """
                                                        NH TE tunnel information
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	Binding label for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_te_tunnel
                                                        
                                                        	NH TE Tunnel info is present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_info_stale
                                                        
                                                        	Tunnel is stale
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_registered
                                                        
                                                        	Tunnel registered flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_up
                                                        
                                                        	Tunnel Up flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: last_tunnel_update
                                                        
                                                        	Time since the last rib update happened
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_if_handle
                                                        
                                                        	Interface handle for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_name
                                                        
                                                        	tunnel name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        .. attribute:: tunnel_type
                                                        
                                                        	tunnel type
                                                        	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                        
                                                        .. attribute:: tunnel_v6_enabled
                                                        
                                                        	IPv6 enabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_v6_required
                                                        
                                                        	Tunnel need IPv6
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.binding_label = None
                                                            self.has_te_tunnel = None
                                                            self.is_tunnel_info_stale = None
                                                            self.is_tunnel_registered = None
                                                            self.is_tunnel_up = None
                                                            self.last_tunnel_update = None
                                                            self.tunnel_if_handle = None
                                                            self.tunnel_name = None
                                                            self.tunnel_type = None
                                                            self.tunnel_v6_enabled = None
                                                            self.tunnel_v6_required = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.binding_label is not None:
                                                                return True

                                                            if self.has_te_tunnel is not None:
                                                                return True

                                                            if self.is_tunnel_info_stale is not None:
                                                                return True

                                                            if self.is_tunnel_registered is not None:
                                                                return True

                                                            if self.is_tunnel_up is not None:
                                                                return True

                                                            if self.last_tunnel_update is not None:
                                                                return True

                                                            if self.tunnel_if_handle is not None:
                                                                return True

                                                            if self.tunnel_name is not None:
                                                                return True

                                                            if self.tunnel_type is not None:
                                                                return True

                                                            if self.tunnel_v6_enabled is not None:
                                                                return True

                                                            if self.tunnel_v6_required is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.NhteTunnel']['meta_info']


                                                    class PelemPathNeighborAddr(object):
                                                        """
                                                        Path neighbor address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-neighbor-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-path-element'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_perm_path_pelem is not None:
                                                            return True

                                                        if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                            return True

                                                        if self.pelem_flags is not None:
                                                            return True

                                                        if self.pelem_gw_metric is not None:
                                                            return True

                                                        if self.pelem_no_addpath_table_attr_version is not None:
                                                            return True

                                                        if self.pelem_no_bestpath_table_attr_version is not None:
                                                            return True

                                                        if self.pelem_path_flags is not None:
                                                            return True

                                                        if self.pelem_path_id is not None:
                                                            return True

                                                        if self.pelem_path_neighbor_addr is not None and self.pelem_path_neighbor_addr._has_data():
                                                            return True

                                                        if self.pelem_path_nexthop is not None and self.pelem_path_nexthop._has_data():
                                                            return True

                                                        if self.pelem_path_peer_path_id is not None:
                                                            return True

                                                        if self.pelem_path_table_attr_version is not None:
                                                            return True

                                                        if self.pelem_table_attr_version is not None:
                                                            return True

                                                        if self.pelem_version is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement']['meta_info']


                                                class ActivePathElement(object):
                                                    """
                                                    Path element list received from Active inst
                                                    
                                                    .. attribute:: is_perm_path_pelem
                                                    
                                                    	Pelem for permanent path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: nhte_tunnel
                                                    
                                                    	NH TE tunnel information
                                                    	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.NhteTunnel>`
                                                    
                                                    .. attribute:: pelem_flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_gw_metric
                                                    
                                                    	Gateway metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_no_addpath_table_attr_version
                                                    
                                                    	No\-addpath Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_no_bestpath_table_attr_version
                                                    
                                                    	No\-bestpath Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_flags
                                                    
                                                    	Path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: pelem_path_id
                                                    
                                                    	Local Path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_neighbor_addr
                                                    
                                                    	Path neighbor address
                                                    	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr>`
                                                    
                                                    .. attribute:: pelem_path_nexthop
                                                    
                                                    	Path nexthop address
                                                    	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop>`
                                                    
                                                    .. attribute:: pelem_path_peer_path_id
                                                    
                                                    	Path peer path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_table_attr_version
                                                    
                                                    	Path Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_table_attr_version
                                                    
                                                    	Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_version
                                                    
                                                    	Version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_perm_path_pelem = None
                                                        self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.NhteTunnel()
                                                        self.nhte_tunnel.parent = self
                                                        self.pelem_flags = None
                                                        self.pelem_gw_metric = None
                                                        self.pelem_no_addpath_table_attr_version = None
                                                        self.pelem_no_bestpath_table_attr_version = None
                                                        self.pelem_path_flags = None
                                                        self.pelem_path_id = None
                                                        self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr()
                                                        self.pelem_path_neighbor_addr.parent = self
                                                        self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop()
                                                        self.pelem_path_nexthop.parent = self
                                                        self.pelem_path_peer_path_id = None
                                                        self.pelem_path_table_attr_version = None
                                                        self.pelem_table_attr_version = None
                                                        self.pelem_version = None


                                                    class PelemPathNexthop(object):
                                                        """
                                                        Path nexthop address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-nexthop'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop']['meta_info']


                                                    class NhteTunnel(object):
                                                        """
                                                        NH TE tunnel information
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	Binding label for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_te_tunnel
                                                        
                                                        	NH TE Tunnel info is present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_info_stale
                                                        
                                                        	Tunnel is stale
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_registered
                                                        
                                                        	Tunnel registered flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_up
                                                        
                                                        	Tunnel Up flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: last_tunnel_update
                                                        
                                                        	Time since the last rib update happened
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_if_handle
                                                        
                                                        	Interface handle for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_name
                                                        
                                                        	tunnel name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        .. attribute:: tunnel_type
                                                        
                                                        	tunnel type
                                                        	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                        
                                                        .. attribute:: tunnel_v6_enabled
                                                        
                                                        	IPv6 enabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_v6_required
                                                        
                                                        	Tunnel need IPv6
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.binding_label = None
                                                            self.has_te_tunnel = None
                                                            self.is_tunnel_info_stale = None
                                                            self.is_tunnel_registered = None
                                                            self.is_tunnel_up = None
                                                            self.last_tunnel_update = None
                                                            self.tunnel_if_handle = None
                                                            self.tunnel_name = None
                                                            self.tunnel_type = None
                                                            self.tunnel_v6_enabled = None
                                                            self.tunnel_v6_required = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.binding_label is not None:
                                                                return True

                                                            if self.has_te_tunnel is not None:
                                                                return True

                                                            if self.is_tunnel_info_stale is not None:
                                                                return True

                                                            if self.is_tunnel_registered is not None:
                                                                return True

                                                            if self.is_tunnel_up is not None:
                                                                return True

                                                            if self.last_tunnel_update is not None:
                                                                return True

                                                            if self.tunnel_if_handle is not None:
                                                                return True

                                                            if self.tunnel_name is not None:
                                                                return True

                                                            if self.tunnel_type is not None:
                                                                return True

                                                            if self.tunnel_v6_enabled is not None:
                                                                return True

                                                            if self.tunnel_v6_required is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.NhteTunnel']['meta_info']


                                                    class PelemPathNeighborAddr(object):
                                                        """
                                                        Path neighbor address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-neighbor-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-path-element'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_perm_path_pelem is not None:
                                                            return True

                                                        if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                            return True

                                                        if self.pelem_flags is not None:
                                                            return True

                                                        if self.pelem_gw_metric is not None:
                                                            return True

                                                        if self.pelem_no_addpath_table_attr_version is not None:
                                                            return True

                                                        if self.pelem_no_bestpath_table_attr_version is not None:
                                                            return True

                                                        if self.pelem_path_flags is not None:
                                                            return True

                                                        if self.pelem_path_id is not None:
                                                            return True

                                                        if self.pelem_path_neighbor_addr is not None and self.pelem_path_neighbor_addr._has_data():
                                                            return True

                                                        if self.pelem_path_nexthop is not None and self.pelem_path_nexthop._has_data():
                                                            return True

                                                        if self.pelem_path_peer_path_id is not None:
                                                            return True

                                                        if self.pelem_path_table_attr_version is not None:
                                                            return True

                                                        if self.pelem_table_attr_version is not None:
                                                            return True

                                                        if self.pelem_version is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                                    if self.rd is None:
                                                        raise YPYModelError('Key property rd is None')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-lookup-rd[Cisco-IOS-XR-ipv4-bgp-oper:rd = ' + str(self.rd) + ']'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.rd is not None:
                                                        return True

                                                    if self.active_path_element is not None:
                                                        for child_ref in self.active_path_element:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.active_process_instance_path is not None:
                                                        for child_ref in self.active_process_instance_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.add_path_orr_bitfield is not None:
                                                        for child_ref in self.add_path_orr_bitfield:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.advertisedto_pe is not None:
                                                        return True

                                                    if self.af_name is not None:
                                                        return True

                                                    if self.best_path_orr_bitfield is not None:
                                                        for child_ref in self.best_path_orr_bitfield:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                        return True

                                                    if self.bit is not None:
                                                        return True

                                                    if self.flags is not None:
                                                        return True

                                                    if self.gateway_array is not None:
                                                        return True

                                                    if self.has_inconsistent_paths is not None:
                                                        return True

                                                    if self.has_lbl_retained is not None:
                                                        return True

                                                    if self.has_local_label is not None:
                                                        return True

                                                    if self.is_net_aggregation_suppressed is not None:
                                                        return True

                                                    if self.is_net_ldp_signaled is not None:
                                                        return True

                                                    if self.is_permanent_network is not None:
                                                        return True

                                                    if self.local_path_element is not None:
                                                        for child_ref in self.local_path_element:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_peers_advertised_to is not None:
                                                        for child_ref in self.local_peers_advertised_to:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_process_instance_path is not None:
                                                        for child_ref in self.local_process_instance_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.net_backup_available is not None:
                                                        return True

                                                    if self.net_backup_label_rewrite_available is not None:
                                                        return True

                                                    if self.net_eibgp_multipath is not None:
                                                        return True

                                                    if self.net_extended_flags is not None:
                                                        return True

                                                    if self.net_flags is not None:
                                                        return True

                                                    if self.net_local_label is not None:
                                                        return True

                                                    if self.net_local_label_rewrite is not None:
                                                        return True

                                                    if self.net_local_label_srgb is not None:
                                                        return True

                                                    if self.net_multipath is not None:
                                                        return True

                                                    if self.num_of_path is not None:
                                                        return True

                                                    if self.pe_peers_advertised_to is not None:
                                                        for child_ref in self.pe_peers_advertised_to:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.process_instance_id is not None:
                                                        return True

                                                    if self.resilient_nexthop_set is not None:
                                                        return True

                                                    if self.rib_failed is not None:
                                                        return True

                                                    if self.route_distinguisher is not None:
                                                        return True

                                                    if self.table_brib_version is not None:
                                                        return True

                                                    if self.table_version is not None:
                                                        return True

                                                    if self.version is not None:
                                                        return True

                                                    if self.version_age is not None and self.version_age._has_data():
                                                        return True

                                                    if self.version_timestamp is not None and self.version_timestamp._has_data():
                                                        return True

                                                    if self.vrf_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-lookup-rds'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.network_lookup_rd is not None:
                                                    for child_ref in self.network_lookup_rd:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')
                                            if self.network_prefix is None:
                                                raise YPYModelError('Key property network_prefix is None')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-lookup-all-rd[Cisco-IOS-XR-ipv4-bgp-oper:network-prefix = ' + str(self.network_prefix) + ']'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.network_prefix is not None:
                                                return True

                                            if self.network_lookup_rds is not None and self.network_lookup_rds._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-lookup-all-rds'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.network_lookup_all_rd is not None:
                                            for child_ref in self.network_lookup_all_rd:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkLookupAllRds']['meta_info']


                                class Policies(object):
                                    """
                                    The BGP Policy Table
                                    
                                    .. attribute:: policy
                                    
                                    	A BGP Policy table entry
                                    	**type**\: list of    :py:class:`Policy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.policy = YList()
                                        self.policy.parent = self
                                        self.policy.name = 'policy'


                                    class Policy(object):
                                        """
                                        A BGP Policy table entry
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: attributes_after_policy_out
                                        
                                        	Attributes after outbound policy
                                        	**type**\:   :py:class:`AttributesAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut>`
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr>`
                                        
                                        .. attribute:: network
                                        
                                        	Network Prefix in Hex format
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists All 'sp\_path\_in' fields except 'sp\_path\_in\->bag\_prefix' are invalid.  All 'sp\_path\_out' fields are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_info_after_policy_in
                                        
                                        	Path information after inbound policy
                                        	**type**\:   :py:class:`PathInfoAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn>`
                                        
                                        .. attribute:: path_info_after_policy_out
                                        
                                        	Path information after outbound policy
                                        	**type**\:   :py:class:`PathInfoAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self.attributes_after_policy_out = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut()
                                            self.attributes_after_policy_out.parent = self
                                            self.neighbor_address = None
                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self.network = None
                                            self.no_path = None
                                            self.path_info_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn()
                                            self.path_info_after_policy_in.parent = self
                                            self.path_info_after_policy_out = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut()
                                            self.path_info_after_policy_out.parent = self
                                            self.prefix_length = None
                                            self.rd = None
                                            self.route_distinguisher = None
                                            self.source_route_distinguisher = None
                                            self.vrf_name = None


                                        class NeighborAddressXr(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr']['meta_info']


                                        class PathInfoAfterPolicyIn(object):
                                            """
                                            Path information after inbound policy
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_esi
                                            
                                            	Path has EVPN ESI
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_rcvd_label
                                            
                                            	Path has received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebg_ps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2VpnEvpnEsi>`
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop>`
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhteTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_p_ath = None
                                                self.add_path_orr_bitfield = YList()
                                                self.add_path_orr_bitfield.parent = self
                                                self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                self.advertisedto_pe = None
                                                self.aigp_metric = None
                                                self.best_path_comp_stage = None
                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self.best_path_id = None
                                                self.best_path_id_comp_winner = None
                                                self.best_path_orr_bitfield = YList()
                                                self.best_path_orr_bitfield.parent = self
                                                self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self.dampen_penalty = None
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.fspec_invalid_path = None
                                                self.graceful_shutdown = None
                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr()
                                                self.gw_addr.parent = self
                                                self.halflife_time = None
                                                self.has_esi = None
                                                self.has_gw_addr = None
                                                self.has_local_net_label = None
                                                self.has_mdt_group_addr = None
                                                self.has_mvpn_extcomm = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.has_rcvd_label = None
                                                self.has_second_label = None
                                                self.ibgp_signaled_validity = None
                                                self.igp_metric = None
                                                self.is_aggregation_suppressed = None
                                                self.is_as_best = None
                                                self.is_best_path = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_internal_path = None
                                                self.is_partial_best = None
                                                self.is_path_additional_path = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_af_install_eligible = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_damped = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_history_held = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_imported = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_multipath = None
                                                self.is_path_nexthop_discarded = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebg_ps = None
                                                self.is_path_received_only = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_stale = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_valid = None
                                                self.is_path_vpn_only = None
                                                self.is_permanent_path = None
                                                self.is_received_path_not_modified = None
                                                self.is_spkr_as_best = None
                                                self.l2vpn_circuit_status_value = YList()
                                                self.l2vpn_circuit_status_value.parent = self
                                                self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2VpnEvpnEsi()
                                                self.l2vpn_evpn_esi.parent = self
                                                self.l2vpn_size = None
                                                self.labeled_unicast_safi_path = None
                                                self.local_label = None
                                                self.local_nh = None
                                                self.local_path_id = None
                                                self.local_peers_advertised_to = YList()
                                                self.local_peers_advertised_to.parent = self
                                                self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                self.maximum_suppress_time = None
                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self.mvpn_path_flags = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_value = YList()
                                                self.mvpn_pmsi_value.parent = self
                                                self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                self.mvpn_sfs_path = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.neighbor_router_id = None
                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop()
                                                self.next_hop.parent = self
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.path_flags = None
                                                self.path_flap_count = None
                                                self.path_import_flags = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.path_table_version = None
                                                self.path_weight = None
                                                self.pe_peers_advertised_to = YList()
                                                self.pe_peers_advertised_to.parent = self
                                                self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                self.rcvd_label = None
                                                self.rcvd_path_id = None
                                                self.reuse_value = None
                                                self.rib_failed = None
                                                self.route_type = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.rt_set_limit_enabled = None
                                                self.second_label = None
                                                self.seconds_since_first_flap = None
                                                self.show_rpki_origin_as_validity = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.suppress_penalty = None
                                                self.time_to_unsuppress = None


                                            class BgpPrefix(object):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self.prefix_length = None


                                                class Prefix(object):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.prefix is not None and self.prefix._has_data():
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix']['meta_info']


                                            class NeighborAddress(object):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress']['meta_info']


                                            class NextHop(object):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhteTunnel']['meta_info']


                                            class MdtGroupAddr(object):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr']['meta_info']


                                            class L2VpnEvpnEsi(object):
                                                """
                                                L2VPN EVPN ESI
                                                
                                                .. attribute:: esi
                                                
                                                	esi
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.esi = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.esi is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2VpnEvpnEsi']['meta_info']


                                            class GwAddr(object):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr']['meta_info']


                                            class BestPathCompWinner(object):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner']['meta_info']


                                            class MvpnNbrAddr(object):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr']['meta_info']


                                            class MvpnNexthopAddr(object):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr']['meta_info']


                                            class L2VpnCircuitStatusValue(object):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue']['meta_info']


                                            class MvpnPmsiValue(object):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity']['meta_info']


                                            class LocalPeersAdvertisedTo(object):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo']['meta_info']


                                            class PePeersAdvertisedTo(object):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo']['meta_info']


                                            class BestPathOrrBitfield(object):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield']['meta_info']


                                            class AddPathOrrBitfield(object):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-info-after-policy-in'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.accept_own_path is not None:
                                                    return True

                                                if self.accept_own_self_originated_p_ath is not None:
                                                    return True

                                                if self.add_path_orr_bitfield is not None:
                                                    for child_ref in self.add_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.advertisedto_pe is not None:
                                                    return True

                                                if self.aigp_metric is not None:
                                                    return True

                                                if self.best_path_comp_stage is not None:
                                                    return True

                                                if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                    return True

                                                if self.best_path_id is not None:
                                                    return True

                                                if self.best_path_id_comp_winner is not None:
                                                    return True

                                                if self.best_path_orr_bitfield is not None:
                                                    for child_ref in self.best_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                    return True

                                                if self.dampen_penalty is not None:
                                                    return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.fspec_invalid_path is not None:
                                                    return True

                                                if self.graceful_shutdown is not None:
                                                    return True

                                                if self.gw_addr is not None and self.gw_addr._has_data():
                                                    return True

                                                if self.halflife_time is not None:
                                                    return True

                                                if self.has_esi is not None:
                                                    return True

                                                if self.has_gw_addr is not None:
                                                    return True

                                                if self.has_local_net_label is not None:
                                                    return True

                                                if self.has_mdt_group_addr is not None:
                                                    return True

                                                if self.has_mvpn_extcomm is not None:
                                                    return True

                                                if self.has_mvpn_nbr_addr is not None:
                                                    return True

                                                if self.has_mvpn_nexthop_addr is not None:
                                                    return True

                                                if self.has_mvpn_pmsi is not None:
                                                    return True

                                                if self.has_rcvd_label is not None:
                                                    return True

                                                if self.has_second_label is not None:
                                                    return True

                                                if self.ibgp_signaled_validity is not None:
                                                    return True

                                                if self.igp_metric is not None:
                                                    return True

                                                if self.is_aggregation_suppressed is not None:
                                                    return True

                                                if self.is_as_best is not None:
                                                    return True

                                                if self.is_best_path is not None:
                                                    return True

                                                if self.is_import_dampened is not None:
                                                    return True

                                                if self.is_import_suspect is not None:
                                                    return True

                                                if self.is_internal_path is not None:
                                                    return True

                                                if self.is_partial_best is not None:
                                                    return True

                                                if self.is_path_additional_path is not None:
                                                    return True

                                                if self.is_path_advertised_local_as_only is not None:
                                                    return True

                                                if self.is_path_af_install_eligible is not None:
                                                    return True

                                                if self.is_path_backup is not None:
                                                    return True

                                                if self.is_path_backup_protect_multipath is not None:
                                                    return True

                                                if self.is_path_best_external is not None:
                                                    return True

                                                if self.is_path_damped is not None:
                                                    return True

                                                if self.is_path_from_confederation_peer is not None:
                                                    return True

                                                if self.is_path_from_network_command is not None:
                                                    return True

                                                if self.is_path_from_redistribute_command is not None:
                                                    return True

                                                if self.is_path_from_route_reflector is not None:
                                                    return True

                                                if self.is_path_history_held is not None:
                                                    return True

                                                if self.is_path_imp_candidate is not None:
                                                    return True

                                                if self.is_path_imported is not None:
                                                    return True

                                                if self.is_path_local_aggregate is not None:
                                                    return True

                                                if self.is_path_locally_sourced is not None:
                                                    return True

                                                if self.is_path_long_lived_stale is not None:
                                                    return True

                                                if self.is_path_multipath is not None:
                                                    return True

                                                if self.is_path_nexthop_discarded is not None:
                                                    return True

                                                if self.is_path_not_advertised is not None:
                                                    return True

                                                if self.is_path_not_advertised_to_ebg_ps is not None:
                                                    return True

                                                if self.is_path_received_only is not None:
                                                    return True

                                                if self.is_path_reoriginated is not None:
                                                    return True

                                                if self.is_path_reoriginated_stitching is not None:
                                                    return True

                                                if self.is_path_stale is not None:
                                                    return True

                                                if self.is_path_synced_with_igp is not None:
                                                    return True

                                                if self.is_path_valid is not None:
                                                    return True

                                                if self.is_path_vpn_only is not None:
                                                    return True

                                                if self.is_permanent_path is not None:
                                                    return True

                                                if self.is_received_path_not_modified is not None:
                                                    return True

                                                if self.is_spkr_as_best is not None:
                                                    return True

                                                if self.l2vpn_circuit_status_value is not None:
                                                    for child_ref in self.l2vpn_circuit_status_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                    return True

                                                if self.l2vpn_size is not None:
                                                    return True

                                                if self.labeled_unicast_safi_path is not None:
                                                    return True

                                                if self.local_label is not None:
                                                    return True

                                                if self.local_nh is not None:
                                                    return True

                                                if self.local_path_id is not None:
                                                    return True

                                                if self.local_peers_advertised_to is not None:
                                                    for child_ref in self.local_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.maximum_suppress_time is not None:
                                                    return True

                                                if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                    return True

                                                if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                    return True

                                                if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                    return True

                                                if self.mvpn_path_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_label is not None:
                                                    return True

                                                if self.mvpn_pmsi_type is not None:
                                                    return True

                                                if self.mvpn_pmsi_value is not None:
                                                    for child_ref in self.mvpn_pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.mvpn_sfs_path is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.neighbor_router_id is not None:
                                                    return True

                                                if self.next_hop is not None and self.next_hop._has_data():
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.path_flags is not None:
                                                    return True

                                                if self.path_flap_count is not None:
                                                    return True

                                                if self.path_import_flags is not None:
                                                    return True

                                                if self.path_rt_set_id is not None:
                                                    return True

                                                if self.path_rt_set_route_count is not None:
                                                    return True

                                                if self.path_table_version is not None:
                                                    return True

                                                if self.path_weight is not None:
                                                    return True

                                                if self.pe_peers_advertised_to is not None:
                                                    for child_ref in self.pe_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.rcvd_label is not None:
                                                    return True

                                                if self.rcvd_path_id is not None:
                                                    return True

                                                if self.reuse_value is not None:
                                                    return True

                                                if self.rib_failed is not None:
                                                    return True

                                                if self.route_type is not None:
                                                    return True

                                                if self.rpki_origin_as_validation_disabled is not None:
                                                    return True

                                                if self.rt_set_limit_enabled is not None:
                                                    return True

                                                if self.second_label is not None:
                                                    return True

                                                if self.seconds_since_first_flap is not None:
                                                    return True

                                                if self.show_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.sn_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.suppress_penalty is not None:
                                                    return True

                                                if self.time_to_unsuppress is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn']['meta_info']


                                        class PathInfoAfterPolicyOut(object):
                                            """
                                            Path information after outbound policy
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_esi
                                            
                                            	Path has EVPN ESI
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_rcvd_label
                                            
                                            	Path has received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebg_ps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2VpnEvpnEsi>`
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop>`
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhteTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_p_ath = None
                                                self.add_path_orr_bitfield = YList()
                                                self.add_path_orr_bitfield.parent = self
                                                self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                self.advertisedto_pe = None
                                                self.aigp_metric = None
                                                self.best_path_comp_stage = None
                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self.best_path_id = None
                                                self.best_path_id_comp_winner = None
                                                self.best_path_orr_bitfield = YList()
                                                self.best_path_orr_bitfield.parent = self
                                                self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self.dampen_penalty = None
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.fspec_invalid_path = None
                                                self.graceful_shutdown = None
                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr()
                                                self.gw_addr.parent = self
                                                self.halflife_time = None
                                                self.has_esi = None
                                                self.has_gw_addr = None
                                                self.has_local_net_label = None
                                                self.has_mdt_group_addr = None
                                                self.has_mvpn_extcomm = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.has_rcvd_label = None
                                                self.has_second_label = None
                                                self.ibgp_signaled_validity = None
                                                self.igp_metric = None
                                                self.is_aggregation_suppressed = None
                                                self.is_as_best = None
                                                self.is_best_path = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_internal_path = None
                                                self.is_partial_best = None
                                                self.is_path_additional_path = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_af_install_eligible = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_damped = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_history_held = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_imported = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_multipath = None
                                                self.is_path_nexthop_discarded = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebg_ps = None
                                                self.is_path_received_only = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_stale = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_valid = None
                                                self.is_path_vpn_only = None
                                                self.is_permanent_path = None
                                                self.is_received_path_not_modified = None
                                                self.is_spkr_as_best = None
                                                self.l2vpn_circuit_status_value = YList()
                                                self.l2vpn_circuit_status_value.parent = self
                                                self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2VpnEvpnEsi()
                                                self.l2vpn_evpn_esi.parent = self
                                                self.l2vpn_size = None
                                                self.labeled_unicast_safi_path = None
                                                self.local_label = None
                                                self.local_nh = None
                                                self.local_path_id = None
                                                self.local_peers_advertised_to = YList()
                                                self.local_peers_advertised_to.parent = self
                                                self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                self.maximum_suppress_time = None
                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self.mvpn_path_flags = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_value = YList()
                                                self.mvpn_pmsi_value.parent = self
                                                self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                self.mvpn_sfs_path = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.neighbor_router_id = None
                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop()
                                                self.next_hop.parent = self
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.path_flags = None
                                                self.path_flap_count = None
                                                self.path_import_flags = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.path_table_version = None
                                                self.path_weight = None
                                                self.pe_peers_advertised_to = YList()
                                                self.pe_peers_advertised_to.parent = self
                                                self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                self.rcvd_label = None
                                                self.rcvd_path_id = None
                                                self.reuse_value = None
                                                self.rib_failed = None
                                                self.route_type = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.rt_set_limit_enabled = None
                                                self.second_label = None
                                                self.seconds_since_first_flap = None
                                                self.show_rpki_origin_as_validity = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.suppress_penalty = None
                                                self.time_to_unsuppress = None


                                            class BgpPrefix(object):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self.prefix_length = None


                                                class Prefix(object):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.prefix is not None and self.prefix._has_data():
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix']['meta_info']


                                            class NeighborAddress(object):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress']['meta_info']


                                            class NextHop(object):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhteTunnel']['meta_info']


                                            class MdtGroupAddr(object):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr']['meta_info']


                                            class L2VpnEvpnEsi(object):
                                                """
                                                L2VPN EVPN ESI
                                                
                                                .. attribute:: esi
                                                
                                                	esi
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.esi = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.esi is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2VpnEvpnEsi']['meta_info']


                                            class GwAddr(object):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr']['meta_info']


                                            class BestPathCompWinner(object):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner']['meta_info']


                                            class MvpnNbrAddr(object):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr']['meta_info']


                                            class MvpnNexthopAddr(object):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr']['meta_info']


                                            class L2VpnCircuitStatusValue(object):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue']['meta_info']


                                            class MvpnPmsiValue(object):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity']['meta_info']


                                            class LocalPeersAdvertisedTo(object):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo']['meta_info']


                                            class PePeersAdvertisedTo(object):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo']['meta_info']


                                            class BestPathOrrBitfield(object):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield']['meta_info']


                                            class AddPathOrrBitfield(object):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-info-after-policy-out'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.accept_own_path is not None:
                                                    return True

                                                if self.accept_own_self_originated_p_ath is not None:
                                                    return True

                                                if self.add_path_orr_bitfield is not None:
                                                    for child_ref in self.add_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.advertisedto_pe is not None:
                                                    return True

                                                if self.aigp_metric is not None:
                                                    return True

                                                if self.best_path_comp_stage is not None:
                                                    return True

                                                if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                    return True

                                                if self.best_path_id is not None:
                                                    return True

                                                if self.best_path_id_comp_winner is not None:
                                                    return True

                                                if self.best_path_orr_bitfield is not None:
                                                    for child_ref in self.best_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                    return True

                                                if self.dampen_penalty is not None:
                                                    return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.fspec_invalid_path is not None:
                                                    return True

                                                if self.graceful_shutdown is not None:
                                                    return True

                                                if self.gw_addr is not None and self.gw_addr._has_data():
                                                    return True

                                                if self.halflife_time is not None:
                                                    return True

                                                if self.has_esi is not None:
                                                    return True

                                                if self.has_gw_addr is not None:
                                                    return True

                                                if self.has_local_net_label is not None:
                                                    return True

                                                if self.has_mdt_group_addr is not None:
                                                    return True

                                                if self.has_mvpn_extcomm is not None:
                                                    return True

                                                if self.has_mvpn_nbr_addr is not None:
                                                    return True

                                                if self.has_mvpn_nexthop_addr is not None:
                                                    return True

                                                if self.has_mvpn_pmsi is not None:
                                                    return True

                                                if self.has_rcvd_label is not None:
                                                    return True

                                                if self.has_second_label is not None:
                                                    return True

                                                if self.ibgp_signaled_validity is not None:
                                                    return True

                                                if self.igp_metric is not None:
                                                    return True

                                                if self.is_aggregation_suppressed is not None:
                                                    return True

                                                if self.is_as_best is not None:
                                                    return True

                                                if self.is_best_path is not None:
                                                    return True

                                                if self.is_import_dampened is not None:
                                                    return True

                                                if self.is_import_suspect is not None:
                                                    return True

                                                if self.is_internal_path is not None:
                                                    return True

                                                if self.is_partial_best is not None:
                                                    return True

                                                if self.is_path_additional_path is not None:
                                                    return True

                                                if self.is_path_advertised_local_as_only is not None:
                                                    return True

                                                if self.is_path_af_install_eligible is not None:
                                                    return True

                                                if self.is_path_backup is not None:
                                                    return True

                                                if self.is_path_backup_protect_multipath is not None:
                                                    return True

                                                if self.is_path_best_external is not None:
                                                    return True

                                                if self.is_path_damped is not None:
                                                    return True

                                                if self.is_path_from_confederation_peer is not None:
                                                    return True

                                                if self.is_path_from_network_command is not None:
                                                    return True

                                                if self.is_path_from_redistribute_command is not None:
                                                    return True

                                                if self.is_path_from_route_reflector is not None:
                                                    return True

                                                if self.is_path_history_held is not None:
                                                    return True

                                                if self.is_path_imp_candidate is not None:
                                                    return True

                                                if self.is_path_imported is not None:
                                                    return True

                                                if self.is_path_local_aggregate is not None:
                                                    return True

                                                if self.is_path_locally_sourced is not None:
                                                    return True

                                                if self.is_path_long_lived_stale is not None:
                                                    return True

                                                if self.is_path_multipath is not None:
                                                    return True

                                                if self.is_path_nexthop_discarded is not None:
                                                    return True

                                                if self.is_path_not_advertised is not None:
                                                    return True

                                                if self.is_path_not_advertised_to_ebg_ps is not None:
                                                    return True

                                                if self.is_path_received_only is not None:
                                                    return True

                                                if self.is_path_reoriginated is not None:
                                                    return True

                                                if self.is_path_reoriginated_stitching is not None:
                                                    return True

                                                if self.is_path_stale is not None:
                                                    return True

                                                if self.is_path_synced_with_igp is not None:
                                                    return True

                                                if self.is_path_valid is not None:
                                                    return True

                                                if self.is_path_vpn_only is not None:
                                                    return True

                                                if self.is_permanent_path is not None:
                                                    return True

                                                if self.is_received_path_not_modified is not None:
                                                    return True

                                                if self.is_spkr_as_best is not None:
                                                    return True

                                                if self.l2vpn_circuit_status_value is not None:
                                                    for child_ref in self.l2vpn_circuit_status_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                    return True

                                                if self.l2vpn_size is not None:
                                                    return True

                                                if self.labeled_unicast_safi_path is not None:
                                                    return True

                                                if self.local_label is not None:
                                                    return True

                                                if self.local_nh is not None:
                                                    return True

                                                if self.local_path_id is not None:
                                                    return True

                                                if self.local_peers_advertised_to is not None:
                                                    for child_ref in self.local_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.maximum_suppress_time is not None:
                                                    return True

                                                if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                    return True

                                                if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                    return True

                                                if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                    return True

                                                if self.mvpn_path_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_label is not None:
                                                    return True

                                                if self.mvpn_pmsi_type is not None:
                                                    return True

                                                if self.mvpn_pmsi_value is not None:
                                                    for child_ref in self.mvpn_pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.mvpn_sfs_path is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.neighbor_router_id is not None:
                                                    return True

                                                if self.next_hop is not None and self.next_hop._has_data():
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.path_flags is not None:
                                                    return True

                                                if self.path_flap_count is not None:
                                                    return True

                                                if self.path_import_flags is not None:
                                                    return True

                                                if self.path_rt_set_id is not None:
                                                    return True

                                                if self.path_rt_set_route_count is not None:
                                                    return True

                                                if self.path_table_version is not None:
                                                    return True

                                                if self.path_weight is not None:
                                                    return True

                                                if self.pe_peers_advertised_to is not None:
                                                    for child_ref in self.pe_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.rcvd_label is not None:
                                                    return True

                                                if self.rcvd_path_id is not None:
                                                    return True

                                                if self.reuse_value is not None:
                                                    return True

                                                if self.rib_failed is not None:
                                                    return True

                                                if self.route_type is not None:
                                                    return True

                                                if self.rpki_origin_as_validation_disabled is not None:
                                                    return True

                                                if self.rt_set_limit_enabled is not None:
                                                    return True

                                                if self.second_label is not None:
                                                    return True

                                                if self.seconds_since_first_flap is not None:
                                                    return True

                                                if self.show_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.sn_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.suppress_penalty is not None:
                                                    return True

                                                if self.time_to_unsuppress is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut']['meta_info']


                                        class AttributesAfterPolicyIn(object):
                                            """
                                            Attributes after inbound policy
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self.is_application_gateway_present = None
                                                self.is_as_path2_byte = None
                                                self.is_attr_set_present = None
                                                self.is_ribrnh_present = None
                                                self.is_rnh_present = None
                                                self.ribrnh_encap = None
                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self.ribrnh_mac = None
                                                self.ribrnh_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnhip_table = None
                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self.rnh_addr_len = None
                                                self.rnh_len = None
                                                self.rnh_type = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.vpn_distinguisher = None


                                            class CommonAttributes(object):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                            class AttrSet(object):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                            class RnhAddr(object):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None
                                                    self.mac_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    if self.mac_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                            class RibrnhIp(object):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.attr_set is not None and self.attr_set._has_data():
                                                    return True

                                                if self.attribute_key_number is not None:
                                                    return True

                                                if self.attribute_reuse_id_config is not None:
                                                    return True

                                                if self.attribute_reuse_id_current is not None:
                                                    return True

                                                if self.attribute_reuse_id_keys is not None:
                                                    return True

                                                if self.attribute_reuse_id_max_id is not None:
                                                    return True

                                                if self.attribute_reuse_id_node is not None:
                                                    return True

                                                if self.attribute_reuse_id_recover_sec is not None:
                                                    return True

                                                if self.common_attributes is not None and self.common_attributes._has_data():
                                                    return True

                                                if self.is_application_gateway_present is not None:
                                                    return True

                                                if self.is_as_path2_byte is not None:
                                                    return True

                                                if self.is_attr_set_present is not None:
                                                    return True

                                                if self.is_ribrnh_present is not None:
                                                    return True

                                                if self.is_rnh_present is not None:
                                                    return True

                                                if self.ribrnh_encap is not None:
                                                    return True

                                                if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                    return True

                                                if self.ribrnh_mac is not None:
                                                    return True

                                                if self.ribrnh_table is not None:
                                                    return True

                                                if self.ribrnh_vni is not None:
                                                    return True

                                                if self.ribrnhip_table is not None:
                                                    return True

                                                if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                    return True

                                                if self.rnh_addr_len is not None:
                                                    return True

                                                if self.rnh_len is not None:
                                                    return True

                                                if self.rnh_type is not None:
                                                    return True

                                                if self.set_aigp_inbound_igp is not None:
                                                    return True

                                                if self.set_aigp_inbound_metric is not None:
                                                    return True

                                                if self.vpn_distinguisher is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn']['meta_info']


                                        class AttributesAfterPolicyOut(object):
                                            """
                                            Attributes after outbound policy
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet()
                                                self.attr_set.parent = self
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self.is_application_gateway_present = None
                                                self.is_as_path2_byte = None
                                                self.is_attr_set_present = None
                                                self.is_ribrnh_present = None
                                                self.is_rnh_present = None
                                                self.ribrnh_encap = None
                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self.ribrnh_mac = None
                                                self.ribrnh_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnhip_table = None
                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self.rnh_addr_len = None
                                                self.rnh_len = None
                                                self.rnh_type = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.vpn_distinguisher = None


                                            class CommonAttributes(object):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes']['meta_info']


                                            class AttrSet(object):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet']['meta_info']


                                            class RnhAddr(object):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None
                                                    self.mac_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    if self.mac_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr']['meta_info']


                                            class RibrnhIp(object):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-out'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.attr_set is not None and self.attr_set._has_data():
                                                    return True

                                                if self.attribute_key_number is not None:
                                                    return True

                                                if self.attribute_reuse_id_config is not None:
                                                    return True

                                                if self.attribute_reuse_id_current is not None:
                                                    return True

                                                if self.attribute_reuse_id_keys is not None:
                                                    return True

                                                if self.attribute_reuse_id_max_id is not None:
                                                    return True

                                                if self.attribute_reuse_id_node is not None:
                                                    return True

                                                if self.attribute_reuse_id_recover_sec is not None:
                                                    return True

                                                if self.common_attributes is not None and self.common_attributes._has_data():
                                                    return True

                                                if self.is_application_gateway_present is not None:
                                                    return True

                                                if self.is_as_path2_byte is not None:
                                                    return True

                                                if self.is_attr_set_present is not None:
                                                    return True

                                                if self.is_ribrnh_present is not None:
                                                    return True

                                                if self.is_rnh_present is not None:
                                                    return True

                                                if self.ribrnh_encap is not None:
                                                    return True

                                                if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                    return True

                                                if self.ribrnh_mac is not None:
                                                    return True

                                                if self.ribrnh_table is not None:
                                                    return True

                                                if self.ribrnh_vni is not None:
                                                    return True

                                                if self.ribrnhip_table is not None:
                                                    return True

                                                if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                    return True

                                                if self.rnh_addr_len is not None:
                                                    return True

                                                if self.rnh_len is not None:
                                                    return True

                                                if self.rnh_type is not None:
                                                    return True

                                                if self.set_aigp_inbound_igp is not None:
                                                    return True

                                                if self.set_aigp_inbound_metric is not None:
                                                    return True

                                                if self.vpn_distinguisher is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:policy'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                return True

                                            if self.attributes_after_policy_out is not None and self.attributes_after_policy_out._has_data():
                                                return True

                                            if self.neighbor_address is not None:
                                                return True

                                            if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                return True

                                            if self.network is not None:
                                                return True

                                            if self.no_path is not None:
                                                return True

                                            if self.path_info_after_policy_in is not None and self.path_info_after_policy_in._has_data():
                                                return True

                                            if self.path_info_after_policy_out is not None and self.path_info_after_policy_out._has_data():
                                                return True

                                            if self.prefix_length is not None:
                                                return True

                                            if self.rd is not None:
                                                return True

                                            if self.route_distinguisher is not None:
                                                return True

                                            if self.source_route_distinguisher is not None:
                                                return True

                                            if self.vrf_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:policies'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.policy is not None:
                                            for child_ref in self.policy:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies']['meta_info']


                                class Convergence(object):
                                    """
                                    A BGP Convergence table entry
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: are_write_queues_empty
                                    
                                    	All neighbor write queues are empty
                                    	**type**\:  bool
                                    
                                    .. attribute:: has_converged
                                    
                                    	Convergence has been reached
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.are_write_queues_empty = None
                                        self.has_converged = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:convergence'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.are_write_queues_empty is not None:
                                            return True

                                        if self.has_converged is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Convergence']['meta_info']


                                class AfProcessInfo(object):
                                    """
                                    A BGP Process address family table entry
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family id
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: global_
                                    
                                    	Global information
                                    	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_>`
                                    
                                    .. attribute:: performance_statistics
                                    
                                    	Performance statistics
                                    	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics>`
                                    
                                    .. attribute:: process_instance
                                    
                                    	ID for the BGP process instance
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:   :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Vrf_>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    .. attribute:: vrf_totals
                                    
                                    	per VRF information aggregated across all VRFs
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.global_ = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_()
                                        self.global_.parent = self
                                        self.performance_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics()
                                        self.performance_statistics.parent = self
                                        self.process_instance = None
                                        self.vrf = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Vrf_()
                                        self.vrf.parent = self
                                        self.vrf_name = None
                                        self.vrf_totals = None


                                    class Global_(object):
                                        """
                                        Global information
                                        
                                        .. attribute:: freed_rd_count
                                        
                                        	Activity\: Number of RDs freed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_bgp_version
                                        
                                        	BGP version when Import thread is last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_last_trigger
                                        
                                        	Timestamp when Import thread is last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: import_triggers
                                        
                                        	Import thread triggers
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_version
                                        
                                        	Version updated by import thread
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: imported_paths_memory
                                        
                                        	Total imported paths memory
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: imported_paths_num
                                        
                                        	Total impoorted paths 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_bgp_version
                                        
                                        	BGP version when label thread is last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_last_trigger
                                        
                                        	Timestamp when Label thread is last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: label_triggers
                                        
                                        	Label thread triggers
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_version
                                        
                                        	Version updated by label thread
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_import_version
                                        
                                        	Import thread version when last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_label_version
                                        
                                        	Label thread version when last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_rib_version
                                        
                                        	RIB thread version when last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_networks_freed_num
                                        
                                        	Total local networks freed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_networks_malloced_num
                                        
                                        	Total local networks malloced
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_networks_memory
                                        
                                        	Total local networks memory
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_networks_num
                                        
                                        	Total local networks
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_paths_freed_num
                                        
                                        	Total local paths freed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_paths_malloced_num
                                        
                                        	Total local paths malloced
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_paths_memory
                                        
                                        	Total local paths memory
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_paths_num
                                        
                                        	Total local paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: malloced_rd_count
                                        
                                        	Activity\: Number of RDs malloced
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: max_active_pelem_version
                                        
                                        	Maximum Active Pelem Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: merged_table_version
                                        
                                        	Merged Table Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multipath_network_entry_count
                                        
                                        	Number of multipath network entries
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multipath_network_entry_memory
                                        
                                        	Memory (in bytes) used bymultipath network entries
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: multipath_paths_count
                                        
                                        	Number of multipath paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multipath_paths_memory
                                        
                                        	Memory (in bytes) used bymultimpath paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: networks_freed_num
                                        
                                        	Total networks freed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: networks_malloced_num
                                        
                                        	Total networks malloced
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: networks_memory
                                        
                                        	Total networks memory
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: networks_num
                                        
                                        	Total Num of networks
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_init_sync_pfx
                                        
                                        	Num of prefix synced during Initsync
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_elems_freed_num
                                        
                                        	Total path\-elems freed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_elems_malloced_num
                                        
                                        	Total path\-elems malloced
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_elems_memory
                                        
                                        	Total path\-elems memory
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_elems_num
                                        
                                        	Total Num of path\-elems
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: paths_freed_num
                                        
                                        	Total paths freed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: paths_malloced_num
                                        
                                        	Total paths malloced
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: paths_memory
                                        
                                        	Total paths memory
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: paths_num
                                        
                                        	Total Num of paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rd_memory
                                        
                                        	Memory (in bytes) used by RD data
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rib_ack_requests
                                        
                                        	Counter for RIB ack requests
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_acked_table_version
                                        
                                        	Table version acked by RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_acks_received
                                        
                                        	Counter for RIB ack received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_brib_received_version
                                        
                                        	Version received from 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_install
                                        
                                        	RIB install info
                                        	**type**\:   :py:class:`RibInstall <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall>`
                                        
                                        .. attribute:: rib_last_trigger
                                        
                                        	Timestamp when RIB thread is last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: rib_slow_acks
                                        
                                        	Counter for slow RIB acks
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_triggers
                                        
                                        	RIB thread triggers
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribbgp_version
                                        
                                        	BGP version when RIB thread is last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_download_go_active_done_pending
                                        
                                        	Route Download Go Active Done Pending
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: router_state
                                        
                                        	Router state
                                        	**type**\:   :py:class:`BgpRtrStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRtrStateEnum>`
                                        
                                        .. attribute:: send_version
                                        
                                        	Version for sending updates to peers
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: standby_version
                                        
                                        	Version updated by sync thread
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: table_brib_version
                                        
                                        	Version sent to RIB/bRIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: table_version
                                        
                                        	BGP table version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_r_ds_num
                                        
                                        	Total Num of RDs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_remote_r_ds_num
                                        
                                        	Total Num of remote RDs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_same_r_ds_num
                                        
                                        	Total Num of same RDs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: trigger_import
                                        
                                        	Trigger import
                                        	**type**\:   :py:class:`TriggerImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport>`
                                        
                                        .. attribute:: trigger_label
                                        
                                        	Trigger label
                                        	**type**\:   :py:class:`TriggerLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel>`
                                        
                                        .. attribute:: trigger_rib
                                        
                                        	Trigger RIB
                                        	**type**\:   :py:class:`TriggerRib <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib>`
                                        
                                        .. attribute:: trigger_update
                                        
                                        	Trigger update
                                        	**type**\:   :py:class:`TriggerUpdate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate>`
                                        
                                        .. attribute:: update_gen_bgp_version
                                        
                                        	BGP version when Update generation thread is last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_gen_last_trigger
                                        
                                        	Timestamp when Update generation thread is last triggered
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_triggers
                                        
                                        	Update thread triggers
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_wait_install_enabled
                                        
                                        	Update wait\-install enabled
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version_wrap_done_time_spec
                                        
                                        	Version Wrap handle Done timestamp
                                        	**type**\:   :py:class:`VersionWrapDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapDoneTimeSpec>`
                                        
                                        .. attribute:: version_wrap_start_time_spec
                                        
                                        	Version Wrap handle start timestamp
                                        	**type**\:   :py:class:`VersionWrapStartTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapStartTimeSpec>`
                                        
                                        .. attribute:: version_wrap_time_spec
                                        
                                        	Version Wrap timestamp
                                        	**type**\:   :py:class:`VersionWrapTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapTimeSpec>`
                                        
                                        .. attribute:: version_wrapped
                                        
                                        	Number of times Version Wrap happened
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version_wrapped_tid
                                        
                                        	Version Wrapped trigger tid
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.freed_rd_count = None
                                            self.import_bgp_version = None
                                            self.import_last_trigger = None
                                            self.import_triggers = None
                                            self.import_version = None
                                            self.imported_paths_memory = None
                                            self.imported_paths_num = None
                                            self.label_bgp_version = None
                                            self.label_last_trigger = None
                                            self.label_triggers = None
                                            self.label_version = None
                                            self.last_import_version = None
                                            self.last_label_version = None
                                            self.last_rib_version = None
                                            self.local_networks_freed_num = None
                                            self.local_networks_malloced_num = None
                                            self.local_networks_memory = None
                                            self.local_networks_num = None
                                            self.local_paths_freed_num = None
                                            self.local_paths_malloced_num = None
                                            self.local_paths_memory = None
                                            self.local_paths_num = None
                                            self.malloced_rd_count = None
                                            self.max_active_pelem_version = None
                                            self.merged_table_version = None
                                            self.multipath_network_entry_count = None
                                            self.multipath_network_entry_memory = None
                                            self.multipath_paths_count = None
                                            self.multipath_paths_memory = None
                                            self.networks_freed_num = None
                                            self.networks_malloced_num = None
                                            self.networks_memory = None
                                            self.networks_num = None
                                            self.num_init_sync_pfx = None
                                            self.path_elems_freed_num = None
                                            self.path_elems_malloced_num = None
                                            self.path_elems_memory = None
                                            self.path_elems_num = None
                                            self.paths_freed_num = None
                                            self.paths_malloced_num = None
                                            self.paths_memory = None
                                            self.paths_num = None
                                            self.rd_memory = None
                                            self.rib_ack_requests = None
                                            self.rib_acked_table_version = None
                                            self.rib_acks_received = None
                                            self.rib_brib_received_version = None
                                            self.rib_install = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall()
                                            self.rib_install.parent = self
                                            self.rib_last_trigger = None
                                            self.rib_slow_acks = None
                                            self.rib_triggers = None
                                            self.ribbgp_version = None
                                            self.route_download_go_active_done_pending = None
                                            self.router_state = None
                                            self.send_version = None
                                            self.standby_version = None
                                            self.table_brib_version = None
                                            self.table_version = None
                                            self.total_r_ds_num = None
                                            self.total_remote_r_ds_num = None
                                            self.total_same_r_ds_num = None
                                            self.trigger_import = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport()
                                            self.trigger_import.parent = self
                                            self.trigger_label = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel()
                                            self.trigger_label.parent = self
                                            self.trigger_rib = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib()
                                            self.trigger_rib.parent = self
                                            self.trigger_update = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate()
                                            self.trigger_update.parent = self
                                            self.update_gen_bgp_version = None
                                            self.update_gen_last_trigger = None
                                            self.update_triggers = None
                                            self.update_wait_install_enabled = None
                                            self.version_wrap_done_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapDoneTimeSpec()
                                            self.version_wrap_done_time_spec.parent = self
                                            self.version_wrap_start_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapStartTimeSpec()
                                            self.version_wrap_start_time_spec.parent = self
                                            self.version_wrap_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapTimeSpec()
                                            self.version_wrap_time_spec.parent = self
                                            self.version_wrapped = None
                                            self.version_wrapped_tid = None


                                        class VersionWrapTimeSpec(object):
                                            """
                                            Version Wrap timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-wrap-time-spec'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapTimeSpec']['meta_info']


                                        class VersionWrapStartTimeSpec(object):
                                            """
                                            Version Wrap handle start timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-wrap-start-time-spec'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapStartTimeSpec']['meta_info']


                                        class VersionWrapDoneTimeSpec(object):
                                            """
                                            Version Wrap handle Done timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-wrap-done-time-spec'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.VersionWrapDoneTimeSpec']['meta_info']


                                        class TriggerRib(object):
                                            """
                                            Trigger RIB
                                            
                                            .. attribute:: statistic
                                            
                                            	statistic
                                            	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic>`
                                            
                                            .. attribute:: triggers
                                            
                                            	Triggers
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.statistic = YList()
                                                self.statistic.parent = self
                                                self.statistic.name = 'statistic'
                                                self.triggers = None


                                            class Statistic(object):
                                                """
                                                statistic
                                                
                                                .. attribute:: trigger_table_version
                                                
                                                	TriggerTableVersion
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: trigger_time_spec
                                                
                                                	trigger time spec
                                                	**type**\:   :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic.TriggerTimeSpec>`
                                                
                                                .. attribute:: trigger_version
                                                
                                                	TriggerVersion
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.trigger_table_version = None
                                                    self.trigger_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic.TriggerTimeSpec()
                                                    self.trigger_time_spec.parent = self
                                                    self.trigger_version = None


                                                class TriggerTimeSpec(object):
                                                    """
                                                    trigger time spec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:trigger-time-spec'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic.TriggerTimeSpec']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:statistic'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.trigger_table_version is not None:
                                                        return True

                                                    if self.trigger_time_spec is not None and self.trigger_time_spec._has_data():
                                                        return True

                                                    if self.trigger_version is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:trigger-rib'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.statistic is not None:
                                                    for child_ref in self.statistic:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.triggers is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerRib']['meta_info']


                                        class TriggerImport(object):
                                            """
                                            Trigger import
                                            
                                            .. attribute:: statistic
                                            
                                            	statistic
                                            	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic>`
                                            
                                            .. attribute:: triggers
                                            
                                            	Triggers
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.statistic = YList()
                                                self.statistic.parent = self
                                                self.statistic.name = 'statistic'
                                                self.triggers = None


                                            class Statistic(object):
                                                """
                                                statistic
                                                
                                                .. attribute:: trigger_table_version
                                                
                                                	TriggerTableVersion
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: trigger_time_spec
                                                
                                                	trigger time spec
                                                	**type**\:   :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic.TriggerTimeSpec>`
                                                
                                                .. attribute:: trigger_version
                                                
                                                	TriggerVersion
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.trigger_table_version = None
                                                    self.trigger_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic.TriggerTimeSpec()
                                                    self.trigger_time_spec.parent = self
                                                    self.trigger_version = None


                                                class TriggerTimeSpec(object):
                                                    """
                                                    trigger time spec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:trigger-time-spec'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic.TriggerTimeSpec']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:statistic'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.trigger_table_version is not None:
                                                        return True

                                                    if self.trigger_time_spec is not None and self.trigger_time_spec._has_data():
                                                        return True

                                                    if self.trigger_version is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:trigger-import'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.statistic is not None:
                                                    for child_ref in self.statistic:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.triggers is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerImport']['meta_info']


                                        class TriggerUpdate(object):
                                            """
                                            Trigger update
                                            
                                            .. attribute:: statistic
                                            
                                            	statistic
                                            	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic>`
                                            
                                            .. attribute:: triggers
                                            
                                            	Triggers
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.statistic = YList()
                                                self.statistic.parent = self
                                                self.statistic.name = 'statistic'
                                                self.triggers = None


                                            class Statistic(object):
                                                """
                                                statistic
                                                
                                                .. attribute:: trigger_table_version
                                                
                                                	TriggerTableVersion
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: trigger_time_spec
                                                
                                                	trigger time spec
                                                	**type**\:   :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic.TriggerTimeSpec>`
                                                
                                                .. attribute:: trigger_version
                                                
                                                	TriggerVersion
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.trigger_table_version = None
                                                    self.trigger_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic.TriggerTimeSpec()
                                                    self.trigger_time_spec.parent = self
                                                    self.trigger_version = None


                                                class TriggerTimeSpec(object):
                                                    """
                                                    trigger time spec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:trigger-time-spec'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic.TriggerTimeSpec']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:statistic'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.trigger_table_version is not None:
                                                        return True

                                                    if self.trigger_time_spec is not None and self.trigger_time_spec._has_data():
                                                        return True

                                                    if self.trigger_version is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:trigger-update'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.statistic is not None:
                                                    for child_ref in self.statistic:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.triggers is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate']['meta_info']


                                        class TriggerLabel(object):
                                            """
                                            Trigger label
                                            
                                            .. attribute:: statistic
                                            
                                            	statistic
                                            	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic>`
                                            
                                            .. attribute:: triggers
                                            
                                            	Triggers
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.statistic = YList()
                                                self.statistic.parent = self
                                                self.statistic.name = 'statistic'
                                                self.triggers = None


                                            class Statistic(object):
                                                """
                                                statistic
                                                
                                                .. attribute:: trigger_table_version
                                                
                                                	TriggerTableVersion
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: trigger_time_spec
                                                
                                                	trigger time spec
                                                	**type**\:   :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic.TriggerTimeSpec>`
                                                
                                                .. attribute:: trigger_version
                                                
                                                	TriggerVersion
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.trigger_table_version = None
                                                    self.trigger_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic.TriggerTimeSpec()
                                                    self.trigger_time_spec.parent = self
                                                    self.trigger_version = None


                                                class TriggerTimeSpec(object):
                                                    """
                                                    trigger time spec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:trigger-time-spec'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic.TriggerTimeSpec']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:statistic'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.trigger_table_version is not None:
                                                        return True

                                                    if self.trigger_time_spec is not None and self.trigger_time_spec._has_data():
                                                        return True

                                                    if self.trigger_version is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:trigger-label'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.statistic is not None:
                                                    for child_ref in self.statistic:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.triggers is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel']['meta_info']


                                        class RibInstall(object):
                                            """
                                            RIB install info
                                            
                                            .. attribute:: install_time
                                            
                                            	RIB install time
                                            	**type**\:   :py:class:`InstallTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall.InstallTime>`
                                            
                                            .. attribute:: installed_count
                                            
                                            	Installed routes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: modified_count
                                            
                                            	Modified routes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: start_version
                                            
                                            	Start version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: target_version
                                            
                                            	Target version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_time
                                            
                                            	RIB update time
                                            	**type**\:   :py:class:`UpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall.UpdateTime>`
                                            
                                            .. attribute:: withdrawn_count
                                            
                                            	Withdrawn routes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.install_time = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall.InstallTime()
                                                self.install_time.parent = self
                                                self.installed_count = None
                                                self.modified_count = None
                                                self.start_version = None
                                                self.target_version = None
                                                self.update_time = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall.UpdateTime()
                                                self.update_time.parent = self
                                                self.withdrawn_count = None


                                            class UpdateTime(object):
                                                """
                                                RIB update time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-time'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall.UpdateTime']['meta_info']


                                            class InstallTime(object):
                                                """
                                                RIB install time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:install-time'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall.InstallTime']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rib-install'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.install_time is not None and self.install_time._has_data():
                                                    return True

                                                if self.installed_count is not None:
                                                    return True

                                                if self.modified_count is not None:
                                                    return True

                                                if self.start_version is not None:
                                                    return True

                                                if self.target_version is not None:
                                                    return True

                                                if self.update_time is not None and self.update_time._has_data():
                                                    return True

                                                if self.withdrawn_count is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_.RibInstall']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:global'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.freed_rd_count is not None:
                                                return True

                                            if self.import_bgp_version is not None:
                                                return True

                                            if self.import_last_trigger is not None:
                                                return True

                                            if self.import_triggers is not None:
                                                return True

                                            if self.import_version is not None:
                                                return True

                                            if self.imported_paths_memory is not None:
                                                return True

                                            if self.imported_paths_num is not None:
                                                return True

                                            if self.label_bgp_version is not None:
                                                return True

                                            if self.label_last_trigger is not None:
                                                return True

                                            if self.label_triggers is not None:
                                                return True

                                            if self.label_version is not None:
                                                return True

                                            if self.last_import_version is not None:
                                                return True

                                            if self.last_label_version is not None:
                                                return True

                                            if self.last_rib_version is not None:
                                                return True

                                            if self.local_networks_freed_num is not None:
                                                return True

                                            if self.local_networks_malloced_num is not None:
                                                return True

                                            if self.local_networks_memory is not None:
                                                return True

                                            if self.local_networks_num is not None:
                                                return True

                                            if self.local_paths_freed_num is not None:
                                                return True

                                            if self.local_paths_malloced_num is not None:
                                                return True

                                            if self.local_paths_memory is not None:
                                                return True

                                            if self.local_paths_num is not None:
                                                return True

                                            if self.malloced_rd_count is not None:
                                                return True

                                            if self.max_active_pelem_version is not None:
                                                return True

                                            if self.merged_table_version is not None:
                                                return True

                                            if self.multipath_network_entry_count is not None:
                                                return True

                                            if self.multipath_network_entry_memory is not None:
                                                return True

                                            if self.multipath_paths_count is not None:
                                                return True

                                            if self.multipath_paths_memory is not None:
                                                return True

                                            if self.networks_freed_num is not None:
                                                return True

                                            if self.networks_malloced_num is not None:
                                                return True

                                            if self.networks_memory is not None:
                                                return True

                                            if self.networks_num is not None:
                                                return True

                                            if self.num_init_sync_pfx is not None:
                                                return True

                                            if self.path_elems_freed_num is not None:
                                                return True

                                            if self.path_elems_malloced_num is not None:
                                                return True

                                            if self.path_elems_memory is not None:
                                                return True

                                            if self.path_elems_num is not None:
                                                return True

                                            if self.paths_freed_num is not None:
                                                return True

                                            if self.paths_malloced_num is not None:
                                                return True

                                            if self.paths_memory is not None:
                                                return True

                                            if self.paths_num is not None:
                                                return True

                                            if self.rd_memory is not None:
                                                return True

                                            if self.rib_ack_requests is not None:
                                                return True

                                            if self.rib_acked_table_version is not None:
                                                return True

                                            if self.rib_acks_received is not None:
                                                return True

                                            if self.rib_brib_received_version is not None:
                                                return True

                                            if self.rib_install is not None and self.rib_install._has_data():
                                                return True

                                            if self.rib_last_trigger is not None:
                                                return True

                                            if self.rib_slow_acks is not None:
                                                return True

                                            if self.rib_triggers is not None:
                                                return True

                                            if self.ribbgp_version is not None:
                                                return True

                                            if self.route_download_go_active_done_pending is not None:
                                                return True

                                            if self.router_state is not None:
                                                return True

                                            if self.send_version is not None:
                                                return True

                                            if self.standby_version is not None:
                                                return True

                                            if self.table_brib_version is not None:
                                                return True

                                            if self.table_version is not None:
                                                return True

                                            if self.total_r_ds_num is not None:
                                                return True

                                            if self.total_remote_r_ds_num is not None:
                                                return True

                                            if self.total_same_r_ds_num is not None:
                                                return True

                                            if self.trigger_import is not None and self.trigger_import._has_data():
                                                return True

                                            if self.trigger_label is not None and self.trigger_label._has_data():
                                                return True

                                            if self.trigger_rib is not None and self.trigger_rib._has_data():
                                                return True

                                            if self.trigger_update is not None and self.trigger_update._has_data():
                                                return True

                                            if self.update_gen_bgp_version is not None:
                                                return True

                                            if self.update_gen_last_trigger is not None:
                                                return True

                                            if self.update_triggers is not None:
                                                return True

                                            if self.update_wait_install_enabled is not None:
                                                return True

                                            if self.version_wrap_done_time_spec is not None and self.version_wrap_done_time_spec._has_data():
                                                return True

                                            if self.version_wrap_start_time_spec is not None and self.version_wrap_start_time_spec._has_data():
                                                return True

                                            if self.version_wrap_time_spec is not None and self.version_wrap_time_spec._has_data():
                                                return True

                                            if self.version_wrapped is not None:
                                                return True

                                            if self.version_wrapped_tid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global_']['meta_info']


                                    class Vrf_(object):
                                        """
                                        VRF information
                                        
                                        .. attribute:: add_path_install_disable
                                        
                                        	Additional paths installation is disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: add_path_install_enable
                                        
                                        	Additional paths installation is enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: any_ebgp_neighbor_missing_policy
                                        
                                        	Is there any neighbor which is missing either inbound or outbound or both routing policy for this address family?
                                        	**type**\:  bool
                                        
                                        .. attribute:: asbr
                                        
                                        	Router is an ASBR for this AF
                                        	**type**\:  bool
                                        
                                        .. attribute:: attribute_download
                                        
                                        	Attribute download is 
                                        	**type**\:  bool
                                        
                                        .. attribute:: best_external
                                        
                                        	Best External is enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: best_external_disable
                                        
                                        	Best External is enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: bmp_network_entry_count
                                        
                                        	Number of BMP net entries
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_path_memory
                                        
                                        	Memory (in bytes) used by path data
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bmp_paths_count
                                        
                                        	Total Number of BMP paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_prefix_memory
                                        
                                        	Memory (in bytes) used by prefix data
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: damped_path_count
                                        
                                        	Number of dampened paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: freed_path_count
                                        
                                        	Activity\: Number of paths freed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: freed_path_elem_count
                                        
                                        	Activity\: Number of pathelems freed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: freed_prefix_count
                                        
                                        	Activity\: Number of prefixes freed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: history_path_count
                                        
                                        	Number of history paths (for dampening)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ibgp_nexthop_self_count
                                        
                                        	Number of iBGP sessions configured with nh\-self
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: imported_path_memory
                                        
                                        	Memory (in bytes) used by imported paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: imported_paths
                                        
                                        	Number of imported paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_route_reflector
                                        
                                        	Router is an RR for this AF
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_retain
                                        
                                        	Label retention is enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_retainvalue
                                        
                                        	Label retention value enabled
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_path_memory
                                        
                                        	Memory (in bytes) used by local paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: local_paths
                                        
                                        	Number of local paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: malloced_path_count
                                        
                                        	Activity\: Number of paths malloced
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: malloced_path_elem_count
                                        
                                        	Activity\: Number of path elems malloced
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: malloced_prefix_count
                                        
                                        	Activity\: Number of prefixes malloced
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: network_entry_count
                                        
                                        	Number of network entries
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_elem_memory
                                        
                                        	Memory (in bytes) used by pathelem data
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: path_elems_count
                                        
                                        	Number of path elems
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_memory
                                        
                                        	Memory (in bytes) used by path data
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: paths_count
                                        
                                        	Number of paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefix_memory
                                        
                                        	Memory (in bytes) used by prefix data
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: received_path_count
                                        
                                        	Number of (unused) received paths for inbound soft reconfiguration
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: retain_rt_all
                                        
                                        	Retain\-RT\-All enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_target_download
                                        
                                        	Route Target download is enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: tbl_bitf_size
                                        
                                        	Bitfield size on table
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: tbl_chunk_bitf_size
                                        
                                        	Chunk Bitfield size on table
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: use_igpsr_label
                                        
                                        	Use IGP SR label for resolution
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.add_path_install_disable = None
                                            self.add_path_install_enable = None
                                            self.any_ebgp_neighbor_missing_policy = None
                                            self.asbr = None
                                            self.attribute_download = None
                                            self.best_external = None
                                            self.best_external_disable = None
                                            self.bmp_network_entry_count = None
                                            self.bmp_path_memory = None
                                            self.bmp_paths_count = None
                                            self.bmp_prefix_memory = None
                                            self.damped_path_count = None
                                            self.freed_path_count = None
                                            self.freed_path_elem_count = None
                                            self.freed_prefix_count = None
                                            self.history_path_count = None
                                            self.ibgp_nexthop_self_count = None
                                            self.imported_path_memory = None
                                            self.imported_paths = None
                                            self.is_route_reflector = None
                                            self.label_retain = None
                                            self.label_retainvalue = None
                                            self.local_path_memory = None
                                            self.local_paths = None
                                            self.malloced_path_count = None
                                            self.malloced_path_elem_count = None
                                            self.malloced_prefix_count = None
                                            self.network_entry_count = None
                                            self.path_elem_memory = None
                                            self.path_elems_count = None
                                            self.path_memory = None
                                            self.paths_count = None
                                            self.prefix_memory = None
                                            self.received_path_count = None
                                            self.retain_rt_all = None
                                            self.route_target_download = None
                                            self.tbl_bitf_size = None
                                            self.tbl_chunk_bitf_size = None
                                            self.use_igpsr_label = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:vrf'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.add_path_install_disable is not None:
                                                return True

                                            if self.add_path_install_enable is not None:
                                                return True

                                            if self.any_ebgp_neighbor_missing_policy is not None:
                                                return True

                                            if self.asbr is not None:
                                                return True

                                            if self.attribute_download is not None:
                                                return True

                                            if self.best_external is not None:
                                                return True

                                            if self.best_external_disable is not None:
                                                return True

                                            if self.bmp_network_entry_count is not None:
                                                return True

                                            if self.bmp_path_memory is not None:
                                                return True

                                            if self.bmp_paths_count is not None:
                                                return True

                                            if self.bmp_prefix_memory is not None:
                                                return True

                                            if self.damped_path_count is not None:
                                                return True

                                            if self.freed_path_count is not None:
                                                return True

                                            if self.freed_path_elem_count is not None:
                                                return True

                                            if self.freed_prefix_count is not None:
                                                return True

                                            if self.history_path_count is not None:
                                                return True

                                            if self.ibgp_nexthop_self_count is not None:
                                                return True

                                            if self.imported_path_memory is not None:
                                                return True

                                            if self.imported_paths is not None:
                                                return True

                                            if self.is_route_reflector is not None:
                                                return True

                                            if self.label_retain is not None:
                                                return True

                                            if self.label_retainvalue is not None:
                                                return True

                                            if self.local_path_memory is not None:
                                                return True

                                            if self.local_paths is not None:
                                                return True

                                            if self.malloced_path_count is not None:
                                                return True

                                            if self.malloced_path_elem_count is not None:
                                                return True

                                            if self.malloced_prefix_count is not None:
                                                return True

                                            if self.network_entry_count is not None:
                                                return True

                                            if self.path_elem_memory is not None:
                                                return True

                                            if self.path_elems_count is not None:
                                                return True

                                            if self.path_memory is not None:
                                                return True

                                            if self.paths_count is not None:
                                                return True

                                            if self.prefix_memory is not None:
                                                return True

                                            if self.received_path_count is not None:
                                                return True

                                            if self.retain_rt_all is not None:
                                                return True

                                            if self.route_target_download is not None:
                                                return True

                                            if self.tbl_bitf_size is not None:
                                                return True

                                            if self.tbl_chunk_bitf_size is not None:
                                                return True

                                            if self.use_igpsr_label is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Vrf_']['meta_info']


                                    class PerformanceStatistics(object):
                                        """
                                        Performance statistics
                                        
                                        .. attribute:: global_
                                        
                                        	Global information
                                        	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_>`
                                        
                                        .. attribute:: vrf
                                        
                                        	VRF information
                                        	**type**\:   :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.global_ = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_()
                                            self.global_.parent = self
                                            self.vrf = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_()
                                            self.vrf.parent = self


                                        class Global_(object):
                                            """
                                            Global information
                                            
                                            .. attribute:: first_nbr_up_time
                                            
                                            	Time when first peer came up (seconds since Jan 1 1970)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: has_converged
                                            
                                            	TRUE if process has converged
                                            	**type**\:  bool
                                            
                                            .. attribute:: mode_enter_time
                                            
                                            	Time that each mode was entered (seconds since  Jan 1 1970)
                                            	**type**\: list of    :py:class:`ModeEnterTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.ModeEnterTime>`
                                            
                                            .. attribute:: total_pim_callback_add
                                            
                                            	Total number of Pim callbacks for add
                                            	**type**\: list of    :py:class:`TotalPimCallbackAdd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAdd>`
                                            
                                            .. attribute:: total_pim_callback_add_local
                                            
                                            	Total number of Pim callbacks for local add
                                            	**type**\: list of    :py:class:`TotalPimCallbackAddLocal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAddLocal>`
                                            
                                            .. attribute:: total_pim_callback_batch
                                            
                                            	Total number of Pim callback batches
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: total_pim_callback_del
                                            
                                            	Total number of Pim callbacks for del
                                            	**type**\: list of    :py:class:`TotalPimCallbackDel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDel>`
                                            
                                            .. attribute:: total_pim_callback_del_local
                                            
                                            	Total number of Pim callbacks for Local del
                                            	**type**\: list of    :py:class:`TotalPimCallbackDelLocal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDelLocal>`
                                            
                                            .. attribute:: total_pim_callbacks
                                            
                                            	Total number of PIM callbacks
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: total_pim_install
                                            
                                            	Total number of install to PIM
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: total_pim_install_add
                                            
                                            	Total number of install to PIM for add
                                            	**type**\: list of    :py:class:`TotalPimInstallAdd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallAdd>`
                                            
                                            .. attribute:: total_pim_install_del
                                            
                                            	Total number of install to PIM for del
                                            	**type**\: list of    :py:class:`TotalPimInstallDel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallDel>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.first_nbr_up_time = None
                                                self.has_converged = None
                                                self.mode_enter_time = YList()
                                                self.mode_enter_time.parent = self
                                                self.mode_enter_time.name = 'mode_enter_time'
                                                self.total_pim_callback_add = YList()
                                                self.total_pim_callback_add.parent = self
                                                self.total_pim_callback_add.name = 'total_pim_callback_add'
                                                self.total_pim_callback_add_local = YList()
                                                self.total_pim_callback_add_local.parent = self
                                                self.total_pim_callback_add_local.name = 'total_pim_callback_add_local'
                                                self.total_pim_callback_batch = None
                                                self.total_pim_callback_del = YList()
                                                self.total_pim_callback_del.parent = self
                                                self.total_pim_callback_del.name = 'total_pim_callback_del'
                                                self.total_pim_callback_del_local = YList()
                                                self.total_pim_callback_del_local.parent = self
                                                self.total_pim_callback_del_local.name = 'total_pim_callback_del_local'
                                                self.total_pim_callbacks = None
                                                self.total_pim_install = None
                                                self.total_pim_install_add = YList()
                                                self.total_pim_install_add.parent = self
                                                self.total_pim_install_add.name = 'total_pim_install_add'
                                                self.total_pim_install_del = YList()
                                                self.total_pim_install_del.parent = self
                                                self.total_pim_install_del.name = 'total_pim_install_del'


                                            class ModeEnterTime(object):
                                                """
                                                Time that each mode was entered (seconds since
                                                
                                                Jan 1 1970)
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mode-enter-time'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.ModeEnterTime']['meta_info']


                                            class TotalPimInstallAdd(object):
                                                """
                                                Total number of install to PIM for add
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:total-pim-install-add'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallAdd']['meta_info']


                                            class TotalPimInstallDel(object):
                                                """
                                                Total number of install to PIM for del
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:total-pim-install-del'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallDel']['meta_info']


                                            class TotalPimCallbackAdd(object):
                                                """
                                                Total number of Pim callbacks for add
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:total-pim-callback-add'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAdd']['meta_info']


                                            class TotalPimCallbackDel(object):
                                                """
                                                Total number of Pim callbacks for del
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:total-pim-callback-del'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDel']['meta_info']


                                            class TotalPimCallbackAddLocal(object):
                                                """
                                                Total number of Pim callbacks for local add
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:total-pim-callback-add-local'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAddLocal']['meta_info']


                                            class TotalPimCallbackDelLocal(object):
                                                """
                                                Total number of Pim callbacks for Local del
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:total-pim-callback-del-local'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDelLocal']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:global'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.first_nbr_up_time is not None:
                                                    return True

                                                if self.has_converged is not None:
                                                    return True

                                                if self.mode_enter_time is not None:
                                                    for child_ref in self.mode_enter_time:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.total_pim_callback_add is not None:
                                                    for child_ref in self.total_pim_callback_add:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.total_pim_callback_add_local is not None:
                                                    for child_ref in self.total_pim_callback_add_local:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.total_pim_callback_batch is not None:
                                                    return True

                                                if self.total_pim_callback_del is not None:
                                                    for child_ref in self.total_pim_callback_del:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.total_pim_callback_del_local is not None:
                                                    for child_ref in self.total_pim_callback_del_local:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.total_pim_callbacks is not None:
                                                    return True

                                                if self.total_pim_install is not None:
                                                    return True

                                                if self.total_pim_install_add is not None:
                                                    for child_ref in self.total_pim_install_add:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.total_pim_install_del is not None:
                                                    for child_ref in self.total_pim_install_del:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_']['meta_info']


                                        class Vrf_(object):
                                            """
                                            VRF information
                                            
                                            .. attribute:: attributes_recover_from_rib
                                            
                                            	No. of attributes recovered from RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attributes_removed_from_rib
                                            
                                            	No. of attributes withdrawn from RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attributes_sent_to_rib
                                            
                                            	No. of attributes sent to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: first_rib_table_full_timestamp
                                            
                                            	Timestamp when RIB table was full for the first time
                                            	**type**\:   :py:class:`FirstRibTableFullTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.FirstRibTableFullTimestamp>`
                                            
                                            .. attribute:: first_rib_table_full_version
                                            
                                            	Version when RIB table was full for the first time
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: first_rib_table_has_space_timestamp
                                            
                                            	Timestamp when RIB table had space for the first time
                                            	**type**\:   :py:class:`FirstRibTableHasSpaceTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.FirstRibTableHasSpaceTimestamp>`
                                            
                                            .. attribute:: first_rib_table_has_space_version
                                            
                                            	Version when RIB table had space for the first time
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_added_path_count
                                            
                                            	Number of imported paths added
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_calls
                                            
                                            	Number of calls to import processing function
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_dest_net_processed_count
                                            
                                            	Number of destination nets processed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_removed_path_count
                                            
                                            	Number of imported paths removed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_replaced_path_count
                                            
                                            	Number of imported paths 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_src_net_processed_count
                                            
                                            	Number of source nets processed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_time
                                            
                                            	Time spent in import processing (milliseconds) Note time accounted against source nets
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: is_rib_table_full
                                            
                                            	Indicates if RIB table is in prefix\-limit state
                                            	**type**\:  bool
                                            
                                            .. attribute:: label_added_count
                                            
                                            	Number of labels requested
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_calls
                                            
                                            	No. of calls to label allocation processing function
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_release_count
                                            
                                            	Number of labels released
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_rewrite_count
                                            
                                            	Number of label rewrites created
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_time
                                            
                                            	Time spent running label processing (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: last_rib_table_full_age
                                            
                                            	Time since RIB table was full for the last time (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_rib_table_full_timestamp
                                            
                                            	Timestamp when RIB table was full for the last time
                                            	**type**\:   :py:class:`LastRibTableFullTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.LastRibTableFullTimestamp>`
                                            
                                            .. attribute:: last_rib_table_full_version
                                            
                                            	Version when RIB table was full for the last time
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_rib_table_has_space_age
                                            
                                            	Times since RIB table had space for the last time (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_rib_table_has_space_timestamp
                                            
                                            	Timestamp when RIB table had space for the last time
                                            	**type**\:   :py:class:`LastRibTableHasSpaceTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.LastRibTableHasSpaceTimestamp>`
                                            
                                            .. attribute:: last_rib_table_has_space_version
                                            
                                            	Version when RIB table had space for the last time
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_removed_from_rib
                                            
                                            	No. of prefixes withdrawn from RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_resent_to_rib
                                            
                                            	No. of prefixes re\-sent to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_sent_to_rib
                                            
                                            	No. of prefixes sent to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_table_full_version
                                            
                                            	Version when RIB table became full (from non\-full)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_tbl_del_calls
                                            
                                            	No. of rib update skipped on account of table delete
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_tbl_invalid_calls
                                            
                                            	No. of  rib update skipped due to table invalid
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_tbl_local_label
                                            
                                            	No. of rib update skipped. due to no local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_tbl_retry
                                            
                                            	No. of table rib retires
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_tbl_skip_calls
                                            
                                            	No. of rib update skipped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_trigger
                                            
                                            	Rib trigger enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rib_update_calls
                                            
                                            	No. of calls to RIB update function
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_update_time
                                            
                                            	Time spent sending RIB updates (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: scanner_runs
                                            
                                            	# of times scanner has run
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: scanner_time
                                            
                                            	Time spent running scanner (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: subgroup_count
                                            
                                            	No. of update subgroup
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_label_retain
                                            
                                            	Time last label retentiontriggered 
                                            	**type**\:   :py:class:`TimeLabelRetain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeLabelRetain>`
                                            
                                            .. attribute:: time_last_update_sent
                                            
                                            	Time last update was sent (seconds since Jan 1 1970)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: time_rib_coverged
                                            
                                            	Time last RIB ack was sent 
                                            	**type**\:   :py:class:`TimeRibCoverged <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeRibCoverged>`
                                            
                                            .. attribute:: time_rib_down
                                            
                                            	Time last RIB down wassent. This field is deprecated
                                            	**type**\:   :py:class:`TimeRibDown <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeRibDown>`
                                            
                                            .. attribute:: update_generation_be_prefixes_count
                                            
                                            	No. of be prefixes updates generated for
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_calls
                                            
                                            	No. of calls to update generation function
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_messages_count
                                            
                                            	No. of update messages generated
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_prefixes_count
                                            
                                            	No. of prefixes updates generated for
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_time
                                            
                                            	Time spent generating updates (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: update_group_count
                                            
                                            	No. of update group
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vrf_flags
                                            
                                            	VRF flags for debug display
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.attributes_recover_from_rib = None
                                                self.attributes_removed_from_rib = None
                                                self.attributes_sent_to_rib = None
                                                self.first_rib_table_full_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.FirstRibTableFullTimestamp()
                                                self.first_rib_table_full_timestamp.parent = self
                                                self.first_rib_table_full_version = None
                                                self.first_rib_table_has_space_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.FirstRibTableHasSpaceTimestamp()
                                                self.first_rib_table_has_space_timestamp.parent = self
                                                self.first_rib_table_has_space_version = None
                                                self.import_added_path_count = None
                                                self.import_calls = None
                                                self.import_dest_net_processed_count = None
                                                self.import_removed_path_count = None
                                                self.import_replaced_path_count = None
                                                self.import_src_net_processed_count = None
                                                self.import_time = None
                                                self.is_rib_table_full = None
                                                self.label_added_count = None
                                                self.label_calls = None
                                                self.label_release_count = None
                                                self.label_rewrite_count = None
                                                self.label_time = None
                                                self.last_rib_table_full_age = None
                                                self.last_rib_table_full_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.LastRibTableFullTimestamp()
                                                self.last_rib_table_full_timestamp.parent = self
                                                self.last_rib_table_full_version = None
                                                self.last_rib_table_has_space_age = None
                                                self.last_rib_table_has_space_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.LastRibTableHasSpaceTimestamp()
                                                self.last_rib_table_has_space_timestamp.parent = self
                                                self.last_rib_table_has_space_version = None
                                                self.prefixes_removed_from_rib = None
                                                self.prefixes_resent_to_rib = None
                                                self.prefixes_sent_to_rib = None
                                                self.rib_table_full_version = None
                                                self.rib_tbl_del_calls = None
                                                self.rib_tbl_invalid_calls = None
                                                self.rib_tbl_local_label = None
                                                self.rib_tbl_retry = None
                                                self.rib_tbl_skip_calls = None
                                                self.rib_trigger = None
                                                self.rib_update_calls = None
                                                self.rib_update_time = None
                                                self.scanner_runs = None
                                                self.scanner_time = None
                                                self.subgroup_count = None
                                                self.time_label_retain = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeLabelRetain()
                                                self.time_label_retain.parent = self
                                                self.time_last_update_sent = None
                                                self.time_rib_coverged = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeRibCoverged()
                                                self.time_rib_coverged.parent = self
                                                self.time_rib_down = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeRibDown()
                                                self.time_rib_down.parent = self
                                                self.update_generation_be_prefixes_count = None
                                                self.update_generation_calls = None
                                                self.update_generation_messages_count = None
                                                self.update_generation_prefixes_count = None
                                                self.update_generation_time = None
                                                self.update_group_count = None
                                                self.vrf_flags = None


                                            class TimeRibCoverged(object):
                                                """
                                                Time last RIB ack was sent 
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:time-rib-coverged'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeRibCoverged']['meta_info']


                                            class TimeRibDown(object):
                                                """
                                                Time last RIB down wassent. This field is
                                                deprecated
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:time-rib-down'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeRibDown']['meta_info']


                                            class FirstRibTableFullTimestamp(object):
                                                """
                                                Timestamp when RIB table was full for the first
                                                time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-rib-table-full-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.FirstRibTableFullTimestamp']['meta_info']


                                            class LastRibTableFullTimestamp(object):
                                                """
                                                Timestamp when RIB table was full for the last
                                                time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-rib-table-full-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.LastRibTableFullTimestamp']['meta_info']


                                            class FirstRibTableHasSpaceTimestamp(object):
                                                """
                                                Timestamp when RIB table had space for the first
                                                time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-rib-table-has-space-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.FirstRibTableHasSpaceTimestamp']['meta_info']


                                            class LastRibTableHasSpaceTimestamp(object):
                                                """
                                                Timestamp when RIB table had space for the last
                                                time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-rib-table-has-space-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.LastRibTableHasSpaceTimestamp']['meta_info']


                                            class TimeLabelRetain(object):
                                                """
                                                Time last label retentiontriggered 
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:time-label-retain'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeLabelRetain']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:vrf'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.attributes_recover_from_rib is not None:
                                                    return True

                                                if self.attributes_removed_from_rib is not None:
                                                    return True

                                                if self.attributes_sent_to_rib is not None:
                                                    return True

                                                if self.first_rib_table_full_timestamp is not None and self.first_rib_table_full_timestamp._has_data():
                                                    return True

                                                if self.first_rib_table_full_version is not None:
                                                    return True

                                                if self.first_rib_table_has_space_timestamp is not None and self.first_rib_table_has_space_timestamp._has_data():
                                                    return True

                                                if self.first_rib_table_has_space_version is not None:
                                                    return True

                                                if self.import_added_path_count is not None:
                                                    return True

                                                if self.import_calls is not None:
                                                    return True

                                                if self.import_dest_net_processed_count is not None:
                                                    return True

                                                if self.import_removed_path_count is not None:
                                                    return True

                                                if self.import_replaced_path_count is not None:
                                                    return True

                                                if self.import_src_net_processed_count is not None:
                                                    return True

                                                if self.import_time is not None:
                                                    return True

                                                if self.is_rib_table_full is not None:
                                                    return True

                                                if self.label_added_count is not None:
                                                    return True

                                                if self.label_calls is not None:
                                                    return True

                                                if self.label_release_count is not None:
                                                    return True

                                                if self.label_rewrite_count is not None:
                                                    return True

                                                if self.label_time is not None:
                                                    return True

                                                if self.last_rib_table_full_age is not None:
                                                    return True

                                                if self.last_rib_table_full_timestamp is not None and self.last_rib_table_full_timestamp._has_data():
                                                    return True

                                                if self.last_rib_table_full_version is not None:
                                                    return True

                                                if self.last_rib_table_has_space_age is not None:
                                                    return True

                                                if self.last_rib_table_has_space_timestamp is not None and self.last_rib_table_has_space_timestamp._has_data():
                                                    return True

                                                if self.last_rib_table_has_space_version is not None:
                                                    return True

                                                if self.prefixes_removed_from_rib is not None:
                                                    return True

                                                if self.prefixes_resent_to_rib is not None:
                                                    return True

                                                if self.prefixes_sent_to_rib is not None:
                                                    return True

                                                if self.rib_table_full_version is not None:
                                                    return True

                                                if self.rib_tbl_del_calls is not None:
                                                    return True

                                                if self.rib_tbl_invalid_calls is not None:
                                                    return True

                                                if self.rib_tbl_local_label is not None:
                                                    return True

                                                if self.rib_tbl_retry is not None:
                                                    return True

                                                if self.rib_tbl_skip_calls is not None:
                                                    return True

                                                if self.rib_trigger is not None:
                                                    return True

                                                if self.rib_update_calls is not None:
                                                    return True

                                                if self.rib_update_time is not None:
                                                    return True

                                                if self.scanner_runs is not None:
                                                    return True

                                                if self.scanner_time is not None:
                                                    return True

                                                if self.subgroup_count is not None:
                                                    return True

                                                if self.time_label_retain is not None and self.time_label_retain._has_data():
                                                    return True

                                                if self.time_last_update_sent is not None:
                                                    return True

                                                if self.time_rib_coverged is not None and self.time_rib_coverged._has_data():
                                                    return True

                                                if self.time_rib_down is not None and self.time_rib_down._has_data():
                                                    return True

                                                if self.update_generation_be_prefixes_count is not None:
                                                    return True

                                                if self.update_generation_calls is not None:
                                                    return True

                                                if self.update_generation_messages_count is not None:
                                                    return True

                                                if self.update_generation_prefixes_count is not None:
                                                    return True

                                                if self.update_generation_time is not None:
                                                    return True

                                                if self.update_group_count is not None:
                                                    return True

                                                if self.vrf_flags is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:performance-statistics'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.global_ is not None and self.global_._has_data():
                                                return True

                                            if self.vrf is not None and self.vrf._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af-process-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.global_ is not None and self.global_._has_data():
                                            return True

                                        if self.performance_statistics is not None and self.performance_statistics._has_data():
                                            return True

                                        if self.process_instance is not None:
                                            return True

                                        if self.vrf is not None and self.vrf._has_data():
                                            return True

                                        if self.vrf_name is not None:
                                            return True

                                        if self.vrf_totals is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo']['meta_info']


                                class PathUsedTable(object):
                                    """
                                    The BGP Path Used Table
                                    
                                    .. attribute:: path
                                    
                                    	A BGP path table entry
                                    	**type**\: list of    :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.path = YList()
                                        self.path.parent = self
                                        self.path.name = 'path'


                                    class Path(object):
                                        """
                                        A BGP path table entry
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor adddress
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr>`
                                        
                                        .. attribute:: network
                                        
                                        	Network Prefix in Hex format
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_id
                                        
                                        	Received Path ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type
                                        	**type**\:   :py:class:`BgpRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRouteEnum>`
                                        
                                        .. attribute:: source_rd
                                        
                                        	Source Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self.label_fail = None
                                            self.label_o_or_version = None
                                            self.label_oor = None
                                            self.neighbor_address = None
                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self.network = None
                                            self.no_path = None
                                            self.path_id = None
                                            self.path_information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation()
                                            self.path_information.parent = self
                                            self.prefix_length = None
                                            self.prefix_version = None
                                            self.process_instance_id = None
                                            self.rd = None
                                            self.route_distinguisher = None
                                            self.route_type = None
                                            self.source_rd = None
                                            self.source_route_distinguisher = None
                                            self.source_vrf_name = None
                                            self.srcaf_name = None
                                            self.vrf_name = None


                                        class NeighborAddressXr(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr']['meta_info']


                                        class PathInformation(object):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_esi
                                            
                                            	Path has EVPN ESI
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_rcvd_label
                                            
                                            	Path has received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebg_ps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.L2VpnEvpnEsi>`
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop>`
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhteTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_p_ath = None
                                                self.add_path_orr_bitfield = YList()
                                                self.add_path_orr_bitfield.parent = self
                                                self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                self.advertisedto_pe = None
                                                self.aigp_metric = None
                                                self.best_path_comp_stage = None
                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self.best_path_id = None
                                                self.best_path_id_comp_winner = None
                                                self.best_path_orr_bitfield = YList()
                                                self.best_path_orr_bitfield.parent = self
                                                self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self.dampen_penalty = None
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.fspec_invalid_path = None
                                                self.graceful_shutdown = None
                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self.halflife_time = None
                                                self.has_esi = None
                                                self.has_gw_addr = None
                                                self.has_local_net_label = None
                                                self.has_mdt_group_addr = None
                                                self.has_mvpn_extcomm = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.has_rcvd_label = None
                                                self.has_second_label = None
                                                self.ibgp_signaled_validity = None
                                                self.igp_metric = None
                                                self.is_aggregation_suppressed = None
                                                self.is_as_best = None
                                                self.is_best_path = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_internal_path = None
                                                self.is_partial_best = None
                                                self.is_path_additional_path = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_af_install_eligible = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_damped = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_history_held = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_imported = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_multipath = None
                                                self.is_path_nexthop_discarded = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebg_ps = None
                                                self.is_path_received_only = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_stale = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_valid = None
                                                self.is_path_vpn_only = None
                                                self.is_permanent_path = None
                                                self.is_received_path_not_modified = None
                                                self.is_spkr_as_best = None
                                                self.l2vpn_circuit_status_value = YList()
                                                self.l2vpn_circuit_status_value.parent = self
                                                self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.L2VpnEvpnEsi()
                                                self.l2vpn_evpn_esi.parent = self
                                                self.l2vpn_size = None
                                                self.labeled_unicast_safi_path = None
                                                self.local_label = None
                                                self.local_nh = None
                                                self.local_path_id = None
                                                self.local_peers_advertised_to = YList()
                                                self.local_peers_advertised_to.parent = self
                                                self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                self.maximum_suppress_time = None
                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self.mvpn_path_flags = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_value = YList()
                                                self.mvpn_pmsi_value.parent = self
                                                self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                self.mvpn_sfs_path = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.neighbor_router_id = None
                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.path_flags = None
                                                self.path_flap_count = None
                                                self.path_import_flags = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.path_table_version = None
                                                self.path_weight = None
                                                self.pe_peers_advertised_to = YList()
                                                self.pe_peers_advertised_to.parent = self
                                                self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                self.rcvd_label = None
                                                self.rcvd_path_id = None
                                                self.reuse_value = None
                                                self.rib_failed = None
                                                self.route_type = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.rt_set_limit_enabled = None
                                                self.second_label = None
                                                self.seconds_since_first_flap = None
                                                self.show_rpki_origin_as_validity = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.suppress_penalty = None
                                                self.time_to_unsuppress = None


                                            class BgpPrefix(object):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self.prefix_length = None


                                                class Prefix(object):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.prefix is not None and self.prefix._has_data():
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix']['meta_info']


                                            class NeighborAddress(object):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress']['meta_info']


                                            class NextHop(object):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhteTunnel']['meta_info']


                                            class MdtGroupAddr(object):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr']['meta_info']


                                            class L2VpnEvpnEsi(object):
                                                """
                                                L2VPN EVPN ESI
                                                
                                                .. attribute:: esi
                                                
                                                	esi
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.esi = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.esi is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.L2VpnEvpnEsi']['meta_info']


                                            class GwAddr(object):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr']['meta_info']


                                            class BestPathCompWinner(object):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner']['meta_info']


                                            class MvpnNbrAddr(object):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr']['meta_info']


                                            class MvpnNexthopAddr(object):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr']['meta_info']


                                            class L2VpnCircuitStatusValue(object):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                            class MvpnPmsiValue(object):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity']['meta_info']


                                            class LocalPeersAdvertisedTo(object):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                            class PePeersAdvertisedTo(object):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo']['meta_info']


                                            class BestPathOrrBitfield(object):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield']['meta_info']


                                            class AddPathOrrBitfield(object):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.accept_own_path is not None:
                                                    return True

                                                if self.accept_own_self_originated_p_ath is not None:
                                                    return True

                                                if self.add_path_orr_bitfield is not None:
                                                    for child_ref in self.add_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.advertisedto_pe is not None:
                                                    return True

                                                if self.aigp_metric is not None:
                                                    return True

                                                if self.best_path_comp_stage is not None:
                                                    return True

                                                if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                    return True

                                                if self.best_path_id is not None:
                                                    return True

                                                if self.best_path_id_comp_winner is not None:
                                                    return True

                                                if self.best_path_orr_bitfield is not None:
                                                    for child_ref in self.best_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                    return True

                                                if self.dampen_penalty is not None:
                                                    return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.fspec_invalid_path is not None:
                                                    return True

                                                if self.graceful_shutdown is not None:
                                                    return True

                                                if self.gw_addr is not None and self.gw_addr._has_data():
                                                    return True

                                                if self.halflife_time is not None:
                                                    return True

                                                if self.has_esi is not None:
                                                    return True

                                                if self.has_gw_addr is not None:
                                                    return True

                                                if self.has_local_net_label is not None:
                                                    return True

                                                if self.has_mdt_group_addr is not None:
                                                    return True

                                                if self.has_mvpn_extcomm is not None:
                                                    return True

                                                if self.has_mvpn_nbr_addr is not None:
                                                    return True

                                                if self.has_mvpn_nexthop_addr is not None:
                                                    return True

                                                if self.has_mvpn_pmsi is not None:
                                                    return True

                                                if self.has_rcvd_label is not None:
                                                    return True

                                                if self.has_second_label is not None:
                                                    return True

                                                if self.ibgp_signaled_validity is not None:
                                                    return True

                                                if self.igp_metric is not None:
                                                    return True

                                                if self.is_aggregation_suppressed is not None:
                                                    return True

                                                if self.is_as_best is not None:
                                                    return True

                                                if self.is_best_path is not None:
                                                    return True

                                                if self.is_import_dampened is not None:
                                                    return True

                                                if self.is_import_suspect is not None:
                                                    return True

                                                if self.is_internal_path is not None:
                                                    return True

                                                if self.is_partial_best is not None:
                                                    return True

                                                if self.is_path_additional_path is not None:
                                                    return True

                                                if self.is_path_advertised_local_as_only is not None:
                                                    return True

                                                if self.is_path_af_install_eligible is not None:
                                                    return True

                                                if self.is_path_backup is not None:
                                                    return True

                                                if self.is_path_backup_protect_multipath is not None:
                                                    return True

                                                if self.is_path_best_external is not None:
                                                    return True

                                                if self.is_path_damped is not None:
                                                    return True

                                                if self.is_path_from_confederation_peer is not None:
                                                    return True

                                                if self.is_path_from_network_command is not None:
                                                    return True

                                                if self.is_path_from_redistribute_command is not None:
                                                    return True

                                                if self.is_path_from_route_reflector is not None:
                                                    return True

                                                if self.is_path_history_held is not None:
                                                    return True

                                                if self.is_path_imp_candidate is not None:
                                                    return True

                                                if self.is_path_imported is not None:
                                                    return True

                                                if self.is_path_local_aggregate is not None:
                                                    return True

                                                if self.is_path_locally_sourced is not None:
                                                    return True

                                                if self.is_path_long_lived_stale is not None:
                                                    return True

                                                if self.is_path_multipath is not None:
                                                    return True

                                                if self.is_path_nexthop_discarded is not None:
                                                    return True

                                                if self.is_path_not_advertised is not None:
                                                    return True

                                                if self.is_path_not_advertised_to_ebg_ps is not None:
                                                    return True

                                                if self.is_path_received_only is not None:
                                                    return True

                                                if self.is_path_reoriginated is not None:
                                                    return True

                                                if self.is_path_reoriginated_stitching is not None:
                                                    return True

                                                if self.is_path_stale is not None:
                                                    return True

                                                if self.is_path_synced_with_igp is not None:
                                                    return True

                                                if self.is_path_valid is not None:
                                                    return True

                                                if self.is_path_vpn_only is not None:
                                                    return True

                                                if self.is_permanent_path is not None:
                                                    return True

                                                if self.is_received_path_not_modified is not None:
                                                    return True

                                                if self.is_spkr_as_best is not None:
                                                    return True

                                                if self.l2vpn_circuit_status_value is not None:
                                                    for child_ref in self.l2vpn_circuit_status_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                    return True

                                                if self.l2vpn_size is not None:
                                                    return True

                                                if self.labeled_unicast_safi_path is not None:
                                                    return True

                                                if self.local_label is not None:
                                                    return True

                                                if self.local_nh is not None:
                                                    return True

                                                if self.local_path_id is not None:
                                                    return True

                                                if self.local_peers_advertised_to is not None:
                                                    for child_ref in self.local_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.maximum_suppress_time is not None:
                                                    return True

                                                if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                    return True

                                                if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                    return True

                                                if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                    return True

                                                if self.mvpn_path_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_label is not None:
                                                    return True

                                                if self.mvpn_pmsi_type is not None:
                                                    return True

                                                if self.mvpn_pmsi_value is not None:
                                                    for child_ref in self.mvpn_pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.mvpn_sfs_path is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.neighbor_router_id is not None:
                                                    return True

                                                if self.next_hop is not None and self.next_hop._has_data():
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.path_flags is not None:
                                                    return True

                                                if self.path_flap_count is not None:
                                                    return True

                                                if self.path_import_flags is not None:
                                                    return True

                                                if self.path_rt_set_id is not None:
                                                    return True

                                                if self.path_rt_set_route_count is not None:
                                                    return True

                                                if self.path_table_version is not None:
                                                    return True

                                                if self.path_weight is not None:
                                                    return True

                                                if self.pe_peers_advertised_to is not None:
                                                    for child_ref in self.pe_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.rcvd_label is not None:
                                                    return True

                                                if self.rcvd_path_id is not None:
                                                    return True

                                                if self.reuse_value is not None:
                                                    return True

                                                if self.rib_failed is not None:
                                                    return True

                                                if self.route_type is not None:
                                                    return True

                                                if self.rpki_origin_as_validation_disabled is not None:
                                                    return True

                                                if self.rt_set_limit_enabled is not None:
                                                    return True

                                                if self.second_label is not None:
                                                    return True

                                                if self.seconds_since_first_flap is not None:
                                                    return True

                                                if self.show_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.sn_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.suppress_penalty is not None:
                                                    return True

                                                if self.time_to_unsuppress is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation']['meta_info']


                                        class AttributesAfterPolicyIn(object):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self.is_application_gateway_present = None
                                                self.is_as_path2_byte = None
                                                self.is_attr_set_present = None
                                                self.is_ribrnh_present = None
                                                self.is_rnh_present = None
                                                self.ribrnh_encap = None
                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self.ribrnh_mac = None
                                                self.ribrnh_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnhip_table = None
                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self.rnh_addr_len = None
                                                self.rnh_len = None
                                                self.rnh_type = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.vpn_distinguisher = None


                                            class CommonAttributes(object):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                            class AttrSet(object):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                            class RnhAddr(object):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None
                                                    self.mac_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    if self.mac_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                            class RibrnhIp(object):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.attr_set is not None and self.attr_set._has_data():
                                                    return True

                                                if self.attribute_key_number is not None:
                                                    return True

                                                if self.attribute_reuse_id_config is not None:
                                                    return True

                                                if self.attribute_reuse_id_current is not None:
                                                    return True

                                                if self.attribute_reuse_id_keys is not None:
                                                    return True

                                                if self.attribute_reuse_id_max_id is not None:
                                                    return True

                                                if self.attribute_reuse_id_node is not None:
                                                    return True

                                                if self.attribute_reuse_id_recover_sec is not None:
                                                    return True

                                                if self.common_attributes is not None and self.common_attributes._has_data():
                                                    return True

                                                if self.is_application_gateway_present is not None:
                                                    return True

                                                if self.is_as_path2_byte is not None:
                                                    return True

                                                if self.is_attr_set_present is not None:
                                                    return True

                                                if self.is_ribrnh_present is not None:
                                                    return True

                                                if self.is_rnh_present is not None:
                                                    return True

                                                if self.ribrnh_encap is not None:
                                                    return True

                                                if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                    return True

                                                if self.ribrnh_mac is not None:
                                                    return True

                                                if self.ribrnh_table is not None:
                                                    return True

                                                if self.ribrnh_vni is not None:
                                                    return True

                                                if self.ribrnhip_table is not None:
                                                    return True

                                                if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                    return True

                                                if self.rnh_addr_len is not None:
                                                    return True

                                                if self.rnh_len is not None:
                                                    return True

                                                if self.rnh_type is not None:
                                                    return True

                                                if self.set_aigp_inbound_igp is not None:
                                                    return True

                                                if self.set_aigp_inbound_metric is not None:
                                                    return True

                                                if self.vpn_distinguisher is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                return True

                                            if self.label_fail is not None:
                                                return True

                                            if self.label_o_or_version is not None:
                                                return True

                                            if self.label_oor is not None:
                                                return True

                                            if self.neighbor_address is not None:
                                                return True

                                            if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                return True

                                            if self.network is not None:
                                                return True

                                            if self.no_path is not None:
                                                return True

                                            if self.path_id is not None:
                                                return True

                                            if self.path_information is not None and self.path_information._has_data():
                                                return True

                                            if self.prefix_length is not None:
                                                return True

                                            if self.prefix_version is not None:
                                                return True

                                            if self.process_instance_id is not None:
                                                return True

                                            if self.rd is not None:
                                                return True

                                            if self.route_distinguisher is not None:
                                                return True

                                            if self.route_type is not None:
                                                return True

                                            if self.source_rd is not None:
                                                return True

                                            if self.source_route_distinguisher is not None:
                                                return True

                                            if self.source_vrf_name is not None:
                                                return True

                                            if self.srcaf_name is not None:
                                                return True

                                            if self.vrf_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-used-table'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.path is not None:
                                            for child_ref in self.path:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable']['meta_info']


                                class RpcSets(object):
                                    """
                                    BGP next\-hop set table
                                    
                                    .. attribute:: rpc_set
                                    
                                    	A BGP next\-hop set
                                    	**type**\: list of    :py:class:`RpcSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.rpc_set = YList()
                                        self.rpc_set.parent = self
                                        self.rpc_set.name = 'rpc_set'


                                    class RpcSet(object):
                                        """
                                        A BGP next\-hop set
                                        
                                        .. attribute:: rpc_set_index  <key>
                                        
                                        	Nexthop set index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: label
                                        
                                        	Label assigned to the RPCnext\-hop set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: next_hop
                                        
                                        	List of multipath next\-hops
                                        	**type**\: list of    :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop>`
                                        
                                        .. attribute:: next_hop_xr
                                        
                                        	Number of multipath next\-hops
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ref_count
                                        
                                        	Refcount
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.rpc_set_index = None
                                            self.label = None
                                            self.next_hop = YList()
                                            self.next_hop.parent = self
                                            self.next_hop.name = 'next_hop'
                                            self.next_hop_xr = None
                                            self.ref_count = None


                                        class NextHop(object):
                                            """
                                            List of multipath next\-hops
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')
                                            if self.rpc_set_index is None:
                                                raise YPYModelError('Key property rpc_set_index is None')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rpc-set[Cisco-IOS-XR-ipv4-bgp-oper:rpc-set-index = ' + str(self.rpc_set_index) + ']'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.rpc_set_index is not None:
                                                return True

                                            if self.label is not None:
                                                return True

                                            if self.next_hop is not None:
                                                for child_ref in self.next_hop:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.next_hop_xr is not None:
                                                return True

                                            if self.ref_count is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rpc-sets'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.rpc_set is not None:
                                            for child_ref in self.rpc_set:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets']['meta_info']


                                class GlobalAfProcessInfo(object):
                                    """
                                    The Global Address Family Process information
                                    table
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family id
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: global_
                                    
                                    	Global information
                                    	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_>`
                                    
                                    .. attribute:: is_nsr_enabled
                                    
                                    	Non\-stop routing enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:   :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Vrf_>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.global_ = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_()
                                        self.global_.parent = self
                                        self.is_nsr_enabled = None
                                        self.vrf = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Vrf_()
                                        self.vrf.parent = self
                                        self.vrf_name = None


                                    class Global_(object):
                                        """
                                        Global information
                                        
                                        .. attribute:: gblafrpki_allow_invalid
                                        
                                        	Prefix v. allow invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: gblafrpki_disable
                                        
                                        	Prefix validation disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: gblafrpki_signal_ibgp
                                        
                                        	Prefix v. signal ibgp
                                        	**type**\:  bool
                                        
                                        .. attribute:: gblafrpki_use_validity
                                        
                                        	Prefix v. use validity
                                        	**type**\:  bool
                                        
                                        .. attribute:: global_mcast_enabled
                                        
                                        	Is global table mcast enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: inter_as_install_enabled
                                        
                                        	Is inter\-AS install to pim on ASBR enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_perm_net_cfg
                                        
                                        	Permanent Network Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: nh_tunnel_version
                                        
                                        	NH Tunnel Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: perm_nbr_count
                                        
                                        	Count of neighbors configured with perm net
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_del_count
                                        
                                        	Count of removed perm paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_existing_count
                                        
                                        	Count of existing perm paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_insert_count
                                        
                                        	Count of inserted perm paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_rpl_process_count
                                        
                                        	Count of perm nets processed in RPL
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_rpl_query_count
                                        
                                        	Count of perm nets given by RPL
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_stale_del_count
                                        
                                        	Count of stale perm paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_stale_mark_count
                                        
                                        	Count of stale marked perm paths
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_path_refresh_count
                                        
                                        	Count of perm paths refreshed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_pelem_all_bump_count
                                        
                                        	Count of bumped perm pelems
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_pelem_bump_count
                                        
                                        	Count of bumped perm pelems
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_pelem_free_count
                                        
                                        	Count of freed perm pelems
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rib_ack_requests
                                        
                                        	Counter for RIB ack requests
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_acks_received
                                        
                                        	Counter for RIB ack received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_install
                                        
                                        	RIB install info
                                        	**type**\:   :py:class:`RibInstall <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall>`
                                        
                                        .. attribute:: rib_perm_path_found_count
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rib_perm_path_not_found_count
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rib_perm_pelem_found_count
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rib_perm_pelem_not_found_count
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rib_reg_path_found_count
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rib_slow_acks
                                        
                                        	Counter for slow RIB acks
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: scan_prefixes
                                        
                                        	Total prefixes of address\-family scanned
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: scan_segment_prefixes
                                        
                                        	Number of prefixes scanned in a segment of address\-family
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: scan_segments
                                        
                                        	Number of segments to scan all prefixes of address\-family
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: scanner_period
                                        
                                        	Period (in seconds) of address\-family scanner runs
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: segmented_mcast_enabled
                                        
                                        	Is segmented mcast enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: syncgrp_version
                                        
                                        	Sync\-group Version
                                        	**type**\: list of    :py:class:`SyncgrpVersion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.SyncgrpVersion>`
                                        
                                        .. attribute:: update_wait_install_enabled
                                        
                                        	Update wait\-install enabled
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.gblafrpki_allow_invalid = None
                                            self.gblafrpki_disable = None
                                            self.gblafrpki_signal_ibgp = None
                                            self.gblafrpki_use_validity = None
                                            self.global_mcast_enabled = None
                                            self.inter_as_install_enabled = None
                                            self.is_perm_net_cfg = None
                                            self.nh_tunnel_version = None
                                            self.perm_nbr_count = None
                                            self.perm_net_del_count = None
                                            self.perm_net_existing_count = None
                                            self.perm_net_insert_count = None
                                            self.perm_net_rpl_process_count = None
                                            self.perm_net_rpl_query_count = None
                                            self.perm_net_stale_del_count = None
                                            self.perm_net_stale_mark_count = None
                                            self.perm_path_refresh_count = None
                                            self.perm_pelem_all_bump_count = None
                                            self.perm_pelem_bump_count = None
                                            self.perm_pelem_free_count = None
                                            self.rib_ack_requests = None
                                            self.rib_acks_received = None
                                            self.rib_install = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall()
                                            self.rib_install.parent = self
                                            self.rib_perm_path_found_count = None
                                            self.rib_perm_path_not_found_count = None
                                            self.rib_perm_pelem_found_count = None
                                            self.rib_perm_pelem_not_found_count = None
                                            self.rib_reg_path_found_count = None
                                            self.rib_slow_acks = None
                                            self.scan_prefixes = None
                                            self.scan_segment_prefixes = None
                                            self.scan_segments = None
                                            self.scanner_period = None
                                            self.segmented_mcast_enabled = None
                                            self.syncgrp_version = YList()
                                            self.syncgrp_version.parent = self
                                            self.syncgrp_version.name = 'syncgrp_version'
                                            self.update_wait_install_enabled = None


                                        class RibInstall(object):
                                            """
                                            RIB install info
                                            
                                            .. attribute:: install_time
                                            
                                            	RIB install time
                                            	**type**\:   :py:class:`InstallTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.InstallTime>`
                                            
                                            .. attribute:: installed_count
                                            
                                            	Installed routes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: modified_count
                                            
                                            	Modified routes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: start_version
                                            
                                            	Start version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: target_version
                                            
                                            	Target version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_time
                                            
                                            	RIB update time
                                            	**type**\:   :py:class:`UpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.UpdateTime>`
                                            
                                            .. attribute:: withdrawn_count
                                            
                                            	Withdrawn routes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.install_time = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.InstallTime()
                                                self.install_time.parent = self
                                                self.installed_count = None
                                                self.modified_count = None
                                                self.start_version = None
                                                self.target_version = None
                                                self.update_time = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.UpdateTime()
                                                self.update_time.parent = self
                                                self.withdrawn_count = None


                                            class UpdateTime(object):
                                                """
                                                RIB update time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-time'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.UpdateTime']['meta_info']


                                            class InstallTime(object):
                                                """
                                                RIB install time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:install-time'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.InstallTime']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rib-install'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.install_time is not None and self.install_time._has_data():
                                                    return True

                                                if self.installed_count is not None:
                                                    return True

                                                if self.modified_count is not None:
                                                    return True

                                                if self.start_version is not None:
                                                    return True

                                                if self.target_version is not None:
                                                    return True

                                                if self.update_time is not None and self.update_time._has_data():
                                                    return True

                                                if self.withdrawn_count is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall']['meta_info']


                                        class SyncgrpVersion(object):
                                            """
                                            Sync\-group Version
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:syncgrp-version'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_.SyncgrpVersion']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:global'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.gblafrpki_allow_invalid is not None:
                                                return True

                                            if self.gblafrpki_disable is not None:
                                                return True

                                            if self.gblafrpki_signal_ibgp is not None:
                                                return True

                                            if self.gblafrpki_use_validity is not None:
                                                return True

                                            if self.global_mcast_enabled is not None:
                                                return True

                                            if self.inter_as_install_enabled is not None:
                                                return True

                                            if self.is_perm_net_cfg is not None:
                                                return True

                                            if self.nh_tunnel_version is not None:
                                                return True

                                            if self.perm_nbr_count is not None:
                                                return True

                                            if self.perm_net_del_count is not None:
                                                return True

                                            if self.perm_net_existing_count is not None:
                                                return True

                                            if self.perm_net_insert_count is not None:
                                                return True

                                            if self.perm_net_rpl_process_count is not None:
                                                return True

                                            if self.perm_net_rpl_query_count is not None:
                                                return True

                                            if self.perm_net_stale_del_count is not None:
                                                return True

                                            if self.perm_net_stale_mark_count is not None:
                                                return True

                                            if self.perm_path_refresh_count is not None:
                                                return True

                                            if self.perm_pelem_all_bump_count is not None:
                                                return True

                                            if self.perm_pelem_bump_count is not None:
                                                return True

                                            if self.perm_pelem_free_count is not None:
                                                return True

                                            if self.rib_ack_requests is not None:
                                                return True

                                            if self.rib_acks_received is not None:
                                                return True

                                            if self.rib_install is not None and self.rib_install._has_data():
                                                return True

                                            if self.rib_perm_path_found_count is not None:
                                                return True

                                            if self.rib_perm_path_not_found_count is not None:
                                                return True

                                            if self.rib_perm_pelem_found_count is not None:
                                                return True

                                            if self.rib_perm_pelem_not_found_count is not None:
                                                return True

                                            if self.rib_reg_path_found_count is not None:
                                                return True

                                            if self.rib_slow_acks is not None:
                                                return True

                                            if self.scan_prefixes is not None:
                                                return True

                                            if self.scan_segment_prefixes is not None:
                                                return True

                                            if self.scan_segments is not None:
                                                return True

                                            if self.scanner_period is not None:
                                                return True

                                            if self.segmented_mcast_enabled is not None:
                                                return True

                                            if self.syncgrp_version is not None:
                                                for child_ref in self.syncgrp_version:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.update_wait_install_enabled is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global_']['meta_info']


                                    class Vrf_(object):
                                        """
                                        VRF information
                                        
                                        .. attribute:: aggregates_distance
                                        
                                        	Dist for aggregate routes (local)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: client_reflection_enabled
                                        
                                        	Client reflection enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: dampening_enabled
                                        
                                        	Dampening enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: dynamic_med_enabled
                                        
                                        	Update generation enabled for MED change
                                        	**type**\:  bool
                                        
                                        .. attribute:: dynamic_med_interval
                                        
                                        	Delay in update generation after a MED change (in minutes)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: minute
                                        
                                        .. attribute:: dynamic_med_periodic_timer_running
                                        
                                        	Dynamic MED periodic timer running
                                        	**type**\:  bool
                                        
                                        .. attribute:: dynamic_med_periodic_timer_value
                                        
                                        	Dynamic MED periodic timer value (in seconds) left on the timer
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: dynamic_med_timer_running
                                        
                                        	Dynamic MED timer running
                                        	**type**\:  bool
                                        
                                        .. attribute:: dynamic_med_timer_value
                                        
                                        	Dynamic MED timer value (in seconds) left on the timer
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: ebgp_distance
                                        
                                        	Distance for eBGP routes (external)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ibgp_distance
                                        
                                        	Distance for iBGP routes (internal)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_rib_table_full
                                        
                                        	Indicates if RIB table is in prefix\-limit state
                                        	**type**\:  bool
                                        
                                        .. attribute:: nexthop_resolution_minimum_prefix_length
                                        
                                        	Nexthop resoultion minimum prefix\-length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nexthop_resolution_minimum_prefix_length_configured
                                        
                                        	Is nexthop resoultion minimum prefix\-length configured ?
                                        	**type**\:  bool
                                        
                                        .. attribute:: nsr_conv_version
                                        
                                        	NSR conv version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nsr_is_conv
                                        
                                        	NSR is converged
                                        	**type**\:  bool
                                        
                                        .. attribute:: rd_version
                                        
                                        	RD version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_acked_table_version
                                        
                                        	Table version acked by RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_convergence_version
                                        
                                        	Last convergence version received from RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_has_converged
                                        
                                        	Received convergence notification from RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: rib_table_full_version
                                        
                                        	Version when RIB table became full (from non\-full)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_version
                                        
                                        	Table version synced to RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: selective_ebgp_multipath_enabled
                                        
                                        	Selective eBGP multipath isenabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: selective_eibgp_multipath_enabled
                                        
                                        	Selective eiBGP multipath isenabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: selective_ibgp_multipath_enabled
                                        
                                        	Selective iBGP multipath isenabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: table_id
                                        
                                        	Table ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: table_is_active
                                        
                                        	Table state is active
                                        	**type**\:  bool
                                        
                                        .. attribute:: table_version
                                        
                                        	Table version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.aggregates_distance = None
                                            self.client_reflection_enabled = None
                                            self.dampening_enabled = None
                                            self.dynamic_med_enabled = None
                                            self.dynamic_med_interval = None
                                            self.dynamic_med_periodic_timer_running = None
                                            self.dynamic_med_periodic_timer_value = None
                                            self.dynamic_med_timer_running = None
                                            self.dynamic_med_timer_value = None
                                            self.ebgp_distance = None
                                            self.ibgp_distance = None
                                            self.is_rib_table_full = None
                                            self.nexthop_resolution_minimum_prefix_length = None
                                            self.nexthop_resolution_minimum_prefix_length_configured = None
                                            self.nsr_conv_version = None
                                            self.nsr_is_conv = None
                                            self.rd_version = None
                                            self.rib_acked_table_version = None
                                            self.rib_convergence_version = None
                                            self.rib_has_converged = None
                                            self.rib_table_full_version = None
                                            self.rib_version = None
                                            self.selective_ebgp_multipath_enabled = None
                                            self.selective_eibgp_multipath_enabled = None
                                            self.selective_ibgp_multipath_enabled = None
                                            self.table_id = None
                                            self.table_is_active = None
                                            self.table_version = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:vrf'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.aggregates_distance is not None:
                                                return True

                                            if self.client_reflection_enabled is not None:
                                                return True

                                            if self.dampening_enabled is not None:
                                                return True

                                            if self.dynamic_med_enabled is not None:
                                                return True

                                            if self.dynamic_med_interval is not None:
                                                return True

                                            if self.dynamic_med_periodic_timer_running is not None:
                                                return True

                                            if self.dynamic_med_periodic_timer_value is not None:
                                                return True

                                            if self.dynamic_med_timer_running is not None:
                                                return True

                                            if self.dynamic_med_timer_value is not None:
                                                return True

                                            if self.ebgp_distance is not None:
                                                return True

                                            if self.ibgp_distance is not None:
                                                return True

                                            if self.is_rib_table_full is not None:
                                                return True

                                            if self.nexthop_resolution_minimum_prefix_length is not None:
                                                return True

                                            if self.nexthop_resolution_minimum_prefix_length_configured is not None:
                                                return True

                                            if self.nsr_conv_version is not None:
                                                return True

                                            if self.nsr_is_conv is not None:
                                                return True

                                            if self.rd_version is not None:
                                                return True

                                            if self.rib_acked_table_version is not None:
                                                return True

                                            if self.rib_convergence_version is not None:
                                                return True

                                            if self.rib_has_converged is not None:
                                                return True

                                            if self.rib_table_full_version is not None:
                                                return True

                                            if self.rib_version is not None:
                                                return True

                                            if self.selective_ebgp_multipath_enabled is not None:
                                                return True

                                            if self.selective_eibgp_multipath_enabled is not None:
                                                return True

                                            if self.selective_ibgp_multipath_enabled is not None:
                                                return True

                                            if self.table_id is not None:
                                                return True

                                            if self.table_is_active is not None:
                                                return True

                                            if self.table_version is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Vrf_']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:global-af-process-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.global_ is not None and self.global_._has_data():
                                            return True

                                        if self.is_nsr_enabled is not None:
                                            return True

                                        if self.vrf is not None and self.vrf._has_data():
                                            return True

                                        if self.vrf_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo']['meta_info']


                                class NetworkPrefixes(object):
                                    """
                                    The BGP Network Lookup table
                                    
                                    .. attribute:: network_prefix
                                    
                                    	A BGP Network Lookup prefix entry
                                    	**type**\: list of    :py:class:`NetworkPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.network_prefix = YList()
                                        self.network_prefix.parent = self
                                        self.network_prefix.name = 'network_prefix'


                                    class NetworkPrefix(object):
                                        """
                                        A BGP Network Lookup prefix entry
                                        
                                        .. attribute:: active_path_element
                                        
                                        	Path element list received from Active inst
                                        	**type**\: list of    :py:class:`ActivePathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement>`
                                        
                                        .. attribute:: active_process_instance_path
                                        
                                        	Active's paths for this net 
                                        	**type**\: list of    :py:class:`ActiveProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath>`
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield>`
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix>`
                                        
                                        .. attribute:: bit
                                        
                                        	Bit
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: flags
                                        
                                        	Flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: gateway_array
                                        
                                        	Gateway array ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_inconsistent_paths
                                        
                                        	Net has inconsistent paths
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_lbl_retained
                                        
                                        	Net has label retained
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_local_label
                                        
                                        	Net has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_net_aggregation_suppressed
                                        
                                        	Net suppressed due to aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_net_ldp_signaled
                                        
                                        	L2VPN Net LDP signaled  aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_permanent_network
                                        
                                        	Permanent Network
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_path_element
                                        
                                        	Local path element list
                                        	**type**\: list of    :py:class:`LocalPathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement>`
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: local_process_instance_path
                                        
                                        	Local (to process instance) paths for this net 
                                        	**type**\: list of    :py:class:`LocalProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath>`
                                        
                                        .. attribute:: net_backup_available
                                        
                                        	Net has backup path
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_backup_label_rewrite_available
                                        
                                        	Net has label rewrite for backup path
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_eibgp_multipath
                                        
                                        	Net has EIBGP multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_extended_flags
                                        
                                        	Net extended flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: net_flags
                                        
                                        	Flags associated with                            net
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: net_local_label
                                        
                                        	Local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: net_local_label_rewrite
                                        
                                        	Net label has rewrite
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_local_label_srgb
                                        
                                        	Net label allocated fromSegment routing global block
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_multipath
                                        
                                        	Net has multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: network_prefix
                                        
                                        	Network prefix
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: num_of_path
                                        
                                        	Number of path for this net
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: resilient_nexthop_set
                                        
                                        	Resilient nexthop set ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_failed
                                        
                                        	RIB install failed
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: table_brib_version
                                        
                                        	Table version # for updates
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: table_version
                                        
                                        	Table version # for net
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version
                                        
                                        	Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version_age
                                        
                                        	Version age
                                        	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionAge>`
                                        
                                        .. attribute:: version_timestamp
                                        
                                        	Version timestamp
                                        	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionTimestamp>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.active_path_element = YList()
                                            self.active_path_element.parent = self
                                            self.active_path_element.name = 'active_path_element'
                                            self.active_process_instance_path = YList()
                                            self.active_process_instance_path.parent = self
                                            self.active_process_instance_path.name = 'active_process_instance_path'
                                            self.add_path_orr_bitfield = YList()
                                            self.add_path_orr_bitfield.parent = self
                                            self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                            self.advertisedto_pe = None
                                            self.af_name = None
                                            self.best_path_orr_bitfield = YList()
                                            self.best_path_orr_bitfield.parent = self
                                            self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self.bit = None
                                            self.flags = None
                                            self.gateway_array = None
                                            self.has_inconsistent_paths = None
                                            self.has_lbl_retained = None
                                            self.has_local_label = None
                                            self.is_net_aggregation_suppressed = None
                                            self.is_net_ldp_signaled = None
                                            self.is_permanent_network = None
                                            self.local_path_element = YList()
                                            self.local_path_element.parent = self
                                            self.local_path_element.name = 'local_path_element'
                                            self.local_peers_advertised_to = YList()
                                            self.local_peers_advertised_to.parent = self
                                            self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                            self.local_process_instance_path = YList()
                                            self.local_process_instance_path.parent = self
                                            self.local_process_instance_path.name = 'local_process_instance_path'
                                            self.net_backup_available = None
                                            self.net_backup_label_rewrite_available = None
                                            self.net_eibgp_multipath = None
                                            self.net_extended_flags = None
                                            self.net_flags = None
                                            self.net_local_label = None
                                            self.net_local_label_rewrite = None
                                            self.net_local_label_srgb = None
                                            self.net_multipath = None
                                            self.network_prefix = None
                                            self.num_of_path = None
                                            self.pe_peers_advertised_to = YList()
                                            self.pe_peers_advertised_to.parent = self
                                            self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                            self.process_instance_id = None
                                            self.rd = None
                                            self.resilient_nexthop_set = None
                                            self.rib_failed = None
                                            self.route_distinguisher = None
                                            self.table_brib_version = None
                                            self.table_version = None
                                            self.version = None
                                            self.version_age = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionAge()
                                            self.version_age.parent = self
                                            self.version_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionTimestamp()
                                            self.version_timestamp.parent = self
                                            self.vrf_name = None


                                        class BgpPrefix(object):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self.prefix_length = None


                                            class Prefix(object):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.prefix is not None and self.prefix._has_data():
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix']['meta_info']


                                        class VersionTimestamp(object):
                                            """
                                            Version timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionTimestamp']['meta_info']


                                        class VersionAge(object):
                                            """
                                            Version age
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-age'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionAge']['meta_info']


                                        class LocalPeersAdvertisedTo(object):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo']['meta_info']


                                        class PePeersAdvertisedTo(object):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo']['meta_info']


                                        class BestPathOrrBitfield(object):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield']['meta_info']


                                        class AddPathOrrBitfield(object):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield']['meta_info']


                                        class LocalProcessInstancePath(object):
                                            """
                                            Local (to process instance) paths for this net 
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: attributes_after_policy_in
                                            
                                            	Attributes after inbound policy applied
                                            	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn>`
                                            
                                            .. attribute:: label_fail
                                            
                                            	LSD label allocation failed 
                                            	**type**\:  bool
                                            
                                            .. attribute:: label_o_or_version
                                            
                                            	Label Version when OOR happens
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_oor
                                            
                                            	LSD label space is exhausted
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address_xr
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr>`
                                            
                                            .. attribute:: no_path
                                            
                                            	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                            	**type**\:  bool
                                            
                                            .. attribute:: path_information
                                            
                                            	Path information
                                            	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation>`
                                            
                                            .. attribute:: prefix_version
                                            
                                            	Version of BGP Prefix Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: process_instance_id
                                            
                                            	Process instance ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_route_distinguisher
                                            
                                            	Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_vrf_name
                                            
                                            	Name of the source VRF
                                            	**type**\:  str
                                            
                                            .. attribute:: srcaf_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.af_name = None
                                                self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn()
                                                self.attributes_after_policy_in.parent = self
                                                self.label_fail = None
                                                self.label_o_or_version = None
                                                self.label_oor = None
                                                self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr()
                                                self.neighbor_address_xr.parent = self
                                                self.no_path = None
                                                self.path_information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation()
                                                self.path_information.parent = self
                                                self.prefix_version = None
                                                self.process_instance_id = None
                                                self.route_distinguisher = None
                                                self.source_route_distinguisher = None
                                                self.source_vrf_name = None
                                                self.srcaf_name = None
                                                self.vrf_name = None


                                            class NeighborAddressXr(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr']['meta_info']


                                            class PathInformation(object):
                                                """
                                                Path information
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\:  bool
                                                
                                                .. attribute:: accept_own_self_originated_p_ath
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\:  bool
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\:  bool
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix>`
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\:  bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\:  bool
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.GwAddr>`
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_esi
                                                
                                                	Path has EVPN ESI
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_rcvd_label
                                                
                                                	Path has received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\:  bool
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebg_ps
                                                
                                                	Not advertised to EBGPs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi>`
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress>`
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop>`
                                                
                                                .. attribute:: nhte_tunnel
                                                
                                                	NH TE tunnel information
                                                	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhteTunnel>`
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\:  bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.accept_own_path = None
                                                    self.accept_own_self_originated_p_ath = None
                                                    self.add_path_orr_bitfield = YList()
                                                    self.add_path_orr_bitfield.parent = self
                                                    self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                    self.advertisedto_pe = None
                                                    self.aigp_metric = None
                                                    self.best_path_comp_stage = None
                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self.best_path_id = None
                                                    self.best_path_id_comp_winner = None
                                                    self.best_path_orr_bitfield = YList()
                                                    self.best_path_orr_bitfield.parent = self
                                                    self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self.dampen_penalty = None
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.fspec_invalid_path = None
                                                    self.graceful_shutdown = None
                                                    self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self.halflife_time = None
                                                    self.has_esi = None
                                                    self.has_gw_addr = None
                                                    self.has_local_net_label = None
                                                    self.has_mdt_group_addr = None
                                                    self.has_mvpn_extcomm = None
                                                    self.has_mvpn_nbr_addr = None
                                                    self.has_mvpn_nexthop_addr = None
                                                    self.has_mvpn_pmsi = None
                                                    self.has_rcvd_label = None
                                                    self.has_second_label = None
                                                    self.ibgp_signaled_validity = None
                                                    self.igp_metric = None
                                                    self.is_aggregation_suppressed = None
                                                    self.is_as_best = None
                                                    self.is_best_path = None
                                                    self.is_import_dampened = None
                                                    self.is_import_suspect = None
                                                    self.is_internal_path = None
                                                    self.is_partial_best = None
                                                    self.is_path_additional_path = None
                                                    self.is_path_advertised_local_as_only = None
                                                    self.is_path_af_install_eligible = None
                                                    self.is_path_backup = None
                                                    self.is_path_backup_protect_multipath = None
                                                    self.is_path_best_external = None
                                                    self.is_path_damped = None
                                                    self.is_path_from_confederation_peer = None
                                                    self.is_path_from_network_command = None
                                                    self.is_path_from_redistribute_command = None
                                                    self.is_path_from_route_reflector = None
                                                    self.is_path_history_held = None
                                                    self.is_path_imp_candidate = None
                                                    self.is_path_imported = None
                                                    self.is_path_local_aggregate = None
                                                    self.is_path_locally_sourced = None
                                                    self.is_path_long_lived_stale = None
                                                    self.is_path_multipath = None
                                                    self.is_path_nexthop_discarded = None
                                                    self.is_path_not_advertised = None
                                                    self.is_path_not_advertised_to_ebg_ps = None
                                                    self.is_path_received_only = None
                                                    self.is_path_reoriginated = None
                                                    self.is_path_reoriginated_stitching = None
                                                    self.is_path_stale = None
                                                    self.is_path_synced_with_igp = None
                                                    self.is_path_valid = None
                                                    self.is_path_vpn_only = None
                                                    self.is_permanent_path = None
                                                    self.is_received_path_not_modified = None
                                                    self.is_spkr_as_best = None
                                                    self.l2vpn_circuit_status_value = YList()
                                                    self.l2vpn_circuit_status_value.parent = self
                                                    self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                    self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi()
                                                    self.l2vpn_evpn_esi.parent = self
                                                    self.l2vpn_size = None
                                                    self.labeled_unicast_safi_path = None
                                                    self.local_label = None
                                                    self.local_nh = None
                                                    self.local_path_id = None
                                                    self.local_peers_advertised_to = YList()
                                                    self.local_peers_advertised_to.parent = self
                                                    self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                    self.maximum_suppress_time = None
                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self.mvpn_path_flags = None
                                                    self.mvpn_pmsi_flags = None
                                                    self.mvpn_pmsi_label = None
                                                    self.mvpn_pmsi_type = None
                                                    self.mvpn_pmsi_value = YList()
                                                    self.mvpn_pmsi_value.parent = self
                                                    self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                    self.mvpn_sfs_path = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.neighbor_router_id = None
                                                    self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop()
                                                    self.next_hop.parent = self
                                                    self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhteTunnel()
                                                    self.nhte_tunnel.parent = self
                                                    self.path_flags = None
                                                    self.path_flap_count = None
                                                    self.path_import_flags = None
                                                    self.path_rt_set_id = None
                                                    self.path_rt_set_route_count = None
                                                    self.path_table_version = None
                                                    self.path_weight = None
                                                    self.pe_peers_advertised_to = YList()
                                                    self.pe_peers_advertised_to.parent = self
                                                    self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                    self.rcvd_label = None
                                                    self.rcvd_path_id = None
                                                    self.reuse_value = None
                                                    self.rib_failed = None
                                                    self.route_type = None
                                                    self.rpki_origin_as_validation_disabled = None
                                                    self.rt_set_limit_enabled = None
                                                    self.second_label = None
                                                    self.seconds_since_first_flap = None
                                                    self.show_rpki_origin_as_validity = None
                                                    self.sn_rpki_origin_as_validity = None
                                                    self.suppress_penalty = None
                                                    self.time_to_unsuppress = None


                                                class BgpPrefix(object):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self.prefix_length = None


                                                    class Prefix(object):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.prefix is not None and self.prefix._has_data():
                                                            return True

                                                        if self.prefix_length is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix']['meta_info']


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress']['meta_info']


                                                class NextHop(object):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop']['meta_info']


                                                class NhteTunnel(object):
                                                    """
                                                    NH TE tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_te_tunnel
                                                    
                                                    	NH TE Tunnel info is present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last rib update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	tunnel name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	tunnel type
                                                    	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.binding_label = None
                                                        self.has_te_tunnel = None
                                                        self.is_tunnel_info_stale = None
                                                        self.is_tunnel_registered = None
                                                        self.is_tunnel_up = None
                                                        self.last_tunnel_update = None
                                                        self.tunnel_if_handle = None
                                                        self.tunnel_name = None
                                                        self.tunnel_type = None
                                                        self.tunnel_v6_enabled = None
                                                        self.tunnel_v6_required = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.binding_label is not None:
                                                            return True

                                                        if self.has_te_tunnel is not None:
                                                            return True

                                                        if self.is_tunnel_info_stale is not None:
                                                            return True

                                                        if self.is_tunnel_registered is not None:
                                                            return True

                                                        if self.is_tunnel_up is not None:
                                                            return True

                                                        if self.last_tunnel_update is not None:
                                                            return True

                                                        if self.tunnel_if_handle is not None:
                                                            return True

                                                        if self.tunnel_name is not None:
                                                            return True

                                                        if self.tunnel_type is not None:
                                                            return True

                                                        if self.tunnel_v6_enabled is not None:
                                                            return True

                                                        if self.tunnel_v6_required is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhteTunnel']['meta_info']


                                                class MdtGroupAddr(object):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr']['meta_info']


                                                class L2VpnEvpnEsi(object):
                                                    """
                                                    L2VPN EVPN ESI
                                                    
                                                    .. attribute:: esi
                                                    
                                                    	esi
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.esi = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.esi is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi']['meta_info']


                                                class GwAddr(object):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.len = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.len is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.GwAddr']['meta_info']


                                                class BestPathCompWinner(object):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner']['meta_info']


                                                class MvpnNbrAddr(object):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr']['meta_info']


                                                class MvpnNexthopAddr(object):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr']['meta_info']


                                                class L2VpnCircuitStatusValue(object):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                                class MvpnPmsiValue(object):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnPmsiValue']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.ExtendedCommunity']['meta_info']


                                                class LocalPeersAdvertisedTo(object):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                                class PePeersAdvertisedTo(object):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo']['meta_info']


                                                class BestPathOrrBitfield(object):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield']['meta_info']


                                                class AddPathOrrBitfield(object):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.accept_own_path is not None:
                                                        return True

                                                    if self.accept_own_self_originated_p_ath is not None:
                                                        return True

                                                    if self.add_path_orr_bitfield is not None:
                                                        for child_ref in self.add_path_orr_bitfield:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.advertisedto_pe is not None:
                                                        return True

                                                    if self.aigp_metric is not None:
                                                        return True

                                                    if self.best_path_comp_stage is not None:
                                                        return True

                                                    if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                        return True

                                                    if self.best_path_id is not None:
                                                        return True

                                                    if self.best_path_id_comp_winner is not None:
                                                        return True

                                                    if self.best_path_orr_bitfield is not None:
                                                        for child_ref in self.best_path_orr_bitfield:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                        return True

                                                    if self.dampen_penalty is not None:
                                                        return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.fspec_invalid_path is not None:
                                                        return True

                                                    if self.graceful_shutdown is not None:
                                                        return True

                                                    if self.gw_addr is not None and self.gw_addr._has_data():
                                                        return True

                                                    if self.halflife_time is not None:
                                                        return True

                                                    if self.has_esi is not None:
                                                        return True

                                                    if self.has_gw_addr is not None:
                                                        return True

                                                    if self.has_local_net_label is not None:
                                                        return True

                                                    if self.has_mdt_group_addr is not None:
                                                        return True

                                                    if self.has_mvpn_extcomm is not None:
                                                        return True

                                                    if self.has_mvpn_nbr_addr is not None:
                                                        return True

                                                    if self.has_mvpn_nexthop_addr is not None:
                                                        return True

                                                    if self.has_mvpn_pmsi is not None:
                                                        return True

                                                    if self.has_rcvd_label is not None:
                                                        return True

                                                    if self.has_second_label is not None:
                                                        return True

                                                    if self.ibgp_signaled_validity is not None:
                                                        return True

                                                    if self.igp_metric is not None:
                                                        return True

                                                    if self.is_aggregation_suppressed is not None:
                                                        return True

                                                    if self.is_as_best is not None:
                                                        return True

                                                    if self.is_best_path is not None:
                                                        return True

                                                    if self.is_import_dampened is not None:
                                                        return True

                                                    if self.is_import_suspect is not None:
                                                        return True

                                                    if self.is_internal_path is not None:
                                                        return True

                                                    if self.is_partial_best is not None:
                                                        return True

                                                    if self.is_path_additional_path is not None:
                                                        return True

                                                    if self.is_path_advertised_local_as_only is not None:
                                                        return True

                                                    if self.is_path_af_install_eligible is not None:
                                                        return True

                                                    if self.is_path_backup is not None:
                                                        return True

                                                    if self.is_path_backup_protect_multipath is not None:
                                                        return True

                                                    if self.is_path_best_external is not None:
                                                        return True

                                                    if self.is_path_damped is not None:
                                                        return True

                                                    if self.is_path_from_confederation_peer is not None:
                                                        return True

                                                    if self.is_path_from_network_command is not None:
                                                        return True

                                                    if self.is_path_from_redistribute_command is not None:
                                                        return True

                                                    if self.is_path_from_route_reflector is not None:
                                                        return True

                                                    if self.is_path_history_held is not None:
                                                        return True

                                                    if self.is_path_imp_candidate is not None:
                                                        return True

                                                    if self.is_path_imported is not None:
                                                        return True

                                                    if self.is_path_local_aggregate is not None:
                                                        return True

                                                    if self.is_path_locally_sourced is not None:
                                                        return True

                                                    if self.is_path_long_lived_stale is not None:
                                                        return True

                                                    if self.is_path_multipath is not None:
                                                        return True

                                                    if self.is_path_nexthop_discarded is not None:
                                                        return True

                                                    if self.is_path_not_advertised is not None:
                                                        return True

                                                    if self.is_path_not_advertised_to_ebg_ps is not None:
                                                        return True

                                                    if self.is_path_received_only is not None:
                                                        return True

                                                    if self.is_path_reoriginated is not None:
                                                        return True

                                                    if self.is_path_reoriginated_stitching is not None:
                                                        return True

                                                    if self.is_path_stale is not None:
                                                        return True

                                                    if self.is_path_synced_with_igp is not None:
                                                        return True

                                                    if self.is_path_valid is not None:
                                                        return True

                                                    if self.is_path_vpn_only is not None:
                                                        return True

                                                    if self.is_permanent_path is not None:
                                                        return True

                                                    if self.is_received_path_not_modified is not None:
                                                        return True

                                                    if self.is_spkr_as_best is not None:
                                                        return True

                                                    if self.l2vpn_circuit_status_value is not None:
                                                        for child_ref in self.l2vpn_circuit_status_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                        return True

                                                    if self.l2vpn_size is not None:
                                                        return True

                                                    if self.labeled_unicast_safi_path is not None:
                                                        return True

                                                    if self.local_label is not None:
                                                        return True

                                                    if self.local_nh is not None:
                                                        return True

                                                    if self.local_path_id is not None:
                                                        return True

                                                    if self.local_peers_advertised_to is not None:
                                                        for child_ref in self.local_peers_advertised_to:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.maximum_suppress_time is not None:
                                                        return True

                                                    if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                        return True

                                                    if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                        return True

                                                    if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                        return True

                                                    if self.mvpn_path_flags is not None:
                                                        return True

                                                    if self.mvpn_pmsi_flags is not None:
                                                        return True

                                                    if self.mvpn_pmsi_label is not None:
                                                        return True

                                                    if self.mvpn_pmsi_type is not None:
                                                        return True

                                                    if self.mvpn_pmsi_value is not None:
                                                        for child_ref in self.mvpn_pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.mvpn_sfs_path is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.neighbor_router_id is not None:
                                                        return True

                                                    if self.next_hop is not None and self.next_hop._has_data():
                                                        return True

                                                    if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                        return True

                                                    if self.path_flags is not None:
                                                        return True

                                                    if self.path_flap_count is not None:
                                                        return True

                                                    if self.path_import_flags is not None:
                                                        return True

                                                    if self.path_rt_set_id is not None:
                                                        return True

                                                    if self.path_rt_set_route_count is not None:
                                                        return True

                                                    if self.path_table_version is not None:
                                                        return True

                                                    if self.path_weight is not None:
                                                        return True

                                                    if self.pe_peers_advertised_to is not None:
                                                        for child_ref in self.pe_peers_advertised_to:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.rcvd_label is not None:
                                                        return True

                                                    if self.rcvd_path_id is not None:
                                                        return True

                                                    if self.reuse_value is not None:
                                                        return True

                                                    if self.rib_failed is not None:
                                                        return True

                                                    if self.route_type is not None:
                                                        return True

                                                    if self.rpki_origin_as_validation_disabled is not None:
                                                        return True

                                                    if self.rt_set_limit_enabled is not None:
                                                        return True

                                                    if self.second_label is not None:
                                                        return True

                                                    if self.seconds_since_first_flap is not None:
                                                        return True

                                                    if self.show_rpki_origin_as_validity is not None:
                                                        return True

                                                    if self.sn_rpki_origin_as_validity is not None:
                                                        return True

                                                    if self.suppress_penalty is not None:
                                                        return True

                                                    if self.time_to_unsuppress is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation']['meta_info']


                                            class AttributesAfterPolicyIn(object):
                                                """
                                                Attributes after inbound policy applied
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\:  bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\:  bool
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                    self.attr_set.parent = self
                                                    self.attribute_key_number = None
                                                    self.attribute_reuse_id_config = None
                                                    self.attribute_reuse_id_current = None
                                                    self.attribute_reuse_id_keys = None
                                                    self.attribute_reuse_id_max_id = None
                                                    self.attribute_reuse_id_node = None
                                                    self.attribute_reuse_id_recover_sec = None
                                                    self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self.is_application_gateway_present = None
                                                    self.is_as_path2_byte = None
                                                    self.is_attr_set_present = None
                                                    self.is_ribrnh_present = None
                                                    self.is_rnh_present = None
                                                    self.ribrnh_encap = None
                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self.ribrnh_mac = None
                                                    self.ribrnh_table = None
                                                    self.ribrnh_vni = None
                                                    self.ribrnhip_table = None
                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self.rnh_addr_len = None
                                                    self.rnh_len = None
                                                    self.rnh_type = None
                                                    self.set_aigp_inbound_igp = None
                                                    self.set_aigp_inbound_metric = None
                                                    self.vpn_distinguisher = None


                                                class CommonAttributes(object):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_encap_present
                                                    
                                                    	Tunnel Encap attribute present 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_policy_allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_binding_sid
                                                    
                                                    	SR Policy Binding sid
                                                    	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_explicit_path
                                                    
                                                    	SR Policy Explicit paths
                                                    	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                    
                                                    .. attribute:: sr_policy_preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_tunnel_request_state
                                                    
                                                    	SR Tunnel Request State
                                                    	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                    
                                                    .. attribute:: sr_tunnel_state
                                                    
                                                    	SR Tunnel State
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encap Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.aggregator_address = None
                                                        self.aggregator_as = None
                                                        self.aigp_metric_value = None
                                                        self.as_path = None
                                                        self.cluster = YList()
                                                        self.cluster.parent = self
                                                        self.cluster.name = 'cluster'
                                                        self.community = YList()
                                                        self.community.parent = self
                                                        self.community.name = 'community'
                                                        self.connector_type = None
                                                        self.connector_value = YList()
                                                        self.connector_value.parent = self
                                                        self.connector_value.name = 'connector_value'
                                                        self.extended_community = YList()
                                                        self.extended_community.parent = self
                                                        self.extended_community.name = 'extended_community'
                                                        self.extended_community_flags = None
                                                        self.is_aggregator_present = None
                                                        self.is_aigp_present = None
                                                        self.is_as_path_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_community_present = None
                                                        self.is_connector_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_label_index_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_metric_present = None
                                                        self.is_origin_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_ssa_present = None
                                                        self.is_tunnel_encap_present = None
                                                        self.l2tpv3_cookie = YList()
                                                        self.l2tpv3_cookie.parent = self
                                                        self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                        self.l2tpv3_session_id = None
                                                        self.label_index_attr = YList()
                                                        self.label_index_attr.parent = self
                                                        self.label_index_attr.name = 'label_index_attr'
                                                        self.local_preference = None
                                                        self.ls_attr = YList()
                                                        self.ls_attr.parent = self
                                                        self.ls_attr.name = 'ls_attr'
                                                        self.metric = None
                                                        self.neighbor_as = None
                                                        self.origin = None
                                                        self.originator = None
                                                        self.pe_distinguisher_label = YList()
                                                        self.pe_distinguisher_label.parent = self
                                                        self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.pmsi_type = None
                                                        self.pmsi_value = YList()
                                                        self.pmsi_value.parent = self
                                                        self.pmsi_value.name = 'pmsi_value'
                                                        self.ppm_pvalue = None
                                                        self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                        self.sr_policy_allocated_binding_sid.parent = self
                                                        self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                        self.sr_policy_binding_sid.parent = self
                                                        self.sr_policy_explicit_path = YList()
                                                        self.sr_policy_explicit_path.parent = self
                                                        self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                        self.sr_policy_preference = None
                                                        self.sr_tunnel_request_state = None
                                                        self.sr_tunnel_state = None
                                                        self.tunnel_encap_type = None
                                                        self.unknown_attribute = YList()
                                                        self.unknown_attribute.parent = self
                                                        self.unknown_attribute.name = 'unknown_attribute'


                                                    class SrPolicyBindingSid(object):
                                                        """
                                                        SR Policy Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                    class SrPolicyAllocatedBindingSid(object):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                    class Community(object):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                    class ExtendedCommunity(object):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                    class UnknownAttribute(object):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                    class Cluster(object):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                    class L2Tpv3Cookie(object):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                    class ConnectorValue(object):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                    class PmsiValue(object):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                    class LsAttr(object):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                    class LabelIndexAttr(object):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                    class PeDistinguisherLabel(object):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.label = None
                                                            self.pe_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.label is not None:
                                                                return True

                                                            if self.pe_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                    class SrPolicyExplicitPath(object):
                                                        """
                                                        SR Policy Explicit paths
                                                        
                                                        .. attribute:: sid
                                                        
                                                        	Sidlist for explicit path
                                                        	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of explicit path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.sid = YList()
                                                            self.sid.parent = self
                                                            self.sid.name = 'sid'
                                                            self.weight = None


                                                        class Sid(object):
                                                            """
                                                            Sidlist for explicit path
                                                            
                                                            .. attribute:: ipv4
                                                            
                                                            	IP Address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6
                                                            
                                                            	IPv6 address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label sid
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Sid Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4 = None
                                                                self.ipv6 = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4 is not None:
                                                                    return True

                                                                if self.ipv6 is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.sid is not None:
                                                                for child_ref in self.sid:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.weight is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.aggregator_address is not None:
                                                            return True

                                                        if self.aggregator_as is not None:
                                                            return True

                                                        if self.aigp_metric_value is not None:
                                                            return True

                                                        if self.as_path is not None:
                                                            return True

                                                        if self.cluster is not None:
                                                            for child_ref in self.cluster:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.community is not None:
                                                            for child_ref in self.community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.connector_type is not None:
                                                            return True

                                                        if self.connector_value is not None:
                                                            for child_ref in self.connector_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community is not None:
                                                            for child_ref in self.extended_community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community_flags is not None:
                                                            return True

                                                        if self.is_aggregator_present is not None:
                                                            return True

                                                        if self.is_aigp_present is not None:
                                                            return True

                                                        if self.is_as_path_present is not None:
                                                            return True

                                                        if self.is_atomic_aggregate_present is not None:
                                                            return True

                                                        if self.is_community_present is not None:
                                                            return True

                                                        if self.is_connector_present is not None:
                                                            return True

                                                        if self.is_extended_community_present is not None:
                                                            return True

                                                        if self.is_label_index_present is not None:
                                                            return True

                                                        if self.is_local_pref_present is not None:
                                                            return True

                                                        if self.is_ls_attribute_present is not None:
                                                            return True

                                                        if self.is_metric_present is not None:
                                                            return True

                                                        if self.is_origin_present is not None:
                                                            return True

                                                        if self.is_pe_distinguisher_label_present is not None:
                                                            return True

                                                        if self.is_pmsi_present is not None:
                                                            return True

                                                        if self.is_pppmp_present is not None:
                                                            return True

                                                        if self.is_ssa_present is not None:
                                                            return True

                                                        if self.is_tunnel_encap_present is not None:
                                                            return True

                                                        if self.l2tpv3_cookie is not None:
                                                            for child_ref in self.l2tpv3_cookie:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.l2tpv3_session_id is not None:
                                                            return True

                                                        if self.label_index_attr is not None:
                                                            for child_ref in self.label_index_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.local_preference is not None:
                                                            return True

                                                        if self.ls_attr is not None:
                                                            for child_ref in self.ls_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.metric is not None:
                                                            return True

                                                        if self.neighbor_as is not None:
                                                            return True

                                                        if self.origin is not None:
                                                            return True

                                                        if self.originator is not None:
                                                            return True

                                                        if self.pe_distinguisher_label is not None:
                                                            for child_ref in self.pe_distinguisher_label:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.pmsi_flags is not None:
                                                            return True

                                                        if self.pmsi_label is not None:
                                                            return True

                                                        if self.pmsi_type is not None:
                                                            return True

                                                        if self.pmsi_value is not None:
                                                            for child_ref in self.pmsi_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.ppm_pvalue is not None:
                                                            return True

                                                        if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_explicit_path is not None:
                                                            for child_ref in self.sr_policy_explicit_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.sr_policy_preference is not None:
                                                            return True

                                                        if self.sr_tunnel_request_state is not None:
                                                            return True

                                                        if self.sr_tunnel_state is not None:
                                                            return True

                                                        if self.tunnel_encap_type is not None:
                                                            return True

                                                        if self.unknown_attribute is not None:
                                                            for child_ref in self.unknown_attribute:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                                class AttrSet(object):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_encap_present
                                                    
                                                    	Tunnel Encap attribute present 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_policy_allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_binding_sid
                                                    
                                                    	SR Policy Binding sid
                                                    	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_explicit_path
                                                    
                                                    	SR Policy Explicit paths
                                                    	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                    
                                                    .. attribute:: sr_policy_preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_tunnel_request_state
                                                    
                                                    	SR Tunnel Request State
                                                    	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                    
                                                    .. attribute:: sr_tunnel_state
                                                    
                                                    	SR Tunnel State
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encap Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.aggregator_address = None
                                                        self.aggregator_as = None
                                                        self.aigp_metric_value = None
                                                        self.as_path = None
                                                        self.cluster = YList()
                                                        self.cluster.parent = self
                                                        self.cluster.name = 'cluster'
                                                        self.community = YList()
                                                        self.community.parent = self
                                                        self.community.name = 'community'
                                                        self.connector_type = None
                                                        self.connector_value = YList()
                                                        self.connector_value.parent = self
                                                        self.connector_value.name = 'connector_value'
                                                        self.extended_community = YList()
                                                        self.extended_community.parent = self
                                                        self.extended_community.name = 'extended_community'
                                                        self.extended_community_flags = None
                                                        self.is_aggregator_present = None
                                                        self.is_aigp_present = None
                                                        self.is_as_path_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_community_present = None
                                                        self.is_connector_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_label_index_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_metric_present = None
                                                        self.is_origin_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_ssa_present = None
                                                        self.is_tunnel_encap_present = None
                                                        self.l2tpv3_cookie = YList()
                                                        self.l2tpv3_cookie.parent = self
                                                        self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                        self.l2tpv3_session_id = None
                                                        self.label_index_attr = YList()
                                                        self.label_index_attr.parent = self
                                                        self.label_index_attr.name = 'label_index_attr'
                                                        self.local_preference = None
                                                        self.ls_attr = YList()
                                                        self.ls_attr.parent = self
                                                        self.ls_attr.name = 'ls_attr'
                                                        self.metric = None
                                                        self.neighbor_as = None
                                                        self.origin = None
                                                        self.originator = None
                                                        self.pe_distinguisher_label = YList()
                                                        self.pe_distinguisher_label.parent = self
                                                        self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.pmsi_type = None
                                                        self.pmsi_value = YList()
                                                        self.pmsi_value.parent = self
                                                        self.pmsi_value.name = 'pmsi_value'
                                                        self.ppm_pvalue = None
                                                        self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                        self.sr_policy_allocated_binding_sid.parent = self
                                                        self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                        self.sr_policy_binding_sid.parent = self
                                                        self.sr_policy_explicit_path = YList()
                                                        self.sr_policy_explicit_path.parent = self
                                                        self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                        self.sr_policy_preference = None
                                                        self.sr_tunnel_request_state = None
                                                        self.sr_tunnel_state = None
                                                        self.tunnel_encap_type = None
                                                        self.unknown_attribute = YList()
                                                        self.unknown_attribute.parent = self
                                                        self.unknown_attribute.name = 'unknown_attribute'


                                                    class SrPolicyBindingSid(object):
                                                        """
                                                        SR Policy Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                    class SrPolicyAllocatedBindingSid(object):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                    class Community(object):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                    class ExtendedCommunity(object):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                    class UnknownAttribute(object):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                    class Cluster(object):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                    class L2Tpv3Cookie(object):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                    class ConnectorValue(object):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                    class PmsiValue(object):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                    class LsAttr(object):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                    class LabelIndexAttr(object):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                    class PeDistinguisherLabel(object):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.label = None
                                                            self.pe_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.label is not None:
                                                                return True

                                                            if self.pe_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                    class SrPolicyExplicitPath(object):
                                                        """
                                                        SR Policy Explicit paths
                                                        
                                                        .. attribute:: sid
                                                        
                                                        	Sidlist for explicit path
                                                        	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of explicit path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.sid = YList()
                                                            self.sid.parent = self
                                                            self.sid.name = 'sid'
                                                            self.weight = None


                                                        class Sid(object):
                                                            """
                                                            Sidlist for explicit path
                                                            
                                                            .. attribute:: ipv4
                                                            
                                                            	IP Address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6
                                                            
                                                            	IPv6 address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label sid
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Sid Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4 = None
                                                                self.ipv6 = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4 is not None:
                                                                    return True

                                                                if self.ipv6 is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.sid is not None:
                                                                for child_ref in self.sid:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.weight is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.aggregator_address is not None:
                                                            return True

                                                        if self.aggregator_as is not None:
                                                            return True

                                                        if self.aigp_metric_value is not None:
                                                            return True

                                                        if self.as_path is not None:
                                                            return True

                                                        if self.cluster is not None:
                                                            for child_ref in self.cluster:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.community is not None:
                                                            for child_ref in self.community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.connector_type is not None:
                                                            return True

                                                        if self.connector_value is not None:
                                                            for child_ref in self.connector_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community is not None:
                                                            for child_ref in self.extended_community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community_flags is not None:
                                                            return True

                                                        if self.is_aggregator_present is not None:
                                                            return True

                                                        if self.is_aigp_present is not None:
                                                            return True

                                                        if self.is_as_path_present is not None:
                                                            return True

                                                        if self.is_atomic_aggregate_present is not None:
                                                            return True

                                                        if self.is_community_present is not None:
                                                            return True

                                                        if self.is_connector_present is not None:
                                                            return True

                                                        if self.is_extended_community_present is not None:
                                                            return True

                                                        if self.is_label_index_present is not None:
                                                            return True

                                                        if self.is_local_pref_present is not None:
                                                            return True

                                                        if self.is_ls_attribute_present is not None:
                                                            return True

                                                        if self.is_metric_present is not None:
                                                            return True

                                                        if self.is_origin_present is not None:
                                                            return True

                                                        if self.is_pe_distinguisher_label_present is not None:
                                                            return True

                                                        if self.is_pmsi_present is not None:
                                                            return True

                                                        if self.is_pppmp_present is not None:
                                                            return True

                                                        if self.is_ssa_present is not None:
                                                            return True

                                                        if self.is_tunnel_encap_present is not None:
                                                            return True

                                                        if self.l2tpv3_cookie is not None:
                                                            for child_ref in self.l2tpv3_cookie:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.l2tpv3_session_id is not None:
                                                            return True

                                                        if self.label_index_attr is not None:
                                                            for child_ref in self.label_index_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.local_preference is not None:
                                                            return True

                                                        if self.ls_attr is not None:
                                                            for child_ref in self.ls_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.metric is not None:
                                                            return True

                                                        if self.neighbor_as is not None:
                                                            return True

                                                        if self.origin is not None:
                                                            return True

                                                        if self.originator is not None:
                                                            return True

                                                        if self.pe_distinguisher_label is not None:
                                                            for child_ref in self.pe_distinguisher_label:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.pmsi_flags is not None:
                                                            return True

                                                        if self.pmsi_label is not None:
                                                            return True

                                                        if self.pmsi_type is not None:
                                                            return True

                                                        if self.pmsi_value is not None:
                                                            for child_ref in self.pmsi_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.ppm_pvalue is not None:
                                                            return True

                                                        if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_explicit_path is not None:
                                                            for child_ref in self.sr_policy_explicit_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.sr_policy_preference is not None:
                                                            return True

                                                        if self.sr_tunnel_request_state is not None:
                                                            return True

                                                        if self.sr_tunnel_state is not None:
                                                            return True

                                                        if self.tunnel_encap_type is not None:
                                                            return True

                                                        if self.unknown_attribute is not None:
                                                            for child_ref in self.unknown_attribute:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                                class RnhAddr(object):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.len = None
                                                        self.mac_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.len is not None:
                                                            return True

                                                        if self.mac_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                                class RibrnhIp(object):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.attr_set is not None and self.attr_set._has_data():
                                                        return True

                                                    if self.attribute_key_number is not None:
                                                        return True

                                                    if self.attribute_reuse_id_config is not None:
                                                        return True

                                                    if self.attribute_reuse_id_current is not None:
                                                        return True

                                                    if self.attribute_reuse_id_keys is not None:
                                                        return True

                                                    if self.attribute_reuse_id_max_id is not None:
                                                        return True

                                                    if self.attribute_reuse_id_node is not None:
                                                        return True

                                                    if self.attribute_reuse_id_recover_sec is not None:
                                                        return True

                                                    if self.common_attributes is not None and self.common_attributes._has_data():
                                                        return True

                                                    if self.is_application_gateway_present is not None:
                                                        return True

                                                    if self.is_as_path2_byte is not None:
                                                        return True

                                                    if self.is_attr_set_present is not None:
                                                        return True

                                                    if self.is_ribrnh_present is not None:
                                                        return True

                                                    if self.is_rnh_present is not None:
                                                        return True

                                                    if self.ribrnh_encap is not None:
                                                        return True

                                                    if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                        return True

                                                    if self.ribrnh_mac is not None:
                                                        return True

                                                    if self.ribrnh_table is not None:
                                                        return True

                                                    if self.ribrnh_vni is not None:
                                                        return True

                                                    if self.ribrnhip_table is not None:
                                                        return True

                                                    if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                        return True

                                                    if self.rnh_addr_len is not None:
                                                        return True

                                                    if self.rnh_len is not None:
                                                        return True

                                                    if self.rnh_type is not None:
                                                        return True

                                                    if self.set_aigp_inbound_igp is not None:
                                                        return True

                                                    if self.set_aigp_inbound_metric is not None:
                                                        return True

                                                    if self.vpn_distinguisher is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-process-instance-path'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.af_name is not None:
                                                    return True

                                                if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                    return True

                                                if self.label_fail is not None:
                                                    return True

                                                if self.label_o_or_version is not None:
                                                    return True

                                                if self.label_oor is not None:
                                                    return True

                                                if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                    return True

                                                if self.no_path is not None:
                                                    return True

                                                if self.path_information is not None and self.path_information._has_data():
                                                    return True

                                                if self.prefix_version is not None:
                                                    return True

                                                if self.process_instance_id is not None:
                                                    return True

                                                if self.route_distinguisher is not None:
                                                    return True

                                                if self.source_route_distinguisher is not None:
                                                    return True

                                                if self.source_vrf_name is not None:
                                                    return True

                                                if self.srcaf_name is not None:
                                                    return True

                                                if self.vrf_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath']['meta_info']


                                        class ActiveProcessInstancePath(object):
                                            """
                                            Active's paths for this net 
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: attributes_after_policy_in
                                            
                                            	Attributes after inbound policy applied
                                            	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn>`
                                            
                                            .. attribute:: label_fail
                                            
                                            	LSD label allocation failed 
                                            	**type**\:  bool
                                            
                                            .. attribute:: label_o_or_version
                                            
                                            	Label Version when OOR happens
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_oor
                                            
                                            	LSD label space is exhausted
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address_xr
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr>`
                                            
                                            .. attribute:: no_path
                                            
                                            	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                            	**type**\:  bool
                                            
                                            .. attribute:: path_information
                                            
                                            	Path information
                                            	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation>`
                                            
                                            .. attribute:: prefix_version
                                            
                                            	Version of BGP Prefix Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: process_instance_id
                                            
                                            	Process instance ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_route_distinguisher
                                            
                                            	Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_vrf_name
                                            
                                            	Name of the source VRF
                                            	**type**\:  str
                                            
                                            .. attribute:: srcaf_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.af_name = None
                                                self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn()
                                                self.attributes_after_policy_in.parent = self
                                                self.label_fail = None
                                                self.label_o_or_version = None
                                                self.label_oor = None
                                                self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr()
                                                self.neighbor_address_xr.parent = self
                                                self.no_path = None
                                                self.path_information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation()
                                                self.path_information.parent = self
                                                self.prefix_version = None
                                                self.process_instance_id = None
                                                self.route_distinguisher = None
                                                self.source_route_distinguisher = None
                                                self.source_vrf_name = None
                                                self.srcaf_name = None
                                                self.vrf_name = None


                                            class NeighborAddressXr(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr']['meta_info']


                                            class PathInformation(object):
                                                """
                                                Path information
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\:  bool
                                                
                                                .. attribute:: accept_own_self_originated_p_ath
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\:  bool
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\:  bool
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix>`
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\:  bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\:  bool
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.GwAddr>`
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_esi
                                                
                                                	Path has EVPN ESI
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_rcvd_label
                                                
                                                	Path has received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\:  bool
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebg_ps
                                                
                                                	Not advertised to EBGPs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi>`
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress>`
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop>`
                                                
                                                .. attribute:: nhte_tunnel
                                                
                                                	NH TE tunnel information
                                                	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhteTunnel>`
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\:  bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.accept_own_path = None
                                                    self.accept_own_self_originated_p_ath = None
                                                    self.add_path_orr_bitfield = YList()
                                                    self.add_path_orr_bitfield.parent = self
                                                    self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                    self.advertisedto_pe = None
                                                    self.aigp_metric = None
                                                    self.best_path_comp_stage = None
                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self.best_path_id = None
                                                    self.best_path_id_comp_winner = None
                                                    self.best_path_orr_bitfield = YList()
                                                    self.best_path_orr_bitfield.parent = self
                                                    self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self.dampen_penalty = None
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.fspec_invalid_path = None
                                                    self.graceful_shutdown = None
                                                    self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self.halflife_time = None
                                                    self.has_esi = None
                                                    self.has_gw_addr = None
                                                    self.has_local_net_label = None
                                                    self.has_mdt_group_addr = None
                                                    self.has_mvpn_extcomm = None
                                                    self.has_mvpn_nbr_addr = None
                                                    self.has_mvpn_nexthop_addr = None
                                                    self.has_mvpn_pmsi = None
                                                    self.has_rcvd_label = None
                                                    self.has_second_label = None
                                                    self.ibgp_signaled_validity = None
                                                    self.igp_metric = None
                                                    self.is_aggregation_suppressed = None
                                                    self.is_as_best = None
                                                    self.is_best_path = None
                                                    self.is_import_dampened = None
                                                    self.is_import_suspect = None
                                                    self.is_internal_path = None
                                                    self.is_partial_best = None
                                                    self.is_path_additional_path = None
                                                    self.is_path_advertised_local_as_only = None
                                                    self.is_path_af_install_eligible = None
                                                    self.is_path_backup = None
                                                    self.is_path_backup_protect_multipath = None
                                                    self.is_path_best_external = None
                                                    self.is_path_damped = None
                                                    self.is_path_from_confederation_peer = None
                                                    self.is_path_from_network_command = None
                                                    self.is_path_from_redistribute_command = None
                                                    self.is_path_from_route_reflector = None
                                                    self.is_path_history_held = None
                                                    self.is_path_imp_candidate = None
                                                    self.is_path_imported = None
                                                    self.is_path_local_aggregate = None
                                                    self.is_path_locally_sourced = None
                                                    self.is_path_long_lived_stale = None
                                                    self.is_path_multipath = None
                                                    self.is_path_nexthop_discarded = None
                                                    self.is_path_not_advertised = None
                                                    self.is_path_not_advertised_to_ebg_ps = None
                                                    self.is_path_received_only = None
                                                    self.is_path_reoriginated = None
                                                    self.is_path_reoriginated_stitching = None
                                                    self.is_path_stale = None
                                                    self.is_path_synced_with_igp = None
                                                    self.is_path_valid = None
                                                    self.is_path_vpn_only = None
                                                    self.is_permanent_path = None
                                                    self.is_received_path_not_modified = None
                                                    self.is_spkr_as_best = None
                                                    self.l2vpn_circuit_status_value = YList()
                                                    self.l2vpn_circuit_status_value.parent = self
                                                    self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                    self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi()
                                                    self.l2vpn_evpn_esi.parent = self
                                                    self.l2vpn_size = None
                                                    self.labeled_unicast_safi_path = None
                                                    self.local_label = None
                                                    self.local_nh = None
                                                    self.local_path_id = None
                                                    self.local_peers_advertised_to = YList()
                                                    self.local_peers_advertised_to.parent = self
                                                    self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                    self.maximum_suppress_time = None
                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self.mvpn_path_flags = None
                                                    self.mvpn_pmsi_flags = None
                                                    self.mvpn_pmsi_label = None
                                                    self.mvpn_pmsi_type = None
                                                    self.mvpn_pmsi_value = YList()
                                                    self.mvpn_pmsi_value.parent = self
                                                    self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                    self.mvpn_sfs_path = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.neighbor_router_id = None
                                                    self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop()
                                                    self.next_hop.parent = self
                                                    self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhteTunnel()
                                                    self.nhte_tunnel.parent = self
                                                    self.path_flags = None
                                                    self.path_flap_count = None
                                                    self.path_import_flags = None
                                                    self.path_rt_set_id = None
                                                    self.path_rt_set_route_count = None
                                                    self.path_table_version = None
                                                    self.path_weight = None
                                                    self.pe_peers_advertised_to = YList()
                                                    self.pe_peers_advertised_to.parent = self
                                                    self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                    self.rcvd_label = None
                                                    self.rcvd_path_id = None
                                                    self.reuse_value = None
                                                    self.rib_failed = None
                                                    self.route_type = None
                                                    self.rpki_origin_as_validation_disabled = None
                                                    self.rt_set_limit_enabled = None
                                                    self.second_label = None
                                                    self.seconds_since_first_flap = None
                                                    self.show_rpki_origin_as_validity = None
                                                    self.sn_rpki_origin_as_validity = None
                                                    self.suppress_penalty = None
                                                    self.time_to_unsuppress = None


                                                class BgpPrefix(object):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self.prefix_length = None


                                                    class Prefix(object):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.prefix is not None and self.prefix._has_data():
                                                            return True

                                                        if self.prefix_length is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix']['meta_info']


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress']['meta_info']


                                                class NextHop(object):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop']['meta_info']


                                                class NhteTunnel(object):
                                                    """
                                                    NH TE tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_te_tunnel
                                                    
                                                    	NH TE Tunnel info is present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last rib update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	tunnel name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	tunnel type
                                                    	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.binding_label = None
                                                        self.has_te_tunnel = None
                                                        self.is_tunnel_info_stale = None
                                                        self.is_tunnel_registered = None
                                                        self.is_tunnel_up = None
                                                        self.last_tunnel_update = None
                                                        self.tunnel_if_handle = None
                                                        self.tunnel_name = None
                                                        self.tunnel_type = None
                                                        self.tunnel_v6_enabled = None
                                                        self.tunnel_v6_required = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.binding_label is not None:
                                                            return True

                                                        if self.has_te_tunnel is not None:
                                                            return True

                                                        if self.is_tunnel_info_stale is not None:
                                                            return True

                                                        if self.is_tunnel_registered is not None:
                                                            return True

                                                        if self.is_tunnel_up is not None:
                                                            return True

                                                        if self.last_tunnel_update is not None:
                                                            return True

                                                        if self.tunnel_if_handle is not None:
                                                            return True

                                                        if self.tunnel_name is not None:
                                                            return True

                                                        if self.tunnel_type is not None:
                                                            return True

                                                        if self.tunnel_v6_enabled is not None:
                                                            return True

                                                        if self.tunnel_v6_required is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhteTunnel']['meta_info']


                                                class MdtGroupAddr(object):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr']['meta_info']


                                                class L2VpnEvpnEsi(object):
                                                    """
                                                    L2VPN EVPN ESI
                                                    
                                                    .. attribute:: esi
                                                    
                                                    	esi
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.esi = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.esi is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi']['meta_info']


                                                class GwAddr(object):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.len = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.len is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.GwAddr']['meta_info']


                                                class BestPathCompWinner(object):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner']['meta_info']


                                                class MvpnNbrAddr(object):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr']['meta_info']


                                                class MvpnNexthopAddr(object):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr']['meta_info']


                                                class L2VpnCircuitStatusValue(object):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                                class MvpnPmsiValue(object):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.ExtendedCommunity']['meta_info']


                                                class LocalPeersAdvertisedTo(object):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                                class PePeersAdvertisedTo(object):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo']['meta_info']


                                                class BestPathOrrBitfield(object):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield']['meta_info']


                                                class AddPathOrrBitfield(object):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.accept_own_path is not None:
                                                        return True

                                                    if self.accept_own_self_originated_p_ath is not None:
                                                        return True

                                                    if self.add_path_orr_bitfield is not None:
                                                        for child_ref in self.add_path_orr_bitfield:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.advertisedto_pe is not None:
                                                        return True

                                                    if self.aigp_metric is not None:
                                                        return True

                                                    if self.best_path_comp_stage is not None:
                                                        return True

                                                    if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                        return True

                                                    if self.best_path_id is not None:
                                                        return True

                                                    if self.best_path_id_comp_winner is not None:
                                                        return True

                                                    if self.best_path_orr_bitfield is not None:
                                                        for child_ref in self.best_path_orr_bitfield:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                        return True

                                                    if self.dampen_penalty is not None:
                                                        return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.fspec_invalid_path is not None:
                                                        return True

                                                    if self.graceful_shutdown is not None:
                                                        return True

                                                    if self.gw_addr is not None and self.gw_addr._has_data():
                                                        return True

                                                    if self.halflife_time is not None:
                                                        return True

                                                    if self.has_esi is not None:
                                                        return True

                                                    if self.has_gw_addr is not None:
                                                        return True

                                                    if self.has_local_net_label is not None:
                                                        return True

                                                    if self.has_mdt_group_addr is not None:
                                                        return True

                                                    if self.has_mvpn_extcomm is not None:
                                                        return True

                                                    if self.has_mvpn_nbr_addr is not None:
                                                        return True

                                                    if self.has_mvpn_nexthop_addr is not None:
                                                        return True

                                                    if self.has_mvpn_pmsi is not None:
                                                        return True

                                                    if self.has_rcvd_label is not None:
                                                        return True

                                                    if self.has_second_label is not None:
                                                        return True

                                                    if self.ibgp_signaled_validity is not None:
                                                        return True

                                                    if self.igp_metric is not None:
                                                        return True

                                                    if self.is_aggregation_suppressed is not None:
                                                        return True

                                                    if self.is_as_best is not None:
                                                        return True

                                                    if self.is_best_path is not None:
                                                        return True

                                                    if self.is_import_dampened is not None:
                                                        return True

                                                    if self.is_import_suspect is not None:
                                                        return True

                                                    if self.is_internal_path is not None:
                                                        return True

                                                    if self.is_partial_best is not None:
                                                        return True

                                                    if self.is_path_additional_path is not None:
                                                        return True

                                                    if self.is_path_advertised_local_as_only is not None:
                                                        return True

                                                    if self.is_path_af_install_eligible is not None:
                                                        return True

                                                    if self.is_path_backup is not None:
                                                        return True

                                                    if self.is_path_backup_protect_multipath is not None:
                                                        return True

                                                    if self.is_path_best_external is not None:
                                                        return True

                                                    if self.is_path_damped is not None:
                                                        return True

                                                    if self.is_path_from_confederation_peer is not None:
                                                        return True

                                                    if self.is_path_from_network_command is not None:
                                                        return True

                                                    if self.is_path_from_redistribute_command is not None:
                                                        return True

                                                    if self.is_path_from_route_reflector is not None:
                                                        return True

                                                    if self.is_path_history_held is not None:
                                                        return True

                                                    if self.is_path_imp_candidate is not None:
                                                        return True

                                                    if self.is_path_imported is not None:
                                                        return True

                                                    if self.is_path_local_aggregate is not None:
                                                        return True

                                                    if self.is_path_locally_sourced is not None:
                                                        return True

                                                    if self.is_path_long_lived_stale is not None:
                                                        return True

                                                    if self.is_path_multipath is not None:
                                                        return True

                                                    if self.is_path_nexthop_discarded is not None:
                                                        return True

                                                    if self.is_path_not_advertised is not None:
                                                        return True

                                                    if self.is_path_not_advertised_to_ebg_ps is not None:
                                                        return True

                                                    if self.is_path_received_only is not None:
                                                        return True

                                                    if self.is_path_reoriginated is not None:
                                                        return True

                                                    if self.is_path_reoriginated_stitching is not None:
                                                        return True

                                                    if self.is_path_stale is not None:
                                                        return True

                                                    if self.is_path_synced_with_igp is not None:
                                                        return True

                                                    if self.is_path_valid is not None:
                                                        return True

                                                    if self.is_path_vpn_only is not None:
                                                        return True

                                                    if self.is_permanent_path is not None:
                                                        return True

                                                    if self.is_received_path_not_modified is not None:
                                                        return True

                                                    if self.is_spkr_as_best is not None:
                                                        return True

                                                    if self.l2vpn_circuit_status_value is not None:
                                                        for child_ref in self.l2vpn_circuit_status_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                        return True

                                                    if self.l2vpn_size is not None:
                                                        return True

                                                    if self.labeled_unicast_safi_path is not None:
                                                        return True

                                                    if self.local_label is not None:
                                                        return True

                                                    if self.local_nh is not None:
                                                        return True

                                                    if self.local_path_id is not None:
                                                        return True

                                                    if self.local_peers_advertised_to is not None:
                                                        for child_ref in self.local_peers_advertised_to:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.maximum_suppress_time is not None:
                                                        return True

                                                    if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                        return True

                                                    if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                        return True

                                                    if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                        return True

                                                    if self.mvpn_path_flags is not None:
                                                        return True

                                                    if self.mvpn_pmsi_flags is not None:
                                                        return True

                                                    if self.mvpn_pmsi_label is not None:
                                                        return True

                                                    if self.mvpn_pmsi_type is not None:
                                                        return True

                                                    if self.mvpn_pmsi_value is not None:
                                                        for child_ref in self.mvpn_pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.mvpn_sfs_path is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.neighbor_router_id is not None:
                                                        return True

                                                    if self.next_hop is not None and self.next_hop._has_data():
                                                        return True

                                                    if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                        return True

                                                    if self.path_flags is not None:
                                                        return True

                                                    if self.path_flap_count is not None:
                                                        return True

                                                    if self.path_import_flags is not None:
                                                        return True

                                                    if self.path_rt_set_id is not None:
                                                        return True

                                                    if self.path_rt_set_route_count is not None:
                                                        return True

                                                    if self.path_table_version is not None:
                                                        return True

                                                    if self.path_weight is not None:
                                                        return True

                                                    if self.pe_peers_advertised_to is not None:
                                                        for child_ref in self.pe_peers_advertised_to:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.rcvd_label is not None:
                                                        return True

                                                    if self.rcvd_path_id is not None:
                                                        return True

                                                    if self.reuse_value is not None:
                                                        return True

                                                    if self.rib_failed is not None:
                                                        return True

                                                    if self.route_type is not None:
                                                        return True

                                                    if self.rpki_origin_as_validation_disabled is not None:
                                                        return True

                                                    if self.rt_set_limit_enabled is not None:
                                                        return True

                                                    if self.second_label is not None:
                                                        return True

                                                    if self.seconds_since_first_flap is not None:
                                                        return True

                                                    if self.show_rpki_origin_as_validity is not None:
                                                        return True

                                                    if self.sn_rpki_origin_as_validity is not None:
                                                        return True

                                                    if self.suppress_penalty is not None:
                                                        return True

                                                    if self.time_to_unsuppress is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation']['meta_info']


                                            class AttributesAfterPolicyIn(object):
                                                """
                                                Attributes after inbound policy applied
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\:  bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\:  bool
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                    self.attr_set.parent = self
                                                    self.attribute_key_number = None
                                                    self.attribute_reuse_id_config = None
                                                    self.attribute_reuse_id_current = None
                                                    self.attribute_reuse_id_keys = None
                                                    self.attribute_reuse_id_max_id = None
                                                    self.attribute_reuse_id_node = None
                                                    self.attribute_reuse_id_recover_sec = None
                                                    self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self.is_application_gateway_present = None
                                                    self.is_as_path2_byte = None
                                                    self.is_attr_set_present = None
                                                    self.is_ribrnh_present = None
                                                    self.is_rnh_present = None
                                                    self.ribrnh_encap = None
                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self.ribrnh_mac = None
                                                    self.ribrnh_table = None
                                                    self.ribrnh_vni = None
                                                    self.ribrnhip_table = None
                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self.rnh_addr_len = None
                                                    self.rnh_len = None
                                                    self.rnh_type = None
                                                    self.set_aigp_inbound_igp = None
                                                    self.set_aigp_inbound_metric = None
                                                    self.vpn_distinguisher = None


                                                class CommonAttributes(object):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_encap_present
                                                    
                                                    	Tunnel Encap attribute present 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_policy_allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_binding_sid
                                                    
                                                    	SR Policy Binding sid
                                                    	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_explicit_path
                                                    
                                                    	SR Policy Explicit paths
                                                    	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                    
                                                    .. attribute:: sr_policy_preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_tunnel_request_state
                                                    
                                                    	SR Tunnel Request State
                                                    	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                    
                                                    .. attribute:: sr_tunnel_state
                                                    
                                                    	SR Tunnel State
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encap Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.aggregator_address = None
                                                        self.aggregator_as = None
                                                        self.aigp_metric_value = None
                                                        self.as_path = None
                                                        self.cluster = YList()
                                                        self.cluster.parent = self
                                                        self.cluster.name = 'cluster'
                                                        self.community = YList()
                                                        self.community.parent = self
                                                        self.community.name = 'community'
                                                        self.connector_type = None
                                                        self.connector_value = YList()
                                                        self.connector_value.parent = self
                                                        self.connector_value.name = 'connector_value'
                                                        self.extended_community = YList()
                                                        self.extended_community.parent = self
                                                        self.extended_community.name = 'extended_community'
                                                        self.extended_community_flags = None
                                                        self.is_aggregator_present = None
                                                        self.is_aigp_present = None
                                                        self.is_as_path_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_community_present = None
                                                        self.is_connector_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_label_index_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_metric_present = None
                                                        self.is_origin_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_ssa_present = None
                                                        self.is_tunnel_encap_present = None
                                                        self.l2tpv3_cookie = YList()
                                                        self.l2tpv3_cookie.parent = self
                                                        self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                        self.l2tpv3_session_id = None
                                                        self.label_index_attr = YList()
                                                        self.label_index_attr.parent = self
                                                        self.label_index_attr.name = 'label_index_attr'
                                                        self.local_preference = None
                                                        self.ls_attr = YList()
                                                        self.ls_attr.parent = self
                                                        self.ls_attr.name = 'ls_attr'
                                                        self.metric = None
                                                        self.neighbor_as = None
                                                        self.origin = None
                                                        self.originator = None
                                                        self.pe_distinguisher_label = YList()
                                                        self.pe_distinguisher_label.parent = self
                                                        self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.pmsi_type = None
                                                        self.pmsi_value = YList()
                                                        self.pmsi_value.parent = self
                                                        self.pmsi_value.name = 'pmsi_value'
                                                        self.ppm_pvalue = None
                                                        self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                        self.sr_policy_allocated_binding_sid.parent = self
                                                        self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                        self.sr_policy_binding_sid.parent = self
                                                        self.sr_policy_explicit_path = YList()
                                                        self.sr_policy_explicit_path.parent = self
                                                        self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                        self.sr_policy_preference = None
                                                        self.sr_tunnel_request_state = None
                                                        self.sr_tunnel_state = None
                                                        self.tunnel_encap_type = None
                                                        self.unknown_attribute = YList()
                                                        self.unknown_attribute.parent = self
                                                        self.unknown_attribute.name = 'unknown_attribute'


                                                    class SrPolicyBindingSid(object):
                                                        """
                                                        SR Policy Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                    class SrPolicyAllocatedBindingSid(object):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                    class Community(object):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                    class ExtendedCommunity(object):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                    class UnknownAttribute(object):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                    class Cluster(object):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                    class L2Tpv3Cookie(object):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                    class ConnectorValue(object):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                    class PmsiValue(object):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                    class LsAttr(object):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                    class LabelIndexAttr(object):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                    class PeDistinguisherLabel(object):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.label = None
                                                            self.pe_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.label is not None:
                                                                return True

                                                            if self.pe_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                    class SrPolicyExplicitPath(object):
                                                        """
                                                        SR Policy Explicit paths
                                                        
                                                        .. attribute:: sid
                                                        
                                                        	Sidlist for explicit path
                                                        	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of explicit path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.sid = YList()
                                                            self.sid.parent = self
                                                            self.sid.name = 'sid'
                                                            self.weight = None


                                                        class Sid(object):
                                                            """
                                                            Sidlist for explicit path
                                                            
                                                            .. attribute:: ipv4
                                                            
                                                            	IP Address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6
                                                            
                                                            	IPv6 address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label sid
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Sid Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4 = None
                                                                self.ipv6 = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4 is not None:
                                                                    return True

                                                                if self.ipv6 is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.sid is not None:
                                                                for child_ref in self.sid:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.weight is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.aggregator_address is not None:
                                                            return True

                                                        if self.aggregator_as is not None:
                                                            return True

                                                        if self.aigp_metric_value is not None:
                                                            return True

                                                        if self.as_path is not None:
                                                            return True

                                                        if self.cluster is not None:
                                                            for child_ref in self.cluster:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.community is not None:
                                                            for child_ref in self.community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.connector_type is not None:
                                                            return True

                                                        if self.connector_value is not None:
                                                            for child_ref in self.connector_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community is not None:
                                                            for child_ref in self.extended_community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community_flags is not None:
                                                            return True

                                                        if self.is_aggregator_present is not None:
                                                            return True

                                                        if self.is_aigp_present is not None:
                                                            return True

                                                        if self.is_as_path_present is not None:
                                                            return True

                                                        if self.is_atomic_aggregate_present is not None:
                                                            return True

                                                        if self.is_community_present is not None:
                                                            return True

                                                        if self.is_connector_present is not None:
                                                            return True

                                                        if self.is_extended_community_present is not None:
                                                            return True

                                                        if self.is_label_index_present is not None:
                                                            return True

                                                        if self.is_local_pref_present is not None:
                                                            return True

                                                        if self.is_ls_attribute_present is not None:
                                                            return True

                                                        if self.is_metric_present is not None:
                                                            return True

                                                        if self.is_origin_present is not None:
                                                            return True

                                                        if self.is_pe_distinguisher_label_present is not None:
                                                            return True

                                                        if self.is_pmsi_present is not None:
                                                            return True

                                                        if self.is_pppmp_present is not None:
                                                            return True

                                                        if self.is_ssa_present is not None:
                                                            return True

                                                        if self.is_tunnel_encap_present is not None:
                                                            return True

                                                        if self.l2tpv3_cookie is not None:
                                                            for child_ref in self.l2tpv3_cookie:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.l2tpv3_session_id is not None:
                                                            return True

                                                        if self.label_index_attr is not None:
                                                            for child_ref in self.label_index_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.local_preference is not None:
                                                            return True

                                                        if self.ls_attr is not None:
                                                            for child_ref in self.ls_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.metric is not None:
                                                            return True

                                                        if self.neighbor_as is not None:
                                                            return True

                                                        if self.origin is not None:
                                                            return True

                                                        if self.originator is not None:
                                                            return True

                                                        if self.pe_distinguisher_label is not None:
                                                            for child_ref in self.pe_distinguisher_label:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.pmsi_flags is not None:
                                                            return True

                                                        if self.pmsi_label is not None:
                                                            return True

                                                        if self.pmsi_type is not None:
                                                            return True

                                                        if self.pmsi_value is not None:
                                                            for child_ref in self.pmsi_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.ppm_pvalue is not None:
                                                            return True

                                                        if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_explicit_path is not None:
                                                            for child_ref in self.sr_policy_explicit_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.sr_policy_preference is not None:
                                                            return True

                                                        if self.sr_tunnel_request_state is not None:
                                                            return True

                                                        if self.sr_tunnel_state is not None:
                                                            return True

                                                        if self.tunnel_encap_type is not None:
                                                            return True

                                                        if self.unknown_attribute is not None:
                                                            for child_ref in self.unknown_attribute:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                                class AttrSet(object):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_encap_present
                                                    
                                                    	Tunnel Encap attribute present 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_policy_allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_binding_sid
                                                    
                                                    	SR Policy Binding sid
                                                    	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_explicit_path
                                                    
                                                    	SR Policy Explicit paths
                                                    	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                    
                                                    .. attribute:: sr_policy_preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_tunnel_request_state
                                                    
                                                    	SR Tunnel Request State
                                                    	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                    
                                                    .. attribute:: sr_tunnel_state
                                                    
                                                    	SR Tunnel State
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encap Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.aggregator_address = None
                                                        self.aggregator_as = None
                                                        self.aigp_metric_value = None
                                                        self.as_path = None
                                                        self.cluster = YList()
                                                        self.cluster.parent = self
                                                        self.cluster.name = 'cluster'
                                                        self.community = YList()
                                                        self.community.parent = self
                                                        self.community.name = 'community'
                                                        self.connector_type = None
                                                        self.connector_value = YList()
                                                        self.connector_value.parent = self
                                                        self.connector_value.name = 'connector_value'
                                                        self.extended_community = YList()
                                                        self.extended_community.parent = self
                                                        self.extended_community.name = 'extended_community'
                                                        self.extended_community_flags = None
                                                        self.is_aggregator_present = None
                                                        self.is_aigp_present = None
                                                        self.is_as_path_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_community_present = None
                                                        self.is_connector_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_label_index_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_metric_present = None
                                                        self.is_origin_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_ssa_present = None
                                                        self.is_tunnel_encap_present = None
                                                        self.l2tpv3_cookie = YList()
                                                        self.l2tpv3_cookie.parent = self
                                                        self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                        self.l2tpv3_session_id = None
                                                        self.label_index_attr = YList()
                                                        self.label_index_attr.parent = self
                                                        self.label_index_attr.name = 'label_index_attr'
                                                        self.local_preference = None
                                                        self.ls_attr = YList()
                                                        self.ls_attr.parent = self
                                                        self.ls_attr.name = 'ls_attr'
                                                        self.metric = None
                                                        self.neighbor_as = None
                                                        self.origin = None
                                                        self.originator = None
                                                        self.pe_distinguisher_label = YList()
                                                        self.pe_distinguisher_label.parent = self
                                                        self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.pmsi_type = None
                                                        self.pmsi_value = YList()
                                                        self.pmsi_value.parent = self
                                                        self.pmsi_value.name = 'pmsi_value'
                                                        self.ppm_pvalue = None
                                                        self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                        self.sr_policy_allocated_binding_sid.parent = self
                                                        self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                        self.sr_policy_binding_sid.parent = self
                                                        self.sr_policy_explicit_path = YList()
                                                        self.sr_policy_explicit_path.parent = self
                                                        self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                        self.sr_policy_preference = None
                                                        self.sr_tunnel_request_state = None
                                                        self.sr_tunnel_state = None
                                                        self.tunnel_encap_type = None
                                                        self.unknown_attribute = YList()
                                                        self.unknown_attribute.parent = self
                                                        self.unknown_attribute.name = 'unknown_attribute'


                                                    class SrPolicyBindingSid(object):
                                                        """
                                                        SR Policy Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                    class SrPolicyAllocatedBindingSid(object):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                    class Community(object):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                    class ExtendedCommunity(object):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                    class UnknownAttribute(object):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                    class Cluster(object):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                    class L2Tpv3Cookie(object):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                    class ConnectorValue(object):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                    class PmsiValue(object):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                    class LsAttr(object):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                    class LabelIndexAttr(object):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                    class PeDistinguisherLabel(object):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.label = None
                                                            self.pe_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.label is not None:
                                                                return True

                                                            if self.pe_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                    class SrPolicyExplicitPath(object):
                                                        """
                                                        SR Policy Explicit paths
                                                        
                                                        .. attribute:: sid
                                                        
                                                        	Sidlist for explicit path
                                                        	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of explicit path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.sid = YList()
                                                            self.sid.parent = self
                                                            self.sid.name = 'sid'
                                                            self.weight = None


                                                        class Sid(object):
                                                            """
                                                            Sidlist for explicit path
                                                            
                                                            .. attribute:: ipv4
                                                            
                                                            	IP Address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6
                                                            
                                                            	IPv6 address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label sid
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Sid Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4 = None
                                                                self.ipv6 = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4 is not None:
                                                                    return True

                                                                if self.ipv6 is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.sid is not None:
                                                                for child_ref in self.sid:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.weight is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.aggregator_address is not None:
                                                            return True

                                                        if self.aggregator_as is not None:
                                                            return True

                                                        if self.aigp_metric_value is not None:
                                                            return True

                                                        if self.as_path is not None:
                                                            return True

                                                        if self.cluster is not None:
                                                            for child_ref in self.cluster:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.community is not None:
                                                            for child_ref in self.community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.connector_type is not None:
                                                            return True

                                                        if self.connector_value is not None:
                                                            for child_ref in self.connector_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community is not None:
                                                            for child_ref in self.extended_community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community_flags is not None:
                                                            return True

                                                        if self.is_aggregator_present is not None:
                                                            return True

                                                        if self.is_aigp_present is not None:
                                                            return True

                                                        if self.is_as_path_present is not None:
                                                            return True

                                                        if self.is_atomic_aggregate_present is not None:
                                                            return True

                                                        if self.is_community_present is not None:
                                                            return True

                                                        if self.is_connector_present is not None:
                                                            return True

                                                        if self.is_extended_community_present is not None:
                                                            return True

                                                        if self.is_label_index_present is not None:
                                                            return True

                                                        if self.is_local_pref_present is not None:
                                                            return True

                                                        if self.is_ls_attribute_present is not None:
                                                            return True

                                                        if self.is_metric_present is not None:
                                                            return True

                                                        if self.is_origin_present is not None:
                                                            return True

                                                        if self.is_pe_distinguisher_label_present is not None:
                                                            return True

                                                        if self.is_pmsi_present is not None:
                                                            return True

                                                        if self.is_pppmp_present is not None:
                                                            return True

                                                        if self.is_ssa_present is not None:
                                                            return True

                                                        if self.is_tunnel_encap_present is not None:
                                                            return True

                                                        if self.l2tpv3_cookie is not None:
                                                            for child_ref in self.l2tpv3_cookie:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.l2tpv3_session_id is not None:
                                                            return True

                                                        if self.label_index_attr is not None:
                                                            for child_ref in self.label_index_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.local_preference is not None:
                                                            return True

                                                        if self.ls_attr is not None:
                                                            for child_ref in self.ls_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.metric is not None:
                                                            return True

                                                        if self.neighbor_as is not None:
                                                            return True

                                                        if self.origin is not None:
                                                            return True

                                                        if self.originator is not None:
                                                            return True

                                                        if self.pe_distinguisher_label is not None:
                                                            for child_ref in self.pe_distinguisher_label:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.pmsi_flags is not None:
                                                            return True

                                                        if self.pmsi_label is not None:
                                                            return True

                                                        if self.pmsi_type is not None:
                                                            return True

                                                        if self.pmsi_value is not None:
                                                            for child_ref in self.pmsi_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.ppm_pvalue is not None:
                                                            return True

                                                        if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_explicit_path is not None:
                                                            for child_ref in self.sr_policy_explicit_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.sr_policy_preference is not None:
                                                            return True

                                                        if self.sr_tunnel_request_state is not None:
                                                            return True

                                                        if self.sr_tunnel_state is not None:
                                                            return True

                                                        if self.tunnel_encap_type is not None:
                                                            return True

                                                        if self.unknown_attribute is not None:
                                                            for child_ref in self.unknown_attribute:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                                class RnhAddr(object):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.len = None
                                                        self.mac_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.len is not None:
                                                            return True

                                                        if self.mac_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                                class RibrnhIp(object):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.attr_set is not None and self.attr_set._has_data():
                                                        return True

                                                    if self.attribute_key_number is not None:
                                                        return True

                                                    if self.attribute_reuse_id_config is not None:
                                                        return True

                                                    if self.attribute_reuse_id_current is not None:
                                                        return True

                                                    if self.attribute_reuse_id_keys is not None:
                                                        return True

                                                    if self.attribute_reuse_id_max_id is not None:
                                                        return True

                                                    if self.attribute_reuse_id_node is not None:
                                                        return True

                                                    if self.attribute_reuse_id_recover_sec is not None:
                                                        return True

                                                    if self.common_attributes is not None and self.common_attributes._has_data():
                                                        return True

                                                    if self.is_application_gateway_present is not None:
                                                        return True

                                                    if self.is_as_path2_byte is not None:
                                                        return True

                                                    if self.is_attr_set_present is not None:
                                                        return True

                                                    if self.is_ribrnh_present is not None:
                                                        return True

                                                    if self.is_rnh_present is not None:
                                                        return True

                                                    if self.ribrnh_encap is not None:
                                                        return True

                                                    if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                        return True

                                                    if self.ribrnh_mac is not None:
                                                        return True

                                                    if self.ribrnh_table is not None:
                                                        return True

                                                    if self.ribrnh_vni is not None:
                                                        return True

                                                    if self.ribrnhip_table is not None:
                                                        return True

                                                    if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                        return True

                                                    if self.rnh_addr_len is not None:
                                                        return True

                                                    if self.rnh_len is not None:
                                                        return True

                                                    if self.rnh_type is not None:
                                                        return True

                                                    if self.set_aigp_inbound_igp is not None:
                                                        return True

                                                    if self.set_aigp_inbound_metric is not None:
                                                        return True

                                                    if self.vpn_distinguisher is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-process-instance-path'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.af_name is not None:
                                                    return True

                                                if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                    return True

                                                if self.label_fail is not None:
                                                    return True

                                                if self.label_o_or_version is not None:
                                                    return True

                                                if self.label_oor is not None:
                                                    return True

                                                if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                    return True

                                                if self.no_path is not None:
                                                    return True

                                                if self.path_information is not None and self.path_information._has_data():
                                                    return True

                                                if self.prefix_version is not None:
                                                    return True

                                                if self.process_instance_id is not None:
                                                    return True

                                                if self.route_distinguisher is not None:
                                                    return True

                                                if self.source_route_distinguisher is not None:
                                                    return True

                                                if self.source_vrf_name is not None:
                                                    return True

                                                if self.srcaf_name is not None:
                                                    return True

                                                if self.vrf_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath']['meta_info']


                                        class LocalPathElement(object):
                                            """
                                            Local path element list
                                            
                                            .. attribute:: is_perm_path_pelem
                                            
                                            	Pelem for permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.NhteTunnel>`
                                            
                                            .. attribute:: pelem_flags
                                            
                                            	Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_gw_metric
                                            
                                            	Gateway metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_addpath_table_attr_version
                                            
                                            	No\-addpath Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_bestpath_table_attr_version
                                            
                                            	No\-bestpath Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_flags
                                            
                                            	Path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pelem_path_id
                                            
                                            	Local Path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_neighbor_addr
                                            
                                            	Path neighbor address
                                            	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr>`
                                            
                                            .. attribute:: pelem_path_nexthop
                                            
                                            	Path nexthop address
                                            	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop>`
                                            
                                            .. attribute:: pelem_path_peer_path_id
                                            
                                            	Path peer path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_table_attr_version
                                            
                                            	Path Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_table_attr_version
                                            
                                            	Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_version
                                            
                                            	Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_perm_path_pelem = None
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.pelem_flags = None
                                                self.pelem_gw_metric = None
                                                self.pelem_no_addpath_table_attr_version = None
                                                self.pelem_no_bestpath_table_attr_version = None
                                                self.pelem_path_flags = None
                                                self.pelem_path_id = None
                                                self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr()
                                                self.pelem_path_neighbor_addr.parent = self
                                                self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop()
                                                self.pelem_path_nexthop.parent = self
                                                self.pelem_path_peer_path_id = None
                                                self.pelem_path_table_attr_version = None
                                                self.pelem_table_attr_version = None
                                                self.pelem_version = None


                                            class PelemPathNexthop(object):
                                                """
                                                Path nexthop address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-nexthop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.NhteTunnel']['meta_info']


                                            class PelemPathNeighborAddr(object):
                                                """
                                                Path neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-neighbor-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-path-element'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_perm_path_pelem is not None:
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.pelem_flags is not None:
                                                    return True

                                                if self.pelem_gw_metric is not None:
                                                    return True

                                                if self.pelem_no_addpath_table_attr_version is not None:
                                                    return True

                                                if self.pelem_no_bestpath_table_attr_version is not None:
                                                    return True

                                                if self.pelem_path_flags is not None:
                                                    return True

                                                if self.pelem_path_id is not None:
                                                    return True

                                                if self.pelem_path_neighbor_addr is not None and self.pelem_path_neighbor_addr._has_data():
                                                    return True

                                                if self.pelem_path_nexthop is not None and self.pelem_path_nexthop._has_data():
                                                    return True

                                                if self.pelem_path_peer_path_id is not None:
                                                    return True

                                                if self.pelem_path_table_attr_version is not None:
                                                    return True

                                                if self.pelem_table_attr_version is not None:
                                                    return True

                                                if self.pelem_version is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement']['meta_info']


                                        class ActivePathElement(object):
                                            """
                                            Path element list received from Active inst
                                            
                                            .. attribute:: is_perm_path_pelem
                                            
                                            	Pelem for permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.NhteTunnel>`
                                            
                                            .. attribute:: pelem_flags
                                            
                                            	Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_gw_metric
                                            
                                            	Gateway metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_addpath_table_attr_version
                                            
                                            	No\-addpath Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_bestpath_table_attr_version
                                            
                                            	No\-bestpath Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_flags
                                            
                                            	Path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pelem_path_id
                                            
                                            	Local Path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_neighbor_addr
                                            
                                            	Path neighbor address
                                            	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr>`
                                            
                                            .. attribute:: pelem_path_nexthop
                                            
                                            	Path nexthop address
                                            	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop>`
                                            
                                            .. attribute:: pelem_path_peer_path_id
                                            
                                            	Path peer path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_table_attr_version
                                            
                                            	Path Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_table_attr_version
                                            
                                            	Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_version
                                            
                                            	Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_perm_path_pelem = None
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.pelem_flags = None
                                                self.pelem_gw_metric = None
                                                self.pelem_no_addpath_table_attr_version = None
                                                self.pelem_no_bestpath_table_attr_version = None
                                                self.pelem_path_flags = None
                                                self.pelem_path_id = None
                                                self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr()
                                                self.pelem_path_neighbor_addr.parent = self
                                                self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop()
                                                self.pelem_path_nexthop.parent = self
                                                self.pelem_path_peer_path_id = None
                                                self.pelem_path_table_attr_version = None
                                                self.pelem_table_attr_version = None
                                                self.pelem_version = None


                                            class PelemPathNexthop(object):
                                                """
                                                Path nexthop address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-nexthop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.NhteTunnel']['meta_info']


                                            class PelemPathNeighborAddr(object):
                                                """
                                                Path neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-neighbor-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-path-element'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_perm_path_pelem is not None:
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.pelem_flags is not None:
                                                    return True

                                                if self.pelem_gw_metric is not None:
                                                    return True

                                                if self.pelem_no_addpath_table_attr_version is not None:
                                                    return True

                                                if self.pelem_no_bestpath_table_attr_version is not None:
                                                    return True

                                                if self.pelem_path_flags is not None:
                                                    return True

                                                if self.pelem_path_id is not None:
                                                    return True

                                                if self.pelem_path_neighbor_addr is not None and self.pelem_path_neighbor_addr._has_data():
                                                    return True

                                                if self.pelem_path_nexthop is not None and self.pelem_path_nexthop._has_data():
                                                    return True

                                                if self.pelem_path_peer_path_id is not None:
                                                    return True

                                                if self.pelem_path_table_attr_version is not None:
                                                    return True

                                                if self.pelem_table_attr_version is not None:
                                                    return True

                                                if self.pelem_version is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-prefix'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.active_path_element is not None:
                                                for child_ref in self.active_path_element:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.active_process_instance_path is not None:
                                                for child_ref in self.active_process_instance_path:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.add_path_orr_bitfield is not None:
                                                for child_ref in self.add_path_orr_bitfield:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.advertisedto_pe is not None:
                                                return True

                                            if self.af_name is not None:
                                                return True

                                            if self.best_path_orr_bitfield is not None:
                                                for child_ref in self.best_path_orr_bitfield:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                return True

                                            if self.bit is not None:
                                                return True

                                            if self.flags is not None:
                                                return True

                                            if self.gateway_array is not None:
                                                return True

                                            if self.has_inconsistent_paths is not None:
                                                return True

                                            if self.has_lbl_retained is not None:
                                                return True

                                            if self.has_local_label is not None:
                                                return True

                                            if self.is_net_aggregation_suppressed is not None:
                                                return True

                                            if self.is_net_ldp_signaled is not None:
                                                return True

                                            if self.is_permanent_network is not None:
                                                return True

                                            if self.local_path_element is not None:
                                                for child_ref in self.local_path_element:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.local_peers_advertised_to is not None:
                                                for child_ref in self.local_peers_advertised_to:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.local_process_instance_path is not None:
                                                for child_ref in self.local_process_instance_path:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.net_backup_available is not None:
                                                return True

                                            if self.net_backup_label_rewrite_available is not None:
                                                return True

                                            if self.net_eibgp_multipath is not None:
                                                return True

                                            if self.net_extended_flags is not None:
                                                return True

                                            if self.net_flags is not None:
                                                return True

                                            if self.net_local_label is not None:
                                                return True

                                            if self.net_local_label_rewrite is not None:
                                                return True

                                            if self.net_local_label_srgb is not None:
                                                return True

                                            if self.net_multipath is not None:
                                                return True

                                            if self.network_prefix is not None:
                                                return True

                                            if self.num_of_path is not None:
                                                return True

                                            if self.pe_peers_advertised_to is not None:
                                                for child_ref in self.pe_peers_advertised_to:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.process_instance_id is not None:
                                                return True

                                            if self.rd is not None:
                                                return True

                                            if self.resilient_nexthop_set is not None:
                                                return True

                                            if self.rib_failed is not None:
                                                return True

                                            if self.route_distinguisher is not None:
                                                return True

                                            if self.table_brib_version is not None:
                                                return True

                                            if self.table_version is not None:
                                                return True

                                            if self.version is not None:
                                                return True

                                            if self.version_age is not None and self.version_age._has_data():
                                                return True

                                            if self.version_timestamp is not None and self.version_timestamp._has_data():
                                                return True

                                            if self.vrf_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes.NetworkPrefix']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-prefixes'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.network_prefix is not None:
                                            for child_ref in self.network_prefix:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkPrefixes']['meta_info']


                                class AdvertisedPathXr(object):
                                    """
                                    The BGP Advertised path table (bestpath)
                                    
                                    .. attribute:: advertised_path
                                    
                                    	A BGP Advertised path table entry (bestpath)
                                    	**type**\: list of    :py:class:`AdvertisedPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.advertised_path = YList()
                                        self.advertised_path.parent = self
                                        self.advertised_path.name = 'advertised_path'


                                    class AdvertisedPath(object):
                                        """
                                        A BGP Advertised path table entry (bestpath)
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr>`
                                        
                                        .. attribute:: network
                                        
                                        	Network Prefix in Hex format
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self.label_fail = None
                                            self.label_o_or_version = None
                                            self.label_oor = None
                                            self.neighbor_address = None
                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self.network = None
                                            self.no_path = None
                                            self.path_information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation()
                                            self.path_information.parent = self
                                            self.prefix_length = None
                                            self.prefix_version = None
                                            self.process_instance_id = None
                                            self.rd = None
                                            self.route_distinguisher = None
                                            self.source_route_distinguisher = None
                                            self.source_vrf_name = None
                                            self.srcaf_name = None
                                            self.vrf_name = None


                                        class NeighborAddressXr(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr']['meta_info']


                                        class PathInformation(object):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_esi
                                            
                                            	Path has EVPN ESI
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_rcvd_label
                                            
                                            	Path has received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebg_ps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2VpnEvpnEsi>`
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop>`
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhteTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_p_ath = None
                                                self.add_path_orr_bitfield = YList()
                                                self.add_path_orr_bitfield.parent = self
                                                self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                self.advertisedto_pe = None
                                                self.aigp_metric = None
                                                self.best_path_comp_stage = None
                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self.best_path_id = None
                                                self.best_path_id_comp_winner = None
                                                self.best_path_orr_bitfield = YList()
                                                self.best_path_orr_bitfield.parent = self
                                                self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self.dampen_penalty = None
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.fspec_invalid_path = None
                                                self.graceful_shutdown = None
                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self.halflife_time = None
                                                self.has_esi = None
                                                self.has_gw_addr = None
                                                self.has_local_net_label = None
                                                self.has_mdt_group_addr = None
                                                self.has_mvpn_extcomm = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.has_rcvd_label = None
                                                self.has_second_label = None
                                                self.ibgp_signaled_validity = None
                                                self.igp_metric = None
                                                self.is_aggregation_suppressed = None
                                                self.is_as_best = None
                                                self.is_best_path = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_internal_path = None
                                                self.is_partial_best = None
                                                self.is_path_additional_path = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_af_install_eligible = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_damped = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_history_held = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_imported = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_multipath = None
                                                self.is_path_nexthop_discarded = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebg_ps = None
                                                self.is_path_received_only = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_stale = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_valid = None
                                                self.is_path_vpn_only = None
                                                self.is_permanent_path = None
                                                self.is_received_path_not_modified = None
                                                self.is_spkr_as_best = None
                                                self.l2vpn_circuit_status_value = YList()
                                                self.l2vpn_circuit_status_value.parent = self
                                                self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2VpnEvpnEsi()
                                                self.l2vpn_evpn_esi.parent = self
                                                self.l2vpn_size = None
                                                self.labeled_unicast_safi_path = None
                                                self.local_label = None
                                                self.local_nh = None
                                                self.local_path_id = None
                                                self.local_peers_advertised_to = YList()
                                                self.local_peers_advertised_to.parent = self
                                                self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                self.maximum_suppress_time = None
                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self.mvpn_path_flags = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_value = YList()
                                                self.mvpn_pmsi_value.parent = self
                                                self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                self.mvpn_sfs_path = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.neighbor_router_id = None
                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.path_flags = None
                                                self.path_flap_count = None
                                                self.path_import_flags = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.path_table_version = None
                                                self.path_weight = None
                                                self.pe_peers_advertised_to = YList()
                                                self.pe_peers_advertised_to.parent = self
                                                self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                self.rcvd_label = None
                                                self.rcvd_path_id = None
                                                self.reuse_value = None
                                                self.rib_failed = None
                                                self.route_type = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.rt_set_limit_enabled = None
                                                self.second_label = None
                                                self.seconds_since_first_flap = None
                                                self.show_rpki_origin_as_validity = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.suppress_penalty = None
                                                self.time_to_unsuppress = None


                                            class BgpPrefix(object):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self.prefix_length = None


                                                class Prefix(object):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.prefix is not None and self.prefix._has_data():
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix']['meta_info']


                                            class NeighborAddress(object):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress']['meta_info']


                                            class NextHop(object):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhteTunnel']['meta_info']


                                            class MdtGroupAddr(object):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr']['meta_info']


                                            class L2VpnEvpnEsi(object):
                                                """
                                                L2VPN EVPN ESI
                                                
                                                .. attribute:: esi
                                                
                                                	esi
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.esi = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.esi is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2VpnEvpnEsi']['meta_info']


                                            class GwAddr(object):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr']['meta_info']


                                            class BestPathCompWinner(object):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner']['meta_info']


                                            class MvpnNbrAddr(object):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr']['meta_info']


                                            class MvpnNexthopAddr(object):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr']['meta_info']


                                            class L2VpnCircuitStatusValue(object):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                            class MvpnPmsiValue(object):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity']['meta_info']


                                            class LocalPeersAdvertisedTo(object):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                            class PePeersAdvertisedTo(object):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo']['meta_info']


                                            class BestPathOrrBitfield(object):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield']['meta_info']


                                            class AddPathOrrBitfield(object):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.accept_own_path is not None:
                                                    return True

                                                if self.accept_own_self_originated_p_ath is not None:
                                                    return True

                                                if self.add_path_orr_bitfield is not None:
                                                    for child_ref in self.add_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.advertisedto_pe is not None:
                                                    return True

                                                if self.aigp_metric is not None:
                                                    return True

                                                if self.best_path_comp_stage is not None:
                                                    return True

                                                if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                    return True

                                                if self.best_path_id is not None:
                                                    return True

                                                if self.best_path_id_comp_winner is not None:
                                                    return True

                                                if self.best_path_orr_bitfield is not None:
                                                    for child_ref in self.best_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                    return True

                                                if self.dampen_penalty is not None:
                                                    return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.fspec_invalid_path is not None:
                                                    return True

                                                if self.graceful_shutdown is not None:
                                                    return True

                                                if self.gw_addr is not None and self.gw_addr._has_data():
                                                    return True

                                                if self.halflife_time is not None:
                                                    return True

                                                if self.has_esi is not None:
                                                    return True

                                                if self.has_gw_addr is not None:
                                                    return True

                                                if self.has_local_net_label is not None:
                                                    return True

                                                if self.has_mdt_group_addr is not None:
                                                    return True

                                                if self.has_mvpn_extcomm is not None:
                                                    return True

                                                if self.has_mvpn_nbr_addr is not None:
                                                    return True

                                                if self.has_mvpn_nexthop_addr is not None:
                                                    return True

                                                if self.has_mvpn_pmsi is not None:
                                                    return True

                                                if self.has_rcvd_label is not None:
                                                    return True

                                                if self.has_second_label is not None:
                                                    return True

                                                if self.ibgp_signaled_validity is not None:
                                                    return True

                                                if self.igp_metric is not None:
                                                    return True

                                                if self.is_aggregation_suppressed is not None:
                                                    return True

                                                if self.is_as_best is not None:
                                                    return True

                                                if self.is_best_path is not None:
                                                    return True

                                                if self.is_import_dampened is not None:
                                                    return True

                                                if self.is_import_suspect is not None:
                                                    return True

                                                if self.is_internal_path is not None:
                                                    return True

                                                if self.is_partial_best is not None:
                                                    return True

                                                if self.is_path_additional_path is not None:
                                                    return True

                                                if self.is_path_advertised_local_as_only is not None:
                                                    return True

                                                if self.is_path_af_install_eligible is not None:
                                                    return True

                                                if self.is_path_backup is not None:
                                                    return True

                                                if self.is_path_backup_protect_multipath is not None:
                                                    return True

                                                if self.is_path_best_external is not None:
                                                    return True

                                                if self.is_path_damped is not None:
                                                    return True

                                                if self.is_path_from_confederation_peer is not None:
                                                    return True

                                                if self.is_path_from_network_command is not None:
                                                    return True

                                                if self.is_path_from_redistribute_command is not None:
                                                    return True

                                                if self.is_path_from_route_reflector is not None:
                                                    return True

                                                if self.is_path_history_held is not None:
                                                    return True

                                                if self.is_path_imp_candidate is not None:
                                                    return True

                                                if self.is_path_imported is not None:
                                                    return True

                                                if self.is_path_local_aggregate is not None:
                                                    return True

                                                if self.is_path_locally_sourced is not None:
                                                    return True

                                                if self.is_path_long_lived_stale is not None:
                                                    return True

                                                if self.is_path_multipath is not None:
                                                    return True

                                                if self.is_path_nexthop_discarded is not None:
                                                    return True

                                                if self.is_path_not_advertised is not None:
                                                    return True

                                                if self.is_path_not_advertised_to_ebg_ps is not None:
                                                    return True

                                                if self.is_path_received_only is not None:
                                                    return True

                                                if self.is_path_reoriginated is not None:
                                                    return True

                                                if self.is_path_reoriginated_stitching is not None:
                                                    return True

                                                if self.is_path_stale is not None:
                                                    return True

                                                if self.is_path_synced_with_igp is not None:
                                                    return True

                                                if self.is_path_valid is not None:
                                                    return True

                                                if self.is_path_vpn_only is not None:
                                                    return True

                                                if self.is_permanent_path is not None:
                                                    return True

                                                if self.is_received_path_not_modified is not None:
                                                    return True

                                                if self.is_spkr_as_best is not None:
                                                    return True

                                                if self.l2vpn_circuit_status_value is not None:
                                                    for child_ref in self.l2vpn_circuit_status_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                    return True

                                                if self.l2vpn_size is not None:
                                                    return True

                                                if self.labeled_unicast_safi_path is not None:
                                                    return True

                                                if self.local_label is not None:
                                                    return True

                                                if self.local_nh is not None:
                                                    return True

                                                if self.local_path_id is not None:
                                                    return True

                                                if self.local_peers_advertised_to is not None:
                                                    for child_ref in self.local_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.maximum_suppress_time is not None:
                                                    return True

                                                if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                    return True

                                                if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                    return True

                                                if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                    return True

                                                if self.mvpn_path_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_label is not None:
                                                    return True

                                                if self.mvpn_pmsi_type is not None:
                                                    return True

                                                if self.mvpn_pmsi_value is not None:
                                                    for child_ref in self.mvpn_pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.mvpn_sfs_path is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.neighbor_router_id is not None:
                                                    return True

                                                if self.next_hop is not None and self.next_hop._has_data():
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.path_flags is not None:
                                                    return True

                                                if self.path_flap_count is not None:
                                                    return True

                                                if self.path_import_flags is not None:
                                                    return True

                                                if self.path_rt_set_id is not None:
                                                    return True

                                                if self.path_rt_set_route_count is not None:
                                                    return True

                                                if self.path_table_version is not None:
                                                    return True

                                                if self.path_weight is not None:
                                                    return True

                                                if self.pe_peers_advertised_to is not None:
                                                    for child_ref in self.pe_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.rcvd_label is not None:
                                                    return True

                                                if self.rcvd_path_id is not None:
                                                    return True

                                                if self.reuse_value is not None:
                                                    return True

                                                if self.rib_failed is not None:
                                                    return True

                                                if self.route_type is not None:
                                                    return True

                                                if self.rpki_origin_as_validation_disabled is not None:
                                                    return True

                                                if self.rt_set_limit_enabled is not None:
                                                    return True

                                                if self.second_label is not None:
                                                    return True

                                                if self.seconds_since_first_flap is not None:
                                                    return True

                                                if self.show_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.sn_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.suppress_penalty is not None:
                                                    return True

                                                if self.time_to_unsuppress is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation']['meta_info']


                                        class AttributesAfterPolicyIn(object):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self.is_application_gateway_present = None
                                                self.is_as_path2_byte = None
                                                self.is_attr_set_present = None
                                                self.is_ribrnh_present = None
                                                self.is_rnh_present = None
                                                self.ribrnh_encap = None
                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self.ribrnh_mac = None
                                                self.ribrnh_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnhip_table = None
                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self.rnh_addr_len = None
                                                self.rnh_len = None
                                                self.rnh_type = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.vpn_distinguisher = None


                                            class CommonAttributes(object):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                            class AttrSet(object):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                            class RnhAddr(object):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None
                                                    self.mac_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    if self.mac_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                            class RibrnhIp(object):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.attr_set is not None and self.attr_set._has_data():
                                                    return True

                                                if self.attribute_key_number is not None:
                                                    return True

                                                if self.attribute_reuse_id_config is not None:
                                                    return True

                                                if self.attribute_reuse_id_current is not None:
                                                    return True

                                                if self.attribute_reuse_id_keys is not None:
                                                    return True

                                                if self.attribute_reuse_id_max_id is not None:
                                                    return True

                                                if self.attribute_reuse_id_node is not None:
                                                    return True

                                                if self.attribute_reuse_id_recover_sec is not None:
                                                    return True

                                                if self.common_attributes is not None and self.common_attributes._has_data():
                                                    return True

                                                if self.is_application_gateway_present is not None:
                                                    return True

                                                if self.is_as_path2_byte is not None:
                                                    return True

                                                if self.is_attr_set_present is not None:
                                                    return True

                                                if self.is_ribrnh_present is not None:
                                                    return True

                                                if self.is_rnh_present is not None:
                                                    return True

                                                if self.ribrnh_encap is not None:
                                                    return True

                                                if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                    return True

                                                if self.ribrnh_mac is not None:
                                                    return True

                                                if self.ribrnh_table is not None:
                                                    return True

                                                if self.ribrnh_vni is not None:
                                                    return True

                                                if self.ribrnhip_table is not None:
                                                    return True

                                                if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                    return True

                                                if self.rnh_addr_len is not None:
                                                    return True

                                                if self.rnh_len is not None:
                                                    return True

                                                if self.rnh_type is not None:
                                                    return True

                                                if self.set_aigp_inbound_igp is not None:
                                                    return True

                                                if self.set_aigp_inbound_metric is not None:
                                                    return True

                                                if self.vpn_distinguisher is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertised-path'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                return True

                                            if self.label_fail is not None:
                                                return True

                                            if self.label_o_or_version is not None:
                                                return True

                                            if self.label_oor is not None:
                                                return True

                                            if self.neighbor_address is not None:
                                                return True

                                            if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                return True

                                            if self.network is not None:
                                                return True

                                            if self.no_path is not None:
                                                return True

                                            if self.path_information is not None and self.path_information._has_data():
                                                return True

                                            if self.prefix_length is not None:
                                                return True

                                            if self.prefix_version is not None:
                                                return True

                                            if self.process_instance_id is not None:
                                                return True

                                            if self.rd is not None:
                                                return True

                                            if self.route_distinguisher is not None:
                                                return True

                                            if self.source_route_distinguisher is not None:
                                                return True

                                            if self.source_vrf_name is not None:
                                                return True

                                            if self.srcaf_name is not None:
                                                return True

                                            if self.vrf_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertised-path-xr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.advertised_path is not None:
                                            for child_ref in self.advertised_path:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr']['meta_info']


                                class SourcedNetworks(object):
                                    """
                                    The BGP Convergence table
                                    
                                    .. attribute:: sourced_network
                                    
                                    	A BGP network command table entry
                                    	**type**\: list of    :py:class:`SourcedNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.sourced_network = YList()
                                        self.sourced_network.parent = self
                                        self.sourced_network.name = 'sourced_network'


                                    class SourcedNetwork(object):
                                        """
                                        A BGP network command table entry
                                        
                                        .. attribute:: network  <key>
                                        
                                        	Network in prefix/length format
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        
                                        ----
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: is_backdoor
                                        
                                        	TRUE if net is a backdoor route
                                        	**type**\:  bool
                                        
                                        .. attribute:: sourced_prefix
                                        
                                        	Prefix length
                                        	**type**\:   :py:class:`SourcedPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.network = None
                                            self.af_name = None
                                            self.is_backdoor = None
                                            self.sourced_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix()
                                            self.sourced_prefix.parent = self


                                        class SourcedPrefix(object):
                                            """
                                            Prefix length
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix()
                                                self.prefix.parent = self
                                                self.prefix_length = None


                                            class Prefix(object):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sourced-prefix'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.prefix is not None and self.prefix._has_data():
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')
                                            if self.network is None:
                                                raise YPYModelError('Key property network is None')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sourced-network[Cisco-IOS-XR-ipv4-bgp-oper:network = ' + str(self.network) + ']'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.network is not None:
                                                return True

                                            if self.af_name is not None:
                                                return True

                                            if self.is_backdoor is not None:
                                                return True

                                            if self.sourced_prefix is not None and self.sourced_prefix._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sourced-networks'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.sourced_network is not None:
                                            for child_ref in self.sourced_network:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks']['meta_info']


                                class UpdateGroups(object):
                                    """
                                    The BGP Update group table
                                    
                                    .. attribute:: update_group
                                    
                                    	A BGP Update group table entry
                                    	**type**\: list of    :py:class:`UpdateGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.update_group = YList()
                                        self.update_group.parent = self
                                        self.update_group.name = 'update_group'


                                    class UpdateGroup(object):
                                        """
                                        A BGP Update group table entry
                                        
                                        .. attribute:: accepts_legacy_pe_rt_route
                                        
                                        	accept\-legacy\-pe\-RT route
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_local_labeled_route_unicast
                                        
                                        	Advertise routes with local\-label via Unicast SAFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_rt_type
                                        
                                        	Advertise RT type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: as_override
                                        
                                        	AS Override option
                                        	**type**\:  bool
                                        
                                        .. attribute:: desync_count
                                        
                                        	Number of times the update has been desynchronized
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: disable_def_vrf_imp_advertisement
                                        
                                        	Disable advertising default VRF  imported routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: disable_native_advertisement
                                        
                                        	Disable advertising native routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: disable_vrf_re_imp_advertisement
                                        
                                        	Disable advertising VRF re\-imported routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation type
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ext_nh_encoding
                                        
                                        	Extended nexthop encoding cap received
                                        	**type**\:  bool
                                        
                                        .. attribute:: filter_group_id
                                        
                                        	Filter group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: gshut_active
                                        
                                        	GSHUT active
                                        	**type**\:  bool
                                        
                                        .. attribute:: gshut_locpref
                                        
                                        	GSHUT local preference
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: gshut_locpref_set
                                        
                                        	GSHUT local preference set
                                        	**type**\:  bool
                                        
                                        .. attribute:: gshut_prepends
                                        
                                        	GSHUT AS prepends
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: has_orf_receive_capability
                                        
                                        	ORF receive capability
                                        	**type**\:  bool
                                        
                                        .. attribute:: is4_byte_as_peer
                                        
                                        	4\-byte AS capable peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_addpath_capable
                                        
                                        	Add\-path capable peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_adv_capable
                                        
                                        	Send tranlsated paths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_adv_perm_net_capable
                                        
                                        	Advertise Permanent\-Net capable peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_adv_reorg_capable
                                        
                                        	Send Re\-orig paths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_aigp_capable
                                        
                                        	AIGP capable peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_aigp_cost_community_capable
                                        
                                        	Send AIGP cost community to peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_aigp_med_capable
                                        
                                        	Send AIGP cost in MED
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_client_reflection_disabled
                                        
                                        	True if client\-to\-client reflection is disabled 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_common_admin_peers
                                        
                                        	Common admin peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_directly_connected_ebgp_v6_peers
                                        
                                        	Directly connected EBGP v6 peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_internal_peers
                                        
                                        	Internal peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_labeled_afi_enabled
                                        
                                        	Update group has labeled AFI enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_llgr_capable
                                        
                                        	Send Long\-lived Stale paths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_orr_root_address_configured
                                        
                                        	ORR Root address configuredfor the neighbor connection
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_route_reflector_client
                                        
                                        	Route\-reflector client
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_send_mcast_attr_enabled
                                        
                                        	Send mcast attribute enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_unlabeled_afi_enabled
                                        
                                        	Update group has unlabeled AFI enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_as
                                        
                                        	Local AS number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_as_replace_as
                                        
                                        	Local AS Replace\-AS option
                                        	**type**\:  bool
                                        
                                        .. attribute:: minimum_advertisement_interval
                                        
                                        	Minimum advertisement interval, secs part
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: minimum_advertisement_interval_msecs
                                        
                                        	Minimum advertisement interval, msecs part
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: neighbor
                                        
                                        	Neighbors in this update group which are not in any sub\-group
                                        	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor>`
                                        
                                        .. attribute:: orr_group_index
                                        
                                        	ORR Group Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: orr_group_name
                                        
                                        	ORR Group Name
                                        	**type**\:  str
                                        
                                        .. attribute:: performance_statistics
                                        
                                        	Performance statistics
                                        	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics>`
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: refresh_subgrp_count
                                        
                                        	Current count of refresh subgroups
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_as
                                        
                                        	Remote AS number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_policy_out
                                        
                                        	Outbound route policy name
                                        	**type**\:  str
                                        
                                        .. attribute:: session_af_name
                                        
                                        	Neighbor session Address family
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: should_remove_private_a_ss
                                        
                                        	Remove private AS numbers
                                        	**type**\:  bool
                                        
                                        .. attribute:: should_remove_private_as_ent_path
                                        
                                        	Remove private AS numbersif the entire path consistsof private ASes
                                        	**type**\:  bool
                                        
                                        .. attribute:: should_send_communities
                                        
                                        	Send communities
                                        	**type**\:  bool
                                        
                                        .. attribute:: should_send_ext_communities
                                        
                                        	Send Extended communities
                                        	**type**\:  bool
                                        
                                        .. attribute:: should_send_gshut_community
                                        
                                        	Send GSHUT community
                                        	**type**\:  bool
                                        
                                        .. attribute:: should_send_stitching_rt
                                        
                                        	Send Stitching RT
                                        	**type**\:  bool
                                        
                                        .. attribute:: soo
                                        
                                        	Site\-of\-origin option
                                        	**type**\:  bool
                                        
                                        .. attribute:: soo_value
                                        
                                        	Site\-of\-origin value
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: split_horizon
                                        
                                        	Split horizon check
                                        	**type**\:  bool
                                        
                                        .. attribute:: subgrp_merge_count
                                        
                                        	Number of times sub\-groups have been merged
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_group_af_name
                                        
                                        	Address family for update group
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: update_group_id
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_sub_group
                                        
                                        	Update sub\-group list
                                        	**type**\: list of    :py:class:`UpdateSubGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup>`
                                        
                                        .. attribute:: updates_formatted
                                        
                                        	Number of updates formatted
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: updates_replicated
                                        
                                        	No. of updates replicated
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: updgrp_cluster_id
                                        
                                        	Cluster ID (populated ifclient\-to\-client reflectionis disabled)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: updgrp_cluster_type
                                        
                                        	Cluster ID type\:undefined/number/Ip address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: use_next_hop_self
                                        
                                        	Next hop self
                                        	**type**\:  bool
                                        
                                        .. attribute:: use_next_hop_unchanged_mpath
                                        
                                        	Next\-hop\-unchanged multipath
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.accepts_legacy_pe_rt_route = None
                                            self.advertise_local_labeled_route_unicast = None
                                            self.advertise_rt_type = None
                                            self.as_override = None
                                            self.desync_count = None
                                            self.disable_def_vrf_imp_advertisement = None
                                            self.disable_native_advertisement = None
                                            self.disable_vrf_re_imp_advertisement = None
                                            self.encapsulation_type = None
                                            self.ext_nh_encoding = None
                                            self.filter_group_id = None
                                            self.gshut_active = None
                                            self.gshut_locpref = None
                                            self.gshut_locpref_set = None
                                            self.gshut_prepends = None
                                            self.has_orf_receive_capability = None
                                            self.is4_byte_as_peer = None
                                            self.is_addpath_capable = None
                                            self.is_adv_capable = None
                                            self.is_adv_perm_net_capable = None
                                            self.is_adv_reorg_capable = None
                                            self.is_aigp_capable = None
                                            self.is_aigp_cost_community_capable = None
                                            self.is_aigp_med_capable = None
                                            self.is_client_reflection_disabled = None
                                            self.is_common_admin_peers = None
                                            self.is_directly_connected_ebgp_v6_peers = None
                                            self.is_internal_peers = None
                                            self.is_labeled_afi_enabled = None
                                            self.is_llgr_capable = None
                                            self.is_orr_root_address_configured = None
                                            self.is_route_reflector_client = None
                                            self.is_send_mcast_attr_enabled = None
                                            self.is_unlabeled_afi_enabled = None
                                            self.local_as = None
                                            self.local_as_replace_as = None
                                            self.minimum_advertisement_interval = None
                                            self.minimum_advertisement_interval_msecs = None
                                            self.neighbor = YList()
                                            self.neighbor.parent = self
                                            self.neighbor.name = 'neighbor'
                                            self.orr_group_index = None
                                            self.orr_group_name = None
                                            self.performance_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics()
                                            self.performance_statistics.parent = self
                                            self.process_instance_id = None
                                            self.refresh_subgrp_count = None
                                            self.remote_as = None
                                            self.route_policy_out = None
                                            self.session_af_name = None
                                            self.should_remove_private_a_ss = None
                                            self.should_remove_private_as_ent_path = None
                                            self.should_send_communities = None
                                            self.should_send_ext_communities = None
                                            self.should_send_gshut_community = None
                                            self.should_send_stitching_rt = None
                                            self.soo = None
                                            self.soo_value = None
                                            self.split_horizon = None
                                            self.subgrp_merge_count = None
                                            self.update_group_af_name = None
                                            self.update_group_id = None
                                            self.update_group_number = None
                                            self.update_sub_group = YList()
                                            self.update_sub_group.parent = self
                                            self.update_sub_group.name = 'update_sub_group'
                                            self.updates_formatted = None
                                            self.updates_replicated = None
                                            self.updgrp_cluster_id = None
                                            self.updgrp_cluster_type = None
                                            self.use_next_hop_self = None
                                            self.use_next_hop_unchanged_mpath = None


                                        class PerformanceStatistics(object):
                                            """
                                            Performance statistics
                                            
                                            .. attribute:: update_generation_be_prefixes_count
                                            
                                            	No. of be prefixes updates generated for
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_calls
                                            
                                            	No. of calls to update generation function
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_messages_count
                                            
                                            	No. of update messages generated
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_prefixes_count
                                            
                                            	No. of prefixes updates generated for
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_time
                                            
                                            	Time spent generating updates (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: updgen_timer_process_time
                                            
                                            	Timestamp when update timer processed for updgrp
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: updgen_timer_start_time
                                            
                                            	Timestamp when update timer started for updgrp
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: updgen_timer_stop_time
                                            
                                            	Timestamp when update timer stopped for updgrp
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.update_generation_be_prefixes_count = None
                                                self.update_generation_calls = None
                                                self.update_generation_messages_count = None
                                                self.update_generation_prefixes_count = None
                                                self.update_generation_time = None
                                                self.updgen_timer_process_time = None
                                                self.updgen_timer_start_time = None
                                                self.updgen_timer_stop_time = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:performance-statistics'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.update_generation_be_prefixes_count is not None:
                                                    return True

                                                if self.update_generation_calls is not None:
                                                    return True

                                                if self.update_generation_messages_count is not None:
                                                    return True

                                                if self.update_generation_prefixes_count is not None:
                                                    return True

                                                if self.update_generation_time is not None:
                                                    return True

                                                if self.updgen_timer_process_time is not None:
                                                    return True

                                                if self.updgen_timer_start_time is not None:
                                                    return True

                                                if self.updgen_timer_stop_time is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics']['meta_info']


                                        class Neighbor(object):
                                            """
                                            Neighbors in this update group which are not in
                                            any sub\-group
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor']['meta_info']


                                        class UpdateSubGroup(object):
                                            """
                                            Update sub\-group list
                                            
                                            .. attribute:: filter_group
                                            
                                            	Update sub\-group fgrp\-num
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: neighbor
                                            
                                            	Neighbors in this subgrp not in any filtergrp
                                            	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor>`
                                            
                                            .. attribute:: update_filter_group
                                            
                                            	Update f\-group list
                                            	**type**\: list of    :py:class:`UpdateFilterGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup>`
                                            
                                            .. attribute:: update_sub_group_number
                                            
                                            	Update sub\-group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: wait_for_eo_rs
                                            
                                            	Wait for  RT Nbr EoRs
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.filter_group = None
                                                self.neighbor = YList()
                                                self.neighbor.parent = self
                                                self.neighbor.name = 'neighbor'
                                                self.update_filter_group = YList()
                                                self.update_filter_group.parent = self
                                                self.update_filter_group.name = 'update_filter_group'
                                                self.update_sub_group_number = None
                                                self.wait_for_eo_rs = None


                                            class UpdateFilterGroup(object):
                                                """
                                                Update f\-group list
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity>`
                                                
                                                .. attribute:: fgroup_advertised_prefixes
                                                
                                                	Number of prefixes advertised to filtergroup in last update walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_created_message_elements
                                                
                                                	Number of message elems created for filtergroup
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_deleted_message_elements
                                                
                                                	Number of message elems deleted
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_flags
                                                
                                                	Flags per filter group
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fgroup_neighbors
                                                
                                                	Nbrs per filter group
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: fgroup_queued_message_elements
                                                
                                                	Number of message elems queued
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_skipped_prefixes
                                                
                                                	Number of prefixes skipped for filtergroup in last update walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_suppressed_prefixes
                                                
                                                	Number of prefixes suppressed for filtergroup in last update walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_total_advertised_prefixes
                                                
                                                	Number of prefixes advertised to filtergroup in all update walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_total_non_optimised_prefixes
                                                
                                                	Number of prefixes  non\-optm from filtergroupin all update walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_total_withdrawn_prefixes
                                                
                                                	Number of prefixes withdrawn f`rom filtergroupin all update walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_withdrawn_prefixes
                                                
                                                	Number of prefixes withdrawn f`rom filtergroupin last update walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_rt_present
                                                
                                                	RT attribute list present
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor
                                                
                                                	Neighbors in this update sub\-group
                                                	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor>`
                                                
                                                .. attribute:: rts
                                                
                                                	RT count per filter group
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: update_filter_group_number
                                                
                                                	Update sub\-group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.fgroup_advertised_prefixes = None
                                                    self.fgroup_created_message_elements = None
                                                    self.fgroup_deleted_message_elements = None
                                                    self.fgroup_flags = None
                                                    self.fgroup_neighbors = None
                                                    self.fgroup_queued_message_elements = None
                                                    self.fgroup_skipped_prefixes = None
                                                    self.fgroup_suppressed_prefixes = None
                                                    self.fgroup_total_advertised_prefixes = None
                                                    self.fgroup_total_non_optimised_prefixes = None
                                                    self.fgroup_total_withdrawn_prefixes = None
                                                    self.fgroup_withdrawn_prefixes = None
                                                    self.is_rt_present = None
                                                    self.neighbor = YList()
                                                    self.neighbor.parent = self
                                                    self.neighbor.name = 'neighbor'
                                                    self.rts = None
                                                    self.update_filter_group_number = None


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity']['meta_info']


                                                class Neighbor(object):
                                                    """
                                                    Neighbors in this update sub\-group
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-filter-group'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.fgroup_advertised_prefixes is not None:
                                                        return True

                                                    if self.fgroup_created_message_elements is not None:
                                                        return True

                                                    if self.fgroup_deleted_message_elements is not None:
                                                        return True

                                                    if self.fgroup_flags is not None:
                                                        return True

                                                    if self.fgroup_neighbors is not None:
                                                        return True

                                                    if self.fgroup_queued_message_elements is not None:
                                                        return True

                                                    if self.fgroup_skipped_prefixes is not None:
                                                        return True

                                                    if self.fgroup_suppressed_prefixes is not None:
                                                        return True

                                                    if self.fgroup_total_advertised_prefixes is not None:
                                                        return True

                                                    if self.fgroup_total_non_optimised_prefixes is not None:
                                                        return True

                                                    if self.fgroup_total_withdrawn_prefixes is not None:
                                                        return True

                                                    if self.fgroup_withdrawn_prefixes is not None:
                                                        return True

                                                    if self.is_rt_present is not None:
                                                        return True

                                                    if self.neighbor is not None:
                                                        for child_ref in self.neighbor:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.rts is not None:
                                                        return True

                                                    if self.update_filter_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup']['meta_info']


                                            class Neighbor(object):
                                                """
                                                Neighbors in this subgrp not in any filtergrp
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-sub-group'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.filter_group is not None:
                                                    return True

                                                if self.neighbor is not None:
                                                    for child_ref in self.neighbor:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.update_filter_group is not None:
                                                    for child_ref in self.update_filter_group:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.update_sub_group_number is not None:
                                                    return True

                                                if self.wait_for_eo_rs is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-group'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.accepts_legacy_pe_rt_route is not None:
                                                return True

                                            if self.advertise_local_labeled_route_unicast is not None:
                                                return True

                                            if self.advertise_rt_type is not None:
                                                return True

                                            if self.as_override is not None:
                                                return True

                                            if self.desync_count is not None:
                                                return True

                                            if self.disable_def_vrf_imp_advertisement is not None:
                                                return True

                                            if self.disable_native_advertisement is not None:
                                                return True

                                            if self.disable_vrf_re_imp_advertisement is not None:
                                                return True

                                            if self.encapsulation_type is not None:
                                                return True

                                            if self.ext_nh_encoding is not None:
                                                return True

                                            if self.filter_group_id is not None:
                                                return True

                                            if self.gshut_active is not None:
                                                return True

                                            if self.gshut_locpref is not None:
                                                return True

                                            if self.gshut_locpref_set is not None:
                                                return True

                                            if self.gshut_prepends is not None:
                                                return True

                                            if self.has_orf_receive_capability is not None:
                                                return True

                                            if self.is4_byte_as_peer is not None:
                                                return True

                                            if self.is_addpath_capable is not None:
                                                return True

                                            if self.is_adv_capable is not None:
                                                return True

                                            if self.is_adv_perm_net_capable is not None:
                                                return True

                                            if self.is_adv_reorg_capable is not None:
                                                return True

                                            if self.is_aigp_capable is not None:
                                                return True

                                            if self.is_aigp_cost_community_capable is not None:
                                                return True

                                            if self.is_aigp_med_capable is not None:
                                                return True

                                            if self.is_client_reflection_disabled is not None:
                                                return True

                                            if self.is_common_admin_peers is not None:
                                                return True

                                            if self.is_directly_connected_ebgp_v6_peers is not None:
                                                return True

                                            if self.is_internal_peers is not None:
                                                return True

                                            if self.is_labeled_afi_enabled is not None:
                                                return True

                                            if self.is_llgr_capable is not None:
                                                return True

                                            if self.is_orr_root_address_configured is not None:
                                                return True

                                            if self.is_route_reflector_client is not None:
                                                return True

                                            if self.is_send_mcast_attr_enabled is not None:
                                                return True

                                            if self.is_unlabeled_afi_enabled is not None:
                                                return True

                                            if self.local_as is not None:
                                                return True

                                            if self.local_as_replace_as is not None:
                                                return True

                                            if self.minimum_advertisement_interval is not None:
                                                return True

                                            if self.minimum_advertisement_interval_msecs is not None:
                                                return True

                                            if self.neighbor is not None:
                                                for child_ref in self.neighbor:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.orr_group_index is not None:
                                                return True

                                            if self.orr_group_name is not None:
                                                return True

                                            if self.performance_statistics is not None and self.performance_statistics._has_data():
                                                return True

                                            if self.process_instance_id is not None:
                                                return True

                                            if self.refresh_subgrp_count is not None:
                                                return True

                                            if self.remote_as is not None:
                                                return True

                                            if self.route_policy_out is not None:
                                                return True

                                            if self.session_af_name is not None:
                                                return True

                                            if self.should_remove_private_a_ss is not None:
                                                return True

                                            if self.should_remove_private_as_ent_path is not None:
                                                return True

                                            if self.should_send_communities is not None:
                                                return True

                                            if self.should_send_ext_communities is not None:
                                                return True

                                            if self.should_send_gshut_community is not None:
                                                return True

                                            if self.should_send_stitching_rt is not None:
                                                return True

                                            if self.soo is not None:
                                                return True

                                            if self.soo_value is not None:
                                                return True

                                            if self.split_horizon is not None:
                                                return True

                                            if self.subgrp_merge_count is not None:
                                                return True

                                            if self.update_group_af_name is not None:
                                                return True

                                            if self.update_group_id is not None:
                                                return True

                                            if self.update_group_number is not None:
                                                return True

                                            if self.update_sub_group is not None:
                                                for child_ref in self.update_sub_group:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.updates_formatted is not None:
                                                return True

                                            if self.updates_replicated is not None:
                                                return True

                                            if self.updgrp_cluster_id is not None:
                                                return True

                                            if self.updgrp_cluster_type is not None:
                                                return True

                                            if self.use_next_hop_self is not None:
                                                return True

                                            if self.use_next_hop_unchanged_mpath is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-groups'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.update_group is not None:
                                            for child_ref in self.update_group:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups']['meta_info']


                                class UpdateGenerationSubGroups(object):
                                    """
                                    Update generation for all sub\-groups
                                    
                                    .. attribute:: update_generation_sub_group
                                    
                                    	Update generation for sub\-group
                                    	**type**\: list of    :py:class:`UpdateGenerationSubGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.update_generation_sub_group = YList()
                                        self.update_generation_sub_group.parent = self
                                        self.update_generation_sub_group.name = 'update_generation_sub_group'


                                    class UpdateGenerationSubGroup(object):
                                        """
                                        Update generation for sub\-group
                                        
                                        .. attribute:: configured_update_limit_sub_group
                                        
                                        	Configured update limit
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: creation_timestamp
                                        
                                        	Creation time
                                        	**type**\:   :py:class:`CreationTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp>`
                                        
                                        .. attribute:: current_update_limit_sub_group
                                        
                                        	Current update limit
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: eo_r_attempted
                                        
                                        	Sending EoR has been attempted
                                        	**type**\:  bool
                                        
                                        .. attribute:: filter_group_count
                                        
                                        	Filter\-group count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: first_update_walk_end_timestamp
                                        
                                        	First update walk end time
                                        	**type**\:   :py:class:`FirstUpdateWalkEndTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp>`
                                        
                                        .. attribute:: first_update_walk_start_timestamp
                                        
                                        	First update walk start time
                                        	**type**\:   :py:class:`FirstUpdateWalkStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp>`
                                        
                                        .. attribute:: io_write_event_pending
                                        
                                        	Is IO write event pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: last_merge_timestamp
                                        
                                        	Last merge time
                                        	**type**\:   :py:class:`LastMergeTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp>`
                                        
                                        .. attribute:: last_merged_sub_group_index
                                        
                                        	Last merged sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_queued_age
                                        
                                        	Time since last update queued event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_queued_timestamp
                                        
                                        	Last update queued time
                                        	**type**\:   :py:class:`LastUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp>`
                                        
                                        .. attribute:: last_update_walk_end_age
                                        
                                        	Time since last update walk end event
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_walk_end_timestamp
                                        
                                        	Last update walk end time
                                        	**type**\:   :py:class:`LastUpdateWalkEndTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp>`
                                        
                                        .. attribute:: last_update_walk_start_timestamp
                                        
                                        	Last update walk start time
                                        	**type**\:   :py:class:`LastUpdateWalkStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp>`
                                        
                                        .. attribute:: merge_count
                                        
                                        	Merge count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_count
                                        
                                        	Neighbor count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: next_resume_version
                                        
                                        	Next resume version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nsr_version
                                        
                                        	NSR version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: parent_sub_group_id
                                        
                                        	Parent Sub\-group identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: parent_sub_group_index
                                        
                                        	Parent Sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pending_target_version
                                        
                                        	Pending target version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_id
                                        
                                        	ProcessID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_sub_group_count
                                        
                                        	Refresh sub\-group count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_id
                                        
                                        	Sub\-group ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: sub_group_id_xr
                                        
                                        	Sub\-group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_index
                                        
                                        	Sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: sub_group_index_xr
                                        
                                        	Sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_default_route_sent
                                        
                                        	Is default route sent
                                        	**type**\:  bool
                                        
                                        .. attribute:: update_group_af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: update_group_index
                                        
                                        	Update\-group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: update_group_index_xr
                                        
                                        	Update\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_main_table_version
                                        
                                        	Main table version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages
                                        
                                        	OutQueue messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size
                                        
                                        	OutQueue size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_refresh_target_version
                                        
                                        	Refresh target version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_statistics
                                        
                                        	Update statistics
                                        	**type**\:   :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics>`
                                        
                                        .. attribute:: update_throttled
                                        
                                        	Is update throttled
                                        	**type**\:  bool
                                        
                                        .. attribute:: update_vrf_name
                                        
                                        	VRF Name
                                        	**type**\:  str
                                        
                                        .. attribute:: update_vrf_table_rib_version
                                        
                                        	VRF Table RIB version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version
                                        
                                        	Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.configured_update_limit_sub_group = None
                                            self.creation_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp()
                                            self.creation_timestamp.parent = self
                                            self.current_update_limit_sub_group = None
                                            self.eo_r_attempted = None
                                            self.filter_group_count = None
                                            self.first_update_walk_end_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp()
                                            self.first_update_walk_end_timestamp.parent = self
                                            self.first_update_walk_start_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp()
                                            self.first_update_walk_start_timestamp.parent = self
                                            self.io_write_event_pending = None
                                            self.last_merge_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp()
                                            self.last_merge_timestamp.parent = self
                                            self.last_merged_sub_group_index = None
                                            self.last_update_queued_age = None
                                            self.last_update_queued_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp()
                                            self.last_update_queued_timestamp.parent = self
                                            self.last_update_walk_end_age = None
                                            self.last_update_walk_end_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp()
                                            self.last_update_walk_end_timestamp.parent = self
                                            self.last_update_walk_start_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp()
                                            self.last_update_walk_start_timestamp.parent = self
                                            self.merge_count = None
                                            self.neighbor_count = None
                                            self.next_resume_version = None
                                            self.nsr_version = None
                                            self.parent_sub_group_id = None
                                            self.parent_sub_group_index = None
                                            self.pending_target_version = None
                                            self.process_id = None
                                            self.refresh_sub_group_count = None
                                            self.sub_group_id = None
                                            self.sub_group_id_xr = None
                                            self.sub_group_index = None
                                            self.sub_group_index_xr = None
                                            self.update_default_route_sent = None
                                            self.update_group_af_name = None
                                            self.update_group_index = None
                                            self.update_group_index_xr = None
                                            self.update_main_table_version = None
                                            self.update_out_queue_messages = None
                                            self.update_out_queue_size = None
                                            self.update_refresh_target_version = None
                                            self.update_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics()
                                            self.update_statistics.parent = self
                                            self.update_throttled = None
                                            self.update_vrf_name = None
                                            self.update_vrf_table_rib_version = None
                                            self.version = None


                                        class CreationTimestamp(object):
                                            """
                                            Creation time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:creation-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp']['meta_info']


                                        class LastMergeTimestamp(object):
                                            """
                                            Last merge time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-merge-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp']['meta_info']


                                        class FirstUpdateWalkStartTimestamp(object):
                                            """
                                            First update walk start time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-update-walk-start-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp']['meta_info']


                                        class FirstUpdateWalkEndTimestamp(object):
                                            """
                                            First update walk end time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-update-walk-end-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp']['meta_info']


                                        class LastUpdateWalkStartTimestamp(object):
                                            """
                                            Last update walk start time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-walk-start-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp']['meta_info']


                                        class LastUpdateWalkEndTimestamp(object):
                                            """
                                            Last update walk end time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-walk-end-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp']['meta_info']


                                        class LastUpdateQueuedTimestamp(object):
                                            """
                                            Last update queued time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-queued-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp']['meta_info']


                                        class UpdateStatistics(object):
                                            """
                                            Update statistics
                                            
                                            .. attribute:: last_update_cleard_age
                                            
                                            	Time since last Clear event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_cleared_timestamp
                                            
                                            	Last Cleared time
                                            	**type**\:   :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp>`
                                            
                                            .. attribute:: last_update_discard_age
                                            
                                            	Time since last Discard event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_discard_timestamp
                                            
                                            	Last Discarded time
                                            	**type**\:   :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                            
                                            .. attribute:: last_update_memory_allocation_fail_age
                                            
                                            	Time since last memory allocation failure event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_memory_allocation_fail_timestamp
                                            
                                            	Memory allocation failure time
                                            	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                            
                                            .. attribute:: last_update_recovery_age
                                            
                                            	Time since last Recovery event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_recovery_timestamp
                                            
                                            	Last Recovery time
                                            	**type**\:   :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                            
                                            .. attribute:: last_update_throttle_age
                                            
                                            	Time since last Throttle event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_throttle_timestamp
                                            
                                            	Last Throttled time
                                            	**type**\:   :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                            
                                            .. attribute:: update_memory_allocation_fail_count
                                            
                                            	Memory allocation failure count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_cleared
                                            
                                            	OutQueue Cleared Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_cumulative
                                            
                                            	OutQueue Cumulative Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_discarded
                                            
                                            	OutQueue Discarded Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_high
                                            
                                            	OutQueue High Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_size_cleared
                                            
                                            	OutQueue Cleared Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_cumulative
                                            
                                            	OutQueue Cumulative Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_discarded
                                            
                                            	OutQueue Discarded Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_high
                                            
                                            	OutQueue Hi Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_recovery_count
                                            
                                            	Recovery Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_throttle_count
                                            
                                            	Throttle Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.last_update_cleard_age = None
                                                self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp()
                                                self.last_update_cleared_timestamp.parent = self
                                                self.last_update_discard_age = None
                                                self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp()
                                                self.last_update_discard_timestamp.parent = self
                                                self.last_update_memory_allocation_fail_age = None
                                                self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                                self.last_update_memory_allocation_fail_timestamp.parent = self
                                                self.last_update_recovery_age = None
                                                self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                                self.last_update_recovery_timestamp.parent = self
                                                self.last_update_throttle_age = None
                                                self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp()
                                                self.last_update_throttle_timestamp.parent = self
                                                self.update_memory_allocation_fail_count = None
                                                self.update_out_queue_messages_cleared = None
                                                self.update_out_queue_messages_cumulative = None
                                                self.update_out_queue_messages_discarded = None
                                                self.update_out_queue_messages_high = None
                                                self.update_out_queue_size_cleared = None
                                                self.update_out_queue_size_cumulative = None
                                                self.update_out_queue_size_discarded = None
                                                self.update_out_queue_size_high = None
                                                self.update_recovery_count = None
                                                self.update_throttle_count = None


                                            class LastUpdateDiscardTimestamp(object):
                                                """
                                                Last Discarded time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-discard-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp']['meta_info']


                                            class LastUpdateClearedTimestamp(object):
                                                """
                                                Last Cleared time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-cleared-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp']['meta_info']


                                            class LastUpdateThrottleTimestamp(object):
                                                """
                                                Last Throttled time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-throttle-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp']['meta_info']


                                            class LastUpdateRecoveryTimestamp(object):
                                                """
                                                Last Recovery time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-recovery-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp']['meta_info']


                                            class LastUpdateMemoryAllocationFailTimestamp(object):
                                                """
                                                Memory allocation failure time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-memory-allocation-fail-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-statistics'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.last_update_cleard_age is not None:
                                                    return True

                                                if self.last_update_cleared_timestamp is not None and self.last_update_cleared_timestamp._has_data():
                                                    return True

                                                if self.last_update_discard_age is not None:
                                                    return True

                                                if self.last_update_discard_timestamp is not None and self.last_update_discard_timestamp._has_data():
                                                    return True

                                                if self.last_update_memory_allocation_fail_age is not None:
                                                    return True

                                                if self.last_update_memory_allocation_fail_timestamp is not None and self.last_update_memory_allocation_fail_timestamp._has_data():
                                                    return True

                                                if self.last_update_recovery_age is not None:
                                                    return True

                                                if self.last_update_recovery_timestamp is not None and self.last_update_recovery_timestamp._has_data():
                                                    return True

                                                if self.last_update_throttle_age is not None:
                                                    return True

                                                if self.last_update_throttle_timestamp is not None and self.last_update_throttle_timestamp._has_data():
                                                    return True

                                                if self.update_memory_allocation_fail_count is not None:
                                                    return True

                                                if self.update_out_queue_messages_cleared is not None:
                                                    return True

                                                if self.update_out_queue_messages_cumulative is not None:
                                                    return True

                                                if self.update_out_queue_messages_discarded is not None:
                                                    return True

                                                if self.update_out_queue_messages_high is not None:
                                                    return True

                                                if self.update_out_queue_size_cleared is not None:
                                                    return True

                                                if self.update_out_queue_size_cumulative is not None:
                                                    return True

                                                if self.update_out_queue_size_discarded is not None:
                                                    return True

                                                if self.update_out_queue_size_high is not None:
                                                    return True

                                                if self.update_recovery_count is not None:
                                                    return True

                                                if self.update_throttle_count is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-sub-group'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.configured_update_limit_sub_group is not None:
                                                return True

                                            if self.creation_timestamp is not None and self.creation_timestamp._has_data():
                                                return True

                                            if self.current_update_limit_sub_group is not None:
                                                return True

                                            if self.eo_r_attempted is not None:
                                                return True

                                            if self.filter_group_count is not None:
                                                return True

                                            if self.first_update_walk_end_timestamp is not None and self.first_update_walk_end_timestamp._has_data():
                                                return True

                                            if self.first_update_walk_start_timestamp is not None and self.first_update_walk_start_timestamp._has_data():
                                                return True

                                            if self.io_write_event_pending is not None:
                                                return True

                                            if self.last_merge_timestamp is not None and self.last_merge_timestamp._has_data():
                                                return True

                                            if self.last_merged_sub_group_index is not None:
                                                return True

                                            if self.last_update_queued_age is not None:
                                                return True

                                            if self.last_update_queued_timestamp is not None and self.last_update_queued_timestamp._has_data():
                                                return True

                                            if self.last_update_walk_end_age is not None:
                                                return True

                                            if self.last_update_walk_end_timestamp is not None and self.last_update_walk_end_timestamp._has_data():
                                                return True

                                            if self.last_update_walk_start_timestamp is not None and self.last_update_walk_start_timestamp._has_data():
                                                return True

                                            if self.merge_count is not None:
                                                return True

                                            if self.neighbor_count is not None:
                                                return True

                                            if self.next_resume_version is not None:
                                                return True

                                            if self.nsr_version is not None:
                                                return True

                                            if self.parent_sub_group_id is not None:
                                                return True

                                            if self.parent_sub_group_index is not None:
                                                return True

                                            if self.pending_target_version is not None:
                                                return True

                                            if self.process_id is not None:
                                                return True

                                            if self.refresh_sub_group_count is not None:
                                                return True

                                            if self.sub_group_id is not None:
                                                return True

                                            if self.sub_group_id_xr is not None:
                                                return True

                                            if self.sub_group_index is not None:
                                                return True

                                            if self.sub_group_index_xr is not None:
                                                return True

                                            if self.update_default_route_sent is not None:
                                                return True

                                            if self.update_group_af_name is not None:
                                                return True

                                            if self.update_group_index is not None:
                                                return True

                                            if self.update_group_index_xr is not None:
                                                return True

                                            if self.update_main_table_version is not None:
                                                return True

                                            if self.update_out_queue_messages is not None:
                                                return True

                                            if self.update_out_queue_size is not None:
                                                return True

                                            if self.update_refresh_target_version is not None:
                                                return True

                                            if self.update_statistics is not None and self.update_statistics._has_data():
                                                return True

                                            if self.update_throttled is not None:
                                                return True

                                            if self.update_vrf_name is not None:
                                                return True

                                            if self.update_vrf_table_rib_version is not None:
                                                return True

                                            if self.version is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-sub-groups'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.update_generation_sub_group is not None:
                                            for child_ref in self.update_generation_sub_group:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups']['meta_info']


                                class NextHopAddressFamilies(object):
                                    """
                                    Address family of nexthop table
                                    
                                    .. attribute:: next_hop_address_family
                                    
                                    	Nexthop Address family
                                    	**type**\: list of    :py:class:`NextHopAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.next_hop_address_family = YList()
                                        self.next_hop_address_family.parent = self
                                        self.next_hop_address_family.name = 'next_hop_address_family'


                                    class NextHopAddressFamily(object):
                                        """
                                        Nexthop Address family
                                        
                                        .. attribute:: next_hop_af_name  <key>
                                        
                                        	Address family
                                        	**type**\:   :py:class:`BgpAddressFamilyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamilyEnum>`
                                        
                                        .. attribute:: next_hop_af_vrf_af
                                        
                                        	A BGP Next\-hop VRF AF table entry
                                        	**type**\:   :py:class:`NextHopAfVrfAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf>`
                                        
                                        .. attribute:: next_hop_afs
                                        
                                        	The BGP Next\-hop table
                                        	**type**\:   :py:class:`NextHopAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.next_hop_af_name = None
                                            self.next_hop_af_vrf_af = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf()
                                            self.next_hop_af_vrf_af.parent = self
                                            self.next_hop_afs = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs()
                                            self.next_hop_afs.parent = self


                                        class NextHopAfVrfAf(object):
                                            """
                                            A BGP Next\-hop VRF AF table entry
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: critical_trigger_delay
                                            
                                            	Trigger delay for critical event processing
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: epe_downloaded_version
                                            
                                            	Version of the EPE table downloaded
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: epe_label_version
                                            
                                            	Version of the EPE label walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: epe_standby_version
                                            
                                            	Version of the EPE table processed by sync thread
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: epe_table_version
                                            
                                            	Version of the EPE table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: gwaf_name
                                            
                                            	GW Address family identifier
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: nh_nexthop_version
                                            
                                            	NH version for gw\_ctx
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_rib_up
                                            
                                            	Whether the VRF is active
                                            	**type**\:  bool
                                            
                                            .. attribute:: nh_rib_version
                                            
                                            	RIB version for gw\_ctx
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_table_id
                                            
                                            	Gateway context table id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: non_critical_trigger_delay
                                            
                                            	Trigger delay for non\-critical event processing
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: performance_statistics
                                            
                                            	Performance statistics
                                            	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics>`
                                            
                                            .. attribute:: table_active
                                            
                                            	Whether the VRF is active
                                            	**type**\:  bool
                                            
                                            .. attribute:: total_nexthops
                                            
                                            	Total number of nexthops
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.af_name = None
                                                self.critical_trigger_delay = None
                                                self.epe_downloaded_version = None
                                                self.epe_label_version = None
                                                self.epe_standby_version = None
                                                self.epe_table_version = None
                                                self.gwaf_name = None
                                                self.nh_nexthop_version = None
                                                self.nh_rib_up = None
                                                self.nh_rib_version = None
                                                self.nh_table_id = None
                                                self.non_critical_trigger_delay = None
                                                self.performance_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics()
                                                self.performance_statistics.parent = self
                                                self.table_active = None
                                                self.total_nexthops = None


                                            class PerformanceStatistics(object):
                                                """
                                                Performance statistics
                                                
                                                .. attribute:: critical_notf_count
                                                
                                                	Number of critical event notifications from RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_notf_bestpath_changes
                                                
                                                	Number of bestpath changes due to last notification
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_notf_bestpath_deletes
                                                
                                                	Number of bestpath deletes due to last notification
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthops_removed_from_rib
                                                
                                                	No. of nexthops withdrawn from RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthops_resent_to_rib
                                                
                                                	No. of nexthops re\-sent to RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthops_sent_to_rib
                                                
                                                	No. of nexthops sent to RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_batch_finish_calls
                                                
                                                	NH batch finish calls
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_flush_timer_calls
                                                
                                                	NH flush timer calls
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_last_a_sync_reg_ts
                                                
                                                	NH Last async Register TS
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_last_a_sync_un_reg_ts
                                                
                                                	NH Last async UnRegister TS
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_last_batch_finish_ts
                                                
                                                	NH Last batch finish TS
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_last_flush_timer_ts
                                                
                                                	NH Last flush timer TS
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_last_sync_reg_ts
                                                
                                                	NH Last sync Register TS
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_peak_registrations
                                                
                                                	NH Registration List Count Peak
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_pending_registrations
                                                
                                                	NH Registration List Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_sync_reg_calls
                                                
                                                	NH sync register calls
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nha_sync_reg_calls
                                                
                                                	NH async register calls
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nha_sync_un_reg_calls
                                                
                                                	NH async unregister calls
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nhrib_update_calls
                                                
                                                	No. of calls to RIB update function
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nhrib_update_time
                                                
                                                	Time spent sending RIB updates (milliseconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: millisecond
                                                
                                                .. attribute:: noncritical_notf_count
                                                
                                                	Number of non\-critical event notifications from RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_sync_registers_failed
                                                
                                                	No. of sync registers with RIB that failed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: riba_sync_registers_failed
                                                
                                                	No. of async registers with RIB that failed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribnh_reg_failed_for_no_rib_conn
                                                
                                                	No. of nh registers failed because of no rib conn
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribnh_reg_failed_for_no_tbl_id
                                                
                                                	No. of nh registers failed because of no tbl\-id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_walk_backup_creates
                                                
                                                	No. of times backup tid created during tunnel walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_walk_gw_not_found
                                                
                                                	No. of times gw was not found during tunnel walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_walk_nh_not_found
                                                
                                                	No. of times nexthop was not found during tunnel walk
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.critical_notf_count = None
                                                    self.last_notf_bestpath_changes = None
                                                    self.last_notf_bestpath_deletes = None
                                                    self.nexthops_removed_from_rib = None
                                                    self.nexthops_resent_to_rib = None
                                                    self.nexthops_sent_to_rib = None
                                                    self.nh_batch_finish_calls = None
                                                    self.nh_flush_timer_calls = None
                                                    self.nh_last_a_sync_reg_ts = None
                                                    self.nh_last_a_sync_un_reg_ts = None
                                                    self.nh_last_batch_finish_ts = None
                                                    self.nh_last_flush_timer_ts = None
                                                    self.nh_last_sync_reg_ts = None
                                                    self.nh_peak_registrations = None
                                                    self.nh_pending_registrations = None
                                                    self.nh_sync_reg_calls = None
                                                    self.nha_sync_reg_calls = None
                                                    self.nha_sync_un_reg_calls = None
                                                    self.nhrib_update_calls = None
                                                    self.nhrib_update_time = None
                                                    self.noncritical_notf_count = None
                                                    self.rib_sync_registers_failed = None
                                                    self.riba_sync_registers_failed = None
                                                    self.ribnh_reg_failed_for_no_rib_conn = None
                                                    self.ribnh_reg_failed_for_no_tbl_id = None
                                                    self.tunnel_walk_backup_creates = None
                                                    self.tunnel_walk_gw_not_found = None
                                                    self.tunnel_walk_nh_not_found = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:performance-statistics'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.critical_notf_count is not None:
                                                        return True

                                                    if self.last_notf_bestpath_changes is not None:
                                                        return True

                                                    if self.last_notf_bestpath_deletes is not None:
                                                        return True

                                                    if self.nexthops_removed_from_rib is not None:
                                                        return True

                                                    if self.nexthops_resent_to_rib is not None:
                                                        return True

                                                    if self.nexthops_sent_to_rib is not None:
                                                        return True

                                                    if self.nh_batch_finish_calls is not None:
                                                        return True

                                                    if self.nh_flush_timer_calls is not None:
                                                        return True

                                                    if self.nh_last_a_sync_reg_ts is not None:
                                                        return True

                                                    if self.nh_last_a_sync_un_reg_ts is not None:
                                                        return True

                                                    if self.nh_last_batch_finish_ts is not None:
                                                        return True

                                                    if self.nh_last_flush_timer_ts is not None:
                                                        return True

                                                    if self.nh_last_sync_reg_ts is not None:
                                                        return True

                                                    if self.nh_peak_registrations is not None:
                                                        return True

                                                    if self.nh_pending_registrations is not None:
                                                        return True

                                                    if self.nh_sync_reg_calls is not None:
                                                        return True

                                                    if self.nha_sync_reg_calls is not None:
                                                        return True

                                                    if self.nha_sync_un_reg_calls is not None:
                                                        return True

                                                    if self.nhrib_update_calls is not None:
                                                        return True

                                                    if self.nhrib_update_time is not None:
                                                        return True

                                                    if self.noncritical_notf_count is not None:
                                                        return True

                                                    if self.rib_sync_registers_failed is not None:
                                                        return True

                                                    if self.riba_sync_registers_failed is not None:
                                                        return True

                                                    if self.ribnh_reg_failed_for_no_rib_conn is not None:
                                                        return True

                                                    if self.ribnh_reg_failed_for_no_tbl_id is not None:
                                                        return True

                                                    if self.tunnel_walk_backup_creates is not None:
                                                        return True

                                                    if self.tunnel_walk_gw_not_found is not None:
                                                        return True

                                                    if self.tunnel_walk_nh_not_found is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop-af-vrf-af'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.af_name is not None:
                                                    return True

                                                if self.critical_trigger_delay is not None:
                                                    return True

                                                if self.epe_downloaded_version is not None:
                                                    return True

                                                if self.epe_label_version is not None:
                                                    return True

                                                if self.epe_standby_version is not None:
                                                    return True

                                                if self.epe_table_version is not None:
                                                    return True

                                                if self.gwaf_name is not None:
                                                    return True

                                                if self.nh_nexthop_version is not None:
                                                    return True

                                                if self.nh_rib_up is not None:
                                                    return True

                                                if self.nh_rib_version is not None:
                                                    return True

                                                if self.nh_table_id is not None:
                                                    return True

                                                if self.non_critical_trigger_delay is not None:
                                                    return True

                                                if self.performance_statistics is not None and self.performance_statistics._has_data():
                                                    return True

                                                if self.table_active is not None:
                                                    return True

                                                if self.total_nexthops is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf']['meta_info']


                                        class NextHopAfs(object):
                                            """
                                            The BGP Next\-hop table
                                            
                                            .. attribute:: next_hop_af
                                            
                                            	A BGP Next hop entry
                                            	**type**\: list of    :py:class:`NextHopAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.next_hop_af = YList()
                                                self.next_hop_af.parent = self
                                                self.next_hop_af.name = 'next_hop_af'


                                            class NextHopAf(object):
                                                """
                                                A BGP Next hop entry
                                                
                                                .. attribute:: af_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: attribute_set
                                                
                                                	Attribute Set Name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address List
                                                	**type**\: list of    :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress>`
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: nexthop_address
                                                
                                                	Nexthop address
                                                	**type**\:   :py:class:`NexthopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress>`
                                                
                                                .. attribute:: nexthop_aigp_metric
                                                
                                                	AIGP metrice of nexthop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_gateway_info
                                                
                                                	Gateway related info, includingOptimal Route Reflector Gateways
                                                	**type**\: list of    :py:class:`NexthopGatewayInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo>`
                                                
                                                .. attribute:: nexthop_gateway_prefix_connected
                                                
                                                	Is Gateway resolved through Connected route ?
                                                	**type**\:  bool
                                                
                                                .. attribute:: nexthop_gateway_prefix_length
                                                
                                                	Gateway prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_gateway_reachable
                                                
                                                	Is Gateway reachable ?
                                                	**type**\:  bool
                                                
                                                .. attribute:: nexthop_internal_info
                                                
                                                	Internal nexthop info
                                                	**type**\:   :py:class:`NexthopInternalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo>`
                                                
                                                .. attribute:: nexthop_pending_registration
                                                
                                                	Nexthop registration is pending
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nexthop_reference_count
                                                
                                                	Number of neighbors/prefixes referencing this nexthop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_first_hop_if_handle
                                                
                                                	First\-hop interface handle
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                                
                                                .. attribute:: nh_reference_count_total
                                                
                                                	Number of neighbors/prefixes referencing this nexthop (AFs)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nhte_tunnel
                                                
                                                	NH TE tunnel information
                                                	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhteTunnel>`
                                                
                                                .. attribute:: rib_nexthop_id
                                                
                                                	RIB Nexthop Id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.af_name = None
                                                    self.attribute_set = None
                                                    self.neighbor_address = YList()
                                                    self.neighbor_address.parent = self
                                                    self.neighbor_address.name = 'neighbor_address'
                                                    self.next_hop_address = None
                                                    self.nexthop_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress()
                                                    self.nexthop_address.parent = self
                                                    self.nexthop_aigp_metric = None
                                                    self.nexthop_gateway_info = YList()
                                                    self.nexthop_gateway_info.parent = self
                                                    self.nexthop_gateway_info.name = 'nexthop_gateway_info'
                                                    self.nexthop_gateway_prefix_connected = None
                                                    self.nexthop_gateway_prefix_length = None
                                                    self.nexthop_gateway_reachable = None
                                                    self.nexthop_internal_info = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo()
                                                    self.nexthop_internal_info.parent = self
                                                    self.nexthop_pending_registration = None
                                                    self.nexthop_reference_count = None
                                                    self.nh_first_hop_if_handle = None
                                                    self.nh_reference_count_total = None
                                                    self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhteTunnel()
                                                    self.nhte_tunnel.parent = self
                                                    self.rib_nexthop_id = None


                                                class NexthopAddress(object):
                                                    """
                                                    Nexthop address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress']['meta_info']


                                                class NhteTunnel(object):
                                                    """
                                                    NH TE tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_te_tunnel
                                                    
                                                    	NH TE Tunnel info is present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last rib update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	tunnel name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	tunnel type
                                                    	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.binding_label = None
                                                        self.has_te_tunnel = None
                                                        self.is_tunnel_info_stale = None
                                                        self.is_tunnel_registered = None
                                                        self.is_tunnel_up = None
                                                        self.last_tunnel_update = None
                                                        self.tunnel_if_handle = None
                                                        self.tunnel_name = None
                                                        self.tunnel_type = None
                                                        self.tunnel_v6_enabled = None
                                                        self.tunnel_v6_required = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.binding_label is not None:
                                                            return True

                                                        if self.has_te_tunnel is not None:
                                                            return True

                                                        if self.is_tunnel_info_stale is not None:
                                                            return True

                                                        if self.is_tunnel_registered is not None:
                                                            return True

                                                        if self.is_tunnel_up is not None:
                                                            return True

                                                        if self.last_tunnel_update is not None:
                                                            return True

                                                        if self.tunnel_if_handle is not None:
                                                            return True

                                                        if self.tunnel_name is not None:
                                                            return True

                                                        if self.tunnel_type is not None:
                                                            return True

                                                        if self.tunnel_v6_enabled is not None:
                                                            return True

                                                        if self.tunnel_v6_required is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhteTunnel']['meta_info']


                                                class NexthopInternalInfo(object):
                                                    """
                                                    Internal nexthop info
                                                    
                                                    .. attribute:: gateway_flags
                                                    
                                                    	Gateway flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_address
                                                    
                                                    	Nexthop address
                                                    	**type**\:   :py:class:`NexthopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress>`
                                                    
                                                    .. attribute:: nexthop_af_user_bits
                                                    
                                                    	Bitmask indicating the AFs which share the nexthop
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_flags
                                                    
                                                    	Nexthop flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_gateway_internal_info
                                                    
                                                    	Internal nexthop Gateway info
                                                    	**type**\: list of    :py:class:`NexthopGatewayInternalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo>`
                                                    
                                                    .. attribute:: nexthop_id
                                                    
                                                    	Comm librray ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_if_handle
                                                    
                                                    	Nexthop ifhandle
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_label
                                                    
                                                    	Nexthop label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_metrice
                                                    
                                                    	Nexthop metrices
                                                    	**type**\: list of    :py:class:`NexthopMetrice <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice>`
                                                    
                                                    .. attribute:: nexthop_refcount
                                                    
                                                    	Nexthop refcounts
                                                    	**type**\: list of    :py:class:`NexthopRefcount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount>`
                                                    
                                                    .. attribute:: nexthop_version
                                                    
                                                    	Table version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.gateway_flags = None
                                                        self.nexthop_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress()
                                                        self.nexthop_address.parent = self
                                                        self.nexthop_af_user_bits = None
                                                        self.nexthop_flags = None
                                                        self.nexthop_gateway_internal_info = YList()
                                                        self.nexthop_gateway_internal_info.parent = self
                                                        self.nexthop_gateway_internal_info.name = 'nexthop_gateway_internal_info'
                                                        self.nexthop_id = None
                                                        self.nexthop_if_handle = None
                                                        self.nexthop_label = None
                                                        self.nexthop_metrice = YList()
                                                        self.nexthop_metrice.parent = self
                                                        self.nexthop_metrice.name = 'nexthop_metrice'
                                                        self.nexthop_refcount = YList()
                                                        self.nexthop_refcount.parent = self
                                                        self.nexthop_refcount.name = 'nexthop_refcount'
                                                        self.nexthop_version = None


                                                    class NexthopAddress(object):
                                                        """
                                                        Nexthop address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress']['meta_info']


                                                    class NexthopMetrice(object):
                                                        """
                                                        Nexthop metrices
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-metrice'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice']['meta_info']


                                                    class NexthopRefcount(object):
                                                        """
                                                        Nexthop refcounts
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-refcount'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount']['meta_info']


                                                    class NexthopGatewayInternalInfo(object):
                                                        """
                                                        Internal nexthop Gateway info
                                                        
                                                        .. attribute:: gateway_flags
                                                        
                                                        	Gateway flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: registration_since
                                                        
                                                        	Time since registration
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: registration_type
                                                        
                                                        	Nexthop registration type
                                                        	**type**\:   :py:class:`BgpNhValidateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpNhValidateEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.gateway_flags = None
                                                            self.registration_since = None
                                                            self.registration_type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-gateway-internal-info'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.gateway_flags is not None:
                                                                return True

                                                            if self.registration_since is not None:
                                                                return True

                                                            if self.registration_type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-internal-info'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.gateway_flags is not None:
                                                            return True

                                                        if self.nexthop_address is not None and self.nexthop_address._has_data():
                                                            return True

                                                        if self.nexthop_af_user_bits is not None:
                                                            return True

                                                        if self.nexthop_flags is not None:
                                                            return True

                                                        if self.nexthop_gateway_internal_info is not None:
                                                            for child_ref in self.nexthop_gateway_internal_info:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.nexthop_id is not None:
                                                            return True

                                                        if self.nexthop_if_handle is not None:
                                                            return True

                                                        if self.nexthop_label is not None:
                                                            return True

                                                        if self.nexthop_metrice is not None:
                                                            for child_ref in self.nexthop_metrice:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.nexthop_refcount is not None:
                                                            for child_ref in self.nexthop_refcount:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.nexthop_version is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo']['meta_info']


                                                class NexthopGatewayInfo(object):
                                                    """
                                                    Gateway related info, includingOptimal Route
                                                    Reflector Gateways
                                                    
                                                    .. attribute:: critical_events
                                                    
                                                    	Number of critical events received from RIB
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_event_since
                                                    
                                                    	Time since the last event sent to or received from RIB
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_event_type
                                                    
                                                    	Last nexthop event type
                                                    	**type**\:   :py:class:`BgpNhEventEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpNhEventEnum>`
                                                    
                                                    .. attribute:: last_rib_update
                                                    
                                                    	Time since the last rib update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_update_type
                                                    
                                                    	Last nexthop update type
                                                    	**type**\:   :py:class:`BgpNhUpdateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpNhUpdateEnum>`
                                                    
                                                    .. attribute:: nexthop_af_invalid_bits
                                                    
                                                    	Bitmask indicating the AFs which have been invalidated for the nexthop
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: nexthop_metric
                                                    
                                                    	IGP metric for nexthop
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_mpls_enabled
                                                    
                                                    	TRUE if MPLS is configured for IAS/CsC application
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: nexthop_mpls_interfaces
                                                    
                                                    	Number of interfaces on which MPLS is enabled
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_mpls_label
                                                    
                                                    	Local label allocated for IAS/CsC application
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_route
                                                    
                                                    	Route resolving the nethop
                                                    	**type**\:   :py:class:`NexthopRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute>`
                                                    
                                                    .. attribute:: nexthop_route_path
                                                    
                                                    	Nexthops of the resolving route
                                                    	**type**\: list of    :py:class:`NexthopRoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath>`
                                                    
                                                    .. attribute:: nexthop_route_path_count
                                                    
                                                    	Number of paths in the resolving route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_route_prefix_length
                                                    
                                                    	Prefix length of the route resolving the nexthop
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nexthop_route_protocol
                                                    
                                                    	Protocol that resolves the route to the nexthop
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: nexthop_status
                                                    
                                                    	Nexthop status
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nexthop_tableid
                                                    
                                                    	Nexthop Table id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: non_critical_events
                                                    
                                                    	Number of non\-critical events received from RIB
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.critical_events = None
                                                        self.last_event_since = None
                                                        self.last_event_type = None
                                                        self.last_rib_update = None
                                                        self.last_update_type = None
                                                        self.nexthop_af_invalid_bits = None
                                                        self.nexthop_metric = None
                                                        self.nexthop_mpls_enabled = None
                                                        self.nexthop_mpls_interfaces = None
                                                        self.nexthop_mpls_label = None
                                                        self.nexthop_route = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute()
                                                        self.nexthop_route.parent = self
                                                        self.nexthop_route_path = YList()
                                                        self.nexthop_route_path.parent = self
                                                        self.nexthop_route_path.name = 'nexthop_route_path'
                                                        self.nexthop_route_path_count = None
                                                        self.nexthop_route_prefix_length = None
                                                        self.nexthop_route_protocol = None
                                                        self.nexthop_status = None
                                                        self.nexthop_tableid = None
                                                        self.non_critical_events = None


                                                    class NexthopRoute(object):
                                                        """
                                                        Route resolving the nethop
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-route'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute']['meta_info']


                                                    class NexthopRoutePath(object):
                                                        """
                                                        Nexthops of the resolving route
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-route-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-gateway-info'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.critical_events is not None:
                                                            return True

                                                        if self.last_event_since is not None:
                                                            return True

                                                        if self.last_event_type is not None:
                                                            return True

                                                        if self.last_rib_update is not None:
                                                            return True

                                                        if self.last_update_type is not None:
                                                            return True

                                                        if self.nexthop_af_invalid_bits is not None:
                                                            return True

                                                        if self.nexthop_metric is not None:
                                                            return True

                                                        if self.nexthop_mpls_enabled is not None:
                                                            return True

                                                        if self.nexthop_mpls_interfaces is not None:
                                                            return True

                                                        if self.nexthop_mpls_label is not None:
                                                            return True

                                                        if self.nexthop_route is not None and self.nexthop_route._has_data():
                                                            return True

                                                        if self.nexthop_route_path is not None:
                                                            for child_ref in self.nexthop_route_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.nexthop_route_path_count is not None:
                                                            return True

                                                        if self.nexthop_route_prefix_length is not None:
                                                            return True

                                                        if self.nexthop_route_protocol is not None:
                                                            return True

                                                        if self.nexthop_status is not None:
                                                            return True

                                                        if self.nexthop_tableid is not None:
                                                            return True

                                                        if self.non_critical_events is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo']['meta_info']


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address List
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop-af'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.af_name is not None:
                                                        return True

                                                    if self.attribute_set is not None:
                                                        return True

                                                    if self.neighbor_address is not None:
                                                        for child_ref in self.neighbor_address:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.next_hop_address is not None:
                                                        return True

                                                    if self.nexthop_address is not None and self.nexthop_address._has_data():
                                                        return True

                                                    if self.nexthop_aigp_metric is not None:
                                                        return True

                                                    if self.nexthop_gateway_info is not None:
                                                        for child_ref in self.nexthop_gateway_info:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.nexthop_gateway_prefix_connected is not None:
                                                        return True

                                                    if self.nexthop_gateway_prefix_length is not None:
                                                        return True

                                                    if self.nexthop_gateway_reachable is not None:
                                                        return True

                                                    if self.nexthop_internal_info is not None and self.nexthop_internal_info._has_data():
                                                        return True

                                                    if self.nexthop_pending_registration is not None:
                                                        return True

                                                    if self.nexthop_reference_count is not None:
                                                        return True

                                                    if self.nh_first_hop_if_handle is not None:
                                                        return True

                                                    if self.nh_reference_count_total is not None:
                                                        return True

                                                    if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                        return True

                                                    if self.rib_nexthop_id is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop-afs'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.next_hop_af is not None:
                                                    for child_ref in self.next_hop_af:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')
                                            if self.next_hop_af_name is None:
                                                raise YPYModelError('Key property next_hop_af_name is None')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop-address-family[Cisco-IOS-XR-ipv4-bgp-oper:next-hop-af-name = ' + str(self.next_hop_af_name) + ']'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.next_hop_af_name is not None:
                                                return True

                                            if self.next_hop_af_vrf_af is not None and self.next_hop_af_vrf_af._has_data():
                                                return True

                                            if self.next_hop_afs is not None and self.next_hop_afs._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop-address-families'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.next_hop_address_family is not None:
                                            for child_ref in self.next_hop_address_family:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies']['meta_info']


                                class RtSetCounters(object):
                                    """
                                    The RT\-set counter table
                                    
                                    .. attribute:: rt_set_counter
                                    
                                    	One RT\-set counter table entry
                                    	**type**\: list of    :py:class:`RtSetCounter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.rt_set_counter = YList()
                                        self.rt_set_counter.parent = self
                                        self.rt_set_counter.name = 'rt_set_counter'


                                    class RtSetCounter(object):
                                        """
                                        One RT\-set counter table entry
                                        
                                        .. attribute:: rt_set_id  <key>
                                        
                                        	RTSet ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: route_target_set
                                        
                                        	Route Target set
                                        	**type**\:   :py:class:`RouteTargetSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.rt_set_id = None
                                            self.route_target_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet()
                                            self.route_target_set.parent = self


                                        class RouteTargetSet(object):
                                            """
                                            Route Target set
                                            
                                            .. attribute:: rt_set
                                            
                                            	Set of route targets
                                            	**type**\: list of    :py:class:`RtSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet>`
                                            
                                            .. attribute:: rt_set_id
                                            
                                            	Identifier of the rtset
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rt_set_len
                                            
                                            	Length in bytes of set of route targets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rt_set_net_count
                                            
                                            	Count of nets with paths with the rtset
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.rt_set = YList()
                                                self.rt_set.parent = self
                                                self.rt_set.name = 'rt_set'
                                                self.rt_set_id = None
                                                self.rt_set_len = None
                                                self.rt_set_net_count = None


                                            class RtSet(object):
                                                """
                                                Set of route targets
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rt-set'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:route-target-set'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.rt_set is not None:
                                                    for child_ref in self.rt_set:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.rt_set_id is not None:
                                                    return True

                                                if self.rt_set_len is not None:
                                                    return True

                                                if self.rt_set_net_count is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')
                                            if self.rt_set_id is None:
                                                raise YPYModelError('Key property rt_set_id is None')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rt-set-counter[Cisco-IOS-XR-ipv4-bgp-oper:rt-set-id = ' + str(self.rt_set_id) + ']'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.rt_set_id is not None:
                                                return True

                                            if self.route_target_set is not None and self.route_target_set._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rt-set-counters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.rt_set_counter is not None:
                                            for child_ref in self.rt_set_counter:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters']['meta_info']


                                class BmpPaths(object):
                                    """
                                    The paths in BMP Table
                                    
                                    .. attribute:: bmp_path
                                    
                                    	A BMP path table entry
                                    	**type**\: list of    :py:class:`BmpPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.bmp_path = YList()
                                        self.bmp_path.parent = self
                                        self.bmp_path.name = 'bmp_path'


                                    class BmpPath(object):
                                        """
                                        A BMP path table entry
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix>`
                                        
                                        .. attribute:: bmp_net_flags
                                        
                                        	Flags associated with net
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_net_version
                                        
                                        	Net's version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_path
                                        
                                        	List of paths under the BMP net
                                        	**type**\: list of    :py:class:`BmpPath_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_>`
                                        
                                        .. attribute:: has_local_label
                                        
                                        	Net has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_local_label
                                        
                                        	Local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: network
                                        
                                        	Network Prefix in Hex format
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: num_of_path
                                        
                                        	Number of path for the net
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: version_age
                                        
                                        	Net Version bump age
                                        	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionAge>`
                                        
                                        .. attribute:: version_timestamp
                                        
                                        	Net Version bump timestamp
                                        	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self.bmp_net_flags = None
                                            self.bmp_net_version = None
                                            self.bmp_path = YList()
                                            self.bmp_path.parent = self
                                            self.bmp_path.name = 'bmp_path'
                                            self.has_local_label = None
                                            self.net_local_label = None
                                            self.network = None
                                            self.num_of_path = None
                                            self.prefix_length = None
                                            self.version_age = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionAge()
                                            self.version_age.parent = self
                                            self.version_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp()
                                            self.version_timestamp.parent = self


                                        class BgpPrefix(object):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self.prefix_length = None


                                            class Prefix(object):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.prefix is not None and self.prefix._has_data():
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix']['meta_info']


                                        class VersionTimestamp(object):
                                            """
                                            Net Version bump timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp']['meta_info']


                                        class VersionAge(object):
                                            """
                                            Net Version bump age
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-age'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionAge']['meta_info']


                                        class BmpPath_(object):
                                            """
                                            List of paths under the BMP net
                                            
                                            .. attribute:: bmp_nbr_bit_map
                                            
                                            	Paths Nbr bmp bit map
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_path_adv_bit_map
                                            
                                            	Path's Adv bit map
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: bmp_path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_path_snd_bit_map
                                            
                                            	Path's pending snd bit map
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: bpath_pointer
                                            
                                            	BGP Path pointer
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: local_path
                                            
                                            	Is path originated locally?
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress>`
                                            
                                            .. attribute:: received_label
                                            
                                            	Label received from peer
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.bmp_nbr_bit_map = None
                                                self.bmp_path_adv_bit_map = None
                                                self.bmp_path_flags = None
                                                self.bmp_path_snd_bit_map = None
                                                self.bpath_pointer = None
                                                self.local_path = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.received_label = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-path'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bmp_nbr_bit_map is not None:
                                                    return True

                                                if self.bmp_path_adv_bit_map is not None:
                                                    return True

                                                if self.bmp_path_flags is not None:
                                                    return True

                                                if self.bmp_path_snd_bit_map is not None:
                                                    return True

                                                if self.bpath_pointer is not None:
                                                    return True

                                                if self.local_path is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.received_label is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-path'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                return True

                                            if self.bmp_net_flags is not None:
                                                return True

                                            if self.bmp_net_version is not None:
                                                return True

                                            if self.bmp_path is not None:
                                                for child_ref in self.bmp_path:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.has_local_label is not None:
                                                return True

                                            if self.net_local_label is not None:
                                                return True

                                            if self.network is not None:
                                                return True

                                            if self.num_of_path is not None:
                                                return True

                                            if self.prefix_length is not None:
                                                return True

                                            if self.version_age is not None and self.version_age._has_data():
                                                return True

                                            if self.version_timestamp is not None and self.version_timestamp._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-paths'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bmp_path is not None:
                                            for child_ref in self.bmp_path:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths']['meta_info']


                                class UpdateGenerationUpdateGroups(object):
                                    """
                                    Update generation for all update\-groups
                                    
                                    .. attribute:: update_generation_update_group
                                    
                                    	Update generation for update\-group
                                    	**type**\: list of    :py:class:`UpdateGenerationUpdateGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.update_generation_update_group = YList()
                                        self.update_generation_update_group.parent = self
                                        self.update_generation_update_group.name = 'update_generation_update_group'


                                    class UpdateGenerationUpdateGroup(object):
                                        """
                                        Update generation for update\-group
                                        
                                        .. attribute:: update_group_index  <key>
                                        
                                        	Update\-group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: filter_group_count
                                        
                                        	Filter\-group count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_permanent
                                        
                                        	Permanent UG check
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_update_timer_running
                                        
                                        	Is update timer running
                                        	**type**\:  bool
                                        
                                        .. attribute:: last_update_timer_delay_value
                                        
                                        	Last update timer delay value
                                        	**type**\:   :py:class:`LastUpdateTimerDelayValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue>`
                                        
                                        .. attribute:: last_update_timer_expiry_age
                                        
                                        	Time since last update timer expiry event
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_timer_expiry_timestamp
                                        
                                        	Last update timer expiry time
                                        	**type**\:   :py:class:`LastUpdateTimerExpiryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp>`
                                        
                                        .. attribute:: last_update_timer_remaining_value
                                        
                                        	Update timer remaining time
                                        	**type**\:   :py:class:`LastUpdateTimerRemainingValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue>`
                                        
                                        .. attribute:: last_update_timer_start_timestamp
                                        
                                        	Last update timer start time
                                        	**type**\:   :py:class:`LastUpdateTimerStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp>`
                                        
                                        .. attribute:: last_update_timer_stop_timestamp
                                        
                                        	Last update timer stop time
                                        	**type**\:   :py:class:`LastUpdateTimerStopTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp>`
                                        
                                        .. attribute:: neighbor_count
                                        
                                        	Neighbor count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_leaving_count
                                        
                                        	Count of neighbors leaving the update\-group
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_session_af_name
                                        
                                        	Neighbor session address family
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: perm_pelem_allowed
                                        
                                        	Count of Perm Pelems allowed by updgen
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: perm_pelem_encountered
                                        
                                        	Count of Perm Pelems seen by updgen
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: perm_pelem_exp_wdr
                                        
                                        	Count of Perm Pelems explicitly wdrn by updgen
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: perm_pelem_not_allowed
                                        
                                        	Count of Perm Pelems not allowed by updgen
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: perm_pelem_spur_wdr
                                        
                                        	Count of Perm Pelems Spurious withdraws by updgen
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_id
                                        
                                        	ProcessID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_sub_group_count
                                        
                                        	Refresh sub\-group count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_sub_group_throttled_count
                                        
                                        	Throttled refresh sub\-group count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_throttled_count
                                        
                                        	Throttled sub\-group count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_recovery_pending
                                        
                                        	Is update generation recovery pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: update_group_af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: update_group_flags2
                                        
                                        	Update\-group internal flags2
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_group_index_xr
                                        
                                        	Update\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages
                                        
                                        	OutQueue Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size
                                        
                                        	OutQueue Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_statistics
                                        
                                        	Update statistics
                                        	**type**\:   :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics>`
                                        
                                        .. attribute:: update_sub_group_count
                                        
                                        	Sub\-group count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_vrf_name
                                        
                                        	VRF Name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.update_group_index = None
                                            self.filter_group_count = None
                                            self.is_permanent = None
                                            self.is_update_timer_running = None
                                            self.last_update_timer_delay_value = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue()
                                            self.last_update_timer_delay_value.parent = self
                                            self.last_update_timer_expiry_age = None
                                            self.last_update_timer_expiry_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp()
                                            self.last_update_timer_expiry_timestamp.parent = self
                                            self.last_update_timer_remaining_value = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue()
                                            self.last_update_timer_remaining_value.parent = self
                                            self.last_update_timer_start_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp()
                                            self.last_update_timer_start_timestamp.parent = self
                                            self.last_update_timer_stop_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp()
                                            self.last_update_timer_stop_timestamp.parent = self
                                            self.neighbor_count = None
                                            self.neighbor_leaving_count = None
                                            self.neighbor_session_af_name = None
                                            self.perm_pelem_allowed = None
                                            self.perm_pelem_encountered = None
                                            self.perm_pelem_exp_wdr = None
                                            self.perm_pelem_not_allowed = None
                                            self.perm_pelem_spur_wdr = None
                                            self.process_id = None
                                            self.refresh_sub_group_count = None
                                            self.refresh_sub_group_throttled_count = None
                                            self.sub_group_throttled_count = None
                                            self.update_generation_recovery_pending = None
                                            self.update_group_af_name = None
                                            self.update_group_flags2 = None
                                            self.update_group_index_xr = None
                                            self.update_out_queue_messages = None
                                            self.update_out_queue_size = None
                                            self.update_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics()
                                            self.update_statistics.parent = self
                                            self.update_sub_group_count = None
                                            self.update_vrf_name = None


                                        class LastUpdateTimerStartTimestamp(object):
                                            """
                                            Last update timer start time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-timer-start-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp']['meta_info']


                                        class LastUpdateTimerStopTimestamp(object):
                                            """
                                            Last update timer stop time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-timer-stop-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp']['meta_info']


                                        class LastUpdateTimerExpiryTimestamp(object):
                                            """
                                            Last update timer expiry time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-timer-expiry-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp']['meta_info']


                                        class LastUpdateTimerRemainingValue(object):
                                            """
                                            Update timer remaining time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-timer-remaining-value'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue']['meta_info']


                                        class LastUpdateTimerDelayValue(object):
                                            """
                                            Last update timer delay value
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-timer-delay-value'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue']['meta_info']


                                        class UpdateStatistics(object):
                                            """
                                            Update statistics
                                            
                                            .. attribute:: last_update_cleard_age
                                            
                                            	Time since last Clear event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_cleared_timestamp
                                            
                                            	Last Cleared time
                                            	**type**\:   :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp>`
                                            
                                            .. attribute:: last_update_discard_age
                                            
                                            	Time since last Discard event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_discard_timestamp
                                            
                                            	Last Discarded time
                                            	**type**\:   :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                            
                                            .. attribute:: last_update_memory_allocation_fail_age
                                            
                                            	Time since last memory allocation failure event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_memory_allocation_fail_timestamp
                                            
                                            	Memory allocation failure time
                                            	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                            
                                            .. attribute:: last_update_recovery_age
                                            
                                            	Time since last Recovery event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_recovery_timestamp
                                            
                                            	Last Recovery time
                                            	**type**\:   :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                            
                                            .. attribute:: last_update_throttle_age
                                            
                                            	Time since last Throttle event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_throttle_timestamp
                                            
                                            	Last Throttled time
                                            	**type**\:   :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                            
                                            .. attribute:: update_memory_allocation_fail_count
                                            
                                            	Memory allocation failure count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_cleared
                                            
                                            	OutQueue Cleared Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_cumulative
                                            
                                            	OutQueue Cumulative Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_discarded
                                            
                                            	OutQueue Discarded Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_high
                                            
                                            	OutQueue High Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_size_cleared
                                            
                                            	OutQueue Cleared Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_cumulative
                                            
                                            	OutQueue Cumulative Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_discarded
                                            
                                            	OutQueue Discarded Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_high
                                            
                                            	OutQueue Hi Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_recovery_count
                                            
                                            	Recovery Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_throttle_count
                                            
                                            	Throttle Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.last_update_cleard_age = None
                                                self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp()
                                                self.last_update_cleared_timestamp.parent = self
                                                self.last_update_discard_age = None
                                                self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp()
                                                self.last_update_discard_timestamp.parent = self
                                                self.last_update_memory_allocation_fail_age = None
                                                self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                                self.last_update_memory_allocation_fail_timestamp.parent = self
                                                self.last_update_recovery_age = None
                                                self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                                self.last_update_recovery_timestamp.parent = self
                                                self.last_update_throttle_age = None
                                                self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp()
                                                self.last_update_throttle_timestamp.parent = self
                                                self.update_memory_allocation_fail_count = None
                                                self.update_out_queue_messages_cleared = None
                                                self.update_out_queue_messages_cumulative = None
                                                self.update_out_queue_messages_discarded = None
                                                self.update_out_queue_messages_high = None
                                                self.update_out_queue_size_cleared = None
                                                self.update_out_queue_size_cumulative = None
                                                self.update_out_queue_size_discarded = None
                                                self.update_out_queue_size_high = None
                                                self.update_recovery_count = None
                                                self.update_throttle_count = None


                                            class LastUpdateDiscardTimestamp(object):
                                                """
                                                Last Discarded time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-discard-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp']['meta_info']


                                            class LastUpdateClearedTimestamp(object):
                                                """
                                                Last Cleared time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-cleared-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp']['meta_info']


                                            class LastUpdateThrottleTimestamp(object):
                                                """
                                                Last Throttled time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-throttle-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp']['meta_info']


                                            class LastUpdateRecoveryTimestamp(object):
                                                """
                                                Last Recovery time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-recovery-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp']['meta_info']


                                            class LastUpdateMemoryAllocationFailTimestamp(object):
                                                """
                                                Memory allocation failure time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-memory-allocation-fail-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-statistics'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.last_update_cleard_age is not None:
                                                    return True

                                                if self.last_update_cleared_timestamp is not None and self.last_update_cleared_timestamp._has_data():
                                                    return True

                                                if self.last_update_discard_age is not None:
                                                    return True

                                                if self.last_update_discard_timestamp is not None and self.last_update_discard_timestamp._has_data():
                                                    return True

                                                if self.last_update_memory_allocation_fail_age is not None:
                                                    return True

                                                if self.last_update_memory_allocation_fail_timestamp is not None and self.last_update_memory_allocation_fail_timestamp._has_data():
                                                    return True

                                                if self.last_update_recovery_age is not None:
                                                    return True

                                                if self.last_update_recovery_timestamp is not None and self.last_update_recovery_timestamp._has_data():
                                                    return True

                                                if self.last_update_throttle_age is not None:
                                                    return True

                                                if self.last_update_throttle_timestamp is not None and self.last_update_throttle_timestamp._has_data():
                                                    return True

                                                if self.update_memory_allocation_fail_count is not None:
                                                    return True

                                                if self.update_out_queue_messages_cleared is not None:
                                                    return True

                                                if self.update_out_queue_messages_cumulative is not None:
                                                    return True

                                                if self.update_out_queue_messages_discarded is not None:
                                                    return True

                                                if self.update_out_queue_messages_high is not None:
                                                    return True

                                                if self.update_out_queue_size_cleared is not None:
                                                    return True

                                                if self.update_out_queue_size_cumulative is not None:
                                                    return True

                                                if self.update_out_queue_size_discarded is not None:
                                                    return True

                                                if self.update_out_queue_size_high is not None:
                                                    return True

                                                if self.update_recovery_count is not None:
                                                    return True

                                                if self.update_throttle_count is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')
                                            if self.update_group_index is None:
                                                raise YPYModelError('Key property update_group_index is None')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-update-group[Cisco-IOS-XR-ipv4-bgp-oper:update-group-index = ' + str(self.update_group_index) + ']'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.update_group_index is not None:
                                                return True

                                            if self.filter_group_count is not None:
                                                return True

                                            if self.is_permanent is not None:
                                                return True

                                            if self.is_update_timer_running is not None:
                                                return True

                                            if self.last_update_timer_delay_value is not None and self.last_update_timer_delay_value._has_data():
                                                return True

                                            if self.last_update_timer_expiry_age is not None:
                                                return True

                                            if self.last_update_timer_expiry_timestamp is not None and self.last_update_timer_expiry_timestamp._has_data():
                                                return True

                                            if self.last_update_timer_remaining_value is not None and self.last_update_timer_remaining_value._has_data():
                                                return True

                                            if self.last_update_timer_start_timestamp is not None and self.last_update_timer_start_timestamp._has_data():
                                                return True

                                            if self.last_update_timer_stop_timestamp is not None and self.last_update_timer_stop_timestamp._has_data():
                                                return True

                                            if self.neighbor_count is not None:
                                                return True

                                            if self.neighbor_leaving_count is not None:
                                                return True

                                            if self.neighbor_session_af_name is not None:
                                                return True

                                            if self.perm_pelem_allowed is not None:
                                                return True

                                            if self.perm_pelem_encountered is not None:
                                                return True

                                            if self.perm_pelem_exp_wdr is not None:
                                                return True

                                            if self.perm_pelem_not_allowed is not None:
                                                return True

                                            if self.perm_pelem_spur_wdr is not None:
                                                return True

                                            if self.process_id is not None:
                                                return True

                                            if self.refresh_sub_group_count is not None:
                                                return True

                                            if self.refresh_sub_group_throttled_count is not None:
                                                return True

                                            if self.sub_group_throttled_count is not None:
                                                return True

                                            if self.update_generation_recovery_pending is not None:
                                                return True

                                            if self.update_group_af_name is not None:
                                                return True

                                            if self.update_group_flags2 is not None:
                                                return True

                                            if self.update_group_index_xr is not None:
                                                return True

                                            if self.update_out_queue_messages is not None:
                                                return True

                                            if self.update_out_queue_size is not None:
                                                return True

                                            if self.update_statistics is not None and self.update_statistics._has_data():
                                                return True

                                            if self.update_sub_group_count is not None:
                                                return True

                                            if self.update_vrf_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-update-groups'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.update_generation_update_group is not None:
                                            for child_ref in self.update_generation_update_group:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups']['meta_info']


                                class UpdateGenerationFilterGroups(object):
                                    """
                                    Update generation for all filter\-groups under
                                    a sub\-group
                                    
                                    .. attribute:: update_generation_filter_group
                                    
                                    	Update generation for filter\-group
                                    	**type**\: list of    :py:class:`UpdateGenerationFilterGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.update_generation_filter_group = YList()
                                        self.update_generation_filter_group.parent = self
                                        self.update_generation_filter_group.name = 'update_generation_filter_group'


                                    class UpdateGenerationFilterGroup(object):
                                        """
                                        Update generation for filter\-group
                                        
                                        .. attribute:: filter_group_index
                                        
                                        	Filter\-group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: neighbor_count
                                        
                                        	Neighbor count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: parent_filter_group_index
                                        
                                        	Parent Filter\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: parent_sub_group_id
                                        
                                        	Parent Sub\-group identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: parent_sub_group_index
                                        
                                        	Parent Sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_id
                                        
                                        	ProcessID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_id
                                        
                                        	Sub\-group ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: sub_group_id_xr
                                        
                                        	Sub\-group identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_index
                                        
                                        	Sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: sub_group_index_xr
                                        
                                        	Sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_filter_group_index
                                        
                                        	Filter\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_group_af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: update_group_index
                                        
                                        	Update\-group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: update_group_index_xr
                                        
                                        	Update\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_vrf_name
                                        
                                        	VRF Name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.filter_group_index = None
                                            self.neighbor_count = None
                                            self.parent_filter_group_index = None
                                            self.parent_sub_group_id = None
                                            self.parent_sub_group_index = None
                                            self.process_id = None
                                            self.sub_group_id = None
                                            self.sub_group_id_xr = None
                                            self.sub_group_index = None
                                            self.sub_group_index_xr = None
                                            self.update_filter_group_index = None
                                            self.update_group_af_name = None
                                            self.update_group_index = None
                                            self.update_group_index_xr = None
                                            self.update_vrf_name = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-filter-group'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.filter_group_index is not None:
                                                return True

                                            if self.neighbor_count is not None:
                                                return True

                                            if self.parent_filter_group_index is not None:
                                                return True

                                            if self.parent_sub_group_id is not None:
                                                return True

                                            if self.parent_sub_group_index is not None:
                                                return True

                                            if self.process_id is not None:
                                                return True

                                            if self.sub_group_id is not None:
                                                return True

                                            if self.sub_group_id_xr is not None:
                                                return True

                                            if self.sub_group_index is not None:
                                                return True

                                            if self.sub_group_index_xr is not None:
                                                return True

                                            if self.update_filter_group_index is not None:
                                                return True

                                            if self.update_group_af_name is not None:
                                                return True

                                            if self.update_group_index is not None:
                                                return True

                                            if self.update_group_index_xr is not None:
                                                return True

                                            if self.update_vrf_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-filter-groups'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.update_generation_filter_group is not None:
                                            for child_ref in self.update_generation_filter_group:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups']['meta_info']


                                class Networks(object):
                                    """
                                    The BGP Network Table
                                    
                                    .. attribute:: network
                                    
                                    	A BGP Network table entry
                                    	**type**\: list of    :py:class:`Network <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.network = YList()
                                        self.network.parent = self
                                        self.network.name = 'network'


                                    class Network(object):
                                        """
                                        A BGP Network table entry
                                        
                                        .. attribute:: active_path_element
                                        
                                        	Path element list received from Active inst
                                        	**type**\: list of    :py:class:`ActivePathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement>`
                                        
                                        .. attribute:: active_process_instance_path
                                        
                                        	Active's paths for this net 
                                        	**type**\: list of    :py:class:`ActiveProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath>`
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield>`
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix>`
                                        
                                        .. attribute:: bit
                                        
                                        	Bit
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: flags
                                        
                                        	Flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: gateway_array
                                        
                                        	Gateway array ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_inconsistent_paths
                                        
                                        	Net has inconsistent paths
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_lbl_retained
                                        
                                        	Net has label retained
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_local_label
                                        
                                        	Net has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_net_aggregation_suppressed
                                        
                                        	Net suppressed due to aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_net_ldp_signaled
                                        
                                        	L2VPN Net LDP signaled  aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_permanent_network
                                        
                                        	Permanent Network
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_path_element
                                        
                                        	Local path element list
                                        	**type**\: list of    :py:class:`LocalPathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement>`
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: local_process_instance_path
                                        
                                        	Local (to process instance) paths for this net 
                                        	**type**\: list of    :py:class:`LocalProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath>`
                                        
                                        .. attribute:: net_backup_available
                                        
                                        	Net has backup path
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_backup_label_rewrite_available
                                        
                                        	Net has label rewrite for backup path
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_eibgp_multipath
                                        
                                        	Net has EIBGP multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_extended_flags
                                        
                                        	Net extended flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: net_flags
                                        
                                        	Flags associated with                            net
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: net_local_label
                                        
                                        	Local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: net_local_label_rewrite
                                        
                                        	Net label has rewrite
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_local_label_srgb
                                        
                                        	Net label allocated fromSegment routing global block
                                        	**type**\:  bool
                                        
                                        .. attribute:: net_multipath
                                        
                                        	Net has multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: network
                                        
                                        	Network in prefix/length format
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        
                                        ----
                                        .. attribute:: num_of_path
                                        
                                        	Number of path for this net
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: resilient_nexthop_set
                                        
                                        	Resilient nexthop set ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_failed
                                        
                                        	RIB install failed
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: table_brib_version
                                        
                                        	Table version # for updates
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: table_version
                                        
                                        	Table version # for net
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version
                                        
                                        	Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version_age
                                        
                                        	Version age
                                        	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.VersionAge>`
                                        
                                        .. attribute:: version_timestamp
                                        
                                        	Version timestamp
                                        	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.VersionTimestamp>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.active_path_element = YList()
                                            self.active_path_element.parent = self
                                            self.active_path_element.name = 'active_path_element'
                                            self.active_process_instance_path = YList()
                                            self.active_process_instance_path.parent = self
                                            self.active_process_instance_path.name = 'active_process_instance_path'
                                            self.add_path_orr_bitfield = YList()
                                            self.add_path_orr_bitfield.parent = self
                                            self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                            self.advertisedto_pe = None
                                            self.af_name = None
                                            self.best_path_orr_bitfield = YList()
                                            self.best_path_orr_bitfield.parent = self
                                            self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self.bit = None
                                            self.flags = None
                                            self.gateway_array = None
                                            self.has_inconsistent_paths = None
                                            self.has_lbl_retained = None
                                            self.has_local_label = None
                                            self.is_net_aggregation_suppressed = None
                                            self.is_net_ldp_signaled = None
                                            self.is_permanent_network = None
                                            self.local_path_element = YList()
                                            self.local_path_element.parent = self
                                            self.local_path_element.name = 'local_path_element'
                                            self.local_peers_advertised_to = YList()
                                            self.local_peers_advertised_to.parent = self
                                            self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                            self.local_process_instance_path = YList()
                                            self.local_process_instance_path.parent = self
                                            self.local_process_instance_path.name = 'local_process_instance_path'
                                            self.net_backup_available = None
                                            self.net_backup_label_rewrite_available = None
                                            self.net_eibgp_multipath = None
                                            self.net_extended_flags = None
                                            self.net_flags = None
                                            self.net_local_label = None
                                            self.net_local_label_rewrite = None
                                            self.net_local_label_srgb = None
                                            self.net_multipath = None
                                            self.network = None
                                            self.num_of_path = None
                                            self.pe_peers_advertised_to = YList()
                                            self.pe_peers_advertised_to.parent = self
                                            self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                            self.process_instance_id = None
                                            self.rd = None
                                            self.resilient_nexthop_set = None
                                            self.rib_failed = None
                                            self.route_distinguisher = None
                                            self.table_brib_version = None
                                            self.table_version = None
                                            self.version = None
                                            self.version_age = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.VersionAge()
                                            self.version_age.parent = self
                                            self.version_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.VersionTimestamp()
                                            self.version_timestamp.parent = self
                                            self.vrf_name = None


                                        class BgpPrefix(object):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self.prefix_length = None


                                            class Prefix(object):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.prefix is not None and self.prefix._has_data():
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix']['meta_info']


                                        class VersionTimestamp(object):
                                            """
                                            Version timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.VersionTimestamp']['meta_info']


                                        class VersionAge(object):
                                            """
                                            Version age
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-age'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.VersionAge']['meta_info']


                                        class LocalPeersAdvertisedTo(object):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo']['meta_info']


                                        class PePeersAdvertisedTo(object):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo']['meta_info']


                                        class BestPathOrrBitfield(object):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield']['meta_info']


                                        class AddPathOrrBitfield(object):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield']['meta_info']


                                        class LocalProcessInstancePath(object):
                                            """
                                            Local (to process instance) paths for this net 
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: attributes_after_policy_in
                                            
                                            	Attributes after inbound policy applied
                                            	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn>`
                                            
                                            .. attribute:: label_fail
                                            
                                            	LSD label allocation failed 
                                            	**type**\:  bool
                                            
                                            .. attribute:: label_o_or_version
                                            
                                            	Label Version when OOR happens
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_oor
                                            
                                            	LSD label space is exhausted
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address_xr
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr>`
                                            
                                            .. attribute:: no_path
                                            
                                            	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                            	**type**\:  bool
                                            
                                            .. attribute:: path_information
                                            
                                            	Path information
                                            	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation>`
                                            
                                            .. attribute:: prefix_version
                                            
                                            	Version of BGP Prefix Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: process_instance_id
                                            
                                            	Process instance ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_route_distinguisher
                                            
                                            	Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_vrf_name
                                            
                                            	Name of the source VRF
                                            	**type**\:  str
                                            
                                            .. attribute:: srcaf_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.af_name = None
                                                self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn()
                                                self.attributes_after_policy_in.parent = self
                                                self.label_fail = None
                                                self.label_o_or_version = None
                                                self.label_oor = None
                                                self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr()
                                                self.neighbor_address_xr.parent = self
                                                self.no_path = None
                                                self.path_information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation()
                                                self.path_information.parent = self
                                                self.prefix_version = None
                                                self.process_instance_id = None
                                                self.route_distinguisher = None
                                                self.source_route_distinguisher = None
                                                self.source_vrf_name = None
                                                self.srcaf_name = None
                                                self.vrf_name = None


                                            class NeighborAddressXr(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr']['meta_info']


                                            class PathInformation(object):
                                                """
                                                Path information
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\:  bool
                                                
                                                .. attribute:: accept_own_self_originated_p_ath
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\:  bool
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\:  bool
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix>`
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\:  bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\:  bool
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr>`
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_esi
                                                
                                                	Path has EVPN ESI
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_rcvd_label
                                                
                                                	Path has received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\:  bool
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebg_ps
                                                
                                                	Not advertised to EBGPs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi>`
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress>`
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop>`
                                                
                                                .. attribute:: nhte_tunnel
                                                
                                                	NH TE tunnel information
                                                	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhteTunnel>`
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\:  bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.accept_own_path = None
                                                    self.accept_own_self_originated_p_ath = None
                                                    self.add_path_orr_bitfield = YList()
                                                    self.add_path_orr_bitfield.parent = self
                                                    self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                    self.advertisedto_pe = None
                                                    self.aigp_metric = None
                                                    self.best_path_comp_stage = None
                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self.best_path_id = None
                                                    self.best_path_id_comp_winner = None
                                                    self.best_path_orr_bitfield = YList()
                                                    self.best_path_orr_bitfield.parent = self
                                                    self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self.dampen_penalty = None
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.fspec_invalid_path = None
                                                    self.graceful_shutdown = None
                                                    self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self.halflife_time = None
                                                    self.has_esi = None
                                                    self.has_gw_addr = None
                                                    self.has_local_net_label = None
                                                    self.has_mdt_group_addr = None
                                                    self.has_mvpn_extcomm = None
                                                    self.has_mvpn_nbr_addr = None
                                                    self.has_mvpn_nexthop_addr = None
                                                    self.has_mvpn_pmsi = None
                                                    self.has_rcvd_label = None
                                                    self.has_second_label = None
                                                    self.ibgp_signaled_validity = None
                                                    self.igp_metric = None
                                                    self.is_aggregation_suppressed = None
                                                    self.is_as_best = None
                                                    self.is_best_path = None
                                                    self.is_import_dampened = None
                                                    self.is_import_suspect = None
                                                    self.is_internal_path = None
                                                    self.is_partial_best = None
                                                    self.is_path_additional_path = None
                                                    self.is_path_advertised_local_as_only = None
                                                    self.is_path_af_install_eligible = None
                                                    self.is_path_backup = None
                                                    self.is_path_backup_protect_multipath = None
                                                    self.is_path_best_external = None
                                                    self.is_path_damped = None
                                                    self.is_path_from_confederation_peer = None
                                                    self.is_path_from_network_command = None
                                                    self.is_path_from_redistribute_command = None
                                                    self.is_path_from_route_reflector = None
                                                    self.is_path_history_held = None
                                                    self.is_path_imp_candidate = None
                                                    self.is_path_imported = None
                                                    self.is_path_local_aggregate = None
                                                    self.is_path_locally_sourced = None
                                                    self.is_path_long_lived_stale = None
                                                    self.is_path_multipath = None
                                                    self.is_path_nexthop_discarded = None
                                                    self.is_path_not_advertised = None
                                                    self.is_path_not_advertised_to_ebg_ps = None
                                                    self.is_path_received_only = None
                                                    self.is_path_reoriginated = None
                                                    self.is_path_reoriginated_stitching = None
                                                    self.is_path_stale = None
                                                    self.is_path_synced_with_igp = None
                                                    self.is_path_valid = None
                                                    self.is_path_vpn_only = None
                                                    self.is_permanent_path = None
                                                    self.is_received_path_not_modified = None
                                                    self.is_spkr_as_best = None
                                                    self.l2vpn_circuit_status_value = YList()
                                                    self.l2vpn_circuit_status_value.parent = self
                                                    self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                    self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi()
                                                    self.l2vpn_evpn_esi.parent = self
                                                    self.l2vpn_size = None
                                                    self.labeled_unicast_safi_path = None
                                                    self.local_label = None
                                                    self.local_nh = None
                                                    self.local_path_id = None
                                                    self.local_peers_advertised_to = YList()
                                                    self.local_peers_advertised_to.parent = self
                                                    self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                    self.maximum_suppress_time = None
                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self.mvpn_path_flags = None
                                                    self.mvpn_pmsi_flags = None
                                                    self.mvpn_pmsi_label = None
                                                    self.mvpn_pmsi_type = None
                                                    self.mvpn_pmsi_value = YList()
                                                    self.mvpn_pmsi_value.parent = self
                                                    self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                    self.mvpn_sfs_path = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.neighbor_router_id = None
                                                    self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop()
                                                    self.next_hop.parent = self
                                                    self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhteTunnel()
                                                    self.nhte_tunnel.parent = self
                                                    self.path_flags = None
                                                    self.path_flap_count = None
                                                    self.path_import_flags = None
                                                    self.path_rt_set_id = None
                                                    self.path_rt_set_route_count = None
                                                    self.path_table_version = None
                                                    self.path_weight = None
                                                    self.pe_peers_advertised_to = YList()
                                                    self.pe_peers_advertised_to.parent = self
                                                    self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                    self.rcvd_label = None
                                                    self.rcvd_path_id = None
                                                    self.reuse_value = None
                                                    self.rib_failed = None
                                                    self.route_type = None
                                                    self.rpki_origin_as_validation_disabled = None
                                                    self.rt_set_limit_enabled = None
                                                    self.second_label = None
                                                    self.seconds_since_first_flap = None
                                                    self.show_rpki_origin_as_validity = None
                                                    self.sn_rpki_origin_as_validity = None
                                                    self.suppress_penalty = None
                                                    self.time_to_unsuppress = None


                                                class BgpPrefix(object):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self.prefix_length = None


                                                    class Prefix(object):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.prefix is not None and self.prefix._has_data():
                                                            return True

                                                        if self.prefix_length is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix']['meta_info']


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress']['meta_info']


                                                class NextHop(object):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop']['meta_info']


                                                class NhteTunnel(object):
                                                    """
                                                    NH TE tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_te_tunnel
                                                    
                                                    	NH TE Tunnel info is present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last rib update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	tunnel name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	tunnel type
                                                    	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.binding_label = None
                                                        self.has_te_tunnel = None
                                                        self.is_tunnel_info_stale = None
                                                        self.is_tunnel_registered = None
                                                        self.is_tunnel_up = None
                                                        self.last_tunnel_update = None
                                                        self.tunnel_if_handle = None
                                                        self.tunnel_name = None
                                                        self.tunnel_type = None
                                                        self.tunnel_v6_enabled = None
                                                        self.tunnel_v6_required = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.binding_label is not None:
                                                            return True

                                                        if self.has_te_tunnel is not None:
                                                            return True

                                                        if self.is_tunnel_info_stale is not None:
                                                            return True

                                                        if self.is_tunnel_registered is not None:
                                                            return True

                                                        if self.is_tunnel_up is not None:
                                                            return True

                                                        if self.last_tunnel_update is not None:
                                                            return True

                                                        if self.tunnel_if_handle is not None:
                                                            return True

                                                        if self.tunnel_name is not None:
                                                            return True

                                                        if self.tunnel_type is not None:
                                                            return True

                                                        if self.tunnel_v6_enabled is not None:
                                                            return True

                                                        if self.tunnel_v6_required is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhteTunnel']['meta_info']


                                                class MdtGroupAddr(object):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr']['meta_info']


                                                class L2VpnEvpnEsi(object):
                                                    """
                                                    L2VPN EVPN ESI
                                                    
                                                    .. attribute:: esi
                                                    
                                                    	esi
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.esi = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.esi is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi']['meta_info']


                                                class GwAddr(object):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.len = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.len is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr']['meta_info']


                                                class BestPathCompWinner(object):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner']['meta_info']


                                                class MvpnNbrAddr(object):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr']['meta_info']


                                                class MvpnNexthopAddr(object):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr']['meta_info']


                                                class L2VpnCircuitStatusValue(object):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                                class MvpnPmsiValue(object):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity']['meta_info']


                                                class LocalPeersAdvertisedTo(object):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                                class PePeersAdvertisedTo(object):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo']['meta_info']


                                                class BestPathOrrBitfield(object):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield']['meta_info']


                                                class AddPathOrrBitfield(object):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.accept_own_path is not None:
                                                        return True

                                                    if self.accept_own_self_originated_p_ath is not None:
                                                        return True

                                                    if self.add_path_orr_bitfield is not None:
                                                        for child_ref in self.add_path_orr_bitfield:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.advertisedto_pe is not None:
                                                        return True

                                                    if self.aigp_metric is not None:
                                                        return True

                                                    if self.best_path_comp_stage is not None:
                                                        return True

                                                    if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                        return True

                                                    if self.best_path_id is not None:
                                                        return True

                                                    if self.best_path_id_comp_winner is not None:
                                                        return True

                                                    if self.best_path_orr_bitfield is not None:
                                                        for child_ref in self.best_path_orr_bitfield:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                        return True

                                                    if self.dampen_penalty is not None:
                                                        return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.fspec_invalid_path is not None:
                                                        return True

                                                    if self.graceful_shutdown is not None:
                                                        return True

                                                    if self.gw_addr is not None and self.gw_addr._has_data():
                                                        return True

                                                    if self.halflife_time is not None:
                                                        return True

                                                    if self.has_esi is not None:
                                                        return True

                                                    if self.has_gw_addr is not None:
                                                        return True

                                                    if self.has_local_net_label is not None:
                                                        return True

                                                    if self.has_mdt_group_addr is not None:
                                                        return True

                                                    if self.has_mvpn_extcomm is not None:
                                                        return True

                                                    if self.has_mvpn_nbr_addr is not None:
                                                        return True

                                                    if self.has_mvpn_nexthop_addr is not None:
                                                        return True

                                                    if self.has_mvpn_pmsi is not None:
                                                        return True

                                                    if self.has_rcvd_label is not None:
                                                        return True

                                                    if self.has_second_label is not None:
                                                        return True

                                                    if self.ibgp_signaled_validity is not None:
                                                        return True

                                                    if self.igp_metric is not None:
                                                        return True

                                                    if self.is_aggregation_suppressed is not None:
                                                        return True

                                                    if self.is_as_best is not None:
                                                        return True

                                                    if self.is_best_path is not None:
                                                        return True

                                                    if self.is_import_dampened is not None:
                                                        return True

                                                    if self.is_import_suspect is not None:
                                                        return True

                                                    if self.is_internal_path is not None:
                                                        return True

                                                    if self.is_partial_best is not None:
                                                        return True

                                                    if self.is_path_additional_path is not None:
                                                        return True

                                                    if self.is_path_advertised_local_as_only is not None:
                                                        return True

                                                    if self.is_path_af_install_eligible is not None:
                                                        return True

                                                    if self.is_path_backup is not None:
                                                        return True

                                                    if self.is_path_backup_protect_multipath is not None:
                                                        return True

                                                    if self.is_path_best_external is not None:
                                                        return True

                                                    if self.is_path_damped is not None:
                                                        return True

                                                    if self.is_path_from_confederation_peer is not None:
                                                        return True

                                                    if self.is_path_from_network_command is not None:
                                                        return True

                                                    if self.is_path_from_redistribute_command is not None:
                                                        return True

                                                    if self.is_path_from_route_reflector is not None:
                                                        return True

                                                    if self.is_path_history_held is not None:
                                                        return True

                                                    if self.is_path_imp_candidate is not None:
                                                        return True

                                                    if self.is_path_imported is not None:
                                                        return True

                                                    if self.is_path_local_aggregate is not None:
                                                        return True

                                                    if self.is_path_locally_sourced is not None:
                                                        return True

                                                    if self.is_path_long_lived_stale is not None:
                                                        return True

                                                    if self.is_path_multipath is not None:
                                                        return True

                                                    if self.is_path_nexthop_discarded is not None:
                                                        return True

                                                    if self.is_path_not_advertised is not None:
                                                        return True

                                                    if self.is_path_not_advertised_to_ebg_ps is not None:
                                                        return True

                                                    if self.is_path_received_only is not None:
                                                        return True

                                                    if self.is_path_reoriginated is not None:
                                                        return True

                                                    if self.is_path_reoriginated_stitching is not None:
                                                        return True

                                                    if self.is_path_stale is not None:
                                                        return True

                                                    if self.is_path_synced_with_igp is not None:
                                                        return True

                                                    if self.is_path_valid is not None:
                                                        return True

                                                    if self.is_path_vpn_only is not None:
                                                        return True

                                                    if self.is_permanent_path is not None:
                                                        return True

                                                    if self.is_received_path_not_modified is not None:
                                                        return True

                                                    if self.is_spkr_as_best is not None:
                                                        return True

                                                    if self.l2vpn_circuit_status_value is not None:
                                                        for child_ref in self.l2vpn_circuit_status_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                        return True

                                                    if self.l2vpn_size is not None:
                                                        return True

                                                    if self.labeled_unicast_safi_path is not None:
                                                        return True

                                                    if self.local_label is not None:
                                                        return True

                                                    if self.local_nh is not None:
                                                        return True

                                                    if self.local_path_id is not None:
                                                        return True

                                                    if self.local_peers_advertised_to is not None:
                                                        for child_ref in self.local_peers_advertised_to:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.maximum_suppress_time is not None:
                                                        return True

                                                    if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                        return True

                                                    if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                        return True

                                                    if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                        return True

                                                    if self.mvpn_path_flags is not None:
                                                        return True

                                                    if self.mvpn_pmsi_flags is not None:
                                                        return True

                                                    if self.mvpn_pmsi_label is not None:
                                                        return True

                                                    if self.mvpn_pmsi_type is not None:
                                                        return True

                                                    if self.mvpn_pmsi_value is not None:
                                                        for child_ref in self.mvpn_pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.mvpn_sfs_path is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.neighbor_router_id is not None:
                                                        return True

                                                    if self.next_hop is not None and self.next_hop._has_data():
                                                        return True

                                                    if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                        return True

                                                    if self.path_flags is not None:
                                                        return True

                                                    if self.path_flap_count is not None:
                                                        return True

                                                    if self.path_import_flags is not None:
                                                        return True

                                                    if self.path_rt_set_id is not None:
                                                        return True

                                                    if self.path_rt_set_route_count is not None:
                                                        return True

                                                    if self.path_table_version is not None:
                                                        return True

                                                    if self.path_weight is not None:
                                                        return True

                                                    if self.pe_peers_advertised_to is not None:
                                                        for child_ref in self.pe_peers_advertised_to:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.rcvd_label is not None:
                                                        return True

                                                    if self.rcvd_path_id is not None:
                                                        return True

                                                    if self.reuse_value is not None:
                                                        return True

                                                    if self.rib_failed is not None:
                                                        return True

                                                    if self.route_type is not None:
                                                        return True

                                                    if self.rpki_origin_as_validation_disabled is not None:
                                                        return True

                                                    if self.rt_set_limit_enabled is not None:
                                                        return True

                                                    if self.second_label is not None:
                                                        return True

                                                    if self.seconds_since_first_flap is not None:
                                                        return True

                                                    if self.show_rpki_origin_as_validity is not None:
                                                        return True

                                                    if self.sn_rpki_origin_as_validity is not None:
                                                        return True

                                                    if self.suppress_penalty is not None:
                                                        return True

                                                    if self.time_to_unsuppress is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation']['meta_info']


                                            class AttributesAfterPolicyIn(object):
                                                """
                                                Attributes after inbound policy applied
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\:  bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\:  bool
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                    self.attr_set.parent = self
                                                    self.attribute_key_number = None
                                                    self.attribute_reuse_id_config = None
                                                    self.attribute_reuse_id_current = None
                                                    self.attribute_reuse_id_keys = None
                                                    self.attribute_reuse_id_max_id = None
                                                    self.attribute_reuse_id_node = None
                                                    self.attribute_reuse_id_recover_sec = None
                                                    self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self.is_application_gateway_present = None
                                                    self.is_as_path2_byte = None
                                                    self.is_attr_set_present = None
                                                    self.is_ribrnh_present = None
                                                    self.is_rnh_present = None
                                                    self.ribrnh_encap = None
                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self.ribrnh_mac = None
                                                    self.ribrnh_table = None
                                                    self.ribrnh_vni = None
                                                    self.ribrnhip_table = None
                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self.rnh_addr_len = None
                                                    self.rnh_len = None
                                                    self.rnh_type = None
                                                    self.set_aigp_inbound_igp = None
                                                    self.set_aigp_inbound_metric = None
                                                    self.vpn_distinguisher = None


                                                class CommonAttributes(object):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_encap_present
                                                    
                                                    	Tunnel Encap attribute present 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_policy_allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_binding_sid
                                                    
                                                    	SR Policy Binding sid
                                                    	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_explicit_path
                                                    
                                                    	SR Policy Explicit paths
                                                    	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                    
                                                    .. attribute:: sr_policy_preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_tunnel_request_state
                                                    
                                                    	SR Tunnel Request State
                                                    	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                    
                                                    .. attribute:: sr_tunnel_state
                                                    
                                                    	SR Tunnel State
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encap Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.aggregator_address = None
                                                        self.aggregator_as = None
                                                        self.aigp_metric_value = None
                                                        self.as_path = None
                                                        self.cluster = YList()
                                                        self.cluster.parent = self
                                                        self.cluster.name = 'cluster'
                                                        self.community = YList()
                                                        self.community.parent = self
                                                        self.community.name = 'community'
                                                        self.connector_type = None
                                                        self.connector_value = YList()
                                                        self.connector_value.parent = self
                                                        self.connector_value.name = 'connector_value'
                                                        self.extended_community = YList()
                                                        self.extended_community.parent = self
                                                        self.extended_community.name = 'extended_community'
                                                        self.extended_community_flags = None
                                                        self.is_aggregator_present = None
                                                        self.is_aigp_present = None
                                                        self.is_as_path_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_community_present = None
                                                        self.is_connector_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_label_index_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_metric_present = None
                                                        self.is_origin_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_ssa_present = None
                                                        self.is_tunnel_encap_present = None
                                                        self.l2tpv3_cookie = YList()
                                                        self.l2tpv3_cookie.parent = self
                                                        self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                        self.l2tpv3_session_id = None
                                                        self.label_index_attr = YList()
                                                        self.label_index_attr.parent = self
                                                        self.label_index_attr.name = 'label_index_attr'
                                                        self.local_preference = None
                                                        self.ls_attr = YList()
                                                        self.ls_attr.parent = self
                                                        self.ls_attr.name = 'ls_attr'
                                                        self.metric = None
                                                        self.neighbor_as = None
                                                        self.origin = None
                                                        self.originator = None
                                                        self.pe_distinguisher_label = YList()
                                                        self.pe_distinguisher_label.parent = self
                                                        self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.pmsi_type = None
                                                        self.pmsi_value = YList()
                                                        self.pmsi_value.parent = self
                                                        self.pmsi_value.name = 'pmsi_value'
                                                        self.ppm_pvalue = None
                                                        self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                        self.sr_policy_allocated_binding_sid.parent = self
                                                        self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                        self.sr_policy_binding_sid.parent = self
                                                        self.sr_policy_explicit_path = YList()
                                                        self.sr_policy_explicit_path.parent = self
                                                        self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                        self.sr_policy_preference = None
                                                        self.sr_tunnel_request_state = None
                                                        self.sr_tunnel_state = None
                                                        self.tunnel_encap_type = None
                                                        self.unknown_attribute = YList()
                                                        self.unknown_attribute.parent = self
                                                        self.unknown_attribute.name = 'unknown_attribute'


                                                    class SrPolicyBindingSid(object):
                                                        """
                                                        SR Policy Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                    class SrPolicyAllocatedBindingSid(object):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                    class Community(object):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                    class ExtendedCommunity(object):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                    class UnknownAttribute(object):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                    class Cluster(object):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                    class L2Tpv3Cookie(object):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                    class ConnectorValue(object):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                    class PmsiValue(object):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                    class LsAttr(object):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                    class LabelIndexAttr(object):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                    class PeDistinguisherLabel(object):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.label = None
                                                            self.pe_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.label is not None:
                                                                return True

                                                            if self.pe_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                    class SrPolicyExplicitPath(object):
                                                        """
                                                        SR Policy Explicit paths
                                                        
                                                        .. attribute:: sid
                                                        
                                                        	Sidlist for explicit path
                                                        	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of explicit path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.sid = YList()
                                                            self.sid.parent = self
                                                            self.sid.name = 'sid'
                                                            self.weight = None


                                                        class Sid(object):
                                                            """
                                                            Sidlist for explicit path
                                                            
                                                            .. attribute:: ipv4
                                                            
                                                            	IP Address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6
                                                            
                                                            	IPv6 address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label sid
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Sid Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4 = None
                                                                self.ipv6 = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4 is not None:
                                                                    return True

                                                                if self.ipv6 is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.sid is not None:
                                                                for child_ref in self.sid:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.weight is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.aggregator_address is not None:
                                                            return True

                                                        if self.aggregator_as is not None:
                                                            return True

                                                        if self.aigp_metric_value is not None:
                                                            return True

                                                        if self.as_path is not None:
                                                            return True

                                                        if self.cluster is not None:
                                                            for child_ref in self.cluster:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.community is not None:
                                                            for child_ref in self.community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.connector_type is not None:
                                                            return True

                                                        if self.connector_value is not None:
                                                            for child_ref in self.connector_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community is not None:
                                                            for child_ref in self.extended_community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community_flags is not None:
                                                            return True

                                                        if self.is_aggregator_present is not None:
                                                            return True

                                                        if self.is_aigp_present is not None:
                                                            return True

                                                        if self.is_as_path_present is not None:
                                                            return True

                                                        if self.is_atomic_aggregate_present is not None:
                                                            return True

                                                        if self.is_community_present is not None:
                                                            return True

                                                        if self.is_connector_present is not None:
                                                            return True

                                                        if self.is_extended_community_present is not None:
                                                            return True

                                                        if self.is_label_index_present is not None:
                                                            return True

                                                        if self.is_local_pref_present is not None:
                                                            return True

                                                        if self.is_ls_attribute_present is not None:
                                                            return True

                                                        if self.is_metric_present is not None:
                                                            return True

                                                        if self.is_origin_present is not None:
                                                            return True

                                                        if self.is_pe_distinguisher_label_present is not None:
                                                            return True

                                                        if self.is_pmsi_present is not None:
                                                            return True

                                                        if self.is_pppmp_present is not None:
                                                            return True

                                                        if self.is_ssa_present is not None:
                                                            return True

                                                        if self.is_tunnel_encap_present is not None:
                                                            return True

                                                        if self.l2tpv3_cookie is not None:
                                                            for child_ref in self.l2tpv3_cookie:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.l2tpv3_session_id is not None:
                                                            return True

                                                        if self.label_index_attr is not None:
                                                            for child_ref in self.label_index_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.local_preference is not None:
                                                            return True

                                                        if self.ls_attr is not None:
                                                            for child_ref in self.ls_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.metric is not None:
                                                            return True

                                                        if self.neighbor_as is not None:
                                                            return True

                                                        if self.origin is not None:
                                                            return True

                                                        if self.originator is not None:
                                                            return True

                                                        if self.pe_distinguisher_label is not None:
                                                            for child_ref in self.pe_distinguisher_label:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.pmsi_flags is not None:
                                                            return True

                                                        if self.pmsi_label is not None:
                                                            return True

                                                        if self.pmsi_type is not None:
                                                            return True

                                                        if self.pmsi_value is not None:
                                                            for child_ref in self.pmsi_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.ppm_pvalue is not None:
                                                            return True

                                                        if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_explicit_path is not None:
                                                            for child_ref in self.sr_policy_explicit_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.sr_policy_preference is not None:
                                                            return True

                                                        if self.sr_tunnel_request_state is not None:
                                                            return True

                                                        if self.sr_tunnel_state is not None:
                                                            return True

                                                        if self.tunnel_encap_type is not None:
                                                            return True

                                                        if self.unknown_attribute is not None:
                                                            for child_ref in self.unknown_attribute:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                                class AttrSet(object):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_encap_present
                                                    
                                                    	Tunnel Encap attribute present 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_policy_allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_binding_sid
                                                    
                                                    	SR Policy Binding sid
                                                    	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_explicit_path
                                                    
                                                    	SR Policy Explicit paths
                                                    	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                    
                                                    .. attribute:: sr_policy_preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_tunnel_request_state
                                                    
                                                    	SR Tunnel Request State
                                                    	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                    
                                                    .. attribute:: sr_tunnel_state
                                                    
                                                    	SR Tunnel State
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encap Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.aggregator_address = None
                                                        self.aggregator_as = None
                                                        self.aigp_metric_value = None
                                                        self.as_path = None
                                                        self.cluster = YList()
                                                        self.cluster.parent = self
                                                        self.cluster.name = 'cluster'
                                                        self.community = YList()
                                                        self.community.parent = self
                                                        self.community.name = 'community'
                                                        self.connector_type = None
                                                        self.connector_value = YList()
                                                        self.connector_value.parent = self
                                                        self.connector_value.name = 'connector_value'
                                                        self.extended_community = YList()
                                                        self.extended_community.parent = self
                                                        self.extended_community.name = 'extended_community'
                                                        self.extended_community_flags = None
                                                        self.is_aggregator_present = None
                                                        self.is_aigp_present = None
                                                        self.is_as_path_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_community_present = None
                                                        self.is_connector_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_label_index_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_metric_present = None
                                                        self.is_origin_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_ssa_present = None
                                                        self.is_tunnel_encap_present = None
                                                        self.l2tpv3_cookie = YList()
                                                        self.l2tpv3_cookie.parent = self
                                                        self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                        self.l2tpv3_session_id = None
                                                        self.label_index_attr = YList()
                                                        self.label_index_attr.parent = self
                                                        self.label_index_attr.name = 'label_index_attr'
                                                        self.local_preference = None
                                                        self.ls_attr = YList()
                                                        self.ls_attr.parent = self
                                                        self.ls_attr.name = 'ls_attr'
                                                        self.metric = None
                                                        self.neighbor_as = None
                                                        self.origin = None
                                                        self.originator = None
                                                        self.pe_distinguisher_label = YList()
                                                        self.pe_distinguisher_label.parent = self
                                                        self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.pmsi_type = None
                                                        self.pmsi_value = YList()
                                                        self.pmsi_value.parent = self
                                                        self.pmsi_value.name = 'pmsi_value'
                                                        self.ppm_pvalue = None
                                                        self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                        self.sr_policy_allocated_binding_sid.parent = self
                                                        self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                        self.sr_policy_binding_sid.parent = self
                                                        self.sr_policy_explicit_path = YList()
                                                        self.sr_policy_explicit_path.parent = self
                                                        self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                        self.sr_policy_preference = None
                                                        self.sr_tunnel_request_state = None
                                                        self.sr_tunnel_state = None
                                                        self.tunnel_encap_type = None
                                                        self.unknown_attribute = YList()
                                                        self.unknown_attribute.parent = self
                                                        self.unknown_attribute.name = 'unknown_attribute'


                                                    class SrPolicyBindingSid(object):
                                                        """
                                                        SR Policy Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                    class SrPolicyAllocatedBindingSid(object):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                    class Community(object):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                    class ExtendedCommunity(object):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                    class UnknownAttribute(object):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                    class Cluster(object):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                    class L2Tpv3Cookie(object):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                    class ConnectorValue(object):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                    class PmsiValue(object):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                    class LsAttr(object):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                    class LabelIndexAttr(object):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                    class PeDistinguisherLabel(object):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.label = None
                                                            self.pe_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.label is not None:
                                                                return True

                                                            if self.pe_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                    class SrPolicyExplicitPath(object):
                                                        """
                                                        SR Policy Explicit paths
                                                        
                                                        .. attribute:: sid
                                                        
                                                        	Sidlist for explicit path
                                                        	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of explicit path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.sid = YList()
                                                            self.sid.parent = self
                                                            self.sid.name = 'sid'
                                                            self.weight = None


                                                        class Sid(object):
                                                            """
                                                            Sidlist for explicit path
                                                            
                                                            .. attribute:: ipv4
                                                            
                                                            	IP Address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6
                                                            
                                                            	IPv6 address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label sid
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Sid Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4 = None
                                                                self.ipv6 = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4 is not None:
                                                                    return True

                                                                if self.ipv6 is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.sid is not None:
                                                                for child_ref in self.sid:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.weight is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.aggregator_address is not None:
                                                            return True

                                                        if self.aggregator_as is not None:
                                                            return True

                                                        if self.aigp_metric_value is not None:
                                                            return True

                                                        if self.as_path is not None:
                                                            return True

                                                        if self.cluster is not None:
                                                            for child_ref in self.cluster:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.community is not None:
                                                            for child_ref in self.community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.connector_type is not None:
                                                            return True

                                                        if self.connector_value is not None:
                                                            for child_ref in self.connector_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community is not None:
                                                            for child_ref in self.extended_community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community_flags is not None:
                                                            return True

                                                        if self.is_aggregator_present is not None:
                                                            return True

                                                        if self.is_aigp_present is not None:
                                                            return True

                                                        if self.is_as_path_present is not None:
                                                            return True

                                                        if self.is_atomic_aggregate_present is not None:
                                                            return True

                                                        if self.is_community_present is not None:
                                                            return True

                                                        if self.is_connector_present is not None:
                                                            return True

                                                        if self.is_extended_community_present is not None:
                                                            return True

                                                        if self.is_label_index_present is not None:
                                                            return True

                                                        if self.is_local_pref_present is not None:
                                                            return True

                                                        if self.is_ls_attribute_present is not None:
                                                            return True

                                                        if self.is_metric_present is not None:
                                                            return True

                                                        if self.is_origin_present is not None:
                                                            return True

                                                        if self.is_pe_distinguisher_label_present is not None:
                                                            return True

                                                        if self.is_pmsi_present is not None:
                                                            return True

                                                        if self.is_pppmp_present is not None:
                                                            return True

                                                        if self.is_ssa_present is not None:
                                                            return True

                                                        if self.is_tunnel_encap_present is not None:
                                                            return True

                                                        if self.l2tpv3_cookie is not None:
                                                            for child_ref in self.l2tpv3_cookie:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.l2tpv3_session_id is not None:
                                                            return True

                                                        if self.label_index_attr is not None:
                                                            for child_ref in self.label_index_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.local_preference is not None:
                                                            return True

                                                        if self.ls_attr is not None:
                                                            for child_ref in self.ls_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.metric is not None:
                                                            return True

                                                        if self.neighbor_as is not None:
                                                            return True

                                                        if self.origin is not None:
                                                            return True

                                                        if self.originator is not None:
                                                            return True

                                                        if self.pe_distinguisher_label is not None:
                                                            for child_ref in self.pe_distinguisher_label:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.pmsi_flags is not None:
                                                            return True

                                                        if self.pmsi_label is not None:
                                                            return True

                                                        if self.pmsi_type is not None:
                                                            return True

                                                        if self.pmsi_value is not None:
                                                            for child_ref in self.pmsi_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.ppm_pvalue is not None:
                                                            return True

                                                        if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_explicit_path is not None:
                                                            for child_ref in self.sr_policy_explicit_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.sr_policy_preference is not None:
                                                            return True

                                                        if self.sr_tunnel_request_state is not None:
                                                            return True

                                                        if self.sr_tunnel_state is not None:
                                                            return True

                                                        if self.tunnel_encap_type is not None:
                                                            return True

                                                        if self.unknown_attribute is not None:
                                                            for child_ref in self.unknown_attribute:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                                class RnhAddr(object):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.len = None
                                                        self.mac_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.len is not None:
                                                            return True

                                                        if self.mac_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                                class RibrnhIp(object):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.attr_set is not None and self.attr_set._has_data():
                                                        return True

                                                    if self.attribute_key_number is not None:
                                                        return True

                                                    if self.attribute_reuse_id_config is not None:
                                                        return True

                                                    if self.attribute_reuse_id_current is not None:
                                                        return True

                                                    if self.attribute_reuse_id_keys is not None:
                                                        return True

                                                    if self.attribute_reuse_id_max_id is not None:
                                                        return True

                                                    if self.attribute_reuse_id_node is not None:
                                                        return True

                                                    if self.attribute_reuse_id_recover_sec is not None:
                                                        return True

                                                    if self.common_attributes is not None and self.common_attributes._has_data():
                                                        return True

                                                    if self.is_application_gateway_present is not None:
                                                        return True

                                                    if self.is_as_path2_byte is not None:
                                                        return True

                                                    if self.is_attr_set_present is not None:
                                                        return True

                                                    if self.is_ribrnh_present is not None:
                                                        return True

                                                    if self.is_rnh_present is not None:
                                                        return True

                                                    if self.ribrnh_encap is not None:
                                                        return True

                                                    if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                        return True

                                                    if self.ribrnh_mac is not None:
                                                        return True

                                                    if self.ribrnh_table is not None:
                                                        return True

                                                    if self.ribrnh_vni is not None:
                                                        return True

                                                    if self.ribrnhip_table is not None:
                                                        return True

                                                    if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                        return True

                                                    if self.rnh_addr_len is not None:
                                                        return True

                                                    if self.rnh_len is not None:
                                                        return True

                                                    if self.rnh_type is not None:
                                                        return True

                                                    if self.set_aigp_inbound_igp is not None:
                                                        return True

                                                    if self.set_aigp_inbound_metric is not None:
                                                        return True

                                                    if self.vpn_distinguisher is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-process-instance-path'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.af_name is not None:
                                                    return True

                                                if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                    return True

                                                if self.label_fail is not None:
                                                    return True

                                                if self.label_o_or_version is not None:
                                                    return True

                                                if self.label_oor is not None:
                                                    return True

                                                if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                    return True

                                                if self.no_path is not None:
                                                    return True

                                                if self.path_information is not None and self.path_information._has_data():
                                                    return True

                                                if self.prefix_version is not None:
                                                    return True

                                                if self.process_instance_id is not None:
                                                    return True

                                                if self.route_distinguisher is not None:
                                                    return True

                                                if self.source_route_distinguisher is not None:
                                                    return True

                                                if self.source_vrf_name is not None:
                                                    return True

                                                if self.srcaf_name is not None:
                                                    return True

                                                if self.vrf_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath']['meta_info']


                                        class ActiveProcessInstancePath(object):
                                            """
                                            Active's paths for this net 
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: attributes_after_policy_in
                                            
                                            	Attributes after inbound policy applied
                                            	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn>`
                                            
                                            .. attribute:: label_fail
                                            
                                            	LSD label allocation failed 
                                            	**type**\:  bool
                                            
                                            .. attribute:: label_o_or_version
                                            
                                            	Label Version when OOR happens
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_oor
                                            
                                            	LSD label space is exhausted
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address_xr
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr>`
                                            
                                            .. attribute:: no_path
                                            
                                            	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                            	**type**\:  bool
                                            
                                            .. attribute:: path_information
                                            
                                            	Path information
                                            	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation>`
                                            
                                            .. attribute:: prefix_version
                                            
                                            	Version of BGP Prefix Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: process_instance_id
                                            
                                            	Process instance ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_route_distinguisher
                                            
                                            	Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_vrf_name
                                            
                                            	Name of the source VRF
                                            	**type**\:  str
                                            
                                            .. attribute:: srcaf_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.af_name = None
                                                self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn()
                                                self.attributes_after_policy_in.parent = self
                                                self.label_fail = None
                                                self.label_o_or_version = None
                                                self.label_oor = None
                                                self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr()
                                                self.neighbor_address_xr.parent = self
                                                self.no_path = None
                                                self.path_information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation()
                                                self.path_information.parent = self
                                                self.prefix_version = None
                                                self.process_instance_id = None
                                                self.route_distinguisher = None
                                                self.source_route_distinguisher = None
                                                self.source_vrf_name = None
                                                self.srcaf_name = None
                                                self.vrf_name = None


                                            class NeighborAddressXr(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr']['meta_info']


                                            class PathInformation(object):
                                                """
                                                Path information
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\:  bool
                                                
                                                .. attribute:: accept_own_self_originated_p_ath
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\:  bool
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\:  bool
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix>`
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\:  bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\:  bool
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr>`
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_esi
                                                
                                                	Path has EVPN ESI
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_rcvd_label
                                                
                                                	Path has received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\:  bool
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebg_ps
                                                
                                                	Not advertised to EBGPs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi>`
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress>`
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop>`
                                                
                                                .. attribute:: nhte_tunnel
                                                
                                                	NH TE tunnel information
                                                	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhteTunnel>`
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\:  bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.accept_own_path = None
                                                    self.accept_own_self_originated_p_ath = None
                                                    self.add_path_orr_bitfield = YList()
                                                    self.add_path_orr_bitfield.parent = self
                                                    self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                    self.advertisedto_pe = None
                                                    self.aigp_metric = None
                                                    self.best_path_comp_stage = None
                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self.best_path_id = None
                                                    self.best_path_id_comp_winner = None
                                                    self.best_path_orr_bitfield = YList()
                                                    self.best_path_orr_bitfield.parent = self
                                                    self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self.dampen_penalty = None
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.fspec_invalid_path = None
                                                    self.graceful_shutdown = None
                                                    self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self.halflife_time = None
                                                    self.has_esi = None
                                                    self.has_gw_addr = None
                                                    self.has_local_net_label = None
                                                    self.has_mdt_group_addr = None
                                                    self.has_mvpn_extcomm = None
                                                    self.has_mvpn_nbr_addr = None
                                                    self.has_mvpn_nexthop_addr = None
                                                    self.has_mvpn_pmsi = None
                                                    self.has_rcvd_label = None
                                                    self.has_second_label = None
                                                    self.ibgp_signaled_validity = None
                                                    self.igp_metric = None
                                                    self.is_aggregation_suppressed = None
                                                    self.is_as_best = None
                                                    self.is_best_path = None
                                                    self.is_import_dampened = None
                                                    self.is_import_suspect = None
                                                    self.is_internal_path = None
                                                    self.is_partial_best = None
                                                    self.is_path_additional_path = None
                                                    self.is_path_advertised_local_as_only = None
                                                    self.is_path_af_install_eligible = None
                                                    self.is_path_backup = None
                                                    self.is_path_backup_protect_multipath = None
                                                    self.is_path_best_external = None
                                                    self.is_path_damped = None
                                                    self.is_path_from_confederation_peer = None
                                                    self.is_path_from_network_command = None
                                                    self.is_path_from_redistribute_command = None
                                                    self.is_path_from_route_reflector = None
                                                    self.is_path_history_held = None
                                                    self.is_path_imp_candidate = None
                                                    self.is_path_imported = None
                                                    self.is_path_local_aggregate = None
                                                    self.is_path_locally_sourced = None
                                                    self.is_path_long_lived_stale = None
                                                    self.is_path_multipath = None
                                                    self.is_path_nexthop_discarded = None
                                                    self.is_path_not_advertised = None
                                                    self.is_path_not_advertised_to_ebg_ps = None
                                                    self.is_path_received_only = None
                                                    self.is_path_reoriginated = None
                                                    self.is_path_reoriginated_stitching = None
                                                    self.is_path_stale = None
                                                    self.is_path_synced_with_igp = None
                                                    self.is_path_valid = None
                                                    self.is_path_vpn_only = None
                                                    self.is_permanent_path = None
                                                    self.is_received_path_not_modified = None
                                                    self.is_spkr_as_best = None
                                                    self.l2vpn_circuit_status_value = YList()
                                                    self.l2vpn_circuit_status_value.parent = self
                                                    self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                    self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi()
                                                    self.l2vpn_evpn_esi.parent = self
                                                    self.l2vpn_size = None
                                                    self.labeled_unicast_safi_path = None
                                                    self.local_label = None
                                                    self.local_nh = None
                                                    self.local_path_id = None
                                                    self.local_peers_advertised_to = YList()
                                                    self.local_peers_advertised_to.parent = self
                                                    self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                    self.maximum_suppress_time = None
                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self.mvpn_path_flags = None
                                                    self.mvpn_pmsi_flags = None
                                                    self.mvpn_pmsi_label = None
                                                    self.mvpn_pmsi_type = None
                                                    self.mvpn_pmsi_value = YList()
                                                    self.mvpn_pmsi_value.parent = self
                                                    self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                    self.mvpn_sfs_path = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.neighbor_router_id = None
                                                    self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop()
                                                    self.next_hop.parent = self
                                                    self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhteTunnel()
                                                    self.nhte_tunnel.parent = self
                                                    self.path_flags = None
                                                    self.path_flap_count = None
                                                    self.path_import_flags = None
                                                    self.path_rt_set_id = None
                                                    self.path_rt_set_route_count = None
                                                    self.path_table_version = None
                                                    self.path_weight = None
                                                    self.pe_peers_advertised_to = YList()
                                                    self.pe_peers_advertised_to.parent = self
                                                    self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                    self.rcvd_label = None
                                                    self.rcvd_path_id = None
                                                    self.reuse_value = None
                                                    self.rib_failed = None
                                                    self.route_type = None
                                                    self.rpki_origin_as_validation_disabled = None
                                                    self.rt_set_limit_enabled = None
                                                    self.second_label = None
                                                    self.seconds_since_first_flap = None
                                                    self.show_rpki_origin_as_validity = None
                                                    self.sn_rpki_origin_as_validity = None
                                                    self.suppress_penalty = None
                                                    self.time_to_unsuppress = None


                                                class BgpPrefix(object):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self.prefix_length = None


                                                    class Prefix(object):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.prefix is not None and self.prefix._has_data():
                                                            return True

                                                        if self.prefix_length is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix']['meta_info']


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress']['meta_info']


                                                class NextHop(object):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop']['meta_info']


                                                class NhteTunnel(object):
                                                    """
                                                    NH TE tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_te_tunnel
                                                    
                                                    	NH TE Tunnel info is present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last rib update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	tunnel name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	tunnel type
                                                    	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.binding_label = None
                                                        self.has_te_tunnel = None
                                                        self.is_tunnel_info_stale = None
                                                        self.is_tunnel_registered = None
                                                        self.is_tunnel_up = None
                                                        self.last_tunnel_update = None
                                                        self.tunnel_if_handle = None
                                                        self.tunnel_name = None
                                                        self.tunnel_type = None
                                                        self.tunnel_v6_enabled = None
                                                        self.tunnel_v6_required = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.binding_label is not None:
                                                            return True

                                                        if self.has_te_tunnel is not None:
                                                            return True

                                                        if self.is_tunnel_info_stale is not None:
                                                            return True

                                                        if self.is_tunnel_registered is not None:
                                                            return True

                                                        if self.is_tunnel_up is not None:
                                                            return True

                                                        if self.last_tunnel_update is not None:
                                                            return True

                                                        if self.tunnel_if_handle is not None:
                                                            return True

                                                        if self.tunnel_name is not None:
                                                            return True

                                                        if self.tunnel_type is not None:
                                                            return True

                                                        if self.tunnel_v6_enabled is not None:
                                                            return True

                                                        if self.tunnel_v6_required is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhteTunnel']['meta_info']


                                                class MdtGroupAddr(object):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr']['meta_info']


                                                class L2VpnEvpnEsi(object):
                                                    """
                                                    L2VPN EVPN ESI
                                                    
                                                    .. attribute:: esi
                                                    
                                                    	esi
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.esi = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.esi is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi']['meta_info']


                                                class GwAddr(object):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.len = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.len is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr']['meta_info']


                                                class BestPathCompWinner(object):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner']['meta_info']


                                                class MvpnNbrAddr(object):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr']['meta_info']


                                                class MvpnNexthopAddr(object):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr']['meta_info']


                                                class L2VpnCircuitStatusValue(object):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                                class MvpnPmsiValue(object):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity']['meta_info']


                                                class LocalPeersAdvertisedTo(object):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                                class PePeersAdvertisedTo(object):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo']['meta_info']


                                                class BestPathOrrBitfield(object):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield']['meta_info']


                                                class AddPathOrrBitfield(object):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.accept_own_path is not None:
                                                        return True

                                                    if self.accept_own_self_originated_p_ath is not None:
                                                        return True

                                                    if self.add_path_orr_bitfield is not None:
                                                        for child_ref in self.add_path_orr_bitfield:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.advertisedto_pe is not None:
                                                        return True

                                                    if self.aigp_metric is not None:
                                                        return True

                                                    if self.best_path_comp_stage is not None:
                                                        return True

                                                    if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                        return True

                                                    if self.best_path_id is not None:
                                                        return True

                                                    if self.best_path_id_comp_winner is not None:
                                                        return True

                                                    if self.best_path_orr_bitfield is not None:
                                                        for child_ref in self.best_path_orr_bitfield:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                        return True

                                                    if self.dampen_penalty is not None:
                                                        return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.fspec_invalid_path is not None:
                                                        return True

                                                    if self.graceful_shutdown is not None:
                                                        return True

                                                    if self.gw_addr is not None and self.gw_addr._has_data():
                                                        return True

                                                    if self.halflife_time is not None:
                                                        return True

                                                    if self.has_esi is not None:
                                                        return True

                                                    if self.has_gw_addr is not None:
                                                        return True

                                                    if self.has_local_net_label is not None:
                                                        return True

                                                    if self.has_mdt_group_addr is not None:
                                                        return True

                                                    if self.has_mvpn_extcomm is not None:
                                                        return True

                                                    if self.has_mvpn_nbr_addr is not None:
                                                        return True

                                                    if self.has_mvpn_nexthop_addr is not None:
                                                        return True

                                                    if self.has_mvpn_pmsi is not None:
                                                        return True

                                                    if self.has_rcvd_label is not None:
                                                        return True

                                                    if self.has_second_label is not None:
                                                        return True

                                                    if self.ibgp_signaled_validity is not None:
                                                        return True

                                                    if self.igp_metric is not None:
                                                        return True

                                                    if self.is_aggregation_suppressed is not None:
                                                        return True

                                                    if self.is_as_best is not None:
                                                        return True

                                                    if self.is_best_path is not None:
                                                        return True

                                                    if self.is_import_dampened is not None:
                                                        return True

                                                    if self.is_import_suspect is not None:
                                                        return True

                                                    if self.is_internal_path is not None:
                                                        return True

                                                    if self.is_partial_best is not None:
                                                        return True

                                                    if self.is_path_additional_path is not None:
                                                        return True

                                                    if self.is_path_advertised_local_as_only is not None:
                                                        return True

                                                    if self.is_path_af_install_eligible is not None:
                                                        return True

                                                    if self.is_path_backup is not None:
                                                        return True

                                                    if self.is_path_backup_protect_multipath is not None:
                                                        return True

                                                    if self.is_path_best_external is not None:
                                                        return True

                                                    if self.is_path_damped is not None:
                                                        return True

                                                    if self.is_path_from_confederation_peer is not None:
                                                        return True

                                                    if self.is_path_from_network_command is not None:
                                                        return True

                                                    if self.is_path_from_redistribute_command is not None:
                                                        return True

                                                    if self.is_path_from_route_reflector is not None:
                                                        return True

                                                    if self.is_path_history_held is not None:
                                                        return True

                                                    if self.is_path_imp_candidate is not None:
                                                        return True

                                                    if self.is_path_imported is not None:
                                                        return True

                                                    if self.is_path_local_aggregate is not None:
                                                        return True

                                                    if self.is_path_locally_sourced is not None:
                                                        return True

                                                    if self.is_path_long_lived_stale is not None:
                                                        return True

                                                    if self.is_path_multipath is not None:
                                                        return True

                                                    if self.is_path_nexthop_discarded is not None:
                                                        return True

                                                    if self.is_path_not_advertised is not None:
                                                        return True

                                                    if self.is_path_not_advertised_to_ebg_ps is not None:
                                                        return True

                                                    if self.is_path_received_only is not None:
                                                        return True

                                                    if self.is_path_reoriginated is not None:
                                                        return True

                                                    if self.is_path_reoriginated_stitching is not None:
                                                        return True

                                                    if self.is_path_stale is not None:
                                                        return True

                                                    if self.is_path_synced_with_igp is not None:
                                                        return True

                                                    if self.is_path_valid is not None:
                                                        return True

                                                    if self.is_path_vpn_only is not None:
                                                        return True

                                                    if self.is_permanent_path is not None:
                                                        return True

                                                    if self.is_received_path_not_modified is not None:
                                                        return True

                                                    if self.is_spkr_as_best is not None:
                                                        return True

                                                    if self.l2vpn_circuit_status_value is not None:
                                                        for child_ref in self.l2vpn_circuit_status_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                        return True

                                                    if self.l2vpn_size is not None:
                                                        return True

                                                    if self.labeled_unicast_safi_path is not None:
                                                        return True

                                                    if self.local_label is not None:
                                                        return True

                                                    if self.local_nh is not None:
                                                        return True

                                                    if self.local_path_id is not None:
                                                        return True

                                                    if self.local_peers_advertised_to is not None:
                                                        for child_ref in self.local_peers_advertised_to:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.maximum_suppress_time is not None:
                                                        return True

                                                    if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                        return True

                                                    if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                        return True

                                                    if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                        return True

                                                    if self.mvpn_path_flags is not None:
                                                        return True

                                                    if self.mvpn_pmsi_flags is not None:
                                                        return True

                                                    if self.mvpn_pmsi_label is not None:
                                                        return True

                                                    if self.mvpn_pmsi_type is not None:
                                                        return True

                                                    if self.mvpn_pmsi_value is not None:
                                                        for child_ref in self.mvpn_pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.mvpn_sfs_path is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.neighbor_router_id is not None:
                                                        return True

                                                    if self.next_hop is not None and self.next_hop._has_data():
                                                        return True

                                                    if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                        return True

                                                    if self.path_flags is not None:
                                                        return True

                                                    if self.path_flap_count is not None:
                                                        return True

                                                    if self.path_import_flags is not None:
                                                        return True

                                                    if self.path_rt_set_id is not None:
                                                        return True

                                                    if self.path_rt_set_route_count is not None:
                                                        return True

                                                    if self.path_table_version is not None:
                                                        return True

                                                    if self.path_weight is not None:
                                                        return True

                                                    if self.pe_peers_advertised_to is not None:
                                                        for child_ref in self.pe_peers_advertised_to:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.rcvd_label is not None:
                                                        return True

                                                    if self.rcvd_path_id is not None:
                                                        return True

                                                    if self.reuse_value is not None:
                                                        return True

                                                    if self.rib_failed is not None:
                                                        return True

                                                    if self.route_type is not None:
                                                        return True

                                                    if self.rpki_origin_as_validation_disabled is not None:
                                                        return True

                                                    if self.rt_set_limit_enabled is not None:
                                                        return True

                                                    if self.second_label is not None:
                                                        return True

                                                    if self.seconds_since_first_flap is not None:
                                                        return True

                                                    if self.show_rpki_origin_as_validity is not None:
                                                        return True

                                                    if self.sn_rpki_origin_as_validity is not None:
                                                        return True

                                                    if self.suppress_penalty is not None:
                                                        return True

                                                    if self.time_to_unsuppress is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation']['meta_info']


                                            class AttributesAfterPolicyIn(object):
                                                """
                                                Attributes after inbound policy applied
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\:  bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\:  bool
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                    self.attr_set.parent = self
                                                    self.attribute_key_number = None
                                                    self.attribute_reuse_id_config = None
                                                    self.attribute_reuse_id_current = None
                                                    self.attribute_reuse_id_keys = None
                                                    self.attribute_reuse_id_max_id = None
                                                    self.attribute_reuse_id_node = None
                                                    self.attribute_reuse_id_recover_sec = None
                                                    self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self.is_application_gateway_present = None
                                                    self.is_as_path2_byte = None
                                                    self.is_attr_set_present = None
                                                    self.is_ribrnh_present = None
                                                    self.is_rnh_present = None
                                                    self.ribrnh_encap = None
                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self.ribrnh_mac = None
                                                    self.ribrnh_table = None
                                                    self.ribrnh_vni = None
                                                    self.ribrnhip_table = None
                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self.rnh_addr_len = None
                                                    self.rnh_len = None
                                                    self.rnh_type = None
                                                    self.set_aigp_inbound_igp = None
                                                    self.set_aigp_inbound_metric = None
                                                    self.vpn_distinguisher = None


                                                class CommonAttributes(object):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_encap_present
                                                    
                                                    	Tunnel Encap attribute present 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_policy_allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_binding_sid
                                                    
                                                    	SR Policy Binding sid
                                                    	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_explicit_path
                                                    
                                                    	SR Policy Explicit paths
                                                    	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                    
                                                    .. attribute:: sr_policy_preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_tunnel_request_state
                                                    
                                                    	SR Tunnel Request State
                                                    	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                    
                                                    .. attribute:: sr_tunnel_state
                                                    
                                                    	SR Tunnel State
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encap Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.aggregator_address = None
                                                        self.aggregator_as = None
                                                        self.aigp_metric_value = None
                                                        self.as_path = None
                                                        self.cluster = YList()
                                                        self.cluster.parent = self
                                                        self.cluster.name = 'cluster'
                                                        self.community = YList()
                                                        self.community.parent = self
                                                        self.community.name = 'community'
                                                        self.connector_type = None
                                                        self.connector_value = YList()
                                                        self.connector_value.parent = self
                                                        self.connector_value.name = 'connector_value'
                                                        self.extended_community = YList()
                                                        self.extended_community.parent = self
                                                        self.extended_community.name = 'extended_community'
                                                        self.extended_community_flags = None
                                                        self.is_aggregator_present = None
                                                        self.is_aigp_present = None
                                                        self.is_as_path_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_community_present = None
                                                        self.is_connector_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_label_index_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_metric_present = None
                                                        self.is_origin_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_ssa_present = None
                                                        self.is_tunnel_encap_present = None
                                                        self.l2tpv3_cookie = YList()
                                                        self.l2tpv3_cookie.parent = self
                                                        self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                        self.l2tpv3_session_id = None
                                                        self.label_index_attr = YList()
                                                        self.label_index_attr.parent = self
                                                        self.label_index_attr.name = 'label_index_attr'
                                                        self.local_preference = None
                                                        self.ls_attr = YList()
                                                        self.ls_attr.parent = self
                                                        self.ls_attr.name = 'ls_attr'
                                                        self.metric = None
                                                        self.neighbor_as = None
                                                        self.origin = None
                                                        self.originator = None
                                                        self.pe_distinguisher_label = YList()
                                                        self.pe_distinguisher_label.parent = self
                                                        self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.pmsi_type = None
                                                        self.pmsi_value = YList()
                                                        self.pmsi_value.parent = self
                                                        self.pmsi_value.name = 'pmsi_value'
                                                        self.ppm_pvalue = None
                                                        self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                        self.sr_policy_allocated_binding_sid.parent = self
                                                        self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                        self.sr_policy_binding_sid.parent = self
                                                        self.sr_policy_explicit_path = YList()
                                                        self.sr_policy_explicit_path.parent = self
                                                        self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                        self.sr_policy_preference = None
                                                        self.sr_tunnel_request_state = None
                                                        self.sr_tunnel_state = None
                                                        self.tunnel_encap_type = None
                                                        self.unknown_attribute = YList()
                                                        self.unknown_attribute.parent = self
                                                        self.unknown_attribute.name = 'unknown_attribute'


                                                    class SrPolicyBindingSid(object):
                                                        """
                                                        SR Policy Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                    class SrPolicyAllocatedBindingSid(object):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                    class Community(object):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                    class ExtendedCommunity(object):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                    class UnknownAttribute(object):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                    class Cluster(object):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                    class L2Tpv3Cookie(object):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                    class ConnectorValue(object):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                    class PmsiValue(object):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                    class LsAttr(object):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                    class LabelIndexAttr(object):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                    class PeDistinguisherLabel(object):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.label = None
                                                            self.pe_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.label is not None:
                                                                return True

                                                            if self.pe_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                    class SrPolicyExplicitPath(object):
                                                        """
                                                        SR Policy Explicit paths
                                                        
                                                        .. attribute:: sid
                                                        
                                                        	Sidlist for explicit path
                                                        	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of explicit path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.sid = YList()
                                                            self.sid.parent = self
                                                            self.sid.name = 'sid'
                                                            self.weight = None


                                                        class Sid(object):
                                                            """
                                                            Sidlist for explicit path
                                                            
                                                            .. attribute:: ipv4
                                                            
                                                            	IP Address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6
                                                            
                                                            	IPv6 address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label sid
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Sid Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4 = None
                                                                self.ipv6 = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4 is not None:
                                                                    return True

                                                                if self.ipv6 is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.sid is not None:
                                                                for child_ref in self.sid:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.weight is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.aggregator_address is not None:
                                                            return True

                                                        if self.aggregator_as is not None:
                                                            return True

                                                        if self.aigp_metric_value is not None:
                                                            return True

                                                        if self.as_path is not None:
                                                            return True

                                                        if self.cluster is not None:
                                                            for child_ref in self.cluster:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.community is not None:
                                                            for child_ref in self.community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.connector_type is not None:
                                                            return True

                                                        if self.connector_value is not None:
                                                            for child_ref in self.connector_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community is not None:
                                                            for child_ref in self.extended_community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community_flags is not None:
                                                            return True

                                                        if self.is_aggregator_present is not None:
                                                            return True

                                                        if self.is_aigp_present is not None:
                                                            return True

                                                        if self.is_as_path_present is not None:
                                                            return True

                                                        if self.is_atomic_aggregate_present is not None:
                                                            return True

                                                        if self.is_community_present is not None:
                                                            return True

                                                        if self.is_connector_present is not None:
                                                            return True

                                                        if self.is_extended_community_present is not None:
                                                            return True

                                                        if self.is_label_index_present is not None:
                                                            return True

                                                        if self.is_local_pref_present is not None:
                                                            return True

                                                        if self.is_ls_attribute_present is not None:
                                                            return True

                                                        if self.is_metric_present is not None:
                                                            return True

                                                        if self.is_origin_present is not None:
                                                            return True

                                                        if self.is_pe_distinguisher_label_present is not None:
                                                            return True

                                                        if self.is_pmsi_present is not None:
                                                            return True

                                                        if self.is_pppmp_present is not None:
                                                            return True

                                                        if self.is_ssa_present is not None:
                                                            return True

                                                        if self.is_tunnel_encap_present is not None:
                                                            return True

                                                        if self.l2tpv3_cookie is not None:
                                                            for child_ref in self.l2tpv3_cookie:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.l2tpv3_session_id is not None:
                                                            return True

                                                        if self.label_index_attr is not None:
                                                            for child_ref in self.label_index_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.local_preference is not None:
                                                            return True

                                                        if self.ls_attr is not None:
                                                            for child_ref in self.ls_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.metric is not None:
                                                            return True

                                                        if self.neighbor_as is not None:
                                                            return True

                                                        if self.origin is not None:
                                                            return True

                                                        if self.originator is not None:
                                                            return True

                                                        if self.pe_distinguisher_label is not None:
                                                            for child_ref in self.pe_distinguisher_label:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.pmsi_flags is not None:
                                                            return True

                                                        if self.pmsi_label is not None:
                                                            return True

                                                        if self.pmsi_type is not None:
                                                            return True

                                                        if self.pmsi_value is not None:
                                                            for child_ref in self.pmsi_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.ppm_pvalue is not None:
                                                            return True

                                                        if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_explicit_path is not None:
                                                            for child_ref in self.sr_policy_explicit_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.sr_policy_preference is not None:
                                                            return True

                                                        if self.sr_tunnel_request_state is not None:
                                                            return True

                                                        if self.sr_tunnel_state is not None:
                                                            return True

                                                        if self.tunnel_encap_type is not None:
                                                            return True

                                                        if self.unknown_attribute is not None:
                                                            for child_ref in self.unknown_attribute:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                                class AttrSet(object):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_encap_present
                                                    
                                                    	Tunnel Encap attribute present 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_policy_allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_binding_sid
                                                    
                                                    	SR Policy Binding sid
                                                    	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_explicit_path
                                                    
                                                    	SR Policy Explicit paths
                                                    	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                    
                                                    .. attribute:: sr_policy_preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_tunnel_request_state
                                                    
                                                    	SR Tunnel Request State
                                                    	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                    
                                                    .. attribute:: sr_tunnel_state
                                                    
                                                    	SR Tunnel State
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encap Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.aggregator_address = None
                                                        self.aggregator_as = None
                                                        self.aigp_metric_value = None
                                                        self.as_path = None
                                                        self.cluster = YList()
                                                        self.cluster.parent = self
                                                        self.cluster.name = 'cluster'
                                                        self.community = YList()
                                                        self.community.parent = self
                                                        self.community.name = 'community'
                                                        self.connector_type = None
                                                        self.connector_value = YList()
                                                        self.connector_value.parent = self
                                                        self.connector_value.name = 'connector_value'
                                                        self.extended_community = YList()
                                                        self.extended_community.parent = self
                                                        self.extended_community.name = 'extended_community'
                                                        self.extended_community_flags = None
                                                        self.is_aggregator_present = None
                                                        self.is_aigp_present = None
                                                        self.is_as_path_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_community_present = None
                                                        self.is_connector_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_label_index_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_metric_present = None
                                                        self.is_origin_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_ssa_present = None
                                                        self.is_tunnel_encap_present = None
                                                        self.l2tpv3_cookie = YList()
                                                        self.l2tpv3_cookie.parent = self
                                                        self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                        self.l2tpv3_session_id = None
                                                        self.label_index_attr = YList()
                                                        self.label_index_attr.parent = self
                                                        self.label_index_attr.name = 'label_index_attr'
                                                        self.local_preference = None
                                                        self.ls_attr = YList()
                                                        self.ls_attr.parent = self
                                                        self.ls_attr.name = 'ls_attr'
                                                        self.metric = None
                                                        self.neighbor_as = None
                                                        self.origin = None
                                                        self.originator = None
                                                        self.pe_distinguisher_label = YList()
                                                        self.pe_distinguisher_label.parent = self
                                                        self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.pmsi_type = None
                                                        self.pmsi_value = YList()
                                                        self.pmsi_value.parent = self
                                                        self.pmsi_value.name = 'pmsi_value'
                                                        self.ppm_pvalue = None
                                                        self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                        self.sr_policy_allocated_binding_sid.parent = self
                                                        self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                        self.sr_policy_binding_sid.parent = self
                                                        self.sr_policy_explicit_path = YList()
                                                        self.sr_policy_explicit_path.parent = self
                                                        self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                        self.sr_policy_preference = None
                                                        self.sr_tunnel_request_state = None
                                                        self.sr_tunnel_state = None
                                                        self.tunnel_encap_type = None
                                                        self.unknown_attribute = YList()
                                                        self.unknown_attribute.parent = self
                                                        self.unknown_attribute.name = 'unknown_attribute'


                                                    class SrPolicyBindingSid(object):
                                                        """
                                                        SR Policy Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                    class SrPolicyAllocatedBindingSid(object):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                    class Community(object):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                    class ExtendedCommunity(object):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                    class UnknownAttribute(object):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                    class Cluster(object):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                    class L2Tpv3Cookie(object):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                    class ConnectorValue(object):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                    class PmsiValue(object):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                    class LsAttr(object):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                    class LabelIndexAttr(object):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                    class PeDistinguisherLabel(object):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.label = None
                                                            self.pe_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.label is not None:
                                                                return True

                                                            if self.pe_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                    class SrPolicyExplicitPath(object):
                                                        """
                                                        SR Policy Explicit paths
                                                        
                                                        .. attribute:: sid
                                                        
                                                        	Sidlist for explicit path
                                                        	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of explicit path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.sid = YList()
                                                            self.sid.parent = self
                                                            self.sid.name = 'sid'
                                                            self.weight = None


                                                        class Sid(object):
                                                            """
                                                            Sidlist for explicit path
                                                            
                                                            .. attribute:: ipv4
                                                            
                                                            	IP Address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6
                                                            
                                                            	IPv6 address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label sid
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Sid Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4 = None
                                                                self.ipv6 = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4 is not None:
                                                                    return True

                                                                if self.ipv6 is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.sid is not None:
                                                                for child_ref in self.sid:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.weight is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.aggregator_address is not None:
                                                            return True

                                                        if self.aggregator_as is not None:
                                                            return True

                                                        if self.aigp_metric_value is not None:
                                                            return True

                                                        if self.as_path is not None:
                                                            return True

                                                        if self.cluster is not None:
                                                            for child_ref in self.cluster:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.community is not None:
                                                            for child_ref in self.community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.connector_type is not None:
                                                            return True

                                                        if self.connector_value is not None:
                                                            for child_ref in self.connector_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community is not None:
                                                            for child_ref in self.extended_community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community_flags is not None:
                                                            return True

                                                        if self.is_aggregator_present is not None:
                                                            return True

                                                        if self.is_aigp_present is not None:
                                                            return True

                                                        if self.is_as_path_present is not None:
                                                            return True

                                                        if self.is_atomic_aggregate_present is not None:
                                                            return True

                                                        if self.is_community_present is not None:
                                                            return True

                                                        if self.is_connector_present is not None:
                                                            return True

                                                        if self.is_extended_community_present is not None:
                                                            return True

                                                        if self.is_label_index_present is not None:
                                                            return True

                                                        if self.is_local_pref_present is not None:
                                                            return True

                                                        if self.is_ls_attribute_present is not None:
                                                            return True

                                                        if self.is_metric_present is not None:
                                                            return True

                                                        if self.is_origin_present is not None:
                                                            return True

                                                        if self.is_pe_distinguisher_label_present is not None:
                                                            return True

                                                        if self.is_pmsi_present is not None:
                                                            return True

                                                        if self.is_pppmp_present is not None:
                                                            return True

                                                        if self.is_ssa_present is not None:
                                                            return True

                                                        if self.is_tunnel_encap_present is not None:
                                                            return True

                                                        if self.l2tpv3_cookie is not None:
                                                            for child_ref in self.l2tpv3_cookie:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.l2tpv3_session_id is not None:
                                                            return True

                                                        if self.label_index_attr is not None:
                                                            for child_ref in self.label_index_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.local_preference is not None:
                                                            return True

                                                        if self.ls_attr is not None:
                                                            for child_ref in self.ls_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.metric is not None:
                                                            return True

                                                        if self.neighbor_as is not None:
                                                            return True

                                                        if self.origin is not None:
                                                            return True

                                                        if self.originator is not None:
                                                            return True

                                                        if self.pe_distinguisher_label is not None:
                                                            for child_ref in self.pe_distinguisher_label:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.pmsi_flags is not None:
                                                            return True

                                                        if self.pmsi_label is not None:
                                                            return True

                                                        if self.pmsi_type is not None:
                                                            return True

                                                        if self.pmsi_value is not None:
                                                            for child_ref in self.pmsi_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.ppm_pvalue is not None:
                                                            return True

                                                        if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_explicit_path is not None:
                                                            for child_ref in self.sr_policy_explicit_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.sr_policy_preference is not None:
                                                            return True

                                                        if self.sr_tunnel_request_state is not None:
                                                            return True

                                                        if self.sr_tunnel_state is not None:
                                                            return True

                                                        if self.tunnel_encap_type is not None:
                                                            return True

                                                        if self.unknown_attribute is not None:
                                                            for child_ref in self.unknown_attribute:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                                class RnhAddr(object):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.len = None
                                                        self.mac_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.len is not None:
                                                            return True

                                                        if self.mac_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                                class RibrnhIp(object):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.attr_set is not None and self.attr_set._has_data():
                                                        return True

                                                    if self.attribute_key_number is not None:
                                                        return True

                                                    if self.attribute_reuse_id_config is not None:
                                                        return True

                                                    if self.attribute_reuse_id_current is not None:
                                                        return True

                                                    if self.attribute_reuse_id_keys is not None:
                                                        return True

                                                    if self.attribute_reuse_id_max_id is not None:
                                                        return True

                                                    if self.attribute_reuse_id_node is not None:
                                                        return True

                                                    if self.attribute_reuse_id_recover_sec is not None:
                                                        return True

                                                    if self.common_attributes is not None and self.common_attributes._has_data():
                                                        return True

                                                    if self.is_application_gateway_present is not None:
                                                        return True

                                                    if self.is_as_path2_byte is not None:
                                                        return True

                                                    if self.is_attr_set_present is not None:
                                                        return True

                                                    if self.is_ribrnh_present is not None:
                                                        return True

                                                    if self.is_rnh_present is not None:
                                                        return True

                                                    if self.ribrnh_encap is not None:
                                                        return True

                                                    if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                        return True

                                                    if self.ribrnh_mac is not None:
                                                        return True

                                                    if self.ribrnh_table is not None:
                                                        return True

                                                    if self.ribrnh_vni is not None:
                                                        return True

                                                    if self.ribrnhip_table is not None:
                                                        return True

                                                    if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                        return True

                                                    if self.rnh_addr_len is not None:
                                                        return True

                                                    if self.rnh_len is not None:
                                                        return True

                                                    if self.rnh_type is not None:
                                                        return True

                                                    if self.set_aigp_inbound_igp is not None:
                                                        return True

                                                    if self.set_aigp_inbound_metric is not None:
                                                        return True

                                                    if self.vpn_distinguisher is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-process-instance-path'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.af_name is not None:
                                                    return True

                                                if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                    return True

                                                if self.label_fail is not None:
                                                    return True

                                                if self.label_o_or_version is not None:
                                                    return True

                                                if self.label_oor is not None:
                                                    return True

                                                if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                    return True

                                                if self.no_path is not None:
                                                    return True

                                                if self.path_information is not None and self.path_information._has_data():
                                                    return True

                                                if self.prefix_version is not None:
                                                    return True

                                                if self.process_instance_id is not None:
                                                    return True

                                                if self.route_distinguisher is not None:
                                                    return True

                                                if self.source_route_distinguisher is not None:
                                                    return True

                                                if self.source_vrf_name is not None:
                                                    return True

                                                if self.srcaf_name is not None:
                                                    return True

                                                if self.vrf_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath']['meta_info']


                                        class LocalPathElement(object):
                                            """
                                            Local path element list
                                            
                                            .. attribute:: is_perm_path_pelem
                                            
                                            	Pelem for permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.NhteTunnel>`
                                            
                                            .. attribute:: pelem_flags
                                            
                                            	Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_gw_metric
                                            
                                            	Gateway metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_addpath_table_attr_version
                                            
                                            	No\-addpath Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_bestpath_table_attr_version
                                            
                                            	No\-bestpath Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_flags
                                            
                                            	Path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pelem_path_id
                                            
                                            	Local Path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_neighbor_addr
                                            
                                            	Path neighbor address
                                            	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr>`
                                            
                                            .. attribute:: pelem_path_nexthop
                                            
                                            	Path nexthop address
                                            	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop>`
                                            
                                            .. attribute:: pelem_path_peer_path_id
                                            
                                            	Path peer path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_table_attr_version
                                            
                                            	Path Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_table_attr_version
                                            
                                            	Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_version
                                            
                                            	Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_perm_path_pelem = None
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.pelem_flags = None
                                                self.pelem_gw_metric = None
                                                self.pelem_no_addpath_table_attr_version = None
                                                self.pelem_no_bestpath_table_attr_version = None
                                                self.pelem_path_flags = None
                                                self.pelem_path_id = None
                                                self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr()
                                                self.pelem_path_neighbor_addr.parent = self
                                                self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop()
                                                self.pelem_path_nexthop.parent = self
                                                self.pelem_path_peer_path_id = None
                                                self.pelem_path_table_attr_version = None
                                                self.pelem_table_attr_version = None
                                                self.pelem_version = None


                                            class PelemPathNexthop(object):
                                                """
                                                Path nexthop address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-nexthop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.NhteTunnel']['meta_info']


                                            class PelemPathNeighborAddr(object):
                                                """
                                                Path neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-neighbor-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-path-element'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_perm_path_pelem is not None:
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.pelem_flags is not None:
                                                    return True

                                                if self.pelem_gw_metric is not None:
                                                    return True

                                                if self.pelem_no_addpath_table_attr_version is not None:
                                                    return True

                                                if self.pelem_no_bestpath_table_attr_version is not None:
                                                    return True

                                                if self.pelem_path_flags is not None:
                                                    return True

                                                if self.pelem_path_id is not None:
                                                    return True

                                                if self.pelem_path_neighbor_addr is not None and self.pelem_path_neighbor_addr._has_data():
                                                    return True

                                                if self.pelem_path_nexthop is not None and self.pelem_path_nexthop._has_data():
                                                    return True

                                                if self.pelem_path_peer_path_id is not None:
                                                    return True

                                                if self.pelem_path_table_attr_version is not None:
                                                    return True

                                                if self.pelem_table_attr_version is not None:
                                                    return True

                                                if self.pelem_version is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement']['meta_info']


                                        class ActivePathElement(object):
                                            """
                                            Path element list received from Active inst
                                            
                                            .. attribute:: is_perm_path_pelem
                                            
                                            	Pelem for permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.NhteTunnel>`
                                            
                                            .. attribute:: pelem_flags
                                            
                                            	Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_gw_metric
                                            
                                            	Gateway metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_addpath_table_attr_version
                                            
                                            	No\-addpath Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_bestpath_table_attr_version
                                            
                                            	No\-bestpath Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_flags
                                            
                                            	Path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pelem_path_id
                                            
                                            	Local Path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_neighbor_addr
                                            
                                            	Path neighbor address
                                            	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr>`
                                            
                                            .. attribute:: pelem_path_nexthop
                                            
                                            	Path nexthop address
                                            	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop>`
                                            
                                            .. attribute:: pelem_path_peer_path_id
                                            
                                            	Path peer path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_table_attr_version
                                            
                                            	Path Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_table_attr_version
                                            
                                            	Table Attr version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_version
                                            
                                            	Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_perm_path_pelem = None
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.pelem_flags = None
                                                self.pelem_gw_metric = None
                                                self.pelem_no_addpath_table_attr_version = None
                                                self.pelem_no_bestpath_table_attr_version = None
                                                self.pelem_path_flags = None
                                                self.pelem_path_id = None
                                                self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr()
                                                self.pelem_path_neighbor_addr.parent = self
                                                self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop()
                                                self.pelem_path_nexthop.parent = self
                                                self.pelem_path_peer_path_id = None
                                                self.pelem_path_table_attr_version = None
                                                self.pelem_table_attr_version = None
                                                self.pelem_version = None


                                            class PelemPathNexthop(object):
                                                """
                                                Path nexthop address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-nexthop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.NhteTunnel']['meta_info']


                                            class PelemPathNeighborAddr(object):
                                                """
                                                Path neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-neighbor-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-path-element'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_perm_path_pelem is not None:
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.pelem_flags is not None:
                                                    return True

                                                if self.pelem_gw_metric is not None:
                                                    return True

                                                if self.pelem_no_addpath_table_attr_version is not None:
                                                    return True

                                                if self.pelem_no_bestpath_table_attr_version is not None:
                                                    return True

                                                if self.pelem_path_flags is not None:
                                                    return True

                                                if self.pelem_path_id is not None:
                                                    return True

                                                if self.pelem_path_neighbor_addr is not None and self.pelem_path_neighbor_addr._has_data():
                                                    return True

                                                if self.pelem_path_nexthop is not None and self.pelem_path_nexthop._has_data():
                                                    return True

                                                if self.pelem_path_peer_path_id is not None:
                                                    return True

                                                if self.pelem_path_table_attr_version is not None:
                                                    return True

                                                if self.pelem_table_attr_version is not None:
                                                    return True

                                                if self.pelem_version is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.active_path_element is not None:
                                                for child_ref in self.active_path_element:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.active_process_instance_path is not None:
                                                for child_ref in self.active_process_instance_path:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.add_path_orr_bitfield is not None:
                                                for child_ref in self.add_path_orr_bitfield:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.advertisedto_pe is not None:
                                                return True

                                            if self.af_name is not None:
                                                return True

                                            if self.best_path_orr_bitfield is not None:
                                                for child_ref in self.best_path_orr_bitfield:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                return True

                                            if self.bit is not None:
                                                return True

                                            if self.flags is not None:
                                                return True

                                            if self.gateway_array is not None:
                                                return True

                                            if self.has_inconsistent_paths is not None:
                                                return True

                                            if self.has_lbl_retained is not None:
                                                return True

                                            if self.has_local_label is not None:
                                                return True

                                            if self.is_net_aggregation_suppressed is not None:
                                                return True

                                            if self.is_net_ldp_signaled is not None:
                                                return True

                                            if self.is_permanent_network is not None:
                                                return True

                                            if self.local_path_element is not None:
                                                for child_ref in self.local_path_element:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.local_peers_advertised_to is not None:
                                                for child_ref in self.local_peers_advertised_to:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.local_process_instance_path is not None:
                                                for child_ref in self.local_process_instance_path:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.net_backup_available is not None:
                                                return True

                                            if self.net_backup_label_rewrite_available is not None:
                                                return True

                                            if self.net_eibgp_multipath is not None:
                                                return True

                                            if self.net_extended_flags is not None:
                                                return True

                                            if self.net_flags is not None:
                                                return True

                                            if self.net_local_label is not None:
                                                return True

                                            if self.net_local_label_rewrite is not None:
                                                return True

                                            if self.net_local_label_srgb is not None:
                                                return True

                                            if self.net_multipath is not None:
                                                return True

                                            if self.network is not None:
                                                return True

                                            if self.num_of_path is not None:
                                                return True

                                            if self.pe_peers_advertised_to is not None:
                                                for child_ref in self.pe_peers_advertised_to:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.process_instance_id is not None:
                                                return True

                                            if self.rd is not None:
                                                return True

                                            if self.resilient_nexthop_set is not None:
                                                return True

                                            if self.rib_failed is not None:
                                                return True

                                            if self.route_distinguisher is not None:
                                                return True

                                            if self.table_brib_version is not None:
                                                return True

                                            if self.table_version is not None:
                                                return True

                                            if self.version is not None:
                                                return True

                                            if self.version_age is not None and self.version_age._has_data():
                                                return True

                                            if self.version_timestamp is not None and self.version_timestamp._has_data():
                                                return True

                                            if self.vrf_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:networks'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.network is not None:
                                            for child_ref in self.network:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks']['meta_info']


                                class PathTable(object):
                                    """
                                    The BGP Path Table
                                    
                                    .. attribute:: path
                                    
                                    	A BGP path table entry
                                    	**type**\: list of    :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.path = YList()
                                        self.path.parent = self
                                        self.path.name = 'path'


                                    class Path(object):
                                        """
                                        A BGP path table entry
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor adddress
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr>`
                                        
                                        .. attribute:: network
                                        
                                        	Network Prefix in Hex format
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_id
                                        
                                        	Received Path ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type
                                        	**type**\:   :py:class:`BgpRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRouteEnum>`
                                        
                                        .. attribute:: source_rd
                                        
                                        	Source Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self.label_fail = None
                                            self.label_o_or_version = None
                                            self.label_oor = None
                                            self.neighbor_address = None
                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self.network = None
                                            self.no_path = None
                                            self.path_id = None
                                            self.path_information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation()
                                            self.path_information.parent = self
                                            self.prefix_length = None
                                            self.prefix_version = None
                                            self.process_instance_id = None
                                            self.rd = None
                                            self.route_distinguisher = None
                                            self.route_type = None
                                            self.source_rd = None
                                            self.source_route_distinguisher = None
                                            self.source_vrf_name = None
                                            self.srcaf_name = None
                                            self.vrf_name = None


                                        class NeighborAddressXr(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.NeighborAddressXr']['meta_info']


                                        class PathInformation(object):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_esi
                                            
                                            	Path has EVPN ESI
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_rcvd_label
                                            
                                            	Path has received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebg_ps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.L2VpnEvpnEsi>`
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop>`
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhteTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_p_ath = None
                                                self.add_path_orr_bitfield = YList()
                                                self.add_path_orr_bitfield.parent = self
                                                self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                self.advertisedto_pe = None
                                                self.aigp_metric = None
                                                self.best_path_comp_stage = None
                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self.best_path_id = None
                                                self.best_path_id_comp_winner = None
                                                self.best_path_orr_bitfield = YList()
                                                self.best_path_orr_bitfield.parent = self
                                                self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self.dampen_penalty = None
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.fspec_invalid_path = None
                                                self.graceful_shutdown = None
                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self.halflife_time = None
                                                self.has_esi = None
                                                self.has_gw_addr = None
                                                self.has_local_net_label = None
                                                self.has_mdt_group_addr = None
                                                self.has_mvpn_extcomm = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.has_rcvd_label = None
                                                self.has_second_label = None
                                                self.ibgp_signaled_validity = None
                                                self.igp_metric = None
                                                self.is_aggregation_suppressed = None
                                                self.is_as_best = None
                                                self.is_best_path = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_internal_path = None
                                                self.is_partial_best = None
                                                self.is_path_additional_path = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_af_install_eligible = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_damped = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_history_held = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_imported = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_multipath = None
                                                self.is_path_nexthop_discarded = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebg_ps = None
                                                self.is_path_received_only = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_stale = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_valid = None
                                                self.is_path_vpn_only = None
                                                self.is_permanent_path = None
                                                self.is_received_path_not_modified = None
                                                self.is_spkr_as_best = None
                                                self.l2vpn_circuit_status_value = YList()
                                                self.l2vpn_circuit_status_value.parent = self
                                                self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.L2VpnEvpnEsi()
                                                self.l2vpn_evpn_esi.parent = self
                                                self.l2vpn_size = None
                                                self.labeled_unicast_safi_path = None
                                                self.local_label = None
                                                self.local_nh = None
                                                self.local_path_id = None
                                                self.local_peers_advertised_to = YList()
                                                self.local_peers_advertised_to.parent = self
                                                self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                self.maximum_suppress_time = None
                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self.mvpn_path_flags = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_value = YList()
                                                self.mvpn_pmsi_value.parent = self
                                                self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                self.mvpn_sfs_path = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.neighbor_router_id = None
                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.path_flags = None
                                                self.path_flap_count = None
                                                self.path_import_flags = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.path_table_version = None
                                                self.path_weight = None
                                                self.pe_peers_advertised_to = YList()
                                                self.pe_peers_advertised_to.parent = self
                                                self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                self.rcvd_label = None
                                                self.rcvd_path_id = None
                                                self.reuse_value = None
                                                self.rib_failed = None
                                                self.route_type = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.rt_set_limit_enabled = None
                                                self.second_label = None
                                                self.seconds_since_first_flap = None
                                                self.show_rpki_origin_as_validity = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.suppress_penalty = None
                                                self.time_to_unsuppress = None


                                            class BgpPrefix(object):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self.prefix_length = None


                                                class Prefix(object):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.prefix is not None and self.prefix._has_data():
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix']['meta_info']


                                            class NeighborAddress(object):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress']['meta_info']


                                            class NextHop(object):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhteTunnel']['meta_info']


                                            class MdtGroupAddr(object):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr']['meta_info']


                                            class L2VpnEvpnEsi(object):
                                                """
                                                L2VPN EVPN ESI
                                                
                                                .. attribute:: esi
                                                
                                                	esi
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.esi = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.esi is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.L2VpnEvpnEsi']['meta_info']


                                            class GwAddr(object):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.GwAddr']['meta_info']


                                            class BestPathCompWinner(object):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner']['meta_info']


                                            class MvpnNbrAddr(object):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr']['meta_info']


                                            class MvpnNexthopAddr(object):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr']['meta_info']


                                            class L2VpnCircuitStatusValue(object):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                            class MvpnPmsiValue(object):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity']['meta_info']


                                            class LocalPeersAdvertisedTo(object):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                            class PePeersAdvertisedTo(object):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo']['meta_info']


                                            class BestPathOrrBitfield(object):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield']['meta_info']


                                            class AddPathOrrBitfield(object):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.accept_own_path is not None:
                                                    return True

                                                if self.accept_own_self_originated_p_ath is not None:
                                                    return True

                                                if self.add_path_orr_bitfield is not None:
                                                    for child_ref in self.add_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.advertisedto_pe is not None:
                                                    return True

                                                if self.aigp_metric is not None:
                                                    return True

                                                if self.best_path_comp_stage is not None:
                                                    return True

                                                if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                    return True

                                                if self.best_path_id is not None:
                                                    return True

                                                if self.best_path_id_comp_winner is not None:
                                                    return True

                                                if self.best_path_orr_bitfield is not None:
                                                    for child_ref in self.best_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                    return True

                                                if self.dampen_penalty is not None:
                                                    return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.fspec_invalid_path is not None:
                                                    return True

                                                if self.graceful_shutdown is not None:
                                                    return True

                                                if self.gw_addr is not None and self.gw_addr._has_data():
                                                    return True

                                                if self.halflife_time is not None:
                                                    return True

                                                if self.has_esi is not None:
                                                    return True

                                                if self.has_gw_addr is not None:
                                                    return True

                                                if self.has_local_net_label is not None:
                                                    return True

                                                if self.has_mdt_group_addr is not None:
                                                    return True

                                                if self.has_mvpn_extcomm is not None:
                                                    return True

                                                if self.has_mvpn_nbr_addr is not None:
                                                    return True

                                                if self.has_mvpn_nexthop_addr is not None:
                                                    return True

                                                if self.has_mvpn_pmsi is not None:
                                                    return True

                                                if self.has_rcvd_label is not None:
                                                    return True

                                                if self.has_second_label is not None:
                                                    return True

                                                if self.ibgp_signaled_validity is not None:
                                                    return True

                                                if self.igp_metric is not None:
                                                    return True

                                                if self.is_aggregation_suppressed is not None:
                                                    return True

                                                if self.is_as_best is not None:
                                                    return True

                                                if self.is_best_path is not None:
                                                    return True

                                                if self.is_import_dampened is not None:
                                                    return True

                                                if self.is_import_suspect is not None:
                                                    return True

                                                if self.is_internal_path is not None:
                                                    return True

                                                if self.is_partial_best is not None:
                                                    return True

                                                if self.is_path_additional_path is not None:
                                                    return True

                                                if self.is_path_advertised_local_as_only is not None:
                                                    return True

                                                if self.is_path_af_install_eligible is not None:
                                                    return True

                                                if self.is_path_backup is not None:
                                                    return True

                                                if self.is_path_backup_protect_multipath is not None:
                                                    return True

                                                if self.is_path_best_external is not None:
                                                    return True

                                                if self.is_path_damped is not None:
                                                    return True

                                                if self.is_path_from_confederation_peer is not None:
                                                    return True

                                                if self.is_path_from_network_command is not None:
                                                    return True

                                                if self.is_path_from_redistribute_command is not None:
                                                    return True

                                                if self.is_path_from_route_reflector is not None:
                                                    return True

                                                if self.is_path_history_held is not None:
                                                    return True

                                                if self.is_path_imp_candidate is not None:
                                                    return True

                                                if self.is_path_imported is not None:
                                                    return True

                                                if self.is_path_local_aggregate is not None:
                                                    return True

                                                if self.is_path_locally_sourced is not None:
                                                    return True

                                                if self.is_path_long_lived_stale is not None:
                                                    return True

                                                if self.is_path_multipath is not None:
                                                    return True

                                                if self.is_path_nexthop_discarded is not None:
                                                    return True

                                                if self.is_path_not_advertised is not None:
                                                    return True

                                                if self.is_path_not_advertised_to_ebg_ps is not None:
                                                    return True

                                                if self.is_path_received_only is not None:
                                                    return True

                                                if self.is_path_reoriginated is not None:
                                                    return True

                                                if self.is_path_reoriginated_stitching is not None:
                                                    return True

                                                if self.is_path_stale is not None:
                                                    return True

                                                if self.is_path_synced_with_igp is not None:
                                                    return True

                                                if self.is_path_valid is not None:
                                                    return True

                                                if self.is_path_vpn_only is not None:
                                                    return True

                                                if self.is_permanent_path is not None:
                                                    return True

                                                if self.is_received_path_not_modified is not None:
                                                    return True

                                                if self.is_spkr_as_best is not None:
                                                    return True

                                                if self.l2vpn_circuit_status_value is not None:
                                                    for child_ref in self.l2vpn_circuit_status_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                    return True

                                                if self.l2vpn_size is not None:
                                                    return True

                                                if self.labeled_unicast_safi_path is not None:
                                                    return True

                                                if self.local_label is not None:
                                                    return True

                                                if self.local_nh is not None:
                                                    return True

                                                if self.local_path_id is not None:
                                                    return True

                                                if self.local_peers_advertised_to is not None:
                                                    for child_ref in self.local_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.maximum_suppress_time is not None:
                                                    return True

                                                if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                    return True

                                                if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                    return True

                                                if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                    return True

                                                if self.mvpn_path_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_label is not None:
                                                    return True

                                                if self.mvpn_pmsi_type is not None:
                                                    return True

                                                if self.mvpn_pmsi_value is not None:
                                                    for child_ref in self.mvpn_pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.mvpn_sfs_path is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.neighbor_router_id is not None:
                                                    return True

                                                if self.next_hop is not None and self.next_hop._has_data():
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.path_flags is not None:
                                                    return True

                                                if self.path_flap_count is not None:
                                                    return True

                                                if self.path_import_flags is not None:
                                                    return True

                                                if self.path_rt_set_id is not None:
                                                    return True

                                                if self.path_rt_set_route_count is not None:
                                                    return True

                                                if self.path_table_version is not None:
                                                    return True

                                                if self.path_weight is not None:
                                                    return True

                                                if self.pe_peers_advertised_to is not None:
                                                    for child_ref in self.pe_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.rcvd_label is not None:
                                                    return True

                                                if self.rcvd_path_id is not None:
                                                    return True

                                                if self.reuse_value is not None:
                                                    return True

                                                if self.rib_failed is not None:
                                                    return True

                                                if self.route_type is not None:
                                                    return True

                                                if self.rpki_origin_as_validation_disabled is not None:
                                                    return True

                                                if self.rt_set_limit_enabled is not None:
                                                    return True

                                                if self.second_label is not None:
                                                    return True

                                                if self.seconds_since_first_flap is not None:
                                                    return True

                                                if self.show_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.sn_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.suppress_penalty is not None:
                                                    return True

                                                if self.time_to_unsuppress is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation']['meta_info']


                                        class AttributesAfterPolicyIn(object):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self.is_application_gateway_present = None
                                                self.is_as_path2_byte = None
                                                self.is_attr_set_present = None
                                                self.is_ribrnh_present = None
                                                self.is_rnh_present = None
                                                self.ribrnh_encap = None
                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self.ribrnh_mac = None
                                                self.ribrnh_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnhip_table = None
                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self.rnh_addr_len = None
                                                self.rnh_len = None
                                                self.rnh_type = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.vpn_distinguisher = None


                                            class CommonAttributes(object):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                            class AttrSet(object):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                            class RnhAddr(object):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None
                                                    self.mac_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    if self.mac_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                            class RibrnhIp(object):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.attr_set is not None and self.attr_set._has_data():
                                                    return True

                                                if self.attribute_key_number is not None:
                                                    return True

                                                if self.attribute_reuse_id_config is not None:
                                                    return True

                                                if self.attribute_reuse_id_current is not None:
                                                    return True

                                                if self.attribute_reuse_id_keys is not None:
                                                    return True

                                                if self.attribute_reuse_id_max_id is not None:
                                                    return True

                                                if self.attribute_reuse_id_node is not None:
                                                    return True

                                                if self.attribute_reuse_id_recover_sec is not None:
                                                    return True

                                                if self.common_attributes is not None and self.common_attributes._has_data():
                                                    return True

                                                if self.is_application_gateway_present is not None:
                                                    return True

                                                if self.is_as_path2_byte is not None:
                                                    return True

                                                if self.is_attr_set_present is not None:
                                                    return True

                                                if self.is_ribrnh_present is not None:
                                                    return True

                                                if self.is_rnh_present is not None:
                                                    return True

                                                if self.ribrnh_encap is not None:
                                                    return True

                                                if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                    return True

                                                if self.ribrnh_mac is not None:
                                                    return True

                                                if self.ribrnh_table is not None:
                                                    return True

                                                if self.ribrnh_vni is not None:
                                                    return True

                                                if self.ribrnhip_table is not None:
                                                    return True

                                                if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                    return True

                                                if self.rnh_addr_len is not None:
                                                    return True

                                                if self.rnh_len is not None:
                                                    return True

                                                if self.rnh_type is not None:
                                                    return True

                                                if self.set_aigp_inbound_igp is not None:
                                                    return True

                                                if self.set_aigp_inbound_metric is not None:
                                                    return True

                                                if self.vpn_distinguisher is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                return True

                                            if self.label_fail is not None:
                                                return True

                                            if self.label_o_or_version is not None:
                                                return True

                                            if self.label_oor is not None:
                                                return True

                                            if self.neighbor_address is not None:
                                                return True

                                            if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                return True

                                            if self.network is not None:
                                                return True

                                            if self.no_path is not None:
                                                return True

                                            if self.path_id is not None:
                                                return True

                                            if self.path_information is not None and self.path_information._has_data():
                                                return True

                                            if self.prefix_length is not None:
                                                return True

                                            if self.prefix_version is not None:
                                                return True

                                            if self.process_instance_id is not None:
                                                return True

                                            if self.rd is not None:
                                                return True

                                            if self.route_distinguisher is not None:
                                                return True

                                            if self.route_type is not None:
                                                return True

                                            if self.source_rd is not None:
                                                return True

                                            if self.source_route_distinguisher is not None:
                                                return True

                                            if self.source_vrf_name is not None:
                                                return True

                                            if self.srcaf_name is not None:
                                                return True

                                            if self.vrf_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-table'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.path is not None:
                                            for child_ref in self.path:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable']['meta_info']


                                class Epes(object):
                                    """
                                    The BGP Egress Engineering table
                                    
                                    .. attribute:: epe
                                    
                                    	A BGP Egress Engineering table entry
                                    	**type**\: list of    :py:class:`Epe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.epe = YList()
                                        self.epe.parent = self
                                        self.epe.name = 'epe'


                                    class Epe(object):
                                        """
                                        A BGP Egress Engineering table entry
                                        
                                        .. attribute:: epe_flags
                                        
                                        	EPE object's flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: epe_key
                                        
                                        	Key of EPE object
                                        	**type**\: list of    :py:class:`EpeKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeKey>`
                                        
                                        .. attribute:: epe_key_length
                                        
                                        	Epe Key Length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: epe_key_length_xr
                                        
                                        	EPE key length in bits
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: epe_local_address
                                        
                                        	Local address
                                        	**type**\:   :py:class:`EpeLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress>`
                                        
                                        .. attribute:: epe_local_asn
                                        
                                        	Local AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_local_router_id
                                        
                                        	Local router id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_next_hop
                                        
                                        	Nexthop address
                                        	**type**\:   :py:class:`EpeNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop>`
                                        
                                        .. attribute:: epe_remote_asn
                                        
                                        	Remote AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_remote_router_id
                                        
                                        	Remote router id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_set_key
                                        
                                        	Epe Set Key
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: epe_version
                                        
                                        	EPE object's version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: first_hop
                                        
                                        	List of firsthops of EPE
                                        	**type**\: list of    :py:class:`FirstHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop>`
                                        
                                        .. attribute:: ifhandle
                                        
                                        	List of ifhandle of EPE
                                        	**type**\: list of    :py:class:`Ifhandle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.Ifhandle>`
                                        
                                        .. attribute:: label
                                        
                                        	Label assigned to the RPCnext\-hop set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nexthop_id
                                        
                                        	List of nexthop ID of EPE
                                        	**type**\: list of    :py:class:`NexthopId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.NexthopId>`
                                        
                                        .. attribute:: ref_count
                                        
                                        	Refcount
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.epe_flags = None
                                            self.epe_key = YList()
                                            self.epe_key.parent = self
                                            self.epe_key.name = 'epe_key'
                                            self.epe_key_length = None
                                            self.epe_key_length_xr = None
                                            self.epe_local_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress()
                                            self.epe_local_address.parent = self
                                            self.epe_local_asn = None
                                            self.epe_local_router_id = None
                                            self.epe_next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop()
                                            self.epe_next_hop.parent = self
                                            self.epe_remote_asn = None
                                            self.epe_remote_router_id = None
                                            self.epe_set_key = None
                                            self.epe_version = None
                                            self.first_hop = YList()
                                            self.first_hop.parent = self
                                            self.first_hop.name = 'first_hop'
                                            self.ifhandle = YList()
                                            self.ifhandle.parent = self
                                            self.ifhandle.name = 'ifhandle'
                                            self.label = None
                                            self.nexthop_id = YList()
                                            self.nexthop_id.parent = self
                                            self.nexthop_id.name = 'nexthop_id'
                                            self.ref_count = None


                                        class EpeLocalAddress(object):
                                            """
                                            Local address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:epe-local-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress']['meta_info']


                                        class EpeNextHop(object):
                                            """
                                            Nexthop address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:epe-next-hop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop']['meta_info']


                                        class EpeKey(object):
                                            """
                                            Key of EPE object
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:epe-key'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeKey']['meta_info']


                                        class NexthopId(object):
                                            """
                                            List of nexthop ID of EPE
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-id'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.NexthopId']['meta_info']


                                        class Ifhandle(object):
                                            """
                                            List of ifhandle of EPE
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ifhandle'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.Ifhandle']['meta_info']


                                        class FirstHop(object):
                                            """
                                            List of firsthops of EPE
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-hop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:epe'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.epe_flags is not None:
                                                return True

                                            if self.epe_key is not None:
                                                for child_ref in self.epe_key:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.epe_key_length is not None:
                                                return True

                                            if self.epe_key_length_xr is not None:
                                                return True

                                            if self.epe_local_address is not None and self.epe_local_address._has_data():
                                                return True

                                            if self.epe_local_asn is not None:
                                                return True

                                            if self.epe_local_router_id is not None:
                                                return True

                                            if self.epe_next_hop is not None and self.epe_next_hop._has_data():
                                                return True

                                            if self.epe_remote_asn is not None:
                                                return True

                                            if self.epe_remote_router_id is not None:
                                                return True

                                            if self.epe_set_key is not None:
                                                return True

                                            if self.epe_version is not None:
                                                return True

                                            if self.first_hop is not None:
                                                for child_ref in self.first_hop:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.ifhandle is not None:
                                                for child_ref in self.ifhandle:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.label is not None:
                                                return True

                                            if self.nexthop_id is not None:
                                                for child_ref in self.nexthop_id:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.ref_count is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:epes'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.epe is not None:
                                            for child_ref in self.epe:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes']['meta_info']


                                class AdvertisedPathCounts(object):
                                    """
                                    The BGP Advertised paths table (bestpath)
                                    
                                    .. attribute:: advertised_path_count
                                    
                                    	The BGP Advertised path table Count (bestpath)
                                    	**type**\: list of    :py:class:`AdvertisedPathCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.advertised_path_count = YList()
                                        self.advertised_path_count.parent = self
                                        self.advertised_path_count.name = 'advertised_path_count'


                                    class AdvertisedPathCount(object):
                                        """
                                        The BGP Advertised path table Count
                                        (bestpath)
                                        
                                        .. attribute:: neighbor_address  <key>
                                        
                                        	Neighbor address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: max_prefix_advertisedcount
                                        
                                        	Number of prefixes advertsied to neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.neighbor_address = None
                                            self.max_prefix_advertisedcount = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')
                                            if self.neighbor_address is None:
                                                raise YPYModelError('Key property neighbor_address is None')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertised-path-count[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address = ' + str(self.neighbor_address) + ']'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.neighbor_address is not None:
                                                return True

                                            if self.max_prefix_advertisedcount is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertised-path-counts'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.advertised_path_count is not None:
                                            for child_ref in self.advertised_path_count:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts']['meta_info']


                                class PathLabeledTable(object):
                                    """
                                    The BGP Path Labeled Table
                                    
                                    .. attribute:: path
                                    
                                    	A BGP path table entry
                                    	**type**\: list of    :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.path = YList()
                                        self.path.parent = self
                                        self.path.name = 'path'


                                    class Path(object):
                                        """
                                        A BGP path table entry
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor adddress
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr>`
                                        
                                        .. attribute:: network
                                        
                                        	Network Prefix in Hex format
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_id
                                        
                                        	Received Path ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type
                                        	**type**\:   :py:class:`BgpRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRouteEnum>`
                                        
                                        .. attribute:: source_rd
                                        
                                        	Source Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self.label_fail = None
                                            self.label_o_or_version = None
                                            self.label_oor = None
                                            self.neighbor_address = None
                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self.network = None
                                            self.no_path = None
                                            self.path_id = None
                                            self.path_information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation()
                                            self.path_information.parent = self
                                            self.prefix_length = None
                                            self.prefix_version = None
                                            self.process_instance_id = None
                                            self.rd = None
                                            self.route_distinguisher = None
                                            self.route_type = None
                                            self.source_rd = None
                                            self.source_route_distinguisher = None
                                            self.source_vrf_name = None
                                            self.srcaf_name = None
                                            self.vrf_name = None


                                        class NeighborAddressXr(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr']['meta_info']


                                        class PathInformation(object):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_esi
                                            
                                            	Path has EVPN ESI
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_rcvd_label
                                            
                                            	Path has received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebg_ps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2VpnEvpnEsi>`
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop>`
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhteTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_p_ath = None
                                                self.add_path_orr_bitfield = YList()
                                                self.add_path_orr_bitfield.parent = self
                                                self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                self.advertisedto_pe = None
                                                self.aigp_metric = None
                                                self.best_path_comp_stage = None
                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self.best_path_id = None
                                                self.best_path_id_comp_winner = None
                                                self.best_path_orr_bitfield = YList()
                                                self.best_path_orr_bitfield.parent = self
                                                self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self.dampen_penalty = None
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.fspec_invalid_path = None
                                                self.graceful_shutdown = None
                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self.halflife_time = None
                                                self.has_esi = None
                                                self.has_gw_addr = None
                                                self.has_local_net_label = None
                                                self.has_mdt_group_addr = None
                                                self.has_mvpn_extcomm = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.has_rcvd_label = None
                                                self.has_second_label = None
                                                self.ibgp_signaled_validity = None
                                                self.igp_metric = None
                                                self.is_aggregation_suppressed = None
                                                self.is_as_best = None
                                                self.is_best_path = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_internal_path = None
                                                self.is_partial_best = None
                                                self.is_path_additional_path = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_af_install_eligible = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_damped = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_history_held = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_imported = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_multipath = None
                                                self.is_path_nexthop_discarded = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebg_ps = None
                                                self.is_path_received_only = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_stale = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_valid = None
                                                self.is_path_vpn_only = None
                                                self.is_permanent_path = None
                                                self.is_received_path_not_modified = None
                                                self.is_spkr_as_best = None
                                                self.l2vpn_circuit_status_value = YList()
                                                self.l2vpn_circuit_status_value.parent = self
                                                self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2VpnEvpnEsi()
                                                self.l2vpn_evpn_esi.parent = self
                                                self.l2vpn_size = None
                                                self.labeled_unicast_safi_path = None
                                                self.local_label = None
                                                self.local_nh = None
                                                self.local_path_id = None
                                                self.local_peers_advertised_to = YList()
                                                self.local_peers_advertised_to.parent = self
                                                self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                self.maximum_suppress_time = None
                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self.mvpn_path_flags = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_value = YList()
                                                self.mvpn_pmsi_value.parent = self
                                                self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                self.mvpn_sfs_path = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.neighbor_router_id = None
                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.path_flags = None
                                                self.path_flap_count = None
                                                self.path_import_flags = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.path_table_version = None
                                                self.path_weight = None
                                                self.pe_peers_advertised_to = YList()
                                                self.pe_peers_advertised_to.parent = self
                                                self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                self.rcvd_label = None
                                                self.rcvd_path_id = None
                                                self.reuse_value = None
                                                self.rib_failed = None
                                                self.route_type = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.rt_set_limit_enabled = None
                                                self.second_label = None
                                                self.seconds_since_first_flap = None
                                                self.show_rpki_origin_as_validity = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.suppress_penalty = None
                                                self.time_to_unsuppress = None


                                            class BgpPrefix(object):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self.prefix_length = None


                                                class Prefix(object):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.prefix is not None and self.prefix._has_data():
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix']['meta_info']


                                            class NeighborAddress(object):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress']['meta_info']


                                            class NextHop(object):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhteTunnel']['meta_info']


                                            class MdtGroupAddr(object):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr']['meta_info']


                                            class L2VpnEvpnEsi(object):
                                                """
                                                L2VPN EVPN ESI
                                                
                                                .. attribute:: esi
                                                
                                                	esi
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.esi = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.esi is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2VpnEvpnEsi']['meta_info']


                                            class GwAddr(object):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr']['meta_info']


                                            class BestPathCompWinner(object):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner']['meta_info']


                                            class MvpnNbrAddr(object):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr']['meta_info']


                                            class MvpnNexthopAddr(object):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr']['meta_info']


                                            class L2VpnCircuitStatusValue(object):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                            class MvpnPmsiValue(object):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity']['meta_info']


                                            class LocalPeersAdvertisedTo(object):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                            class PePeersAdvertisedTo(object):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo']['meta_info']


                                            class BestPathOrrBitfield(object):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield']['meta_info']


                                            class AddPathOrrBitfield(object):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.accept_own_path is not None:
                                                    return True

                                                if self.accept_own_self_originated_p_ath is not None:
                                                    return True

                                                if self.add_path_orr_bitfield is not None:
                                                    for child_ref in self.add_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.advertisedto_pe is not None:
                                                    return True

                                                if self.aigp_metric is not None:
                                                    return True

                                                if self.best_path_comp_stage is not None:
                                                    return True

                                                if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                    return True

                                                if self.best_path_id is not None:
                                                    return True

                                                if self.best_path_id_comp_winner is not None:
                                                    return True

                                                if self.best_path_orr_bitfield is not None:
                                                    for child_ref in self.best_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                    return True

                                                if self.dampen_penalty is not None:
                                                    return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.fspec_invalid_path is not None:
                                                    return True

                                                if self.graceful_shutdown is not None:
                                                    return True

                                                if self.gw_addr is not None and self.gw_addr._has_data():
                                                    return True

                                                if self.halflife_time is not None:
                                                    return True

                                                if self.has_esi is not None:
                                                    return True

                                                if self.has_gw_addr is not None:
                                                    return True

                                                if self.has_local_net_label is not None:
                                                    return True

                                                if self.has_mdt_group_addr is not None:
                                                    return True

                                                if self.has_mvpn_extcomm is not None:
                                                    return True

                                                if self.has_mvpn_nbr_addr is not None:
                                                    return True

                                                if self.has_mvpn_nexthop_addr is not None:
                                                    return True

                                                if self.has_mvpn_pmsi is not None:
                                                    return True

                                                if self.has_rcvd_label is not None:
                                                    return True

                                                if self.has_second_label is not None:
                                                    return True

                                                if self.ibgp_signaled_validity is not None:
                                                    return True

                                                if self.igp_metric is not None:
                                                    return True

                                                if self.is_aggregation_suppressed is not None:
                                                    return True

                                                if self.is_as_best is not None:
                                                    return True

                                                if self.is_best_path is not None:
                                                    return True

                                                if self.is_import_dampened is not None:
                                                    return True

                                                if self.is_import_suspect is not None:
                                                    return True

                                                if self.is_internal_path is not None:
                                                    return True

                                                if self.is_partial_best is not None:
                                                    return True

                                                if self.is_path_additional_path is not None:
                                                    return True

                                                if self.is_path_advertised_local_as_only is not None:
                                                    return True

                                                if self.is_path_af_install_eligible is not None:
                                                    return True

                                                if self.is_path_backup is not None:
                                                    return True

                                                if self.is_path_backup_protect_multipath is not None:
                                                    return True

                                                if self.is_path_best_external is not None:
                                                    return True

                                                if self.is_path_damped is not None:
                                                    return True

                                                if self.is_path_from_confederation_peer is not None:
                                                    return True

                                                if self.is_path_from_network_command is not None:
                                                    return True

                                                if self.is_path_from_redistribute_command is not None:
                                                    return True

                                                if self.is_path_from_route_reflector is not None:
                                                    return True

                                                if self.is_path_history_held is not None:
                                                    return True

                                                if self.is_path_imp_candidate is not None:
                                                    return True

                                                if self.is_path_imported is not None:
                                                    return True

                                                if self.is_path_local_aggregate is not None:
                                                    return True

                                                if self.is_path_locally_sourced is not None:
                                                    return True

                                                if self.is_path_long_lived_stale is not None:
                                                    return True

                                                if self.is_path_multipath is not None:
                                                    return True

                                                if self.is_path_nexthop_discarded is not None:
                                                    return True

                                                if self.is_path_not_advertised is not None:
                                                    return True

                                                if self.is_path_not_advertised_to_ebg_ps is not None:
                                                    return True

                                                if self.is_path_received_only is not None:
                                                    return True

                                                if self.is_path_reoriginated is not None:
                                                    return True

                                                if self.is_path_reoriginated_stitching is not None:
                                                    return True

                                                if self.is_path_stale is not None:
                                                    return True

                                                if self.is_path_synced_with_igp is not None:
                                                    return True

                                                if self.is_path_valid is not None:
                                                    return True

                                                if self.is_path_vpn_only is not None:
                                                    return True

                                                if self.is_permanent_path is not None:
                                                    return True

                                                if self.is_received_path_not_modified is not None:
                                                    return True

                                                if self.is_spkr_as_best is not None:
                                                    return True

                                                if self.l2vpn_circuit_status_value is not None:
                                                    for child_ref in self.l2vpn_circuit_status_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                    return True

                                                if self.l2vpn_size is not None:
                                                    return True

                                                if self.labeled_unicast_safi_path is not None:
                                                    return True

                                                if self.local_label is not None:
                                                    return True

                                                if self.local_nh is not None:
                                                    return True

                                                if self.local_path_id is not None:
                                                    return True

                                                if self.local_peers_advertised_to is not None:
                                                    for child_ref in self.local_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.maximum_suppress_time is not None:
                                                    return True

                                                if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                    return True

                                                if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                    return True

                                                if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                    return True

                                                if self.mvpn_path_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_label is not None:
                                                    return True

                                                if self.mvpn_pmsi_type is not None:
                                                    return True

                                                if self.mvpn_pmsi_value is not None:
                                                    for child_ref in self.mvpn_pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.mvpn_sfs_path is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.neighbor_router_id is not None:
                                                    return True

                                                if self.next_hop is not None and self.next_hop._has_data():
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.path_flags is not None:
                                                    return True

                                                if self.path_flap_count is not None:
                                                    return True

                                                if self.path_import_flags is not None:
                                                    return True

                                                if self.path_rt_set_id is not None:
                                                    return True

                                                if self.path_rt_set_route_count is not None:
                                                    return True

                                                if self.path_table_version is not None:
                                                    return True

                                                if self.path_weight is not None:
                                                    return True

                                                if self.pe_peers_advertised_to is not None:
                                                    for child_ref in self.pe_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.rcvd_label is not None:
                                                    return True

                                                if self.rcvd_path_id is not None:
                                                    return True

                                                if self.reuse_value is not None:
                                                    return True

                                                if self.rib_failed is not None:
                                                    return True

                                                if self.route_type is not None:
                                                    return True

                                                if self.rpki_origin_as_validation_disabled is not None:
                                                    return True

                                                if self.rt_set_limit_enabled is not None:
                                                    return True

                                                if self.second_label is not None:
                                                    return True

                                                if self.seconds_since_first_flap is not None:
                                                    return True

                                                if self.show_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.sn_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.suppress_penalty is not None:
                                                    return True

                                                if self.time_to_unsuppress is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation']['meta_info']


                                        class AttributesAfterPolicyIn(object):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self.is_application_gateway_present = None
                                                self.is_as_path2_byte = None
                                                self.is_attr_set_present = None
                                                self.is_ribrnh_present = None
                                                self.is_rnh_present = None
                                                self.ribrnh_encap = None
                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self.ribrnh_mac = None
                                                self.ribrnh_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnhip_table = None
                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self.rnh_addr_len = None
                                                self.rnh_len = None
                                                self.rnh_type = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.vpn_distinguisher = None


                                            class CommonAttributes(object):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                            class AttrSet(object):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                            class RnhAddr(object):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None
                                                    self.mac_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    if self.mac_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                            class RibrnhIp(object):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.attr_set is not None and self.attr_set._has_data():
                                                    return True

                                                if self.attribute_key_number is not None:
                                                    return True

                                                if self.attribute_reuse_id_config is not None:
                                                    return True

                                                if self.attribute_reuse_id_current is not None:
                                                    return True

                                                if self.attribute_reuse_id_keys is not None:
                                                    return True

                                                if self.attribute_reuse_id_max_id is not None:
                                                    return True

                                                if self.attribute_reuse_id_node is not None:
                                                    return True

                                                if self.attribute_reuse_id_recover_sec is not None:
                                                    return True

                                                if self.common_attributes is not None and self.common_attributes._has_data():
                                                    return True

                                                if self.is_application_gateway_present is not None:
                                                    return True

                                                if self.is_as_path2_byte is not None:
                                                    return True

                                                if self.is_attr_set_present is not None:
                                                    return True

                                                if self.is_ribrnh_present is not None:
                                                    return True

                                                if self.is_rnh_present is not None:
                                                    return True

                                                if self.ribrnh_encap is not None:
                                                    return True

                                                if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                    return True

                                                if self.ribrnh_mac is not None:
                                                    return True

                                                if self.ribrnh_table is not None:
                                                    return True

                                                if self.ribrnh_vni is not None:
                                                    return True

                                                if self.ribrnhip_table is not None:
                                                    return True

                                                if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                    return True

                                                if self.rnh_addr_len is not None:
                                                    return True

                                                if self.rnh_len is not None:
                                                    return True

                                                if self.rnh_type is not None:
                                                    return True

                                                if self.set_aigp_inbound_igp is not None:
                                                    return True

                                                if self.set_aigp_inbound_metric is not None:
                                                    return True

                                                if self.vpn_distinguisher is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                return True

                                            if self.label_fail is not None:
                                                return True

                                            if self.label_o_or_version is not None:
                                                return True

                                            if self.label_oor is not None:
                                                return True

                                            if self.neighbor_address is not None:
                                                return True

                                            if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                return True

                                            if self.network is not None:
                                                return True

                                            if self.no_path is not None:
                                                return True

                                            if self.path_id is not None:
                                                return True

                                            if self.path_information is not None and self.path_information._has_data():
                                                return True

                                            if self.prefix_length is not None:
                                                return True

                                            if self.prefix_version is not None:
                                                return True

                                            if self.process_instance_id is not None:
                                                return True

                                            if self.rd is not None:
                                                return True

                                            if self.route_distinguisher is not None:
                                                return True

                                            if self.route_type is not None:
                                                return True

                                            if self.source_rd is not None:
                                                return True

                                            if self.source_route_distinguisher is not None:
                                                return True

                                            if self.source_vrf_name is not None:
                                                return True

                                            if self.srcaf_name is not None:
                                                return True

                                            if self.vrf_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-labeled-table'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.path is not None:
                                            for child_ref in self.path:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable']['meta_info']


                                class AdvertisedPaths(object):
                                    """
                                    The BGP Advertised paths table (add\-paths)
                                    
                                    .. attribute:: advertised_path
                                    
                                    	A BGP Advertised paths table entry (add\-paths)
                                    	**type**\: list of    :py:class:`AdvertisedPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.advertised_path = YList()
                                        self.advertised_path.parent = self
                                        self.advertised_path.name = 'advertised_path'


                                    class AdvertisedPath(object):
                                        """
                                        A BGP Advertised paths table entry
                                        (add\-paths)
                                        
                                        .. attribute:: adv_path_info
                                        
                                        	Net Advertized Paths
                                        	**type**\: list of    :py:class:`AdvPathInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo>`
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor 
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: network
                                        
                                        	Network in hex string bytes format
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: paths
                                        
                                        	paths
                                        	**type**\: list of    :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix length
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.adv_path_info = YList()
                                            self.adv_path_info.parent = self
                                            self.adv_path_info.name = 'adv_path_info'
                                            self.neighbor_address = None
                                            self.network = None
                                            self.paths = YList()
                                            self.paths.parent = self
                                            self.paths.name = 'paths'
                                            self.prefix_length = None
                                            self.rd = None


                                        class Paths(object):
                                            """
                                            paths
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: attributes_after_policy_in
                                            
                                            	Attributes after inbound policy applied
                                            	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn>`
                                            
                                            .. attribute:: label_fail
                                            
                                            	LSD label allocation failed 
                                            	**type**\:  bool
                                            
                                            .. attribute:: label_o_or_version
                                            
                                            	Label Version when OOR happens
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_oor
                                            
                                            	LSD label space is exhausted
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address_xr
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr>`
                                            
                                            .. attribute:: no_path
                                            
                                            	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                            	**type**\:  bool
                                            
                                            .. attribute:: path_information
                                            
                                            	Path information
                                            	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation>`
                                            
                                            .. attribute:: prefix_version
                                            
                                            	Version of BGP Prefix Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: process_instance_id
                                            
                                            	Process instance ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_route_distinguisher
                                            
                                            	Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_vrf_name
                                            
                                            	Name of the source VRF
                                            	**type**\:  str
                                            
                                            .. attribute:: srcaf_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.af_name = None
                                                self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn()
                                                self.attributes_after_policy_in.parent = self
                                                self.label_fail = None
                                                self.label_o_or_version = None
                                                self.label_oor = None
                                                self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr()
                                                self.neighbor_address_xr.parent = self
                                                self.no_path = None
                                                self.path_information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation()
                                                self.path_information.parent = self
                                                self.prefix_version = None
                                                self.process_instance_id = None
                                                self.route_distinguisher = None
                                                self.source_route_distinguisher = None
                                                self.source_vrf_name = None
                                                self.srcaf_name = None
                                                self.vrf_name = None


                                            class NeighborAddressXr(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr']['meta_info']


                                            class PathInformation(object):
                                                """
                                                Path information
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\:  bool
                                                
                                                .. attribute:: accept_own_self_originated_p_ath
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\:  bool
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield>`
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\:  bool
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner>`
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield>`
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix>`
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity>`
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\:  bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\:  bool
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr>`
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_esi
                                                
                                                	Path has EVPN ESI
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_rcvd_label
                                                
                                                	Path has received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\:  bool
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebg_ps
                                                
                                                	Not advertised to EBGPs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2VpnCircuitStatusValue>`
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2VpnEvpnEsi>`
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr>`
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue>`
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress>`
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop>`
                                                
                                                .. attribute:: nhte_tunnel
                                                
                                                	NH TE tunnel information
                                                	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhteTunnel>`
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\:  bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.accept_own_path = None
                                                    self.accept_own_self_originated_p_ath = None
                                                    self.add_path_orr_bitfield = YList()
                                                    self.add_path_orr_bitfield.parent = self
                                                    self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                    self.advertisedto_pe = None
                                                    self.aigp_metric = None
                                                    self.best_path_comp_stage = None
                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self.best_path_id = None
                                                    self.best_path_id_comp_winner = None
                                                    self.best_path_orr_bitfield = YList()
                                                    self.best_path_orr_bitfield.parent = self
                                                    self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self.dampen_penalty = None
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.fspec_invalid_path = None
                                                    self.graceful_shutdown = None
                                                    self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self.halflife_time = None
                                                    self.has_esi = None
                                                    self.has_gw_addr = None
                                                    self.has_local_net_label = None
                                                    self.has_mdt_group_addr = None
                                                    self.has_mvpn_extcomm = None
                                                    self.has_mvpn_nbr_addr = None
                                                    self.has_mvpn_nexthop_addr = None
                                                    self.has_mvpn_pmsi = None
                                                    self.has_rcvd_label = None
                                                    self.has_second_label = None
                                                    self.ibgp_signaled_validity = None
                                                    self.igp_metric = None
                                                    self.is_aggregation_suppressed = None
                                                    self.is_as_best = None
                                                    self.is_best_path = None
                                                    self.is_import_dampened = None
                                                    self.is_import_suspect = None
                                                    self.is_internal_path = None
                                                    self.is_partial_best = None
                                                    self.is_path_additional_path = None
                                                    self.is_path_advertised_local_as_only = None
                                                    self.is_path_af_install_eligible = None
                                                    self.is_path_backup = None
                                                    self.is_path_backup_protect_multipath = None
                                                    self.is_path_best_external = None
                                                    self.is_path_damped = None
                                                    self.is_path_from_confederation_peer = None
                                                    self.is_path_from_network_command = None
                                                    self.is_path_from_redistribute_command = None
                                                    self.is_path_from_route_reflector = None
                                                    self.is_path_history_held = None
                                                    self.is_path_imp_candidate = None
                                                    self.is_path_imported = None
                                                    self.is_path_local_aggregate = None
                                                    self.is_path_locally_sourced = None
                                                    self.is_path_long_lived_stale = None
                                                    self.is_path_multipath = None
                                                    self.is_path_nexthop_discarded = None
                                                    self.is_path_not_advertised = None
                                                    self.is_path_not_advertised_to_ebg_ps = None
                                                    self.is_path_received_only = None
                                                    self.is_path_reoriginated = None
                                                    self.is_path_reoriginated_stitching = None
                                                    self.is_path_stale = None
                                                    self.is_path_synced_with_igp = None
                                                    self.is_path_valid = None
                                                    self.is_path_vpn_only = None
                                                    self.is_permanent_path = None
                                                    self.is_received_path_not_modified = None
                                                    self.is_spkr_as_best = None
                                                    self.l2vpn_circuit_status_value = YList()
                                                    self.l2vpn_circuit_status_value.parent = self
                                                    self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                    self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2VpnEvpnEsi()
                                                    self.l2vpn_evpn_esi.parent = self
                                                    self.l2vpn_size = None
                                                    self.labeled_unicast_safi_path = None
                                                    self.local_label = None
                                                    self.local_nh = None
                                                    self.local_path_id = None
                                                    self.local_peers_advertised_to = YList()
                                                    self.local_peers_advertised_to.parent = self
                                                    self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                    self.maximum_suppress_time = None
                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self.mvpn_path_flags = None
                                                    self.mvpn_pmsi_flags = None
                                                    self.mvpn_pmsi_label = None
                                                    self.mvpn_pmsi_type = None
                                                    self.mvpn_pmsi_value = YList()
                                                    self.mvpn_pmsi_value.parent = self
                                                    self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                    self.mvpn_sfs_path = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.neighbor_router_id = None
                                                    self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop()
                                                    self.next_hop.parent = self
                                                    self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhteTunnel()
                                                    self.nhte_tunnel.parent = self
                                                    self.path_flags = None
                                                    self.path_flap_count = None
                                                    self.path_import_flags = None
                                                    self.path_rt_set_id = None
                                                    self.path_rt_set_route_count = None
                                                    self.path_table_version = None
                                                    self.path_weight = None
                                                    self.pe_peers_advertised_to = YList()
                                                    self.pe_peers_advertised_to.parent = self
                                                    self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                    self.rcvd_label = None
                                                    self.rcvd_path_id = None
                                                    self.reuse_value = None
                                                    self.rib_failed = None
                                                    self.route_type = None
                                                    self.rpki_origin_as_validation_disabled = None
                                                    self.rt_set_limit_enabled = None
                                                    self.second_label = None
                                                    self.seconds_since_first_flap = None
                                                    self.show_rpki_origin_as_validity = None
                                                    self.sn_rpki_origin_as_validity = None
                                                    self.suppress_penalty = None
                                                    self.time_to_unsuppress = None


                                                class BgpPrefix(object):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self.prefix_length = None


                                                    class Prefix(object):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.prefix is not None and self.prefix._has_data():
                                                            return True

                                                        if self.prefix_length is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix']['meta_info']


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress']['meta_info']


                                                class NextHop(object):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop']['meta_info']


                                                class NhteTunnel(object):
                                                    """
                                                    NH TE tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_te_tunnel
                                                    
                                                    	NH TE Tunnel info is present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last rib update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	tunnel name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	tunnel type
                                                    	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.binding_label = None
                                                        self.has_te_tunnel = None
                                                        self.is_tunnel_info_stale = None
                                                        self.is_tunnel_registered = None
                                                        self.is_tunnel_up = None
                                                        self.last_tunnel_update = None
                                                        self.tunnel_if_handle = None
                                                        self.tunnel_name = None
                                                        self.tunnel_type = None
                                                        self.tunnel_v6_enabled = None
                                                        self.tunnel_v6_required = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.binding_label is not None:
                                                            return True

                                                        if self.has_te_tunnel is not None:
                                                            return True

                                                        if self.is_tunnel_info_stale is not None:
                                                            return True

                                                        if self.is_tunnel_registered is not None:
                                                            return True

                                                        if self.is_tunnel_up is not None:
                                                            return True

                                                        if self.last_tunnel_update is not None:
                                                            return True

                                                        if self.tunnel_if_handle is not None:
                                                            return True

                                                        if self.tunnel_name is not None:
                                                            return True

                                                        if self.tunnel_type is not None:
                                                            return True

                                                        if self.tunnel_v6_enabled is not None:
                                                            return True

                                                        if self.tunnel_v6_required is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhteTunnel']['meta_info']


                                                class MdtGroupAddr(object):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr']['meta_info']


                                                class L2VpnEvpnEsi(object):
                                                    """
                                                    L2VPN EVPN ESI
                                                    
                                                    .. attribute:: esi
                                                    
                                                    	esi
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.esi = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.esi is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2VpnEvpnEsi']['meta_info']


                                                class GwAddr(object):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.len = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.len is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr']['meta_info']


                                                class BestPathCompWinner(object):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner']['meta_info']


                                                class MvpnNbrAddr(object):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr']['meta_info']


                                                class MvpnNexthopAddr(object):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr']['meta_info']


                                                class L2VpnCircuitStatusValue(object):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                                class MvpnPmsiValue(object):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity']['meta_info']


                                                class LocalPeersAdvertisedTo(object):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                                class PePeersAdvertisedTo(object):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo']['meta_info']


                                                class BestPathOrrBitfield(object):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield']['meta_info']


                                                class AddPathOrrBitfield(object):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.accept_own_path is not None:
                                                        return True

                                                    if self.accept_own_self_originated_p_ath is not None:
                                                        return True

                                                    if self.add_path_orr_bitfield is not None:
                                                        for child_ref in self.add_path_orr_bitfield:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.advertisedto_pe is not None:
                                                        return True

                                                    if self.aigp_metric is not None:
                                                        return True

                                                    if self.best_path_comp_stage is not None:
                                                        return True

                                                    if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                        return True

                                                    if self.best_path_id is not None:
                                                        return True

                                                    if self.best_path_id_comp_winner is not None:
                                                        return True

                                                    if self.best_path_orr_bitfield is not None:
                                                        for child_ref in self.best_path_orr_bitfield:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                        return True

                                                    if self.dampen_penalty is not None:
                                                        return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.fspec_invalid_path is not None:
                                                        return True

                                                    if self.graceful_shutdown is not None:
                                                        return True

                                                    if self.gw_addr is not None and self.gw_addr._has_data():
                                                        return True

                                                    if self.halflife_time is not None:
                                                        return True

                                                    if self.has_esi is not None:
                                                        return True

                                                    if self.has_gw_addr is not None:
                                                        return True

                                                    if self.has_local_net_label is not None:
                                                        return True

                                                    if self.has_mdt_group_addr is not None:
                                                        return True

                                                    if self.has_mvpn_extcomm is not None:
                                                        return True

                                                    if self.has_mvpn_nbr_addr is not None:
                                                        return True

                                                    if self.has_mvpn_nexthop_addr is not None:
                                                        return True

                                                    if self.has_mvpn_pmsi is not None:
                                                        return True

                                                    if self.has_rcvd_label is not None:
                                                        return True

                                                    if self.has_second_label is not None:
                                                        return True

                                                    if self.ibgp_signaled_validity is not None:
                                                        return True

                                                    if self.igp_metric is not None:
                                                        return True

                                                    if self.is_aggregation_suppressed is not None:
                                                        return True

                                                    if self.is_as_best is not None:
                                                        return True

                                                    if self.is_best_path is not None:
                                                        return True

                                                    if self.is_import_dampened is not None:
                                                        return True

                                                    if self.is_import_suspect is not None:
                                                        return True

                                                    if self.is_internal_path is not None:
                                                        return True

                                                    if self.is_partial_best is not None:
                                                        return True

                                                    if self.is_path_additional_path is not None:
                                                        return True

                                                    if self.is_path_advertised_local_as_only is not None:
                                                        return True

                                                    if self.is_path_af_install_eligible is not None:
                                                        return True

                                                    if self.is_path_backup is not None:
                                                        return True

                                                    if self.is_path_backup_protect_multipath is not None:
                                                        return True

                                                    if self.is_path_best_external is not None:
                                                        return True

                                                    if self.is_path_damped is not None:
                                                        return True

                                                    if self.is_path_from_confederation_peer is not None:
                                                        return True

                                                    if self.is_path_from_network_command is not None:
                                                        return True

                                                    if self.is_path_from_redistribute_command is not None:
                                                        return True

                                                    if self.is_path_from_route_reflector is not None:
                                                        return True

                                                    if self.is_path_history_held is not None:
                                                        return True

                                                    if self.is_path_imp_candidate is not None:
                                                        return True

                                                    if self.is_path_imported is not None:
                                                        return True

                                                    if self.is_path_local_aggregate is not None:
                                                        return True

                                                    if self.is_path_locally_sourced is not None:
                                                        return True

                                                    if self.is_path_long_lived_stale is not None:
                                                        return True

                                                    if self.is_path_multipath is not None:
                                                        return True

                                                    if self.is_path_nexthop_discarded is not None:
                                                        return True

                                                    if self.is_path_not_advertised is not None:
                                                        return True

                                                    if self.is_path_not_advertised_to_ebg_ps is not None:
                                                        return True

                                                    if self.is_path_received_only is not None:
                                                        return True

                                                    if self.is_path_reoriginated is not None:
                                                        return True

                                                    if self.is_path_reoriginated_stitching is not None:
                                                        return True

                                                    if self.is_path_stale is not None:
                                                        return True

                                                    if self.is_path_synced_with_igp is not None:
                                                        return True

                                                    if self.is_path_valid is not None:
                                                        return True

                                                    if self.is_path_vpn_only is not None:
                                                        return True

                                                    if self.is_permanent_path is not None:
                                                        return True

                                                    if self.is_received_path_not_modified is not None:
                                                        return True

                                                    if self.is_spkr_as_best is not None:
                                                        return True

                                                    if self.l2vpn_circuit_status_value is not None:
                                                        for child_ref in self.l2vpn_circuit_status_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                        return True

                                                    if self.l2vpn_size is not None:
                                                        return True

                                                    if self.labeled_unicast_safi_path is not None:
                                                        return True

                                                    if self.local_label is not None:
                                                        return True

                                                    if self.local_nh is not None:
                                                        return True

                                                    if self.local_path_id is not None:
                                                        return True

                                                    if self.local_peers_advertised_to is not None:
                                                        for child_ref in self.local_peers_advertised_to:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.maximum_suppress_time is not None:
                                                        return True

                                                    if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                        return True

                                                    if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                        return True

                                                    if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                        return True

                                                    if self.mvpn_path_flags is not None:
                                                        return True

                                                    if self.mvpn_pmsi_flags is not None:
                                                        return True

                                                    if self.mvpn_pmsi_label is not None:
                                                        return True

                                                    if self.mvpn_pmsi_type is not None:
                                                        return True

                                                    if self.mvpn_pmsi_value is not None:
                                                        for child_ref in self.mvpn_pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.mvpn_sfs_path is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.neighbor_router_id is not None:
                                                        return True

                                                    if self.next_hop is not None and self.next_hop._has_data():
                                                        return True

                                                    if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                        return True

                                                    if self.path_flags is not None:
                                                        return True

                                                    if self.path_flap_count is not None:
                                                        return True

                                                    if self.path_import_flags is not None:
                                                        return True

                                                    if self.path_rt_set_id is not None:
                                                        return True

                                                    if self.path_rt_set_route_count is not None:
                                                        return True

                                                    if self.path_table_version is not None:
                                                        return True

                                                    if self.path_weight is not None:
                                                        return True

                                                    if self.pe_peers_advertised_to is not None:
                                                        for child_ref in self.pe_peers_advertised_to:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.rcvd_label is not None:
                                                        return True

                                                    if self.rcvd_path_id is not None:
                                                        return True

                                                    if self.reuse_value is not None:
                                                        return True

                                                    if self.rib_failed is not None:
                                                        return True

                                                    if self.route_type is not None:
                                                        return True

                                                    if self.rpki_origin_as_validation_disabled is not None:
                                                        return True

                                                    if self.rt_set_limit_enabled is not None:
                                                        return True

                                                    if self.second_label is not None:
                                                        return True

                                                    if self.seconds_since_first_flap is not None:
                                                        return True

                                                    if self.show_rpki_origin_as_validity is not None:
                                                        return True

                                                    if self.sn_rpki_origin_as_validity is not None:
                                                        return True

                                                    if self.suppress_penalty is not None:
                                                        return True

                                                    if self.time_to_unsuppress is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation']['meta_info']


                                            class AttributesAfterPolicyIn(object):
                                                """
                                                Attributes after inbound policy applied
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet>`
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes>`
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp>`
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr>`
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\:  bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\:  bool
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet()
                                                    self.attr_set.parent = self
                                                    self.attribute_key_number = None
                                                    self.attribute_reuse_id_config = None
                                                    self.attribute_reuse_id_current = None
                                                    self.attribute_reuse_id_keys = None
                                                    self.attribute_reuse_id_max_id = None
                                                    self.attribute_reuse_id_node = None
                                                    self.attribute_reuse_id_recover_sec = None
                                                    self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self.is_application_gateway_present = None
                                                    self.is_as_path2_byte = None
                                                    self.is_attr_set_present = None
                                                    self.is_ribrnh_present = None
                                                    self.is_rnh_present = None
                                                    self.ribrnh_encap = None
                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self.ribrnh_mac = None
                                                    self.ribrnh_table = None
                                                    self.ribrnh_vni = None
                                                    self.ribrnhip_table = None
                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self.rnh_addr_len = None
                                                    self.rnh_len = None
                                                    self.rnh_type = None
                                                    self.set_aigp_inbound_igp = None
                                                    self.set_aigp_inbound_metric = None
                                                    self.vpn_distinguisher = None


                                                class CommonAttributes(object):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_encap_present
                                                    
                                                    	Tunnel Encap attribute present 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_policy_allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_binding_sid
                                                    
                                                    	SR Policy Binding sid
                                                    	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_explicit_path
                                                    
                                                    	SR Policy Explicit paths
                                                    	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                    
                                                    .. attribute:: sr_policy_preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_tunnel_request_state
                                                    
                                                    	SR Tunnel Request State
                                                    	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                    
                                                    .. attribute:: sr_tunnel_state
                                                    
                                                    	SR Tunnel State
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encap Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.aggregator_address = None
                                                        self.aggregator_as = None
                                                        self.aigp_metric_value = None
                                                        self.as_path = None
                                                        self.cluster = YList()
                                                        self.cluster.parent = self
                                                        self.cluster.name = 'cluster'
                                                        self.community = YList()
                                                        self.community.parent = self
                                                        self.community.name = 'community'
                                                        self.connector_type = None
                                                        self.connector_value = YList()
                                                        self.connector_value.parent = self
                                                        self.connector_value.name = 'connector_value'
                                                        self.extended_community = YList()
                                                        self.extended_community.parent = self
                                                        self.extended_community.name = 'extended_community'
                                                        self.extended_community_flags = None
                                                        self.is_aggregator_present = None
                                                        self.is_aigp_present = None
                                                        self.is_as_path_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_community_present = None
                                                        self.is_connector_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_label_index_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_metric_present = None
                                                        self.is_origin_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_ssa_present = None
                                                        self.is_tunnel_encap_present = None
                                                        self.l2tpv3_cookie = YList()
                                                        self.l2tpv3_cookie.parent = self
                                                        self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                        self.l2tpv3_session_id = None
                                                        self.label_index_attr = YList()
                                                        self.label_index_attr.parent = self
                                                        self.label_index_attr.name = 'label_index_attr'
                                                        self.local_preference = None
                                                        self.ls_attr = YList()
                                                        self.ls_attr.parent = self
                                                        self.ls_attr.name = 'ls_attr'
                                                        self.metric = None
                                                        self.neighbor_as = None
                                                        self.origin = None
                                                        self.originator = None
                                                        self.pe_distinguisher_label = YList()
                                                        self.pe_distinguisher_label.parent = self
                                                        self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.pmsi_type = None
                                                        self.pmsi_value = YList()
                                                        self.pmsi_value.parent = self
                                                        self.pmsi_value.name = 'pmsi_value'
                                                        self.ppm_pvalue = None
                                                        self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                        self.sr_policy_allocated_binding_sid.parent = self
                                                        self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                        self.sr_policy_binding_sid.parent = self
                                                        self.sr_policy_explicit_path = YList()
                                                        self.sr_policy_explicit_path.parent = self
                                                        self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                        self.sr_policy_preference = None
                                                        self.sr_tunnel_request_state = None
                                                        self.sr_tunnel_state = None
                                                        self.tunnel_encap_type = None
                                                        self.unknown_attribute = YList()
                                                        self.unknown_attribute.parent = self
                                                        self.unknown_attribute.name = 'unknown_attribute'


                                                    class SrPolicyBindingSid(object):
                                                        """
                                                        SR Policy Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                    class SrPolicyAllocatedBindingSid(object):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                    class Community(object):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                    class ExtendedCommunity(object):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                    class UnknownAttribute(object):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                    class Cluster(object):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                    class L2Tpv3Cookie(object):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                    class ConnectorValue(object):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                    class PmsiValue(object):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                    class LsAttr(object):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                    class LabelIndexAttr(object):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                    class PeDistinguisherLabel(object):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.label = None
                                                            self.pe_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.label is not None:
                                                                return True

                                                            if self.pe_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                    class SrPolicyExplicitPath(object):
                                                        """
                                                        SR Policy Explicit paths
                                                        
                                                        .. attribute:: sid
                                                        
                                                        	Sidlist for explicit path
                                                        	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of explicit path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.sid = YList()
                                                            self.sid.parent = self
                                                            self.sid.name = 'sid'
                                                            self.weight = None


                                                        class Sid(object):
                                                            """
                                                            Sidlist for explicit path
                                                            
                                                            .. attribute:: ipv4
                                                            
                                                            	IP Address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6
                                                            
                                                            	IPv6 address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label sid
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Sid Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4 = None
                                                                self.ipv6 = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4 is not None:
                                                                    return True

                                                                if self.ipv6 is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.sid is not None:
                                                                for child_ref in self.sid:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.weight is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.aggregator_address is not None:
                                                            return True

                                                        if self.aggregator_as is not None:
                                                            return True

                                                        if self.aigp_metric_value is not None:
                                                            return True

                                                        if self.as_path is not None:
                                                            return True

                                                        if self.cluster is not None:
                                                            for child_ref in self.cluster:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.community is not None:
                                                            for child_ref in self.community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.connector_type is not None:
                                                            return True

                                                        if self.connector_value is not None:
                                                            for child_ref in self.connector_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community is not None:
                                                            for child_ref in self.extended_community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community_flags is not None:
                                                            return True

                                                        if self.is_aggregator_present is not None:
                                                            return True

                                                        if self.is_aigp_present is not None:
                                                            return True

                                                        if self.is_as_path_present is not None:
                                                            return True

                                                        if self.is_atomic_aggregate_present is not None:
                                                            return True

                                                        if self.is_community_present is not None:
                                                            return True

                                                        if self.is_connector_present is not None:
                                                            return True

                                                        if self.is_extended_community_present is not None:
                                                            return True

                                                        if self.is_label_index_present is not None:
                                                            return True

                                                        if self.is_local_pref_present is not None:
                                                            return True

                                                        if self.is_ls_attribute_present is not None:
                                                            return True

                                                        if self.is_metric_present is not None:
                                                            return True

                                                        if self.is_origin_present is not None:
                                                            return True

                                                        if self.is_pe_distinguisher_label_present is not None:
                                                            return True

                                                        if self.is_pmsi_present is not None:
                                                            return True

                                                        if self.is_pppmp_present is not None:
                                                            return True

                                                        if self.is_ssa_present is not None:
                                                            return True

                                                        if self.is_tunnel_encap_present is not None:
                                                            return True

                                                        if self.l2tpv3_cookie is not None:
                                                            for child_ref in self.l2tpv3_cookie:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.l2tpv3_session_id is not None:
                                                            return True

                                                        if self.label_index_attr is not None:
                                                            for child_ref in self.label_index_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.local_preference is not None:
                                                            return True

                                                        if self.ls_attr is not None:
                                                            for child_ref in self.ls_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.metric is not None:
                                                            return True

                                                        if self.neighbor_as is not None:
                                                            return True

                                                        if self.origin is not None:
                                                            return True

                                                        if self.originator is not None:
                                                            return True

                                                        if self.pe_distinguisher_label is not None:
                                                            for child_ref in self.pe_distinguisher_label:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.pmsi_flags is not None:
                                                            return True

                                                        if self.pmsi_label is not None:
                                                            return True

                                                        if self.pmsi_type is not None:
                                                            return True

                                                        if self.pmsi_value is not None:
                                                            for child_ref in self.pmsi_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.ppm_pvalue is not None:
                                                            return True

                                                        if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_explicit_path is not None:
                                                            for child_ref in self.sr_policy_explicit_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.sr_policy_preference is not None:
                                                            return True

                                                        if self.sr_tunnel_request_state is not None:
                                                            return True

                                                        if self.sr_tunnel_state is not None:
                                                            return True

                                                        if self.tunnel_encap_type is not None:
                                                            return True

                                                        if self.unknown_attribute is not None:
                                                            for child_ref in self.unknown_attribute:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                                class AttrSet(object):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_encap_present
                                                    
                                                    	Tunnel Encap attribute present 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_policy_allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_binding_sid
                                                    
                                                    	SR Policy Binding sid
                                                    	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_explicit_path
                                                    
                                                    	SR Policy Explicit paths
                                                    	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                    
                                                    .. attribute:: sr_policy_preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_tunnel_request_state
                                                    
                                                    	SR Tunnel Request State
                                                    	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                    
                                                    .. attribute:: sr_tunnel_state
                                                    
                                                    	SR Tunnel State
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encap Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.aggregator_address = None
                                                        self.aggregator_as = None
                                                        self.aigp_metric_value = None
                                                        self.as_path = None
                                                        self.cluster = YList()
                                                        self.cluster.parent = self
                                                        self.cluster.name = 'cluster'
                                                        self.community = YList()
                                                        self.community.parent = self
                                                        self.community.name = 'community'
                                                        self.connector_type = None
                                                        self.connector_value = YList()
                                                        self.connector_value.parent = self
                                                        self.connector_value.name = 'connector_value'
                                                        self.extended_community = YList()
                                                        self.extended_community.parent = self
                                                        self.extended_community.name = 'extended_community'
                                                        self.extended_community_flags = None
                                                        self.is_aggregator_present = None
                                                        self.is_aigp_present = None
                                                        self.is_as_path_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_community_present = None
                                                        self.is_connector_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_label_index_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_metric_present = None
                                                        self.is_origin_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_ssa_present = None
                                                        self.is_tunnel_encap_present = None
                                                        self.l2tpv3_cookie = YList()
                                                        self.l2tpv3_cookie.parent = self
                                                        self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                        self.l2tpv3_session_id = None
                                                        self.label_index_attr = YList()
                                                        self.label_index_attr.parent = self
                                                        self.label_index_attr.name = 'label_index_attr'
                                                        self.local_preference = None
                                                        self.ls_attr = YList()
                                                        self.ls_attr.parent = self
                                                        self.ls_attr.name = 'ls_attr'
                                                        self.metric = None
                                                        self.neighbor_as = None
                                                        self.origin = None
                                                        self.originator = None
                                                        self.pe_distinguisher_label = YList()
                                                        self.pe_distinguisher_label.parent = self
                                                        self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.pmsi_type = None
                                                        self.pmsi_value = YList()
                                                        self.pmsi_value.parent = self
                                                        self.pmsi_value.name = 'pmsi_value'
                                                        self.ppm_pvalue = None
                                                        self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                        self.sr_policy_allocated_binding_sid.parent = self
                                                        self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                        self.sr_policy_binding_sid.parent = self
                                                        self.sr_policy_explicit_path = YList()
                                                        self.sr_policy_explicit_path.parent = self
                                                        self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                        self.sr_policy_preference = None
                                                        self.sr_tunnel_request_state = None
                                                        self.sr_tunnel_state = None
                                                        self.tunnel_encap_type = None
                                                        self.unknown_attribute = YList()
                                                        self.unknown_attribute.parent = self
                                                        self.unknown_attribute.name = 'unknown_attribute'


                                                    class SrPolicyBindingSid(object):
                                                        """
                                                        SR Policy Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                    class SrPolicyAllocatedBindingSid(object):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                    class Community(object):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                    class ExtendedCommunity(object):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                    class UnknownAttribute(object):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                    class Cluster(object):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                    class L2Tpv3Cookie(object):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                    class ConnectorValue(object):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                    class PmsiValue(object):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                    class LsAttr(object):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                    class LabelIndexAttr(object):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                    class PeDistinguisherLabel(object):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.label = None
                                                            self.pe_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.label is not None:
                                                                return True

                                                            if self.pe_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                    class SrPolicyExplicitPath(object):
                                                        """
                                                        SR Policy Explicit paths
                                                        
                                                        .. attribute:: sid
                                                        
                                                        	Sidlist for explicit path
                                                        	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of explicit path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.sid = YList()
                                                            self.sid.parent = self
                                                            self.sid.name = 'sid'
                                                            self.weight = None


                                                        class Sid(object):
                                                            """
                                                            Sidlist for explicit path
                                                            
                                                            .. attribute:: ipv4
                                                            
                                                            	IP Address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6
                                                            
                                                            	IPv6 address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label sid
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Sid Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4 = None
                                                                self.ipv6 = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4 is not None:
                                                                    return True

                                                                if self.ipv6 is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.sid is not None:
                                                                for child_ref in self.sid:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.weight is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.aggregator_address is not None:
                                                            return True

                                                        if self.aggregator_as is not None:
                                                            return True

                                                        if self.aigp_metric_value is not None:
                                                            return True

                                                        if self.as_path is not None:
                                                            return True

                                                        if self.cluster is not None:
                                                            for child_ref in self.cluster:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.community is not None:
                                                            for child_ref in self.community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.connector_type is not None:
                                                            return True

                                                        if self.connector_value is not None:
                                                            for child_ref in self.connector_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community is not None:
                                                            for child_ref in self.extended_community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community_flags is not None:
                                                            return True

                                                        if self.is_aggregator_present is not None:
                                                            return True

                                                        if self.is_aigp_present is not None:
                                                            return True

                                                        if self.is_as_path_present is not None:
                                                            return True

                                                        if self.is_atomic_aggregate_present is not None:
                                                            return True

                                                        if self.is_community_present is not None:
                                                            return True

                                                        if self.is_connector_present is not None:
                                                            return True

                                                        if self.is_extended_community_present is not None:
                                                            return True

                                                        if self.is_label_index_present is not None:
                                                            return True

                                                        if self.is_local_pref_present is not None:
                                                            return True

                                                        if self.is_ls_attribute_present is not None:
                                                            return True

                                                        if self.is_metric_present is not None:
                                                            return True

                                                        if self.is_origin_present is not None:
                                                            return True

                                                        if self.is_pe_distinguisher_label_present is not None:
                                                            return True

                                                        if self.is_pmsi_present is not None:
                                                            return True

                                                        if self.is_pppmp_present is not None:
                                                            return True

                                                        if self.is_ssa_present is not None:
                                                            return True

                                                        if self.is_tunnel_encap_present is not None:
                                                            return True

                                                        if self.l2tpv3_cookie is not None:
                                                            for child_ref in self.l2tpv3_cookie:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.l2tpv3_session_id is not None:
                                                            return True

                                                        if self.label_index_attr is not None:
                                                            for child_ref in self.label_index_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.local_preference is not None:
                                                            return True

                                                        if self.ls_attr is not None:
                                                            for child_ref in self.ls_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.metric is not None:
                                                            return True

                                                        if self.neighbor_as is not None:
                                                            return True

                                                        if self.origin is not None:
                                                            return True

                                                        if self.originator is not None:
                                                            return True

                                                        if self.pe_distinguisher_label is not None:
                                                            for child_ref in self.pe_distinguisher_label:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.pmsi_flags is not None:
                                                            return True

                                                        if self.pmsi_label is not None:
                                                            return True

                                                        if self.pmsi_type is not None:
                                                            return True

                                                        if self.pmsi_value is not None:
                                                            for child_ref in self.pmsi_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.ppm_pvalue is not None:
                                                            return True

                                                        if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_explicit_path is not None:
                                                            for child_ref in self.sr_policy_explicit_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.sr_policy_preference is not None:
                                                            return True

                                                        if self.sr_tunnel_request_state is not None:
                                                            return True

                                                        if self.sr_tunnel_state is not None:
                                                            return True

                                                        if self.tunnel_encap_type is not None:
                                                            return True

                                                        if self.unknown_attribute is not None:
                                                            for child_ref in self.unknown_attribute:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                                class RnhAddr(object):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.len = None
                                                        self.mac_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.len is not None:
                                                            return True

                                                        if self.mac_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                                class RibrnhIp(object):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.attr_set is not None and self.attr_set._has_data():
                                                        return True

                                                    if self.attribute_key_number is not None:
                                                        return True

                                                    if self.attribute_reuse_id_config is not None:
                                                        return True

                                                    if self.attribute_reuse_id_current is not None:
                                                        return True

                                                    if self.attribute_reuse_id_keys is not None:
                                                        return True

                                                    if self.attribute_reuse_id_max_id is not None:
                                                        return True

                                                    if self.attribute_reuse_id_node is not None:
                                                        return True

                                                    if self.attribute_reuse_id_recover_sec is not None:
                                                        return True

                                                    if self.common_attributes is not None and self.common_attributes._has_data():
                                                        return True

                                                    if self.is_application_gateway_present is not None:
                                                        return True

                                                    if self.is_as_path2_byte is not None:
                                                        return True

                                                    if self.is_attr_set_present is not None:
                                                        return True

                                                    if self.is_ribrnh_present is not None:
                                                        return True

                                                    if self.is_rnh_present is not None:
                                                        return True

                                                    if self.ribrnh_encap is not None:
                                                        return True

                                                    if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                        return True

                                                    if self.ribrnh_mac is not None:
                                                        return True

                                                    if self.ribrnh_table is not None:
                                                        return True

                                                    if self.ribrnh_vni is not None:
                                                        return True

                                                    if self.ribrnhip_table is not None:
                                                        return True

                                                    if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                        return True

                                                    if self.rnh_addr_len is not None:
                                                        return True

                                                    if self.rnh_len is not None:
                                                        return True

                                                    if self.rnh_type is not None:
                                                        return True

                                                    if self.set_aigp_inbound_igp is not None:
                                                        return True

                                                    if self.set_aigp_inbound_metric is not None:
                                                        return True

                                                    if self.vpn_distinguisher is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:paths'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.af_name is not None:
                                                    return True

                                                if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                    return True

                                                if self.label_fail is not None:
                                                    return True

                                                if self.label_o_or_version is not None:
                                                    return True

                                                if self.label_oor is not None:
                                                    return True

                                                if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                    return True

                                                if self.no_path is not None:
                                                    return True

                                                if self.path_information is not None and self.path_information._has_data():
                                                    return True

                                                if self.prefix_version is not None:
                                                    return True

                                                if self.process_instance_id is not None:
                                                    return True

                                                if self.route_distinguisher is not None:
                                                    return True

                                                if self.source_route_distinguisher is not None:
                                                    return True

                                                if self.source_vrf_name is not None:
                                                    return True

                                                if self.srcaf_name is not None:
                                                    return True

                                                if self.vrf_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths']['meta_info']


                                        class AdvPathInfo(object):
                                            """
                                            Net Advertized Paths
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: attributes_after_policy_in
                                            
                                            	Attributes after inbound policy
                                            	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn>`
                                            
                                            .. attribute:: attributes_after_policy_out
                                            
                                            	Attributes after outbound policy
                                            	**type**\:   :py:class:`AttributesAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut>`
                                            
                                            .. attribute:: neighbor_address_xr
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr>`
                                            
                                            .. attribute:: no_path
                                            
                                            	No path exists All 'sp\_path\_in' fields except 'sp\_path\_in\->bag\_prefix' are invalid.  All 'sp\_path\_out' fields are invalid
                                            	**type**\:  bool
                                            
                                            .. attribute:: path_info_after_policy_in
                                            
                                            	Path information after inbound policy
                                            	**type**\:   :py:class:`PathInfoAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn>`
                                            
                                            .. attribute:: path_info_after_policy_out
                                            
                                            	Path information after outbound policy
                                            	**type**\:   :py:class:`PathInfoAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut>`
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_route_distinguisher
                                            
                                            	Source Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.af_name = None
                                                self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn()
                                                self.attributes_after_policy_in.parent = self
                                                self.attributes_after_policy_out = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut()
                                                self.attributes_after_policy_out.parent = self
                                                self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr()
                                                self.neighbor_address_xr.parent = self
                                                self.no_path = None
                                                self.path_info_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn()
                                                self.path_info_after_policy_in.parent = self
                                                self.path_info_after_policy_out = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut()
                                                self.path_info_after_policy_out.parent = self
                                                self.route_distinguisher = None
                                                self.source_route_distinguisher = None
                                                self.vrf_name = None


                                            class NeighborAddressXr(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr']['meta_info']


                                            class PathInfoAfterPolicyIn(object):
                                                """
                                                Path information after inbound policy
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\:  bool
                                                
                                                .. attribute:: accept_own_self_originated_p_ath
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\:  bool
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield>`
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\:  bool
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner>`
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield>`
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix>`
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity>`
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\:  bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\:  bool
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr>`
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_esi
                                                
                                                	Path has EVPN ESI
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_rcvd_label
                                                
                                                	Path has received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\:  bool
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebg_ps
                                                
                                                	Not advertised to EBGPs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue>`
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2VpnEvpnEsi>`
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr>`
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue>`
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress>`
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop>`
                                                
                                                .. attribute:: nhte_tunnel
                                                
                                                	NH TE tunnel information
                                                	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhteTunnel>`
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\:  bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.accept_own_path = None
                                                    self.accept_own_self_originated_p_ath = None
                                                    self.add_path_orr_bitfield = YList()
                                                    self.add_path_orr_bitfield.parent = self
                                                    self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                    self.advertisedto_pe = None
                                                    self.aigp_metric = None
                                                    self.best_path_comp_stage = None
                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self.best_path_id = None
                                                    self.best_path_id_comp_winner = None
                                                    self.best_path_orr_bitfield = YList()
                                                    self.best_path_orr_bitfield.parent = self
                                                    self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self.dampen_penalty = None
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.fspec_invalid_path = None
                                                    self.graceful_shutdown = None
                                                    self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self.halflife_time = None
                                                    self.has_esi = None
                                                    self.has_gw_addr = None
                                                    self.has_local_net_label = None
                                                    self.has_mdt_group_addr = None
                                                    self.has_mvpn_extcomm = None
                                                    self.has_mvpn_nbr_addr = None
                                                    self.has_mvpn_nexthop_addr = None
                                                    self.has_mvpn_pmsi = None
                                                    self.has_rcvd_label = None
                                                    self.has_second_label = None
                                                    self.ibgp_signaled_validity = None
                                                    self.igp_metric = None
                                                    self.is_aggregation_suppressed = None
                                                    self.is_as_best = None
                                                    self.is_best_path = None
                                                    self.is_import_dampened = None
                                                    self.is_import_suspect = None
                                                    self.is_internal_path = None
                                                    self.is_partial_best = None
                                                    self.is_path_additional_path = None
                                                    self.is_path_advertised_local_as_only = None
                                                    self.is_path_af_install_eligible = None
                                                    self.is_path_backup = None
                                                    self.is_path_backup_protect_multipath = None
                                                    self.is_path_best_external = None
                                                    self.is_path_damped = None
                                                    self.is_path_from_confederation_peer = None
                                                    self.is_path_from_network_command = None
                                                    self.is_path_from_redistribute_command = None
                                                    self.is_path_from_route_reflector = None
                                                    self.is_path_history_held = None
                                                    self.is_path_imp_candidate = None
                                                    self.is_path_imported = None
                                                    self.is_path_local_aggregate = None
                                                    self.is_path_locally_sourced = None
                                                    self.is_path_long_lived_stale = None
                                                    self.is_path_multipath = None
                                                    self.is_path_nexthop_discarded = None
                                                    self.is_path_not_advertised = None
                                                    self.is_path_not_advertised_to_ebg_ps = None
                                                    self.is_path_received_only = None
                                                    self.is_path_reoriginated = None
                                                    self.is_path_reoriginated_stitching = None
                                                    self.is_path_stale = None
                                                    self.is_path_synced_with_igp = None
                                                    self.is_path_valid = None
                                                    self.is_path_vpn_only = None
                                                    self.is_permanent_path = None
                                                    self.is_received_path_not_modified = None
                                                    self.is_spkr_as_best = None
                                                    self.l2vpn_circuit_status_value = YList()
                                                    self.l2vpn_circuit_status_value.parent = self
                                                    self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                    self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2VpnEvpnEsi()
                                                    self.l2vpn_evpn_esi.parent = self
                                                    self.l2vpn_size = None
                                                    self.labeled_unicast_safi_path = None
                                                    self.local_label = None
                                                    self.local_nh = None
                                                    self.local_path_id = None
                                                    self.local_peers_advertised_to = YList()
                                                    self.local_peers_advertised_to.parent = self
                                                    self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                    self.maximum_suppress_time = None
                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self.mvpn_path_flags = None
                                                    self.mvpn_pmsi_flags = None
                                                    self.mvpn_pmsi_label = None
                                                    self.mvpn_pmsi_type = None
                                                    self.mvpn_pmsi_value = YList()
                                                    self.mvpn_pmsi_value.parent = self
                                                    self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                    self.mvpn_sfs_path = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.neighbor_router_id = None
                                                    self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop()
                                                    self.next_hop.parent = self
                                                    self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhteTunnel()
                                                    self.nhte_tunnel.parent = self
                                                    self.path_flags = None
                                                    self.path_flap_count = None
                                                    self.path_import_flags = None
                                                    self.path_rt_set_id = None
                                                    self.path_rt_set_route_count = None
                                                    self.path_table_version = None
                                                    self.path_weight = None
                                                    self.pe_peers_advertised_to = YList()
                                                    self.pe_peers_advertised_to.parent = self
                                                    self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                    self.rcvd_label = None
                                                    self.rcvd_path_id = None
                                                    self.reuse_value = None
                                                    self.rib_failed = None
                                                    self.route_type = None
                                                    self.rpki_origin_as_validation_disabled = None
                                                    self.rt_set_limit_enabled = None
                                                    self.second_label = None
                                                    self.seconds_since_first_flap = None
                                                    self.show_rpki_origin_as_validity = None
                                                    self.sn_rpki_origin_as_validity = None
                                                    self.suppress_penalty = None
                                                    self.time_to_unsuppress = None


                                                class BgpPrefix(object):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self.prefix_length = None


                                                    class Prefix(object):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.prefix is not None and self.prefix._has_data():
                                                            return True

                                                        if self.prefix_length is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix']['meta_info']


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress']['meta_info']


                                                class NextHop(object):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop']['meta_info']


                                                class NhteTunnel(object):
                                                    """
                                                    NH TE tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_te_tunnel
                                                    
                                                    	NH TE Tunnel info is present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last rib update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	tunnel name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	tunnel type
                                                    	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.binding_label = None
                                                        self.has_te_tunnel = None
                                                        self.is_tunnel_info_stale = None
                                                        self.is_tunnel_registered = None
                                                        self.is_tunnel_up = None
                                                        self.last_tunnel_update = None
                                                        self.tunnel_if_handle = None
                                                        self.tunnel_name = None
                                                        self.tunnel_type = None
                                                        self.tunnel_v6_enabled = None
                                                        self.tunnel_v6_required = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.binding_label is not None:
                                                            return True

                                                        if self.has_te_tunnel is not None:
                                                            return True

                                                        if self.is_tunnel_info_stale is not None:
                                                            return True

                                                        if self.is_tunnel_registered is not None:
                                                            return True

                                                        if self.is_tunnel_up is not None:
                                                            return True

                                                        if self.last_tunnel_update is not None:
                                                            return True

                                                        if self.tunnel_if_handle is not None:
                                                            return True

                                                        if self.tunnel_name is not None:
                                                            return True

                                                        if self.tunnel_type is not None:
                                                            return True

                                                        if self.tunnel_v6_enabled is not None:
                                                            return True

                                                        if self.tunnel_v6_required is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhteTunnel']['meta_info']


                                                class MdtGroupAddr(object):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr']['meta_info']


                                                class L2VpnEvpnEsi(object):
                                                    """
                                                    L2VPN EVPN ESI
                                                    
                                                    .. attribute:: esi
                                                    
                                                    	esi
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.esi = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.esi is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2VpnEvpnEsi']['meta_info']


                                                class GwAddr(object):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.len = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.len is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr']['meta_info']


                                                class BestPathCompWinner(object):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner']['meta_info']


                                                class MvpnNbrAddr(object):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr']['meta_info']


                                                class MvpnNexthopAddr(object):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr']['meta_info']


                                                class L2VpnCircuitStatusValue(object):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue']['meta_info']


                                                class MvpnPmsiValue(object):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity']['meta_info']


                                                class LocalPeersAdvertisedTo(object):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo']['meta_info']


                                                class PePeersAdvertisedTo(object):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo']['meta_info']


                                                class BestPathOrrBitfield(object):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield']['meta_info']


                                                class AddPathOrrBitfield(object):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-info-after-policy-in'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.accept_own_path is not None:
                                                        return True

                                                    if self.accept_own_self_originated_p_ath is not None:
                                                        return True

                                                    if self.add_path_orr_bitfield is not None:
                                                        for child_ref in self.add_path_orr_bitfield:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.advertisedto_pe is not None:
                                                        return True

                                                    if self.aigp_metric is not None:
                                                        return True

                                                    if self.best_path_comp_stage is not None:
                                                        return True

                                                    if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                        return True

                                                    if self.best_path_id is not None:
                                                        return True

                                                    if self.best_path_id_comp_winner is not None:
                                                        return True

                                                    if self.best_path_orr_bitfield is not None:
                                                        for child_ref in self.best_path_orr_bitfield:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                        return True

                                                    if self.dampen_penalty is not None:
                                                        return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.fspec_invalid_path is not None:
                                                        return True

                                                    if self.graceful_shutdown is not None:
                                                        return True

                                                    if self.gw_addr is not None and self.gw_addr._has_data():
                                                        return True

                                                    if self.halflife_time is not None:
                                                        return True

                                                    if self.has_esi is not None:
                                                        return True

                                                    if self.has_gw_addr is not None:
                                                        return True

                                                    if self.has_local_net_label is not None:
                                                        return True

                                                    if self.has_mdt_group_addr is not None:
                                                        return True

                                                    if self.has_mvpn_extcomm is not None:
                                                        return True

                                                    if self.has_mvpn_nbr_addr is not None:
                                                        return True

                                                    if self.has_mvpn_nexthop_addr is not None:
                                                        return True

                                                    if self.has_mvpn_pmsi is not None:
                                                        return True

                                                    if self.has_rcvd_label is not None:
                                                        return True

                                                    if self.has_second_label is not None:
                                                        return True

                                                    if self.ibgp_signaled_validity is not None:
                                                        return True

                                                    if self.igp_metric is not None:
                                                        return True

                                                    if self.is_aggregation_suppressed is not None:
                                                        return True

                                                    if self.is_as_best is not None:
                                                        return True

                                                    if self.is_best_path is not None:
                                                        return True

                                                    if self.is_import_dampened is not None:
                                                        return True

                                                    if self.is_import_suspect is not None:
                                                        return True

                                                    if self.is_internal_path is not None:
                                                        return True

                                                    if self.is_partial_best is not None:
                                                        return True

                                                    if self.is_path_additional_path is not None:
                                                        return True

                                                    if self.is_path_advertised_local_as_only is not None:
                                                        return True

                                                    if self.is_path_af_install_eligible is not None:
                                                        return True

                                                    if self.is_path_backup is not None:
                                                        return True

                                                    if self.is_path_backup_protect_multipath is not None:
                                                        return True

                                                    if self.is_path_best_external is not None:
                                                        return True

                                                    if self.is_path_damped is not None:
                                                        return True

                                                    if self.is_path_from_confederation_peer is not None:
                                                        return True

                                                    if self.is_path_from_network_command is not None:
                                                        return True

                                                    if self.is_path_from_redistribute_command is not None:
                                                        return True

                                                    if self.is_path_from_route_reflector is not None:
                                                        return True

                                                    if self.is_path_history_held is not None:
                                                        return True

                                                    if self.is_path_imp_candidate is not None:
                                                        return True

                                                    if self.is_path_imported is not None:
                                                        return True

                                                    if self.is_path_local_aggregate is not None:
                                                        return True

                                                    if self.is_path_locally_sourced is not None:
                                                        return True

                                                    if self.is_path_long_lived_stale is not None:
                                                        return True

                                                    if self.is_path_multipath is not None:
                                                        return True

                                                    if self.is_path_nexthop_discarded is not None:
                                                        return True

                                                    if self.is_path_not_advertised is not None:
                                                        return True

                                                    if self.is_path_not_advertised_to_ebg_ps is not None:
                                                        return True

                                                    if self.is_path_received_only is not None:
                                                        return True

                                                    if self.is_path_reoriginated is not None:
                                                        return True

                                                    if self.is_path_reoriginated_stitching is not None:
                                                        return True

                                                    if self.is_path_stale is not None:
                                                        return True

                                                    if self.is_path_synced_with_igp is not None:
                                                        return True

                                                    if self.is_path_valid is not None:
                                                        return True

                                                    if self.is_path_vpn_only is not None:
                                                        return True

                                                    if self.is_permanent_path is not None:
                                                        return True

                                                    if self.is_received_path_not_modified is not None:
                                                        return True

                                                    if self.is_spkr_as_best is not None:
                                                        return True

                                                    if self.l2vpn_circuit_status_value is not None:
                                                        for child_ref in self.l2vpn_circuit_status_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                        return True

                                                    if self.l2vpn_size is not None:
                                                        return True

                                                    if self.labeled_unicast_safi_path is not None:
                                                        return True

                                                    if self.local_label is not None:
                                                        return True

                                                    if self.local_nh is not None:
                                                        return True

                                                    if self.local_path_id is not None:
                                                        return True

                                                    if self.local_peers_advertised_to is not None:
                                                        for child_ref in self.local_peers_advertised_to:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.maximum_suppress_time is not None:
                                                        return True

                                                    if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                        return True

                                                    if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                        return True

                                                    if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                        return True

                                                    if self.mvpn_path_flags is not None:
                                                        return True

                                                    if self.mvpn_pmsi_flags is not None:
                                                        return True

                                                    if self.mvpn_pmsi_label is not None:
                                                        return True

                                                    if self.mvpn_pmsi_type is not None:
                                                        return True

                                                    if self.mvpn_pmsi_value is not None:
                                                        for child_ref in self.mvpn_pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.mvpn_sfs_path is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.neighbor_router_id is not None:
                                                        return True

                                                    if self.next_hop is not None and self.next_hop._has_data():
                                                        return True

                                                    if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                        return True

                                                    if self.path_flags is not None:
                                                        return True

                                                    if self.path_flap_count is not None:
                                                        return True

                                                    if self.path_import_flags is not None:
                                                        return True

                                                    if self.path_rt_set_id is not None:
                                                        return True

                                                    if self.path_rt_set_route_count is not None:
                                                        return True

                                                    if self.path_table_version is not None:
                                                        return True

                                                    if self.path_weight is not None:
                                                        return True

                                                    if self.pe_peers_advertised_to is not None:
                                                        for child_ref in self.pe_peers_advertised_to:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.rcvd_label is not None:
                                                        return True

                                                    if self.rcvd_path_id is not None:
                                                        return True

                                                    if self.reuse_value is not None:
                                                        return True

                                                    if self.rib_failed is not None:
                                                        return True

                                                    if self.route_type is not None:
                                                        return True

                                                    if self.rpki_origin_as_validation_disabled is not None:
                                                        return True

                                                    if self.rt_set_limit_enabled is not None:
                                                        return True

                                                    if self.second_label is not None:
                                                        return True

                                                    if self.seconds_since_first_flap is not None:
                                                        return True

                                                    if self.show_rpki_origin_as_validity is not None:
                                                        return True

                                                    if self.sn_rpki_origin_as_validity is not None:
                                                        return True

                                                    if self.suppress_penalty is not None:
                                                        return True

                                                    if self.time_to_unsuppress is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn']['meta_info']


                                            class PathInfoAfterPolicyOut(object):
                                                """
                                                Path information after outbound policy
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\:  bool
                                                
                                                .. attribute:: accept_own_self_originated_p_ath
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\:  bool
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield>`
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\:  bool
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner>`
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield>`
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix>`
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity>`
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\:  bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\:  bool
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr>`
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_esi
                                                
                                                	Path has EVPN ESI
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_rcvd_label
                                                
                                                	Path has received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\:  bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\:  bool
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebg_ps
                                                
                                                	Not advertised to EBGPs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue>`
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2VpnEvpnEsi>`
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr>`
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue>`
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress>`
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop>`
                                                
                                                .. attribute:: nhte_tunnel
                                                
                                                	NH TE tunnel information
                                                	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhteTunnel>`
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\:  bool
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\:  bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\:  bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.accept_own_path = None
                                                    self.accept_own_self_originated_p_ath = None
                                                    self.add_path_orr_bitfield = YList()
                                                    self.add_path_orr_bitfield.parent = self
                                                    self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                    self.advertisedto_pe = None
                                                    self.aigp_metric = None
                                                    self.best_path_comp_stage = None
                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self.best_path_id = None
                                                    self.best_path_id_comp_winner = None
                                                    self.best_path_orr_bitfield = YList()
                                                    self.best_path_orr_bitfield.parent = self
                                                    self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self.dampen_penalty = None
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.fspec_invalid_path = None
                                                    self.graceful_shutdown = None
                                                    self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self.halflife_time = None
                                                    self.has_esi = None
                                                    self.has_gw_addr = None
                                                    self.has_local_net_label = None
                                                    self.has_mdt_group_addr = None
                                                    self.has_mvpn_extcomm = None
                                                    self.has_mvpn_nbr_addr = None
                                                    self.has_mvpn_nexthop_addr = None
                                                    self.has_mvpn_pmsi = None
                                                    self.has_rcvd_label = None
                                                    self.has_second_label = None
                                                    self.ibgp_signaled_validity = None
                                                    self.igp_metric = None
                                                    self.is_aggregation_suppressed = None
                                                    self.is_as_best = None
                                                    self.is_best_path = None
                                                    self.is_import_dampened = None
                                                    self.is_import_suspect = None
                                                    self.is_internal_path = None
                                                    self.is_partial_best = None
                                                    self.is_path_additional_path = None
                                                    self.is_path_advertised_local_as_only = None
                                                    self.is_path_af_install_eligible = None
                                                    self.is_path_backup = None
                                                    self.is_path_backup_protect_multipath = None
                                                    self.is_path_best_external = None
                                                    self.is_path_damped = None
                                                    self.is_path_from_confederation_peer = None
                                                    self.is_path_from_network_command = None
                                                    self.is_path_from_redistribute_command = None
                                                    self.is_path_from_route_reflector = None
                                                    self.is_path_history_held = None
                                                    self.is_path_imp_candidate = None
                                                    self.is_path_imported = None
                                                    self.is_path_local_aggregate = None
                                                    self.is_path_locally_sourced = None
                                                    self.is_path_long_lived_stale = None
                                                    self.is_path_multipath = None
                                                    self.is_path_nexthop_discarded = None
                                                    self.is_path_not_advertised = None
                                                    self.is_path_not_advertised_to_ebg_ps = None
                                                    self.is_path_received_only = None
                                                    self.is_path_reoriginated = None
                                                    self.is_path_reoriginated_stitching = None
                                                    self.is_path_stale = None
                                                    self.is_path_synced_with_igp = None
                                                    self.is_path_valid = None
                                                    self.is_path_vpn_only = None
                                                    self.is_permanent_path = None
                                                    self.is_received_path_not_modified = None
                                                    self.is_spkr_as_best = None
                                                    self.l2vpn_circuit_status_value = YList()
                                                    self.l2vpn_circuit_status_value.parent = self
                                                    self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                    self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2VpnEvpnEsi()
                                                    self.l2vpn_evpn_esi.parent = self
                                                    self.l2vpn_size = None
                                                    self.labeled_unicast_safi_path = None
                                                    self.local_label = None
                                                    self.local_nh = None
                                                    self.local_path_id = None
                                                    self.local_peers_advertised_to = YList()
                                                    self.local_peers_advertised_to.parent = self
                                                    self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                    self.maximum_suppress_time = None
                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self.mvpn_path_flags = None
                                                    self.mvpn_pmsi_flags = None
                                                    self.mvpn_pmsi_label = None
                                                    self.mvpn_pmsi_type = None
                                                    self.mvpn_pmsi_value = YList()
                                                    self.mvpn_pmsi_value.parent = self
                                                    self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                    self.mvpn_sfs_path = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.neighbor_router_id = None
                                                    self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop()
                                                    self.next_hop.parent = self
                                                    self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhteTunnel()
                                                    self.nhte_tunnel.parent = self
                                                    self.path_flags = None
                                                    self.path_flap_count = None
                                                    self.path_import_flags = None
                                                    self.path_rt_set_id = None
                                                    self.path_rt_set_route_count = None
                                                    self.path_table_version = None
                                                    self.path_weight = None
                                                    self.pe_peers_advertised_to = YList()
                                                    self.pe_peers_advertised_to.parent = self
                                                    self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                    self.rcvd_label = None
                                                    self.rcvd_path_id = None
                                                    self.reuse_value = None
                                                    self.rib_failed = None
                                                    self.route_type = None
                                                    self.rpki_origin_as_validation_disabled = None
                                                    self.rt_set_limit_enabled = None
                                                    self.second_label = None
                                                    self.seconds_since_first_flap = None
                                                    self.show_rpki_origin_as_validity = None
                                                    self.sn_rpki_origin_as_validity = None
                                                    self.suppress_penalty = None
                                                    self.time_to_unsuppress = None


                                                class BgpPrefix(object):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self.prefix_length = None


                                                    class Prefix(object):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.prefix is not None and self.prefix._has_data():
                                                            return True

                                                        if self.prefix_length is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix']['meta_info']


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress']['meta_info']


                                                class NextHop(object):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop']['meta_info']


                                                class NhteTunnel(object):
                                                    """
                                                    NH TE tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_te_tunnel
                                                    
                                                    	NH TE Tunnel info is present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last rib update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	tunnel name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	tunnel type
                                                    	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.binding_label = None
                                                        self.has_te_tunnel = None
                                                        self.is_tunnel_info_stale = None
                                                        self.is_tunnel_registered = None
                                                        self.is_tunnel_up = None
                                                        self.last_tunnel_update = None
                                                        self.tunnel_if_handle = None
                                                        self.tunnel_name = None
                                                        self.tunnel_type = None
                                                        self.tunnel_v6_enabled = None
                                                        self.tunnel_v6_required = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.binding_label is not None:
                                                            return True

                                                        if self.has_te_tunnel is not None:
                                                            return True

                                                        if self.is_tunnel_info_stale is not None:
                                                            return True

                                                        if self.is_tunnel_registered is not None:
                                                            return True

                                                        if self.is_tunnel_up is not None:
                                                            return True

                                                        if self.last_tunnel_update is not None:
                                                            return True

                                                        if self.tunnel_if_handle is not None:
                                                            return True

                                                        if self.tunnel_name is not None:
                                                            return True

                                                        if self.tunnel_type is not None:
                                                            return True

                                                        if self.tunnel_v6_enabled is not None:
                                                            return True

                                                        if self.tunnel_v6_required is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhteTunnel']['meta_info']


                                                class MdtGroupAddr(object):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr']['meta_info']


                                                class L2VpnEvpnEsi(object):
                                                    """
                                                    L2VPN EVPN ESI
                                                    
                                                    .. attribute:: esi
                                                    
                                                    	esi
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.esi = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.esi is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2VpnEvpnEsi']['meta_info']


                                                class GwAddr(object):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.len = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.len is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr']['meta_info']


                                                class BestPathCompWinner(object):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner']['meta_info']


                                                class MvpnNbrAddr(object):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr']['meta_info']


                                                class MvpnNexthopAddr(object):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr']['meta_info']


                                                class L2VpnCircuitStatusValue(object):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue']['meta_info']


                                                class MvpnPmsiValue(object):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity']['meta_info']


                                                class LocalPeersAdvertisedTo(object):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo']['meta_info']


                                                class PePeersAdvertisedTo(object):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo']['meta_info']


                                                class BestPathOrrBitfield(object):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield']['meta_info']


                                                class AddPathOrrBitfield(object):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-info-after-policy-out'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.accept_own_path is not None:
                                                        return True

                                                    if self.accept_own_self_originated_p_ath is not None:
                                                        return True

                                                    if self.add_path_orr_bitfield is not None:
                                                        for child_ref in self.add_path_orr_bitfield:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.advertisedto_pe is not None:
                                                        return True

                                                    if self.aigp_metric is not None:
                                                        return True

                                                    if self.best_path_comp_stage is not None:
                                                        return True

                                                    if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                        return True

                                                    if self.best_path_id is not None:
                                                        return True

                                                    if self.best_path_id_comp_winner is not None:
                                                        return True

                                                    if self.best_path_orr_bitfield is not None:
                                                        for child_ref in self.best_path_orr_bitfield:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                        return True

                                                    if self.dampen_penalty is not None:
                                                        return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.fspec_invalid_path is not None:
                                                        return True

                                                    if self.graceful_shutdown is not None:
                                                        return True

                                                    if self.gw_addr is not None and self.gw_addr._has_data():
                                                        return True

                                                    if self.halflife_time is not None:
                                                        return True

                                                    if self.has_esi is not None:
                                                        return True

                                                    if self.has_gw_addr is not None:
                                                        return True

                                                    if self.has_local_net_label is not None:
                                                        return True

                                                    if self.has_mdt_group_addr is not None:
                                                        return True

                                                    if self.has_mvpn_extcomm is not None:
                                                        return True

                                                    if self.has_mvpn_nbr_addr is not None:
                                                        return True

                                                    if self.has_mvpn_nexthop_addr is not None:
                                                        return True

                                                    if self.has_mvpn_pmsi is not None:
                                                        return True

                                                    if self.has_rcvd_label is not None:
                                                        return True

                                                    if self.has_second_label is not None:
                                                        return True

                                                    if self.ibgp_signaled_validity is not None:
                                                        return True

                                                    if self.igp_metric is not None:
                                                        return True

                                                    if self.is_aggregation_suppressed is not None:
                                                        return True

                                                    if self.is_as_best is not None:
                                                        return True

                                                    if self.is_best_path is not None:
                                                        return True

                                                    if self.is_import_dampened is not None:
                                                        return True

                                                    if self.is_import_suspect is not None:
                                                        return True

                                                    if self.is_internal_path is not None:
                                                        return True

                                                    if self.is_partial_best is not None:
                                                        return True

                                                    if self.is_path_additional_path is not None:
                                                        return True

                                                    if self.is_path_advertised_local_as_only is not None:
                                                        return True

                                                    if self.is_path_af_install_eligible is not None:
                                                        return True

                                                    if self.is_path_backup is not None:
                                                        return True

                                                    if self.is_path_backup_protect_multipath is not None:
                                                        return True

                                                    if self.is_path_best_external is not None:
                                                        return True

                                                    if self.is_path_damped is not None:
                                                        return True

                                                    if self.is_path_from_confederation_peer is not None:
                                                        return True

                                                    if self.is_path_from_network_command is not None:
                                                        return True

                                                    if self.is_path_from_redistribute_command is not None:
                                                        return True

                                                    if self.is_path_from_route_reflector is not None:
                                                        return True

                                                    if self.is_path_history_held is not None:
                                                        return True

                                                    if self.is_path_imp_candidate is not None:
                                                        return True

                                                    if self.is_path_imported is not None:
                                                        return True

                                                    if self.is_path_local_aggregate is not None:
                                                        return True

                                                    if self.is_path_locally_sourced is not None:
                                                        return True

                                                    if self.is_path_long_lived_stale is not None:
                                                        return True

                                                    if self.is_path_multipath is not None:
                                                        return True

                                                    if self.is_path_nexthop_discarded is not None:
                                                        return True

                                                    if self.is_path_not_advertised is not None:
                                                        return True

                                                    if self.is_path_not_advertised_to_ebg_ps is not None:
                                                        return True

                                                    if self.is_path_received_only is not None:
                                                        return True

                                                    if self.is_path_reoriginated is not None:
                                                        return True

                                                    if self.is_path_reoriginated_stitching is not None:
                                                        return True

                                                    if self.is_path_stale is not None:
                                                        return True

                                                    if self.is_path_synced_with_igp is not None:
                                                        return True

                                                    if self.is_path_valid is not None:
                                                        return True

                                                    if self.is_path_vpn_only is not None:
                                                        return True

                                                    if self.is_permanent_path is not None:
                                                        return True

                                                    if self.is_received_path_not_modified is not None:
                                                        return True

                                                    if self.is_spkr_as_best is not None:
                                                        return True

                                                    if self.l2vpn_circuit_status_value is not None:
                                                        for child_ref in self.l2vpn_circuit_status_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                        return True

                                                    if self.l2vpn_size is not None:
                                                        return True

                                                    if self.labeled_unicast_safi_path is not None:
                                                        return True

                                                    if self.local_label is not None:
                                                        return True

                                                    if self.local_nh is not None:
                                                        return True

                                                    if self.local_path_id is not None:
                                                        return True

                                                    if self.local_peers_advertised_to is not None:
                                                        for child_ref in self.local_peers_advertised_to:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.maximum_suppress_time is not None:
                                                        return True

                                                    if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                        return True

                                                    if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                        return True

                                                    if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                        return True

                                                    if self.mvpn_path_flags is not None:
                                                        return True

                                                    if self.mvpn_pmsi_flags is not None:
                                                        return True

                                                    if self.mvpn_pmsi_label is not None:
                                                        return True

                                                    if self.mvpn_pmsi_type is not None:
                                                        return True

                                                    if self.mvpn_pmsi_value is not None:
                                                        for child_ref in self.mvpn_pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.mvpn_sfs_path is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.neighbor_router_id is not None:
                                                        return True

                                                    if self.next_hop is not None and self.next_hop._has_data():
                                                        return True

                                                    if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                        return True

                                                    if self.path_flags is not None:
                                                        return True

                                                    if self.path_flap_count is not None:
                                                        return True

                                                    if self.path_import_flags is not None:
                                                        return True

                                                    if self.path_rt_set_id is not None:
                                                        return True

                                                    if self.path_rt_set_route_count is not None:
                                                        return True

                                                    if self.path_table_version is not None:
                                                        return True

                                                    if self.path_weight is not None:
                                                        return True

                                                    if self.pe_peers_advertised_to is not None:
                                                        for child_ref in self.pe_peers_advertised_to:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.rcvd_label is not None:
                                                        return True

                                                    if self.rcvd_path_id is not None:
                                                        return True

                                                    if self.reuse_value is not None:
                                                        return True

                                                    if self.rib_failed is not None:
                                                        return True

                                                    if self.route_type is not None:
                                                        return True

                                                    if self.rpki_origin_as_validation_disabled is not None:
                                                        return True

                                                    if self.rt_set_limit_enabled is not None:
                                                        return True

                                                    if self.second_label is not None:
                                                        return True

                                                    if self.seconds_since_first_flap is not None:
                                                        return True

                                                    if self.show_rpki_origin_as_validity is not None:
                                                        return True

                                                    if self.sn_rpki_origin_as_validity is not None:
                                                        return True

                                                    if self.suppress_penalty is not None:
                                                        return True

                                                    if self.time_to_unsuppress is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut']['meta_info']


                                            class AttributesAfterPolicyIn(object):
                                                """
                                                Attributes after inbound policy
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet>`
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes>`
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp>`
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr>`
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\:  bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\:  bool
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet()
                                                    self.attr_set.parent = self
                                                    self.attribute_key_number = None
                                                    self.attribute_reuse_id_config = None
                                                    self.attribute_reuse_id_current = None
                                                    self.attribute_reuse_id_keys = None
                                                    self.attribute_reuse_id_max_id = None
                                                    self.attribute_reuse_id_node = None
                                                    self.attribute_reuse_id_recover_sec = None
                                                    self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self.is_application_gateway_present = None
                                                    self.is_as_path2_byte = None
                                                    self.is_attr_set_present = None
                                                    self.is_ribrnh_present = None
                                                    self.is_rnh_present = None
                                                    self.ribrnh_encap = None
                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self.ribrnh_mac = None
                                                    self.ribrnh_table = None
                                                    self.ribrnh_vni = None
                                                    self.ribrnhip_table = None
                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self.rnh_addr_len = None
                                                    self.rnh_len = None
                                                    self.rnh_type = None
                                                    self.set_aigp_inbound_igp = None
                                                    self.set_aigp_inbound_metric = None
                                                    self.vpn_distinguisher = None


                                                class CommonAttributes(object):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_encap_present
                                                    
                                                    	Tunnel Encap attribute present 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_policy_allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_binding_sid
                                                    
                                                    	SR Policy Binding sid
                                                    	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_explicit_path
                                                    
                                                    	SR Policy Explicit paths
                                                    	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                    
                                                    .. attribute:: sr_policy_preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_tunnel_request_state
                                                    
                                                    	SR Tunnel Request State
                                                    	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                    
                                                    .. attribute:: sr_tunnel_state
                                                    
                                                    	SR Tunnel State
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encap Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.aggregator_address = None
                                                        self.aggregator_as = None
                                                        self.aigp_metric_value = None
                                                        self.as_path = None
                                                        self.cluster = YList()
                                                        self.cluster.parent = self
                                                        self.cluster.name = 'cluster'
                                                        self.community = YList()
                                                        self.community.parent = self
                                                        self.community.name = 'community'
                                                        self.connector_type = None
                                                        self.connector_value = YList()
                                                        self.connector_value.parent = self
                                                        self.connector_value.name = 'connector_value'
                                                        self.extended_community = YList()
                                                        self.extended_community.parent = self
                                                        self.extended_community.name = 'extended_community'
                                                        self.extended_community_flags = None
                                                        self.is_aggregator_present = None
                                                        self.is_aigp_present = None
                                                        self.is_as_path_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_community_present = None
                                                        self.is_connector_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_label_index_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_metric_present = None
                                                        self.is_origin_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_ssa_present = None
                                                        self.is_tunnel_encap_present = None
                                                        self.l2tpv3_cookie = YList()
                                                        self.l2tpv3_cookie.parent = self
                                                        self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                        self.l2tpv3_session_id = None
                                                        self.label_index_attr = YList()
                                                        self.label_index_attr.parent = self
                                                        self.label_index_attr.name = 'label_index_attr'
                                                        self.local_preference = None
                                                        self.ls_attr = YList()
                                                        self.ls_attr.parent = self
                                                        self.ls_attr.name = 'ls_attr'
                                                        self.metric = None
                                                        self.neighbor_as = None
                                                        self.origin = None
                                                        self.originator = None
                                                        self.pe_distinguisher_label = YList()
                                                        self.pe_distinguisher_label.parent = self
                                                        self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.pmsi_type = None
                                                        self.pmsi_value = YList()
                                                        self.pmsi_value.parent = self
                                                        self.pmsi_value.name = 'pmsi_value'
                                                        self.ppm_pvalue = None
                                                        self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                        self.sr_policy_allocated_binding_sid.parent = self
                                                        self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                        self.sr_policy_binding_sid.parent = self
                                                        self.sr_policy_explicit_path = YList()
                                                        self.sr_policy_explicit_path.parent = self
                                                        self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                        self.sr_policy_preference = None
                                                        self.sr_tunnel_request_state = None
                                                        self.sr_tunnel_state = None
                                                        self.tunnel_encap_type = None
                                                        self.unknown_attribute = YList()
                                                        self.unknown_attribute.parent = self
                                                        self.unknown_attribute.name = 'unknown_attribute'


                                                    class SrPolicyBindingSid(object):
                                                        """
                                                        SR Policy Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                    class SrPolicyAllocatedBindingSid(object):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                    class Community(object):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                    class ExtendedCommunity(object):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                    class UnknownAttribute(object):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                    class Cluster(object):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                    class L2Tpv3Cookie(object):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                    class ConnectorValue(object):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                    class PmsiValue(object):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                    class LsAttr(object):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                    class LabelIndexAttr(object):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                    class PeDistinguisherLabel(object):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.label = None
                                                            self.pe_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.label is not None:
                                                                return True

                                                            if self.pe_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                    class SrPolicyExplicitPath(object):
                                                        """
                                                        SR Policy Explicit paths
                                                        
                                                        .. attribute:: sid
                                                        
                                                        	Sidlist for explicit path
                                                        	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of explicit path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.sid = YList()
                                                            self.sid.parent = self
                                                            self.sid.name = 'sid'
                                                            self.weight = None


                                                        class Sid(object):
                                                            """
                                                            Sidlist for explicit path
                                                            
                                                            .. attribute:: ipv4
                                                            
                                                            	IP Address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6
                                                            
                                                            	IPv6 address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label sid
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Sid Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4 = None
                                                                self.ipv6 = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4 is not None:
                                                                    return True

                                                                if self.ipv6 is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.sid is not None:
                                                                for child_ref in self.sid:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.weight is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.aggregator_address is not None:
                                                            return True

                                                        if self.aggregator_as is not None:
                                                            return True

                                                        if self.aigp_metric_value is not None:
                                                            return True

                                                        if self.as_path is not None:
                                                            return True

                                                        if self.cluster is not None:
                                                            for child_ref in self.cluster:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.community is not None:
                                                            for child_ref in self.community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.connector_type is not None:
                                                            return True

                                                        if self.connector_value is not None:
                                                            for child_ref in self.connector_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community is not None:
                                                            for child_ref in self.extended_community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community_flags is not None:
                                                            return True

                                                        if self.is_aggregator_present is not None:
                                                            return True

                                                        if self.is_aigp_present is not None:
                                                            return True

                                                        if self.is_as_path_present is not None:
                                                            return True

                                                        if self.is_atomic_aggregate_present is not None:
                                                            return True

                                                        if self.is_community_present is not None:
                                                            return True

                                                        if self.is_connector_present is not None:
                                                            return True

                                                        if self.is_extended_community_present is not None:
                                                            return True

                                                        if self.is_label_index_present is not None:
                                                            return True

                                                        if self.is_local_pref_present is not None:
                                                            return True

                                                        if self.is_ls_attribute_present is not None:
                                                            return True

                                                        if self.is_metric_present is not None:
                                                            return True

                                                        if self.is_origin_present is not None:
                                                            return True

                                                        if self.is_pe_distinguisher_label_present is not None:
                                                            return True

                                                        if self.is_pmsi_present is not None:
                                                            return True

                                                        if self.is_pppmp_present is not None:
                                                            return True

                                                        if self.is_ssa_present is not None:
                                                            return True

                                                        if self.is_tunnel_encap_present is not None:
                                                            return True

                                                        if self.l2tpv3_cookie is not None:
                                                            for child_ref in self.l2tpv3_cookie:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.l2tpv3_session_id is not None:
                                                            return True

                                                        if self.label_index_attr is not None:
                                                            for child_ref in self.label_index_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.local_preference is not None:
                                                            return True

                                                        if self.ls_attr is not None:
                                                            for child_ref in self.ls_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.metric is not None:
                                                            return True

                                                        if self.neighbor_as is not None:
                                                            return True

                                                        if self.origin is not None:
                                                            return True

                                                        if self.originator is not None:
                                                            return True

                                                        if self.pe_distinguisher_label is not None:
                                                            for child_ref in self.pe_distinguisher_label:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.pmsi_flags is not None:
                                                            return True

                                                        if self.pmsi_label is not None:
                                                            return True

                                                        if self.pmsi_type is not None:
                                                            return True

                                                        if self.pmsi_value is not None:
                                                            for child_ref in self.pmsi_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.ppm_pvalue is not None:
                                                            return True

                                                        if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_explicit_path is not None:
                                                            for child_ref in self.sr_policy_explicit_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.sr_policy_preference is not None:
                                                            return True

                                                        if self.sr_tunnel_request_state is not None:
                                                            return True

                                                        if self.sr_tunnel_state is not None:
                                                            return True

                                                        if self.tunnel_encap_type is not None:
                                                            return True

                                                        if self.unknown_attribute is not None:
                                                            for child_ref in self.unknown_attribute:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                                class AttrSet(object):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_encap_present
                                                    
                                                    	Tunnel Encap attribute present 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_policy_allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_binding_sid
                                                    
                                                    	SR Policy Binding sid
                                                    	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_explicit_path
                                                    
                                                    	SR Policy Explicit paths
                                                    	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                    
                                                    .. attribute:: sr_policy_preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_tunnel_request_state
                                                    
                                                    	SR Tunnel Request State
                                                    	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                    
                                                    .. attribute:: sr_tunnel_state
                                                    
                                                    	SR Tunnel State
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encap Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.aggregator_address = None
                                                        self.aggregator_as = None
                                                        self.aigp_metric_value = None
                                                        self.as_path = None
                                                        self.cluster = YList()
                                                        self.cluster.parent = self
                                                        self.cluster.name = 'cluster'
                                                        self.community = YList()
                                                        self.community.parent = self
                                                        self.community.name = 'community'
                                                        self.connector_type = None
                                                        self.connector_value = YList()
                                                        self.connector_value.parent = self
                                                        self.connector_value.name = 'connector_value'
                                                        self.extended_community = YList()
                                                        self.extended_community.parent = self
                                                        self.extended_community.name = 'extended_community'
                                                        self.extended_community_flags = None
                                                        self.is_aggregator_present = None
                                                        self.is_aigp_present = None
                                                        self.is_as_path_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_community_present = None
                                                        self.is_connector_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_label_index_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_metric_present = None
                                                        self.is_origin_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_ssa_present = None
                                                        self.is_tunnel_encap_present = None
                                                        self.l2tpv3_cookie = YList()
                                                        self.l2tpv3_cookie.parent = self
                                                        self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                        self.l2tpv3_session_id = None
                                                        self.label_index_attr = YList()
                                                        self.label_index_attr.parent = self
                                                        self.label_index_attr.name = 'label_index_attr'
                                                        self.local_preference = None
                                                        self.ls_attr = YList()
                                                        self.ls_attr.parent = self
                                                        self.ls_attr.name = 'ls_attr'
                                                        self.metric = None
                                                        self.neighbor_as = None
                                                        self.origin = None
                                                        self.originator = None
                                                        self.pe_distinguisher_label = YList()
                                                        self.pe_distinguisher_label.parent = self
                                                        self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.pmsi_type = None
                                                        self.pmsi_value = YList()
                                                        self.pmsi_value.parent = self
                                                        self.pmsi_value.name = 'pmsi_value'
                                                        self.ppm_pvalue = None
                                                        self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                        self.sr_policy_allocated_binding_sid.parent = self
                                                        self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                        self.sr_policy_binding_sid.parent = self
                                                        self.sr_policy_explicit_path = YList()
                                                        self.sr_policy_explicit_path.parent = self
                                                        self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                        self.sr_policy_preference = None
                                                        self.sr_tunnel_request_state = None
                                                        self.sr_tunnel_state = None
                                                        self.tunnel_encap_type = None
                                                        self.unknown_attribute = YList()
                                                        self.unknown_attribute.parent = self
                                                        self.unknown_attribute.name = 'unknown_attribute'


                                                    class SrPolicyBindingSid(object):
                                                        """
                                                        SR Policy Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                    class SrPolicyAllocatedBindingSid(object):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                    class Community(object):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                    class ExtendedCommunity(object):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                    class UnknownAttribute(object):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                    class Cluster(object):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                    class L2Tpv3Cookie(object):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                    class ConnectorValue(object):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                    class PmsiValue(object):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                    class LsAttr(object):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                    class LabelIndexAttr(object):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                    class PeDistinguisherLabel(object):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.label = None
                                                            self.pe_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.label is not None:
                                                                return True

                                                            if self.pe_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                    class SrPolicyExplicitPath(object):
                                                        """
                                                        SR Policy Explicit paths
                                                        
                                                        .. attribute:: sid
                                                        
                                                        	Sidlist for explicit path
                                                        	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of explicit path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.sid = YList()
                                                            self.sid.parent = self
                                                            self.sid.name = 'sid'
                                                            self.weight = None


                                                        class Sid(object):
                                                            """
                                                            Sidlist for explicit path
                                                            
                                                            .. attribute:: ipv4
                                                            
                                                            	IP Address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6
                                                            
                                                            	IPv6 address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label sid
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Sid Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4 = None
                                                                self.ipv6 = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4 is not None:
                                                                    return True

                                                                if self.ipv6 is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.sid is not None:
                                                                for child_ref in self.sid:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.weight is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.aggregator_address is not None:
                                                            return True

                                                        if self.aggregator_as is not None:
                                                            return True

                                                        if self.aigp_metric_value is not None:
                                                            return True

                                                        if self.as_path is not None:
                                                            return True

                                                        if self.cluster is not None:
                                                            for child_ref in self.cluster:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.community is not None:
                                                            for child_ref in self.community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.connector_type is not None:
                                                            return True

                                                        if self.connector_value is not None:
                                                            for child_ref in self.connector_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community is not None:
                                                            for child_ref in self.extended_community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community_flags is not None:
                                                            return True

                                                        if self.is_aggregator_present is not None:
                                                            return True

                                                        if self.is_aigp_present is not None:
                                                            return True

                                                        if self.is_as_path_present is not None:
                                                            return True

                                                        if self.is_atomic_aggregate_present is not None:
                                                            return True

                                                        if self.is_community_present is not None:
                                                            return True

                                                        if self.is_connector_present is not None:
                                                            return True

                                                        if self.is_extended_community_present is not None:
                                                            return True

                                                        if self.is_label_index_present is not None:
                                                            return True

                                                        if self.is_local_pref_present is not None:
                                                            return True

                                                        if self.is_ls_attribute_present is not None:
                                                            return True

                                                        if self.is_metric_present is not None:
                                                            return True

                                                        if self.is_origin_present is not None:
                                                            return True

                                                        if self.is_pe_distinguisher_label_present is not None:
                                                            return True

                                                        if self.is_pmsi_present is not None:
                                                            return True

                                                        if self.is_pppmp_present is not None:
                                                            return True

                                                        if self.is_ssa_present is not None:
                                                            return True

                                                        if self.is_tunnel_encap_present is not None:
                                                            return True

                                                        if self.l2tpv3_cookie is not None:
                                                            for child_ref in self.l2tpv3_cookie:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.l2tpv3_session_id is not None:
                                                            return True

                                                        if self.label_index_attr is not None:
                                                            for child_ref in self.label_index_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.local_preference is not None:
                                                            return True

                                                        if self.ls_attr is not None:
                                                            for child_ref in self.ls_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.metric is not None:
                                                            return True

                                                        if self.neighbor_as is not None:
                                                            return True

                                                        if self.origin is not None:
                                                            return True

                                                        if self.originator is not None:
                                                            return True

                                                        if self.pe_distinguisher_label is not None:
                                                            for child_ref in self.pe_distinguisher_label:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.pmsi_flags is not None:
                                                            return True

                                                        if self.pmsi_label is not None:
                                                            return True

                                                        if self.pmsi_type is not None:
                                                            return True

                                                        if self.pmsi_value is not None:
                                                            for child_ref in self.pmsi_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.ppm_pvalue is not None:
                                                            return True

                                                        if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_explicit_path is not None:
                                                            for child_ref in self.sr_policy_explicit_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.sr_policy_preference is not None:
                                                            return True

                                                        if self.sr_tunnel_request_state is not None:
                                                            return True

                                                        if self.sr_tunnel_state is not None:
                                                            return True

                                                        if self.tunnel_encap_type is not None:
                                                            return True

                                                        if self.unknown_attribute is not None:
                                                            for child_ref in self.unknown_attribute:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                                class RnhAddr(object):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.len = None
                                                        self.mac_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.len is not None:
                                                            return True

                                                        if self.mac_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                                class RibrnhIp(object):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.attr_set is not None and self.attr_set._has_data():
                                                        return True

                                                    if self.attribute_key_number is not None:
                                                        return True

                                                    if self.attribute_reuse_id_config is not None:
                                                        return True

                                                    if self.attribute_reuse_id_current is not None:
                                                        return True

                                                    if self.attribute_reuse_id_keys is not None:
                                                        return True

                                                    if self.attribute_reuse_id_max_id is not None:
                                                        return True

                                                    if self.attribute_reuse_id_node is not None:
                                                        return True

                                                    if self.attribute_reuse_id_recover_sec is not None:
                                                        return True

                                                    if self.common_attributes is not None and self.common_attributes._has_data():
                                                        return True

                                                    if self.is_application_gateway_present is not None:
                                                        return True

                                                    if self.is_as_path2_byte is not None:
                                                        return True

                                                    if self.is_attr_set_present is not None:
                                                        return True

                                                    if self.is_ribrnh_present is not None:
                                                        return True

                                                    if self.is_rnh_present is not None:
                                                        return True

                                                    if self.ribrnh_encap is not None:
                                                        return True

                                                    if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                        return True

                                                    if self.ribrnh_mac is not None:
                                                        return True

                                                    if self.ribrnh_table is not None:
                                                        return True

                                                    if self.ribrnh_vni is not None:
                                                        return True

                                                    if self.ribrnhip_table is not None:
                                                        return True

                                                    if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                        return True

                                                    if self.rnh_addr_len is not None:
                                                        return True

                                                    if self.rnh_len is not None:
                                                        return True

                                                    if self.rnh_type is not None:
                                                        return True

                                                    if self.set_aigp_inbound_igp is not None:
                                                        return True

                                                    if self.set_aigp_inbound_metric is not None:
                                                        return True

                                                    if self.vpn_distinguisher is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn']['meta_info']


                                            class AttributesAfterPolicyOut(object):
                                                """
                                                Attributes after outbound policy
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet>`
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes>`
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp>`
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr>`
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\:  bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\:  bool
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet()
                                                    self.attr_set.parent = self
                                                    self.attribute_key_number = None
                                                    self.attribute_reuse_id_config = None
                                                    self.attribute_reuse_id_current = None
                                                    self.attribute_reuse_id_keys = None
                                                    self.attribute_reuse_id_max_id = None
                                                    self.attribute_reuse_id_node = None
                                                    self.attribute_reuse_id_recover_sec = None
                                                    self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self.is_application_gateway_present = None
                                                    self.is_as_path2_byte = None
                                                    self.is_attr_set_present = None
                                                    self.is_ribrnh_present = None
                                                    self.is_rnh_present = None
                                                    self.ribrnh_encap = None
                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self.ribrnh_mac = None
                                                    self.ribrnh_table = None
                                                    self.ribrnh_vni = None
                                                    self.ribrnhip_table = None
                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self.rnh_addr_len = None
                                                    self.rnh_len = None
                                                    self.rnh_type = None
                                                    self.set_aigp_inbound_igp = None
                                                    self.set_aigp_inbound_metric = None
                                                    self.vpn_distinguisher = None


                                                class CommonAttributes(object):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_encap_present
                                                    
                                                    	Tunnel Encap attribute present 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_policy_allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_binding_sid
                                                    
                                                    	SR Policy Binding sid
                                                    	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_explicit_path
                                                    
                                                    	SR Policy Explicit paths
                                                    	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyExplicitPath>`
                                                    
                                                    .. attribute:: sr_policy_preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_tunnel_request_state
                                                    
                                                    	SR Tunnel Request State
                                                    	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                    
                                                    .. attribute:: sr_tunnel_state
                                                    
                                                    	SR Tunnel State
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encap Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.aggregator_address = None
                                                        self.aggregator_as = None
                                                        self.aigp_metric_value = None
                                                        self.as_path = None
                                                        self.cluster = YList()
                                                        self.cluster.parent = self
                                                        self.cluster.name = 'cluster'
                                                        self.community = YList()
                                                        self.community.parent = self
                                                        self.community.name = 'community'
                                                        self.connector_type = None
                                                        self.connector_value = YList()
                                                        self.connector_value.parent = self
                                                        self.connector_value.name = 'connector_value'
                                                        self.extended_community = YList()
                                                        self.extended_community.parent = self
                                                        self.extended_community.name = 'extended_community'
                                                        self.extended_community_flags = None
                                                        self.is_aggregator_present = None
                                                        self.is_aigp_present = None
                                                        self.is_as_path_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_community_present = None
                                                        self.is_connector_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_label_index_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_metric_present = None
                                                        self.is_origin_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_ssa_present = None
                                                        self.is_tunnel_encap_present = None
                                                        self.l2tpv3_cookie = YList()
                                                        self.l2tpv3_cookie.parent = self
                                                        self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                        self.l2tpv3_session_id = None
                                                        self.label_index_attr = YList()
                                                        self.label_index_attr.parent = self
                                                        self.label_index_attr.name = 'label_index_attr'
                                                        self.local_preference = None
                                                        self.ls_attr = YList()
                                                        self.ls_attr.parent = self
                                                        self.ls_attr.name = 'ls_attr'
                                                        self.metric = None
                                                        self.neighbor_as = None
                                                        self.origin = None
                                                        self.originator = None
                                                        self.pe_distinguisher_label = YList()
                                                        self.pe_distinguisher_label.parent = self
                                                        self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.pmsi_type = None
                                                        self.pmsi_value = YList()
                                                        self.pmsi_value.parent = self
                                                        self.pmsi_value.name = 'pmsi_value'
                                                        self.ppm_pvalue = None
                                                        self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                        self.sr_policy_allocated_binding_sid.parent = self
                                                        self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyBindingSid()
                                                        self.sr_policy_binding_sid.parent = self
                                                        self.sr_policy_explicit_path = YList()
                                                        self.sr_policy_explicit_path.parent = self
                                                        self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                        self.sr_policy_preference = None
                                                        self.sr_tunnel_request_state = None
                                                        self.sr_tunnel_state = None
                                                        self.tunnel_encap_type = None
                                                        self.unknown_attribute = YList()
                                                        self.unknown_attribute.parent = self
                                                        self.unknown_attribute.name = 'unknown_attribute'


                                                    class SrPolicyBindingSid(object):
                                                        """
                                                        SR Policy Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                    class SrPolicyAllocatedBindingSid(object):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                    class Community(object):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community']['meta_info']


                                                    class ExtendedCommunity(object):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity']['meta_info']


                                                    class UnknownAttribute(object):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute']['meta_info']


                                                    class Cluster(object):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster']['meta_info']


                                                    class L2Tpv3Cookie(object):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                    class ConnectorValue(object):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue']['meta_info']


                                                    class PmsiValue(object):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue']['meta_info']


                                                    class LsAttr(object):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr']['meta_info']


                                                    class LabelIndexAttr(object):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr']['meta_info']


                                                    class PeDistinguisherLabel(object):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.label = None
                                                            self.pe_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.label is not None:
                                                                return True

                                                            if self.pe_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                    class SrPolicyExplicitPath(object):
                                                        """
                                                        SR Policy Explicit paths
                                                        
                                                        .. attribute:: sid
                                                        
                                                        	Sidlist for explicit path
                                                        	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of explicit path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.sid = YList()
                                                            self.sid.parent = self
                                                            self.sid.name = 'sid'
                                                            self.weight = None


                                                        class Sid(object):
                                                            """
                                                            Sidlist for explicit path
                                                            
                                                            .. attribute:: ipv4
                                                            
                                                            	IP Address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6
                                                            
                                                            	IPv6 address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label sid
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Sid Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4 = None
                                                                self.ipv6 = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4 is not None:
                                                                    return True

                                                                if self.ipv6 is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.sid is not None:
                                                                for child_ref in self.sid:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.weight is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.aggregator_address is not None:
                                                            return True

                                                        if self.aggregator_as is not None:
                                                            return True

                                                        if self.aigp_metric_value is not None:
                                                            return True

                                                        if self.as_path is not None:
                                                            return True

                                                        if self.cluster is not None:
                                                            for child_ref in self.cluster:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.community is not None:
                                                            for child_ref in self.community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.connector_type is not None:
                                                            return True

                                                        if self.connector_value is not None:
                                                            for child_ref in self.connector_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community is not None:
                                                            for child_ref in self.extended_community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community_flags is not None:
                                                            return True

                                                        if self.is_aggregator_present is not None:
                                                            return True

                                                        if self.is_aigp_present is not None:
                                                            return True

                                                        if self.is_as_path_present is not None:
                                                            return True

                                                        if self.is_atomic_aggregate_present is not None:
                                                            return True

                                                        if self.is_community_present is not None:
                                                            return True

                                                        if self.is_connector_present is not None:
                                                            return True

                                                        if self.is_extended_community_present is not None:
                                                            return True

                                                        if self.is_label_index_present is not None:
                                                            return True

                                                        if self.is_local_pref_present is not None:
                                                            return True

                                                        if self.is_ls_attribute_present is not None:
                                                            return True

                                                        if self.is_metric_present is not None:
                                                            return True

                                                        if self.is_origin_present is not None:
                                                            return True

                                                        if self.is_pe_distinguisher_label_present is not None:
                                                            return True

                                                        if self.is_pmsi_present is not None:
                                                            return True

                                                        if self.is_pppmp_present is not None:
                                                            return True

                                                        if self.is_ssa_present is not None:
                                                            return True

                                                        if self.is_tunnel_encap_present is not None:
                                                            return True

                                                        if self.l2tpv3_cookie is not None:
                                                            for child_ref in self.l2tpv3_cookie:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.l2tpv3_session_id is not None:
                                                            return True

                                                        if self.label_index_attr is not None:
                                                            for child_ref in self.label_index_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.local_preference is not None:
                                                            return True

                                                        if self.ls_attr is not None:
                                                            for child_ref in self.ls_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.metric is not None:
                                                            return True

                                                        if self.neighbor_as is not None:
                                                            return True

                                                        if self.origin is not None:
                                                            return True

                                                        if self.originator is not None:
                                                            return True

                                                        if self.pe_distinguisher_label is not None:
                                                            for child_ref in self.pe_distinguisher_label:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.pmsi_flags is not None:
                                                            return True

                                                        if self.pmsi_label is not None:
                                                            return True

                                                        if self.pmsi_type is not None:
                                                            return True

                                                        if self.pmsi_value is not None:
                                                            for child_ref in self.pmsi_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.ppm_pvalue is not None:
                                                            return True

                                                        if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_explicit_path is not None:
                                                            for child_ref in self.sr_policy_explicit_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.sr_policy_preference is not None:
                                                            return True

                                                        if self.sr_tunnel_request_state is not None:
                                                            return True

                                                        if self.sr_tunnel_state is not None:
                                                            return True

                                                        if self.tunnel_encap_type is not None:
                                                            return True

                                                        if self.unknown_attribute is not None:
                                                            for child_ref in self.unknown_attribute:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes']['meta_info']


                                                class AttrSet(object):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community>`
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_encap_present
                                                    
                                                    	Tunnel Encap attribute present 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie>`
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_index_attr
                                                    
                                                    	Label Index attribute
                                                    	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr>`
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_policy_allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyAllocatedBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_binding_sid
                                                    
                                                    	SR Policy Binding sid
                                                    	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyBindingSid>`
                                                    
                                                    .. attribute:: sr_policy_explicit_path
                                                    
                                                    	SR Policy Explicit paths
                                                    	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyExplicitPath>`
                                                    
                                                    .. attribute:: sr_policy_preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sr_tunnel_request_state
                                                    
                                                    	SR Tunnel Request State
                                                    	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                    
                                                    .. attribute:: sr_tunnel_state
                                                    
                                                    	SR Tunnel State
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encap Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.aggregator_address = None
                                                        self.aggregator_as = None
                                                        self.aigp_metric_value = None
                                                        self.as_path = None
                                                        self.cluster = YList()
                                                        self.cluster.parent = self
                                                        self.cluster.name = 'cluster'
                                                        self.community = YList()
                                                        self.community.parent = self
                                                        self.community.name = 'community'
                                                        self.connector_type = None
                                                        self.connector_value = YList()
                                                        self.connector_value.parent = self
                                                        self.connector_value.name = 'connector_value'
                                                        self.extended_community = YList()
                                                        self.extended_community.parent = self
                                                        self.extended_community.name = 'extended_community'
                                                        self.extended_community_flags = None
                                                        self.is_aggregator_present = None
                                                        self.is_aigp_present = None
                                                        self.is_as_path_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_community_present = None
                                                        self.is_connector_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_label_index_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_metric_present = None
                                                        self.is_origin_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_ssa_present = None
                                                        self.is_tunnel_encap_present = None
                                                        self.l2tpv3_cookie = YList()
                                                        self.l2tpv3_cookie.parent = self
                                                        self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                        self.l2tpv3_session_id = None
                                                        self.label_index_attr = YList()
                                                        self.label_index_attr.parent = self
                                                        self.label_index_attr.name = 'label_index_attr'
                                                        self.local_preference = None
                                                        self.ls_attr = YList()
                                                        self.ls_attr.parent = self
                                                        self.ls_attr.name = 'ls_attr'
                                                        self.metric = None
                                                        self.neighbor_as = None
                                                        self.origin = None
                                                        self.originator = None
                                                        self.pe_distinguisher_label = YList()
                                                        self.pe_distinguisher_label.parent = self
                                                        self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.pmsi_type = None
                                                        self.pmsi_value = YList()
                                                        self.pmsi_value.parent = self
                                                        self.pmsi_value.name = 'pmsi_value'
                                                        self.ppm_pvalue = None
                                                        self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyAllocatedBindingSid()
                                                        self.sr_policy_allocated_binding_sid.parent = self
                                                        self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyBindingSid()
                                                        self.sr_policy_binding_sid.parent = self
                                                        self.sr_policy_explicit_path = YList()
                                                        self.sr_policy_explicit_path.parent = self
                                                        self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                        self.sr_policy_preference = None
                                                        self.sr_tunnel_request_state = None
                                                        self.sr_tunnel_state = None
                                                        self.tunnel_encap_type = None
                                                        self.unknown_attribute = YList()
                                                        self.unknown_attribute.parent = self
                                                        self.unknown_attribute.name = 'unknown_attribute'


                                                    class SrPolicyBindingSid(object):
                                                        """
                                                        SR Policy Binding sid
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyBindingSid']['meta_info']


                                                    class SrPolicyAllocatedBindingSid(object):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_address = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                    class Community(object):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community']['meta_info']


                                                    class ExtendedCommunity(object):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity']['meta_info']


                                                    class UnknownAttribute(object):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute']['meta_info']


                                                    class Cluster(object):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster']['meta_info']


                                                    class L2Tpv3Cookie(object):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie']['meta_info']


                                                    class ConnectorValue(object):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue']['meta_info']


                                                    class PmsiValue(object):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue']['meta_info']


                                                    class LsAttr(object):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr']['meta_info']


                                                    class LabelIndexAttr(object):
                                                        """
                                                        Label Index attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr']['meta_info']


                                                    class PeDistinguisherLabel(object):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.label = None
                                                            self.pe_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.label is not None:
                                                                return True

                                                            if self.pe_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel']['meta_info']


                                                    class SrPolicyExplicitPath(object):
                                                        """
                                                        SR Policy Explicit paths
                                                        
                                                        .. attribute:: sid
                                                        
                                                        	Sidlist for explicit path
                                                        	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyExplicitPath.Sid>`
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of explicit path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.sid = YList()
                                                            self.sid.parent = self
                                                            self.sid.name = 'sid'
                                                            self.weight = None


                                                        class Sid(object):
                                                            """
                                                            Sidlist for explicit path
                                                            
                                                            .. attribute:: ipv4
                                                            
                                                            	IP Address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6
                                                            
                                                            	IPv6 address sid
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label sid
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Sid Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4 = None
                                                                self.ipv6 = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4 is not None:
                                                                    return True

                                                                if self.ipv6 is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.sid is not None:
                                                                for child_ref in self.sid:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.weight is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.aggregator_address is not None:
                                                            return True

                                                        if self.aggregator_as is not None:
                                                            return True

                                                        if self.aigp_metric_value is not None:
                                                            return True

                                                        if self.as_path is not None:
                                                            return True

                                                        if self.cluster is not None:
                                                            for child_ref in self.cluster:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.community is not None:
                                                            for child_ref in self.community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.connector_type is not None:
                                                            return True

                                                        if self.connector_value is not None:
                                                            for child_ref in self.connector_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community is not None:
                                                            for child_ref in self.extended_community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.extended_community_flags is not None:
                                                            return True

                                                        if self.is_aggregator_present is not None:
                                                            return True

                                                        if self.is_aigp_present is not None:
                                                            return True

                                                        if self.is_as_path_present is not None:
                                                            return True

                                                        if self.is_atomic_aggregate_present is not None:
                                                            return True

                                                        if self.is_community_present is not None:
                                                            return True

                                                        if self.is_connector_present is not None:
                                                            return True

                                                        if self.is_extended_community_present is not None:
                                                            return True

                                                        if self.is_label_index_present is not None:
                                                            return True

                                                        if self.is_local_pref_present is not None:
                                                            return True

                                                        if self.is_ls_attribute_present is not None:
                                                            return True

                                                        if self.is_metric_present is not None:
                                                            return True

                                                        if self.is_origin_present is not None:
                                                            return True

                                                        if self.is_pe_distinguisher_label_present is not None:
                                                            return True

                                                        if self.is_pmsi_present is not None:
                                                            return True

                                                        if self.is_pppmp_present is not None:
                                                            return True

                                                        if self.is_ssa_present is not None:
                                                            return True

                                                        if self.is_tunnel_encap_present is not None:
                                                            return True

                                                        if self.l2tpv3_cookie is not None:
                                                            for child_ref in self.l2tpv3_cookie:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.l2tpv3_session_id is not None:
                                                            return True

                                                        if self.label_index_attr is not None:
                                                            for child_ref in self.label_index_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.local_preference is not None:
                                                            return True

                                                        if self.ls_attr is not None:
                                                            for child_ref in self.ls_attr:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.metric is not None:
                                                            return True

                                                        if self.neighbor_as is not None:
                                                            return True

                                                        if self.origin is not None:
                                                            return True

                                                        if self.originator is not None:
                                                            return True

                                                        if self.pe_distinguisher_label is not None:
                                                            for child_ref in self.pe_distinguisher_label:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.pmsi_flags is not None:
                                                            return True

                                                        if self.pmsi_label is not None:
                                                            return True

                                                        if self.pmsi_type is not None:
                                                            return True

                                                        if self.pmsi_value is not None:
                                                            for child_ref in self.pmsi_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.ppm_pvalue is not None:
                                                            return True

                                                        if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                            return True

                                                        if self.sr_policy_explicit_path is not None:
                                                            for child_ref in self.sr_policy_explicit_path:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.sr_policy_preference is not None:
                                                            return True

                                                        if self.sr_tunnel_request_state is not None:
                                                            return True

                                                        if self.sr_tunnel_state is not None:
                                                            return True

                                                        if self.tunnel_encap_type is not None:
                                                            return True

                                                        if self.unknown_attribute is not None:
                                                            for child_ref in self.unknown_attribute:
                                                                if child_ref._has_data():
                                                                    return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet']['meta_info']


                                                class RnhAddr(object):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.len = None
                                                        self.mac_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.len is not None:
                                                            return True

                                                        if self.mac_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr']['meta_info']


                                                class RibrnhIp(object):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-out'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.attr_set is not None and self.attr_set._has_data():
                                                        return True

                                                    if self.attribute_key_number is not None:
                                                        return True

                                                    if self.attribute_reuse_id_config is not None:
                                                        return True

                                                    if self.attribute_reuse_id_current is not None:
                                                        return True

                                                    if self.attribute_reuse_id_keys is not None:
                                                        return True

                                                    if self.attribute_reuse_id_max_id is not None:
                                                        return True

                                                    if self.attribute_reuse_id_node is not None:
                                                        return True

                                                    if self.attribute_reuse_id_recover_sec is not None:
                                                        return True

                                                    if self.common_attributes is not None and self.common_attributes._has_data():
                                                        return True

                                                    if self.is_application_gateway_present is not None:
                                                        return True

                                                    if self.is_as_path2_byte is not None:
                                                        return True

                                                    if self.is_attr_set_present is not None:
                                                        return True

                                                    if self.is_ribrnh_present is not None:
                                                        return True

                                                    if self.is_rnh_present is not None:
                                                        return True

                                                    if self.ribrnh_encap is not None:
                                                        return True

                                                    if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                        return True

                                                    if self.ribrnh_mac is not None:
                                                        return True

                                                    if self.ribrnh_table is not None:
                                                        return True

                                                    if self.ribrnh_vni is not None:
                                                        return True

                                                    if self.ribrnhip_table is not None:
                                                        return True

                                                    if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                        return True

                                                    if self.rnh_addr_len is not None:
                                                        return True

                                                    if self.rnh_len is not None:
                                                        return True

                                                    if self.rnh_type is not None:
                                                        return True

                                                    if self.set_aigp_inbound_igp is not None:
                                                        return True

                                                    if self.set_aigp_inbound_metric is not None:
                                                        return True

                                                    if self.vpn_distinguisher is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:adv-path-info'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.af_name is not None:
                                                    return True

                                                if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                    return True

                                                if self.attributes_after_policy_out is not None and self.attributes_after_policy_out._has_data():
                                                    return True

                                                if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                    return True

                                                if self.no_path is not None:
                                                    return True

                                                if self.path_info_after_policy_in is not None and self.path_info_after_policy_in._has_data():
                                                    return True

                                                if self.path_info_after_policy_out is not None and self.path_info_after_policy_out._has_data():
                                                    return True

                                                if self.route_distinguisher is not None:
                                                    return True

                                                if self.source_route_distinguisher is not None:
                                                    return True

                                                if self.vrf_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertised-path'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.adv_path_info is not None:
                                                for child_ref in self.adv_path_info:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.neighbor_address is not None:
                                                return True

                                            if self.network is not None:
                                                return True

                                            if self.paths is not None:
                                                for child_ref in self.paths:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.prefix_length is not None:
                                                return True

                                            if self.rd is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertised-paths'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.advertised_path is not None:
                                            for child_ref in self.advertised_path:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths']['meta_info']


                                class NeighborAfTable(object):
                                    """
                                    The BGP Neighbor AF table
                                    
                                    .. attribute:: neighbor
                                    
                                    	A BGP Neighbor table entry
                                    	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.neighbor = YList()
                                        self.neighbor.parent = self
                                        self.neighbor.name = 'neighbor'


                                    class Neighbor(object):
                                        """
                                        A BGP Neighbor table entry
                                        
                                        .. attribute:: neighbor_address  <key>
                                        
                                        	Neighbor address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: active_bmp_servers
                                        
                                        	BMP Servers to which the neighbor sends logs
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: actual_last_write_bytes
                                        
                                        	Actual size of last write
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: actual_last_write_reset_bytes
                                        
                                        	Actual size of last write before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: actual_second_last_write_bytes
                                        
                                        	Actual size of second last write
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: actual_second_last_write_reset_bytes
                                        
                                        	Actual size of second last write before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: af_data
                                        
                                        	Address family specific neighbor data
                                        	**type**\: list of    :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData>`
                                        
                                        .. attribute:: attempted_last_write_bytes
                                        
                                        	Attempted size of last write
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attempted_last_write_reset_bytes
                                        
                                        	Attempted size of last write before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attempted_second_last_write_bytes
                                        
                                        	Attempted size of second last write
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attempted_second_last_write_reset_bytes
                                        
                                        	Attempted size of second last write before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bfd_minintervalval
                                        
                                        	BFD Mininterval for this peer
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bfd_multiplierval
                                        
                                        	BFD Multiplier for this peer
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bfd_session_created_state
                                        
                                        	BFD state for this peer
                                        	**type**\:   :py:class:`BgpBfdStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdStateEnum>`
                                        
                                        .. attribute:: bfd_session_enable_mode
                                        
                                        	BFD enable mode for this peer
                                        	**type**\:   :py:class:`BgpBfdEnableModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdEnableModeEnum>`
                                        
                                        .. attribute:: bfd_session_state
                                        
                                        	BFD state for this peer
                                        	**type**\:   :py:class:`BgpBfdStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdStateEnum>`
                                        
                                        .. attribute:: bfd_state_ts
                                        
                                        	Timestamp since when nbr is in this bfd state
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bytes_read
                                        
                                        	Total bytes read
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bytes_written
                                        
                                        	Total bytes written by write thread
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: configured_hold_time
                                        
                                        	Hold time (in secs) configured for this connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: configured_keepalive
                                        
                                        	Keepalive time (in secs) configured for this connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: configured_min_acc_hold_time
                                        
                                        	Minimum acceptable hold time from neighbor (in secs) configured for this connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: connect_retry_interval
                                        
                                        	Time (in secs) for connect retry timer
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: connection_admin_status
                                        
                                        	Administrative status of connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: connection_down_count
                                        
                                        	Number of times connection was dropped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: connection_established_time
                                        
                                        	Time (in secs) that the connection has been established
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: connection_local_address
                                        
                                        	Local address for the connection
                                        	**type**\:   :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress>`
                                        
                                        .. attribute:: connection_local_port
                                        
                                        	Local port for the connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: connection_remote_address
                                        
                                        	Remote address for the connection
                                        	**type**\:   :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress>`
                                        
                                        .. attribute:: connection_remote_port
                                        
                                        	Remote port for the connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: connection_state
                                        
                                        	State of connection
                                        	**type**\:   :py:class:`BgpConnStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnStateEnum>`
                                        
                                        .. attribute:: connection_up_count
                                        
                                        	Number of times the connection was established
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: count_last_write
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: description
                                        
                                        	Description
                                        	**type**\:  str
                                        
                                        .. attribute:: discard_as4_path
                                        
                                        	Discard AS4\_PATH in case there is a discrepancy in merging AS\_PATH and AS4\_PATH,retain ASPATH
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: discard_data_bytes
                                        
                                        	Remaining discard data (bytes) on Standby
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: dmz_link_bandwidth
                                        
                                        	Bandwidth of link to single\-hop eBGP peer
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: dynamic_neighbor
                                        
                                        	Dynamic neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: ebgp_recv_dmz
                                        
                                        	Receive Bandwidth of link to single\-hop eBGP peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: ebgp_send_dmz_mode
                                        
                                        	Ebgp send dmz link bw mode
                                        	**type**\:   :py:class:`BgpEbgpSendDmzEnableModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableModeEnum>`
                                        
                                        .. attribute:: ebgp_time_to_live
                                        
                                        	Maximum number of hops for external BGP neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: egress_peer_engineering_enabled
                                        
                                        	Indicates if Egress Peer Engineering is enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: error_notifies_received
                                        
                                        	Number of error notifications received on the connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: error_notifies_sent
                                        
                                        	Number of error notifications sent on the connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fpbsn_offset
                                        
                                        	First standby PDU boundary SeqNo offset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fssn_offset
                                        
                                        	First standby SeqNo offset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: gr_restart_time
                                        
                                        	Neighbor restart time (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: gr_stale_path_time
                                        
                                        	Neighbor stale\-path time (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: graceful_maintenance
                                        
                                        	Graceful Maintenance
                                        	**type**\:   :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance>`
                                        
                                        .. attribute:: graceful_restart_enabled_nbr
                                        
                                        	Neighbor supports graceful\-restart
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_internal_link
                                        
                                        	Internal link to neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: hold_time
                                        
                                        	Hold time (in secs) negotiated for this connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: ignore_connected
                                        
                                        	If true, the VPN client isan IBGP CE peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: internal_vpn_client
                                        
                                        	If true, don't do NHconnected check for nbr
                                        	**type**\:  bool
                                        
                                        .. attribute:: io_armed
                                        
                                        	If true, socket has beenauto\-armed for io control
                                        	**type**\:  bool
                                        
                                        .. attribute:: is4_byte_as_capability_received
                                        
                                        	4\-byte AScapability received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is4_byte_as_capability_sent
                                        
                                        	4\-byte AScapability Snt
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_administratively_shut_down
                                        
                                        	Neighbor is administratively shut down
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_capability_negotiation_performed
                                        
                                        	Capability negotiation performed
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_capability_negotiation_suppressed
                                        
                                        	Capability negotiation suppressed
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ebgp_multihop_bgpmpls_forwarding_disabled
                                        
                                        	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ebgp_peer_as_league
                                        
                                        	EBGP peer belongs to AS League
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ebgp_peer_common_admin
                                        
                                        	EBGP peer with common administation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_external_neighbor_not_directly_connected
                                        
                                        	External neighbor not directly connected
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_gr_aware
                                        
                                        	GR awareness received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_local_address_configured
                                        
                                        	Local address configured for the neighbor connection
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_max_prefix_shutdown
                                        
                                        	Neighbor shut down because it exceeded max prfx count
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_out_of_memory_forced_up
                                        
                                        	Neighbor forced up during a low memory condition
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_out_of_memory_shutdown
                                        
                                        	Neighbor shut down during a SEVERE low memory condition
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_passive_close
                                        
                                        	If true, active socket canbe closed if passive openis received for a GRcapable neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_read_disabled
                                        
                                        	If true, socket read isdisabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_route_refresh_capability_received
                                        
                                        	Route refresh capability received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_route_refresh_old_capability_received
                                        
                                        	Route refresh old capability received
                                        	**type**\:  bool
                                        
                                        .. attribute:: keep_alive_time
                                        
                                        	Keepalive time (in secs) negotiated for this connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_ackd_seq_no
                                        
                                        	SeqNo of the last Ackd byte
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_k_aerror_reset
                                        
                                        	Duration (in secs) since last time that an error was encountered after KA expiry
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_k_aexpiry_reset
                                        
                                        	Time (in secs) since last KA timer expiry before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_k_anotsent_reset
                                        
                                        	Duration (in secs) since last time that KA was not sent before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_k_astart_reset
                                        
                                        	Time (in secs) since the last KA timer start before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_notify_error_code
                                        
                                        	Code for the last error notification seen on the connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: last_notify_error_subcode
                                        
                                        	Error subcode of the last error notification seen on the connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: last_write_event
                                        
                                        	Time (in secs) since last write thread event
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: local_as
                                        
                                        	Local AS number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_as_dual_as
                                        
                                        	Local AS Dual\-AS option
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_as_dual_as_mode_native
                                        
                                        	Applies only if Local AS Dual\-AS option is enabled. Indicates if Dual\-AS mode is native
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_as_no_prepend
                                        
                                        	Option to not prepend the Local AS to announcements
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_as_replace_as
                                        
                                        	Local AS Replace\-AS option
                                        	**type**\:  bool
                                        
                                        .. attribute:: message_statistics
                                        
                                        	Message statistics
                                        	**type**\:   :py:class:`MessageStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics>`
                                        
                                        .. attribute:: messages_queued_in
                                        
                                        	No. of msgs on receive queue
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: messages_queued_out
                                        
                                        	No. of messages on send queue
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: messages_received
                                        
                                        	Number of messages received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: messages_sent
                                        
                                        	Number of messages sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: min_advertise_interval
                                        
                                        	Minimum advertisement interval, secs part
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: min_advertise_interval_msecs
                                        
                                        	Minimum advertisement interval, msecs part
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: min_origination_interval
                                        
                                        	Minimum origination interval (in secs)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: msg_log_in
                                        
                                        	Message in log count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: msg_log_out
                                        
                                        	Message out log count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multi_protocol_capability_received
                                        
                                        	Multi\-protocol capability has been received
                                        	**type**\:  bool
                                        
                                        .. attribute:: nbr_cluster_id
                                        
                                        	Cluster id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nbr_enforce_first_as
                                        
                                        	Neighbor enforce first AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: nbr_in_cluster
                                        
                                        	Type of cluster\_id\:undefined/number/Ip address
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: negotiated_protocol_version
                                        
                                        	Negotiated protocol version
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: neighbor_interface_handle
                                        
                                        	Interface Handle of Neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_local_as
                                        
                                        	Local AS configured on the neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nsr_enabled
                                        
                                        	Neighbor supports NSR
                                        	**type**\:  bool
                                        
                                        .. attribute:: nsr_state
                                        
                                        	NSR state
                                        	**type**\:   :py:class:`BgpSyncNbrNsrStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrStateEnum>`
                                        
                                        .. attribute:: open_check_error_code
                                        
                                        	Open check error code
                                        	**type**\:   :py:class:`BgpOpenCheckErrEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpOpenCheckErrEnum>`
                                        
                                        .. attribute:: peer_error_code
                                        
                                        	If peer closed, error received from transport
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: peer_reset_reason
                                        
                                        	Reason for last peer close event
                                        	**type**\:   :py:class:`BgpPeerResetReasonIndexEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPeerResetReasonIndexEnum>`
                                        
                                        .. attribute:: performance_statistics
                                        
                                        	Performance statistics
                                        	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics>`
                                        
                                        .. attribute:: previous_connection_state
                                        
                                        	Previous state of connection
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: read_armed
                                        
                                        	If true, socket has beenauto\-armed for read
                                        	**type**\:  bool
                                        
                                        .. attribute:: received_notification_info
                                        
                                        	Information on the last notification received
                                        	**type**\:   :py:class:`ReceivedNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo>`
                                        
                                        .. attribute:: remote_as
                                        
                                        	Remote AS number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_as_number
                                        
                                        	Remote AS number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reset_notification_sent
                                        
                                        	Notification was sent during last reset
                                        	**type**\:  bool
                                        
                                        .. attribute:: reset_reason
                                        
                                        	Reason for last connection reset
                                        	**type**\:   :py:class:`BgpResetReasonIndexEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndexEnum>`
                                        
                                        .. attribute:: router_id
                                        
                                        	Router ID for the neighbor
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rpki_allow_invalid
                                        
                                        	Prefix v. allow invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: rpki_disable
                                        
                                        	Prefix validation disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: rpki_signal_ibgp
                                        
                                        	Prefix v. signal ibgp
                                        	**type**\:  bool
                                        
                                        .. attribute:: rpki_use_validity
                                        
                                        	Prefix v. use validity
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_last_k_aexpiry_reset
                                        
                                        	Time (in secs) since second last KA timer expiry before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: second_last_k_astart_reset
                                        
                                        	Time (in secs) since the second last KA timer start before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: second_last_write_event
                                        
                                        	Time (in secs) since second last write thread event
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: send_notification_info
                                        
                                        	Information on the last notification sent
                                        	**type**\:   :py:class:`SendNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo>`
                                        
                                        .. attribute:: socket_read_bytes
                                        
                                        	Total read bytes value insocket\-lib
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: speaker_id
                                        
                                        	Speaker this neighbor is allocated to
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: standby_rp
                                        
                                        	Standby RP socket inited for Active Open
                                        	**type**\:  bool
                                        
                                        .. attribute:: suppress4_byte_as
                                        
                                        	Suppress 4byteas capability
                                        	**type**\:  bool
                                        
                                        .. attribute:: tcp_init_sync_done_time_spec
                                        
                                        	Time when neighbor entered TCP Init Sync Done
                                        	**type**\:   :py:class:`TcpInitSyncDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec>`
                                        
                                        .. attribute:: tcp_init_sync_phase_two_time_spec
                                        
                                        	Time when neighbor entered TCP Init Sync Phase Two
                                        	**type**\:   :py:class:`TcpInitSyncPhaseTwoTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec>`
                                        
                                        .. attribute:: tcp_init_sync_time_spec
                                        
                                        	Time When neighbor entered TCP Init Sync
                                        	**type**\:   :py:class:`TcpInitSyncTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec>`
                                        
                                        .. attribute:: tcp_session_open_mode
                                        
                                        	The TCP mode to be used to set up BGP session with the neighbor
                                        	**type**\:   :py:class:`BgpTcpModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpModeEnum>`
                                        
                                        .. attribute:: tcpmss
                                        
                                        	Neighbor TCP Maximum Segment                     size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_last_cb
                                        
                                        	CB
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: time_last_cb_reset
                                        
                                        	Last CB before reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_last_fb
                                        
                                        	FB
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: time_since_connection_last_dropped
                                        
                                        	Time since the connection last went down (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_since_last_read
                                        
                                        	Time (in secs) since last read
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_since_last_read_reset
                                        
                                        	Time (in secs) since last read before last reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_since_last_update
                                        
                                        	Time (in secs) since last update message was received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_since_last_write
                                        
                                        	Time (in secs) since last write
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_since_last_write_reset
                                        
                                        	Time (in secs) since last write before last reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_since_second_last_write
                                        
                                        	Time (in secs) since second  last write
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_since_second_last_write_reset
                                        
                                        	Time (in secs) since last write before last reset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: tos_type
                                        
                                        	Precedence or DSCP type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: tos_value
                                        
                                        	Precedence or DSCP value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ttl_security_enabled
                                        
                                        	TTL Security enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: update_bytes_read
                                        
                                        	Total update bytes read
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: update_messages_in
                                        
                                        	No. of update msgs received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_messages_out
                                        
                                        	No. of update messages sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: write_armed
                                        
                                        	If true, socket has beenauto\-armed for write
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.neighbor_address = None
                                            self.active_bmp_servers = None
                                            self.actual_last_write_bytes = None
                                            self.actual_last_write_reset_bytes = None
                                            self.actual_second_last_write_bytes = None
                                            self.actual_second_last_write_reset_bytes = None
                                            self.af_data = YList()
                                            self.af_data.parent = self
                                            self.af_data.name = 'af_data'
                                            self.attempted_last_write_bytes = None
                                            self.attempted_last_write_reset_bytes = None
                                            self.attempted_second_last_write_bytes = None
                                            self.attempted_second_last_write_reset_bytes = None
                                            self.bfd_minintervalval = None
                                            self.bfd_multiplierval = None
                                            self.bfd_session_created_state = None
                                            self.bfd_session_enable_mode = None
                                            self.bfd_session_state = None
                                            self.bfd_state_ts = None
                                            self.bytes_read = None
                                            self.bytes_written = None
                                            self.configured_hold_time = None
                                            self.configured_keepalive = None
                                            self.configured_min_acc_hold_time = None
                                            self.connect_retry_interval = None
                                            self.connection_admin_status = None
                                            self.connection_down_count = None
                                            self.connection_established_time = None
                                            self.connection_local_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress()
                                            self.connection_local_address.parent = self
                                            self.connection_local_port = None
                                            self.connection_remote_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress()
                                            self.connection_remote_address.parent = self
                                            self.connection_remote_port = None
                                            self.connection_state = None
                                            self.connection_up_count = None
                                            self.count_last_write = None
                                            self.description = None
                                            self.discard_as4_path = None
                                            self.discard_data_bytes = None
                                            self.dmz_link_bandwidth = None
                                            self.dynamic_neighbor = None
                                            self.ebgp_recv_dmz = None
                                            self.ebgp_send_dmz_mode = None
                                            self.ebgp_time_to_live = None
                                            self.egress_peer_engineering_enabled = None
                                            self.error_notifies_received = None
                                            self.error_notifies_sent = None
                                            self.fpbsn_offset = None
                                            self.fssn_offset = None
                                            self.gr_restart_time = None
                                            self.gr_stale_path_time = None
                                            self.graceful_maintenance = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance()
                                            self.graceful_maintenance.parent = self
                                            self.graceful_restart_enabled_nbr = None
                                            self.has_internal_link = None
                                            self.hold_time = None
                                            self.ignore_connected = None
                                            self.internal_vpn_client = None
                                            self.io_armed = None
                                            self.is4_byte_as_capability_received = None
                                            self.is4_byte_as_capability_sent = None
                                            self.is_administratively_shut_down = None
                                            self.is_capability_negotiation_performed = None
                                            self.is_capability_negotiation_suppressed = None
                                            self.is_ebgp_multihop_bgpmpls_forwarding_disabled = None
                                            self.is_ebgp_peer_as_league = None
                                            self.is_ebgp_peer_common_admin = None
                                            self.is_external_neighbor_not_directly_connected = None
                                            self.is_gr_aware = None
                                            self.is_local_address_configured = None
                                            self.is_neighbor_max_prefix_shutdown = None
                                            self.is_out_of_memory_forced_up = None
                                            self.is_out_of_memory_shutdown = None
                                            self.is_passive_close = None
                                            self.is_read_disabled = None
                                            self.is_route_refresh_capability_received = None
                                            self.is_route_refresh_old_capability_received = None
                                            self.keep_alive_time = None
                                            self.last_ackd_seq_no = None
                                            self.last_k_aerror_reset = None
                                            self.last_k_aexpiry_reset = None
                                            self.last_k_anotsent_reset = None
                                            self.last_k_astart_reset = None
                                            self.last_notify_error_code = None
                                            self.last_notify_error_subcode = None
                                            self.last_write_event = None
                                            self.local_as = None
                                            self.local_as_dual_as = None
                                            self.local_as_dual_as_mode_native = None
                                            self.local_as_no_prepend = None
                                            self.local_as_replace_as = None
                                            self.message_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics()
                                            self.message_statistics.parent = self
                                            self.messages_queued_in = None
                                            self.messages_queued_out = None
                                            self.messages_received = None
                                            self.messages_sent = None
                                            self.min_advertise_interval = None
                                            self.min_advertise_interval_msecs = None
                                            self.min_origination_interval = None
                                            self.msg_log_in = None
                                            self.msg_log_out = None
                                            self.multi_protocol_capability_received = None
                                            self.nbr_cluster_id = None
                                            self.nbr_enforce_first_as = None
                                            self.nbr_in_cluster = None
                                            self.negotiated_protocol_version = None
                                            self.neighbor_interface_handle = None
                                            self.neighbor_local_as = None
                                            self.nsr_enabled = None
                                            self.nsr_state = None
                                            self.open_check_error_code = None
                                            self.peer_error_code = None
                                            self.peer_reset_reason = None
                                            self.performance_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics()
                                            self.performance_statistics.parent = self
                                            self.previous_connection_state = None
                                            self.read_armed = None
                                            self.received_notification_info = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo()
                                            self.received_notification_info.parent = self
                                            self.remote_as = None
                                            self.remote_as_number = None
                                            self.reset_notification_sent = None
                                            self.reset_reason = None
                                            self.router_id = None
                                            self.rpki_allow_invalid = None
                                            self.rpki_disable = None
                                            self.rpki_signal_ibgp = None
                                            self.rpki_use_validity = None
                                            self.second_last_k_aexpiry_reset = None
                                            self.second_last_k_astart_reset = None
                                            self.second_last_write_event = None
                                            self.send_notification_info = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo()
                                            self.send_notification_info.parent = self
                                            self.socket_read_bytes = None
                                            self.speaker_id = None
                                            self.standby_rp = None
                                            self.suppress4_byte_as = None
                                            self.tcp_init_sync_done_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec()
                                            self.tcp_init_sync_done_time_spec.parent = self
                                            self.tcp_init_sync_phase_two_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec()
                                            self.tcp_init_sync_phase_two_time_spec.parent = self
                                            self.tcp_init_sync_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec()
                                            self.tcp_init_sync_time_spec.parent = self
                                            self.tcp_session_open_mode = None
                                            self.tcpmss = None
                                            self.time_last_cb = None
                                            self.time_last_cb_reset = None
                                            self.time_last_fb = None
                                            self.time_since_connection_last_dropped = None
                                            self.time_since_last_read = None
                                            self.time_since_last_read_reset = None
                                            self.time_since_last_update = None
                                            self.time_since_last_write = None
                                            self.time_since_last_write_reset = None
                                            self.time_since_second_last_write = None
                                            self.time_since_second_last_write_reset = None
                                            self.tos_type = None
                                            self.tos_value = None
                                            self.ttl_security_enabled = None
                                            self.update_bytes_read = None
                                            self.update_messages_in = None
                                            self.update_messages_out = None
                                            self.vrf_name = None
                                            self.write_armed = None


                                        class ConnectionLocalAddress(object):
                                            """
                                            Local address for the connection
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connection-local-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress']['meta_info']


                                        class ConnectionRemoteAddress(object):
                                            """
                                            Remote address for the connection
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connection-remote-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress']['meta_info']


                                        class SendNotificationInfo(object):
                                            """
                                            Information on the last notification sent
                                            
                                            .. attribute:: last_notification_data
                                            
                                            	Message data in last notification
                                            	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData>`
                                            
                                            .. attribute:: notification_error_code
                                            
                                            	Error code in last notification
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: notification_error_subcode
                                            
                                            	Error subcode in last notification
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: time_since_last_notification
                                            
                                            	Time since the last notification was sent or received (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.last_notification_data = YList()
                                                self.last_notification_data.parent = self
                                                self.last_notification_data.name = 'last_notification_data'
                                                self.notification_error_code = None
                                                self.notification_error_subcode = None
                                                self.time_since_last_notification = None


                                            class LastNotificationData(object):
                                                """
                                                Message data in last notification
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-notification-data'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:send-notification-info'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.last_notification_data is not None:
                                                    for child_ref in self.last_notification_data:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.notification_error_code is not None:
                                                    return True

                                                if self.notification_error_subcode is not None:
                                                    return True

                                                if self.time_since_last_notification is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo']['meta_info']


                                        class ReceivedNotificationInfo(object):
                                            """
                                            Information on the last notification received
                                            
                                            .. attribute:: last_notification_data
                                            
                                            	Message data in last notification
                                            	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData>`
                                            
                                            .. attribute:: notification_error_code
                                            
                                            	Error code in last notification
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: notification_error_subcode
                                            
                                            	Error subcode in last notification
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: time_since_last_notification
                                            
                                            	Time since the last notification was sent or received (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.last_notification_data = YList()
                                                self.last_notification_data.parent = self
                                                self.last_notification_data.name = 'last_notification_data'
                                                self.notification_error_code = None
                                                self.notification_error_subcode = None
                                                self.time_since_last_notification = None


                                            class LastNotificationData(object):
                                                """
                                                Message data in last notification
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-notification-data'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:received-notification-info'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.last_notification_data is not None:
                                                    for child_ref in self.last_notification_data:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.notification_error_code is not None:
                                                    return True

                                                if self.notification_error_subcode is not None:
                                                    return True

                                                if self.time_since_last_notification is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo']['meta_info']


                                        class PerformanceStatistics(object):
                                            """
                                            Performance statistics
                                            
                                            .. attribute:: active_collision
                                            
                                            	Number of Closed Active connections for this neighbor due to collision 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: actives
                                            
                                            	Number of retried Active opens for this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: control_to_read_thread_trigger
                                            
                                            	Number of times io\-control thread trigger read thread
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: control_to_write_thread_trigger
                                            
                                            	Number of times io\-control thread trigger write thread
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: data_bytes_read
                                            
                                            	No. of bytes of data read
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: data_bytes_written
                                            
                                            	No. of data bytes written
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: failed_post_actives
                                            
                                            	Number of Active Opens that failed in the Post Active State for this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: high_throttled_read
                                            
                                            	Num of socket reads after nbr crossed high threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: inbound_update_messages
                                            
                                            	Number of inbound update messages processed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: inbound_update_messages_time
                                            
                                            	Time spent processing inbound update messages (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: io_read_time
                                            
                                            	Time spent reading inbound data (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: io_write_time
                                            
                                            	Time spent writing outbound data (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: last_nsr_scoped_sync
                                            
                                            	Last time NSR scoped syncwas done for the neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_sent_seq_no
                                            
                                            	Seq No of the last sent byte
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: low_throttled_read
                                            
                                            	Num socket reads after nbrs crossed low threshold
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_read_size
                                            
                                            	Size of largest socket (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: nbr_fd
                                            
                                            	Primary FD, per nbr
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: nbr_flags
                                            
                                            	Nbr flags, per thread
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: network_status
                                            
                                            	Socket status, TRUE if socket closed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nsr_oper_down_count
                                            
                                            	Number of times NSR scoped sync has been done
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: passive_collision
                                            
                                            	Number of Closed Remote opens for this neighborneighbor due to collision 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: passives
                                            
                                            	Number of retried Passive opens for this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: read_calls_count
                                            
                                            	No. of calls to function to read inbound data
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: read_messages_count
                                            
                                            	Number of BGP messages read
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: read_throttles
                                            
                                            	Number of partial read throttles
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rejected_passives
                                            
                                            	Number of rejected Passive opens for this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reset_flags
                                            
                                            	Reset flags, per thread
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reset_retries
                                            
                                            	Reset Retries, per nbr
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: subgroup_list_time
                                            
                                            	Time spent processing sub\-group message list  (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: sync_flags
                                            
                                            	Sync flags, per nbr
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_since_last_throttled_read
                                            
                                            	Time (in secs) since last read after being throttled
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: write_calls_count
                                            
                                            	No. of calls to function to write outbound data
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: write_queue_calls_count
                                            
                                            	No. of calls to function to process write queue
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: write_queue_messages_count
                                            
                                            	Number of write queue messages processed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: write_queue_time
                                            
                                            	Time spent processing write queue (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: write_subgroup_calls_count
                                            
                                            	No. of calls to function to process sub\-group message list
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: write_subgroup_messages_count
                                            
                                            	Number of sub\-group msgs processed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.active_collision = None
                                                self.actives = None
                                                self.control_to_read_thread_trigger = None
                                                self.control_to_write_thread_trigger = None
                                                self.data_bytes_read = None
                                                self.data_bytes_written = None
                                                self.failed_post_actives = None
                                                self.high_throttled_read = None
                                                self.inbound_update_messages = None
                                                self.inbound_update_messages_time = None
                                                self.io_read_time = None
                                                self.io_write_time = None
                                                self.last_nsr_scoped_sync = None
                                                self.last_sent_seq_no = None
                                                self.low_throttled_read = None
                                                self.maximum_read_size = None
                                                self.nbr_fd = None
                                                self.nbr_flags = None
                                                self.network_status = None
                                                self.nsr_oper_down_count = None
                                                self.passive_collision = None
                                                self.passives = None
                                                self.read_calls_count = None
                                                self.read_messages_count = None
                                                self.read_throttles = None
                                                self.rejected_passives = None
                                                self.reset_flags = None
                                                self.reset_retries = None
                                                self.subgroup_list_time = None
                                                self.sync_flags = None
                                                self.time_since_last_throttled_read = None
                                                self.write_calls_count = None
                                                self.write_queue_calls_count = None
                                                self.write_queue_messages_count = None
                                                self.write_queue_time = None
                                                self.write_subgroup_calls_count = None
                                                self.write_subgroup_messages_count = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:performance-statistics'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.active_collision is not None:
                                                    return True

                                                if self.actives is not None:
                                                    return True

                                                if self.control_to_read_thread_trigger is not None:
                                                    return True

                                                if self.control_to_write_thread_trigger is not None:
                                                    return True

                                                if self.data_bytes_read is not None:
                                                    return True

                                                if self.data_bytes_written is not None:
                                                    return True

                                                if self.failed_post_actives is not None:
                                                    return True

                                                if self.high_throttled_read is not None:
                                                    return True

                                                if self.inbound_update_messages is not None:
                                                    return True

                                                if self.inbound_update_messages_time is not None:
                                                    return True

                                                if self.io_read_time is not None:
                                                    return True

                                                if self.io_write_time is not None:
                                                    return True

                                                if self.last_nsr_scoped_sync is not None:
                                                    return True

                                                if self.last_sent_seq_no is not None:
                                                    return True

                                                if self.low_throttled_read is not None:
                                                    return True

                                                if self.maximum_read_size is not None:
                                                    return True

                                                if self.nbr_fd is not None:
                                                    return True

                                                if self.nbr_flags is not None:
                                                    return True

                                                if self.network_status is not None:
                                                    return True

                                                if self.nsr_oper_down_count is not None:
                                                    return True

                                                if self.passive_collision is not None:
                                                    return True

                                                if self.passives is not None:
                                                    return True

                                                if self.read_calls_count is not None:
                                                    return True

                                                if self.read_messages_count is not None:
                                                    return True

                                                if self.read_throttles is not None:
                                                    return True

                                                if self.rejected_passives is not None:
                                                    return True

                                                if self.reset_flags is not None:
                                                    return True

                                                if self.reset_retries is not None:
                                                    return True

                                                if self.subgroup_list_time is not None:
                                                    return True

                                                if self.sync_flags is not None:
                                                    return True

                                                if self.time_since_last_throttled_read is not None:
                                                    return True

                                                if self.write_calls_count is not None:
                                                    return True

                                                if self.write_queue_calls_count is not None:
                                                    return True

                                                if self.write_queue_messages_count is not None:
                                                    return True

                                                if self.write_queue_time is not None:
                                                    return True

                                                if self.write_subgroup_calls_count is not None:
                                                    return True

                                                if self.write_subgroup_messages_count is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics']['meta_info']


                                        class MessageStatistics(object):
                                            """
                                            Message statistics
                                            
                                            .. attribute:: keepalive
                                            
                                            	Keepalive
                                            	**type**\:   :py:class:`Keepalive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive>`
                                            
                                            .. attribute:: notification
                                            
                                            	Notification
                                            	**type**\:   :py:class:`Notification <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification>`
                                            
                                            .. attribute:: open
                                            
                                            	Open
                                            	**type**\:   :py:class:`Open <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open>`
                                            
                                            .. attribute:: route_refresh
                                            
                                            	Route refresh
                                            	**type**\:   :py:class:`RouteRefresh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh>`
                                            
                                            .. attribute:: total
                                            
                                            	Total
                                            	**type**\:   :py:class:`Total <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total>`
                                            
                                            .. attribute:: update
                                            
                                            	Update
                                            	**type**\:   :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.keepalive = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive()
                                                self.keepalive.parent = self
                                                self.notification = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification()
                                                self.notification.parent = self
                                                self.open = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open()
                                                self.open.parent = self
                                                self.route_refresh = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh()
                                                self.route_refresh.parent = self
                                                self.total = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total()
                                                self.total.parent = self
                                                self.update = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update()
                                                self.update.parent = self


                                            class Open(object):
                                                """
                                                Open
                                                
                                                .. attribute:: rx
                                                
                                                	Receive
                                                	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx>`
                                                
                                                .. attribute:: tx
                                                
                                                	Transmit
                                                	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.rx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx()
                                                    self.rx.parent = self
                                                    self.tx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx()
                                                    self.tx.parent = self


                                                class Tx(object):
                                                    """
                                                    Transmit
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.count = None
                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec()
                                                        self.last_time_spec.parent = self


                                                    class LastTimeSpec(object):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.nanoseconds = None
                                                            self.seconds = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.nanoseconds is not None:
                                                                return True

                                                            if self.seconds is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.count is not None:
                                                            return True

                                                        if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx']['meta_info']


                                                class Rx(object):
                                                    """
                                                    Receive
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.count = None
                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec()
                                                        self.last_time_spec.parent = self


                                                    class LastTimeSpec(object):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.nanoseconds = None
                                                            self.seconds = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.nanoseconds is not None:
                                                                return True

                                                            if self.seconds is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.count is not None:
                                                            return True

                                                        if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:open'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.rx is not None and self.rx._has_data():
                                                        return True

                                                    if self.tx is not None and self.tx._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open']['meta_info']


                                            class Notification(object):
                                                """
                                                Notification
                                                
                                                .. attribute:: rx
                                                
                                                	Receive
                                                	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx>`
                                                
                                                .. attribute:: tx
                                                
                                                	Transmit
                                                	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.rx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx()
                                                    self.rx.parent = self
                                                    self.tx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx()
                                                    self.tx.parent = self


                                                class Tx(object):
                                                    """
                                                    Transmit
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.count = None
                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec()
                                                        self.last_time_spec.parent = self


                                                    class LastTimeSpec(object):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.nanoseconds = None
                                                            self.seconds = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.nanoseconds is not None:
                                                                return True

                                                            if self.seconds is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.count is not None:
                                                            return True

                                                        if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx']['meta_info']


                                                class Rx(object):
                                                    """
                                                    Receive
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.count = None
                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec()
                                                        self.last_time_spec.parent = self


                                                    class LastTimeSpec(object):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.nanoseconds = None
                                                            self.seconds = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.nanoseconds is not None:
                                                                return True

                                                            if self.seconds is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.count is not None:
                                                            return True

                                                        if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:notification'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.rx is not None and self.rx._has_data():
                                                        return True

                                                    if self.tx is not None and self.tx._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification']['meta_info']


                                            class Update(object):
                                                """
                                                Update
                                                
                                                .. attribute:: rx
                                                
                                                	Receive
                                                	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx>`
                                                
                                                .. attribute:: tx
                                                
                                                	Transmit
                                                	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.rx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx()
                                                    self.rx.parent = self
                                                    self.tx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx()
                                                    self.tx.parent = self


                                                class Tx(object):
                                                    """
                                                    Transmit
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.count = None
                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec()
                                                        self.last_time_spec.parent = self


                                                    class LastTimeSpec(object):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.nanoseconds = None
                                                            self.seconds = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.nanoseconds is not None:
                                                                return True

                                                            if self.seconds is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.count is not None:
                                                            return True

                                                        if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx']['meta_info']


                                                class Rx(object):
                                                    """
                                                    Receive
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.count = None
                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec()
                                                        self.last_time_spec.parent = self


                                                    class LastTimeSpec(object):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.nanoseconds = None
                                                            self.seconds = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.nanoseconds is not None:
                                                                return True

                                                            if self.seconds is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.count is not None:
                                                            return True

                                                        if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.rx is not None and self.rx._has_data():
                                                        return True

                                                    if self.tx is not None and self.tx._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update']['meta_info']


                                            class Keepalive(object):
                                                """
                                                Keepalive
                                                
                                                .. attribute:: rx
                                                
                                                	Receive
                                                	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx>`
                                                
                                                .. attribute:: tx
                                                
                                                	Transmit
                                                	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.rx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx()
                                                    self.rx.parent = self
                                                    self.tx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx()
                                                    self.tx.parent = self


                                                class Tx(object):
                                                    """
                                                    Transmit
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.count = None
                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec()
                                                        self.last_time_spec.parent = self


                                                    class LastTimeSpec(object):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.nanoseconds = None
                                                            self.seconds = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.nanoseconds is not None:
                                                                return True

                                                            if self.seconds is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.count is not None:
                                                            return True

                                                        if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx']['meta_info']


                                                class Rx(object):
                                                    """
                                                    Receive
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.count = None
                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec()
                                                        self.last_time_spec.parent = self


                                                    class LastTimeSpec(object):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.nanoseconds = None
                                                            self.seconds = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.nanoseconds is not None:
                                                                return True

                                                            if self.seconds is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.count is not None:
                                                            return True

                                                        if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:keepalive'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.rx is not None and self.rx._has_data():
                                                        return True

                                                    if self.tx is not None and self.tx._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive']['meta_info']


                                            class RouteRefresh(object):
                                                """
                                                Route refresh
                                                
                                                .. attribute:: rx
                                                
                                                	Receive
                                                	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx>`
                                                
                                                .. attribute:: tx
                                                
                                                	Transmit
                                                	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.rx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx()
                                                    self.rx.parent = self
                                                    self.tx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx()
                                                    self.tx.parent = self


                                                class Tx(object):
                                                    """
                                                    Transmit
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.count = None
                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec()
                                                        self.last_time_spec.parent = self


                                                    class LastTimeSpec(object):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.nanoseconds = None
                                                            self.seconds = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.nanoseconds is not None:
                                                                return True

                                                            if self.seconds is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.count is not None:
                                                            return True

                                                        if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx']['meta_info']


                                                class Rx(object):
                                                    """
                                                    Receive
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.count = None
                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec()
                                                        self.last_time_spec.parent = self


                                                    class LastTimeSpec(object):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.nanoseconds = None
                                                            self.seconds = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.nanoseconds is not None:
                                                                return True

                                                            if self.seconds is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.count is not None:
                                                            return True

                                                        if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:route-refresh'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.rx is not None and self.rx._has_data():
                                                        return True

                                                    if self.tx is not None and self.tx._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh']['meta_info']


                                            class Total(object):
                                                """
                                                Total
                                                
                                                .. attribute:: rx
                                                
                                                	Receive
                                                	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx>`
                                                
                                                .. attribute:: tx
                                                
                                                	Transmit
                                                	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.rx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx()
                                                    self.rx.parent = self
                                                    self.tx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx()
                                                    self.tx.parent = self


                                                class Tx(object):
                                                    """
                                                    Transmit
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.count = None
                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec()
                                                        self.last_time_spec.parent = self


                                                    class LastTimeSpec(object):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.nanoseconds = None
                                                            self.seconds = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.nanoseconds is not None:
                                                                return True

                                                            if self.seconds is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.count is not None:
                                                            return True

                                                        if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx']['meta_info']


                                                class Rx(object):
                                                    """
                                                    Receive
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.count = None
                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec()
                                                        self.last_time_spec.parent = self


                                                    class LastTimeSpec(object):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.nanoseconds = None
                                                            self.seconds = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.nanoseconds is not None:
                                                                return True

                                                            if self.seconds is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.count is not None:
                                                            return True

                                                        if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:total'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.rx is not None and self.rx._has_data():
                                                        return True

                                                    if self.tx is not None and self.tx._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:message-statistics'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.keepalive is not None and self.keepalive._has_data():
                                                    return True

                                                if self.notification is not None and self.notification._has_data():
                                                    return True

                                                if self.open is not None and self.open._has_data():
                                                    return True

                                                if self.route_refresh is not None and self.route_refresh._has_data():
                                                    return True

                                                if self.total is not None and self.total._has_data():
                                                    return True

                                                if self.update is not None and self.update._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics']['meta_info']


                                        class TcpInitSyncTimeSpec(object):
                                            """
                                            Time When neighbor entered TCP Init Sync
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tcp-init-sync-time-spec'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec']['meta_info']


                                        class TcpInitSyncPhaseTwoTimeSpec(object):
                                            """
                                            Time when neighbor entered TCP Init Sync Phase
                                            Two
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tcp-init-sync-phase-two-time-spec'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec']['meta_info']


                                        class TcpInitSyncDoneTimeSpec(object):
                                            """
                                            Time when neighbor entered TCP Init Sync Done
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tcp-init-sync-done-time-spec'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec']['meta_info']


                                        class GracefulMaintenance(object):
                                            """
                                            Graceful Maintenance
                                            
                                            .. attribute:: gshut_active
                                            
                                            	Graceful Maintenance activated
                                            	**type**\:  bool
                                            
                                            .. attribute:: gshut_exists
                                            
                                            	Graceful Maintenance enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: gshut_local_active
                                            
                                            	Graceful Maintenance locally activated
                                            	**type**\:  bool
                                            
                                            .. attribute:: gshut_locpref
                                            
                                            	Graceful Maintenance Local Preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: gshut_locpref_set
                                            
                                            	Graceful Maintenance Local Preference set
                                            	**type**\:  bool
                                            
                                            .. attribute:: gshut_prepends
                                            
                                            	Graceful Maintenance number of AS prepends
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.gshut_active = None
                                                self.gshut_exists = None
                                                self.gshut_local_active = None
                                                self.gshut_locpref = None
                                                self.gshut_locpref_set = None
                                                self.gshut_prepends = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:graceful-maintenance'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.gshut_active is not None:
                                                    return True

                                                if self.gshut_exists is not None:
                                                    return True

                                                if self.gshut_local_active is not None:
                                                    return True

                                                if self.gshut_locpref is not None:
                                                    return True

                                                if self.gshut_locpref_set is not None:
                                                    return True

                                                if self.gshut_prepends is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance']['meta_info']


                                        class AfData(object):
                                            """
                                            Address family specific neighbor data
                                            
                                            .. attribute:: accept_own_enabled
                                            
                                            	Accept\-Own enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: acked_version
                                            
                                            	Version mapped from acked seqNo
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: address_family_long_lived_time
                                            
                                            	AF specific Long\-lived\-time config
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertise_afi
                                            
                                            	Encode in Advertise AFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_afi_def_vrf_imp_disable
                                            
                                            	Advertise of default VRF import disable
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_afi_disable
                                            
                                            	Encode in Advertise AFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_afi_eo_r_ready
                                            
                                            	EoR Can be sent for Advertise AFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_afi_reorg
                                            
                                            	Encode in Advertise AFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_afi_vrf_re_imp_disable
                                            
                                            	Advertise of VRF re\-import disable
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_evp_nv4afi_def_vrf_imp_disable
                                            
                                            	Advertise of v4 default VRF import disable
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_evp_nv4afi_vrf_re_imp_disable
                                            
                                            	Advertise of v4 VRF re\-import disable
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_evp_nv6afi_def_vrf_imp_disable
                                            
                                            	Advertise of v6 default VRF import disable
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_evp_nv6afi_vrf_re_imp_disable
                                            
                                            	Advertise of v6 VRF re\-import disable
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_local_labeled_route_unicast
                                            
                                            	Advertise routes with local\-label via Unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: advertise_rt_type
                                            
                                            	Advertise RT type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: advertise_v4_flags
                                            
                                            	Advertise options for VPNV4
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertise_v6_flags
                                            
                                            	Advertise options for VPNV6
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: afrpki_allow_invalid
                                            
                                            	Prefix v. allow invalid
                                            	**type**\:  bool
                                            
                                            .. attribute:: afrpki_disable
                                            
                                            	Prefix validation disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: afrpki_signal_ibgp
                                            
                                            	Prefix v. signal ibgp
                                            	**type**\:  bool
                                            
                                            .. attribute:: afrpki_use_validity
                                            
                                            	Prefix v. use validity
                                            	**type**\:  bool
                                            
                                            .. attribute:: allow_as_in_count
                                            
                                            	Allowas\-in count config
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: always_use_next_hop_local
                                            
                                            	Local router always used for next\-hop
                                            	**type**\:  bool
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation type
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: eo_r_received_in_read_only
                                            
                                            	An EoR was received while in read\-only mode
                                            	**type**\:  bool
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_standby
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunityStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby>`
                                            
                                            .. attribute:: filter_group_index
                                            
                                            	Filter group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: flowspec_redirect_validation_d_isable
                                            
                                            	Flowspec Redirect Validation Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: flowspec_validation_d_isable
                                            
                                            	Flowspec Validation Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: import_reoriginate
                                            
                                            	Import Reoriginate enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: import_reoriginate_stitching
                                            
                                            	Import Reoriginate Stitching enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: import_stitching
                                            
                                            	Import Stitching enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_add_path_receive_capability_advertised
                                            
                                            	Addpath Receive capability advertised
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_add_path_receive_capability_received
                                            
                                            	Addpath Receive capability received
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_add_path_send_capability_advertised
                                            
                                            	Addpath Send capability advertised
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_add_path_send_capability_received
                                            
                                            	Addpath Send capability received
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_addpath_receive_operational
                                            
                                            	Addpath is operational on receive\-side
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_addpath_send_operational
                                            
                                            	Addpath is operational on send\-side
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertise_permanent_network
                                            
                                            	Advertise Permanent Network
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertised_graceful_restart
                                            
                                            	Graceful Restart Capability advertised
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertised_orf_receive
                                            
                                            	Prefix based ORF receive mode capability advertised
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_advertised_orf_send
                                            
                                            	Prefix based ORF send mode capability advertised
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_set
                                            
                                            	AIGP set 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_allow_as_in_set
                                            
                                            	Allowas\-in set 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_override_set
                                            
                                            	As override set 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_default_originate_sent
                                            
                                            	Default origination update sent
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ext_nh_encoding_capability_received
                                            
                                            	Extended nexthop encoding capability received
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ext_nh_encoding_capability_sent
                                            
                                            	Extended nexhop encoding capability Sent
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_graceful_restart_state_flag
                                            
                                            	Restart state flag enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_legacy_pe_rt
                                            
                                            	Nbr accepts route from legacy PE for RT\-Constraint AF 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_af_capable
                                            
                                            	Address family capability received from neighbor
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_ebgp_without_inbound_policy
                                            
                                            	eBGP neighbor with no configured inbound policy
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_ebgp_without_outbound_policy
                                            
                                            	eBGP neighbor with no configured outbound policy
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_neighbor_route_reflector_client
                                            
                                            	Nbr is a route reflector client
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orf_send_scheduled
                                            
                                            	Scheduled to send prefix based ORF
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orf_sent
                                            
                                            	Outbound route filter sent to neighbor
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_orr_root_address_configured
                                            
                                            	ORR Root address configuredfor the neighbor connection
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_peer_orf_capable
                                            
                                            	Peer has outbound route filter capability
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_prefix_orf_present
                                            
                                            	Outbound route filter prefix ORF present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_graceful_restart_capable
                                            
                                            	Graceful Restart Capability received
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_orf_receive_capable
                                            
                                            	Prefix based ORF receive mode capability received
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_orf_send_capable
                                            
                                            	Prefix based ORF send mode capability received
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rt_present
                                            
                                            	RT attribute list present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rt_present_standby
                                            
                                            	RT attribute list present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_send_mcast_attr
                                            
                                            	Send Mcast Attr
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_soft_reconfiguration_inbound_allowed
                                            
                                            	Inbound soft reconfiguration allowed
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_update_deferred
                                            
                                            	Update deferred until ORF/route refresh received
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_update_leaving
                                            
                                            	Nbr leaving update\-groupto another
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_update_throttled
                                            
                                            	Updates Throttled becausewrite limit is reached
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_use_soft_reconfiguration_always_on
                                            
                                            	Soft reconf overrides route refresh
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_restart_time
                                            
                                            	Local Restart time (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: long_lived_graceful_restart_capability_received
                                            
                                            	Long\-lived graceful\-restart capability received from the neighbor
                                            	**type**\:  bool
                                            
                                            .. attribute:: long_lived_graceful_restart_stale_time_accept
                                            
                                            	Maximum long\-lived graceful\-restart stale time acceptable from the neighbor (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: long_lived_graceful_restart_stale_time_configured
                                            
                                            	Long\-lived graceful\-restart stale time is configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: long_lived_graceful_restart_stale_time_received
                                            
                                            	Long\-lived graceful\-restart stale time received from the neighbor (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: long_lived_graceful_restart_stale_time_sent
                                            
                                            	Stale time sent in long\-lived graceful\-restart capability (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: max_prefix_discard_extra_paths
                                            
                                            	Discard extra paths when prefix limit reached
                                            	**type**\:  bool
                                            
                                            .. attribute:: max_prefix_exceed_discard_paths
                                            
                                            	Did we discard extra paths when prefix limit reached
                                            	**type**\:  bool
                                            
                                            .. attribute:: max_prefix_limit
                                            
                                            	Max limit for # of prefixes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: max_prefix_restart_time
                                            
                                            	Time interval (in minutes) after which peering session will be reestablished
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: minute
                                            
                                            .. attribute:: max_prefix_threshold_percent
                                            
                                            	Percentage of maximum no. of prefixes at which to generate warning
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: percentage
                                            
                                            .. attribute:: neighbor_af_performance_statistics
                                            
                                            	Neighbor AF statistics
                                            	**type**\:   :py:class:`NeighborAfPerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics>`
                                            
                                            .. attribute:: neighbor_default_originate
                                            
                                            	Neighbor originates default
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_long_lived_graceful_restart_capable
                                            
                                            	Treat neighbor as long\-lived graceful\-restart capable
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_long_lived_graceful_restart_time_remaining
                                            
                                            	Remaining long\-lived graceful\-restart time
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_preserved_forwarding_state
                                            
                                            	Neighbor preserved forwarding state
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_preserved_long_lived_forwarding_state
                                            
                                            	Neighbor preserved long\-lived forwarding state
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_version
                                            
                                            	Neighbor version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: number_of_best_externalpaths
                                            
                                            	No. of best\-external paths from this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: number_of_bestpaths
                                            
                                            	No. of bestpaths from this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: orf_entries_received
                                            
                                            	Number of outbound route filter entries received
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: orr_group_index
                                            
                                            	ORR Group Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: orr_group_name
                                            
                                            	ORR Group Name
                                            	**type**\:  str
                                            
                                            .. attribute:: outstanding_version
                                            
                                            	Version mapped from acked seqNo that was synced last
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: outstanding_version_max
                                            
                                            	Version mapped from acked seqNo that was synced last
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_accepted
                                            
                                            	No. of prefixes accepted
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_advertised
                                            
                                            	No. of prefixes advertised
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_be_advertised
                                            
                                            	No BE prefixes advertised
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_denied
                                            
                                            	No. of prefixes denied
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_denied_no_policy
                                            
                                            	No. of prefixes denied because there was no inbound policy
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_denied_non_cumulative
                                            
                                            	No. of prefixes exactly denied (non cumulative)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_denied_orf_policy
                                            
                                            	No. of prefixes denied by prefix based ORF policy
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_denied_policy
                                            
                                            	No. of prefixes denied by inbound policy
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_denied_rt_permit
                                            
                                            	No. of prefixes denied because RT extended community is not imported
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_suppressed
                                            
                                            	No. of prefixes suppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_synced
                                            
                                            	Number of prefixes synced to standby
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_withdrawn
                                            
                                            	No. of prefixes withdrawn
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_withdrawn_not_found
                                            
                                            	No. of prefixes withdrawn but not found
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: refresh_acked_version
                                            
                                            	Version acked by the peer for refresh updates sent
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: refresh_target_version
                                            
                                            	Target version for refresh update generation
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: refresh_version
                                            
                                            	Version till which refresh updates have been generated
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remove_private_as_entire_aspath_from_inbound_updates
                                            
                                            	Private AS numbers removed from updates from this nbr only if the aspath has only private ASes
                                            	**type**\:  bool
                                            
                                            .. attribute:: remove_private_as_entire_aspath_from_updates
                                            
                                            	Private AS numbers removed from updates to thisnbr only if the aspath hasonly private ASes
                                            	**type**\:  bool
                                            
                                            .. attribute:: remove_private_as_from_inbound_updates
                                            
                                            	Private AS numbers removed from updates from this nbr
                                            	**type**\:  bool
                                            
                                            .. attribute:: remove_private_as_from_updates
                                            
                                            	Private AS numbers removed from updates to this nbr
                                            	**type**\:  bool
                                            
                                            .. attribute:: restart_time
                                            
                                            	Restart time advertised (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: rib_purge_timeout_value
                                            
                                            	RIB purge timeout time (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: route_policy_default_originate
                                            
                                            	Default\-originate route policy name
                                            	**type**\:  str
                                            
                                            .. attribute:: route_policy_in
                                            
                                            	Incoming route policy name
                                            	**type**\:  str
                                            
                                            .. attribute:: route_policy_out
                                            
                                            	Outgoing route policy name
                                            	**type**\:  str
                                            
                                            .. attribute:: route_policy_prefix_orf
                                            
                                            	Prefix based ORF for incoming updates
                                            	**type**\:  str
                                            
                                            .. attribute:: route_refreshes_received
                                            
                                            	Number of route refresh requests received
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_refreshes_sent
                                            
                                            	Number of route refresh requests sent
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: selective_multipath_eligible
                                            
                                            	Selective multipath eligible
                                            	**type**\:  bool
                                            
                                            .. attribute:: sent_community_to_neighbor
                                            
                                            	Community attribute sent to neighbor
                                            	**type**\:  bool
                                            
                                            .. attribute:: sent_extended_community_to_neighbor
                                            
                                            	Extended community attribute sent to neighbor
                                            	**type**\:  bool
                                            
                                            .. attribute:: sent_gshut_community_to_neighbor
                                            
                                            	GSHUT Community attribute sent to neighbor
                                            	**type**\:  bool
                                            
                                            .. attribute:: stale_path_timeout
                                            
                                            	Stale path timeout time (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: synced_acked_version
                                            
                                            	Version mapped from acked seqNo that was synced last
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: use_max_prefix_warning_only
                                            
                                            	Warning only when maximum prefix limit reached
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_update_gen_enabled
                                            
                                            	RT Nbr enabled for updategento another
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_update_gen_trigger_enabled
                                            
                                            	RT Nbr enabled for updategento another
                                            	**type**\:  bool
                                            
                                            .. attribute:: weight
                                            
                                            	Weight for this AF
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.accept_own_enabled = None
                                                self.acked_version = None
                                                self.address_family_long_lived_time = None
                                                self.advertise_afi = None
                                                self.advertise_afi_def_vrf_imp_disable = None
                                                self.advertise_afi_disable = None
                                                self.advertise_afi_eo_r_ready = None
                                                self.advertise_afi_reorg = None
                                                self.advertise_afi_vrf_re_imp_disable = None
                                                self.advertise_evp_nv4afi_def_vrf_imp_disable = None
                                                self.advertise_evp_nv4afi_vrf_re_imp_disable = None
                                                self.advertise_evp_nv6afi_def_vrf_imp_disable = None
                                                self.advertise_evp_nv6afi_vrf_re_imp_disable = None
                                                self.advertise_local_labeled_route_unicast = None
                                                self.advertise_rt_type = None
                                                self.advertise_v4_flags = None
                                                self.advertise_v6_flags = None
                                                self.af_name = None
                                                self.afrpki_allow_invalid = None
                                                self.afrpki_disable = None
                                                self.afrpki_signal_ibgp = None
                                                self.afrpki_use_validity = None
                                                self.allow_as_in_count = None
                                                self.always_use_next_hop_local = None
                                                self.encapsulation_type = None
                                                self.eo_r_received_in_read_only = None
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.extended_community_standby = YList()
                                                self.extended_community_standby.parent = self
                                                self.extended_community_standby.name = 'extended_community_standby'
                                                self.filter_group_index = None
                                                self.flowspec_redirect_validation_d_isable = None
                                                self.flowspec_validation_d_isable = None
                                                self.import_reoriginate = None
                                                self.import_reoriginate_stitching = None
                                                self.import_stitching = None
                                                self.is_add_path_receive_capability_advertised = None
                                                self.is_add_path_receive_capability_received = None
                                                self.is_add_path_send_capability_advertised = None
                                                self.is_add_path_send_capability_received = None
                                                self.is_addpath_receive_operational = None
                                                self.is_addpath_send_operational = None
                                                self.is_advertise_permanent_network = None
                                                self.is_advertised_graceful_restart = None
                                                self.is_advertised_orf_receive = None
                                                self.is_advertised_orf_send = None
                                                self.is_aigp_set = None
                                                self.is_allow_as_in_set = None
                                                self.is_as_override_set = None
                                                self.is_default_originate_sent = None
                                                self.is_ext_nh_encoding_capability_received = None
                                                self.is_ext_nh_encoding_capability_sent = None
                                                self.is_graceful_restart_state_flag = None
                                                self.is_legacy_pe_rt = None
                                                self.is_neighbor_af_capable = None
                                                self.is_neighbor_ebgp_without_inbound_policy = None
                                                self.is_neighbor_ebgp_without_outbound_policy = None
                                                self.is_neighbor_route_reflector_client = None
                                                self.is_orf_send_scheduled = None
                                                self.is_orf_sent = None
                                                self.is_orr_root_address_configured = None
                                                self.is_peer_orf_capable = None
                                                self.is_prefix_orf_present = None
                                                self.is_received_graceful_restart_capable = None
                                                self.is_received_orf_receive_capable = None
                                                self.is_received_orf_send_capable = None
                                                self.is_rt_present = None
                                                self.is_rt_present_standby = None
                                                self.is_send_mcast_attr = None
                                                self.is_soft_reconfiguration_inbound_allowed = None
                                                self.is_update_deferred = None
                                                self.is_update_leaving = None
                                                self.is_update_throttled = None
                                                self.is_use_soft_reconfiguration_always_on = None
                                                self.local_restart_time = None
                                                self.long_lived_graceful_restart_capability_received = None
                                                self.long_lived_graceful_restart_stale_time_accept = None
                                                self.long_lived_graceful_restart_stale_time_configured = None
                                                self.long_lived_graceful_restart_stale_time_received = None
                                                self.long_lived_graceful_restart_stale_time_sent = None
                                                self.max_prefix_discard_extra_paths = None
                                                self.max_prefix_exceed_discard_paths = None
                                                self.max_prefix_limit = None
                                                self.max_prefix_restart_time = None
                                                self.max_prefix_threshold_percent = None
                                                self.neighbor_af_performance_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics()
                                                self.neighbor_af_performance_statistics.parent = self
                                                self.neighbor_default_originate = None
                                                self.neighbor_long_lived_graceful_restart_capable = None
                                                self.neighbor_long_lived_graceful_restart_time_remaining = None
                                                self.neighbor_preserved_forwarding_state = None
                                                self.neighbor_preserved_long_lived_forwarding_state = None
                                                self.neighbor_version = None
                                                self.number_of_best_externalpaths = None
                                                self.number_of_bestpaths = None
                                                self.orf_entries_received = None
                                                self.orr_group_index = None
                                                self.orr_group_name = None
                                                self.outstanding_version = None
                                                self.outstanding_version_max = None
                                                self.prefixes_accepted = None
                                                self.prefixes_advertised = None
                                                self.prefixes_be_advertised = None
                                                self.prefixes_denied = None
                                                self.prefixes_denied_no_policy = None
                                                self.prefixes_denied_non_cumulative = None
                                                self.prefixes_denied_orf_policy = None
                                                self.prefixes_denied_policy = None
                                                self.prefixes_denied_rt_permit = None
                                                self.prefixes_suppressed = None
                                                self.prefixes_synced = None
                                                self.prefixes_withdrawn = None
                                                self.prefixes_withdrawn_not_found = None
                                                self.refresh_acked_version = None
                                                self.refresh_target_version = None
                                                self.refresh_version = None
                                                self.remove_private_as_entire_aspath_from_inbound_updates = None
                                                self.remove_private_as_entire_aspath_from_updates = None
                                                self.remove_private_as_from_inbound_updates = None
                                                self.remove_private_as_from_updates = None
                                                self.restart_time = None
                                                self.rib_purge_timeout_value = None
                                                self.route_policy_default_originate = None
                                                self.route_policy_in = None
                                                self.route_policy_out = None
                                                self.route_policy_prefix_orf = None
                                                self.route_refreshes_received = None
                                                self.route_refreshes_sent = None
                                                self.selective_multipath_eligible = None
                                                self.sent_community_to_neighbor = None
                                                self.sent_extended_community_to_neighbor = None
                                                self.sent_gshut_community_to_neighbor = None
                                                self.stale_path_timeout = None
                                                self.synced_acked_version = None
                                                self.update_group_number = None
                                                self.use_max_prefix_warning_only = None
                                                self.vpn_update_gen_enabled = None
                                                self.vpn_update_gen_trigger_enabled = None
                                                self.weight = None


                                            class NeighborAfPerformanceStatistics(object):
                                                """
                                                Neighbor AF statistics
                                                
                                                .. attribute:: processed_messages
                                                
                                                	Number of messages processed from the neighbor's write queue
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sent_messages
                                                
                                                	Number of messages sent from the neighbor's write queue
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: split_horizon_update_blocked
                                                
                                                	No. of update messages with split\-horizon flag that were blocked
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: split_horizon_update_transmit
                                                
                                                	No. of update messages with split\-horizon flag that were sent out
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: split_horizon_withdraw_blocked
                                                
                                                	No. of withdraw messages with split\-horizon flag that were blocked
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: split_horizon_withdraw_transmit
                                                
                                                	No. of withdraw messages with split\-horizon flag that were sent out
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sub_group_pending_message_count
                                                
                                                	No. of sub\-group messages waiting to be sent out on this neighbor \-\- DEPRECATED \-\- 
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.processed_messages = None
                                                    self.sent_messages = None
                                                    self.split_horizon_update_blocked = None
                                                    self.split_horizon_update_transmit = None
                                                    self.split_horizon_withdraw_blocked = None
                                                    self.split_horizon_withdraw_transmit = None
                                                    self.sub_group_pending_message_count = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-af-performance-statistics'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.processed_messages is not None:
                                                        return True

                                                    if self.sent_messages is not None:
                                                        return True

                                                    if self.split_horizon_update_blocked is not None:
                                                        return True

                                                    if self.split_horizon_update_transmit is not None:
                                                        return True

                                                    if self.split_horizon_withdraw_blocked is not None:
                                                        return True

                                                    if self.split_horizon_withdraw_transmit is not None:
                                                        return True

                                                    if self.sub_group_pending_message_count is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity']['meta_info']


                                            class ExtendedCommunityStandby(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community-standby'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af-data'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.accept_own_enabled is not None:
                                                    return True

                                                if self.acked_version is not None:
                                                    return True

                                                if self.address_family_long_lived_time is not None:
                                                    return True

                                                if self.advertise_afi is not None:
                                                    return True

                                                if self.advertise_afi_def_vrf_imp_disable is not None:
                                                    return True

                                                if self.advertise_afi_disable is not None:
                                                    return True

                                                if self.advertise_afi_eo_r_ready is not None:
                                                    return True

                                                if self.advertise_afi_reorg is not None:
                                                    return True

                                                if self.advertise_afi_vrf_re_imp_disable is not None:
                                                    return True

                                                if self.advertise_evp_nv4afi_def_vrf_imp_disable is not None:
                                                    return True

                                                if self.advertise_evp_nv4afi_vrf_re_imp_disable is not None:
                                                    return True

                                                if self.advertise_evp_nv6afi_def_vrf_imp_disable is not None:
                                                    return True

                                                if self.advertise_evp_nv6afi_vrf_re_imp_disable is not None:
                                                    return True

                                                if self.advertise_local_labeled_route_unicast is not None:
                                                    return True

                                                if self.advertise_rt_type is not None:
                                                    return True

                                                if self.advertise_v4_flags is not None:
                                                    return True

                                                if self.advertise_v6_flags is not None:
                                                    return True

                                                if self.af_name is not None:
                                                    return True

                                                if self.afrpki_allow_invalid is not None:
                                                    return True

                                                if self.afrpki_disable is not None:
                                                    return True

                                                if self.afrpki_signal_ibgp is not None:
                                                    return True

                                                if self.afrpki_use_validity is not None:
                                                    return True

                                                if self.allow_as_in_count is not None:
                                                    return True

                                                if self.always_use_next_hop_local is not None:
                                                    return True

                                                if self.encapsulation_type is not None:
                                                    return True

                                                if self.eo_r_received_in_read_only is not None:
                                                    return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community_standby is not None:
                                                    for child_ref in self.extended_community_standby:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.filter_group_index is not None:
                                                    return True

                                                if self.flowspec_redirect_validation_d_isable is not None:
                                                    return True

                                                if self.flowspec_validation_d_isable is not None:
                                                    return True

                                                if self.import_reoriginate is not None:
                                                    return True

                                                if self.import_reoriginate_stitching is not None:
                                                    return True

                                                if self.import_stitching is not None:
                                                    return True

                                                if self.is_add_path_receive_capability_advertised is not None:
                                                    return True

                                                if self.is_add_path_receive_capability_received is not None:
                                                    return True

                                                if self.is_add_path_send_capability_advertised is not None:
                                                    return True

                                                if self.is_add_path_send_capability_received is not None:
                                                    return True

                                                if self.is_addpath_receive_operational is not None:
                                                    return True

                                                if self.is_addpath_send_operational is not None:
                                                    return True

                                                if self.is_advertise_permanent_network is not None:
                                                    return True

                                                if self.is_advertised_graceful_restart is not None:
                                                    return True

                                                if self.is_advertised_orf_receive is not None:
                                                    return True

                                                if self.is_advertised_orf_send is not None:
                                                    return True

                                                if self.is_aigp_set is not None:
                                                    return True

                                                if self.is_allow_as_in_set is not None:
                                                    return True

                                                if self.is_as_override_set is not None:
                                                    return True

                                                if self.is_default_originate_sent is not None:
                                                    return True

                                                if self.is_ext_nh_encoding_capability_received is not None:
                                                    return True

                                                if self.is_ext_nh_encoding_capability_sent is not None:
                                                    return True

                                                if self.is_graceful_restart_state_flag is not None:
                                                    return True

                                                if self.is_legacy_pe_rt is not None:
                                                    return True

                                                if self.is_neighbor_af_capable is not None:
                                                    return True

                                                if self.is_neighbor_ebgp_without_inbound_policy is not None:
                                                    return True

                                                if self.is_neighbor_ebgp_without_outbound_policy is not None:
                                                    return True

                                                if self.is_neighbor_route_reflector_client is not None:
                                                    return True

                                                if self.is_orf_send_scheduled is not None:
                                                    return True

                                                if self.is_orf_sent is not None:
                                                    return True

                                                if self.is_orr_root_address_configured is not None:
                                                    return True

                                                if self.is_peer_orf_capable is not None:
                                                    return True

                                                if self.is_prefix_orf_present is not None:
                                                    return True

                                                if self.is_received_graceful_restart_capable is not None:
                                                    return True

                                                if self.is_received_orf_receive_capable is not None:
                                                    return True

                                                if self.is_received_orf_send_capable is not None:
                                                    return True

                                                if self.is_rt_present is not None:
                                                    return True

                                                if self.is_rt_present_standby is not None:
                                                    return True

                                                if self.is_send_mcast_attr is not None:
                                                    return True

                                                if self.is_soft_reconfiguration_inbound_allowed is not None:
                                                    return True

                                                if self.is_update_deferred is not None:
                                                    return True

                                                if self.is_update_leaving is not None:
                                                    return True

                                                if self.is_update_throttled is not None:
                                                    return True

                                                if self.is_use_soft_reconfiguration_always_on is not None:
                                                    return True

                                                if self.local_restart_time is not None:
                                                    return True

                                                if self.long_lived_graceful_restart_capability_received is not None:
                                                    return True

                                                if self.long_lived_graceful_restart_stale_time_accept is not None:
                                                    return True

                                                if self.long_lived_graceful_restart_stale_time_configured is not None:
                                                    return True

                                                if self.long_lived_graceful_restart_stale_time_received is not None:
                                                    return True

                                                if self.long_lived_graceful_restart_stale_time_sent is not None:
                                                    return True

                                                if self.max_prefix_discard_extra_paths is not None:
                                                    return True

                                                if self.max_prefix_exceed_discard_paths is not None:
                                                    return True

                                                if self.max_prefix_limit is not None:
                                                    return True

                                                if self.max_prefix_restart_time is not None:
                                                    return True

                                                if self.max_prefix_threshold_percent is not None:
                                                    return True

                                                if self.neighbor_af_performance_statistics is not None and self.neighbor_af_performance_statistics._has_data():
                                                    return True

                                                if self.neighbor_default_originate is not None:
                                                    return True

                                                if self.neighbor_long_lived_graceful_restart_capable is not None:
                                                    return True

                                                if self.neighbor_long_lived_graceful_restart_time_remaining is not None:
                                                    return True

                                                if self.neighbor_preserved_forwarding_state is not None:
                                                    return True

                                                if self.neighbor_preserved_long_lived_forwarding_state is not None:
                                                    return True

                                                if self.neighbor_version is not None:
                                                    return True

                                                if self.number_of_best_externalpaths is not None:
                                                    return True

                                                if self.number_of_bestpaths is not None:
                                                    return True

                                                if self.orf_entries_received is not None:
                                                    return True

                                                if self.orr_group_index is not None:
                                                    return True

                                                if self.orr_group_name is not None:
                                                    return True

                                                if self.outstanding_version is not None:
                                                    return True

                                                if self.outstanding_version_max is not None:
                                                    return True

                                                if self.prefixes_accepted is not None:
                                                    return True

                                                if self.prefixes_advertised is not None:
                                                    return True

                                                if self.prefixes_be_advertised is not None:
                                                    return True

                                                if self.prefixes_denied is not None:
                                                    return True

                                                if self.prefixes_denied_no_policy is not None:
                                                    return True

                                                if self.prefixes_denied_non_cumulative is not None:
                                                    return True

                                                if self.prefixes_denied_orf_policy is not None:
                                                    return True

                                                if self.prefixes_denied_policy is not None:
                                                    return True

                                                if self.prefixes_denied_rt_permit is not None:
                                                    return True

                                                if self.prefixes_suppressed is not None:
                                                    return True

                                                if self.prefixes_synced is not None:
                                                    return True

                                                if self.prefixes_withdrawn is not None:
                                                    return True

                                                if self.prefixes_withdrawn_not_found is not None:
                                                    return True

                                                if self.refresh_acked_version is not None:
                                                    return True

                                                if self.refresh_target_version is not None:
                                                    return True

                                                if self.refresh_version is not None:
                                                    return True

                                                if self.remove_private_as_entire_aspath_from_inbound_updates is not None:
                                                    return True

                                                if self.remove_private_as_entire_aspath_from_updates is not None:
                                                    return True

                                                if self.remove_private_as_from_inbound_updates is not None:
                                                    return True

                                                if self.remove_private_as_from_updates is not None:
                                                    return True

                                                if self.restart_time is not None:
                                                    return True

                                                if self.rib_purge_timeout_value is not None:
                                                    return True

                                                if self.route_policy_default_originate is not None:
                                                    return True

                                                if self.route_policy_in is not None:
                                                    return True

                                                if self.route_policy_out is not None:
                                                    return True

                                                if self.route_policy_prefix_orf is not None:
                                                    return True

                                                if self.route_refreshes_received is not None:
                                                    return True

                                                if self.route_refreshes_sent is not None:
                                                    return True

                                                if self.selective_multipath_eligible is not None:
                                                    return True

                                                if self.sent_community_to_neighbor is not None:
                                                    return True

                                                if self.sent_extended_community_to_neighbor is not None:
                                                    return True

                                                if self.sent_gshut_community_to_neighbor is not None:
                                                    return True

                                                if self.stale_path_timeout is not None:
                                                    return True

                                                if self.synced_acked_version is not None:
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                if self.use_max_prefix_warning_only is not None:
                                                    return True

                                                if self.vpn_update_gen_enabled is not None:
                                                    return True

                                                if self.vpn_update_gen_trigger_enabled is not None:
                                                    return True

                                                if self.weight is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')
                                            if self.neighbor_address is None:
                                                raise YPYModelError('Key property neighbor_address is None')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address = ' + str(self.neighbor_address) + ']'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.neighbor_address is not None:
                                                return True

                                            if self.active_bmp_servers is not None:
                                                return True

                                            if self.actual_last_write_bytes is not None:
                                                return True

                                            if self.actual_last_write_reset_bytes is not None:
                                                return True

                                            if self.actual_second_last_write_bytes is not None:
                                                return True

                                            if self.actual_second_last_write_reset_bytes is not None:
                                                return True

                                            if self.af_data is not None:
                                                for child_ref in self.af_data:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.attempted_last_write_bytes is not None:
                                                return True

                                            if self.attempted_last_write_reset_bytes is not None:
                                                return True

                                            if self.attempted_second_last_write_bytes is not None:
                                                return True

                                            if self.attempted_second_last_write_reset_bytes is not None:
                                                return True

                                            if self.bfd_minintervalval is not None:
                                                return True

                                            if self.bfd_multiplierval is not None:
                                                return True

                                            if self.bfd_session_created_state is not None:
                                                return True

                                            if self.bfd_session_enable_mode is not None:
                                                return True

                                            if self.bfd_session_state is not None:
                                                return True

                                            if self.bfd_state_ts is not None:
                                                return True

                                            if self.bytes_read is not None:
                                                return True

                                            if self.bytes_written is not None:
                                                return True

                                            if self.configured_hold_time is not None:
                                                return True

                                            if self.configured_keepalive is not None:
                                                return True

                                            if self.configured_min_acc_hold_time is not None:
                                                return True

                                            if self.connect_retry_interval is not None:
                                                return True

                                            if self.connection_admin_status is not None:
                                                return True

                                            if self.connection_down_count is not None:
                                                return True

                                            if self.connection_established_time is not None:
                                                return True

                                            if self.connection_local_address is not None and self.connection_local_address._has_data():
                                                return True

                                            if self.connection_local_port is not None:
                                                return True

                                            if self.connection_remote_address is not None and self.connection_remote_address._has_data():
                                                return True

                                            if self.connection_remote_port is not None:
                                                return True

                                            if self.connection_state is not None:
                                                return True

                                            if self.connection_up_count is not None:
                                                return True

                                            if self.count_last_write is not None:
                                                return True

                                            if self.description is not None:
                                                return True

                                            if self.discard_as4_path is not None:
                                                return True

                                            if self.discard_data_bytes is not None:
                                                return True

                                            if self.dmz_link_bandwidth is not None:
                                                return True

                                            if self.dynamic_neighbor is not None:
                                                return True

                                            if self.ebgp_recv_dmz is not None:
                                                return True

                                            if self.ebgp_send_dmz_mode is not None:
                                                return True

                                            if self.ebgp_time_to_live is not None:
                                                return True

                                            if self.egress_peer_engineering_enabled is not None:
                                                return True

                                            if self.error_notifies_received is not None:
                                                return True

                                            if self.error_notifies_sent is not None:
                                                return True

                                            if self.fpbsn_offset is not None:
                                                return True

                                            if self.fssn_offset is not None:
                                                return True

                                            if self.gr_restart_time is not None:
                                                return True

                                            if self.gr_stale_path_time is not None:
                                                return True

                                            if self.graceful_maintenance is not None and self.graceful_maintenance._has_data():
                                                return True

                                            if self.graceful_restart_enabled_nbr is not None:
                                                return True

                                            if self.has_internal_link is not None:
                                                return True

                                            if self.hold_time is not None:
                                                return True

                                            if self.ignore_connected is not None:
                                                return True

                                            if self.internal_vpn_client is not None:
                                                return True

                                            if self.io_armed is not None:
                                                return True

                                            if self.is4_byte_as_capability_received is not None:
                                                return True

                                            if self.is4_byte_as_capability_sent is not None:
                                                return True

                                            if self.is_administratively_shut_down is not None:
                                                return True

                                            if self.is_capability_negotiation_performed is not None:
                                                return True

                                            if self.is_capability_negotiation_suppressed is not None:
                                                return True

                                            if self.is_ebgp_multihop_bgpmpls_forwarding_disabled is not None:
                                                return True

                                            if self.is_ebgp_peer_as_league is not None:
                                                return True

                                            if self.is_ebgp_peer_common_admin is not None:
                                                return True

                                            if self.is_external_neighbor_not_directly_connected is not None:
                                                return True

                                            if self.is_gr_aware is not None:
                                                return True

                                            if self.is_local_address_configured is not None:
                                                return True

                                            if self.is_neighbor_max_prefix_shutdown is not None:
                                                return True

                                            if self.is_out_of_memory_forced_up is not None:
                                                return True

                                            if self.is_out_of_memory_shutdown is not None:
                                                return True

                                            if self.is_passive_close is not None:
                                                return True

                                            if self.is_read_disabled is not None:
                                                return True

                                            if self.is_route_refresh_capability_received is not None:
                                                return True

                                            if self.is_route_refresh_old_capability_received is not None:
                                                return True

                                            if self.keep_alive_time is not None:
                                                return True

                                            if self.last_ackd_seq_no is not None:
                                                return True

                                            if self.last_k_aerror_reset is not None:
                                                return True

                                            if self.last_k_aexpiry_reset is not None:
                                                return True

                                            if self.last_k_anotsent_reset is not None:
                                                return True

                                            if self.last_k_astart_reset is not None:
                                                return True

                                            if self.last_notify_error_code is not None:
                                                return True

                                            if self.last_notify_error_subcode is not None:
                                                return True

                                            if self.last_write_event is not None:
                                                return True

                                            if self.local_as is not None:
                                                return True

                                            if self.local_as_dual_as is not None:
                                                return True

                                            if self.local_as_dual_as_mode_native is not None:
                                                return True

                                            if self.local_as_no_prepend is not None:
                                                return True

                                            if self.local_as_replace_as is not None:
                                                return True

                                            if self.message_statistics is not None and self.message_statistics._has_data():
                                                return True

                                            if self.messages_queued_in is not None:
                                                return True

                                            if self.messages_queued_out is not None:
                                                return True

                                            if self.messages_received is not None:
                                                return True

                                            if self.messages_sent is not None:
                                                return True

                                            if self.min_advertise_interval is not None:
                                                return True

                                            if self.min_advertise_interval_msecs is not None:
                                                return True

                                            if self.min_origination_interval is not None:
                                                return True

                                            if self.msg_log_in is not None:
                                                return True

                                            if self.msg_log_out is not None:
                                                return True

                                            if self.multi_protocol_capability_received is not None:
                                                return True

                                            if self.nbr_cluster_id is not None:
                                                return True

                                            if self.nbr_enforce_first_as is not None:
                                                return True

                                            if self.nbr_in_cluster is not None:
                                                return True

                                            if self.negotiated_protocol_version is not None:
                                                return True

                                            if self.neighbor_interface_handle is not None:
                                                return True

                                            if self.neighbor_local_as is not None:
                                                return True

                                            if self.nsr_enabled is not None:
                                                return True

                                            if self.nsr_state is not None:
                                                return True

                                            if self.open_check_error_code is not None:
                                                return True

                                            if self.peer_error_code is not None:
                                                return True

                                            if self.peer_reset_reason is not None:
                                                return True

                                            if self.performance_statistics is not None and self.performance_statistics._has_data():
                                                return True

                                            if self.previous_connection_state is not None:
                                                return True

                                            if self.read_armed is not None:
                                                return True

                                            if self.received_notification_info is not None and self.received_notification_info._has_data():
                                                return True

                                            if self.remote_as is not None:
                                                return True

                                            if self.remote_as_number is not None:
                                                return True

                                            if self.reset_notification_sent is not None:
                                                return True

                                            if self.reset_reason is not None:
                                                return True

                                            if self.router_id is not None:
                                                return True

                                            if self.rpki_allow_invalid is not None:
                                                return True

                                            if self.rpki_disable is not None:
                                                return True

                                            if self.rpki_signal_ibgp is not None:
                                                return True

                                            if self.rpki_use_validity is not None:
                                                return True

                                            if self.second_last_k_aexpiry_reset is not None:
                                                return True

                                            if self.second_last_k_astart_reset is not None:
                                                return True

                                            if self.second_last_write_event is not None:
                                                return True

                                            if self.send_notification_info is not None and self.send_notification_info._has_data():
                                                return True

                                            if self.socket_read_bytes is not None:
                                                return True

                                            if self.speaker_id is not None:
                                                return True

                                            if self.standby_rp is not None:
                                                return True

                                            if self.suppress4_byte_as is not None:
                                                return True

                                            if self.tcp_init_sync_done_time_spec is not None and self.tcp_init_sync_done_time_spec._has_data():
                                                return True

                                            if self.tcp_init_sync_phase_two_time_spec is not None and self.tcp_init_sync_phase_two_time_spec._has_data():
                                                return True

                                            if self.tcp_init_sync_time_spec is not None and self.tcp_init_sync_time_spec._has_data():
                                                return True

                                            if self.tcp_session_open_mode is not None:
                                                return True

                                            if self.tcpmss is not None:
                                                return True

                                            if self.time_last_cb is not None:
                                                return True

                                            if self.time_last_cb_reset is not None:
                                                return True

                                            if self.time_last_fb is not None:
                                                return True

                                            if self.time_since_connection_last_dropped is not None:
                                                return True

                                            if self.time_since_last_read is not None:
                                                return True

                                            if self.time_since_last_read_reset is not None:
                                                return True

                                            if self.time_since_last_update is not None:
                                                return True

                                            if self.time_since_last_write is not None:
                                                return True

                                            if self.time_since_last_write_reset is not None:
                                                return True

                                            if self.time_since_second_last_write is not None:
                                                return True

                                            if self.time_since_second_last_write_reset is not None:
                                                return True

                                            if self.tos_type is not None:
                                                return True

                                            if self.tos_value is not None:
                                                return True

                                            if self.ttl_security_enabled is not None:
                                                return True

                                            if self.update_bytes_read is not None:
                                                return True

                                            if self.update_messages_in is not None:
                                                return True

                                            if self.update_messages_out is not None:
                                                return True

                                            if self.vrf_name is not None:
                                                return True

                                            if self.write_armed is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-af-table'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.neighbor is not None:
                                            for child_ref in self.neighbor:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable']['meta_info']


                                class NetworkAllRds(object):
                                    """
                                    The BGP Network Lookup Table
                                    
                                    .. attribute:: network_all_rd
                                    
                                    	The BGP Network Lookup table
                                    	**type**\: list of    :py:class:`NetworkAllRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.network_all_rd = YList()
                                        self.network_all_rd.parent = self
                                        self.network_all_rd.name = 'network_all_rd'


                                    class NetworkAllRd(object):
                                        """
                                        The BGP Network Lookup table
                                        
                                        .. attribute:: network_addr  <key>
                                        
                                        	Network in prefix/length format (address part)
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: network_prefix  <key>
                                        
                                        	Network in prefix/length format (prefix part)
                                        	**type**\:  int
                                        
                                        	**range:** 0..128
                                        
                                        .. attribute:: network_rds
                                        
                                        	The BGP Network Lookup table
                                        	**type**\:   :py:class:`NetworkRds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.network_addr = None
                                            self.network_prefix = None
                                            self.network_rds = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds()
                                            self.network_rds.parent = self


                                        class NetworkRds(object):
                                            """
                                            The BGP Network Lookup table
                                            
                                            .. attribute:: network_rd
                                            
                                            	A BGP Network table entry
                                            	**type**\: list of    :py:class:`NetworkRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.network_rd = YList()
                                                self.network_rd.parent = self
                                                self.network_rd.name = 'network_rd'


                                            class NetworkRd(object):
                                                """
                                                A BGP Network table entry
                                                
                                                .. attribute:: rd  <key>
                                                
                                                	Route Distinguisher value
                                                	**type**\:  str
                                                
                                                .. attribute:: active_path_element
                                                
                                                	Path element list received from Active inst
                                                	**type**\: list of    :py:class:`ActivePathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement>`
                                                
                                                .. attribute:: active_process_instance_path
                                                
                                                	Active's paths for this net 
                                                	**type**\: list of    :py:class:`ActiveProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath>`
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield>`
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\:  bool
                                                
                                                .. attribute:: af_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield>`
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix>`
                                                
                                                .. attribute:: bit
                                                
                                                	Bit
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: flags
                                                
                                                	Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: gateway_array
                                                
                                                	Gateway array ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_inconsistent_paths
                                                
                                                	Net has inconsistent paths
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_lbl_retained
                                                
                                                	Net has label retained
                                                	**type**\:  bool
                                                
                                                .. attribute:: has_local_label
                                                
                                                	Net has local label
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_net_aggregation_suppressed
                                                
                                                	Net suppressed due to aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_net_ldp_signaled
                                                
                                                	L2VPN Net LDP signaled  aggregation
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_permanent_network
                                                
                                                	Permanent Network
                                                	**type**\:  bool
                                                
                                                .. attribute:: local_path_element
                                                
                                                	Local path element list
                                                	**type**\: list of    :py:class:`LocalPathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement>`
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: local_process_instance_path
                                                
                                                	Local (to process instance) paths for this net 
                                                	**type**\: list of    :py:class:`LocalProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath>`
                                                
                                                .. attribute:: net_backup_available
                                                
                                                	Net has backup path
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_backup_label_rewrite_available
                                                
                                                	Net has label rewrite for backup path
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_eibgp_multipath
                                                
                                                	Net has EIBGP multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_extended_flags
                                                
                                                	Net extended flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: net_flags
                                                
                                                	Flags associated with                            net
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: net_local_label
                                                
                                                	Local label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: net_local_label_rewrite
                                                
                                                	Net label has rewrite
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_local_label_srgb
                                                
                                                	Net label allocated fromSegment routing global block
                                                	**type**\:  bool
                                                
                                                .. attribute:: net_multipath
                                                
                                                	Net has multipaths
                                                	**type**\:  bool
                                                
                                                .. attribute:: num_of_path
                                                
                                                	Number of path for this net
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: process_instance_id
                                                
                                                	Process instance ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: resilient_nexthop_set
                                                
                                                	Resilient nexthop set ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_failed
                                                
                                                	RIB install failed
                                                	**type**\:  bool
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: table_brib_version
                                                
                                                	Table version # for updates
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: table_version
                                                
                                                	Table version # for net
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: version
                                                
                                                	Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: version_age
                                                
                                                	Version age
                                                	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionAge>`
                                                
                                                .. attribute:: version_timestamp
                                                
                                                	Version timestamp
                                                	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionTimestamp>`
                                                
                                                .. attribute:: vrf_name
                                                
                                                	Name of the VRF
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.rd = None
                                                    self.active_path_element = YList()
                                                    self.active_path_element.parent = self
                                                    self.active_path_element.name = 'active_path_element'
                                                    self.active_process_instance_path = YList()
                                                    self.active_process_instance_path.parent = self
                                                    self.active_process_instance_path.name = 'active_process_instance_path'
                                                    self.add_path_orr_bitfield = YList()
                                                    self.add_path_orr_bitfield.parent = self
                                                    self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                    self.advertisedto_pe = None
                                                    self.af_name = None
                                                    self.best_path_orr_bitfield = YList()
                                                    self.best_path_orr_bitfield.parent = self
                                                    self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self.bit = None
                                                    self.flags = None
                                                    self.gateway_array = None
                                                    self.has_inconsistent_paths = None
                                                    self.has_lbl_retained = None
                                                    self.has_local_label = None
                                                    self.is_net_aggregation_suppressed = None
                                                    self.is_net_ldp_signaled = None
                                                    self.is_permanent_network = None
                                                    self.local_path_element = YList()
                                                    self.local_path_element.parent = self
                                                    self.local_path_element.name = 'local_path_element'
                                                    self.local_peers_advertised_to = YList()
                                                    self.local_peers_advertised_to.parent = self
                                                    self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                    self.local_process_instance_path = YList()
                                                    self.local_process_instance_path.parent = self
                                                    self.local_process_instance_path.name = 'local_process_instance_path'
                                                    self.net_backup_available = None
                                                    self.net_backup_label_rewrite_available = None
                                                    self.net_eibgp_multipath = None
                                                    self.net_extended_flags = None
                                                    self.net_flags = None
                                                    self.net_local_label = None
                                                    self.net_local_label_rewrite = None
                                                    self.net_local_label_srgb = None
                                                    self.net_multipath = None
                                                    self.num_of_path = None
                                                    self.pe_peers_advertised_to = YList()
                                                    self.pe_peers_advertised_to.parent = self
                                                    self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                    self.process_instance_id = None
                                                    self.resilient_nexthop_set = None
                                                    self.rib_failed = None
                                                    self.route_distinguisher = None
                                                    self.table_brib_version = None
                                                    self.table_version = None
                                                    self.version = None
                                                    self.version_age = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionAge()
                                                    self.version_age.parent = self
                                                    self.version_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionTimestamp()
                                                    self.version_timestamp.parent = self
                                                    self.vrf_name = None


                                                class BgpPrefix(object):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self.prefix_length = None


                                                    class Prefix(object):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.prefix is not None and self.prefix._has_data():
                                                            return True

                                                        if self.prefix_length is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix']['meta_info']


                                                class VersionTimestamp(object):
                                                    """
                                                    Version timestamp
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-timestamp'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionTimestamp']['meta_info']


                                                class VersionAge(object):
                                                    """
                                                    Version age
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-age'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionAge']['meta_info']


                                                class LocalPeersAdvertisedTo(object):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo']['meta_info']


                                                class PePeersAdvertisedTo(object):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo']['meta_info']


                                                class BestPathOrrBitfield(object):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield']['meta_info']


                                                class AddPathOrrBitfield(object):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_neighbor = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.update_group_number = None


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_neighbor is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.update_group_number is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield']['meta_info']


                                                class LocalProcessInstancePath(object):
                                                    """
                                                    Local (to process instance) paths for this net 
                                                    
                                                    .. attribute:: af_name
                                                    
                                                    	Address family identifier
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: attributes_after_policy_in
                                                    
                                                    	Attributes after inbound policy applied
                                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn>`
                                                    
                                                    .. attribute:: label_fail
                                                    
                                                    	LSD label allocation failed 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: label_o_or_version
                                                    
                                                    	Label Version when OOR happens
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_oor
                                                    
                                                    	LSD label space is exhausted
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address_xr
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr>`
                                                    
                                                    .. attribute:: no_path
                                                    
                                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: path_information
                                                    
                                                    	Path information
                                                    	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation>`
                                                    
                                                    .. attribute:: prefix_version
                                                    
                                                    	Version of BGP Prefix Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: process_instance_id
                                                    
                                                    	Process instance ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: route_distinguisher
                                                    
                                                    	Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: source_route_distinguisher
                                                    
                                                    	Source Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: source_vrf_name
                                                    
                                                    	Name of the source VRF
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: srcaf_name
                                                    
                                                    	Address family identifier
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: vrf_name
                                                    
                                                    	Name of the VRF
                                                    	**type**\:  str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.af_name = None
                                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn()
                                                        self.attributes_after_policy_in.parent = self
                                                        self.label_fail = None
                                                        self.label_o_or_version = None
                                                        self.label_oor = None
                                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr()
                                                        self.neighbor_address_xr.parent = self
                                                        self.no_path = None
                                                        self.path_information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation()
                                                        self.path_information.parent = self
                                                        self.prefix_version = None
                                                        self.process_instance_id = None
                                                        self.route_distinguisher = None
                                                        self.source_route_distinguisher = None
                                                        self.source_vrf_name = None
                                                        self.srcaf_name = None
                                                        self.vrf_name = None


                                                    class NeighborAddressXr(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr']['meta_info']


                                                    class PathInformation(object):
                                                        """
                                                        Path information
                                                        
                                                        .. attribute:: accept_own_path
                                                        
                                                        	Accept Own
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: accept_own_self_originated_p_ath
                                                        
                                                        	Accept\-Own self\-originated
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: add_path_orr_bitfield
                                                        
                                                        	ORR Add path Bitfields
                                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                        
                                                        .. attribute:: advertisedto_pe
                                                        
                                                        	Net could be advertised                          to PE peers
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: aigp_metric
                                                        
                                                        	Total AIGP metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: best_path_comp_stage
                                                        
                                                        	Stage where the path lost to the best path or group best
                                                        	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                                        
                                                        .. attribute:: best_path_comp_winner
                                                        
                                                        	Neighbor address of the path which won best path comparison
                                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                        
                                                        .. attribute:: best_path_id
                                                        
                                                        	Best path ID; DEPRECATED BYLocalPathId
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: best_path_id_comp_winner
                                                        
                                                        	Path ID of the path which won best path comparison
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: best_path_orr_bitfield
                                                        
                                                        	ORR Best path Bitfields
                                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                        
                                                        .. attribute:: bgp_prefix
                                                        
                                                        	BGP prefix
                                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix>`
                                                        
                                                        .. attribute:: dampen_penalty
                                                        
                                                        	Dampening penalty
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Mvpn Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                        
                                                        .. attribute:: fspec_invalid_path
                                                        
                                                        	Is Fspec invalid path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: graceful_shutdown
                                                        
                                                        	Marked for graceful shutdown
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: gw_addr
                                                        
                                                        	Path GW Address
                                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.GwAddr>`
                                                        
                                                        .. attribute:: halflife_time
                                                        
                                                        	Half\-life time for the penalty
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_esi
                                                        
                                                        	Path has EVPN ESI
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_gw_addr
                                                        
                                                        	Path has GW Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_local_net_label
                                                        
                                                        	Path has local label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mdt_group_addr
                                                        
                                                        	Path has MDT Group Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_extcomm
                                                        
                                                        	Path has MVPN EXTCOMM feedback
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_nbr_addr
                                                        
                                                        	Path has Mvpn nbr Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_nexthop_addr
                                                        
                                                        	Path has MVPN nexthop Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_pmsi
                                                        
                                                        	Path has MVPN PMSI feedback
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_rcvd_label
                                                        
                                                        	Path has received label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_second_label
                                                        
                                                        	Path has second received label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: ibgp_signaled_validity
                                                        
                                                        	IBGP signalled validation
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: igp_metric
                                                        
                                                        	IGP metric to the gateway
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: is_aggregation_suppressed
                                                        
                                                        	Path suppressed due to aggregation
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_best
                                                        
                                                        	Best available path within AS
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_best_path
                                                        
                                                        	Best available path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_import_dampened
                                                        
                                                        	net import dampened
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_import_suspect
                                                        
                                                        	net import suspect
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_internal_path
                                                        
                                                        	Received over an internal link
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_partial_best
                                                        
                                                        	Partial best path within distributed speaker
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_additional_path
                                                        
                                                        	Path is an additional\-path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_advertised_local_as_only
                                                        
                                                        	Not advertised outside local AS
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_af_install_eligible
                                                        
                                                        	Path can be installed in AF RIB
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_backup
                                                        
                                                        	Path is a backup path 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_backup_protect_multipath
                                                        
                                                        	Path is a backup path to protect multipaths
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_best_external
                                                        
                                                        	Path is a best external path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_damped
                                                        
                                                        	Path suppressed due to dampening
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_confederation_peer
                                                        
                                                        	Path received from confederation peer
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_network_command
                                                        
                                                        	Path sourced by network command
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_redistribute_command
                                                        
                                                        	Path sourced by redistribute command
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_route_reflector
                                                        
                                                        	Path received from route reflector
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_history_held
                                                        
                                                        	Path entry held to remember history
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_imp_candidate
                                                        
                                                        	Path is a candidate for multipath import
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_imported
                                                        
                                                        	Path is imported
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_local_aggregate
                                                        
                                                        	Path is a locally created aggregate
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_locally_sourced
                                                        
                                                        	Path sourced locally
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_long_lived_stale
                                                        
                                                        	Long lived stale routes learnt before neighbor restarts
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_multipath
                                                        
                                                        	Path is one of multipath best routes
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_nexthop_discarded
                                                        
                                                        	Path is redirected to Null0
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_not_advertised
                                                        
                                                        	Not advertised to any peer
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_not_advertised_to_ebg_ps
                                                        
                                                        	Not advertised to EBGPs
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_received_only
                                                        
                                                        	Path is received only
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_reoriginated
                                                        
                                                        	Path is reoriginated
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_reoriginated_stitching
                                                        
                                                        	Path is reoriginated with stitching RTs
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_stale
                                                        
                                                        	Stale routes learnt before neighbor restarts
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_synced_with_igp
                                                        
                                                        	Path synchronized with IGP
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_valid
                                                        
                                                        	Path attributes are usable
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_vpn_only
                                                        
                                                        	Path is not in the vrf
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_permanent_path
                                                        
                                                        	Path is of type Permanent path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_received_path_not_modified
                                                        
                                                        	Received path used without modification
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_spkr_as_best
                                                        
                                                        	Best available path within AS in speaker
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2vpn_circuit_status_value
                                                        
                                                        	L2VPN Circuit Status Value
                                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                        
                                                        .. attribute:: l2vpn_evpn_esi
                                                        
                                                        	L2VPN EVPN ESI
                                                        	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi>`
                                                        
                                                        .. attribute:: l2vpn_size
                                                        
                                                        	Path block size
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: labeled_unicast_safi_path
                                                        
                                                        	Path was learnt by labeled\-unicast SAFI
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: local_label
                                                        
                                                        	Path local label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_nh
                                                        
                                                        	Path has local nexthop
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: local_path_id
                                                        
                                                        	Local path ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_peers_advertised_to
                                                        
                                                        	Local peers that this prefix has been advertised to
                                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                        
                                                        .. attribute:: maximum_suppress_time
                                                        
                                                        	Maximum duration to suppress a stable route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mdt_group_addr
                                                        
                                                        	IPv4 MDT Group Address for the path
                                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                        
                                                        .. attribute:: mvpn_nbr_addr
                                                        
                                                        	Mvpn nbr Address for the path
                                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                        
                                                        .. attribute:: mvpn_nexthop_addr
                                                        
                                                        	Mvpn nexthop Address for the path
                                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                        
                                                        .. attribute:: mvpn_path_flags
                                                        
                                                        	Mvpn path flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: mvpn_pmsi_flags
                                                        
                                                        	Mvpn PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: mvpn_pmsi_label
                                                        
                                                        	Mvpn PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mvpn_pmsi_type
                                                        
                                                        	Mvpn PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: mvpn_pmsi_value
                                                        
                                                        	Mvpn PMSI Value
                                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                        
                                                        .. attribute:: mvpn_sfs_path
                                                        
                                                        	Is MVPN single forwarder PE path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress>`
                                                        
                                                        .. attribute:: neighbor_router_id
                                                        
                                                        	Router ID of the neighbor for the path
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: next_hop
                                                        
                                                        	Next hop
                                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop>`
                                                        
                                                        .. attribute:: nhte_tunnel
                                                        
                                                        	NH TE tunnel information
                                                        	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhteTunnel>`
                                                        
                                                        .. attribute:: path_flags
                                                        
                                                        	Flags associated with path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: path_flap_count
                                                        
                                                        	Number of times this route has flapped
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_import_flags
                                                        
                                                        	Path import flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_rt_set_id
                                                        
                                                        	RT\-set id of the path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_rt_set_route_count
                                                        
                                                        	Count in RT\-set
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_table_version
                                                        
                                                        	Table version # for pelem
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_weight
                                                        
                                                        	Weight for the path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pe_peers_advertised_to
                                                        
                                                        	PE peers that this prefix has been advertised to
                                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                        
                                                        .. attribute:: rcvd_label
                                                        
                                                        	Path received label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rcvd_path_id
                                                        
                                                        	Received path ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: reuse_value
                                                        
                                                        	Value to start reusing a route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rib_failed
                                                        
                                                        	Is net failed installed                          in RIB
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route Type of path
                                                        	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                                        
                                                        .. attribute:: rpki_origin_as_validation_disabled
                                                        
                                                        	RPKI originAS V. Disabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: rt_set_limit_enabled
                                                        
                                                        	Path subject to RT\-set net limit
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: second_label
                                                        
                                                        	Path second received label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: seconds_since_first_flap
                                                        
                                                        	Seconds since route first flapped
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: show_rpki_origin_as_validity
                                                        
                                                        	Display validity state ?
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: sn_rpki_origin_as_validity
                                                        
                                                        	RPKI origin validation state
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: suppress_penalty
                                                        
                                                        	Value to start suppressing a route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: time_to_unsuppress
                                                        
                                                        	Seconds until route is unsuppressed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.accept_own_path = None
                                                            self.accept_own_self_originated_p_ath = None
                                                            self.add_path_orr_bitfield = YList()
                                                            self.add_path_orr_bitfield.parent = self
                                                            self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                            self.advertisedto_pe = None
                                                            self.aigp_metric = None
                                                            self.best_path_comp_stage = None
                                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner()
                                                            self.best_path_comp_winner.parent = self
                                                            self.best_path_id = None
                                                            self.best_path_id_comp_winner = None
                                                            self.best_path_orr_bitfield = YList()
                                                            self.best_path_orr_bitfield.parent = self
                                                            self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix()
                                                            self.bgp_prefix.parent = self
                                                            self.dampen_penalty = None
                                                            self.extended_community = YList()
                                                            self.extended_community.parent = self
                                                            self.extended_community.name = 'extended_community'
                                                            self.fspec_invalid_path = None
                                                            self.graceful_shutdown = None
                                                            self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.GwAddr()
                                                            self.gw_addr.parent = self
                                                            self.halflife_time = None
                                                            self.has_esi = None
                                                            self.has_gw_addr = None
                                                            self.has_local_net_label = None
                                                            self.has_mdt_group_addr = None
                                                            self.has_mvpn_extcomm = None
                                                            self.has_mvpn_nbr_addr = None
                                                            self.has_mvpn_nexthop_addr = None
                                                            self.has_mvpn_pmsi = None
                                                            self.has_rcvd_label = None
                                                            self.has_second_label = None
                                                            self.ibgp_signaled_validity = None
                                                            self.igp_metric = None
                                                            self.is_aggregation_suppressed = None
                                                            self.is_as_best = None
                                                            self.is_best_path = None
                                                            self.is_import_dampened = None
                                                            self.is_import_suspect = None
                                                            self.is_internal_path = None
                                                            self.is_partial_best = None
                                                            self.is_path_additional_path = None
                                                            self.is_path_advertised_local_as_only = None
                                                            self.is_path_af_install_eligible = None
                                                            self.is_path_backup = None
                                                            self.is_path_backup_protect_multipath = None
                                                            self.is_path_best_external = None
                                                            self.is_path_damped = None
                                                            self.is_path_from_confederation_peer = None
                                                            self.is_path_from_network_command = None
                                                            self.is_path_from_redistribute_command = None
                                                            self.is_path_from_route_reflector = None
                                                            self.is_path_history_held = None
                                                            self.is_path_imp_candidate = None
                                                            self.is_path_imported = None
                                                            self.is_path_local_aggregate = None
                                                            self.is_path_locally_sourced = None
                                                            self.is_path_long_lived_stale = None
                                                            self.is_path_multipath = None
                                                            self.is_path_nexthop_discarded = None
                                                            self.is_path_not_advertised = None
                                                            self.is_path_not_advertised_to_ebg_ps = None
                                                            self.is_path_received_only = None
                                                            self.is_path_reoriginated = None
                                                            self.is_path_reoriginated_stitching = None
                                                            self.is_path_stale = None
                                                            self.is_path_synced_with_igp = None
                                                            self.is_path_valid = None
                                                            self.is_path_vpn_only = None
                                                            self.is_permanent_path = None
                                                            self.is_received_path_not_modified = None
                                                            self.is_spkr_as_best = None
                                                            self.l2vpn_circuit_status_value = YList()
                                                            self.l2vpn_circuit_status_value.parent = self
                                                            self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                            self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi()
                                                            self.l2vpn_evpn_esi.parent = self
                                                            self.l2vpn_size = None
                                                            self.labeled_unicast_safi_path = None
                                                            self.local_label = None
                                                            self.local_nh = None
                                                            self.local_path_id = None
                                                            self.local_peers_advertised_to = YList()
                                                            self.local_peers_advertised_to.parent = self
                                                            self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                            self.maximum_suppress_time = None
                                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr()
                                                            self.mdt_group_addr.parent = self
                                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                            self.mvpn_nbr_addr.parent = self
                                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                            self.mvpn_nexthop_addr.parent = self
                                                            self.mvpn_path_flags = None
                                                            self.mvpn_pmsi_flags = None
                                                            self.mvpn_pmsi_label = None
                                                            self.mvpn_pmsi_type = None
                                                            self.mvpn_pmsi_value = YList()
                                                            self.mvpn_pmsi_value.parent = self
                                                            self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                            self.mvpn_sfs_path = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.neighbor_router_id = None
                                                            self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop()
                                                            self.next_hop.parent = self
                                                            self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhteTunnel()
                                                            self.nhte_tunnel.parent = self
                                                            self.path_flags = None
                                                            self.path_flap_count = None
                                                            self.path_import_flags = None
                                                            self.path_rt_set_id = None
                                                            self.path_rt_set_route_count = None
                                                            self.path_table_version = None
                                                            self.path_weight = None
                                                            self.pe_peers_advertised_to = YList()
                                                            self.pe_peers_advertised_to.parent = self
                                                            self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                            self.rcvd_label = None
                                                            self.rcvd_path_id = None
                                                            self.reuse_value = None
                                                            self.rib_failed = None
                                                            self.route_type = None
                                                            self.rpki_origin_as_validation_disabled = None
                                                            self.rt_set_limit_enabled = None
                                                            self.second_label = None
                                                            self.seconds_since_first_flap = None
                                                            self.show_rpki_origin_as_validity = None
                                                            self.sn_rpki_origin_as_validity = None
                                                            self.suppress_penalty = None
                                                            self.time_to_unsuppress = None


                                                        class BgpPrefix(object):
                                                            """
                                                            BGP prefix
                                                            
                                                            .. attribute:: prefix
                                                            
                                                            	Prefix
                                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                            
                                                            .. attribute:: prefix_length
                                                            
                                                            	Prefix length
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                                self.prefix.parent = self
                                                                self.prefix_length = None


                                                            class Prefix(object):
                                                                """
                                                                Prefix
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.prefix is not None and self.prefix._has_data():
                                                                    return True

                                                                if self.prefix_length is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix']['meta_info']


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress']['meta_info']


                                                        class NextHop(object):
                                                            """
                                                            Next hop
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop']['meta_info']


                                                        class NhteTunnel(object):
                                                            """
                                                            NH TE tunnel information
                                                            
                                                            .. attribute:: binding_label
                                                            
                                                            	Binding label for the tunnel
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: has_te_tunnel
                                                            
                                                            	NH TE Tunnel info is present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_info_stale
                                                            
                                                            	Tunnel is stale
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_registered
                                                            
                                                            	Tunnel registered flag
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_up
                                                            
                                                            	Tunnel Up flag
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: last_tunnel_update
                                                            
                                                            	Time since the last rib update happened
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_if_handle
                                                            
                                                            	Interface handle for the tunnel
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_name
                                                            
                                                            	tunnel name
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            .. attribute:: tunnel_type
                                                            
                                                            	tunnel type
                                                            	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                            
                                                            .. attribute:: tunnel_v6_enabled
                                                            
                                                            	IPv6 enabled
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_v6_required
                                                            
                                                            	Tunnel need IPv6
                                                            	**type**\:  bool
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.binding_label = None
                                                                self.has_te_tunnel = None
                                                                self.is_tunnel_info_stale = None
                                                                self.is_tunnel_registered = None
                                                                self.is_tunnel_up = None
                                                                self.last_tunnel_update = None
                                                                self.tunnel_if_handle = None
                                                                self.tunnel_name = None
                                                                self.tunnel_type = None
                                                                self.tunnel_v6_enabled = None
                                                                self.tunnel_v6_required = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.binding_label is not None:
                                                                    return True

                                                                if self.has_te_tunnel is not None:
                                                                    return True

                                                                if self.is_tunnel_info_stale is not None:
                                                                    return True

                                                                if self.is_tunnel_registered is not None:
                                                                    return True

                                                                if self.is_tunnel_up is not None:
                                                                    return True

                                                                if self.last_tunnel_update is not None:
                                                                    return True

                                                                if self.tunnel_if_handle is not None:
                                                                    return True

                                                                if self.tunnel_name is not None:
                                                                    return True

                                                                if self.tunnel_type is not None:
                                                                    return True

                                                                if self.tunnel_v6_enabled is not None:
                                                                    return True

                                                                if self.tunnel_v6_required is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhteTunnel']['meta_info']


                                                        class MdtGroupAddr(object):
                                                            """
                                                            IPv4 MDT Group Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr']['meta_info']


                                                        class L2VpnEvpnEsi(object):
                                                            """
                                                            L2VPN EVPN ESI
                                                            
                                                            .. attribute:: esi
                                                            
                                                            	esi
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.esi = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.esi is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi']['meta_info']


                                                        class GwAddr(object):
                                                            """
                                                            Path GW Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self.len = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.len is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.GwAddr']['meta_info']


                                                        class BestPathCompWinner(object):
                                                            """
                                                            Neighbor address of the path which won best path
                                                            comparison
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner']['meta_info']


                                                        class MvpnNbrAddr(object):
                                                            """
                                                            Mvpn nbr Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr']['meta_info']


                                                        class MvpnNexthopAddr(object):
                                                            """
                                                            Mvpn nexthop Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr']['meta_info']


                                                        class L2VpnCircuitStatusValue(object):
                                                            """
                                                            L2VPN Circuit Status Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                                        class MvpnPmsiValue(object):
                                                            """
                                                            Mvpn PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue']['meta_info']


                                                        class ExtendedCommunity(object):
                                                            """
                                                            Mvpn Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity']['meta_info']


                                                        class LocalPeersAdvertisedTo(object):
                                                            """
                                                            Local peers that this prefix has been advertised
                                                            to
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.is_neighbor = None
                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self.update_group_number = None


                                                            class NeighborAddress(object):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.is_neighbor is not None:
                                                                    return True

                                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                    return True

                                                                if self.update_group_number is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                                        class PePeersAdvertisedTo(object):
                                                            """
                                                            PE peers that this prefix has been advertised to
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.is_neighbor = None
                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self.update_group_number = None


                                                            class NeighborAddress(object):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.is_neighbor is not None:
                                                                    return True

                                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                    return True

                                                                if self.update_group_number is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo']['meta_info']


                                                        class BestPathOrrBitfield(object):
                                                            """
                                                            ORR Best path Bitfields
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.is_neighbor = None
                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self.update_group_number = None


                                                            class NeighborAddress(object):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.is_neighbor is not None:
                                                                    return True

                                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                    return True

                                                                if self.update_group_number is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield']['meta_info']


                                                        class AddPathOrrBitfield(object):
                                                            """
                                                            ORR Add path Bitfields
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.is_neighbor = None
                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self.update_group_number = None


                                                            class NeighborAddress(object):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.is_neighbor is not None:
                                                                    return True

                                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                    return True

                                                                if self.update_group_number is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.accept_own_path is not None:
                                                                return True

                                                            if self.accept_own_self_originated_p_ath is not None:
                                                                return True

                                                            if self.add_path_orr_bitfield is not None:
                                                                for child_ref in self.add_path_orr_bitfield:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.advertisedto_pe is not None:
                                                                return True

                                                            if self.aigp_metric is not None:
                                                                return True

                                                            if self.best_path_comp_stage is not None:
                                                                return True

                                                            if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                                return True

                                                            if self.best_path_id is not None:
                                                                return True

                                                            if self.best_path_id_comp_winner is not None:
                                                                return True

                                                            if self.best_path_orr_bitfield is not None:
                                                                for child_ref in self.best_path_orr_bitfield:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                                return True

                                                            if self.dampen_penalty is not None:
                                                                return True

                                                            if self.extended_community is not None:
                                                                for child_ref in self.extended_community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.fspec_invalid_path is not None:
                                                                return True

                                                            if self.graceful_shutdown is not None:
                                                                return True

                                                            if self.gw_addr is not None and self.gw_addr._has_data():
                                                                return True

                                                            if self.halflife_time is not None:
                                                                return True

                                                            if self.has_esi is not None:
                                                                return True

                                                            if self.has_gw_addr is not None:
                                                                return True

                                                            if self.has_local_net_label is not None:
                                                                return True

                                                            if self.has_mdt_group_addr is not None:
                                                                return True

                                                            if self.has_mvpn_extcomm is not None:
                                                                return True

                                                            if self.has_mvpn_nbr_addr is not None:
                                                                return True

                                                            if self.has_mvpn_nexthop_addr is not None:
                                                                return True

                                                            if self.has_mvpn_pmsi is not None:
                                                                return True

                                                            if self.has_rcvd_label is not None:
                                                                return True

                                                            if self.has_second_label is not None:
                                                                return True

                                                            if self.ibgp_signaled_validity is not None:
                                                                return True

                                                            if self.igp_metric is not None:
                                                                return True

                                                            if self.is_aggregation_suppressed is not None:
                                                                return True

                                                            if self.is_as_best is not None:
                                                                return True

                                                            if self.is_best_path is not None:
                                                                return True

                                                            if self.is_import_dampened is not None:
                                                                return True

                                                            if self.is_import_suspect is not None:
                                                                return True

                                                            if self.is_internal_path is not None:
                                                                return True

                                                            if self.is_partial_best is not None:
                                                                return True

                                                            if self.is_path_additional_path is not None:
                                                                return True

                                                            if self.is_path_advertised_local_as_only is not None:
                                                                return True

                                                            if self.is_path_af_install_eligible is not None:
                                                                return True

                                                            if self.is_path_backup is not None:
                                                                return True

                                                            if self.is_path_backup_protect_multipath is not None:
                                                                return True

                                                            if self.is_path_best_external is not None:
                                                                return True

                                                            if self.is_path_damped is not None:
                                                                return True

                                                            if self.is_path_from_confederation_peer is not None:
                                                                return True

                                                            if self.is_path_from_network_command is not None:
                                                                return True

                                                            if self.is_path_from_redistribute_command is not None:
                                                                return True

                                                            if self.is_path_from_route_reflector is not None:
                                                                return True

                                                            if self.is_path_history_held is not None:
                                                                return True

                                                            if self.is_path_imp_candidate is not None:
                                                                return True

                                                            if self.is_path_imported is not None:
                                                                return True

                                                            if self.is_path_local_aggregate is not None:
                                                                return True

                                                            if self.is_path_locally_sourced is not None:
                                                                return True

                                                            if self.is_path_long_lived_stale is not None:
                                                                return True

                                                            if self.is_path_multipath is not None:
                                                                return True

                                                            if self.is_path_nexthop_discarded is not None:
                                                                return True

                                                            if self.is_path_not_advertised is not None:
                                                                return True

                                                            if self.is_path_not_advertised_to_ebg_ps is not None:
                                                                return True

                                                            if self.is_path_received_only is not None:
                                                                return True

                                                            if self.is_path_reoriginated is not None:
                                                                return True

                                                            if self.is_path_reoriginated_stitching is not None:
                                                                return True

                                                            if self.is_path_stale is not None:
                                                                return True

                                                            if self.is_path_synced_with_igp is not None:
                                                                return True

                                                            if self.is_path_valid is not None:
                                                                return True

                                                            if self.is_path_vpn_only is not None:
                                                                return True

                                                            if self.is_permanent_path is not None:
                                                                return True

                                                            if self.is_received_path_not_modified is not None:
                                                                return True

                                                            if self.is_spkr_as_best is not None:
                                                                return True

                                                            if self.l2vpn_circuit_status_value is not None:
                                                                for child_ref in self.l2vpn_circuit_status_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                                return True

                                                            if self.l2vpn_size is not None:
                                                                return True

                                                            if self.labeled_unicast_safi_path is not None:
                                                                return True

                                                            if self.local_label is not None:
                                                                return True

                                                            if self.local_nh is not None:
                                                                return True

                                                            if self.local_path_id is not None:
                                                                return True

                                                            if self.local_peers_advertised_to is not None:
                                                                for child_ref in self.local_peers_advertised_to:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.maximum_suppress_time is not None:
                                                                return True

                                                            if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                                return True

                                                            if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                                return True

                                                            if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                                return True

                                                            if self.mvpn_path_flags is not None:
                                                                return True

                                                            if self.mvpn_pmsi_flags is not None:
                                                                return True

                                                            if self.mvpn_pmsi_label is not None:
                                                                return True

                                                            if self.mvpn_pmsi_type is not None:
                                                                return True

                                                            if self.mvpn_pmsi_value is not None:
                                                                for child_ref in self.mvpn_pmsi_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.mvpn_sfs_path is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.neighbor_router_id is not None:
                                                                return True

                                                            if self.next_hop is not None and self.next_hop._has_data():
                                                                return True

                                                            if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                                return True

                                                            if self.path_flags is not None:
                                                                return True

                                                            if self.path_flap_count is not None:
                                                                return True

                                                            if self.path_import_flags is not None:
                                                                return True

                                                            if self.path_rt_set_id is not None:
                                                                return True

                                                            if self.path_rt_set_route_count is not None:
                                                                return True

                                                            if self.path_table_version is not None:
                                                                return True

                                                            if self.path_weight is not None:
                                                                return True

                                                            if self.pe_peers_advertised_to is not None:
                                                                for child_ref in self.pe_peers_advertised_to:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.rcvd_label is not None:
                                                                return True

                                                            if self.rcvd_path_id is not None:
                                                                return True

                                                            if self.reuse_value is not None:
                                                                return True

                                                            if self.rib_failed is not None:
                                                                return True

                                                            if self.route_type is not None:
                                                                return True

                                                            if self.rpki_origin_as_validation_disabled is not None:
                                                                return True

                                                            if self.rt_set_limit_enabled is not None:
                                                                return True

                                                            if self.second_label is not None:
                                                                return True

                                                            if self.seconds_since_first_flap is not None:
                                                                return True

                                                            if self.show_rpki_origin_as_validity is not None:
                                                                return True

                                                            if self.sn_rpki_origin_as_validity is not None:
                                                                return True

                                                            if self.suppress_penalty is not None:
                                                                return True

                                                            if self.time_to_unsuppress is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation']['meta_info']


                                                    class AttributesAfterPolicyIn(object):
                                                        """
                                                        Attributes after inbound policy applied
                                                        
                                                        .. attribute:: attr_set
                                                        
                                                        	ATTR\_SET attribute
                                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                        
                                                        .. attribute:: attribute_key_number
                                                        
                                                        	Attribute key number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_config
                                                        
                                                        	Attribute reuse ID Configured
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: attribute_reuse_id_current
                                                        
                                                        	Attribute reuse ID current ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_keys
                                                        
                                                        	Attribute reuse ID allocated keys
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_max_id
                                                        
                                                        	Attribute reuse ID maximum ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_node
                                                        
                                                        	Attribute reuse ID nodes
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_recover_sec
                                                        
                                                        	Attribute reuse ID timer in seconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: common_attributes
                                                        
                                                        	Common attributes
                                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                        
                                                        .. attribute:: is_application_gateway_present
                                                        
                                                        	Application gateway present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path2_byte
                                                        
                                                        	AS path encoded as 2\-byte
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_attr_set_present
                                                        
                                                        	BGP ATTR\_SET attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ribrnh_present
                                                        
                                                        	RIB RNH Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_rnh_present
                                                        
                                                        	RNH Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: ribrnh_encap
                                                        
                                                        	RIB RNH Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ribrnh_ip
                                                        
                                                        	RIB RNH IP Address
                                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                        
                                                        .. attribute:: ribrnh_mac
                                                        
                                                        	RIB RNH MAC Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                        
                                                        .. attribute:: ribrnh_table
                                                        
                                                        	RIB RNH Table
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ribrnh_vni
                                                        
                                                        	RIB RNH Vni
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ribrnhip_table
                                                        
                                                        	RIB RNH IP Table
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rnh_addr
                                                        
                                                        	RNH Address
                                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                        
                                                        .. attribute:: rnh_addr_len
                                                        
                                                        	RNH Address Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rnh_len
                                                        
                                                        	RNH Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: rnh_type
                                                        
                                                        	RNH Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: set_aigp_inbound_igp
                                                        
                                                        	AIGP set by policy inbound IGP 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: set_aigp_inbound_metric
                                                        
                                                        	AIGP set by policy inbound metric
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: vpn_distinguisher
                                                        
                                                        	VPN Distinguisher
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                            self.attr_set.parent = self
                                                            self.attribute_key_number = None
                                                            self.attribute_reuse_id_config = None
                                                            self.attribute_reuse_id_current = None
                                                            self.attribute_reuse_id_keys = None
                                                            self.attribute_reuse_id_max_id = None
                                                            self.attribute_reuse_id_node = None
                                                            self.attribute_reuse_id_recover_sec = None
                                                            self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                            self.common_attributes.parent = self
                                                            self.is_application_gateway_present = None
                                                            self.is_as_path2_byte = None
                                                            self.is_attr_set_present = None
                                                            self.is_ribrnh_present = None
                                                            self.is_rnh_present = None
                                                            self.ribrnh_encap = None
                                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                            self.ribrnh_ip.parent = self
                                                            self.ribrnh_mac = None
                                                            self.ribrnh_table = None
                                                            self.ribrnh_vni = None
                                                            self.ribrnhip_table = None
                                                            self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                            self.rnh_addr.parent = self
                                                            self.rnh_addr_len = None
                                                            self.rnh_len = None
                                                            self.rnh_type = None
                                                            self.set_aigp_inbound_igp = None
                                                            self.set_aigp_inbound_metric = None
                                                            self.vpn_distinguisher = None


                                                        class CommonAttributes(object):
                                                            """
                                                            Common attributes
                                                            
                                                            .. attribute:: aggregator_address
                                                            
                                                            	Address where aggregation was performed
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: aggregator_as
                                                            
                                                            	AS where aggregation was last performed
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: aigp_metric_value
                                                            
                                                            	AIGP metric value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..18446744073709551615
                                                            
                                                            .. attribute:: as_path
                                                            
                                                            	AS path attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: cluster
                                                            
                                                            	Cluster list attribute
                                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                            
                                                            .. attribute:: community
                                                            
                                                            	Community attribute
                                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                            
                                                            .. attribute:: connector_type
                                                            
                                                            	Connector Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: connector_value
                                                            
                                                            	Connector Value
                                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                            
                                                            .. attribute:: extended_community
                                                            
                                                            	Extended community attribute
                                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                            
                                                            .. attribute:: extended_community_flags
                                                            
                                                            	Extended community Flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: is_aggregator_present
                                                            
                                                            	Aggregator attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_aigp_present
                                                            
                                                            	AIGP Present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_as_path_present
                                                            
                                                            	AS path attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_atomic_aggregate_present
                                                            
                                                            	Atomic aggregate attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_community_present
                                                            
                                                            	Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_connector_present
                                                            
                                                            	Connector present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_extended_community_present
                                                            
                                                            	Extended community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_label_index_present
                                                            
                                                            	Label Index attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_local_pref_present
                                                            
                                                            	Local Preference attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ls_attribute_present
                                                            
                                                            	BGP LS attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_metric_present
                                                            
                                                            	Metric attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_origin_present
                                                            
                                                            	Origin attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pe_distinguisher_label_present
                                                            
                                                            	PE distinguisher label  attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pmsi_present
                                                            
                                                            	PMSI Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pppmp_present
                                                            
                                                            	PPMP Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ssa_present
                                                            
                                                            	SSA attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_encap_present
                                                            
                                                            	Tunnel Encap attribute present 
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: l2tpv3_cookie
                                                            
                                                            	L2TPv3 Cookie
                                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                            
                                                            .. attribute:: l2tpv3_session_id
                                                            
                                                            	L2TPv3 session id
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: label_index_attr
                                                            
                                                            	Label Index attribute
                                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                            
                                                            .. attribute:: local_preference
                                                            
                                                            	Local preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ls_attr
                                                            
                                                            	BGP LS attribute
                                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	Metric
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: neighbor_as
                                                            
                                                            	Neighbor AS number
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: origin
                                                            
                                                            	Origin
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: originator
                                                            
                                                            	Originator attribute
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: pe_distinguisher_label
                                                            
                                                            	PE distinguisher label attribute
                                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                            
                                                            .. attribute:: pmsi_flags
                                                            
                                                            	PMSI Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pmsi_label
                                                            
                                                            	PMSI label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pmsi_type
                                                            
                                                            	PMSI Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: pmsi_value
                                                            
                                                            	PMSI Value
                                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                            
                                                            .. attribute:: ppm_pvalue
                                                            
                                                            	PPMP Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: sr_policy_allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                            
                                                            .. attribute:: sr_policy_binding_sid
                                                            
                                                            	SR Policy Binding sid
                                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                            
                                                            .. attribute:: sr_policy_explicit_path
                                                            
                                                            	SR Policy Explicit paths
                                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                            
                                                            .. attribute:: sr_policy_preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: sr_tunnel_request_state
                                                            
                                                            	SR Tunnel Request State
                                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                            
                                                            .. attribute:: sr_tunnel_state
                                                            
                                                            	SR Tunnel State
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encap Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: unknown_attribute
                                                            
                                                            	Unknown attributes
                                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.aggregator_address = None
                                                                self.aggregator_as = None
                                                                self.aigp_metric_value = None
                                                                self.as_path = None
                                                                self.cluster = YList()
                                                                self.cluster.parent = self
                                                                self.cluster.name = 'cluster'
                                                                self.community = YList()
                                                                self.community.parent = self
                                                                self.community.name = 'community'
                                                                self.connector_type = None
                                                                self.connector_value = YList()
                                                                self.connector_value.parent = self
                                                                self.connector_value.name = 'connector_value'
                                                                self.extended_community = YList()
                                                                self.extended_community.parent = self
                                                                self.extended_community.name = 'extended_community'
                                                                self.extended_community_flags = None
                                                                self.is_aggregator_present = None
                                                                self.is_aigp_present = None
                                                                self.is_as_path_present = None
                                                                self.is_atomic_aggregate_present = None
                                                                self.is_community_present = None
                                                                self.is_connector_present = None
                                                                self.is_extended_community_present = None
                                                                self.is_label_index_present = None
                                                                self.is_local_pref_present = None
                                                                self.is_ls_attribute_present = None
                                                                self.is_metric_present = None
                                                                self.is_origin_present = None
                                                                self.is_pe_distinguisher_label_present = None
                                                                self.is_pmsi_present = None
                                                                self.is_pppmp_present = None
                                                                self.is_ssa_present = None
                                                                self.is_tunnel_encap_present = None
                                                                self.l2tpv3_cookie = YList()
                                                                self.l2tpv3_cookie.parent = self
                                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                                self.l2tpv3_session_id = None
                                                                self.label_index_attr = YList()
                                                                self.label_index_attr.parent = self
                                                                self.label_index_attr.name = 'label_index_attr'
                                                                self.local_preference = None
                                                                self.ls_attr = YList()
                                                                self.ls_attr.parent = self
                                                                self.ls_attr.name = 'ls_attr'
                                                                self.metric = None
                                                                self.neighbor_as = None
                                                                self.origin = None
                                                                self.originator = None
                                                                self.pe_distinguisher_label = YList()
                                                                self.pe_distinguisher_label.parent = self
                                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                                self.pmsi_flags = None
                                                                self.pmsi_label = None
                                                                self.pmsi_type = None
                                                                self.pmsi_value = YList()
                                                                self.pmsi_value.parent = self
                                                                self.pmsi_value.name = 'pmsi_value'
                                                                self.ppm_pvalue = None
                                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                                self.sr_policy_allocated_binding_sid.parent = self
                                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                                self.sr_policy_binding_sid.parent = self
                                                                self.sr_policy_explicit_path = YList()
                                                                self.sr_policy_explicit_path.parent = self
                                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                                self.sr_policy_preference = None
                                                                self.sr_tunnel_request_state = None
                                                                self.sr_tunnel_state = None
                                                                self.tunnel_encap_type = None
                                                                self.unknown_attribute = YList()
                                                                self.unknown_attribute.parent = self
                                                                self.unknown_attribute.name = 'unknown_attribute'


                                                            class SrPolicyBindingSid(object):
                                                                """
                                                                SR Policy Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_address = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                            class SrPolicyAllocatedBindingSid(object):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_address = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                            class Community(object):
                                                                """
                                                                Community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                            class ExtendedCommunity(object):
                                                                """
                                                                Extended community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                            class UnknownAttribute(object):
                                                                """
                                                                Unknown attributes
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                            class Cluster(object):
                                                                """
                                                                Cluster list attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                            class L2Tpv3Cookie(object):
                                                                """
                                                                L2TPv3 Cookie
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                            class ConnectorValue(object):
                                                                """
                                                                Connector Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                            class PmsiValue(object):
                                                                """
                                                                PMSI Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                            class LsAttr(object):
                                                                """
                                                                BGP LS attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                            class LabelIndexAttr(object):
                                                                """
                                                                Label Index attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                            class PeDistinguisherLabel(object):
                                                                """
                                                                PE distinguisher label attribute
                                                                
                                                                .. attribute:: label
                                                                
                                                                	Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pe_address
                                                                
                                                                	 PE address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.label = None
                                                                    self.pe_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.pe_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                            class SrPolicyExplicitPath(object):
                                                                """
                                                                SR Policy Explicit paths
                                                                
                                                                .. attribute:: sid
                                                                
                                                                	Sidlist for explicit path
                                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of explicit path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.sid = YList()
                                                                    self.sid.parent = self
                                                                    self.sid.name = 'sid'
                                                                    self.weight = None


                                                                class Sid(object):
                                                                    """
                                                                    Sidlist for explicit path
                                                                    
                                                                    .. attribute:: ipv4
                                                                    
                                                                    	IP Address sid
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6
                                                                    
                                                                    	IPv6 address sid
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label sid
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Sid Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4 = None
                                                                        self.ipv6 = None
                                                                        self.label = None
                                                                        self.type = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4 is not None:
                                                                            return True

                                                                        if self.ipv6 is not None:
                                                                            return True

                                                                        if self.label is not None:
                                                                            return True

                                                                        if self.type is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.sid is not None:
                                                                        for child_ref in self.sid:
                                                                            if child_ref._has_data():
                                                                                return True

                                                                    if self.weight is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.aggregator_address is not None:
                                                                    return True

                                                                if self.aggregator_as is not None:
                                                                    return True

                                                                if self.aigp_metric_value is not None:
                                                                    return True

                                                                if self.as_path is not None:
                                                                    return True

                                                                if self.cluster is not None:
                                                                    for child_ref in self.cluster:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.community is not None:
                                                                    for child_ref in self.community:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.connector_type is not None:
                                                                    return True

                                                                if self.connector_value is not None:
                                                                    for child_ref in self.connector_value:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.extended_community is not None:
                                                                    for child_ref in self.extended_community:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.extended_community_flags is not None:
                                                                    return True

                                                                if self.is_aggregator_present is not None:
                                                                    return True

                                                                if self.is_aigp_present is not None:
                                                                    return True

                                                                if self.is_as_path_present is not None:
                                                                    return True

                                                                if self.is_atomic_aggregate_present is not None:
                                                                    return True

                                                                if self.is_community_present is not None:
                                                                    return True

                                                                if self.is_connector_present is not None:
                                                                    return True

                                                                if self.is_extended_community_present is not None:
                                                                    return True

                                                                if self.is_label_index_present is not None:
                                                                    return True

                                                                if self.is_local_pref_present is not None:
                                                                    return True

                                                                if self.is_ls_attribute_present is not None:
                                                                    return True

                                                                if self.is_metric_present is not None:
                                                                    return True

                                                                if self.is_origin_present is not None:
                                                                    return True

                                                                if self.is_pe_distinguisher_label_present is not None:
                                                                    return True

                                                                if self.is_pmsi_present is not None:
                                                                    return True

                                                                if self.is_pppmp_present is not None:
                                                                    return True

                                                                if self.is_ssa_present is not None:
                                                                    return True

                                                                if self.is_tunnel_encap_present is not None:
                                                                    return True

                                                                if self.l2tpv3_cookie is not None:
                                                                    for child_ref in self.l2tpv3_cookie:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.l2tpv3_session_id is not None:
                                                                    return True

                                                                if self.label_index_attr is not None:
                                                                    for child_ref in self.label_index_attr:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.local_preference is not None:
                                                                    return True

                                                                if self.ls_attr is not None:
                                                                    for child_ref in self.ls_attr:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.metric is not None:
                                                                    return True

                                                                if self.neighbor_as is not None:
                                                                    return True

                                                                if self.origin is not None:
                                                                    return True

                                                                if self.originator is not None:
                                                                    return True

                                                                if self.pe_distinguisher_label is not None:
                                                                    for child_ref in self.pe_distinguisher_label:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.pmsi_flags is not None:
                                                                    return True

                                                                if self.pmsi_label is not None:
                                                                    return True

                                                                if self.pmsi_type is not None:
                                                                    return True

                                                                if self.pmsi_value is not None:
                                                                    for child_ref in self.pmsi_value:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.ppm_pvalue is not None:
                                                                    return True

                                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                                    return True

                                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                                    return True

                                                                if self.sr_policy_explicit_path is not None:
                                                                    for child_ref in self.sr_policy_explicit_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.sr_policy_preference is not None:
                                                                    return True

                                                                if self.sr_tunnel_request_state is not None:
                                                                    return True

                                                                if self.sr_tunnel_state is not None:
                                                                    return True

                                                                if self.tunnel_encap_type is not None:
                                                                    return True

                                                                if self.unknown_attribute is not None:
                                                                    for child_ref in self.unknown_attribute:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                                        class AttrSet(object):
                                                            """
                                                            ATTR\_SET attribute
                                                            
                                                            .. attribute:: aggregator_address
                                                            
                                                            	Address where aggregation was performed
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: aggregator_as
                                                            
                                                            	AS where aggregation was last performed
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: aigp_metric_value
                                                            
                                                            	AIGP metric value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..18446744073709551615
                                                            
                                                            .. attribute:: as_path
                                                            
                                                            	AS path attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: cluster
                                                            
                                                            	Cluster list attribute
                                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                            
                                                            .. attribute:: community
                                                            
                                                            	Community attribute
                                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                            
                                                            .. attribute:: connector_type
                                                            
                                                            	Connector Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: connector_value
                                                            
                                                            	Connector Value
                                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                            
                                                            .. attribute:: extended_community
                                                            
                                                            	Extended community attribute
                                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                            
                                                            .. attribute:: extended_community_flags
                                                            
                                                            	Extended community Flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: is_aggregator_present
                                                            
                                                            	Aggregator attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_aigp_present
                                                            
                                                            	AIGP Present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_as_path_present
                                                            
                                                            	AS path attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_atomic_aggregate_present
                                                            
                                                            	Atomic aggregate attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_community_present
                                                            
                                                            	Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_connector_present
                                                            
                                                            	Connector present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_extended_community_present
                                                            
                                                            	Extended community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_label_index_present
                                                            
                                                            	Label Index attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_local_pref_present
                                                            
                                                            	Local Preference attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ls_attribute_present
                                                            
                                                            	BGP LS attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_metric_present
                                                            
                                                            	Metric attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_origin_present
                                                            
                                                            	Origin attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pe_distinguisher_label_present
                                                            
                                                            	PE distinguisher label  attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pmsi_present
                                                            
                                                            	PMSI Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pppmp_present
                                                            
                                                            	PPMP Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ssa_present
                                                            
                                                            	SSA attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_encap_present
                                                            
                                                            	Tunnel Encap attribute present 
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: l2tpv3_cookie
                                                            
                                                            	L2TPv3 Cookie
                                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                            
                                                            .. attribute:: l2tpv3_session_id
                                                            
                                                            	L2TPv3 session id
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: label_index_attr
                                                            
                                                            	Label Index attribute
                                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                            
                                                            .. attribute:: local_preference
                                                            
                                                            	Local preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ls_attr
                                                            
                                                            	BGP LS attribute
                                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	Metric
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: neighbor_as
                                                            
                                                            	Neighbor AS number
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: origin
                                                            
                                                            	Origin
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: originator
                                                            
                                                            	Originator attribute
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: pe_distinguisher_label
                                                            
                                                            	PE distinguisher label attribute
                                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                            
                                                            .. attribute:: pmsi_flags
                                                            
                                                            	PMSI Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pmsi_label
                                                            
                                                            	PMSI label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pmsi_type
                                                            
                                                            	PMSI Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: pmsi_value
                                                            
                                                            	PMSI Value
                                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                            
                                                            .. attribute:: ppm_pvalue
                                                            
                                                            	PPMP Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: sr_policy_allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                            
                                                            .. attribute:: sr_policy_binding_sid
                                                            
                                                            	SR Policy Binding sid
                                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                            
                                                            .. attribute:: sr_policy_explicit_path
                                                            
                                                            	SR Policy Explicit paths
                                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                            
                                                            .. attribute:: sr_policy_preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: sr_tunnel_request_state
                                                            
                                                            	SR Tunnel Request State
                                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                            
                                                            .. attribute:: sr_tunnel_state
                                                            
                                                            	SR Tunnel State
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encap Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: unknown_attribute
                                                            
                                                            	Unknown attributes
                                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.aggregator_address = None
                                                                self.aggregator_as = None
                                                                self.aigp_metric_value = None
                                                                self.as_path = None
                                                                self.cluster = YList()
                                                                self.cluster.parent = self
                                                                self.cluster.name = 'cluster'
                                                                self.community = YList()
                                                                self.community.parent = self
                                                                self.community.name = 'community'
                                                                self.connector_type = None
                                                                self.connector_value = YList()
                                                                self.connector_value.parent = self
                                                                self.connector_value.name = 'connector_value'
                                                                self.extended_community = YList()
                                                                self.extended_community.parent = self
                                                                self.extended_community.name = 'extended_community'
                                                                self.extended_community_flags = None
                                                                self.is_aggregator_present = None
                                                                self.is_aigp_present = None
                                                                self.is_as_path_present = None
                                                                self.is_atomic_aggregate_present = None
                                                                self.is_community_present = None
                                                                self.is_connector_present = None
                                                                self.is_extended_community_present = None
                                                                self.is_label_index_present = None
                                                                self.is_local_pref_present = None
                                                                self.is_ls_attribute_present = None
                                                                self.is_metric_present = None
                                                                self.is_origin_present = None
                                                                self.is_pe_distinguisher_label_present = None
                                                                self.is_pmsi_present = None
                                                                self.is_pppmp_present = None
                                                                self.is_ssa_present = None
                                                                self.is_tunnel_encap_present = None
                                                                self.l2tpv3_cookie = YList()
                                                                self.l2tpv3_cookie.parent = self
                                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                                self.l2tpv3_session_id = None
                                                                self.label_index_attr = YList()
                                                                self.label_index_attr.parent = self
                                                                self.label_index_attr.name = 'label_index_attr'
                                                                self.local_preference = None
                                                                self.ls_attr = YList()
                                                                self.ls_attr.parent = self
                                                                self.ls_attr.name = 'ls_attr'
                                                                self.metric = None
                                                                self.neighbor_as = None
                                                                self.origin = None
                                                                self.originator = None
                                                                self.pe_distinguisher_label = YList()
                                                                self.pe_distinguisher_label.parent = self
                                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                                self.pmsi_flags = None
                                                                self.pmsi_label = None
                                                                self.pmsi_type = None
                                                                self.pmsi_value = YList()
                                                                self.pmsi_value.parent = self
                                                                self.pmsi_value.name = 'pmsi_value'
                                                                self.ppm_pvalue = None
                                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                                self.sr_policy_allocated_binding_sid.parent = self
                                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                                self.sr_policy_binding_sid.parent = self
                                                                self.sr_policy_explicit_path = YList()
                                                                self.sr_policy_explicit_path.parent = self
                                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                                self.sr_policy_preference = None
                                                                self.sr_tunnel_request_state = None
                                                                self.sr_tunnel_state = None
                                                                self.tunnel_encap_type = None
                                                                self.unknown_attribute = YList()
                                                                self.unknown_attribute.parent = self
                                                                self.unknown_attribute.name = 'unknown_attribute'


                                                            class SrPolicyBindingSid(object):
                                                                """
                                                                SR Policy Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_address = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                            class SrPolicyAllocatedBindingSid(object):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_address = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                            class Community(object):
                                                                """
                                                                Community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                            class ExtendedCommunity(object):
                                                                """
                                                                Extended community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                            class UnknownAttribute(object):
                                                                """
                                                                Unknown attributes
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                            class Cluster(object):
                                                                """
                                                                Cluster list attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                            class L2Tpv3Cookie(object):
                                                                """
                                                                L2TPv3 Cookie
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                            class ConnectorValue(object):
                                                                """
                                                                Connector Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                            class PmsiValue(object):
                                                                """
                                                                PMSI Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                            class LsAttr(object):
                                                                """
                                                                BGP LS attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                            class LabelIndexAttr(object):
                                                                """
                                                                Label Index attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                            class PeDistinguisherLabel(object):
                                                                """
                                                                PE distinguisher label attribute
                                                                
                                                                .. attribute:: label
                                                                
                                                                	Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pe_address
                                                                
                                                                	 PE address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.label = None
                                                                    self.pe_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.pe_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                            class SrPolicyExplicitPath(object):
                                                                """
                                                                SR Policy Explicit paths
                                                                
                                                                .. attribute:: sid
                                                                
                                                                	Sidlist for explicit path
                                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of explicit path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.sid = YList()
                                                                    self.sid.parent = self
                                                                    self.sid.name = 'sid'
                                                                    self.weight = None


                                                                class Sid(object):
                                                                    """
                                                                    Sidlist for explicit path
                                                                    
                                                                    .. attribute:: ipv4
                                                                    
                                                                    	IP Address sid
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6
                                                                    
                                                                    	IPv6 address sid
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label sid
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Sid Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4 = None
                                                                        self.ipv6 = None
                                                                        self.label = None
                                                                        self.type = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4 is not None:
                                                                            return True

                                                                        if self.ipv6 is not None:
                                                                            return True

                                                                        if self.label is not None:
                                                                            return True

                                                                        if self.type is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.sid is not None:
                                                                        for child_ref in self.sid:
                                                                            if child_ref._has_data():
                                                                                return True

                                                                    if self.weight is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.aggregator_address is not None:
                                                                    return True

                                                                if self.aggregator_as is not None:
                                                                    return True

                                                                if self.aigp_metric_value is not None:
                                                                    return True

                                                                if self.as_path is not None:
                                                                    return True

                                                                if self.cluster is not None:
                                                                    for child_ref in self.cluster:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.community is not None:
                                                                    for child_ref in self.community:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.connector_type is not None:
                                                                    return True

                                                                if self.connector_value is not None:
                                                                    for child_ref in self.connector_value:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.extended_community is not None:
                                                                    for child_ref in self.extended_community:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.extended_community_flags is not None:
                                                                    return True

                                                                if self.is_aggregator_present is not None:
                                                                    return True

                                                                if self.is_aigp_present is not None:
                                                                    return True

                                                                if self.is_as_path_present is not None:
                                                                    return True

                                                                if self.is_atomic_aggregate_present is not None:
                                                                    return True

                                                                if self.is_community_present is not None:
                                                                    return True

                                                                if self.is_connector_present is not None:
                                                                    return True

                                                                if self.is_extended_community_present is not None:
                                                                    return True

                                                                if self.is_label_index_present is not None:
                                                                    return True

                                                                if self.is_local_pref_present is not None:
                                                                    return True

                                                                if self.is_ls_attribute_present is not None:
                                                                    return True

                                                                if self.is_metric_present is not None:
                                                                    return True

                                                                if self.is_origin_present is not None:
                                                                    return True

                                                                if self.is_pe_distinguisher_label_present is not None:
                                                                    return True

                                                                if self.is_pmsi_present is not None:
                                                                    return True

                                                                if self.is_pppmp_present is not None:
                                                                    return True

                                                                if self.is_ssa_present is not None:
                                                                    return True

                                                                if self.is_tunnel_encap_present is not None:
                                                                    return True

                                                                if self.l2tpv3_cookie is not None:
                                                                    for child_ref in self.l2tpv3_cookie:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.l2tpv3_session_id is not None:
                                                                    return True

                                                                if self.label_index_attr is not None:
                                                                    for child_ref in self.label_index_attr:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.local_preference is not None:
                                                                    return True

                                                                if self.ls_attr is not None:
                                                                    for child_ref in self.ls_attr:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.metric is not None:
                                                                    return True

                                                                if self.neighbor_as is not None:
                                                                    return True

                                                                if self.origin is not None:
                                                                    return True

                                                                if self.originator is not None:
                                                                    return True

                                                                if self.pe_distinguisher_label is not None:
                                                                    for child_ref in self.pe_distinguisher_label:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.pmsi_flags is not None:
                                                                    return True

                                                                if self.pmsi_label is not None:
                                                                    return True

                                                                if self.pmsi_type is not None:
                                                                    return True

                                                                if self.pmsi_value is not None:
                                                                    for child_ref in self.pmsi_value:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.ppm_pvalue is not None:
                                                                    return True

                                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                                    return True

                                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                                    return True

                                                                if self.sr_policy_explicit_path is not None:
                                                                    for child_ref in self.sr_policy_explicit_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.sr_policy_preference is not None:
                                                                    return True

                                                                if self.sr_tunnel_request_state is not None:
                                                                    return True

                                                                if self.sr_tunnel_state is not None:
                                                                    return True

                                                                if self.tunnel_encap_type is not None:
                                                                    return True

                                                                if self.unknown_attribute is not None:
                                                                    for child_ref in self.unknown_attribute:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                                        class RnhAddr(object):
                                                            """
                                                            RNH Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                            
                                                            .. attribute:: mac_address
                                                            
                                                            	MAC Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self.len = None
                                                                self.mac_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.len is not None:
                                                                    return True

                                                                if self.mac_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                                        class RibrnhIp(object):
                                                            """
                                                            RIB RNH IP Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.attr_set is not None and self.attr_set._has_data():
                                                                return True

                                                            if self.attribute_key_number is not None:
                                                                return True

                                                            if self.attribute_reuse_id_config is not None:
                                                                return True

                                                            if self.attribute_reuse_id_current is not None:
                                                                return True

                                                            if self.attribute_reuse_id_keys is not None:
                                                                return True

                                                            if self.attribute_reuse_id_max_id is not None:
                                                                return True

                                                            if self.attribute_reuse_id_node is not None:
                                                                return True

                                                            if self.attribute_reuse_id_recover_sec is not None:
                                                                return True

                                                            if self.common_attributes is not None and self.common_attributes._has_data():
                                                                return True

                                                            if self.is_application_gateway_present is not None:
                                                                return True

                                                            if self.is_as_path2_byte is not None:
                                                                return True

                                                            if self.is_attr_set_present is not None:
                                                                return True

                                                            if self.is_ribrnh_present is not None:
                                                                return True

                                                            if self.is_rnh_present is not None:
                                                                return True

                                                            if self.ribrnh_encap is not None:
                                                                return True

                                                            if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                                return True

                                                            if self.ribrnh_mac is not None:
                                                                return True

                                                            if self.ribrnh_table is not None:
                                                                return True

                                                            if self.ribrnh_vni is not None:
                                                                return True

                                                            if self.ribrnhip_table is not None:
                                                                return True

                                                            if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                                return True

                                                            if self.rnh_addr_len is not None:
                                                                return True

                                                            if self.rnh_len is not None:
                                                                return True

                                                            if self.rnh_type is not None:
                                                                return True

                                                            if self.set_aigp_inbound_igp is not None:
                                                                return True

                                                            if self.set_aigp_inbound_metric is not None:
                                                                return True

                                                            if self.vpn_distinguisher is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-process-instance-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.af_name is not None:
                                                            return True

                                                        if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                            return True

                                                        if self.label_fail is not None:
                                                            return True

                                                        if self.label_o_or_version is not None:
                                                            return True

                                                        if self.label_oor is not None:
                                                            return True

                                                        if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                            return True

                                                        if self.no_path is not None:
                                                            return True

                                                        if self.path_information is not None and self.path_information._has_data():
                                                            return True

                                                        if self.prefix_version is not None:
                                                            return True

                                                        if self.process_instance_id is not None:
                                                            return True

                                                        if self.route_distinguisher is not None:
                                                            return True

                                                        if self.source_route_distinguisher is not None:
                                                            return True

                                                        if self.source_vrf_name is not None:
                                                            return True

                                                        if self.srcaf_name is not None:
                                                            return True

                                                        if self.vrf_name is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath']['meta_info']


                                                class ActiveProcessInstancePath(object):
                                                    """
                                                    Active's paths for this net 
                                                    
                                                    .. attribute:: af_name
                                                    
                                                    	Address family identifier
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: attributes_after_policy_in
                                                    
                                                    	Attributes after inbound policy applied
                                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn>`
                                                    
                                                    .. attribute:: label_fail
                                                    
                                                    	LSD label allocation failed 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: label_o_or_version
                                                    
                                                    	Label Version when OOR happens
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: label_oor
                                                    
                                                    	LSD label space is exhausted
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address_xr
                                                    
                                                    	Neighbor Address
                                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr>`
                                                    
                                                    .. attribute:: no_path
                                                    
                                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: path_information
                                                    
                                                    	Path information
                                                    	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation>`
                                                    
                                                    .. attribute:: prefix_version
                                                    
                                                    	Version of BGP Prefix Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: process_instance_id
                                                    
                                                    	Process instance ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: route_distinguisher
                                                    
                                                    	Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: source_route_distinguisher
                                                    
                                                    	Source Route Distinguisher
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                                    
                                                    .. attribute:: source_vrf_name
                                                    
                                                    	Name of the source VRF
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: srcaf_name
                                                    
                                                    	Address family identifier
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: vrf_name
                                                    
                                                    	Name of the VRF
                                                    	**type**\:  str
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.af_name = None
                                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn()
                                                        self.attributes_after_policy_in.parent = self
                                                        self.label_fail = None
                                                        self.label_o_or_version = None
                                                        self.label_oor = None
                                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr()
                                                        self.neighbor_address_xr.parent = self
                                                        self.no_path = None
                                                        self.path_information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation()
                                                        self.path_information.parent = self
                                                        self.prefix_version = None
                                                        self.process_instance_id = None
                                                        self.route_distinguisher = None
                                                        self.source_route_distinguisher = None
                                                        self.source_vrf_name = None
                                                        self.srcaf_name = None
                                                        self.vrf_name = None


                                                    class NeighborAddressXr(object):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr']['meta_info']


                                                    class PathInformation(object):
                                                        """
                                                        Path information
                                                        
                                                        .. attribute:: accept_own_path
                                                        
                                                        	Accept Own
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: accept_own_self_originated_p_ath
                                                        
                                                        	Accept\-Own self\-originated
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: add_path_orr_bitfield
                                                        
                                                        	ORR Add path Bitfields
                                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                        
                                                        .. attribute:: advertisedto_pe
                                                        
                                                        	Net could be advertised                          to PE peers
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: aigp_metric
                                                        
                                                        	Total AIGP metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: best_path_comp_stage
                                                        
                                                        	Stage where the path lost to the best path or group best
                                                        	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                                        
                                                        .. attribute:: best_path_comp_winner
                                                        
                                                        	Neighbor address of the path which won best path comparison
                                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                        
                                                        .. attribute:: best_path_id
                                                        
                                                        	Best path ID; DEPRECATED BYLocalPathId
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: best_path_id_comp_winner
                                                        
                                                        	Path ID of the path which won best path comparison
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: best_path_orr_bitfield
                                                        
                                                        	ORR Best path Bitfields
                                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                        
                                                        .. attribute:: bgp_prefix
                                                        
                                                        	BGP prefix
                                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix>`
                                                        
                                                        .. attribute:: dampen_penalty
                                                        
                                                        	Dampening penalty
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Mvpn Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                        
                                                        .. attribute:: fspec_invalid_path
                                                        
                                                        	Is Fspec invalid path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: graceful_shutdown
                                                        
                                                        	Marked for graceful shutdown
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: gw_addr
                                                        
                                                        	Path GW Address
                                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.GwAddr>`
                                                        
                                                        .. attribute:: halflife_time
                                                        
                                                        	Half\-life time for the penalty
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_esi
                                                        
                                                        	Path has EVPN ESI
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_gw_addr
                                                        
                                                        	Path has GW Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_local_net_label
                                                        
                                                        	Path has local label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mdt_group_addr
                                                        
                                                        	Path has MDT Group Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_extcomm
                                                        
                                                        	Path has MVPN EXTCOMM feedback
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_nbr_addr
                                                        
                                                        	Path has Mvpn nbr Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_nexthop_addr
                                                        
                                                        	Path has MVPN nexthop Address
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_mvpn_pmsi
                                                        
                                                        	Path has MVPN PMSI feedback
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_rcvd_label
                                                        
                                                        	Path has received label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: has_second_label
                                                        
                                                        	Path has second received label
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: ibgp_signaled_validity
                                                        
                                                        	IBGP signalled validation
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: igp_metric
                                                        
                                                        	IGP metric to the gateway
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: is_aggregation_suppressed
                                                        
                                                        	Path suppressed due to aggregation
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_best
                                                        
                                                        	Best available path within AS
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_best_path
                                                        
                                                        	Best available path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_import_dampened
                                                        
                                                        	net import dampened
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_import_suspect
                                                        
                                                        	net import suspect
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_internal_path
                                                        
                                                        	Received over an internal link
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_partial_best
                                                        
                                                        	Partial best path within distributed speaker
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_additional_path
                                                        
                                                        	Path is an additional\-path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_advertised_local_as_only
                                                        
                                                        	Not advertised outside local AS
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_af_install_eligible
                                                        
                                                        	Path can be installed in AF RIB
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_backup
                                                        
                                                        	Path is a backup path 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_backup_protect_multipath
                                                        
                                                        	Path is a backup path to protect multipaths
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_best_external
                                                        
                                                        	Path is a best external path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_damped
                                                        
                                                        	Path suppressed due to dampening
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_confederation_peer
                                                        
                                                        	Path received from confederation peer
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_network_command
                                                        
                                                        	Path sourced by network command
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_redistribute_command
                                                        
                                                        	Path sourced by redistribute command
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_from_route_reflector
                                                        
                                                        	Path received from route reflector
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_history_held
                                                        
                                                        	Path entry held to remember history
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_imp_candidate
                                                        
                                                        	Path is a candidate for multipath import
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_imported
                                                        
                                                        	Path is imported
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_local_aggregate
                                                        
                                                        	Path is a locally created aggregate
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_locally_sourced
                                                        
                                                        	Path sourced locally
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_long_lived_stale
                                                        
                                                        	Long lived stale routes learnt before neighbor restarts
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_multipath
                                                        
                                                        	Path is one of multipath best routes
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_nexthop_discarded
                                                        
                                                        	Path is redirected to Null0
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_not_advertised
                                                        
                                                        	Not advertised to any peer
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_not_advertised_to_ebg_ps
                                                        
                                                        	Not advertised to EBGPs
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_received_only
                                                        
                                                        	Path is received only
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_reoriginated
                                                        
                                                        	Path is reoriginated
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_reoriginated_stitching
                                                        
                                                        	Path is reoriginated with stitching RTs
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_stale
                                                        
                                                        	Stale routes learnt before neighbor restarts
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_synced_with_igp
                                                        
                                                        	Path synchronized with IGP
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_valid
                                                        
                                                        	Path attributes are usable
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_path_vpn_only
                                                        
                                                        	Path is not in the vrf
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_permanent_path
                                                        
                                                        	Path is of type Permanent path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_received_path_not_modified
                                                        
                                                        	Received path used without modification
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_spkr_as_best
                                                        
                                                        	Best available path within AS in speaker
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2vpn_circuit_status_value
                                                        
                                                        	L2VPN Circuit Status Value
                                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                        
                                                        .. attribute:: l2vpn_evpn_esi
                                                        
                                                        	L2VPN EVPN ESI
                                                        	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi>`
                                                        
                                                        .. attribute:: l2vpn_size
                                                        
                                                        	Path block size
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: labeled_unicast_safi_path
                                                        
                                                        	Path was learnt by labeled\-unicast SAFI
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: local_label
                                                        
                                                        	Path local label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_nh
                                                        
                                                        	Path has local nexthop
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: local_path_id
                                                        
                                                        	Local path ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_peers_advertised_to
                                                        
                                                        	Local peers that this prefix has been advertised to
                                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                        
                                                        .. attribute:: maximum_suppress_time
                                                        
                                                        	Maximum duration to suppress a stable route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mdt_group_addr
                                                        
                                                        	IPv4 MDT Group Address for the path
                                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                        
                                                        .. attribute:: mvpn_nbr_addr
                                                        
                                                        	Mvpn nbr Address for the path
                                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                        
                                                        .. attribute:: mvpn_nexthop_addr
                                                        
                                                        	Mvpn nexthop Address for the path
                                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                        
                                                        .. attribute:: mvpn_path_flags
                                                        
                                                        	Mvpn path flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: mvpn_pmsi_flags
                                                        
                                                        	Mvpn PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: mvpn_pmsi_label
                                                        
                                                        	Mvpn PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mvpn_pmsi_type
                                                        
                                                        	Mvpn PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: mvpn_pmsi_value
                                                        
                                                        	Mvpn PMSI Value
                                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                        
                                                        .. attribute:: mvpn_sfs_path
                                                        
                                                        	Is MVPN single forwarder PE path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress>`
                                                        
                                                        .. attribute:: neighbor_router_id
                                                        
                                                        	Router ID of the neighbor for the path
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: next_hop
                                                        
                                                        	Next hop
                                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop>`
                                                        
                                                        .. attribute:: nhte_tunnel
                                                        
                                                        	NH TE tunnel information
                                                        	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhteTunnel>`
                                                        
                                                        .. attribute:: path_flags
                                                        
                                                        	Flags associated with path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: path_flap_count
                                                        
                                                        	Number of times this route has flapped
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_import_flags
                                                        
                                                        	Path import flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_rt_set_id
                                                        
                                                        	RT\-set id of the path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_rt_set_route_count
                                                        
                                                        	Count in RT\-set
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_table_version
                                                        
                                                        	Table version # for pelem
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: path_weight
                                                        
                                                        	Weight for the path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pe_peers_advertised_to
                                                        
                                                        	PE peers that this prefix has been advertised to
                                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                        
                                                        .. attribute:: rcvd_label
                                                        
                                                        	Path received label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rcvd_path_id
                                                        
                                                        	Received path ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: reuse_value
                                                        
                                                        	Value to start reusing a route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rib_failed
                                                        
                                                        	Is net failed installed                          in RIB
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route Type of path
                                                        	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                                        
                                                        .. attribute:: rpki_origin_as_validation_disabled
                                                        
                                                        	RPKI originAS V. Disabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: rt_set_limit_enabled
                                                        
                                                        	Path subject to RT\-set net limit
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: second_label
                                                        
                                                        	Path second received label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: seconds_since_first_flap
                                                        
                                                        	Seconds since route first flapped
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: show_rpki_origin_as_validity
                                                        
                                                        	Display validity state ?
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: sn_rpki_origin_as_validity
                                                        
                                                        	RPKI origin validation state
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: suppress_penalty
                                                        
                                                        	Value to start suppressing a route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: time_to_unsuppress
                                                        
                                                        	Seconds until route is unsuppressed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.accept_own_path = None
                                                            self.accept_own_self_originated_p_ath = None
                                                            self.add_path_orr_bitfield = YList()
                                                            self.add_path_orr_bitfield.parent = self
                                                            self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                            self.advertisedto_pe = None
                                                            self.aigp_metric = None
                                                            self.best_path_comp_stage = None
                                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner()
                                                            self.best_path_comp_winner.parent = self
                                                            self.best_path_id = None
                                                            self.best_path_id_comp_winner = None
                                                            self.best_path_orr_bitfield = YList()
                                                            self.best_path_orr_bitfield.parent = self
                                                            self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix()
                                                            self.bgp_prefix.parent = self
                                                            self.dampen_penalty = None
                                                            self.extended_community = YList()
                                                            self.extended_community.parent = self
                                                            self.extended_community.name = 'extended_community'
                                                            self.fspec_invalid_path = None
                                                            self.graceful_shutdown = None
                                                            self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.GwAddr()
                                                            self.gw_addr.parent = self
                                                            self.halflife_time = None
                                                            self.has_esi = None
                                                            self.has_gw_addr = None
                                                            self.has_local_net_label = None
                                                            self.has_mdt_group_addr = None
                                                            self.has_mvpn_extcomm = None
                                                            self.has_mvpn_nbr_addr = None
                                                            self.has_mvpn_nexthop_addr = None
                                                            self.has_mvpn_pmsi = None
                                                            self.has_rcvd_label = None
                                                            self.has_second_label = None
                                                            self.ibgp_signaled_validity = None
                                                            self.igp_metric = None
                                                            self.is_aggregation_suppressed = None
                                                            self.is_as_best = None
                                                            self.is_best_path = None
                                                            self.is_import_dampened = None
                                                            self.is_import_suspect = None
                                                            self.is_internal_path = None
                                                            self.is_partial_best = None
                                                            self.is_path_additional_path = None
                                                            self.is_path_advertised_local_as_only = None
                                                            self.is_path_af_install_eligible = None
                                                            self.is_path_backup = None
                                                            self.is_path_backup_protect_multipath = None
                                                            self.is_path_best_external = None
                                                            self.is_path_damped = None
                                                            self.is_path_from_confederation_peer = None
                                                            self.is_path_from_network_command = None
                                                            self.is_path_from_redistribute_command = None
                                                            self.is_path_from_route_reflector = None
                                                            self.is_path_history_held = None
                                                            self.is_path_imp_candidate = None
                                                            self.is_path_imported = None
                                                            self.is_path_local_aggregate = None
                                                            self.is_path_locally_sourced = None
                                                            self.is_path_long_lived_stale = None
                                                            self.is_path_multipath = None
                                                            self.is_path_nexthop_discarded = None
                                                            self.is_path_not_advertised = None
                                                            self.is_path_not_advertised_to_ebg_ps = None
                                                            self.is_path_received_only = None
                                                            self.is_path_reoriginated = None
                                                            self.is_path_reoriginated_stitching = None
                                                            self.is_path_stale = None
                                                            self.is_path_synced_with_igp = None
                                                            self.is_path_valid = None
                                                            self.is_path_vpn_only = None
                                                            self.is_permanent_path = None
                                                            self.is_received_path_not_modified = None
                                                            self.is_spkr_as_best = None
                                                            self.l2vpn_circuit_status_value = YList()
                                                            self.l2vpn_circuit_status_value.parent = self
                                                            self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                            self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi()
                                                            self.l2vpn_evpn_esi.parent = self
                                                            self.l2vpn_size = None
                                                            self.labeled_unicast_safi_path = None
                                                            self.local_label = None
                                                            self.local_nh = None
                                                            self.local_path_id = None
                                                            self.local_peers_advertised_to = YList()
                                                            self.local_peers_advertised_to.parent = self
                                                            self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                            self.maximum_suppress_time = None
                                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr()
                                                            self.mdt_group_addr.parent = self
                                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                            self.mvpn_nbr_addr.parent = self
                                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                            self.mvpn_nexthop_addr.parent = self
                                                            self.mvpn_path_flags = None
                                                            self.mvpn_pmsi_flags = None
                                                            self.mvpn_pmsi_label = None
                                                            self.mvpn_pmsi_type = None
                                                            self.mvpn_pmsi_value = YList()
                                                            self.mvpn_pmsi_value.parent = self
                                                            self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                            self.mvpn_sfs_path = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.neighbor_router_id = None
                                                            self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop()
                                                            self.next_hop.parent = self
                                                            self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhteTunnel()
                                                            self.nhte_tunnel.parent = self
                                                            self.path_flags = None
                                                            self.path_flap_count = None
                                                            self.path_import_flags = None
                                                            self.path_rt_set_id = None
                                                            self.path_rt_set_route_count = None
                                                            self.path_table_version = None
                                                            self.path_weight = None
                                                            self.pe_peers_advertised_to = YList()
                                                            self.pe_peers_advertised_to.parent = self
                                                            self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                            self.rcvd_label = None
                                                            self.rcvd_path_id = None
                                                            self.reuse_value = None
                                                            self.rib_failed = None
                                                            self.route_type = None
                                                            self.rpki_origin_as_validation_disabled = None
                                                            self.rt_set_limit_enabled = None
                                                            self.second_label = None
                                                            self.seconds_since_first_flap = None
                                                            self.show_rpki_origin_as_validity = None
                                                            self.sn_rpki_origin_as_validity = None
                                                            self.suppress_penalty = None
                                                            self.time_to_unsuppress = None


                                                        class BgpPrefix(object):
                                                            """
                                                            BGP prefix
                                                            
                                                            .. attribute:: prefix
                                                            
                                                            	Prefix
                                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                            
                                                            .. attribute:: prefix_length
                                                            
                                                            	Prefix length
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                                self.prefix.parent = self
                                                                self.prefix_length = None


                                                            class Prefix(object):
                                                                """
                                                                Prefix
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.prefix is not None and self.prefix._has_data():
                                                                    return True

                                                                if self.prefix_length is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix']['meta_info']


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress']['meta_info']


                                                        class NextHop(object):
                                                            """
                                                            Next hop
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop']['meta_info']


                                                        class NhteTunnel(object):
                                                            """
                                                            NH TE tunnel information
                                                            
                                                            .. attribute:: binding_label
                                                            
                                                            	Binding label for the tunnel
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: has_te_tunnel
                                                            
                                                            	NH TE Tunnel info is present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_info_stale
                                                            
                                                            	Tunnel is stale
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_registered
                                                            
                                                            	Tunnel registered flag
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_up
                                                            
                                                            	Tunnel Up flag
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: last_tunnel_update
                                                            
                                                            	Time since the last rib update happened
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_if_handle
                                                            
                                                            	Interface handle for the tunnel
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_name
                                                            
                                                            	tunnel name
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            .. attribute:: tunnel_type
                                                            
                                                            	tunnel type
                                                            	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                            
                                                            .. attribute:: tunnel_v6_enabled
                                                            
                                                            	IPv6 enabled
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: tunnel_v6_required
                                                            
                                                            	Tunnel need IPv6
                                                            	**type**\:  bool
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.binding_label = None
                                                                self.has_te_tunnel = None
                                                                self.is_tunnel_info_stale = None
                                                                self.is_tunnel_registered = None
                                                                self.is_tunnel_up = None
                                                                self.last_tunnel_update = None
                                                                self.tunnel_if_handle = None
                                                                self.tunnel_name = None
                                                                self.tunnel_type = None
                                                                self.tunnel_v6_enabled = None
                                                                self.tunnel_v6_required = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.binding_label is not None:
                                                                    return True

                                                                if self.has_te_tunnel is not None:
                                                                    return True

                                                                if self.is_tunnel_info_stale is not None:
                                                                    return True

                                                                if self.is_tunnel_registered is not None:
                                                                    return True

                                                                if self.is_tunnel_up is not None:
                                                                    return True

                                                                if self.last_tunnel_update is not None:
                                                                    return True

                                                                if self.tunnel_if_handle is not None:
                                                                    return True

                                                                if self.tunnel_name is not None:
                                                                    return True

                                                                if self.tunnel_type is not None:
                                                                    return True

                                                                if self.tunnel_v6_enabled is not None:
                                                                    return True

                                                                if self.tunnel_v6_required is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhteTunnel']['meta_info']


                                                        class MdtGroupAddr(object):
                                                            """
                                                            IPv4 MDT Group Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr']['meta_info']


                                                        class L2VpnEvpnEsi(object):
                                                            """
                                                            L2VPN EVPN ESI
                                                            
                                                            .. attribute:: esi
                                                            
                                                            	esi
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.esi = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.esi is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi']['meta_info']


                                                        class GwAddr(object):
                                                            """
                                                            Path GW Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self.len = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.len is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.GwAddr']['meta_info']


                                                        class BestPathCompWinner(object):
                                                            """
                                                            Neighbor address of the path which won best path
                                                            comparison
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner']['meta_info']


                                                        class MvpnNbrAddr(object):
                                                            """
                                                            Mvpn nbr Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr']['meta_info']


                                                        class MvpnNexthopAddr(object):
                                                            """
                                                            Mvpn nexthop Address for the path
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr']['meta_info']


                                                        class L2VpnCircuitStatusValue(object):
                                                            """
                                                            L2VPN Circuit Status Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                                        class MvpnPmsiValue(object):
                                                            """
                                                            Mvpn PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue']['meta_info']


                                                        class ExtendedCommunity(object):
                                                            """
                                                            Mvpn Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity']['meta_info']


                                                        class LocalPeersAdvertisedTo(object):
                                                            """
                                                            Local peers that this prefix has been advertised
                                                            to
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.is_neighbor = None
                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self.update_group_number = None


                                                            class NeighborAddress(object):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.is_neighbor is not None:
                                                                    return True

                                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                    return True

                                                                if self.update_group_number is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                                        class PePeersAdvertisedTo(object):
                                                            """
                                                            PE peers that this prefix has been advertised to
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.is_neighbor = None
                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self.update_group_number = None


                                                            class NeighborAddress(object):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.is_neighbor is not None:
                                                                    return True

                                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                    return True

                                                                if self.update_group_number is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo']['meta_info']


                                                        class BestPathOrrBitfield(object):
                                                            """
                                                            ORR Best path Bitfields
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.is_neighbor = None
                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self.update_group_number = None


                                                            class NeighborAddress(object):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.is_neighbor is not None:
                                                                    return True

                                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                    return True

                                                                if self.update_group_number is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield']['meta_info']


                                                        class AddPathOrrBitfield(object):
                                                            """
                                                            ORR Add path Bitfields
                                                            
                                                            .. attribute:: is_neighbor
                                                            
                                                            	Entry is a neighbor (not an update group)
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: neighbor_address
                                                            
                                                            	Neighbor Address
                                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                            
                                                            .. attribute:: update_group_number
                                                            
                                                            	Update group index
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.is_neighbor = None
                                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                                self.neighbor_address.parent = self
                                                                self.update_group_number = None


                                                            class NeighborAddress(object):
                                                                """
                                                                Neighbor Address
                                                                
                                                                .. attribute:: afi
                                                                
                                                                	AFI
                                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_flowspec_address
                                                                
                                                                	IPV4 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4_label_address
                                                                
                                                                	IPv4 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_mcast_address
                                                                
                                                                	IPv4 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4_tunnel_address
                                                                
                                                                	IPv4 Tunnel
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mdt_address
                                                                
                                                                	IPv4 MDT Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                                
                                                                .. attribute:: ipv4mvpn_address
                                                                
                                                                	MVPN4 addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                                
                                                                .. attribute:: ipv4sr_policy_address
                                                                
                                                                	IPV4 Policy Addr
                                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv4vpn_address
                                                                
                                                                	IPv4 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv4vpn_flowspec_address
                                                                
                                                                	IPV4 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv4vpna_mcastddress
                                                                
                                                                	IPv4 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPV6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_flowspec_address
                                                                
                                                                	IPV6 Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6_label_address
                                                                
                                                                	IPv6 Label Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_mcast_address
                                                                
                                                                	IPV6 Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6mvpn_address
                                                                
                                                                	MVPN addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                                
                                                                .. attribute:: ipv6sr_policy_address
                                                                
                                                                	IPV6 Policy Addr
                                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                                
                                                                .. attribute:: ipv6vpn_address
                                                                
                                                                	IPv6 VPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6vpn_flowspec_address
                                                                
                                                                	IPV6 VPN Flowspec Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                                
                                                                .. attribute:: ipv6vpn_mcast_address
                                                                
                                                                	IPv6 VPN Mcast Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: l2vpn_evpn_address
                                                                
                                                                	L2VPN EVPN Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                                
                                                                .. attribute:: l2vpn_mspw_address
                                                                
                                                                	L2VPN MSPW Addr
                                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                                
                                                                .. attribute:: l2vpnvpls_address
                                                                
                                                                	L2VPN VPLS Addr
                                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                                
                                                                .. attribute:: ls_ls_address
                                                                
                                                                	LINKSTATE LINKSTATE Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]+
                                                                
                                                                .. attribute:: rt_constraint_address
                                                                
                                                                	RT Constrt Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.afi = None
                                                                    self.ipv4_address = None
                                                                    self.ipv4_flowspec_address = None
                                                                    self.ipv4_label_address = None
                                                                    self.ipv4_mcast_address = None
                                                                    self.ipv4_tunnel_address = None
                                                                    self.ipv4mdt_address = None
                                                                    self.ipv4mvpn_address = None
                                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                    self.ipv4sr_policy_address.parent = self
                                                                    self.ipv4vpn_address = None
                                                                    self.ipv4vpn_flowspec_address = None
                                                                    self.ipv4vpna_mcastddress = None
                                                                    self.ipv6_address = None
                                                                    self.ipv6_flowspec_address = None
                                                                    self.ipv6_label_address = None
                                                                    self.ipv6_mcast_address = None
                                                                    self.ipv6mvpn_address = None
                                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                    self.ipv6sr_policy_address.parent = self
                                                                    self.ipv6vpn_address = None
                                                                    self.ipv6vpn_flowspec_address = None
                                                                    self.ipv6vpn_mcast_address = None
                                                                    self.l2vpn_evpn_address = None
                                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                    self.l2vpn_mspw_address.parent = self
                                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                                    self.l2vpnvpls_address.parent = self
                                                                    self.ls_ls_address = None
                                                                    self.rt_constraint_address = None


                                                                class L2VpnvplsAddress(object):
                                                                    """
                                                                    L2VPN VPLS Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                                class L2VpnMspwAddress(object):
                                                                    """
                                                                    L2VPN MSPW Addr
                                                                    
                                                                    .. attribute:: l2vpn_address
                                                                    
                                                                    	l2vpn address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.l2vpn_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.l2vpn_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                                class Ipv4SrPolicyAddress(object):
                                                                    """
                                                                    IPV4 Policy Addr
                                                                    
                                                                    .. attribute:: ipv4_srpolicy_address
                                                                    
                                                                    	ipv4 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                                class Ipv6SrPolicyAddress(object):
                                                                    """
                                                                    IPV6 Policy Addr
                                                                    
                                                                    .. attribute:: ipv6_srpolicy_address
                                                                    
                                                                    	ipv6 srpolicy address
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv6_srpolicy_address = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv6_srpolicy_address is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.afi is not None:
                                                                        return True

                                                                    if self.ipv4_address is not None:
                                                                        return True

                                                                    if self.ipv4_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4_label_address is not None:
                                                                        return True

                                                                    if self.ipv4_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv4_tunnel_address is not None:
                                                                        return True

                                                                    if self.ipv4mdt_address is not None:
                                                                        return True

                                                                    if self.ipv4mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv4vpn_address is not None:
                                                                        return True

                                                                    if self.ipv4vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv4vpna_mcastddress is not None:
                                                                        return True

                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.ipv6_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6_label_address is not None:
                                                                        return True

                                                                    if self.ipv6_mcast_address is not None:
                                                                        return True

                                                                    if self.ipv6mvpn_address is not None:
                                                                        return True

                                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                        return True

                                                                    if self.ipv6vpn_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_flowspec_address is not None:
                                                                        return True

                                                                    if self.ipv6vpn_mcast_address is not None:
                                                                        return True

                                                                    if self.l2vpn_evpn_address is not None:
                                                                        return True

                                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                        return True

                                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                        return True

                                                                    if self.ls_ls_address is not None:
                                                                        return True

                                                                    if self.rt_constraint_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.is_neighbor is not None:
                                                                    return True

                                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                    return True

                                                                if self.update_group_number is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.accept_own_path is not None:
                                                                return True

                                                            if self.accept_own_self_originated_p_ath is not None:
                                                                return True

                                                            if self.add_path_orr_bitfield is not None:
                                                                for child_ref in self.add_path_orr_bitfield:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.advertisedto_pe is not None:
                                                                return True

                                                            if self.aigp_metric is not None:
                                                                return True

                                                            if self.best_path_comp_stage is not None:
                                                                return True

                                                            if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                                return True

                                                            if self.best_path_id is not None:
                                                                return True

                                                            if self.best_path_id_comp_winner is not None:
                                                                return True

                                                            if self.best_path_orr_bitfield is not None:
                                                                for child_ref in self.best_path_orr_bitfield:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                                return True

                                                            if self.dampen_penalty is not None:
                                                                return True

                                                            if self.extended_community is not None:
                                                                for child_ref in self.extended_community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.fspec_invalid_path is not None:
                                                                return True

                                                            if self.graceful_shutdown is not None:
                                                                return True

                                                            if self.gw_addr is not None and self.gw_addr._has_data():
                                                                return True

                                                            if self.halflife_time is not None:
                                                                return True

                                                            if self.has_esi is not None:
                                                                return True

                                                            if self.has_gw_addr is not None:
                                                                return True

                                                            if self.has_local_net_label is not None:
                                                                return True

                                                            if self.has_mdt_group_addr is not None:
                                                                return True

                                                            if self.has_mvpn_extcomm is not None:
                                                                return True

                                                            if self.has_mvpn_nbr_addr is not None:
                                                                return True

                                                            if self.has_mvpn_nexthop_addr is not None:
                                                                return True

                                                            if self.has_mvpn_pmsi is not None:
                                                                return True

                                                            if self.has_rcvd_label is not None:
                                                                return True

                                                            if self.has_second_label is not None:
                                                                return True

                                                            if self.ibgp_signaled_validity is not None:
                                                                return True

                                                            if self.igp_metric is not None:
                                                                return True

                                                            if self.is_aggregation_suppressed is not None:
                                                                return True

                                                            if self.is_as_best is not None:
                                                                return True

                                                            if self.is_best_path is not None:
                                                                return True

                                                            if self.is_import_dampened is not None:
                                                                return True

                                                            if self.is_import_suspect is not None:
                                                                return True

                                                            if self.is_internal_path is not None:
                                                                return True

                                                            if self.is_partial_best is not None:
                                                                return True

                                                            if self.is_path_additional_path is not None:
                                                                return True

                                                            if self.is_path_advertised_local_as_only is not None:
                                                                return True

                                                            if self.is_path_af_install_eligible is not None:
                                                                return True

                                                            if self.is_path_backup is not None:
                                                                return True

                                                            if self.is_path_backup_protect_multipath is not None:
                                                                return True

                                                            if self.is_path_best_external is not None:
                                                                return True

                                                            if self.is_path_damped is not None:
                                                                return True

                                                            if self.is_path_from_confederation_peer is not None:
                                                                return True

                                                            if self.is_path_from_network_command is not None:
                                                                return True

                                                            if self.is_path_from_redistribute_command is not None:
                                                                return True

                                                            if self.is_path_from_route_reflector is not None:
                                                                return True

                                                            if self.is_path_history_held is not None:
                                                                return True

                                                            if self.is_path_imp_candidate is not None:
                                                                return True

                                                            if self.is_path_imported is not None:
                                                                return True

                                                            if self.is_path_local_aggregate is not None:
                                                                return True

                                                            if self.is_path_locally_sourced is not None:
                                                                return True

                                                            if self.is_path_long_lived_stale is not None:
                                                                return True

                                                            if self.is_path_multipath is not None:
                                                                return True

                                                            if self.is_path_nexthop_discarded is not None:
                                                                return True

                                                            if self.is_path_not_advertised is not None:
                                                                return True

                                                            if self.is_path_not_advertised_to_ebg_ps is not None:
                                                                return True

                                                            if self.is_path_received_only is not None:
                                                                return True

                                                            if self.is_path_reoriginated is not None:
                                                                return True

                                                            if self.is_path_reoriginated_stitching is not None:
                                                                return True

                                                            if self.is_path_stale is not None:
                                                                return True

                                                            if self.is_path_synced_with_igp is not None:
                                                                return True

                                                            if self.is_path_valid is not None:
                                                                return True

                                                            if self.is_path_vpn_only is not None:
                                                                return True

                                                            if self.is_permanent_path is not None:
                                                                return True

                                                            if self.is_received_path_not_modified is not None:
                                                                return True

                                                            if self.is_spkr_as_best is not None:
                                                                return True

                                                            if self.l2vpn_circuit_status_value is not None:
                                                                for child_ref in self.l2vpn_circuit_status_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                                return True

                                                            if self.l2vpn_size is not None:
                                                                return True

                                                            if self.labeled_unicast_safi_path is not None:
                                                                return True

                                                            if self.local_label is not None:
                                                                return True

                                                            if self.local_nh is not None:
                                                                return True

                                                            if self.local_path_id is not None:
                                                                return True

                                                            if self.local_peers_advertised_to is not None:
                                                                for child_ref in self.local_peers_advertised_to:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.maximum_suppress_time is not None:
                                                                return True

                                                            if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                                return True

                                                            if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                                return True

                                                            if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                                return True

                                                            if self.mvpn_path_flags is not None:
                                                                return True

                                                            if self.mvpn_pmsi_flags is not None:
                                                                return True

                                                            if self.mvpn_pmsi_label is not None:
                                                                return True

                                                            if self.mvpn_pmsi_type is not None:
                                                                return True

                                                            if self.mvpn_pmsi_value is not None:
                                                                for child_ref in self.mvpn_pmsi_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.mvpn_sfs_path is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.neighbor_router_id is not None:
                                                                return True

                                                            if self.next_hop is not None and self.next_hop._has_data():
                                                                return True

                                                            if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                                return True

                                                            if self.path_flags is not None:
                                                                return True

                                                            if self.path_flap_count is not None:
                                                                return True

                                                            if self.path_import_flags is not None:
                                                                return True

                                                            if self.path_rt_set_id is not None:
                                                                return True

                                                            if self.path_rt_set_route_count is not None:
                                                                return True

                                                            if self.path_table_version is not None:
                                                                return True

                                                            if self.path_weight is not None:
                                                                return True

                                                            if self.pe_peers_advertised_to is not None:
                                                                for child_ref in self.pe_peers_advertised_to:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.rcvd_label is not None:
                                                                return True

                                                            if self.rcvd_path_id is not None:
                                                                return True

                                                            if self.reuse_value is not None:
                                                                return True

                                                            if self.rib_failed is not None:
                                                                return True

                                                            if self.route_type is not None:
                                                                return True

                                                            if self.rpki_origin_as_validation_disabled is not None:
                                                                return True

                                                            if self.rt_set_limit_enabled is not None:
                                                                return True

                                                            if self.second_label is not None:
                                                                return True

                                                            if self.seconds_since_first_flap is not None:
                                                                return True

                                                            if self.show_rpki_origin_as_validity is not None:
                                                                return True

                                                            if self.sn_rpki_origin_as_validity is not None:
                                                                return True

                                                            if self.suppress_penalty is not None:
                                                                return True

                                                            if self.time_to_unsuppress is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation']['meta_info']


                                                    class AttributesAfterPolicyIn(object):
                                                        """
                                                        Attributes after inbound policy applied
                                                        
                                                        .. attribute:: attr_set
                                                        
                                                        	ATTR\_SET attribute
                                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                        
                                                        .. attribute:: attribute_key_number
                                                        
                                                        	Attribute key number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_config
                                                        
                                                        	Attribute reuse ID Configured
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: attribute_reuse_id_current
                                                        
                                                        	Attribute reuse ID current ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_keys
                                                        
                                                        	Attribute reuse ID allocated keys
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_max_id
                                                        
                                                        	Attribute reuse ID maximum ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_node
                                                        
                                                        	Attribute reuse ID nodes
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_reuse_id_recover_sec
                                                        
                                                        	Attribute reuse ID timer in seconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: common_attributes
                                                        
                                                        	Common attributes
                                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                        
                                                        .. attribute:: is_application_gateway_present
                                                        
                                                        	Application gateway present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path2_byte
                                                        
                                                        	AS path encoded as 2\-byte
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_attr_set_present
                                                        
                                                        	BGP ATTR\_SET attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ribrnh_present
                                                        
                                                        	RIB RNH Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_rnh_present
                                                        
                                                        	RNH Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: ribrnh_encap
                                                        
                                                        	RIB RNH Encapsulation Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: ribrnh_ip
                                                        
                                                        	RIB RNH IP Address
                                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                        
                                                        .. attribute:: ribrnh_mac
                                                        
                                                        	RIB RNH MAC Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                        
                                                        .. attribute:: ribrnh_table
                                                        
                                                        	RIB RNH Table
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ribrnh_vni
                                                        
                                                        	RIB RNH Vni
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ribrnhip_table
                                                        
                                                        	RIB RNH IP Table
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rnh_addr
                                                        
                                                        	RNH Address
                                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                        
                                                        .. attribute:: rnh_addr_len
                                                        
                                                        	RNH Address Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rnh_len
                                                        
                                                        	RNH Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: rnh_type
                                                        
                                                        	RNH Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: set_aigp_inbound_igp
                                                        
                                                        	AIGP set by policy inbound IGP 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: set_aigp_inbound_metric
                                                        
                                                        	AIGP set by policy inbound metric
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: vpn_distinguisher
                                                        
                                                        	VPN Distinguisher
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                            self.attr_set.parent = self
                                                            self.attribute_key_number = None
                                                            self.attribute_reuse_id_config = None
                                                            self.attribute_reuse_id_current = None
                                                            self.attribute_reuse_id_keys = None
                                                            self.attribute_reuse_id_max_id = None
                                                            self.attribute_reuse_id_node = None
                                                            self.attribute_reuse_id_recover_sec = None
                                                            self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                            self.common_attributes.parent = self
                                                            self.is_application_gateway_present = None
                                                            self.is_as_path2_byte = None
                                                            self.is_attr_set_present = None
                                                            self.is_ribrnh_present = None
                                                            self.is_rnh_present = None
                                                            self.ribrnh_encap = None
                                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                            self.ribrnh_ip.parent = self
                                                            self.ribrnh_mac = None
                                                            self.ribrnh_table = None
                                                            self.ribrnh_vni = None
                                                            self.ribrnhip_table = None
                                                            self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                            self.rnh_addr.parent = self
                                                            self.rnh_addr_len = None
                                                            self.rnh_len = None
                                                            self.rnh_type = None
                                                            self.set_aigp_inbound_igp = None
                                                            self.set_aigp_inbound_metric = None
                                                            self.vpn_distinguisher = None


                                                        class CommonAttributes(object):
                                                            """
                                                            Common attributes
                                                            
                                                            .. attribute:: aggregator_address
                                                            
                                                            	Address where aggregation was performed
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: aggregator_as
                                                            
                                                            	AS where aggregation was last performed
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: aigp_metric_value
                                                            
                                                            	AIGP metric value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..18446744073709551615
                                                            
                                                            .. attribute:: as_path
                                                            
                                                            	AS path attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: cluster
                                                            
                                                            	Cluster list attribute
                                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                            
                                                            .. attribute:: community
                                                            
                                                            	Community attribute
                                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                            
                                                            .. attribute:: connector_type
                                                            
                                                            	Connector Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: connector_value
                                                            
                                                            	Connector Value
                                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                            
                                                            .. attribute:: extended_community
                                                            
                                                            	Extended community attribute
                                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                            
                                                            .. attribute:: extended_community_flags
                                                            
                                                            	Extended community Flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: is_aggregator_present
                                                            
                                                            	Aggregator attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_aigp_present
                                                            
                                                            	AIGP Present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_as_path_present
                                                            
                                                            	AS path attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_atomic_aggregate_present
                                                            
                                                            	Atomic aggregate attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_community_present
                                                            
                                                            	Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_connector_present
                                                            
                                                            	Connector present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_extended_community_present
                                                            
                                                            	Extended community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_label_index_present
                                                            
                                                            	Label Index attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_local_pref_present
                                                            
                                                            	Local Preference attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ls_attribute_present
                                                            
                                                            	BGP LS attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_metric_present
                                                            
                                                            	Metric attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_origin_present
                                                            
                                                            	Origin attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pe_distinguisher_label_present
                                                            
                                                            	PE distinguisher label  attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pmsi_present
                                                            
                                                            	PMSI Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pppmp_present
                                                            
                                                            	PPMP Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ssa_present
                                                            
                                                            	SSA attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_encap_present
                                                            
                                                            	Tunnel Encap attribute present 
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: l2tpv3_cookie
                                                            
                                                            	L2TPv3 Cookie
                                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                            
                                                            .. attribute:: l2tpv3_session_id
                                                            
                                                            	L2TPv3 session id
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: label_index_attr
                                                            
                                                            	Label Index attribute
                                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                            
                                                            .. attribute:: local_preference
                                                            
                                                            	Local preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ls_attr
                                                            
                                                            	BGP LS attribute
                                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	Metric
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: neighbor_as
                                                            
                                                            	Neighbor AS number
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: origin
                                                            
                                                            	Origin
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: originator
                                                            
                                                            	Originator attribute
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: pe_distinguisher_label
                                                            
                                                            	PE distinguisher label attribute
                                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                            
                                                            .. attribute:: pmsi_flags
                                                            
                                                            	PMSI Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pmsi_label
                                                            
                                                            	PMSI label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pmsi_type
                                                            
                                                            	PMSI Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: pmsi_value
                                                            
                                                            	PMSI Value
                                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                            
                                                            .. attribute:: ppm_pvalue
                                                            
                                                            	PPMP Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: sr_policy_allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                            
                                                            .. attribute:: sr_policy_binding_sid
                                                            
                                                            	SR Policy Binding sid
                                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                            
                                                            .. attribute:: sr_policy_explicit_path
                                                            
                                                            	SR Policy Explicit paths
                                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                            
                                                            .. attribute:: sr_policy_preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: sr_tunnel_request_state
                                                            
                                                            	SR Tunnel Request State
                                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                            
                                                            .. attribute:: sr_tunnel_state
                                                            
                                                            	SR Tunnel State
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encap Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: unknown_attribute
                                                            
                                                            	Unknown attributes
                                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.aggregator_address = None
                                                                self.aggregator_as = None
                                                                self.aigp_metric_value = None
                                                                self.as_path = None
                                                                self.cluster = YList()
                                                                self.cluster.parent = self
                                                                self.cluster.name = 'cluster'
                                                                self.community = YList()
                                                                self.community.parent = self
                                                                self.community.name = 'community'
                                                                self.connector_type = None
                                                                self.connector_value = YList()
                                                                self.connector_value.parent = self
                                                                self.connector_value.name = 'connector_value'
                                                                self.extended_community = YList()
                                                                self.extended_community.parent = self
                                                                self.extended_community.name = 'extended_community'
                                                                self.extended_community_flags = None
                                                                self.is_aggregator_present = None
                                                                self.is_aigp_present = None
                                                                self.is_as_path_present = None
                                                                self.is_atomic_aggregate_present = None
                                                                self.is_community_present = None
                                                                self.is_connector_present = None
                                                                self.is_extended_community_present = None
                                                                self.is_label_index_present = None
                                                                self.is_local_pref_present = None
                                                                self.is_ls_attribute_present = None
                                                                self.is_metric_present = None
                                                                self.is_origin_present = None
                                                                self.is_pe_distinguisher_label_present = None
                                                                self.is_pmsi_present = None
                                                                self.is_pppmp_present = None
                                                                self.is_ssa_present = None
                                                                self.is_tunnel_encap_present = None
                                                                self.l2tpv3_cookie = YList()
                                                                self.l2tpv3_cookie.parent = self
                                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                                self.l2tpv3_session_id = None
                                                                self.label_index_attr = YList()
                                                                self.label_index_attr.parent = self
                                                                self.label_index_attr.name = 'label_index_attr'
                                                                self.local_preference = None
                                                                self.ls_attr = YList()
                                                                self.ls_attr.parent = self
                                                                self.ls_attr.name = 'ls_attr'
                                                                self.metric = None
                                                                self.neighbor_as = None
                                                                self.origin = None
                                                                self.originator = None
                                                                self.pe_distinguisher_label = YList()
                                                                self.pe_distinguisher_label.parent = self
                                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                                self.pmsi_flags = None
                                                                self.pmsi_label = None
                                                                self.pmsi_type = None
                                                                self.pmsi_value = YList()
                                                                self.pmsi_value.parent = self
                                                                self.pmsi_value.name = 'pmsi_value'
                                                                self.ppm_pvalue = None
                                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                                self.sr_policy_allocated_binding_sid.parent = self
                                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                                self.sr_policy_binding_sid.parent = self
                                                                self.sr_policy_explicit_path = YList()
                                                                self.sr_policy_explicit_path.parent = self
                                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                                self.sr_policy_preference = None
                                                                self.sr_tunnel_request_state = None
                                                                self.sr_tunnel_state = None
                                                                self.tunnel_encap_type = None
                                                                self.unknown_attribute = YList()
                                                                self.unknown_attribute.parent = self
                                                                self.unknown_attribute.name = 'unknown_attribute'


                                                            class SrPolicyBindingSid(object):
                                                                """
                                                                SR Policy Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_address = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                            class SrPolicyAllocatedBindingSid(object):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_address = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                            class Community(object):
                                                                """
                                                                Community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                            class ExtendedCommunity(object):
                                                                """
                                                                Extended community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                            class UnknownAttribute(object):
                                                                """
                                                                Unknown attributes
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                            class Cluster(object):
                                                                """
                                                                Cluster list attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                            class L2Tpv3Cookie(object):
                                                                """
                                                                L2TPv3 Cookie
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                            class ConnectorValue(object):
                                                                """
                                                                Connector Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                            class PmsiValue(object):
                                                                """
                                                                PMSI Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                            class LsAttr(object):
                                                                """
                                                                BGP LS attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                            class LabelIndexAttr(object):
                                                                """
                                                                Label Index attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                            class PeDistinguisherLabel(object):
                                                                """
                                                                PE distinguisher label attribute
                                                                
                                                                .. attribute:: label
                                                                
                                                                	Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pe_address
                                                                
                                                                	 PE address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.label = None
                                                                    self.pe_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.pe_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                            class SrPolicyExplicitPath(object):
                                                                """
                                                                SR Policy Explicit paths
                                                                
                                                                .. attribute:: sid
                                                                
                                                                	Sidlist for explicit path
                                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of explicit path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.sid = YList()
                                                                    self.sid.parent = self
                                                                    self.sid.name = 'sid'
                                                                    self.weight = None


                                                                class Sid(object):
                                                                    """
                                                                    Sidlist for explicit path
                                                                    
                                                                    .. attribute:: ipv4
                                                                    
                                                                    	IP Address sid
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6
                                                                    
                                                                    	IPv6 address sid
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label sid
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Sid Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4 = None
                                                                        self.ipv6 = None
                                                                        self.label = None
                                                                        self.type = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4 is not None:
                                                                            return True

                                                                        if self.ipv6 is not None:
                                                                            return True

                                                                        if self.label is not None:
                                                                            return True

                                                                        if self.type is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.sid is not None:
                                                                        for child_ref in self.sid:
                                                                            if child_ref._has_data():
                                                                                return True

                                                                    if self.weight is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.aggregator_address is not None:
                                                                    return True

                                                                if self.aggregator_as is not None:
                                                                    return True

                                                                if self.aigp_metric_value is not None:
                                                                    return True

                                                                if self.as_path is not None:
                                                                    return True

                                                                if self.cluster is not None:
                                                                    for child_ref in self.cluster:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.community is not None:
                                                                    for child_ref in self.community:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.connector_type is not None:
                                                                    return True

                                                                if self.connector_value is not None:
                                                                    for child_ref in self.connector_value:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.extended_community is not None:
                                                                    for child_ref in self.extended_community:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.extended_community_flags is not None:
                                                                    return True

                                                                if self.is_aggregator_present is not None:
                                                                    return True

                                                                if self.is_aigp_present is not None:
                                                                    return True

                                                                if self.is_as_path_present is not None:
                                                                    return True

                                                                if self.is_atomic_aggregate_present is not None:
                                                                    return True

                                                                if self.is_community_present is not None:
                                                                    return True

                                                                if self.is_connector_present is not None:
                                                                    return True

                                                                if self.is_extended_community_present is not None:
                                                                    return True

                                                                if self.is_label_index_present is not None:
                                                                    return True

                                                                if self.is_local_pref_present is not None:
                                                                    return True

                                                                if self.is_ls_attribute_present is not None:
                                                                    return True

                                                                if self.is_metric_present is not None:
                                                                    return True

                                                                if self.is_origin_present is not None:
                                                                    return True

                                                                if self.is_pe_distinguisher_label_present is not None:
                                                                    return True

                                                                if self.is_pmsi_present is not None:
                                                                    return True

                                                                if self.is_pppmp_present is not None:
                                                                    return True

                                                                if self.is_ssa_present is not None:
                                                                    return True

                                                                if self.is_tunnel_encap_present is not None:
                                                                    return True

                                                                if self.l2tpv3_cookie is not None:
                                                                    for child_ref in self.l2tpv3_cookie:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.l2tpv3_session_id is not None:
                                                                    return True

                                                                if self.label_index_attr is not None:
                                                                    for child_ref in self.label_index_attr:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.local_preference is not None:
                                                                    return True

                                                                if self.ls_attr is not None:
                                                                    for child_ref in self.ls_attr:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.metric is not None:
                                                                    return True

                                                                if self.neighbor_as is not None:
                                                                    return True

                                                                if self.origin is not None:
                                                                    return True

                                                                if self.originator is not None:
                                                                    return True

                                                                if self.pe_distinguisher_label is not None:
                                                                    for child_ref in self.pe_distinguisher_label:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.pmsi_flags is not None:
                                                                    return True

                                                                if self.pmsi_label is not None:
                                                                    return True

                                                                if self.pmsi_type is not None:
                                                                    return True

                                                                if self.pmsi_value is not None:
                                                                    for child_ref in self.pmsi_value:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.ppm_pvalue is not None:
                                                                    return True

                                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                                    return True

                                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                                    return True

                                                                if self.sr_policy_explicit_path is not None:
                                                                    for child_ref in self.sr_policy_explicit_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.sr_policy_preference is not None:
                                                                    return True

                                                                if self.sr_tunnel_request_state is not None:
                                                                    return True

                                                                if self.sr_tunnel_state is not None:
                                                                    return True

                                                                if self.tunnel_encap_type is not None:
                                                                    return True

                                                                if self.unknown_attribute is not None:
                                                                    for child_ref in self.unknown_attribute:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                                        class AttrSet(object):
                                                            """
                                                            ATTR\_SET attribute
                                                            
                                                            .. attribute:: aggregator_address
                                                            
                                                            	Address where aggregation was performed
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: aggregator_as
                                                            
                                                            	AS where aggregation was last performed
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: aigp_metric_value
                                                            
                                                            	AIGP metric value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..18446744073709551615
                                                            
                                                            .. attribute:: as_path
                                                            
                                                            	AS path attribute
                                                            	**type**\:  str
                                                            
                                                            .. attribute:: cluster
                                                            
                                                            	Cluster list attribute
                                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                            
                                                            .. attribute:: community
                                                            
                                                            	Community attribute
                                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                            
                                                            .. attribute:: connector_type
                                                            
                                                            	Connector Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: connector_value
                                                            
                                                            	Connector Value
                                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                            
                                                            .. attribute:: extended_community
                                                            
                                                            	Extended community attribute
                                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                            
                                                            .. attribute:: extended_community_flags
                                                            
                                                            	Extended community Flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: is_aggregator_present
                                                            
                                                            	Aggregator attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_aigp_present
                                                            
                                                            	AIGP Present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_as_path_present
                                                            
                                                            	AS path attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_atomic_aggregate_present
                                                            
                                                            	Atomic aggregate attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_community_present
                                                            
                                                            	Community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_connector_present
                                                            
                                                            	Connector present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_extended_community_present
                                                            
                                                            	Extended community attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_label_index_present
                                                            
                                                            	Label Index attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_local_pref_present
                                                            
                                                            	Local Preference attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ls_attribute_present
                                                            
                                                            	BGP LS attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_metric_present
                                                            
                                                            	Metric attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_origin_present
                                                            
                                                            	Origin attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pe_distinguisher_label_present
                                                            
                                                            	PE distinguisher label  attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pmsi_present
                                                            
                                                            	PMSI Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_pppmp_present
                                                            
                                                            	PPMP Attribute  present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_ssa_present
                                                            
                                                            	SSA attribute present
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: is_tunnel_encap_present
                                                            
                                                            	Tunnel Encap attribute present 
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: l2tpv3_cookie
                                                            
                                                            	L2TPv3 Cookie
                                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                            
                                                            .. attribute:: l2tpv3_session_id
                                                            
                                                            	L2TPv3 session id
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: label_index_attr
                                                            
                                                            	Label Index attribute
                                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                            
                                                            .. attribute:: local_preference
                                                            
                                                            	Local preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ls_attr
                                                            
                                                            	BGP LS attribute
                                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	Metric
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: neighbor_as
                                                            
                                                            	Neighbor AS number
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: origin
                                                            
                                                            	Origin
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: originator
                                                            
                                                            	Originator attribute
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: pe_distinguisher_label
                                                            
                                                            	PE distinguisher label attribute
                                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                            
                                                            .. attribute:: pmsi_flags
                                                            
                                                            	PMSI Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pmsi_label
                                                            
                                                            	PMSI label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pmsi_type
                                                            
                                                            	PMSI Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: pmsi_value
                                                            
                                                            	PMSI Value
                                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                            
                                                            .. attribute:: ppm_pvalue
                                                            
                                                            	PPMP Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: sr_policy_allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                            
                                                            .. attribute:: sr_policy_binding_sid
                                                            
                                                            	SR Policy Binding sid
                                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                            
                                                            .. attribute:: sr_policy_explicit_path
                                                            
                                                            	SR Policy Explicit paths
                                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                            
                                                            .. attribute:: sr_policy_preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: sr_tunnel_request_state
                                                            
                                                            	SR Tunnel Request State
                                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                            
                                                            .. attribute:: sr_tunnel_state
                                                            
                                                            	SR Tunnel State
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encap Type
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: unknown_attribute
                                                            
                                                            	Unknown attributes
                                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.aggregator_address = None
                                                                self.aggregator_as = None
                                                                self.aigp_metric_value = None
                                                                self.as_path = None
                                                                self.cluster = YList()
                                                                self.cluster.parent = self
                                                                self.cluster.name = 'cluster'
                                                                self.community = YList()
                                                                self.community.parent = self
                                                                self.community.name = 'community'
                                                                self.connector_type = None
                                                                self.connector_value = YList()
                                                                self.connector_value.parent = self
                                                                self.connector_value.name = 'connector_value'
                                                                self.extended_community = YList()
                                                                self.extended_community.parent = self
                                                                self.extended_community.name = 'extended_community'
                                                                self.extended_community_flags = None
                                                                self.is_aggregator_present = None
                                                                self.is_aigp_present = None
                                                                self.is_as_path_present = None
                                                                self.is_atomic_aggregate_present = None
                                                                self.is_community_present = None
                                                                self.is_connector_present = None
                                                                self.is_extended_community_present = None
                                                                self.is_label_index_present = None
                                                                self.is_local_pref_present = None
                                                                self.is_ls_attribute_present = None
                                                                self.is_metric_present = None
                                                                self.is_origin_present = None
                                                                self.is_pe_distinguisher_label_present = None
                                                                self.is_pmsi_present = None
                                                                self.is_pppmp_present = None
                                                                self.is_ssa_present = None
                                                                self.is_tunnel_encap_present = None
                                                                self.l2tpv3_cookie = YList()
                                                                self.l2tpv3_cookie.parent = self
                                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                                self.l2tpv3_session_id = None
                                                                self.label_index_attr = YList()
                                                                self.label_index_attr.parent = self
                                                                self.label_index_attr.name = 'label_index_attr'
                                                                self.local_preference = None
                                                                self.ls_attr = YList()
                                                                self.ls_attr.parent = self
                                                                self.ls_attr.name = 'ls_attr'
                                                                self.metric = None
                                                                self.neighbor_as = None
                                                                self.origin = None
                                                                self.originator = None
                                                                self.pe_distinguisher_label = YList()
                                                                self.pe_distinguisher_label.parent = self
                                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                                self.pmsi_flags = None
                                                                self.pmsi_label = None
                                                                self.pmsi_type = None
                                                                self.pmsi_value = YList()
                                                                self.pmsi_value.parent = self
                                                                self.pmsi_value.name = 'pmsi_value'
                                                                self.ppm_pvalue = None
                                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                                self.sr_policy_allocated_binding_sid.parent = self
                                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                                self.sr_policy_binding_sid.parent = self
                                                                self.sr_policy_explicit_path = YList()
                                                                self.sr_policy_explicit_path.parent = self
                                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                                self.sr_policy_preference = None
                                                                self.sr_tunnel_request_state = None
                                                                self.sr_tunnel_state = None
                                                                self.tunnel_encap_type = None
                                                                self.unknown_attribute = YList()
                                                                self.unknown_attribute.parent = self
                                                                self.unknown_attribute.name = 'unknown_attribute'


                                                            class SrPolicyBindingSid(object):
                                                                """
                                                                SR Policy Binding sid
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_address = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                            class SrPolicyAllocatedBindingSid(object):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_address = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_address is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                            class Community(object):
                                                                """
                                                                Community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                            class ExtendedCommunity(object):
                                                                """
                                                                Extended community attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                            class UnknownAttribute(object):
                                                                """
                                                                Unknown attributes
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                            class Cluster(object):
                                                                """
                                                                Cluster list attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                            class L2Tpv3Cookie(object):
                                                                """
                                                                L2TPv3 Cookie
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                            class ConnectorValue(object):
                                                                """
                                                                Connector Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                            class PmsiValue(object):
                                                                """
                                                                PMSI Value
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                            class LsAttr(object):
                                                                """
                                                                BGP LS attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                            class LabelIndexAttr(object):
                                                                """
                                                                Label Index attribute
                                                                
                                                                .. attribute:: entry
                                                                
                                                                	
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.entry = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.entry is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                            class PeDistinguisherLabel(object):
                                                                """
                                                                PE distinguisher label attribute
                                                                
                                                                .. attribute:: label
                                                                
                                                                	Label
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pe_address
                                                                
                                                                	 PE address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.label = None
                                                                    self.pe_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.pe_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                            class SrPolicyExplicitPath(object):
                                                                """
                                                                SR Policy Explicit paths
                                                                
                                                                .. attribute:: sid
                                                                
                                                                	Sidlist for explicit path
                                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of explicit path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.sid = YList()
                                                                    self.sid.parent = self
                                                                    self.sid.name = 'sid'
                                                                    self.weight = None


                                                                class Sid(object):
                                                                    """
                                                                    Sidlist for explicit path
                                                                    
                                                                    .. attribute:: ipv4
                                                                    
                                                                    	IP Address sid
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6
                                                                    
                                                                    	IPv6 address sid
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label sid
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Sid Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2015-08-27'

                                                                    def __init__(self):
                                                                        self.parent = None
                                                                        self.ipv4 = None
                                                                        self.ipv6 = None
                                                                        self.label = None
                                                                        self.type = None

                                                                    @property
                                                                    def _common_path(self):
                                                                        if self.parent is None:
                                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                                    def is_config(self):
                                                                        ''' Returns True if this instance represents config data else returns False '''
                                                                        return False

                                                                    def _has_data(self):
                                                                        if not self.is_config():
                                                                            return False
                                                                        if self.ipv4 is not None:
                                                                            return True

                                                                        if self.ipv6 is not None:
                                                                            return True

                                                                        if self.label is not None:
                                                                            return True

                                                                        if self.type is not None:
                                                                            return True

                                                                        return False

                                                                    @staticmethod
                                                                    def _meta_info():
                                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.sid is not None:
                                                                        for child_ref in self.sid:
                                                                            if child_ref._has_data():
                                                                                return True

                                                                    if self.weight is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.aggregator_address is not None:
                                                                    return True

                                                                if self.aggregator_as is not None:
                                                                    return True

                                                                if self.aigp_metric_value is not None:
                                                                    return True

                                                                if self.as_path is not None:
                                                                    return True

                                                                if self.cluster is not None:
                                                                    for child_ref in self.cluster:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.community is not None:
                                                                    for child_ref in self.community:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.connector_type is not None:
                                                                    return True

                                                                if self.connector_value is not None:
                                                                    for child_ref in self.connector_value:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.extended_community is not None:
                                                                    for child_ref in self.extended_community:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.extended_community_flags is not None:
                                                                    return True

                                                                if self.is_aggregator_present is not None:
                                                                    return True

                                                                if self.is_aigp_present is not None:
                                                                    return True

                                                                if self.is_as_path_present is not None:
                                                                    return True

                                                                if self.is_atomic_aggregate_present is not None:
                                                                    return True

                                                                if self.is_community_present is not None:
                                                                    return True

                                                                if self.is_connector_present is not None:
                                                                    return True

                                                                if self.is_extended_community_present is not None:
                                                                    return True

                                                                if self.is_label_index_present is not None:
                                                                    return True

                                                                if self.is_local_pref_present is not None:
                                                                    return True

                                                                if self.is_ls_attribute_present is not None:
                                                                    return True

                                                                if self.is_metric_present is not None:
                                                                    return True

                                                                if self.is_origin_present is not None:
                                                                    return True

                                                                if self.is_pe_distinguisher_label_present is not None:
                                                                    return True

                                                                if self.is_pmsi_present is not None:
                                                                    return True

                                                                if self.is_pppmp_present is not None:
                                                                    return True

                                                                if self.is_ssa_present is not None:
                                                                    return True

                                                                if self.is_tunnel_encap_present is not None:
                                                                    return True

                                                                if self.l2tpv3_cookie is not None:
                                                                    for child_ref in self.l2tpv3_cookie:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.l2tpv3_session_id is not None:
                                                                    return True

                                                                if self.label_index_attr is not None:
                                                                    for child_ref in self.label_index_attr:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.local_preference is not None:
                                                                    return True

                                                                if self.ls_attr is not None:
                                                                    for child_ref in self.ls_attr:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.metric is not None:
                                                                    return True

                                                                if self.neighbor_as is not None:
                                                                    return True

                                                                if self.origin is not None:
                                                                    return True

                                                                if self.originator is not None:
                                                                    return True

                                                                if self.pe_distinguisher_label is not None:
                                                                    for child_ref in self.pe_distinguisher_label:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.pmsi_flags is not None:
                                                                    return True

                                                                if self.pmsi_label is not None:
                                                                    return True

                                                                if self.pmsi_type is not None:
                                                                    return True

                                                                if self.pmsi_value is not None:
                                                                    for child_ref in self.pmsi_value:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.ppm_pvalue is not None:
                                                                    return True

                                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                                    return True

                                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                                    return True

                                                                if self.sr_policy_explicit_path is not None:
                                                                    for child_ref in self.sr_policy_explicit_path:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.sr_policy_preference is not None:
                                                                    return True

                                                                if self.sr_tunnel_request_state is not None:
                                                                    return True

                                                                if self.sr_tunnel_state is not None:
                                                                    return True

                                                                if self.tunnel_encap_type is not None:
                                                                    return True

                                                                if self.unknown_attribute is not None:
                                                                    for child_ref in self.unknown_attribute:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                                        class RnhAddr(object):
                                                            """
                                                            RNH Address
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: len
                                                            
                                                            	len
                                                            	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                            
                                                            .. attribute:: mac_address
                                                            
                                                            	MAC Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self.len = None
                                                                self.mac_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.len is not None:
                                                                    return True

                                                                if self.mac_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                                        class RibrnhIp(object):
                                                            """
                                                            RIB RNH IP Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.attr_set is not None and self.attr_set._has_data():
                                                                return True

                                                            if self.attribute_key_number is not None:
                                                                return True

                                                            if self.attribute_reuse_id_config is not None:
                                                                return True

                                                            if self.attribute_reuse_id_current is not None:
                                                                return True

                                                            if self.attribute_reuse_id_keys is not None:
                                                                return True

                                                            if self.attribute_reuse_id_max_id is not None:
                                                                return True

                                                            if self.attribute_reuse_id_node is not None:
                                                                return True

                                                            if self.attribute_reuse_id_recover_sec is not None:
                                                                return True

                                                            if self.common_attributes is not None and self.common_attributes._has_data():
                                                                return True

                                                            if self.is_application_gateway_present is not None:
                                                                return True

                                                            if self.is_as_path2_byte is not None:
                                                                return True

                                                            if self.is_attr_set_present is not None:
                                                                return True

                                                            if self.is_ribrnh_present is not None:
                                                                return True

                                                            if self.is_rnh_present is not None:
                                                                return True

                                                            if self.ribrnh_encap is not None:
                                                                return True

                                                            if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                                return True

                                                            if self.ribrnh_mac is not None:
                                                                return True

                                                            if self.ribrnh_table is not None:
                                                                return True

                                                            if self.ribrnh_vni is not None:
                                                                return True

                                                            if self.ribrnhip_table is not None:
                                                                return True

                                                            if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                                return True

                                                            if self.rnh_addr_len is not None:
                                                                return True

                                                            if self.rnh_len is not None:
                                                                return True

                                                            if self.rnh_type is not None:
                                                                return True

                                                            if self.set_aigp_inbound_igp is not None:
                                                                return True

                                                            if self.set_aigp_inbound_metric is not None:
                                                                return True

                                                            if self.vpn_distinguisher is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-process-instance-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.af_name is not None:
                                                            return True

                                                        if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                            return True

                                                        if self.label_fail is not None:
                                                            return True

                                                        if self.label_o_or_version is not None:
                                                            return True

                                                        if self.label_oor is not None:
                                                            return True

                                                        if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                            return True

                                                        if self.no_path is not None:
                                                            return True

                                                        if self.path_information is not None and self.path_information._has_data():
                                                            return True

                                                        if self.prefix_version is not None:
                                                            return True

                                                        if self.process_instance_id is not None:
                                                            return True

                                                        if self.route_distinguisher is not None:
                                                            return True

                                                        if self.source_route_distinguisher is not None:
                                                            return True

                                                        if self.source_vrf_name is not None:
                                                            return True

                                                        if self.srcaf_name is not None:
                                                            return True

                                                        if self.vrf_name is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath']['meta_info']


                                                class LocalPathElement(object):
                                                    """
                                                    Local path element list
                                                    
                                                    .. attribute:: is_perm_path_pelem
                                                    
                                                    	Pelem for permanent path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: nhte_tunnel
                                                    
                                                    	NH TE tunnel information
                                                    	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.NhteTunnel>`
                                                    
                                                    .. attribute:: pelem_flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_gw_metric
                                                    
                                                    	Gateway metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_no_addpath_table_attr_version
                                                    
                                                    	No\-addpath Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_no_bestpath_table_attr_version
                                                    
                                                    	No\-bestpath Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_flags
                                                    
                                                    	Path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: pelem_path_id
                                                    
                                                    	Local Path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_neighbor_addr
                                                    
                                                    	Path neighbor address
                                                    	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr>`
                                                    
                                                    .. attribute:: pelem_path_nexthop
                                                    
                                                    	Path nexthop address
                                                    	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop>`
                                                    
                                                    .. attribute:: pelem_path_peer_path_id
                                                    
                                                    	Path peer path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_table_attr_version
                                                    
                                                    	Path Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_table_attr_version
                                                    
                                                    	Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_version
                                                    
                                                    	Version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_perm_path_pelem = None
                                                        self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.NhteTunnel()
                                                        self.nhte_tunnel.parent = self
                                                        self.pelem_flags = None
                                                        self.pelem_gw_metric = None
                                                        self.pelem_no_addpath_table_attr_version = None
                                                        self.pelem_no_bestpath_table_attr_version = None
                                                        self.pelem_path_flags = None
                                                        self.pelem_path_id = None
                                                        self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr()
                                                        self.pelem_path_neighbor_addr.parent = self
                                                        self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop()
                                                        self.pelem_path_nexthop.parent = self
                                                        self.pelem_path_peer_path_id = None
                                                        self.pelem_path_table_attr_version = None
                                                        self.pelem_table_attr_version = None
                                                        self.pelem_version = None


                                                    class PelemPathNexthop(object):
                                                        """
                                                        Path nexthop address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-nexthop'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop']['meta_info']


                                                    class NhteTunnel(object):
                                                        """
                                                        NH TE tunnel information
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	Binding label for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_te_tunnel
                                                        
                                                        	NH TE Tunnel info is present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_info_stale
                                                        
                                                        	Tunnel is stale
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_registered
                                                        
                                                        	Tunnel registered flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_up
                                                        
                                                        	Tunnel Up flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: last_tunnel_update
                                                        
                                                        	Time since the last rib update happened
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_if_handle
                                                        
                                                        	Interface handle for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_name
                                                        
                                                        	tunnel name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        .. attribute:: tunnel_type
                                                        
                                                        	tunnel type
                                                        	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                        
                                                        .. attribute:: tunnel_v6_enabled
                                                        
                                                        	IPv6 enabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_v6_required
                                                        
                                                        	Tunnel need IPv6
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.binding_label = None
                                                            self.has_te_tunnel = None
                                                            self.is_tunnel_info_stale = None
                                                            self.is_tunnel_registered = None
                                                            self.is_tunnel_up = None
                                                            self.last_tunnel_update = None
                                                            self.tunnel_if_handle = None
                                                            self.tunnel_name = None
                                                            self.tunnel_type = None
                                                            self.tunnel_v6_enabled = None
                                                            self.tunnel_v6_required = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.binding_label is not None:
                                                                return True

                                                            if self.has_te_tunnel is not None:
                                                                return True

                                                            if self.is_tunnel_info_stale is not None:
                                                                return True

                                                            if self.is_tunnel_registered is not None:
                                                                return True

                                                            if self.is_tunnel_up is not None:
                                                                return True

                                                            if self.last_tunnel_update is not None:
                                                                return True

                                                            if self.tunnel_if_handle is not None:
                                                                return True

                                                            if self.tunnel_name is not None:
                                                                return True

                                                            if self.tunnel_type is not None:
                                                                return True

                                                            if self.tunnel_v6_enabled is not None:
                                                                return True

                                                            if self.tunnel_v6_required is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.NhteTunnel']['meta_info']


                                                    class PelemPathNeighborAddr(object):
                                                        """
                                                        Path neighbor address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-neighbor-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-path-element'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_perm_path_pelem is not None:
                                                            return True

                                                        if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                            return True

                                                        if self.pelem_flags is not None:
                                                            return True

                                                        if self.pelem_gw_metric is not None:
                                                            return True

                                                        if self.pelem_no_addpath_table_attr_version is not None:
                                                            return True

                                                        if self.pelem_no_bestpath_table_attr_version is not None:
                                                            return True

                                                        if self.pelem_path_flags is not None:
                                                            return True

                                                        if self.pelem_path_id is not None:
                                                            return True

                                                        if self.pelem_path_neighbor_addr is not None and self.pelem_path_neighbor_addr._has_data():
                                                            return True

                                                        if self.pelem_path_nexthop is not None and self.pelem_path_nexthop._has_data():
                                                            return True

                                                        if self.pelem_path_peer_path_id is not None:
                                                            return True

                                                        if self.pelem_path_table_attr_version is not None:
                                                            return True

                                                        if self.pelem_table_attr_version is not None:
                                                            return True

                                                        if self.pelem_version is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement']['meta_info']


                                                class ActivePathElement(object):
                                                    """
                                                    Path element list received from Active inst
                                                    
                                                    .. attribute:: is_perm_path_pelem
                                                    
                                                    	Pelem for permanent path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: nhte_tunnel
                                                    
                                                    	NH TE tunnel information
                                                    	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.NhteTunnel>`
                                                    
                                                    .. attribute:: pelem_flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_gw_metric
                                                    
                                                    	Gateway metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_no_addpath_table_attr_version
                                                    
                                                    	No\-addpath Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_no_bestpath_table_attr_version
                                                    
                                                    	No\-bestpath Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_flags
                                                    
                                                    	Path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: pelem_path_id
                                                    
                                                    	Local Path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_neighbor_addr
                                                    
                                                    	Path neighbor address
                                                    	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr>`
                                                    
                                                    .. attribute:: pelem_path_nexthop
                                                    
                                                    	Path nexthop address
                                                    	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop>`
                                                    
                                                    .. attribute:: pelem_path_peer_path_id
                                                    
                                                    	Path peer path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_path_table_attr_version
                                                    
                                                    	Path Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_table_attr_version
                                                    
                                                    	Table Attr version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pelem_version
                                                    
                                                    	Version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.is_perm_path_pelem = None
                                                        self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.NhteTunnel()
                                                        self.nhte_tunnel.parent = self
                                                        self.pelem_flags = None
                                                        self.pelem_gw_metric = None
                                                        self.pelem_no_addpath_table_attr_version = None
                                                        self.pelem_no_bestpath_table_attr_version = None
                                                        self.pelem_path_flags = None
                                                        self.pelem_path_id = None
                                                        self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr()
                                                        self.pelem_path_neighbor_addr.parent = self
                                                        self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop()
                                                        self.pelem_path_nexthop.parent = self
                                                        self.pelem_path_peer_path_id = None
                                                        self.pelem_path_table_attr_version = None
                                                        self.pelem_table_attr_version = None
                                                        self.pelem_version = None


                                                    class PelemPathNexthop(object):
                                                        """
                                                        Path nexthop address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-nexthop'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop']['meta_info']


                                                    class NhteTunnel(object):
                                                        """
                                                        NH TE tunnel information
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	Binding label for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_te_tunnel
                                                        
                                                        	NH TE Tunnel info is present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_info_stale
                                                        
                                                        	Tunnel is stale
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_registered
                                                        
                                                        	Tunnel registered flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_up
                                                        
                                                        	Tunnel Up flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: last_tunnel_update
                                                        
                                                        	Time since the last rib update happened
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_if_handle
                                                        
                                                        	Interface handle for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_name
                                                        
                                                        	tunnel name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        .. attribute:: tunnel_type
                                                        
                                                        	tunnel type
                                                        	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                        
                                                        .. attribute:: tunnel_v6_enabled
                                                        
                                                        	IPv6 enabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_v6_required
                                                        
                                                        	Tunnel need IPv6
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.binding_label = None
                                                            self.has_te_tunnel = None
                                                            self.is_tunnel_info_stale = None
                                                            self.is_tunnel_registered = None
                                                            self.is_tunnel_up = None
                                                            self.last_tunnel_update = None
                                                            self.tunnel_if_handle = None
                                                            self.tunnel_name = None
                                                            self.tunnel_type = None
                                                            self.tunnel_v6_enabled = None
                                                            self.tunnel_v6_required = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.binding_label is not None:
                                                                return True

                                                            if self.has_te_tunnel is not None:
                                                                return True

                                                            if self.is_tunnel_info_stale is not None:
                                                                return True

                                                            if self.is_tunnel_registered is not None:
                                                                return True

                                                            if self.is_tunnel_up is not None:
                                                                return True

                                                            if self.last_tunnel_update is not None:
                                                                return True

                                                            if self.tunnel_if_handle is not None:
                                                                return True

                                                            if self.tunnel_name is not None:
                                                                return True

                                                            if self.tunnel_type is not None:
                                                                return True

                                                            if self.tunnel_v6_enabled is not None:
                                                                return True

                                                            if self.tunnel_v6_required is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.NhteTunnel']['meta_info']


                                                    class PelemPathNeighborAddr(object):
                                                        """
                                                        Path neighbor address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-neighbor-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-path-element'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.is_perm_path_pelem is not None:
                                                            return True

                                                        if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                            return True

                                                        if self.pelem_flags is not None:
                                                            return True

                                                        if self.pelem_gw_metric is not None:
                                                            return True

                                                        if self.pelem_no_addpath_table_attr_version is not None:
                                                            return True

                                                        if self.pelem_no_bestpath_table_attr_version is not None:
                                                            return True

                                                        if self.pelem_path_flags is not None:
                                                            return True

                                                        if self.pelem_path_id is not None:
                                                            return True

                                                        if self.pelem_path_neighbor_addr is not None and self.pelem_path_neighbor_addr._has_data():
                                                            return True

                                                        if self.pelem_path_nexthop is not None and self.pelem_path_nexthop._has_data():
                                                            return True

                                                        if self.pelem_path_peer_path_id is not None:
                                                            return True

                                                        if self.pelem_path_table_attr_version is not None:
                                                            return True

                                                        if self.pelem_table_attr_version is not None:
                                                            return True

                                                        if self.pelem_version is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                                    if self.rd is None:
                                                        raise YPYModelError('Key property rd is None')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-rd[Cisco-IOS-XR-ipv4-bgp-oper:rd = ' + str(self.rd) + ']'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.rd is not None:
                                                        return True

                                                    if self.active_path_element is not None:
                                                        for child_ref in self.active_path_element:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.active_process_instance_path is not None:
                                                        for child_ref in self.active_process_instance_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.add_path_orr_bitfield is not None:
                                                        for child_ref in self.add_path_orr_bitfield:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.advertisedto_pe is not None:
                                                        return True

                                                    if self.af_name is not None:
                                                        return True

                                                    if self.best_path_orr_bitfield is not None:
                                                        for child_ref in self.best_path_orr_bitfield:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                        return True

                                                    if self.bit is not None:
                                                        return True

                                                    if self.flags is not None:
                                                        return True

                                                    if self.gateway_array is not None:
                                                        return True

                                                    if self.has_inconsistent_paths is not None:
                                                        return True

                                                    if self.has_lbl_retained is not None:
                                                        return True

                                                    if self.has_local_label is not None:
                                                        return True

                                                    if self.is_net_aggregation_suppressed is not None:
                                                        return True

                                                    if self.is_net_ldp_signaled is not None:
                                                        return True

                                                    if self.is_permanent_network is not None:
                                                        return True

                                                    if self.local_path_element is not None:
                                                        for child_ref in self.local_path_element:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_peers_advertised_to is not None:
                                                        for child_ref in self.local_peers_advertised_to:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_process_instance_path is not None:
                                                        for child_ref in self.local_process_instance_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.net_backup_available is not None:
                                                        return True

                                                    if self.net_backup_label_rewrite_available is not None:
                                                        return True

                                                    if self.net_eibgp_multipath is not None:
                                                        return True

                                                    if self.net_extended_flags is not None:
                                                        return True

                                                    if self.net_flags is not None:
                                                        return True

                                                    if self.net_local_label is not None:
                                                        return True

                                                    if self.net_local_label_rewrite is not None:
                                                        return True

                                                    if self.net_local_label_srgb is not None:
                                                        return True

                                                    if self.net_multipath is not None:
                                                        return True

                                                    if self.num_of_path is not None:
                                                        return True

                                                    if self.pe_peers_advertised_to is not None:
                                                        for child_ref in self.pe_peers_advertised_to:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.process_instance_id is not None:
                                                        return True

                                                    if self.resilient_nexthop_set is not None:
                                                        return True

                                                    if self.rib_failed is not None:
                                                        return True

                                                    if self.route_distinguisher is not None:
                                                        return True

                                                    if self.table_brib_version is not None:
                                                        return True

                                                    if self.table_version is not None:
                                                        return True

                                                    if self.version is not None:
                                                        return True

                                                    if self.version_age is not None and self.version_age._has_data():
                                                        return True

                                                    if self.version_timestamp is not None and self.version_timestamp._has_data():
                                                        return True

                                                    if self.vrf_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-rds'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.network_rd is not None:
                                                    for child_ref in self.network_rd:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')
                                            if self.network_addr is None:
                                                raise YPYModelError('Key property network_addr is None')
                                            if self.network_prefix is None:
                                                raise YPYModelError('Key property network_prefix is None')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-all-rd[Cisco-IOS-XR-ipv4-bgp-oper:network-addr = ' + str(self.network_addr) + '][Cisco-IOS-XR-ipv4-bgp-oper:network-prefix = ' + str(self.network_prefix) + ']'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.network_addr is not None:
                                                return True

                                            if self.network_prefix is not None:
                                                return True

                                            if self.network_rds is not None and self.network_rds._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds.NetworkAllRd']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-all-rds'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.network_all_rd is not None:
                                            for child_ref in self.network_all_rd:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NetworkAllRds']['meta_info']


                                class UpdateGenerationNeighbors(object):
                                    """
                                    Update generation for all neighbors
                                    
                                    .. attribute:: update_generation_neighbor
                                    
                                    	Update generation for neighbor
                                    	**type**\: list of    :py:class:`UpdateGenerationNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.update_generation_neighbor = YList()
                                        self.update_generation_neighbor.parent = self
                                        self.update_generation_neighbor.name = 'update_generation_neighbor'


                                    class UpdateGenerationNeighbor(object):
                                        """
                                        Update generation for neighbor
                                        
                                        .. attribute:: ack_version
                                        
                                        	Ack version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: current_update_group_af_name
                                        
                                        	Current Update\-group address\-family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: default_originate_internal_context
                                        
                                        	Default\-origination context
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: default_originate_state
                                        
                                        	Default\-origination state
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: filter_group_index
                                        
                                        	Filter\-group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: first_default_originate_timestamp
                                        
                                        	First default\-origination time
                                        	**type**\:   :py:class:`FirstDefaultOriginateTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp>`
                                        
                                        .. attribute:: first_update_queued_timestamp
                                        
                                        	First update queued time
                                        	**type**\:   :py:class:`FirstUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp>`
                                        
                                        .. attribute:: first_update_write_timestamp
                                        
                                        	First update write time
                                        	**type**\:   :py:class:`FirstUpdateWriteTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp>`
                                        
                                        .. attribute:: inbound_refresh_count
                                        
                                        	Refresh Inbound count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_eor_outstanding
                                        
                                        	Number of EORs outstanding
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_update_group_timer_running
                                        
                                        	Is update\-group timer running
                                        	**type**\:  bool
                                        
                                        .. attribute:: last_default_originate_age
                                        
                                        	Time since last default\-origination event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_default_originate_timestamp
                                        
                                        	Last default\-origination time
                                        	**type**\:   :py:class:`LastDefaultOriginateTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp>`
                                        
                                        .. attribute:: last_filter_group_add_timestamp
                                        
                                        	Last added time
                                        	**type**\:   :py:class:`LastFilterGroupAddTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp>`
                                        
                                        .. attribute:: last_filter_group_remove_timestamp
                                        
                                        	Last removed time
                                        	**type**\:   :py:class:`LastFilterGroupRemoveTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp>`
                                        
                                        .. attribute:: last_refresh_update_queued_age
                                        
                                        	Time since last refresh update queued event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_refresh_update_queued_timestamp
                                        
                                        	Last refresh update queued time
                                        	**type**\:   :py:class:`LastRefreshUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp>`
                                        
                                        .. attribute:: last_refresh_update_write_age
                                        
                                        	Time since last refresh update write event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_refresh_update_write_timestamp
                                        
                                        	Last refresh update write time
                                        	**type**\:   :py:class:`LastRefreshUpdateWriteTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp>`
                                        
                                        .. attribute:: last_sub_group_add_timestamp
                                        
                                        	Last added time
                                        	**type**\:   :py:class:`LastSubGroupAddTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp>`
                                        
                                        .. attribute:: last_sub_group_remove_timestamp
                                        
                                        	Last removed time
                                        	**type**\:   :py:class:`LastSubGroupRemoveTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp>`
                                        
                                        .. attribute:: last_update_group_af_name
                                        
                                        	Last Update\-group address\-family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: last_update_group_expiry_timestamp
                                        
                                        	Last update\-group timer expiry
                                        	**type**\:   :py:class:`LastUpdateGroupExpiryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp>`
                                        
                                        .. attribute:: last_update_group_start_timestamp
                                        
                                        	Last update\-group timer start
                                        	**type**\:   :py:class:`LastUpdateGroupStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp>`
                                        
                                        .. attribute:: last_update_queued_age
                                        
                                        	Time since last update queued event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_queued_timestamp
                                        
                                        	Last update queued time
                                        	**type**\:   :py:class:`LastUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp>`
                                        
                                        .. attribute:: last_update_write_age
                                        
                                        	Time since last update write event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_write_timestamp
                                        
                                        	Last update write time
                                        	**type**\:   :py:class:`LastUpdateWriteTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp>`
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: next_resume_version
                                        
                                        	Resume version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: outbound_refresh_count
                                        
                                        	Refresh Outbound count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: outstanding_version_count
                                        
                                        	Outstanding version count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pending_target_version
                                        
                                        	Pending target version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_id
                                        
                                        	ProcessID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_ack_version
                                        
                                        	Refresh Ack version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_filter_group_index
                                        
                                        	Refresh Filter\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_next_resume_version
                                        
                                        	Refresh resume version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_pending_target_version
                                        
                                        	Pending refresh target version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_requested_target_version
                                        
                                        	Requested refresh target version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_sub_group_id
                                        
                                        	Refresh sub\-group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_sub_group_index
                                        
                                        	Refresh Sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_update_out_queue_messages
                                        
                                        	Refresh OutQueue messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_update_out_queue_size
                                        
                                        	Refresh OutQueue size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_id
                                        
                                        	Sub\-group ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: sub_group_index
                                        
                                        	Sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: sub_group_index_xr
                                        
                                        	Sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: synced_ack_version
                                        
                                        	Synced ack version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_filter_group_index
                                        
                                        	Filter\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_filter_group_messages
                                        
                                        	Filter\-group messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_group_af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: update_group_index
                                        
                                        	Update\-group index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: update_group_index_xr
                                        
                                        	Update\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_main_table_version
                                        
                                        	Main table version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:   :py:class:`UpdateNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress>`
                                        
                                        .. attribute:: update_out_queue_messages
                                        
                                        	OutQueue messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size
                                        
                                        	OutQueue size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_refresh_target_version
                                        
                                        	Refresh target version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_refresh_version
                                        
                                        	Refresh version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_statistics
                                        
                                        	Update statistics
                                        	**type**\:   :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics>`
                                        
                                        .. attribute:: update_vrf_name
                                        
                                        	VRF Name
                                        	**type**\:  str
                                        
                                        .. attribute:: update_vrf_table_rib_version
                                        
                                        	VRF Table RIB version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version
                                        
                                        	Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ack_version = None
                                            self.current_update_group_af_name = None
                                            self.default_originate_internal_context = None
                                            self.default_originate_state = None
                                            self.filter_group_index = None
                                            self.first_default_originate_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp()
                                            self.first_default_originate_timestamp.parent = self
                                            self.first_update_queued_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp()
                                            self.first_update_queued_timestamp.parent = self
                                            self.first_update_write_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp()
                                            self.first_update_write_timestamp.parent = self
                                            self.inbound_refresh_count = None
                                            self.is_eor_outstanding = None
                                            self.is_update_group_timer_running = None
                                            self.last_default_originate_age = None
                                            self.last_default_originate_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp()
                                            self.last_default_originate_timestamp.parent = self
                                            self.last_filter_group_add_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp()
                                            self.last_filter_group_add_timestamp.parent = self
                                            self.last_filter_group_remove_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp()
                                            self.last_filter_group_remove_timestamp.parent = self
                                            self.last_refresh_update_queued_age = None
                                            self.last_refresh_update_queued_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp()
                                            self.last_refresh_update_queued_timestamp.parent = self
                                            self.last_refresh_update_write_age = None
                                            self.last_refresh_update_write_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp()
                                            self.last_refresh_update_write_timestamp.parent = self
                                            self.last_sub_group_add_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp()
                                            self.last_sub_group_add_timestamp.parent = self
                                            self.last_sub_group_remove_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp()
                                            self.last_sub_group_remove_timestamp.parent = self
                                            self.last_update_group_af_name = None
                                            self.last_update_group_expiry_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp()
                                            self.last_update_group_expiry_timestamp.parent = self
                                            self.last_update_group_start_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp()
                                            self.last_update_group_start_timestamp.parent = self
                                            self.last_update_queued_age = None
                                            self.last_update_queued_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp()
                                            self.last_update_queued_timestamp.parent = self
                                            self.last_update_write_age = None
                                            self.last_update_write_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp()
                                            self.last_update_write_timestamp.parent = self
                                            self.neighbor_address = None
                                            self.next_resume_version = None
                                            self.outbound_refresh_count = None
                                            self.outstanding_version_count = None
                                            self.pending_target_version = None
                                            self.process_id = None
                                            self.refresh_ack_version = None
                                            self.refresh_filter_group_index = None
                                            self.refresh_next_resume_version = None
                                            self.refresh_pending_target_version = None
                                            self.refresh_requested_target_version = None
                                            self.refresh_sub_group_id = None
                                            self.refresh_sub_group_index = None
                                            self.refresh_update_out_queue_messages = None
                                            self.refresh_update_out_queue_size = None
                                            self.sub_group_id = None
                                            self.sub_group_index = None
                                            self.sub_group_index_xr = None
                                            self.synced_ack_version = None
                                            self.update_filter_group_index = None
                                            self.update_filter_group_messages = None
                                            self.update_group_af_name = None
                                            self.update_group_index = None
                                            self.update_group_index_xr = None
                                            self.update_main_table_version = None
                                            self.update_neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress()
                                            self.update_neighbor_address.parent = self
                                            self.update_out_queue_messages = None
                                            self.update_out_queue_size = None
                                            self.update_refresh_target_version = None
                                            self.update_refresh_version = None
                                            self.update_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics()
                                            self.update_statistics.parent = self
                                            self.update_vrf_name = None
                                            self.update_vrf_table_rib_version = None
                                            self.version = None


                                        class UpdateNeighborAddress(object):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress']['meta_info']


                                        class LastSubGroupAddTimestamp(object):
                                            """
                                            Last added time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-sub-group-add-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp']['meta_info']


                                        class LastSubGroupRemoveTimestamp(object):
                                            """
                                            Last removed time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-sub-group-remove-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp']['meta_info']


                                        class LastFilterGroupAddTimestamp(object):
                                            """
                                            Last added time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-filter-group-add-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp']['meta_info']


                                        class LastFilterGroupRemoveTimestamp(object):
                                            """
                                            Last removed time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-filter-group-remove-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp']['meta_info']


                                        class FirstDefaultOriginateTimestamp(object):
                                            """
                                            First default\-origination time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-default-originate-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp']['meta_info']


                                        class LastDefaultOriginateTimestamp(object):
                                            """
                                            Last default\-origination time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-default-originate-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp']['meta_info']


                                        class LastUpdateGroupStartTimestamp(object):
                                            """
                                            Last update\-group timer start
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-group-start-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp']['meta_info']


                                        class LastUpdateGroupExpiryTimestamp(object):
                                            """
                                            Last update\-group timer expiry
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-group-expiry-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp']['meta_info']


                                        class FirstUpdateQueuedTimestamp(object):
                                            """
                                            First update queued time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-update-queued-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp']['meta_info']


                                        class LastUpdateQueuedTimestamp(object):
                                            """
                                            Last update queued time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-queued-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp']['meta_info']


                                        class LastRefreshUpdateQueuedTimestamp(object):
                                            """
                                            Last refresh update queued time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-refresh-update-queued-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp']['meta_info']


                                        class FirstUpdateWriteTimestamp(object):
                                            """
                                            First update write time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-update-write-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp']['meta_info']


                                        class LastUpdateWriteTimestamp(object):
                                            """
                                            Last update write time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-write-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp']['meta_info']


                                        class LastRefreshUpdateWriteTimestamp(object):
                                            """
                                            Last refresh update write time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-refresh-update-write-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp']['meta_info']


                                        class UpdateStatistics(object):
                                            """
                                            Update statistics
                                            
                                            .. attribute:: last_update_cleard_age
                                            
                                            	Time since last Clear event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_cleared_timestamp
                                            
                                            	Last Cleared time
                                            	**type**\:   :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp>`
                                            
                                            .. attribute:: last_update_discard_age
                                            
                                            	Time since last Discard event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_discard_timestamp
                                            
                                            	Last Discarded time
                                            	**type**\:   :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                            
                                            .. attribute:: last_update_memory_allocation_fail_age
                                            
                                            	Time since last memory allocation failure event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_memory_allocation_fail_timestamp
                                            
                                            	Memory allocation failure time
                                            	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                            
                                            .. attribute:: last_update_recovery_age
                                            
                                            	Time since last Recovery event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_recovery_timestamp
                                            
                                            	Last Recovery time
                                            	**type**\:   :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                            
                                            .. attribute:: last_update_throttle_age
                                            
                                            	Time since last Throttle event (in seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_throttle_timestamp
                                            
                                            	Last Throttled time
                                            	**type**\:   :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                            
                                            .. attribute:: update_memory_allocation_fail_count
                                            
                                            	Memory allocation failure count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_cleared
                                            
                                            	OutQueue Cleared Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_cumulative
                                            
                                            	OutQueue Cumulative Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_discarded
                                            
                                            	OutQueue Discarded Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_high
                                            
                                            	OutQueue High Messages
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_size_cleared
                                            
                                            	OutQueue Cleared Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_cumulative
                                            
                                            	OutQueue Cumulative Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_discarded
                                            
                                            	OutQueue Discarded Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_high
                                            
                                            	OutQueue Hi Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_recovery_count
                                            
                                            	Recovery Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_throttle_count
                                            
                                            	Throttle Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.last_update_cleard_age = None
                                                self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp()
                                                self.last_update_cleared_timestamp.parent = self
                                                self.last_update_discard_age = None
                                                self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp()
                                                self.last_update_discard_timestamp.parent = self
                                                self.last_update_memory_allocation_fail_age = None
                                                self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                                self.last_update_memory_allocation_fail_timestamp.parent = self
                                                self.last_update_recovery_age = None
                                                self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                                self.last_update_recovery_timestamp.parent = self
                                                self.last_update_throttle_age = None
                                                self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp()
                                                self.last_update_throttle_timestamp.parent = self
                                                self.update_memory_allocation_fail_count = None
                                                self.update_out_queue_messages_cleared = None
                                                self.update_out_queue_messages_cumulative = None
                                                self.update_out_queue_messages_discarded = None
                                                self.update_out_queue_messages_high = None
                                                self.update_out_queue_size_cleared = None
                                                self.update_out_queue_size_cumulative = None
                                                self.update_out_queue_size_discarded = None
                                                self.update_out_queue_size_high = None
                                                self.update_recovery_count = None
                                                self.update_throttle_count = None


                                            class LastUpdateDiscardTimestamp(object):
                                                """
                                                Last Discarded time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-discard-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp']['meta_info']


                                            class LastUpdateClearedTimestamp(object):
                                                """
                                                Last Cleared time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-cleared-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp']['meta_info']


                                            class LastUpdateThrottleTimestamp(object):
                                                """
                                                Last Throttled time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-throttle-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp']['meta_info']


                                            class LastUpdateRecoveryTimestamp(object):
                                                """
                                                Last Recovery time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-recovery-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp']['meta_info']


                                            class LastUpdateMemoryAllocationFailTimestamp(object):
                                                """
                                                Memory allocation failure time
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-memory-allocation-fail-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-statistics'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.last_update_cleard_age is not None:
                                                    return True

                                                if self.last_update_cleared_timestamp is not None and self.last_update_cleared_timestamp._has_data():
                                                    return True

                                                if self.last_update_discard_age is not None:
                                                    return True

                                                if self.last_update_discard_timestamp is not None and self.last_update_discard_timestamp._has_data():
                                                    return True

                                                if self.last_update_memory_allocation_fail_age is not None:
                                                    return True

                                                if self.last_update_memory_allocation_fail_timestamp is not None and self.last_update_memory_allocation_fail_timestamp._has_data():
                                                    return True

                                                if self.last_update_recovery_age is not None:
                                                    return True

                                                if self.last_update_recovery_timestamp is not None and self.last_update_recovery_timestamp._has_data():
                                                    return True

                                                if self.last_update_throttle_age is not None:
                                                    return True

                                                if self.last_update_throttle_timestamp is not None and self.last_update_throttle_timestamp._has_data():
                                                    return True

                                                if self.update_memory_allocation_fail_count is not None:
                                                    return True

                                                if self.update_out_queue_messages_cleared is not None:
                                                    return True

                                                if self.update_out_queue_messages_cumulative is not None:
                                                    return True

                                                if self.update_out_queue_messages_discarded is not None:
                                                    return True

                                                if self.update_out_queue_messages_high is not None:
                                                    return True

                                                if self.update_out_queue_size_cleared is not None:
                                                    return True

                                                if self.update_out_queue_size_cumulative is not None:
                                                    return True

                                                if self.update_out_queue_size_discarded is not None:
                                                    return True

                                                if self.update_out_queue_size_high is not None:
                                                    return True

                                                if self.update_recovery_count is not None:
                                                    return True

                                                if self.update_throttle_count is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-neighbor'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ack_version is not None:
                                                return True

                                            if self.current_update_group_af_name is not None:
                                                return True

                                            if self.default_originate_internal_context is not None:
                                                return True

                                            if self.default_originate_state is not None:
                                                return True

                                            if self.filter_group_index is not None:
                                                return True

                                            if self.first_default_originate_timestamp is not None and self.first_default_originate_timestamp._has_data():
                                                return True

                                            if self.first_update_queued_timestamp is not None and self.first_update_queued_timestamp._has_data():
                                                return True

                                            if self.first_update_write_timestamp is not None and self.first_update_write_timestamp._has_data():
                                                return True

                                            if self.inbound_refresh_count is not None:
                                                return True

                                            if self.is_eor_outstanding is not None:
                                                return True

                                            if self.is_update_group_timer_running is not None:
                                                return True

                                            if self.last_default_originate_age is not None:
                                                return True

                                            if self.last_default_originate_timestamp is not None and self.last_default_originate_timestamp._has_data():
                                                return True

                                            if self.last_filter_group_add_timestamp is not None and self.last_filter_group_add_timestamp._has_data():
                                                return True

                                            if self.last_filter_group_remove_timestamp is not None and self.last_filter_group_remove_timestamp._has_data():
                                                return True

                                            if self.last_refresh_update_queued_age is not None:
                                                return True

                                            if self.last_refresh_update_queued_timestamp is not None and self.last_refresh_update_queued_timestamp._has_data():
                                                return True

                                            if self.last_refresh_update_write_age is not None:
                                                return True

                                            if self.last_refresh_update_write_timestamp is not None and self.last_refresh_update_write_timestamp._has_data():
                                                return True

                                            if self.last_sub_group_add_timestamp is not None and self.last_sub_group_add_timestamp._has_data():
                                                return True

                                            if self.last_sub_group_remove_timestamp is not None and self.last_sub_group_remove_timestamp._has_data():
                                                return True

                                            if self.last_update_group_af_name is not None:
                                                return True

                                            if self.last_update_group_expiry_timestamp is not None and self.last_update_group_expiry_timestamp._has_data():
                                                return True

                                            if self.last_update_group_start_timestamp is not None and self.last_update_group_start_timestamp._has_data():
                                                return True

                                            if self.last_update_queued_age is not None:
                                                return True

                                            if self.last_update_queued_timestamp is not None and self.last_update_queued_timestamp._has_data():
                                                return True

                                            if self.last_update_write_age is not None:
                                                return True

                                            if self.last_update_write_timestamp is not None and self.last_update_write_timestamp._has_data():
                                                return True

                                            if self.neighbor_address is not None:
                                                return True

                                            if self.next_resume_version is not None:
                                                return True

                                            if self.outbound_refresh_count is not None:
                                                return True

                                            if self.outstanding_version_count is not None:
                                                return True

                                            if self.pending_target_version is not None:
                                                return True

                                            if self.process_id is not None:
                                                return True

                                            if self.refresh_ack_version is not None:
                                                return True

                                            if self.refresh_filter_group_index is not None:
                                                return True

                                            if self.refresh_next_resume_version is not None:
                                                return True

                                            if self.refresh_pending_target_version is not None:
                                                return True

                                            if self.refresh_requested_target_version is not None:
                                                return True

                                            if self.refresh_sub_group_id is not None:
                                                return True

                                            if self.refresh_sub_group_index is not None:
                                                return True

                                            if self.refresh_update_out_queue_messages is not None:
                                                return True

                                            if self.refresh_update_out_queue_size is not None:
                                                return True

                                            if self.sub_group_id is not None:
                                                return True

                                            if self.sub_group_index is not None:
                                                return True

                                            if self.sub_group_index_xr is not None:
                                                return True

                                            if self.synced_ack_version is not None:
                                                return True

                                            if self.update_filter_group_index is not None:
                                                return True

                                            if self.update_filter_group_messages is not None:
                                                return True

                                            if self.update_group_af_name is not None:
                                                return True

                                            if self.update_group_index is not None:
                                                return True

                                            if self.update_group_index_xr is not None:
                                                return True

                                            if self.update_main_table_version is not None:
                                                return True

                                            if self.update_neighbor_address is not None and self.update_neighbor_address._has_data():
                                                return True

                                            if self.update_out_queue_messages is not None:
                                                return True

                                            if self.update_out_queue_size is not None:
                                                return True

                                            if self.update_refresh_target_version is not None:
                                                return True

                                            if self.update_refresh_version is not None:
                                                return True

                                            if self.update_statistics is not None and self.update_statistics._has_data():
                                                return True

                                            if self.update_vrf_name is not None:
                                                return True

                                            if self.update_vrf_table_rib_version is not None:
                                                return True

                                            if self.version is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-neighbors'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.update_generation_neighbor is not None:
                                            for child_ref in self.update_generation_neighbor:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors']['meta_info']


                                class UpdateGenerationAddressFamily(object):
                                    """
                                    Update generation for address\-family
                                    
                                    .. attribute:: configured_update_limit_af
                                    
                                    	Configured AF update limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: configured_update_limit_sub_group_ibgp
                                    
                                    	Configured IBGP sub\-group update limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: configured_update_limit_subgrp_ebgp
                                    
                                    	Configured EBGP sub\-group update limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: current_update_limit_af
                                    
                                    	Current AF update limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: current_update_limit_sub_group_ibgp
                                    
                                    	Current IBGP sub\-group update limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: current_update_limit_subgrp_ebgp
                                    
                                    	Current EBGP sub\-group update limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: filter_group_count
                                    
                                    	Filter\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_count
                                    
                                    	Neighbor count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_count
                                    
                                    	Refresh sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_throttled_count
                                    
                                    	Throttled refresh sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_throttled_count
                                    
                                    	Throttled sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_neighbor_count
                                    
                                    	VRF Table neighbor count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_refresh_sub_group_count
                                    
                                    	VRF Table refresh sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_refresh_sub_group_throttled_count
                                    
                                    	VRF Table throttled refresh sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_sub_group_throttled_count
                                    
                                    	VRF Table throttled sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_update_group_count
                                    
                                    	VRF Table update\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_group_af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: update_main_table_version
                                    
                                    	Main table version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_min_neighbor_version
                                    
                                    	Minimum Neighbor version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages
                                    
                                    	OutQueue messsages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_size
                                    
                                    	OutQueue size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_rib_version
                                    
                                    	RIB version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_statistics
                                    
                                    	Upate statistics
                                    	**type**\:   :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics>`
                                    
                                    .. attribute:: update_sub_group_count
                                    
                                    	Sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_table_filter_group_count
                                    
                                    	VRF Table filter\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_table_sub_group_count
                                    
                                    	VRF Table sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_table_vrf_name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    .. attribute:: update_throttled
                                    
                                    	Is Update throttled
                                    	**type**\:  bool
                                    
                                    .. attribute:: update_update_group_count
                                    
                                    	Update\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_vrf_rd_version
                                    
                                    	RD Version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_vrf_table_rib_version
                                    
                                    	VRF Table RIB version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_vrfaf_name
                                    
                                    	Address family identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.configured_update_limit_af = None
                                        self.configured_update_limit_sub_group_ibgp = None
                                        self.configured_update_limit_subgrp_ebgp = None
                                        self.current_update_limit_af = None
                                        self.current_update_limit_sub_group_ibgp = None
                                        self.current_update_limit_subgrp_ebgp = None
                                        self.filter_group_count = None
                                        self.neighbor_count = None
                                        self.refresh_sub_group_count = None
                                        self.refresh_sub_group_throttled_count = None
                                        self.sub_group_throttled_count = None
                                        self.table_neighbor_count = None
                                        self.table_refresh_sub_group_count = None
                                        self.table_refresh_sub_group_throttled_count = None
                                        self.table_sub_group_throttled_count = None
                                        self.table_update_group_count = None
                                        self.update_group_af_name = None
                                        self.update_main_table_version = None
                                        self.update_min_neighbor_version = None
                                        self.update_out_queue_messages = None
                                        self.update_out_queue_size = None
                                        self.update_rib_version = None
                                        self.update_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics()
                                        self.update_statistics.parent = self
                                        self.update_sub_group_count = None
                                        self.update_table_filter_group_count = None
                                        self.update_table_sub_group_count = None
                                        self.update_table_vrf_name = None
                                        self.update_throttled = None
                                        self.update_update_group_count = None
                                        self.update_vrf_rd_version = None
                                        self.update_vrf_table_rib_version = None
                                        self.update_vrfaf_name = None


                                    class UpdateStatistics(object):
                                        """
                                        Upate statistics
                                        
                                        .. attribute:: last_update_cleard_age
                                        
                                        	Time since last Clear event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_cleared_timestamp
                                        
                                        	Last Cleared time
                                        	**type**\:   :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp>`
                                        
                                        .. attribute:: last_update_discard_age
                                        
                                        	Time since last Discard event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_discard_timestamp
                                        
                                        	Last Discarded time
                                        	**type**\:   :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                        
                                        .. attribute:: last_update_memory_allocation_fail_age
                                        
                                        	Time since last memory allocation failure event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_memory_allocation_fail_timestamp
                                        
                                        	Memory allocation failure time
                                        	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                        
                                        .. attribute:: last_update_recovery_age
                                        
                                        	Time since last Recovery event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_recovery_timestamp
                                        
                                        	Last Recovery time
                                        	**type**\:   :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                        
                                        .. attribute:: last_update_throttle_age
                                        
                                        	Time since last Throttle event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_throttle_timestamp
                                        
                                        	Last Throttled time
                                        	**type**\:   :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                        
                                        .. attribute:: update_memory_allocation_fail_count
                                        
                                        	Memory allocation failure count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cleared
                                        
                                        	OutQueue Cleared Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cumulative
                                        
                                        	OutQueue Cumulative Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_discarded
                                        
                                        	OutQueue Discarded Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_high
                                        
                                        	OutQueue High Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size_cleared
                                        
                                        	OutQueue Cleared Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_cumulative
                                        
                                        	OutQueue Cumulative Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_discarded
                                        
                                        	OutQueue Discarded Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_high
                                        
                                        	OutQueue Hi Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_recovery_count
                                        
                                        	Recovery Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_throttle_count
                                        
                                        	Throttle Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.last_update_cleard_age = None
                                            self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp()
                                            self.last_update_cleared_timestamp.parent = self
                                            self.last_update_discard_age = None
                                            self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp()
                                            self.last_update_discard_timestamp.parent = self
                                            self.last_update_memory_allocation_fail_age = None
                                            self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                            self.last_update_memory_allocation_fail_timestamp.parent = self
                                            self.last_update_recovery_age = None
                                            self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                            self.last_update_recovery_timestamp.parent = self
                                            self.last_update_throttle_age = None
                                            self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp()
                                            self.last_update_throttle_timestamp.parent = self
                                            self.update_memory_allocation_fail_count = None
                                            self.update_out_queue_messages_cleared = None
                                            self.update_out_queue_messages_cumulative = None
                                            self.update_out_queue_messages_discarded = None
                                            self.update_out_queue_messages_high = None
                                            self.update_out_queue_size_cleared = None
                                            self.update_out_queue_size_cumulative = None
                                            self.update_out_queue_size_discarded = None
                                            self.update_out_queue_size_high = None
                                            self.update_recovery_count = None
                                            self.update_throttle_count = None


                                        class LastUpdateDiscardTimestamp(object):
                                            """
                                            Last Discarded time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-discard-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp']['meta_info']


                                        class LastUpdateClearedTimestamp(object):
                                            """
                                            Last Cleared time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-cleared-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp']['meta_info']


                                        class LastUpdateThrottleTimestamp(object):
                                            """
                                            Last Throttled time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-throttle-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp']['meta_info']


                                        class LastUpdateRecoveryTimestamp(object):
                                            """
                                            Last Recovery time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-recovery-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp']['meta_info']


                                        class LastUpdateMemoryAllocationFailTimestamp(object):
                                            """
                                            Memory allocation failure time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-memory-allocation-fail-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-statistics'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.last_update_cleard_age is not None:
                                                return True

                                            if self.last_update_cleared_timestamp is not None and self.last_update_cleared_timestamp._has_data():
                                                return True

                                            if self.last_update_discard_age is not None:
                                                return True

                                            if self.last_update_discard_timestamp is not None and self.last_update_discard_timestamp._has_data():
                                                return True

                                            if self.last_update_memory_allocation_fail_age is not None:
                                                return True

                                            if self.last_update_memory_allocation_fail_timestamp is not None and self.last_update_memory_allocation_fail_timestamp._has_data():
                                                return True

                                            if self.last_update_recovery_age is not None:
                                                return True

                                            if self.last_update_recovery_timestamp is not None and self.last_update_recovery_timestamp._has_data():
                                                return True

                                            if self.last_update_throttle_age is not None:
                                                return True

                                            if self.last_update_throttle_timestamp is not None and self.last_update_throttle_timestamp._has_data():
                                                return True

                                            if self.update_memory_allocation_fail_count is not None:
                                                return True

                                            if self.update_out_queue_messages_cleared is not None:
                                                return True

                                            if self.update_out_queue_messages_cumulative is not None:
                                                return True

                                            if self.update_out_queue_messages_discarded is not None:
                                                return True

                                            if self.update_out_queue_messages_high is not None:
                                                return True

                                            if self.update_out_queue_size_cleared is not None:
                                                return True

                                            if self.update_out_queue_size_cumulative is not None:
                                                return True

                                            if self.update_out_queue_size_discarded is not None:
                                                return True

                                            if self.update_out_queue_size_high is not None:
                                                return True

                                            if self.update_recovery_count is not None:
                                                return True

                                            if self.update_throttle_count is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-address-family'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.configured_update_limit_af is not None:
                                            return True

                                        if self.configured_update_limit_sub_group_ibgp is not None:
                                            return True

                                        if self.configured_update_limit_subgrp_ebgp is not None:
                                            return True

                                        if self.current_update_limit_af is not None:
                                            return True

                                        if self.current_update_limit_sub_group_ibgp is not None:
                                            return True

                                        if self.current_update_limit_subgrp_ebgp is not None:
                                            return True

                                        if self.filter_group_count is not None:
                                            return True

                                        if self.neighbor_count is not None:
                                            return True

                                        if self.refresh_sub_group_count is not None:
                                            return True

                                        if self.refresh_sub_group_throttled_count is not None:
                                            return True

                                        if self.sub_group_throttled_count is not None:
                                            return True

                                        if self.table_neighbor_count is not None:
                                            return True

                                        if self.table_refresh_sub_group_count is not None:
                                            return True

                                        if self.table_refresh_sub_group_throttled_count is not None:
                                            return True

                                        if self.table_sub_group_throttled_count is not None:
                                            return True

                                        if self.table_update_group_count is not None:
                                            return True

                                        if self.update_group_af_name is not None:
                                            return True

                                        if self.update_main_table_version is not None:
                                            return True

                                        if self.update_min_neighbor_version is not None:
                                            return True

                                        if self.update_out_queue_messages is not None:
                                            return True

                                        if self.update_out_queue_size is not None:
                                            return True

                                        if self.update_rib_version is not None:
                                            return True

                                        if self.update_statistics is not None and self.update_statistics._has_data():
                                            return True

                                        if self.update_sub_group_count is not None:
                                            return True

                                        if self.update_table_filter_group_count is not None:
                                            return True

                                        if self.update_table_sub_group_count is not None:
                                            return True

                                        if self.update_table_vrf_name is not None:
                                            return True

                                        if self.update_throttled is not None:
                                            return True

                                        if self.update_update_group_count is not None:
                                            return True

                                        if self.update_vrf_rd_version is not None:
                                            return True

                                        if self.update_vrf_table_rib_version is not None:
                                            return True

                                        if self.update_vrfaf_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily']['meta_info']


                                class Dampenings(object):
                                    """
                                    The BGP Dampening table
                                    
                                    .. attribute:: dampening
                                    
                                    	A BGP Dampening table entry
                                    	**type**\: list of    :py:class:`Dampening <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.dampening = YList()
                                        self.dampening.parent = self
                                        self.dampening.name = 'dampening'


                                    class Dampening(object):
                                        """
                                        A BGP Dampening table entry
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr>`
                                        
                                        .. attribute:: network
                                        
                                        	Network in prefix/length format
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        
                                        ----
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_id
                                        
                                        	Received Path ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation>`
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: reuse
                                        
                                        	Reuse array index
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_rd
                                        
                                        	Source Route Distinguisher value
                                        	**type**\:  str
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: version
                                        
                                        	Version number
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self.label_fail = None
                                            self.label_o_or_version = None
                                            self.label_oor = None
                                            self.neighbor_address = None
                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self.network = None
                                            self.no_path = None
                                            self.path_id = None
                                            self.path_information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation()
                                            self.path_information.parent = self
                                            self.prefix_version = None
                                            self.process_instance_id = None
                                            self.rd = None
                                            self.reuse = None
                                            self.route_distinguisher = None
                                            self.source_rd = None
                                            self.source_route_distinguisher = None
                                            self.source_vrf_name = None
                                            self.srcaf_name = None
                                            self.version = None
                                            self.vrf_name = None


                                        class NeighborAddressXr(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr']['meta_info']


                                        class PathInformation(object):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_esi
                                            
                                            	Path has EVPN ESI
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_rcvd_label
                                            
                                            	Path has received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebg_ps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.L2VpnEvpnEsi>`
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop>`
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhteTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_p_ath = None
                                                self.add_path_orr_bitfield = YList()
                                                self.add_path_orr_bitfield.parent = self
                                                self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                self.advertisedto_pe = None
                                                self.aigp_metric = None
                                                self.best_path_comp_stage = None
                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self.best_path_id = None
                                                self.best_path_id_comp_winner = None
                                                self.best_path_orr_bitfield = YList()
                                                self.best_path_orr_bitfield.parent = self
                                                self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self.dampen_penalty = None
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.fspec_invalid_path = None
                                                self.graceful_shutdown = None
                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self.halflife_time = None
                                                self.has_esi = None
                                                self.has_gw_addr = None
                                                self.has_local_net_label = None
                                                self.has_mdt_group_addr = None
                                                self.has_mvpn_extcomm = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.has_rcvd_label = None
                                                self.has_second_label = None
                                                self.ibgp_signaled_validity = None
                                                self.igp_metric = None
                                                self.is_aggregation_suppressed = None
                                                self.is_as_best = None
                                                self.is_best_path = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_internal_path = None
                                                self.is_partial_best = None
                                                self.is_path_additional_path = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_af_install_eligible = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_damped = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_history_held = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_imported = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_multipath = None
                                                self.is_path_nexthop_discarded = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebg_ps = None
                                                self.is_path_received_only = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_stale = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_valid = None
                                                self.is_path_vpn_only = None
                                                self.is_permanent_path = None
                                                self.is_received_path_not_modified = None
                                                self.is_spkr_as_best = None
                                                self.l2vpn_circuit_status_value = YList()
                                                self.l2vpn_circuit_status_value.parent = self
                                                self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.L2VpnEvpnEsi()
                                                self.l2vpn_evpn_esi.parent = self
                                                self.l2vpn_size = None
                                                self.labeled_unicast_safi_path = None
                                                self.local_label = None
                                                self.local_nh = None
                                                self.local_path_id = None
                                                self.local_peers_advertised_to = YList()
                                                self.local_peers_advertised_to.parent = self
                                                self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                self.maximum_suppress_time = None
                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self.mvpn_path_flags = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_value = YList()
                                                self.mvpn_pmsi_value.parent = self
                                                self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                self.mvpn_sfs_path = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.neighbor_router_id = None
                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.path_flags = None
                                                self.path_flap_count = None
                                                self.path_import_flags = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.path_table_version = None
                                                self.path_weight = None
                                                self.pe_peers_advertised_to = YList()
                                                self.pe_peers_advertised_to.parent = self
                                                self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                self.rcvd_label = None
                                                self.rcvd_path_id = None
                                                self.reuse_value = None
                                                self.rib_failed = None
                                                self.route_type = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.rt_set_limit_enabled = None
                                                self.second_label = None
                                                self.seconds_since_first_flap = None
                                                self.show_rpki_origin_as_validity = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.suppress_penalty = None
                                                self.time_to_unsuppress = None


                                            class BgpPrefix(object):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self.prefix_length = None


                                                class Prefix(object):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.prefix is not None and self.prefix._has_data():
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix']['meta_info']


                                            class NeighborAddress(object):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress']['meta_info']


                                            class NextHop(object):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhteTunnel']['meta_info']


                                            class MdtGroupAddr(object):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr']['meta_info']


                                            class L2VpnEvpnEsi(object):
                                                """
                                                L2VPN EVPN ESI
                                                
                                                .. attribute:: esi
                                                
                                                	esi
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.esi = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.esi is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.L2VpnEvpnEsi']['meta_info']


                                            class GwAddr(object):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr']['meta_info']


                                            class BestPathCompWinner(object):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner']['meta_info']


                                            class MvpnNbrAddr(object):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr']['meta_info']


                                            class MvpnNexthopAddr(object):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr']['meta_info']


                                            class L2VpnCircuitStatusValue(object):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                            class MvpnPmsiValue(object):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity']['meta_info']


                                            class LocalPeersAdvertisedTo(object):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                            class PePeersAdvertisedTo(object):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo']['meta_info']


                                            class BestPathOrrBitfield(object):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield']['meta_info']


                                            class AddPathOrrBitfield(object):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.accept_own_path is not None:
                                                    return True

                                                if self.accept_own_self_originated_p_ath is not None:
                                                    return True

                                                if self.add_path_orr_bitfield is not None:
                                                    for child_ref in self.add_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.advertisedto_pe is not None:
                                                    return True

                                                if self.aigp_metric is not None:
                                                    return True

                                                if self.best_path_comp_stage is not None:
                                                    return True

                                                if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                    return True

                                                if self.best_path_id is not None:
                                                    return True

                                                if self.best_path_id_comp_winner is not None:
                                                    return True

                                                if self.best_path_orr_bitfield is not None:
                                                    for child_ref in self.best_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                    return True

                                                if self.dampen_penalty is not None:
                                                    return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.fspec_invalid_path is not None:
                                                    return True

                                                if self.graceful_shutdown is not None:
                                                    return True

                                                if self.gw_addr is not None and self.gw_addr._has_data():
                                                    return True

                                                if self.halflife_time is not None:
                                                    return True

                                                if self.has_esi is not None:
                                                    return True

                                                if self.has_gw_addr is not None:
                                                    return True

                                                if self.has_local_net_label is not None:
                                                    return True

                                                if self.has_mdt_group_addr is not None:
                                                    return True

                                                if self.has_mvpn_extcomm is not None:
                                                    return True

                                                if self.has_mvpn_nbr_addr is not None:
                                                    return True

                                                if self.has_mvpn_nexthop_addr is not None:
                                                    return True

                                                if self.has_mvpn_pmsi is not None:
                                                    return True

                                                if self.has_rcvd_label is not None:
                                                    return True

                                                if self.has_second_label is not None:
                                                    return True

                                                if self.ibgp_signaled_validity is not None:
                                                    return True

                                                if self.igp_metric is not None:
                                                    return True

                                                if self.is_aggregation_suppressed is not None:
                                                    return True

                                                if self.is_as_best is not None:
                                                    return True

                                                if self.is_best_path is not None:
                                                    return True

                                                if self.is_import_dampened is not None:
                                                    return True

                                                if self.is_import_suspect is not None:
                                                    return True

                                                if self.is_internal_path is not None:
                                                    return True

                                                if self.is_partial_best is not None:
                                                    return True

                                                if self.is_path_additional_path is not None:
                                                    return True

                                                if self.is_path_advertised_local_as_only is not None:
                                                    return True

                                                if self.is_path_af_install_eligible is not None:
                                                    return True

                                                if self.is_path_backup is not None:
                                                    return True

                                                if self.is_path_backup_protect_multipath is not None:
                                                    return True

                                                if self.is_path_best_external is not None:
                                                    return True

                                                if self.is_path_damped is not None:
                                                    return True

                                                if self.is_path_from_confederation_peer is not None:
                                                    return True

                                                if self.is_path_from_network_command is not None:
                                                    return True

                                                if self.is_path_from_redistribute_command is not None:
                                                    return True

                                                if self.is_path_from_route_reflector is not None:
                                                    return True

                                                if self.is_path_history_held is not None:
                                                    return True

                                                if self.is_path_imp_candidate is not None:
                                                    return True

                                                if self.is_path_imported is not None:
                                                    return True

                                                if self.is_path_local_aggregate is not None:
                                                    return True

                                                if self.is_path_locally_sourced is not None:
                                                    return True

                                                if self.is_path_long_lived_stale is not None:
                                                    return True

                                                if self.is_path_multipath is not None:
                                                    return True

                                                if self.is_path_nexthop_discarded is not None:
                                                    return True

                                                if self.is_path_not_advertised is not None:
                                                    return True

                                                if self.is_path_not_advertised_to_ebg_ps is not None:
                                                    return True

                                                if self.is_path_received_only is not None:
                                                    return True

                                                if self.is_path_reoriginated is not None:
                                                    return True

                                                if self.is_path_reoriginated_stitching is not None:
                                                    return True

                                                if self.is_path_stale is not None:
                                                    return True

                                                if self.is_path_synced_with_igp is not None:
                                                    return True

                                                if self.is_path_valid is not None:
                                                    return True

                                                if self.is_path_vpn_only is not None:
                                                    return True

                                                if self.is_permanent_path is not None:
                                                    return True

                                                if self.is_received_path_not_modified is not None:
                                                    return True

                                                if self.is_spkr_as_best is not None:
                                                    return True

                                                if self.l2vpn_circuit_status_value is not None:
                                                    for child_ref in self.l2vpn_circuit_status_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                    return True

                                                if self.l2vpn_size is not None:
                                                    return True

                                                if self.labeled_unicast_safi_path is not None:
                                                    return True

                                                if self.local_label is not None:
                                                    return True

                                                if self.local_nh is not None:
                                                    return True

                                                if self.local_path_id is not None:
                                                    return True

                                                if self.local_peers_advertised_to is not None:
                                                    for child_ref in self.local_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.maximum_suppress_time is not None:
                                                    return True

                                                if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                    return True

                                                if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                    return True

                                                if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                    return True

                                                if self.mvpn_path_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_label is not None:
                                                    return True

                                                if self.mvpn_pmsi_type is not None:
                                                    return True

                                                if self.mvpn_pmsi_value is not None:
                                                    for child_ref in self.mvpn_pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.mvpn_sfs_path is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.neighbor_router_id is not None:
                                                    return True

                                                if self.next_hop is not None and self.next_hop._has_data():
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.path_flags is not None:
                                                    return True

                                                if self.path_flap_count is not None:
                                                    return True

                                                if self.path_import_flags is not None:
                                                    return True

                                                if self.path_rt_set_id is not None:
                                                    return True

                                                if self.path_rt_set_route_count is not None:
                                                    return True

                                                if self.path_table_version is not None:
                                                    return True

                                                if self.path_weight is not None:
                                                    return True

                                                if self.pe_peers_advertised_to is not None:
                                                    for child_ref in self.pe_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.rcvd_label is not None:
                                                    return True

                                                if self.rcvd_path_id is not None:
                                                    return True

                                                if self.reuse_value is not None:
                                                    return True

                                                if self.rib_failed is not None:
                                                    return True

                                                if self.route_type is not None:
                                                    return True

                                                if self.rpki_origin_as_validation_disabled is not None:
                                                    return True

                                                if self.rt_set_limit_enabled is not None:
                                                    return True

                                                if self.second_label is not None:
                                                    return True

                                                if self.seconds_since_first_flap is not None:
                                                    return True

                                                if self.show_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.sn_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.suppress_penalty is not None:
                                                    return True

                                                if self.time_to_unsuppress is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation']['meta_info']


                                        class AttributesAfterPolicyIn(object):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self.is_application_gateway_present = None
                                                self.is_as_path2_byte = None
                                                self.is_attr_set_present = None
                                                self.is_ribrnh_present = None
                                                self.is_rnh_present = None
                                                self.ribrnh_encap = None
                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self.ribrnh_mac = None
                                                self.ribrnh_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnhip_table = None
                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self.rnh_addr_len = None
                                                self.rnh_len = None
                                                self.rnh_type = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.vpn_distinguisher = None


                                            class CommonAttributes(object):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                            class AttrSet(object):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                            class RnhAddr(object):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None
                                                    self.mac_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    if self.mac_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                            class RibrnhIp(object):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.attr_set is not None and self.attr_set._has_data():
                                                    return True

                                                if self.attribute_key_number is not None:
                                                    return True

                                                if self.attribute_reuse_id_config is not None:
                                                    return True

                                                if self.attribute_reuse_id_current is not None:
                                                    return True

                                                if self.attribute_reuse_id_keys is not None:
                                                    return True

                                                if self.attribute_reuse_id_max_id is not None:
                                                    return True

                                                if self.attribute_reuse_id_node is not None:
                                                    return True

                                                if self.attribute_reuse_id_recover_sec is not None:
                                                    return True

                                                if self.common_attributes is not None and self.common_attributes._has_data():
                                                    return True

                                                if self.is_application_gateway_present is not None:
                                                    return True

                                                if self.is_as_path2_byte is not None:
                                                    return True

                                                if self.is_attr_set_present is not None:
                                                    return True

                                                if self.is_ribrnh_present is not None:
                                                    return True

                                                if self.is_rnh_present is not None:
                                                    return True

                                                if self.ribrnh_encap is not None:
                                                    return True

                                                if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                    return True

                                                if self.ribrnh_mac is not None:
                                                    return True

                                                if self.ribrnh_table is not None:
                                                    return True

                                                if self.ribrnh_vni is not None:
                                                    return True

                                                if self.ribrnhip_table is not None:
                                                    return True

                                                if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                    return True

                                                if self.rnh_addr_len is not None:
                                                    return True

                                                if self.rnh_len is not None:
                                                    return True

                                                if self.rnh_type is not None:
                                                    return True

                                                if self.set_aigp_inbound_igp is not None:
                                                    return True

                                                if self.set_aigp_inbound_metric is not None:
                                                    return True

                                                if self.vpn_distinguisher is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:dampening'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                return True

                                            if self.label_fail is not None:
                                                return True

                                            if self.label_o_or_version is not None:
                                                return True

                                            if self.label_oor is not None:
                                                return True

                                            if self.neighbor_address is not None:
                                                return True

                                            if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                return True

                                            if self.network is not None:
                                                return True

                                            if self.no_path is not None:
                                                return True

                                            if self.path_id is not None:
                                                return True

                                            if self.path_information is not None and self.path_information._has_data():
                                                return True

                                            if self.prefix_version is not None:
                                                return True

                                            if self.process_instance_id is not None:
                                                return True

                                            if self.rd is not None:
                                                return True

                                            if self.reuse is not None:
                                                return True

                                            if self.route_distinguisher is not None:
                                                return True

                                            if self.source_rd is not None:
                                                return True

                                            if self.source_route_distinguisher is not None:
                                                return True

                                            if self.source_vrf_name is not None:
                                                return True

                                            if self.srcaf_name is not None:
                                                return True

                                            if self.version is not None:
                                                return True

                                            if self.vrf_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:dampenings'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dampening is not None:
                                            for child_ref in self.dampening:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings']['meta_info']


                                class PrefixFilters(object):
                                    """
                                    The BGP Prefix Filter table
                                    
                                    .. attribute:: prefix_filter
                                    
                                    	A BGP prefix filter table entry
                                    	**type**\: list of    :py:class:`PrefixFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.prefix_filter = YList()
                                        self.prefix_filter.parent = self
                                        self.prefix_filter.name = 'prefix_filter'


                                    class PrefixFilter(object):
                                        """
                                        A BGP prefix filter table entry
                                        
                                        .. attribute:: neighbor_address  <key>
                                        
                                        	Neighbor address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: af_name
                                        
                                        	Address family identfier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr>`
                                        
                                        .. attribute:: prefix_list_info
                                        
                                        	Prefix list
                                        	**type**\:   :py:class:`PrefixListInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.neighbor_address = None
                                            self.af_name = None
                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self.prefix_list_info = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo()
                                            self.prefix_list_info.parent = self


                                        class NeighborAddressXr(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr']['meta_info']


                                        class PrefixListInfo(object):
                                            """
                                            Prefix list
                                            
                                            .. attribute:: bgp_pfxlst
                                            
                                            	bgp pfxlst
                                            	**type**\: list of    :py:class:`BgpPfxlst <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.bgp_pfxlst = YList()
                                                self.bgp_pfxlst.parent = self
                                                self.bgp_pfxlst.name = 'bgp_pfxlst'


                                            class BgpPfxlst(object):
                                                """
                                                bgp pfxlst
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix>`
                                                
                                                .. attribute:: is_prefix_grant
                                                
                                                	TRUE = permit, FALSE = deny
                                                	**type**\:  bool
                                                
                                                .. attribute:: max_prefix_length
                                                
                                                	Maximum prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: min_prefix_length
                                                
                                                	Minimum prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Sequence number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self.is_prefix_grant = None
                                                    self.max_prefix_length = None
                                                    self.min_prefix_length = None
                                                    self.sequence_number = None


                                                class BgpPrefix(object):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self.prefix_length = None


                                                    class Prefix(object):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.prefix is not None and self.prefix._has_data():
                                                            return True

                                                        if self.prefix_length is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-pfxlst'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                        return True

                                                    if self.is_prefix_grant is not None:
                                                        return True

                                                    if self.max_prefix_length is not None:
                                                        return True

                                                    if self.min_prefix_length is not None:
                                                        return True

                                                    if self.sequence_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix-list-info'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bgp_pfxlst is not None:
                                                    for child_ref in self.bgp_pfxlst:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')
                                            if self.neighbor_address is None:
                                                raise YPYModelError('Key property neighbor_address is None')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix-filter[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address = ' + str(self.neighbor_address) + ']'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.neighbor_address is not None:
                                                return True

                                            if self.af_name is not None:
                                                return True

                                            if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                return True

                                            if self.prefix_list_info is not None and self.prefix_list_info._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix-filters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.prefix_filter is not None:
                                            for child_ref in self.prefix_filter:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters']['meta_info']


                                class Attributes(object):
                                    """
                                    The BGP Attribute table
                                    
                                    .. attribute:: attribute
                                    
                                    	A BGP Attribute table entry
                                    	**type**\: list of    :py:class:`Attribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.attribute = YList()
                                        self.attribute.parent = self
                                        self.attribute.name = 'attribute'


                                    class Attribute(object):
                                        """
                                        A BGP Attribute table entry
                                        
                                        .. attribute:: attribute_cache_bucket
                                        
                                        	Attribute cache bucket
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: attribute_cache_id
                                        
                                        	Attribute cache ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: attribute_iid
                                        
                                        	Attribute IID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: attribute_info
                                        
                                        	Attributes
                                        	**type**\:   :py:class:`AttributeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo>`
                                        
                                        .. attribute:: attribute_instance_id
                                        
                                        	Attribute Instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: attribute_structure_hash_value
                                        
                                        	Hash value for attribute structure
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_structure_id
                                        
                                        	ID of attribute structure
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: reference_count
                                        
                                        	Number of paths which use this attribute structure
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.attribute_cache_bucket = None
                                            self.attribute_cache_id = None
                                            self.attribute_iid = None
                                            self.attribute_info = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo()
                                            self.attribute_info.parent = self
                                            self.attribute_instance_id = None
                                            self.attribute_structure_hash_value = None
                                            self.attribute_structure_id = None
                                            self.process_instance_id = None
                                            self.reference_count = None


                                        class AttributeInfo(object):
                                            """
                                            Attributes
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet()
                                                self.attr_set.parent = self
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self.is_application_gateway_present = None
                                                self.is_as_path2_byte = None
                                                self.is_attr_set_present = None
                                                self.is_ribrnh_present = None
                                                self.is_rnh_present = None
                                                self.ribrnh_encap = None
                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self.ribrnh_mac = None
                                                self.ribrnh_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnhip_table = None
                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self.rnh_addr_len = None
                                                self.rnh_len = None
                                                self.rnh_type = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.vpn_distinguisher = None


                                            class CommonAttributes(object):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes']['meta_info']


                                            class AttrSet(object):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet']['meta_info']


                                            class RnhAddr(object):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None
                                                    self.mac_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    if self.mac_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr']['meta_info']


                                            class RibrnhIp(object):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attribute-info'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.attr_set is not None and self.attr_set._has_data():
                                                    return True

                                                if self.attribute_key_number is not None:
                                                    return True

                                                if self.attribute_reuse_id_config is not None:
                                                    return True

                                                if self.attribute_reuse_id_current is not None:
                                                    return True

                                                if self.attribute_reuse_id_keys is not None:
                                                    return True

                                                if self.attribute_reuse_id_max_id is not None:
                                                    return True

                                                if self.attribute_reuse_id_node is not None:
                                                    return True

                                                if self.attribute_reuse_id_recover_sec is not None:
                                                    return True

                                                if self.common_attributes is not None and self.common_attributes._has_data():
                                                    return True

                                                if self.is_application_gateway_present is not None:
                                                    return True

                                                if self.is_as_path2_byte is not None:
                                                    return True

                                                if self.is_attr_set_present is not None:
                                                    return True

                                                if self.is_ribrnh_present is not None:
                                                    return True

                                                if self.is_rnh_present is not None:
                                                    return True

                                                if self.ribrnh_encap is not None:
                                                    return True

                                                if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                    return True

                                                if self.ribrnh_mac is not None:
                                                    return True

                                                if self.ribrnh_table is not None:
                                                    return True

                                                if self.ribrnh_vni is not None:
                                                    return True

                                                if self.ribrnhip_table is not None:
                                                    return True

                                                if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                    return True

                                                if self.rnh_addr_len is not None:
                                                    return True

                                                if self.rnh_len is not None:
                                                    return True

                                                if self.rnh_type is not None:
                                                    return True

                                                if self.set_aigp_inbound_igp is not None:
                                                    return True

                                                if self.set_aigp_inbound_metric is not None:
                                                    return True

                                                if self.vpn_distinguisher is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attribute'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.attribute_cache_bucket is not None:
                                                return True

                                            if self.attribute_cache_id is not None:
                                                return True

                                            if self.attribute_iid is not None:
                                                return True

                                            if self.attribute_info is not None and self.attribute_info._has_data():
                                                return True

                                            if self.attribute_instance_id is not None:
                                                return True

                                            if self.attribute_structure_hash_value is not None:
                                                return True

                                            if self.attribute_structure_id is not None:
                                                return True

                                            if self.process_instance_id is not None:
                                                return True

                                            if self.reference_count is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.attribute is not None:
                                            for child_ref in self.attribute:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.af_name is None:
                                        raise YPYModelError('Key property af_name is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af[Cisco-IOS-XR-ipv4-bgp-oper:af-name = ' + str(self.af_name) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.advertised_path_counts is not None and self.advertised_path_counts._has_data():
                                        return True

                                    if self.advertised_path_xr is not None and self.advertised_path_xr._has_data():
                                        return True

                                    if self.advertised_paths is not None and self.advertised_paths._has_data():
                                        return True

                                    if self.af_process_info is not None and self.af_process_info._has_data():
                                        return True

                                    if self.attributes is not None and self.attributes._has_data():
                                        return True

                                    if self.bmp_paths is not None and self.bmp_paths._has_data():
                                        return True

                                    if self.convergence is not None and self.convergence._has_data():
                                        return True

                                    if self.dampenings is not None and self.dampenings._has_data():
                                        return True

                                    if self.epes is not None and self.epes._has_data():
                                        return True

                                    if self.global_af_process_info is not None and self.global_af_process_info._has_data():
                                        return True

                                    if self.neighbor_af_table is not None and self.neighbor_af_table._has_data():
                                        return True

                                    if self.network_all_rds is not None and self.network_all_rds._has_data():
                                        return True

                                    if self.network_lookup_all_rds is not None and self.network_lookup_all_rds._has_data():
                                        return True

                                    if self.network_prefixes is not None and self.network_prefixes._has_data():
                                        return True

                                    if self.networks is not None and self.networks._has_data():
                                        return True

                                    if self.next_hop_address_families is not None and self.next_hop_address_families._has_data():
                                        return True

                                    if self.path_labeled_table is not None and self.path_labeled_table._has_data():
                                        return True

                                    if self.path_table is not None and self.path_table._has_data():
                                        return True

                                    if self.path_used_table is not None and self.path_used_table._has_data():
                                        return True

                                    if self.policies is not None and self.policies._has_data():
                                        return True

                                    if self.prefix_filters is not None and self.prefix_filters._has_data():
                                        return True

                                    if self.rpc_sets is not None and self.rpc_sets._has_data():
                                        return True

                                    if self.rt_set_counters is not None and self.rt_set_counters._has_data():
                                        return True

                                    if self.sourced_networks is not None and self.sourced_networks._has_data():
                                        return True

                                    if self.update_generation_address_family is not None and self.update_generation_address_family._has_data():
                                        return True

                                    if self.update_generation_filter_groups is not None and self.update_generation_filter_groups._has_data():
                                        return True

                                    if self.update_generation_neighbors is not None and self.update_generation_neighbors._has_data():
                                        return True

                                    if self.update_generation_sub_groups is not None and self.update_generation_sub_groups._has_data():
                                        return True

                                    if self.update_generation_update_groups is not None and self.update_generation_update_groups._has_data():
                                        return True

                                    if self.update_groups is not None and self.update_groups._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:afs'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af is not None:
                                    for child_ref in self.af:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs']['meta_info']


                        class Information(object):
                            """
                            Meta data for VRF
                            
                            .. attribute:: route_distinguisher
                            
                            	Route Distinguisher
                            	**type**\:  str
                            
                            	**pattern:** [a\-fA\-F0\-9]{16}
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.route_distinguisher = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.route_distinguisher is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Information']['meta_info']


                        class UpdateInboundFilterVrf(object):
                            """
                            Update inbound filtering information for the VRF
                            
                            .. attribute:: last_update_filtered_age
                            
                            	Time since last filtered messages received event (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_update_filtered_timestamp
                            
                            	Last Filtered messages received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`LastUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp>`
                            
                            .. attribute:: update_filtered_message_count
                            
                            	Filtered messages count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_filtered_neighbor_count
                            
                            	Count of neighbors that received filtered messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_vrf_name
                            
                            	VRF Name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.last_update_filtered_age = None
                                self.last_update_filtered_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp()
                                self.last_update_filtered_timestamp.parent = self
                                self.update_filtered_message_count = None
                                self.update_filtered_neighbor_count = None
                                self.update_vrf_name = None


                            class LastUpdateFilteredTimestamp(object):
                                """
                                Last Filtered messages received time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.nanoseconds = None
                                    self.seconds = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-filtered-timestamp'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.nanoseconds is not None:
                                        return True

                                    if self.seconds is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-inbound-filter-vrf'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.last_update_filtered_age is not None:
                                    return True

                                if self.last_update_filtered_timestamp is not None and self.last_update_filtered_timestamp._has_data():
                                    return True

                                if self.update_filtered_message_count is not None:
                                    return True

                                if self.update_filtered_neighbor_count is not None:
                                    return True

                                if self.update_vrf_name is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterVrf']['meta_info']


                        class Postits(object):
                            """
                            The BGP Neighbor table
                            
                            .. attribute:: postit
                            
                            	A BGP Postit table entry
                            	**type**\: list of    :py:class:`Postit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.postit = YList()
                                self.postit.parent = self
                                self.postit.name = 'postit'


                            class Postit(object):
                                """
                                A BGP Postit table entry
                                
                                .. attribute:: neighbor_address  <key>
                                
                                	Neighbor address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: connect_state
                                
                                	State
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_af
                                
                                	Neighbor Afi
                                	**type**\: list of    :py:class:`NeighborAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborAf>`
                                
                                .. attribute:: neighbors_address
                                
                                	Neighbor Addr
                                	**type**\:   :py:class:`NeighborsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress>`
                                
                                .. attribute:: nsr_state
                                
                                	NSR state
                                	**type**\:   :py:class:`BgpSyncNbrNsrStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrStateEnum>`
                                
                                .. attribute:: postit_info
                                
                                	Postit Info
                                	**type**\: list of    :py:class:`PostitInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.PostitInfo>`
                                
                                .. attribute:: start_time
                                
                                	StartTime
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vrf_name
                                
                                	VRF Name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.neighbor_address = None
                                    self.connect_state = None
                                    self.neighbor_af = YList()
                                    self.neighbor_af.parent = self
                                    self.neighbor_af.name = 'neighbor_af'
                                    self.neighbors_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress()
                                    self.neighbors_address.parent = self
                                    self.nsr_state = None
                                    self.postit_info = YList()
                                    self.postit_info.parent = self
                                    self.postit_info.name = 'postit_info'
                                    self.start_time = None
                                    self.vrf_name = None


                                class NeighborsAddress(object):
                                    """
                                    Neighbor Addr
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpnvpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2VpnvplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4mdt_address = None
                                        self.ipv4mvpn_address = None
                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress()
                                        self.ipv4sr_policy_address.parent = self
                                        self.ipv4vpn_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress()
                                        self.ipv6sr_policy_address.parent = self
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_flowspec_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.l2vpn_evpn_address = None
                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2VpnvplsAddress()
                                        self.l2vpnvpls_address.parent = self
                                        self.ls_ls_address = None
                                        self.rt_constraint_address = None


                                    class L2VpnvplsAddress(object):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2VpnvplsAddress']['meta_info']


                                    class L2VpnMspwAddress(object):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2VpnMspwAddress']['meta_info']


                                    class Ipv4SrPolicyAddress(object):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress']['meta_info']


                                    class Ipv6SrPolicyAddress(object):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv6_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv6_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbors-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.afi is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv4_flowspec_address is not None:
                                            return True

                                        if self.ipv4_label_address is not None:
                                            return True

                                        if self.ipv4_mcast_address is not None:
                                            return True

                                        if self.ipv4_tunnel_address is not None:
                                            return True

                                        if self.ipv4mdt_address is not None:
                                            return True

                                        if self.ipv4mvpn_address is not None:
                                            return True

                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                            return True

                                        if self.ipv4vpn_address is not None:
                                            return True

                                        if self.ipv4vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv4vpna_mcastddress is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        if self.ipv6_flowspec_address is not None:
                                            return True

                                        if self.ipv6_label_address is not None:
                                            return True

                                        if self.ipv6_mcast_address is not None:
                                            return True

                                        if self.ipv6mvpn_address is not None:
                                            return True

                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                            return True

                                        if self.ipv6vpn_address is not None:
                                            return True

                                        if self.ipv6vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv6vpn_mcast_address is not None:
                                            return True

                                        if self.l2vpn_evpn_address is not None:
                                            return True

                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                            return True

                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                            return True

                                        if self.ls_ls_address is not None:
                                            return True

                                        if self.rt_constraint_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress']['meta_info']


                                class NeighborAf(object):
                                    """
                                    Neighbor Afi
                                    
                                    .. attribute:: entry
                                    
                                    	Array entry
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-af'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborAf']['meta_info']


                                class PostitInfo(object):
                                    """
                                    Postit Info
                                    
                                    .. attribute:: peer_id
                                    
                                    	Peer ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: postit_af_name
                                    
                                    	Postit Afi
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: postit_direction
                                    
                                    	Postit Direction
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: postit_flags
                                    
                                    	Postit Flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: postit_id
                                    
                                    	Postit ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: postit_notification
                                    
                                    	Postit notification
                                    	**type**\:   :py:class:`PostitNotification <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification>`
                                    
                                    .. attribute:: postit_policy
                                    
                                    	Policy
                                    	**type**\:  str
                                    
                                    .. attribute:: postit_reset
                                    
                                    	Reset
                                    	**type**\:   :py:class:`BgpResetReasonIndexEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndexEnum>`
                                    
                                    .. attribute:: postit_subtype
                                    
                                    	Postit Subtype
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: postit_ts
                                    
                                    	Postit TS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: postit_type
                                    
                                    	Postit Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.peer_id = None
                                        self.postit_af_name = None
                                        self.postit_direction = None
                                        self.postit_flags = None
                                        self.postit_id = None
                                        self.postit_notification = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification()
                                        self.postit_notification.parent = self
                                        self.postit_policy = None
                                        self.postit_reset = None
                                        self.postit_subtype = None
                                        self.postit_ts = None
                                        self.postit_type = None


                                    class PostitNotification(object):
                                        """
                                        Postit notification
                                        
                                        .. attribute:: last_notification_data
                                        
                                        	Message data in last notification
                                        	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData>`
                                        
                                        .. attribute:: notification_error_code
                                        
                                        	Error code in last notification
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: notification_error_subcode
                                        
                                        	Error subcode in last notification
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: time_since_last_notification
                                        
                                        	Time since the last notification was sent or received (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.last_notification_data = YList()
                                            self.last_notification_data.parent = self
                                            self.last_notification_data.name = 'last_notification_data'
                                            self.notification_error_code = None
                                            self.notification_error_subcode = None
                                            self.time_since_last_notification = None


                                        class LastNotificationData(object):
                                            """
                                            Message data in last notification
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-notification-data'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:postit-notification'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.last_notification_data is not None:
                                                for child_ref in self.last_notification_data:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.notification_error_code is not None:
                                                return True

                                            if self.notification_error_subcode is not None:
                                                return True

                                            if self.time_since_last_notification is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:postit-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.peer_id is not None:
                                            return True

                                        if self.postit_af_name is not None:
                                            return True

                                        if self.postit_direction is not None:
                                            return True

                                        if self.postit_flags is not None:
                                            return True

                                        if self.postit_id is not None:
                                            return True

                                        if self.postit_notification is not None and self.postit_notification._has_data():
                                            return True

                                        if self.postit_policy is not None:
                                            return True

                                        if self.postit_reset is not None:
                                            return True

                                        if self.postit_subtype is not None:
                                            return True

                                        if self.postit_ts is not None:
                                            return True

                                        if self.postit_type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.PostitInfo']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.neighbor_address is None:
                                        raise YPYModelError('Key property neighbor_address is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:postit[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address = ' + str(self.neighbor_address) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.neighbor_address is not None:
                                        return True

                                    if self.connect_state is not None:
                                        return True

                                    if self.neighbor_af is not None:
                                        for child_ref in self.neighbor_af:
                                            if child_ref._has_data():
                                                return True

                                    if self.neighbors_address is not None and self.neighbors_address._has_data():
                                        return True

                                    if self.nsr_state is not None:
                                        return True

                                    if self.postit_info is not None:
                                        for child_ref in self.postit_info:
                                            if child_ref._has_data():
                                                return True

                                    if self.start_time is not None:
                                        return True

                                    if self.vrf_name is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:postits'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.postit is not None:
                                    for child_ref in self.postit:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits']['meta_info']


                        class GlobalProcessInfo(object):
                            """
                            The Global Process information table
                            
                            .. attribute:: global_
                            
                            	Global information
                            	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Global_>`
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:   :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Vrf_>`
                            
                            .. attribute:: vrf_name
                            
                            	Name of the VRF
                            	**type**\:  str
                            
                            .. attribute:: vrfid
                            
                            	VRF ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.global_ = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Global_()
                                self.global_.parent = self
                                self.vrf = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Vrf_()
                                self.vrf.parent = self
                                self.vrf_name = None
                                self.vrfid = None


                            class Global_(object):
                                """
                                Global information
                                
                                .. attribute:: asn_format
                                
                                	BGP AS Number Format
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_current_buffer_size
                                
                                	Current value for BMP buffer 
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmp_default_buffer_size
                                
                                	Default value for BMP buffer limit when a value is not configured
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmp_maximum_buffer_size
                                
                                	Maximum limit user can configure for max\-buffer\-size command under bmp\-server
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: cluster_id
                                
                                	Cluster ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: cluster_id_entry
                                
                                	All configured Cluster IDs
                                	**type**\: list of    :py:class:`ClusterIdEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Global_.ClusterIdEntry>`
                                
                                .. attribute:: confederation_id
                                
                                	Confederation ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: configured_cluster_id
                                
                                	Configured cluster ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: generic_scan_period
                                
                                	Period (in seconds) of generic scanner runs
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: graceful_maint_all_nbrs
                                
                                	Graceful Maintenance also for neighbors without GM configuration
                                	**type**\:  bool
                                
                                .. attribute:: graceful_maint_retain_routes
                                
                                	Retaining routes in RIB when BGP process stops while in Graceful Maintenance
                                	**type**\:  bool
                                
                                .. attribute:: graceful_maintenance
                                
                                	Graceful Maintenance
                                	**type**\:  bool
                                
                                .. attribute:: in_standalone_mode
                                
                                	Standalone or Distributed mode
                                	**type**\:  bool
                                
                                .. attribute:: instance_name
                                
                                	Name of BGP instance
                                	**type**\:  str
                                
                                .. attribute:: is_cluster_id_specified_as_ip
                                
                                	Cluster ID specified as an IP address
                                	**type**\:  bool
                                
                                .. attribute:: local_as
                                
                                	Local autonomous system number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: process_rlimit
                                
                                	Platform RLIMIT max for the process
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: restart_count
                                
                                	No of times BGP has started
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: srgb_end
                                
                                	In use Segment\-routing Global Block end value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: srgb_end_configured
                                
                                	Configured segment\-routing Global Block end value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: srgb_start
                                
                                	In use segment\-routing Global Block start value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: srgb_start_configured
                                
                                	Configured segment\-routing Global Block start value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_delay
                                
                                	Update delay timeout time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.asn_format = None
                                    self.bmp_current_buffer_size = None
                                    self.bmp_default_buffer_size = None
                                    self.bmp_maximum_buffer_size = None
                                    self.cluster_id = None
                                    self.cluster_id_entry = YList()
                                    self.cluster_id_entry.parent = self
                                    self.cluster_id_entry.name = 'cluster_id_entry'
                                    self.confederation_id = None
                                    self.configured_cluster_id = None
                                    self.generic_scan_period = None
                                    self.graceful_maint_all_nbrs = None
                                    self.graceful_maint_retain_routes = None
                                    self.graceful_maintenance = None
                                    self.in_standalone_mode = None
                                    self.instance_name = None
                                    self.is_cluster_id_specified_as_ip = None
                                    self.local_as = None
                                    self.process_rlimit = None
                                    self.restart_count = None
                                    self.srgb_end = None
                                    self.srgb_end_configured = None
                                    self.srgb_start = None
                                    self.srgb_start_configured = None
                                    self.update_delay = None


                                class ClusterIdEntry(object):
                                    """
                                    All configured Cluster IDs
                                    
                                    .. attribute:: cluster_id_type
                                    
                                    	Cluster ID type\: number or IPv4 address
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: cluster_id_val
                                    
                                    	Cluster ID 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.cluster_id_type = None
                                        self.cluster_id_val = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster-id-entry'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.cluster_id_type is not None:
                                            return True

                                        if self.cluster_id_val is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Global_.ClusterIdEntry']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:global'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.asn_format is not None:
                                        return True

                                    if self.bmp_current_buffer_size is not None:
                                        return True

                                    if self.bmp_default_buffer_size is not None:
                                        return True

                                    if self.bmp_maximum_buffer_size is not None:
                                        return True

                                    if self.cluster_id is not None:
                                        return True

                                    if self.cluster_id_entry is not None:
                                        for child_ref in self.cluster_id_entry:
                                            if child_ref._has_data():
                                                return True

                                    if self.confederation_id is not None:
                                        return True

                                    if self.configured_cluster_id is not None:
                                        return True

                                    if self.generic_scan_period is not None:
                                        return True

                                    if self.graceful_maint_all_nbrs is not None:
                                        return True

                                    if self.graceful_maint_retain_routes is not None:
                                        return True

                                    if self.graceful_maintenance is not None:
                                        return True

                                    if self.in_standalone_mode is not None:
                                        return True

                                    if self.instance_name is not None:
                                        return True

                                    if self.is_cluster_id_specified_as_ip is not None:
                                        return True

                                    if self.local_as is not None:
                                        return True

                                    if self.process_rlimit is not None:
                                        return True

                                    if self.restart_count is not None:
                                        return True

                                    if self.srgb_end is not None:
                                        return True

                                    if self.srgb_end_configured is not None:
                                        return True

                                    if self.srgb_start is not None:
                                        return True

                                    if self.srgb_start_configured is not None:
                                        return True

                                    if self.update_delay is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Global_']['meta_info']


                            class Vrf_(object):
                                """
                                VRF information
                                
                                .. attribute:: configured_router_id
                                
                                	Configured router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: default_local_preference
                                
                                	Default local preference
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: default_metric
                                
                                	Default metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: hold_time
                                
                                	Default hold timer (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: is_bestpath_aigp_ignore_enabled
                                
                                	Bestpath\: Ignore AIGP unless both paths have AIGP attribute
                                	**type**\:  bool
                                
                                .. attribute:: is_bestpath_always_compare_med_enabled
                                
                                	Bestpath\: Always compare MED
                                	**type**\:  bool
                                
                                .. attribute:: is_bestpath_as_path_mpath_relax_enabled
                                
                                	Bestpath\: Relax AS path for mpath
                                	**type**\:  bool
                                
                                .. attribute:: is_bestpath_compare_med_from_confed_peer_enabled
                                
                                	Bestpath\: Compare MED from confed peer
                                	**type**\:  bool
                                
                                .. attribute:: is_bestpath_compare_router_id_for_ebgp_peers_enabled
                                
                                	Bestpath\: Compare routerID for eBGP peers
                                	**type**\:  bool
                                
                                .. attribute:: is_bestpath_ignore_as_path_enabled
                                
                                	Bestpath\: Ignore AS path
                                	**type**\:  bool
                                
                                .. attribute:: is_bestpath_missing_med_is_worst_enabled
                                
                                	Bestpath\: Treat missing MED as worst
                                	**type**\:  bool
                                
                                .. attribute:: is_default_metric_configured
                                
                                	Default metric configured
                                	**type**\:  bool
                                
                                .. attribute:: is_default_originate_configured
                                
                                	Default route originate configured
                                	**type**\:  bool
                                
                                .. attribute:: is_enforce_first_as_enabled
                                
                                	Enforce first AS
                                	**type**\:  bool
                                
                                .. attribute:: is_fast_external_fallover_enabled
                                
                                	Fast external fallover enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_graceful_restart
                                
                                	Graceful restart enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_multipath_as_path_ignore_onwards_enabled
                                
                                	Multipath\: Ignore everything AS path onwards for mpath
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_logging
                                
                                	Neighbor logging enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_nsr
                                
                                	Non\-stop routing enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_redistribute_ibgp_to_ig_ps_enabled
                                
                                	Redistribute iBGP into IGPs enabled
                                	**type**\:  bool
                                
                                .. attribute:: keep_alive_time
                                
                                	Default keepalive timer (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: min_acceptable_hold_time
                                
                                	Default min acceptable hold time from neighbor(seconds)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: restart_time
                                
                                	Restart time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: rib_purge_timeout
                                
                                	RIB purge timeout time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: route_distinguisher
                                
                                	Route Distinguisher
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: router_id
                                
                                	Router ID for the VRF
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: stale_path_time
                                
                                	Stale path timeout time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: vrf_is_active
                                
                                	VRF state
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.configured_router_id = None
                                    self.default_local_preference = None
                                    self.default_metric = None
                                    self.hold_time = None
                                    self.is_bestpath_aigp_ignore_enabled = None
                                    self.is_bestpath_always_compare_med_enabled = None
                                    self.is_bestpath_as_path_mpath_relax_enabled = None
                                    self.is_bestpath_compare_med_from_confed_peer_enabled = None
                                    self.is_bestpath_compare_router_id_for_ebgp_peers_enabled = None
                                    self.is_bestpath_ignore_as_path_enabled = None
                                    self.is_bestpath_missing_med_is_worst_enabled = None
                                    self.is_default_metric_configured = None
                                    self.is_default_originate_configured = None
                                    self.is_enforce_first_as_enabled = None
                                    self.is_fast_external_fallover_enabled = None
                                    self.is_graceful_restart = None
                                    self.is_multipath_as_path_ignore_onwards_enabled = None
                                    self.is_neighbor_logging = None
                                    self.is_nsr = None
                                    self.is_redistribute_ibgp_to_ig_ps_enabled = None
                                    self.keep_alive_time = None
                                    self.min_acceptable_hold_time = None
                                    self.restart_time = None
                                    self.rib_purge_timeout = None
                                    self.route_distinguisher = None
                                    self.router_id = None
                                    self.stale_path_time = None
                                    self.vrf_is_active = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:vrf'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.configured_router_id is not None:
                                        return True

                                    if self.default_local_preference is not None:
                                        return True

                                    if self.default_metric is not None:
                                        return True

                                    if self.hold_time is not None:
                                        return True

                                    if self.is_bestpath_aigp_ignore_enabled is not None:
                                        return True

                                    if self.is_bestpath_always_compare_med_enabled is not None:
                                        return True

                                    if self.is_bestpath_as_path_mpath_relax_enabled is not None:
                                        return True

                                    if self.is_bestpath_compare_med_from_confed_peer_enabled is not None:
                                        return True

                                    if self.is_bestpath_compare_router_id_for_ebgp_peers_enabled is not None:
                                        return True

                                    if self.is_bestpath_ignore_as_path_enabled is not None:
                                        return True

                                    if self.is_bestpath_missing_med_is_worst_enabled is not None:
                                        return True

                                    if self.is_default_metric_configured is not None:
                                        return True

                                    if self.is_default_originate_configured is not None:
                                        return True

                                    if self.is_enforce_first_as_enabled is not None:
                                        return True

                                    if self.is_fast_external_fallover_enabled is not None:
                                        return True

                                    if self.is_graceful_restart is not None:
                                        return True

                                    if self.is_multipath_as_path_ignore_onwards_enabled is not None:
                                        return True

                                    if self.is_neighbor_logging is not None:
                                        return True

                                    if self.is_nsr is not None:
                                        return True

                                    if self.is_redistribute_ibgp_to_ig_ps_enabled is not None:
                                        return True

                                    if self.keep_alive_time is not None:
                                        return True

                                    if self.min_acceptable_hold_time is not None:
                                        return True

                                    if self.restart_time is not None:
                                        return True

                                    if self.rib_purge_timeout is not None:
                                        return True

                                    if self.route_distinguisher is not None:
                                        return True

                                    if self.router_id is not None:
                                        return True

                                    if self.stale_path_time is not None:
                                        return True

                                    if self.vrf_is_active is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Vrf_']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:global-process-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.global_ is not None and self.global_._has_data():
                                    return True

                                if self.vrf is not None and self.vrf._has_data():
                                    return True

                                if self.vrf_name is not None:
                                    return True

                                if self.vrfid is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo']['meta_info']


                        class UpdateInboundErrorNeighbors(object):
                            """
                            Update inbound error information for all
                            neighbors
                            
                            .. attribute:: update_inbound_error_neighbor
                            
                            	Update inbound error information for neighbor
                            	**type**\: list of    :py:class:`UpdateInboundErrorNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.update_inbound_error_neighbor = YList()
                                self.update_inbound_error_neighbor.parent = self
                                self.update_inbound_error_neighbor.name = 'update_inbound_error_neighbor'


                            class UpdateInboundErrorNeighbor(object):
                                """
                                Update inbound error information for neighbor
                                
                                .. attribute:: neighbor_address  <key>
                                
                                	Neighbor address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: establishment_action_count
                                
                                	Number of occurence of each action type since  session establishment
                                	**type**\: list of    :py:class:`EstablishmentActionCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount>`
                                
                                .. attribute:: establishment_total_update_message_count
                                
                                	Total update messages count since session establishment
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: first_update_error_handling_reset_timestamp
                                
                                	First error\-handling reset time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`FirstUpdateErrorHandlingResetTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp>`
                                
                                .. attribute:: first_update_malformed_timestamp
                                
                                	First malformed message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`FirstUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp>`
                                
                                .. attribute:: first_update_memory_allocation_fail_timestamp
                                
                                	First memory allocation failure time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`FirstUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp>`
                                
                                .. attribute:: last_error_handling_reset_age
                                
                                	Time since last error\-handling reset event (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_error_handling_reset_timestamp
                                
                                	Last error\-handling reset time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`LastErrorHandlingResetTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp>`
                                
                                .. attribute:: last_update_malformed_age
                                
                                	Time since last malformed message received event (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_update_malformed_timestamp
                                
                                	Last malformed message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`LastUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp>`
                                
                                .. attribute:: last_update_memory_allocation_fail_age
                                
                                	Time since last memory allocation failure event (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_update_memory_allocation_fail_timestamp
                                
                                	Last memory allocation failure time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp>`
                                
                                .. attribute:: total_update_message_count
                                
                                	Total update messages count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_attribute_discard_count
                                
                                	Discarded attribute count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_error_handling_avoid_reset
                                
                                	Configure error\-handling to avoid resets
                                	**type**\:  bool
                                
                                .. attribute:: update_error_handling_reset_count
                                
                                	Error\-handling reset count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_error_message
                                
                                	List of malformed messages
                                	**type**\: list of    :py:class:`UpdateErrorMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage>`
                                
                                .. attribute:: update_error_message_list_count
                                
                                	Malformed messages list count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_malformed_message_count
                                
                                	Malformed messages count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_memory_allocation_fail_count
                                
                                	Memory allocation failure count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_neighbor_address
                                
                                	Neighbor address
                                	**type**\:   :py:class:`UpdateNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress>`
                                
                                .. attribute:: update_vrf_name
                                
                                	VRF Name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.neighbor_address = None
                                    self.establishment_action_count = YList()
                                    self.establishment_action_count.parent = self
                                    self.establishment_action_count.name = 'establishment_action_count'
                                    self.establishment_total_update_message_count = None
                                    self.first_update_error_handling_reset_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp()
                                    self.first_update_error_handling_reset_timestamp.parent = self
                                    self.first_update_malformed_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp()
                                    self.first_update_malformed_timestamp.parent = self
                                    self.first_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp()
                                    self.first_update_memory_allocation_fail_timestamp.parent = self
                                    self.last_error_handling_reset_age = None
                                    self.last_error_handling_reset_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp()
                                    self.last_error_handling_reset_timestamp.parent = self
                                    self.last_update_malformed_age = None
                                    self.last_update_malformed_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp()
                                    self.last_update_malformed_timestamp.parent = self
                                    self.last_update_memory_allocation_fail_age = None
                                    self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp()
                                    self.last_update_memory_allocation_fail_timestamp.parent = self
                                    self.total_update_message_count = None
                                    self.update_attribute_discard_count = None
                                    self.update_error_handling_avoid_reset = None
                                    self.update_error_handling_reset_count = None
                                    self.update_error_message = YList()
                                    self.update_error_message.parent = self
                                    self.update_error_message.name = 'update_error_message'
                                    self.update_error_message_list_count = None
                                    self.update_malformed_message_count = None
                                    self.update_memory_allocation_fail_count = None
                                    self.update_neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress()
                                    self.update_neighbor_address.parent = self
                                    self.update_vrf_name = None


                                class UpdateNeighborAddress(object):
                                    """
                                    Neighbor address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpnvpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnvplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4mdt_address = None
                                        self.ipv4mvpn_address = None
                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress()
                                        self.ipv4sr_policy_address.parent = self
                                        self.ipv4vpn_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress()
                                        self.ipv6sr_policy_address.parent = self
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_flowspec_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.l2vpn_evpn_address = None
                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnvplsAddress()
                                        self.l2vpnvpls_address.parent = self
                                        self.ls_ls_address = None
                                        self.rt_constraint_address = None


                                    class L2VpnvplsAddress(object):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnvplsAddress']['meta_info']


                                    class L2VpnMspwAddress(object):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnMspwAddress']['meta_info']


                                    class Ipv4SrPolicyAddress(object):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                    class Ipv6SrPolicyAddress(object):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv6_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv6_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-neighbor-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.afi is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv4_flowspec_address is not None:
                                            return True

                                        if self.ipv4_label_address is not None:
                                            return True

                                        if self.ipv4_mcast_address is not None:
                                            return True

                                        if self.ipv4_tunnel_address is not None:
                                            return True

                                        if self.ipv4mdt_address is not None:
                                            return True

                                        if self.ipv4mvpn_address is not None:
                                            return True

                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                            return True

                                        if self.ipv4vpn_address is not None:
                                            return True

                                        if self.ipv4vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv4vpna_mcastddress is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        if self.ipv6_flowspec_address is not None:
                                            return True

                                        if self.ipv6_label_address is not None:
                                            return True

                                        if self.ipv6_mcast_address is not None:
                                            return True

                                        if self.ipv6mvpn_address is not None:
                                            return True

                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                            return True

                                        if self.ipv6vpn_address is not None:
                                            return True

                                        if self.ipv6vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv6vpn_mcast_address is not None:
                                            return True

                                        if self.l2vpn_evpn_address is not None:
                                            return True

                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                            return True

                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                            return True

                                        if self.ls_ls_address is not None:
                                            return True

                                        if self.rt_constraint_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress']['meta_info']


                                class FirstUpdateMalformedTimestamp(object):
                                    """
                                    First malformed message received time\: time
                                    elapsed since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-update-malformed-timestamp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp']['meta_info']


                                class LastUpdateMalformedTimestamp(object):
                                    """
                                    Last malformed message received time\: time
                                    elapsed since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-malformed-timestamp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp']['meta_info']


                                class FirstUpdateMemoryAllocationFailTimestamp(object):
                                    """
                                    First memory allocation failure time\: time
                                    elapsed since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-update-memory-allocation-fail-timestamp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp']['meta_info']


                                class LastUpdateMemoryAllocationFailTimestamp(object):
                                    """
                                    Last memory allocation failure time\: time
                                    elapsed since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-memory-allocation-fail-timestamp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp']['meta_info']


                                class FirstUpdateErrorHandlingResetTimestamp(object):
                                    """
                                    First error\-handling reset time\: time elapsed
                                    since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-update-error-handling-reset-timestamp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp']['meta_info']


                                class LastErrorHandlingResetTimestamp(object):
                                    """
                                    Last error\-handling reset time\: time elapsed
                                    since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-error-handling-reset-timestamp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp']['meta_info']


                                class EstablishmentActionCount(object):
                                    """
                                    Number of occurence of each action type since
                                    
                                    session establishment
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:establishment-action-count'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount']['meta_info']


                                class UpdateErrorMessage(object):
                                    """
                                    List of malformed messages
                                    
                                    .. attribute:: update_attribute_discard_count
                                    
                                    	Discarded attribute count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_error_element
                                    
                                    	Error element list
                                    	**type**\: list of    :py:class:`UpdateErrorElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement>`
                                    
                                    .. attribute:: update_error_final_action
                                    
                                    	Error final action
                                    	**type**\:   :py:class:`BgpBagUpdErrActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdErrActionEnum>`
                                    
                                    .. attribute:: update_error_nlri_address_family
                                    
                                    	NLRI address\-family
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: update_error_nlri_string
                                    
                                    	List of NLRIs in string format
                                    	**type**\:  str
                                    
                                    .. attribute:: update_error_nlri_string_truncated
                                    
                                    	Indicates whether NLRI string was truncated due to lack of space
                                    	**type**\:  bool
                                    
                                    .. attribute:: update_message_data
                                    
                                    	Raw Message data in binary format
                                    	**type**\: list of    :py:class:`UpdateMessageData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData>`
                                    
                                    .. attribute:: update_message_reset_data
                                    
                                    	Reset data
                                    	**type**\:   :py:class:`UpdateMessageResetData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData>`
                                    
                                    .. attribute:: update_message_timestamp
                                    
                                    	Message timestamp\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                    	**type**\:   :py:class:`UpdateMessageTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.update_attribute_discard_count = None
                                        self.update_error_element = YList()
                                        self.update_error_element.parent = self
                                        self.update_error_element.name = 'update_error_element'
                                        self.update_error_final_action = None
                                        self.update_error_nlri_address_family = None
                                        self.update_error_nlri_string = None
                                        self.update_error_nlri_string_truncated = None
                                        self.update_message_data = YList()
                                        self.update_message_data.parent = self
                                        self.update_message_data.name = 'update_message_data'
                                        self.update_message_reset_data = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData()
                                        self.update_message_reset_data.parent = self
                                        self.update_message_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp()
                                        self.update_message_timestamp.parent = self


                                    class UpdateMessageTimestamp(object):
                                        """
                                        Message timestamp\: time elapsed since 00\:00\:00
                                        UTC, January 1, 1970
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-message-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp']['meta_info']


                                    class UpdateMessageResetData(object):
                                        """
                                        Reset data
                                        
                                        .. attribute:: update_error_reset_notification_code
                                        
                                        	Notification code
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_error_reset_notification_data
                                        
                                        	Notification data
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: update_error_reset_notification_data_length
                                        
                                        	Notification data length
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: update_error_reset_notification_sub_code
                                        
                                        	Notification sub code
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: update_error_reset_reason
                                        
                                        	Reset Reason
                                        	**type**\:   :py:class:`BgpResetReasonIndexEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndexEnum>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.update_error_reset_notification_code = None
                                            self.update_error_reset_notification_data = None
                                            self.update_error_reset_notification_data_length = None
                                            self.update_error_reset_notification_sub_code = None
                                            self.update_error_reset_reason = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-message-reset-data'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.update_error_reset_notification_code is not None:
                                                return True

                                            if self.update_error_reset_notification_data is not None:
                                                return True

                                            if self.update_error_reset_notification_data_length is not None:
                                                return True

                                            if self.update_error_reset_notification_sub_code is not None:
                                                return True

                                            if self.update_error_reset_reason is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData']['meta_info']


                                    class UpdateMessageData(object):
                                        """
                                        Raw Message data in binary format
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.entry = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-message-data'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.entry is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData']['meta_info']


                                    class UpdateErrorElement(object):
                                        """
                                        Error element list
                                        
                                        .. attribute:: update_attribute_code
                                        
                                        	Attribute code [RFC4271\: BGP4]
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_attribute_flags
                                        
                                        	Attribute Flags [RFC4271\: BGP4]
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_attribute_length
                                        
                                        	Attribute Length [RFC4271\: BGP4]
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: update_error_action
                                        
                                        	Error action
                                        	**type**\:   :py:class:`BgpBagUpdErrActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdErrActionEnum>`
                                        
                                        .. attribute:: update_error_data
                                        
                                        	Error data
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: update_error_data_length
                                        
                                        	Error data length
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.update_attribute_code = None
                                            self.update_attribute_flags = None
                                            self.update_attribute_length = None
                                            self.update_error_action = None
                                            self.update_error_data = None
                                            self.update_error_data_length = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-error-element'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.update_attribute_code is not None:
                                                return True

                                            if self.update_attribute_flags is not None:
                                                return True

                                            if self.update_attribute_length is not None:
                                                return True

                                            if self.update_error_action is not None:
                                                return True

                                            if self.update_error_data is not None:
                                                return True

                                            if self.update_error_data_length is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-error-message'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.update_attribute_discard_count is not None:
                                            return True

                                        if self.update_error_element is not None:
                                            for child_ref in self.update_error_element:
                                                if child_ref._has_data():
                                                    return True

                                        if self.update_error_final_action is not None:
                                            return True

                                        if self.update_error_nlri_address_family is not None:
                                            return True

                                        if self.update_error_nlri_string is not None:
                                            return True

                                        if self.update_error_nlri_string_truncated is not None:
                                            return True

                                        if self.update_message_data is not None:
                                            for child_ref in self.update_message_data:
                                                if child_ref._has_data():
                                                    return True

                                        if self.update_message_reset_data is not None and self.update_message_reset_data._has_data():
                                            return True

                                        if self.update_message_timestamp is not None and self.update_message_timestamp._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.neighbor_address is None:
                                        raise YPYModelError('Key property neighbor_address is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-inbound-error-neighbor[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address = ' + str(self.neighbor_address) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.neighbor_address is not None:
                                        return True

                                    if self.establishment_action_count is not None:
                                        for child_ref in self.establishment_action_count:
                                            if child_ref._has_data():
                                                return True

                                    if self.establishment_total_update_message_count is not None:
                                        return True

                                    if self.first_update_error_handling_reset_timestamp is not None and self.first_update_error_handling_reset_timestamp._has_data():
                                        return True

                                    if self.first_update_malformed_timestamp is not None and self.first_update_malformed_timestamp._has_data():
                                        return True

                                    if self.first_update_memory_allocation_fail_timestamp is not None and self.first_update_memory_allocation_fail_timestamp._has_data():
                                        return True

                                    if self.last_error_handling_reset_age is not None:
                                        return True

                                    if self.last_error_handling_reset_timestamp is not None and self.last_error_handling_reset_timestamp._has_data():
                                        return True

                                    if self.last_update_malformed_age is not None:
                                        return True

                                    if self.last_update_malformed_timestamp is not None and self.last_update_malformed_timestamp._has_data():
                                        return True

                                    if self.last_update_memory_allocation_fail_age is not None:
                                        return True

                                    if self.last_update_memory_allocation_fail_timestamp is not None and self.last_update_memory_allocation_fail_timestamp._has_data():
                                        return True

                                    if self.total_update_message_count is not None:
                                        return True

                                    if self.update_attribute_discard_count is not None:
                                        return True

                                    if self.update_error_handling_avoid_reset is not None:
                                        return True

                                    if self.update_error_handling_reset_count is not None:
                                        return True

                                    if self.update_error_message is not None:
                                        for child_ref in self.update_error_message:
                                            if child_ref._has_data():
                                                return True

                                    if self.update_error_message_list_count is not None:
                                        return True

                                    if self.update_malformed_message_count is not None:
                                        return True

                                    if self.update_memory_allocation_fail_count is not None:
                                        return True

                                    if self.update_neighbor_address is not None and self.update_neighbor_address._has_data():
                                        return True

                                    if self.update_vrf_name is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-inbound-error-neighbors'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.update_inbound_error_neighbor is not None:
                                    for child_ref in self.update_inbound_error_neighbor:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors']['meta_info']


                        class UpdateInboundFilterNeighbors(object):
                            """
                            Update inbound filtering information for all
                            neighbors
                            
                            .. attribute:: update_inbound_filter_neighbor
                            
                            	Update inbound filtering information for neighbor
                            	**type**\: list of    :py:class:`UpdateInboundFilterNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.update_inbound_filter_neighbor = YList()
                                self.update_inbound_filter_neighbor.parent = self
                                self.update_inbound_filter_neighbor.name = 'update_inbound_filter_neighbor'


                            class UpdateInboundFilterNeighbor(object):
                                """
                                Update inbound filtering information for
                                neighbor
                                
                                .. attribute:: neighbor_address  <key>
                                
                                	Neighbor address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: configured_update_filter_message_buffer_count
                                
                                	Configured Filtered message buffer count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: establishment_total_filter_update_message_count
                                
                                	Total update messages count since session establishment
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: establishment_update_filtered_message_count
                                
                                	Filtered messages count since session establishment
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: first_update_filtered_timestamp
                                
                                	First filtered message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`FirstUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp>`
                                
                                .. attribute:: last_update_filtered_age
                                
                                	Time since last filtered message received event (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_update_filtered_timestamp
                                
                                	Last filtered message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`LastUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp>`
                                
                                .. attribute:: message_update_attribute_filtering_enabled
                                
                                	Attribute filtering is enabled for the current message being parsed
                                	**type**\:  bool
                                
                                .. attribute:: operational_update_attribute_filtering_enabled
                                
                                	Attribute filtering is enabled
                                	**type**\:  bool
                                
                                .. attribute:: operational_update_filter_message_buffer_count
                                
                                	Operational Filtered messages buffer count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_filter_update_message_count
                                
                                	Total update messages count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_attribute_filter_attributes
                                
                                	List of attributes that can be filtered
                                	**type**\: list of    :py:class:`UpdateAttributeFilterAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes>`
                                
                                .. attribute:: update_attribute_filter_group_name
                                
                                	Update attribute\-filter group name
                                	**type**\:  str
                                
                                .. attribute:: update_filter_logging_enabled
                                
                                	Logging is enabled
                                	**type**\:  bool
                                
                                .. attribute:: update_filter_message
                                
                                	List of filtered messages
                                	**type**\: list of    :py:class:`UpdateFilterMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage>`
                                
                                .. attribute:: update_filter_message_buffer_circular
                                
                                	Indicates if the message buffers are circular
                                	**type**\:  bool
                                
                                .. attribute:: update_filter_message_list_count
                                
                                	Filtered messages list count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_filtered_message_count
                                
                                	Filtered messages count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_neighbor_address
                                
                                	Neighbor address
                                	**type**\:   :py:class:`UpdateNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress>`
                                
                                .. attribute:: update_vrf_name
                                
                                	VRF Name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.neighbor_address = None
                                    self.configured_update_filter_message_buffer_count = None
                                    self.establishment_total_filter_update_message_count = None
                                    self.establishment_update_filtered_message_count = None
                                    self.first_update_filtered_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp()
                                    self.first_update_filtered_timestamp.parent = self
                                    self.last_update_filtered_age = None
                                    self.last_update_filtered_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp()
                                    self.last_update_filtered_timestamp.parent = self
                                    self.message_update_attribute_filtering_enabled = None
                                    self.operational_update_attribute_filtering_enabled = None
                                    self.operational_update_filter_message_buffer_count = None
                                    self.total_filter_update_message_count = None
                                    self.update_attribute_filter_attributes = YList()
                                    self.update_attribute_filter_attributes.parent = self
                                    self.update_attribute_filter_attributes.name = 'update_attribute_filter_attributes'
                                    self.update_attribute_filter_group_name = None
                                    self.update_filter_logging_enabled = None
                                    self.update_filter_message = YList()
                                    self.update_filter_message.parent = self
                                    self.update_filter_message.name = 'update_filter_message'
                                    self.update_filter_message_buffer_circular = None
                                    self.update_filter_message_list_count = None
                                    self.update_filtered_message_count = None
                                    self.update_neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress()
                                    self.update_neighbor_address.parent = self
                                    self.update_vrf_name = None


                                class UpdateNeighborAddress(object):
                                    """
                                    Neighbor address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpnvpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnvplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4mdt_address = None
                                        self.ipv4mvpn_address = None
                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress()
                                        self.ipv4sr_policy_address.parent = self
                                        self.ipv4vpn_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress()
                                        self.ipv6sr_policy_address.parent = self
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_flowspec_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.l2vpn_evpn_address = None
                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnvplsAddress()
                                        self.l2vpnvpls_address.parent = self
                                        self.ls_ls_address = None
                                        self.rt_constraint_address = None


                                    class L2VpnvplsAddress(object):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnvplsAddress']['meta_info']


                                    class L2VpnMspwAddress(object):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnMspwAddress']['meta_info']


                                    class Ipv4SrPolicyAddress(object):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                    class Ipv6SrPolicyAddress(object):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv6_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv6_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-neighbor-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.afi is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv4_flowspec_address is not None:
                                            return True

                                        if self.ipv4_label_address is not None:
                                            return True

                                        if self.ipv4_mcast_address is not None:
                                            return True

                                        if self.ipv4_tunnel_address is not None:
                                            return True

                                        if self.ipv4mdt_address is not None:
                                            return True

                                        if self.ipv4mvpn_address is not None:
                                            return True

                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                            return True

                                        if self.ipv4vpn_address is not None:
                                            return True

                                        if self.ipv4vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv4vpna_mcastddress is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        if self.ipv6_flowspec_address is not None:
                                            return True

                                        if self.ipv6_label_address is not None:
                                            return True

                                        if self.ipv6_mcast_address is not None:
                                            return True

                                        if self.ipv6mvpn_address is not None:
                                            return True

                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                            return True

                                        if self.ipv6vpn_address is not None:
                                            return True

                                        if self.ipv6vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv6vpn_mcast_address is not None:
                                            return True

                                        if self.l2vpn_evpn_address is not None:
                                            return True

                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                            return True

                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                            return True

                                        if self.ls_ls_address is not None:
                                            return True

                                        if self.rt_constraint_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress']['meta_info']


                                class FirstUpdateFilteredTimestamp(object):
                                    """
                                    First filtered message received time\: time
                                    elapsed since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-update-filtered-timestamp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp']['meta_info']


                                class LastUpdateFilteredTimestamp(object):
                                    """
                                    Last filtered message received time\: time
                                    elapsed since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-filtered-timestamp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp']['meta_info']


                                class UpdateAttributeFilterAttributes(object):
                                    """
                                    List of attributes that can be filtered
                                    
                                    .. attribute:: establishment_update_filter_match_count
                                    
                                    	Filter match counter since last session establishment
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_update_filter_match_age
                                    
                                    	Time since this attribute was last filtered (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_filter_match_timestamp
                                    
                                    	Last attribute filtered time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                    	**type**\:   :py:class:`LastUpdateFilterMatchTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp>`
                                    
                                    .. attribute:: update_filter_action
                                    
                                    	Filtering action
                                    	**type**\:   :py:class:`BgpBagUpdFilterActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterActionEnum>`
                                    
                                    .. attribute:: update_filter_match_count
                                    
                                    	Filter match counter
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_internal_attribute_code
                                    
                                    	Internal attribute code [RFC4271\: BGP4]
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.establishment_update_filter_match_count = None
                                        self.last_update_filter_match_age = None
                                        self.last_update_filter_match_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp()
                                        self.last_update_filter_match_timestamp.parent = self
                                        self.update_filter_action = None
                                        self.update_filter_match_count = None
                                        self.update_internal_attribute_code = None


                                    class LastUpdateFilterMatchTimestamp(object):
                                        """
                                        Last attribute filtered time\: time elapsed since
                                        00\:00\:00 UTC, January 1, 1970
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-filter-match-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-attribute-filter-attributes'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.establishment_update_filter_match_count is not None:
                                            return True

                                        if self.last_update_filter_match_age is not None:
                                            return True

                                        if self.last_update_filter_match_timestamp is not None and self.last_update_filter_match_timestamp._has_data():
                                            return True

                                        if self.update_filter_action is not None:
                                            return True

                                        if self.update_filter_match_count is not None:
                                            return True

                                        if self.update_internal_attribute_code is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes']['meta_info']


                                class UpdateFilterMessage(object):
                                    """
                                    List of filtered messages
                                    
                                    .. attribute:: update_filter_element
                                    
                                    	Filtering element list
                                    	**type**\: list of    :py:class:`UpdateFilterElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement>`
                                    
                                    .. attribute:: update_filter_final_action
                                    
                                    	Filtering final action
                                    	**type**\:   :py:class:`BgpBagUpdFilterActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterActionEnum>`
                                    
                                    .. attribute:: update_filter_message_data
                                    
                                    	Raw Message data in binary format
                                    	**type**\: list of    :py:class:`UpdateFilterMessageData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData>`
                                    
                                    .. attribute:: update_filter_message_timestamp
                                    
                                    	Message timestamp\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                    	**type**\:   :py:class:`UpdateFilterMessageTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp>`
                                    
                                    .. attribute:: update_filter_nlri_address_family
                                    
                                    	NLRI address\-family
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: update_filter_nlri_string
                                    
                                    	List of NLRIs in string format
                                    	**type**\:  str
                                    
                                    .. attribute:: update_filter_nlri_string_truncated
                                    
                                    	Indicates whether NLRI string was truncated due to lack of space
                                    	**type**\:  bool
                                    
                                    .. attribute:: update_filtered_attribute_count
                                    
                                    	Filtered attributes count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.update_filter_element = YList()
                                        self.update_filter_element.parent = self
                                        self.update_filter_element.name = 'update_filter_element'
                                        self.update_filter_final_action = None
                                        self.update_filter_message_data = YList()
                                        self.update_filter_message_data.parent = self
                                        self.update_filter_message_data.name = 'update_filter_message_data'
                                        self.update_filter_message_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp()
                                        self.update_filter_message_timestamp.parent = self
                                        self.update_filter_nlri_address_family = None
                                        self.update_filter_nlri_string = None
                                        self.update_filter_nlri_string_truncated = None
                                        self.update_filtered_attribute_count = None


                                    class UpdateFilterMessageTimestamp(object):
                                        """
                                        Message timestamp\: time elapsed since 00\:00\:00
                                        UTC, January 1, 1970
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-filter-message-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp']['meta_info']


                                    class UpdateFilterMessageData(object):
                                        """
                                        Raw Message data in binary format
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.entry = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-filter-message-data'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.entry is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData']['meta_info']


                                    class UpdateFilterElement(object):
                                        """
                                        Filtering element list
                                        
                                        .. attribute:: update_attribute_code
                                        
                                        	Attribute code [RFC4271\: BGP4]
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_attribute_flags
                                        
                                        	Attribute Flags [RFC4271\: BGP4]
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_filter_action
                                        
                                        	Filtering action
                                        	**type**\:   :py:class:`BgpBagUpdFilterActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterActionEnum>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.update_attribute_code = None
                                            self.update_attribute_flags = None
                                            self.update_filter_action = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-filter-element'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.update_attribute_code is not None:
                                                return True

                                            if self.update_attribute_flags is not None:
                                                return True

                                            if self.update_filter_action is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-filter-message'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.update_filter_element is not None:
                                            for child_ref in self.update_filter_element:
                                                if child_ref._has_data():
                                                    return True

                                        if self.update_filter_final_action is not None:
                                            return True

                                        if self.update_filter_message_data is not None:
                                            for child_ref in self.update_filter_message_data:
                                                if child_ref._has_data():
                                                    return True

                                        if self.update_filter_message_timestamp is not None and self.update_filter_message_timestamp._has_data():
                                            return True

                                        if self.update_filter_nlri_address_family is not None:
                                            return True

                                        if self.update_filter_nlri_string is not None:
                                            return True

                                        if self.update_filter_nlri_string_truncated is not None:
                                            return True

                                        if self.update_filtered_attribute_count is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.neighbor_address is None:
                                        raise YPYModelError('Key property neighbor_address is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-inbound-filter-neighbor[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address = ' + str(self.neighbor_address) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.neighbor_address is not None:
                                        return True

                                    if self.configured_update_filter_message_buffer_count is not None:
                                        return True

                                    if self.establishment_total_filter_update_message_count is not None:
                                        return True

                                    if self.establishment_update_filtered_message_count is not None:
                                        return True

                                    if self.first_update_filtered_timestamp is not None and self.first_update_filtered_timestamp._has_data():
                                        return True

                                    if self.last_update_filtered_age is not None:
                                        return True

                                    if self.last_update_filtered_timestamp is not None and self.last_update_filtered_timestamp._has_data():
                                        return True

                                    if self.message_update_attribute_filtering_enabled is not None:
                                        return True

                                    if self.operational_update_attribute_filtering_enabled is not None:
                                        return True

                                    if self.operational_update_filter_message_buffer_count is not None:
                                        return True

                                    if self.total_filter_update_message_count is not None:
                                        return True

                                    if self.update_attribute_filter_attributes is not None:
                                        for child_ref in self.update_attribute_filter_attributes:
                                            if child_ref._has_data():
                                                return True

                                    if self.update_attribute_filter_group_name is not None:
                                        return True

                                    if self.update_filter_logging_enabled is not None:
                                        return True

                                    if self.update_filter_message is not None:
                                        for child_ref in self.update_filter_message:
                                            if child_ref._has_data():
                                                return True

                                    if self.update_filter_message_buffer_circular is not None:
                                        return True

                                    if self.update_filter_message_list_count is not None:
                                        return True

                                    if self.update_filtered_message_count is not None:
                                        return True

                                    if self.update_neighbor_address is not None and self.update_neighbor_address._has_data():
                                        return True

                                    if self.update_vrf_name is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-inbound-filter-neighbors'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.update_inbound_filter_neighbor is not None:
                                    for child_ref in self.update_inbound_filter_neighbor:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors']['meta_info']


                        class Bmp(object):
                            """
                            BMP related Operational Data
                            
                            .. attribute:: server_neighbors
                            
                            	Table of Neighbors for a BMP Server
                            	**type**\:   :py:class:`ServerNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors>`
                            
                            .. attribute:: server_summaries
                            
                            	Table of BMP Servers
                            	**type**\:   :py:class:`ServerSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.server_neighbors = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors()
                                self.server_neighbors.parent = self
                                self.server_summaries = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries()
                                self.server_summaries.parent = self


                            class ServerSummaries(object):
                                """
                                Table of BMP Servers
                                
                                .. attribute:: server_summary
                                
                                	Summary Information about BMP server
                                	**type**\: list of    :py:class:`ServerSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.server_summary = YList()
                                    self.server_summary.parent = self
                                    self.server_summary.name = 'server_summary'


                                class ServerSummary(object):
                                    """
                                    Summary Information about BMP server
                                    
                                    .. attribute:: server_id  <key>
                                    
                                    	BMP Server ID
                                    	**type**\:  int
                                    
                                    	**range:** 1..8
                                    
                                    .. attribute:: bmp_bytes_written_tcp
                                    
                                    	Total bytes sent to TCP
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: bmp_init_msg_count
                                    
                                    	Number of Initiation Msgs sent by this BMP Server
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_messages_wdraw_discarded
                                    
                                    	Total bmpQ wdraw msgs discarded because of peer down
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_peer_msg_drop_count
                                    
                                    	Total number of messages dropped
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_peer_msg_pending_count
                                    
                                    	Total number of bmpQ msgs pending
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_peer_msg_pending_count_hwts
                                    
                                    	Total bmpQ msgs pending max time
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmp_peer_msg_pending_count_max
                                    
                                    	Total bmpQ msgs pending max
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_per_peer_msg_count
                                    
                                    	Total number of per peer messages sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_per_peer_msg_route_mon_count
                                    
                                    	Total number of per peer route mon messages sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_pfx_wdraw_discarded
                                    
                                    	Total bmpQ wdraw pfxes discarded because of peer down
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_send_version
                                    
                                    	Table Version that this BMP server has caught  upto
                                    	**type**\: list of    :py:class:`BmpSendVersion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpSendVersion>`
                                    
                                    .. attribute:: bmp_server_host_name
                                    
                                    	BMP Server Hostname
                                    	**type**\:  str
                                    
                                    .. attribute:: bmp_server_id
                                    
                                    	BMP Server ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: bmp_server_is_flapping
                                    
                                    	Connection to the BMP server Flapping
                                    	**type**\:  bool
                                    
                                    .. attribute:: bmp_server_last_discon_time
                                    
                                    	Timespec of Last Disconnect event received from BMP server
                                    	**type**\:   :py:class:`BmpServerLastDisconTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime>`
                                    
                                    .. attribute:: bmp_server_nbr_count
                                    
                                    	Neighbor count for the BMP Server
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_server_port
                                    
                                    	BMP Server Port Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_server_state
                                    
                                    	Connection state of the BMP server
                                    	**type**\:   :py:class:`BgpBmpStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBmpStateEnum>`
                                    
                                    .. attribute:: bmp_server_state_age
                                    
                                    	Age of current state of BMP Server
                                    	**type**\:   :py:class:`BmpServerStateAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge>`
                                    
                                    .. attribute:: bmp_server_state_time_spec
                                    
                                    	Timespec of current state of BMP Server
                                    	**type**\:   :py:class:`BmpServerStateTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec>`
                                    
                                    .. attribute:: bmp_status_report_count
                                    
                                    	Number of Status ReportMessages sent by this BMP Server
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_termination_msg_count
                                    
                                    	Number of Termination Messages sent by this BMP Server
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_update_mode
                                    
                                    	Update sending mode configured for this BMP server
                                    	**type**\:   :py:class:`BgpBmpUpdModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBmpUpdModeEnum>`
                                    
                                    .. attribute:: bmp_vrf_id
                                    
                                    	VRF ID for the vrf name configured
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_vrf_name
                                    
                                    	VRF Name configured
                                    	**type**\:  str
                                    
                                    .. attribute:: bmpq_last_all_write_pulse_sent_time
                                    
                                    	Last BMPQ write pulse Sent for all BMP servers 
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmpq_last_write_pulse_cb_time
                                    
                                    	Last BMPQ write pulse callback time
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmpq_last_write_pulse_sent_time
                                    
                                    	Last BMPQ write pulse Sent time
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmpr_mon_upd_messages
                                    
                                    	Total bmpQ update msgs 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmpr_mon_update_gen_time
                                    
                                    	Time spent in update generation(milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: bmpr_mon_wdraw_messages
                                    
                                    	Total bmpQ withdraw msgs 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_update_count
                                    
                                    	Number of path update sent 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_update_drop
                                    
                                    	Number of path update drop 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_withdraw_count
                                    
                                    	Number of path wdraw sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_withdraw_drop
                                    
                                    	Number of path wdraw drop 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_keep_alive_interval
                                    
                                    	TCP Keep alive interval configured
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_last_write_cb_time
                                    
                                    	Last TCP Write CB time
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tcp_last_write_result
                                    
                                    	Last TCP Socket write status
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_last_write_time
                                    
                                    	Last TCP Write time
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tcp_maximum_segment_size
                                    
                                    	TCP Maximum Segments size configured
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_write_cb_pending
                                    
                                    	Are we waiting for TCP write callback ?
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_write_time
                                    
                                    	Time spent processing sending msg to TCP(milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: tos_type
                                    
                                    	Precedence (0) or DSCP (1) type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_value
                                    
                                    	Precedence or DSCP value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_source_address
                                    
                                    	Address of Interface configured as Update Source
                                    	**type**\:   :py:class:`UpdateSourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress>`
                                    
                                    .. attribute:: update_source_interface_name
                                    
                                    	Interface configured as Update Source
                                    	**type**\:  str
                                    
                                    .. attribute:: update_source_vrf_id
                                    
                                    	VRF ID of interface configured as Update Source
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.server_id = None
                                        self.bmp_bytes_written_tcp = None
                                        self.bmp_init_msg_count = None
                                        self.bmp_messages_wdraw_discarded = None
                                        self.bmp_peer_msg_drop_count = None
                                        self.bmp_peer_msg_pending_count = None
                                        self.bmp_peer_msg_pending_count_hwts = None
                                        self.bmp_peer_msg_pending_count_max = None
                                        self.bmp_per_peer_msg_count = None
                                        self.bmp_per_peer_msg_route_mon_count = None
                                        self.bmp_pfx_wdraw_discarded = None
                                        self.bmp_send_version = YList()
                                        self.bmp_send_version.parent = self
                                        self.bmp_send_version.name = 'bmp_send_version'
                                        self.bmp_server_host_name = None
                                        self.bmp_server_id = None
                                        self.bmp_server_is_flapping = None
                                        self.bmp_server_last_discon_time = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime()
                                        self.bmp_server_last_discon_time.parent = self
                                        self.bmp_server_nbr_count = None
                                        self.bmp_server_port = None
                                        self.bmp_server_state = None
                                        self.bmp_server_state_age = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge()
                                        self.bmp_server_state_age.parent = self
                                        self.bmp_server_state_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec()
                                        self.bmp_server_state_time_spec.parent = self
                                        self.bmp_status_report_count = None
                                        self.bmp_termination_msg_count = None
                                        self.bmp_update_mode = None
                                        self.bmp_vrf_id = None
                                        self.bmp_vrf_name = None
                                        self.bmpq_last_all_write_pulse_sent_time = None
                                        self.bmpq_last_write_pulse_cb_time = None
                                        self.bmpq_last_write_pulse_sent_time = None
                                        self.bmpr_mon_upd_messages = None
                                        self.bmpr_mon_update_gen_time = None
                                        self.bmpr_mon_wdraw_messages = None
                                        self.path_update_count = None
                                        self.path_update_drop = None
                                        self.path_withdraw_count = None
                                        self.path_withdraw_drop = None
                                        self.tcp_keep_alive_interval = None
                                        self.tcp_last_write_cb_time = None
                                        self.tcp_last_write_result = None
                                        self.tcp_last_write_time = None
                                        self.tcp_maximum_segment_size = None
                                        self.tcp_write_cb_pending = None
                                        self.tcp_write_time = None
                                        self.tos_type = None
                                        self.tos_value = None
                                        self.update_source_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress()
                                        self.update_source_address.parent = self
                                        self.update_source_interface_name = None
                                        self.update_source_vrf_id = None


                                    class BmpServerStateAge(object):
                                        """
                                        Age of current state of BMP Server
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-server-state-age'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge']['meta_info']


                                    class BmpServerStateTimeSpec(object):
                                        """
                                        Timespec of current state of BMP Server
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-server-state-time-spec'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec']['meta_info']


                                    class BmpServerLastDisconTime(object):
                                        """
                                        Timespec of Last Disconnect event received from
                                        BMP server
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-server-last-discon-time'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime']['meta_info']


                                    class UpdateSourceAddress(object):
                                        """
                                        Address of Interface configured as Update Source
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-source-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress']['meta_info']


                                    class BmpSendVersion(object):
                                        """
                                        Table Version that this BMP server has caught
                                        
                                        upto
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.entry = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-send-version'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.entry is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpSendVersion']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.server_id is None:
                                            raise YPYModelError('Key property server_id is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:server-summary[Cisco-IOS-XR-ipv4-bgp-oper:server-id = ' + str(self.server_id) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.server_id is not None:
                                            return True

                                        if self.bmp_bytes_written_tcp is not None:
                                            return True

                                        if self.bmp_init_msg_count is not None:
                                            return True

                                        if self.bmp_messages_wdraw_discarded is not None:
                                            return True

                                        if self.bmp_peer_msg_drop_count is not None:
                                            return True

                                        if self.bmp_peer_msg_pending_count is not None:
                                            return True

                                        if self.bmp_peer_msg_pending_count_hwts is not None:
                                            return True

                                        if self.bmp_peer_msg_pending_count_max is not None:
                                            return True

                                        if self.bmp_per_peer_msg_count is not None:
                                            return True

                                        if self.bmp_per_peer_msg_route_mon_count is not None:
                                            return True

                                        if self.bmp_pfx_wdraw_discarded is not None:
                                            return True

                                        if self.bmp_send_version is not None:
                                            for child_ref in self.bmp_send_version:
                                                if child_ref._has_data():
                                                    return True

                                        if self.bmp_server_host_name is not None:
                                            return True

                                        if self.bmp_server_id is not None:
                                            return True

                                        if self.bmp_server_is_flapping is not None:
                                            return True

                                        if self.bmp_server_last_discon_time is not None and self.bmp_server_last_discon_time._has_data():
                                            return True

                                        if self.bmp_server_nbr_count is not None:
                                            return True

                                        if self.bmp_server_port is not None:
                                            return True

                                        if self.bmp_server_state is not None:
                                            return True

                                        if self.bmp_server_state_age is not None and self.bmp_server_state_age._has_data():
                                            return True

                                        if self.bmp_server_state_time_spec is not None and self.bmp_server_state_time_spec._has_data():
                                            return True

                                        if self.bmp_status_report_count is not None:
                                            return True

                                        if self.bmp_termination_msg_count is not None:
                                            return True

                                        if self.bmp_update_mode is not None:
                                            return True

                                        if self.bmp_vrf_id is not None:
                                            return True

                                        if self.bmp_vrf_name is not None:
                                            return True

                                        if self.bmpq_last_all_write_pulse_sent_time is not None:
                                            return True

                                        if self.bmpq_last_write_pulse_cb_time is not None:
                                            return True

                                        if self.bmpq_last_write_pulse_sent_time is not None:
                                            return True

                                        if self.bmpr_mon_upd_messages is not None:
                                            return True

                                        if self.bmpr_mon_update_gen_time is not None:
                                            return True

                                        if self.bmpr_mon_wdraw_messages is not None:
                                            return True

                                        if self.path_update_count is not None:
                                            return True

                                        if self.path_update_drop is not None:
                                            return True

                                        if self.path_withdraw_count is not None:
                                            return True

                                        if self.path_withdraw_drop is not None:
                                            return True

                                        if self.tcp_keep_alive_interval is not None:
                                            return True

                                        if self.tcp_last_write_cb_time is not None:
                                            return True

                                        if self.tcp_last_write_result is not None:
                                            return True

                                        if self.tcp_last_write_time is not None:
                                            return True

                                        if self.tcp_maximum_segment_size is not None:
                                            return True

                                        if self.tcp_write_cb_pending is not None:
                                            return True

                                        if self.tcp_write_time is not None:
                                            return True

                                        if self.tos_type is not None:
                                            return True

                                        if self.tos_value is not None:
                                            return True

                                        if self.update_source_address is not None and self.update_source_address._has_data():
                                            return True

                                        if self.update_source_interface_name is not None:
                                            return True

                                        if self.update_source_vrf_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:server-summaries'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.server_summary is not None:
                                        for child_ref in self.server_summary:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries']['meta_info']


                            class ServerNeighbors(object):
                                """
                                Table of Neighbors for a BMP Server
                                
                                .. attribute:: server_neighbor
                                
                                	BMP Server under which neighbor info are needed
                                	**type**\: list of    :py:class:`ServerNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.server_neighbor = YList()
                                    self.server_neighbor.parent = self
                                    self.server_neighbor.name = 'server_neighbor'


                                class ServerNeighbor(object):
                                    """
                                    BMP Server under which neighbor info are
                                    needed
                                    
                                    .. attribute:: server_id  <key>
                                    
                                    	BMP Server ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: monitored_neighbors
                                    
                                    	List of Neighbors under which BMP Server is confgiured
                                    	**type**\:   :py:class:`MonitoredNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.server_id = None
                                        self.monitored_neighbors = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors()
                                        self.monitored_neighbors.parent = self


                                    class MonitoredNeighbors(object):
                                        """
                                        List of Neighbors under which BMP Server is
                                        confgiured
                                        
                                        .. attribute:: monitored_neighbor
                                        
                                        	Information about a neighbor monitored by BMP server
                                        	**type**\: list of    :py:class:`MonitoredNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.monitored_neighbor = YList()
                                            self.monitored_neighbor.parent = self
                                            self.monitored_neighbor.name = 'monitored_neighbor'


                                        class MonitoredNeighbor(object):
                                            """
                                            Information about a neighbor monitored by
                                            BMP server
                                            
                                            .. attribute:: neighbor_address  <key>
                                            
                                            	Neighbor address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bmp_neighbor_address
                                            
                                            	Address of Nbr that logs to BMP server
                                            	**type**\:   :py:class:`BmpNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress>`
                                            
                                            .. attribute:: bmp_neighbor_msg_dropped
                                            
                                            	Number of messages dropped sent from this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_msg_pending
                                            
                                            	Number of messages pending to be sent to BMP Server from this Neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_path_update_drop
                                            
                                            	Number of path update drop 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_path_update_sent
                                            
                                            	Number of Path UpdateMessages sent
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_path_withdraw_drop
                                            
                                            	Number of path wdraw drop 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_path_withdraw_sent
                                            
                                            	Number of Path WithdrawMessages sent
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_peer_down_sent
                                            
                                            	Number of Peer DOWN Messages sent from this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_peer_up_sent
                                            
                                            	Number of Peer UP Messages sent from this neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_route_monitor_sent
                                            
                                            	Number of Route Monitor Messages sent
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_upd_msg_sent
                                            
                                            	Number of update message sent
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_wdraw_msg_sent
                                            
                                            	Number of withdraw message sent
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.neighbor_address = None
                                                self.bmp_neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress()
                                                self.bmp_neighbor_address.parent = self
                                                self.bmp_neighbor_msg_dropped = None
                                                self.bmp_neighbor_msg_pending = None
                                                self.bmp_neighbor_path_update_drop = None
                                                self.bmp_neighbor_path_update_sent = None
                                                self.bmp_neighbor_path_withdraw_drop = None
                                                self.bmp_neighbor_path_withdraw_sent = None
                                                self.bmp_neighbor_peer_down_sent = None
                                                self.bmp_neighbor_peer_up_sent = None
                                                self.bmp_neighbor_route_monitor_sent = None
                                                self.bmp_neighbor_upd_msg_sent = None
                                                self.bmp_neighbor_wdraw_msg_sent = None


                                            class BmpNeighborAddress(object):
                                                """
                                                Address of Nbr that logs to BMP server
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.neighbor_address is None:
                                                    raise YPYModelError('Key property neighbor_address is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:monitored-neighbor[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address = ' + str(self.neighbor_address) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.neighbor_address is not None:
                                                    return True

                                                if self.bmp_neighbor_address is not None and self.bmp_neighbor_address._has_data():
                                                    return True

                                                if self.bmp_neighbor_msg_dropped is not None:
                                                    return True

                                                if self.bmp_neighbor_msg_pending is not None:
                                                    return True

                                                if self.bmp_neighbor_path_update_drop is not None:
                                                    return True

                                                if self.bmp_neighbor_path_update_sent is not None:
                                                    return True

                                                if self.bmp_neighbor_path_withdraw_drop is not None:
                                                    return True

                                                if self.bmp_neighbor_path_withdraw_sent is not None:
                                                    return True

                                                if self.bmp_neighbor_peer_down_sent is not None:
                                                    return True

                                                if self.bmp_neighbor_peer_up_sent is not None:
                                                    return True

                                                if self.bmp_neighbor_route_monitor_sent is not None:
                                                    return True

                                                if self.bmp_neighbor_upd_msg_sent is not None:
                                                    return True

                                                if self.bmp_neighbor_wdraw_msg_sent is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:monitored-neighbors'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.monitored_neighbor is not None:
                                                for child_ref in self.monitored_neighbor:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.server_id is None:
                                            raise YPYModelError('Key property server_id is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:server-neighbor[Cisco-IOS-XR-ipv4-bgp-oper:server-id = ' + str(self.server_id) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.server_id is not None:
                                            return True

                                        if self.monitored_neighbors is not None and self.monitored_neighbors._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:server-neighbors'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.server_neighbor is not None:
                                        for child_ref in self.server_neighbor:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.server_neighbors is not None and self.server_neighbors._has_data():
                                    return True

                                if self.server_summaries is not None and self.server_summaries._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp']['meta_info']


                        class ProcessInfo(object):
                            """
                            A Process instance table entry
                            
                            .. attribute:: global_
                            
                            	Global information
                            	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_>`
                            
                            .. attribute:: performance_statistics
                            
                            	Performance statistics
                            	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics>`
                            
                            .. attribute:: process_instance
                            
                            	ID for the BGP process instance
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:   :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Vrf_>`
                            
                            .. attribute:: vrf_name
                            
                            	Name of the VRF
                            	**type**\:  str
                            
                            .. attribute:: vrf_totals
                            
                            	per VRF counts aggregated across all VRFs
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.global_ = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_()
                                self.global_.parent = self
                                self.performance_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics()
                                self.performance_statistics.parent = self
                                self.process_instance = None
                                self.vrf = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Vrf_()
                                self.vrf.parent = self
                                self.vrf_name = None
                                self.vrf_totals = None


                            class Global_(object):
                                """
                                Global information
                                
                                .. attribute:: as_path_entries_memory
                                
                                	Memory (in bytes) used by AS\-path entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: as_path_entry_count
                                
                                	Number of AS\-path entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: attr_set_entry_count
                                
                                	Number of ATTRSET entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: attr_set_memory
                                
                                	Memory (in bytes) used by ATTRSET entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: bmp_pool_alloc_count
                                
                                	bmp pool alloc count
                                	**type**\: list of    :py:class:`BmpPoolAllocCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.BmpPoolAllocCount>`
                                
                                .. attribute:: bmp_pool_free_count
                                
                                	bmp pool free count
                                	**type**\: list of    :py:class:`BmpPoolFreeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.BmpPoolFreeCount>`
                                
                                .. attribute:: bmp_pool_size
                                
                                	bmp pool size
                                	**type**\: list of    :py:class:`BmpPoolSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.BmpPoolSize>`
                                
                                .. attribute:: community_entry_count
                                
                                	Number of community entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: community_memory
                                
                                	Memory (in bytes) used by community entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: established_neighbors_count_total
                                
                                	Total umber of established neighbors
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: extended_community_entry_count
                                
                                	Number of extended community entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: extended_community_memory
                                
                                	Memory (in bytes) used by extended community entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: lindex_entry_count
                                
                                	Number of LINDEX entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lindex_memory
                                
                                	Memory (in bytes) used by LINDEX entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: local_as
                                
                                	Local autonomous system number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsattr_entry_count
                                
                                	Number of LASATTR entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsattr_memory
                                
                                	Memory (in bytes) used by LSATTR entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: msg_log_pool_alloc_count
                                
                                	msg log pool alloc count
                                	**type**\: list of    :py:class:`MsgLogPoolAllocCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.MsgLogPoolAllocCount>`
                                
                                .. attribute:: msg_log_pool_free_count
                                
                                	msg log pool free count
                                	**type**\: list of    :py:class:`MsgLogPoolFreeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.MsgLogPoolFreeCount>`
                                
                                .. attribute:: msg_log_pool_size
                                
                                	msg log pool size
                                	**type**\: list of    :py:class:`MsgLogPoolSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.MsgLogPoolSize>`
                                
                                .. attribute:: neighbors_count_total
                                
                                	Total number of neighbors
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nexthop_count
                                
                                	Number of nexthop attribute info entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nexthop_memory
                                
                                	Memory (in bytes) used by nexthop attribute info entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: path_attribute_memory
                                
                                	Memory (bytes) used by path attribute entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: path_attributes_entry_count
                                
                                	No. of path attribute entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pe_distinguisher_label_entry_count
                                
                                	Number of PE distinguisher label entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pe_distinguisher_label_memory
                                
                                	Memory (in bytes) used by PE distinguisher labels entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: pool_alloc_count
                                
                                	pool alloc count
                                	**type**\: list of    :py:class:`PoolAllocCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.PoolAllocCount>`
                                
                                .. attribute:: pool_free_count
                                
                                	pool free count
                                	**type**\: list of    :py:class:`PoolFreeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.PoolFreeCount>`
                                
                                .. attribute:: pool_size
                                
                                	pool size
                                	**type**\: list of    :py:class:`PoolSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.PoolSize>`
                                
                                .. attribute:: ppmp_entry_count
                                
                                	Number of PPMP entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ppmp_memory
                                
                                	Memory (in bytes) used by PPMP entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: process_instance_node
                                
                                	Node the process instance is on
                                	**type**\:  str
                                
                                .. attribute:: pta_entry_count
                                
                                	Number of PTA entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pta_memory
                                
                                	Memory (in bytes) used by PTA entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: restart_count
                                
                                	No. of times BGP has started
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ribrnh_entry_count
                                
                                	Number of RIBRNH entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ribrnh_memory
                                
                                	Memory (in bytes) used by RIBRNH entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: route_reflector_memory
                                
                                	Memory (in bytes) used by route reflector info entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: route_reflectors
                                
                                	Number of route reflector info entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sn_num_non_dflt_vrf_nbrs
                                
                                	sn num non dflt vrf nbrs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sn_num_non_dflt_vrf_nbrs_estab
                                
                                	sn num non dflt vrf nbrs estab
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_vrf_count
                                
                                	total vrf count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tunnel_encap_entry_count
                                
                                	Number of Tunnel encap entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tunnel_encap_memory
                                
                                	Memory (in bytes) used by tunnel encap entries
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.as_path_entries_memory = None
                                    self.as_path_entry_count = None
                                    self.attr_set_entry_count = None
                                    self.attr_set_memory = None
                                    self.bmp_pool_alloc_count = YList()
                                    self.bmp_pool_alloc_count.parent = self
                                    self.bmp_pool_alloc_count.name = 'bmp_pool_alloc_count'
                                    self.bmp_pool_free_count = YList()
                                    self.bmp_pool_free_count.parent = self
                                    self.bmp_pool_free_count.name = 'bmp_pool_free_count'
                                    self.bmp_pool_size = YList()
                                    self.bmp_pool_size.parent = self
                                    self.bmp_pool_size.name = 'bmp_pool_size'
                                    self.community_entry_count = None
                                    self.community_memory = None
                                    self.established_neighbors_count_total = None
                                    self.extended_community_entry_count = None
                                    self.extended_community_memory = None
                                    self.lindex_entry_count = None
                                    self.lindex_memory = None
                                    self.local_as = None
                                    self.lsattr_entry_count = None
                                    self.lsattr_memory = None
                                    self.msg_log_pool_alloc_count = YList()
                                    self.msg_log_pool_alloc_count.parent = self
                                    self.msg_log_pool_alloc_count.name = 'msg_log_pool_alloc_count'
                                    self.msg_log_pool_free_count = YList()
                                    self.msg_log_pool_free_count.parent = self
                                    self.msg_log_pool_free_count.name = 'msg_log_pool_free_count'
                                    self.msg_log_pool_size = YList()
                                    self.msg_log_pool_size.parent = self
                                    self.msg_log_pool_size.name = 'msg_log_pool_size'
                                    self.neighbors_count_total = None
                                    self.nexthop_count = None
                                    self.nexthop_memory = None
                                    self.path_attribute_memory = None
                                    self.path_attributes_entry_count = None
                                    self.pe_distinguisher_label_entry_count = None
                                    self.pe_distinguisher_label_memory = None
                                    self.pool_alloc_count = YList()
                                    self.pool_alloc_count.parent = self
                                    self.pool_alloc_count.name = 'pool_alloc_count'
                                    self.pool_free_count = YList()
                                    self.pool_free_count.parent = self
                                    self.pool_free_count.name = 'pool_free_count'
                                    self.pool_size = YList()
                                    self.pool_size.parent = self
                                    self.pool_size.name = 'pool_size'
                                    self.ppmp_entry_count = None
                                    self.ppmp_memory = None
                                    self.process_instance_node = None
                                    self.pta_entry_count = None
                                    self.pta_memory = None
                                    self.restart_count = None
                                    self.ribrnh_entry_count = None
                                    self.ribrnh_memory = None
                                    self.route_reflector_memory = None
                                    self.route_reflectors = None
                                    self.sn_num_non_dflt_vrf_nbrs = None
                                    self.sn_num_non_dflt_vrf_nbrs_estab = None
                                    self.total_vrf_count = None
                                    self.tunnel_encap_entry_count = None
                                    self.tunnel_encap_memory = None


                                class PoolSize(object):
                                    """
                                    pool size
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pool-size'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.PoolSize']['meta_info']


                                class PoolAllocCount(object):
                                    """
                                    pool alloc count
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pool-alloc-count'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.PoolAllocCount']['meta_info']


                                class PoolFreeCount(object):
                                    """
                                    pool free count
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pool-free-count'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.PoolFreeCount']['meta_info']


                                class MsgLogPoolSize(object):
                                    """
                                    msg log pool size
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:msg-log-pool-size'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.MsgLogPoolSize']['meta_info']


                                class MsgLogPoolAllocCount(object):
                                    """
                                    msg log pool alloc count
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:msg-log-pool-alloc-count'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.MsgLogPoolAllocCount']['meta_info']


                                class MsgLogPoolFreeCount(object):
                                    """
                                    msg log pool free count
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:msg-log-pool-free-count'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.MsgLogPoolFreeCount']['meta_info']


                                class BmpPoolSize(object):
                                    """
                                    bmp pool size
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-pool-size'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.BmpPoolSize']['meta_info']


                                class BmpPoolAllocCount(object):
                                    """
                                    bmp pool alloc count
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-pool-alloc-count'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.BmpPoolAllocCount']['meta_info']


                                class BmpPoolFreeCount(object):
                                    """
                                    bmp pool free count
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-pool-free-count'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_.BmpPoolFreeCount']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:global'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.as_path_entries_memory is not None:
                                        return True

                                    if self.as_path_entry_count is not None:
                                        return True

                                    if self.attr_set_entry_count is not None:
                                        return True

                                    if self.attr_set_memory is not None:
                                        return True

                                    if self.bmp_pool_alloc_count is not None:
                                        for child_ref in self.bmp_pool_alloc_count:
                                            if child_ref._has_data():
                                                return True

                                    if self.bmp_pool_free_count is not None:
                                        for child_ref in self.bmp_pool_free_count:
                                            if child_ref._has_data():
                                                return True

                                    if self.bmp_pool_size is not None:
                                        for child_ref in self.bmp_pool_size:
                                            if child_ref._has_data():
                                                return True

                                    if self.community_entry_count is not None:
                                        return True

                                    if self.community_memory is not None:
                                        return True

                                    if self.established_neighbors_count_total is not None:
                                        return True

                                    if self.extended_community_entry_count is not None:
                                        return True

                                    if self.extended_community_memory is not None:
                                        return True

                                    if self.lindex_entry_count is not None:
                                        return True

                                    if self.lindex_memory is not None:
                                        return True

                                    if self.local_as is not None:
                                        return True

                                    if self.lsattr_entry_count is not None:
                                        return True

                                    if self.lsattr_memory is not None:
                                        return True

                                    if self.msg_log_pool_alloc_count is not None:
                                        for child_ref in self.msg_log_pool_alloc_count:
                                            if child_ref._has_data():
                                                return True

                                    if self.msg_log_pool_free_count is not None:
                                        for child_ref in self.msg_log_pool_free_count:
                                            if child_ref._has_data():
                                                return True

                                    if self.msg_log_pool_size is not None:
                                        for child_ref in self.msg_log_pool_size:
                                            if child_ref._has_data():
                                                return True

                                    if self.neighbors_count_total is not None:
                                        return True

                                    if self.nexthop_count is not None:
                                        return True

                                    if self.nexthop_memory is not None:
                                        return True

                                    if self.path_attribute_memory is not None:
                                        return True

                                    if self.path_attributes_entry_count is not None:
                                        return True

                                    if self.pe_distinguisher_label_entry_count is not None:
                                        return True

                                    if self.pe_distinguisher_label_memory is not None:
                                        return True

                                    if self.pool_alloc_count is not None:
                                        for child_ref in self.pool_alloc_count:
                                            if child_ref._has_data():
                                                return True

                                    if self.pool_free_count is not None:
                                        for child_ref in self.pool_free_count:
                                            if child_ref._has_data():
                                                return True

                                    if self.pool_size is not None:
                                        for child_ref in self.pool_size:
                                            if child_ref._has_data():
                                                return True

                                    if self.ppmp_entry_count is not None:
                                        return True

                                    if self.ppmp_memory is not None:
                                        return True

                                    if self.process_instance_node is not None:
                                        return True

                                    if self.pta_entry_count is not None:
                                        return True

                                    if self.pta_memory is not None:
                                        return True

                                    if self.restart_count is not None:
                                        return True

                                    if self.ribrnh_entry_count is not None:
                                        return True

                                    if self.ribrnh_memory is not None:
                                        return True

                                    if self.route_reflector_memory is not None:
                                        return True

                                    if self.route_reflectors is not None:
                                        return True

                                    if self.sn_num_non_dflt_vrf_nbrs is not None:
                                        return True

                                    if self.sn_num_non_dflt_vrf_nbrs_estab is not None:
                                        return True

                                    if self.total_vrf_count is not None:
                                        return True

                                    if self.tunnel_encap_entry_count is not None:
                                        return True

                                    if self.tunnel_encap_memory is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global_']['meta_info']


                            class Vrf_(object):
                                """
                                VRF information
                                
                                .. attribute:: established_neighbors_count
                                
                                	Number of established neighbors
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbors_count
                                
                                	Number of neighbors
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: network_count
                                
                                	Number of networks
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: notifications_received
                                
                                	No. of notifications received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: notifications_sent
                                
                                	No. of notifications sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_count
                                
                                	Number of paths
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_messages_received
                                
                                	Number of update messages received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_messages_sent
                                
                                	No. of update messages sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.established_neighbors_count = None
                                    self.neighbors_count = None
                                    self.network_count = None
                                    self.notifications_received = None
                                    self.notifications_sent = None
                                    self.path_count = None
                                    self.update_messages_received = None
                                    self.update_messages_sent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:vrf'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.established_neighbors_count is not None:
                                        return True

                                    if self.neighbors_count is not None:
                                        return True

                                    if self.network_count is not None:
                                        return True

                                    if self.notifications_received is not None:
                                        return True

                                    if self.notifications_sent is not None:
                                        return True

                                    if self.path_count is not None:
                                        return True

                                    if self.update_messages_received is not None:
                                        return True

                                    if self.update_messages_sent is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Vrf_']['meta_info']


                            class PerformanceStatistics(object):
                                """
                                Performance statistics
                                
                                .. attribute:: global_
                                
                                	Global information
                                	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_>`
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:   :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Vrf_>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.global_ = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_()
                                    self.global_.parent = self
                                    self.vrf = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Vrf_()
                                    self.vrf.parent = self


                                class Global_(object):
                                    """
                                    Global information
                                    
                                    .. attribute:: active_nsr_mode_enter_time
                                    
                                    	Time that each mode was entered (seconds since  Jan 1 1970)
                                    	**type**\: list of    :py:class:`ActiveNsrModeEnterTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrModeEnterTime>`
                                    
                                    .. attribute:: active_nsr_state
                                    
                                    	Current Active BGP nsrstate
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: active_nsrfo_time
                                    
                                    	Time that each thread isdone with its  go\-activeprocessing (seconds since Jan 1 1970)
                                    	**type**\: list of    :py:class:`ActiveNsrfoTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrfoTime>`
                                    
                                    .. attribute:: active_nsrtcp_phase_two_enter_time
                                    
                                    	Time that NSR TCP Init Sync Phase Two entered on active (seconds since Jan 1 1970)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: bgp_te_infra_tunnel_type
                                    
                                    	BGP TE infra tunnel type
                                    	**type**\:   :py:class:`BgpTeInfraTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTeInfraTunnelEnum>`
                                    
                                    .. attribute:: brib_api_input_bytes
                                    
                                    	bRIB API input bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: brib_api_input_messages
                                    
                                    	bRIB API input messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_input_prefixes_received
                                    
                                    	bRIB API input advertised prefixes received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_input_processing_time
                                    
                                    	Time spent processing input from bRIB API (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: brib_api_input_withdrawn_prefixes
                                    
                                    	bRIB API input withdrawn prefixes received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_output_bytes_generated
                                    
                                    	bRIB API output bytes generated
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: brib_api_output_bytes_sent
                                    
                                    	bRIB API output bytes sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: brib_api_output_calls
                                    
                                    	bRIB API calls to generate output
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_output_generation_time
                                    
                                    	Time spent generating output for bRIB API (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: brib_api_output_messages_sent
                                    
                                    	bRIB API output messages sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_output_prefixes_advertised
                                    
                                    	bRIB API output prefixes advertised
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_output_prefixes_withdrawn
                                    
                                    	bRIB API output prefixes withdrawn
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_output_sending_time
                                    
                                    	Time spent sending output to bRIB API (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: configuration_items_processed
                                    
                                    	Number of config items processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: configuration_processing_time
                                    
                                    	Time spent processing config (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: current_clock_time
                                    
                                    	Current time
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: ds_npl
                                    
                                    	NSR related DS and NPL information
                                    	**type**\:   :py:class:`DsNpl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl>`
                                    
                                    .. attribute:: edm_processing_time
                                    
                                    	Time spent processing EDM requests (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: edm_requests_count
                                    
                                    	Number of EDM requests processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: in_event_attach_calls
                                    
                                    	event\_file\_attach  calls for input
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: in_out_event_attach_calls
                                    
                                    	event\_file\_attach calls for input
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: initial_sync_sessions_added
                                    
                                    	If true, BGP has at least one established session when NSR initial synchronization is started
                                    	**type**\:  bool
                                    
                                    .. attribute:: instance_node_role
                                    
                                    	Node role \- active/passive
                                    	**type**\:  bool
                                    
                                    .. attribute:: io_handler_tm
                                    
                                    	Timestamp when IO timer handler got called
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: io_timer_id
                                    
                                    	IO master timer ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: io_tree_timer_expiry
                                    
                                    	Time as per tree\->mtexptime
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: io_tree_timer_left
                                    
                                    	Time left before the QNX timer would expire
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: ipv4rib_server
                                    
                                    	IPv4 RIB server global info
                                    	**type**\:   :py:class:`Ipv4RibServer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer>`
                                    
                                    .. attribute:: ipv6rib_server
                                    
                                    	IPv6 RIB server global info
                                    	**type**\:   :py:class:`Ipv6RibServer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer>`
                                    
                                    .. attribute:: issu_milestone
                                    
                                    	ISSU Milestones
                                    	**type**\: list of    :py:class:`IssuMilestone <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.IssuMilestone>`
                                    
                                    .. attribute:: issu_milestone_packed
                                    
                                    	Flag to indicate ISSU Milestones packed
                                    	**type**\:  bool
                                    
                                    .. attribute:: lsd_connection
                                    
                                    	MPLS LSD server connection info
                                    	**type**\:   :py:class:`LsdConnection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection>`
                                    
                                    .. attribute:: nsr_last_reset_reason
                                    
                                    	Reason for last nsr state  machine reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: out_event_attach_calls
                                    
                                    	event\_file\_attach  calls for output
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: postit_count_info
                                    
                                    	List of neighbors and their postit counts
                                    	**type**\: list of    :py:class:`PostitCountInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo>`
                                    
                                    .. attribute:: proc_scoped_sync_state
                                    
                                    	BGP scoped sync state
                                    	**type**\:   :py:class:`BgpScopedSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpScopedSyncStateEnum>`
                                    
                                    .. attribute:: qad_ac_ks_failure
                                    
                                    	Ack failure on QAD 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_ac_ks_received
                                    
                                    	Acks received on QAD 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_init_drops
                                    
                                    	Packets dropped on standby during initialization
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_messages_received
                                    
                                    	Messages received on QAD 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_messages_sent
                                    
                                    	Messages sent on QAD 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_processed
                                    
                                    	Messages processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_recv_drops
                                    
                                    	Received packet dropped due to null peer 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_resumes
                                    
                                    	QAD send resume 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_send_drops
                                    
                                    	Send packets dropped due to null peer 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_send_failure
                                    
                                    	Send failure on QAD 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_suspends
                                    
                                    	QAD send suspend
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_timeout_received
                                    
                                    	Timeouts received on QAD 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_timeout_recvd
                                    
                                    	Number of packet send timeouts 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qadack_sent
                                    
                                    	Acks sent on QAD 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qadoos_drops
                                    
                                    	Packets dropped due to  out of sequence packetreceived
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: redcon_nsr_ready
                                    
                                    	NSR state conveyed to Redcon  by bgp \- nsr ready/unready
                                    	**type**\:  bool
                                    
                                    .. attribute:: redcon_state_time
                                    
                                    	Time when nsr state wasconveyed to Redcon last
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sec_active_nsr_state
                                    
                                    	Current Sec Active BGP nsrstate
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sec_active_nsrtcp_phase_two_enter_time
                                    
                                    	Time that NSR TCP Init Sync Phase Two entered on active (seconds since Jan 1 1970)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: standby_nsr_mode_enter_time
                                    
                                    	Time that each mode was entered (seconds since  Jan 1 1970)
                                    	**type**\: list of    :py:class:`StandbyNsrModeEnterTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.StandbyNsrModeEnterTime>`
                                    
                                    .. attribute:: te_connection
                                    
                                    	MPLS TE server connection info
                                    	**type**\:   :py:class:`TeConnection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection>`
                                    
                                    .. attribute:: tep2p_auto_tunnel_enabled
                                    
                                    	TE support for P2P auto tunnel
                                    	**type**\:  bool
                                    
                                    .. attribute:: total_neighbors_with_pending_postits
                                    
                                    	Total nbrs with pending postits
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_outstanding_postits
                                    
                                    	Total outstanding postits across all neighbors
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: updgen_handler_tm
                                    
                                    	Timestamp when updgen timer handler got called
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: updgen_timer_id
                                    
                                    	Updgen master timer ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: updgen_tree_timer_expiry
                                    
                                    	Time as per tree\->mtexptime
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: updgen_tree_timer_left
                                    
                                    	Time left before the QNX timer would expire
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.active_nsr_mode_enter_time = YList()
                                        self.active_nsr_mode_enter_time.parent = self
                                        self.active_nsr_mode_enter_time.name = 'active_nsr_mode_enter_time'
                                        self.active_nsr_state = None
                                        self.active_nsrfo_time = YList()
                                        self.active_nsrfo_time.parent = self
                                        self.active_nsrfo_time.name = 'active_nsrfo_time'
                                        self.active_nsrtcp_phase_two_enter_time = None
                                        self.bgp_te_infra_tunnel_type = None
                                        self.brib_api_input_bytes = None
                                        self.brib_api_input_messages = None
                                        self.brib_api_input_prefixes_received = None
                                        self.brib_api_input_processing_time = None
                                        self.brib_api_input_withdrawn_prefixes = None
                                        self.brib_api_output_bytes_generated = None
                                        self.brib_api_output_bytes_sent = None
                                        self.brib_api_output_calls = None
                                        self.brib_api_output_generation_time = None
                                        self.brib_api_output_messages_sent = None
                                        self.brib_api_output_prefixes_advertised = None
                                        self.brib_api_output_prefixes_withdrawn = None
                                        self.brib_api_output_sending_time = None
                                        self.configuration_items_processed = None
                                        self.configuration_processing_time = None
                                        self.current_clock_time = None
                                        self.ds_npl = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl()
                                        self.ds_npl.parent = self
                                        self.edm_processing_time = None
                                        self.edm_requests_count = None
                                        self.in_event_attach_calls = None
                                        self.in_out_event_attach_calls = None
                                        self.initial_sync_sessions_added = None
                                        self.instance_node_role = None
                                        self.io_handler_tm = None
                                        self.io_timer_id = None
                                        self.io_tree_timer_expiry = None
                                        self.io_tree_timer_left = None
                                        self.ipv4rib_server = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer()
                                        self.ipv4rib_server.parent = self
                                        self.ipv6rib_server = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer()
                                        self.ipv6rib_server.parent = self
                                        self.issu_milestone = YList()
                                        self.issu_milestone.parent = self
                                        self.issu_milestone.name = 'issu_milestone'
                                        self.issu_milestone_packed = None
                                        self.lsd_connection = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection()
                                        self.lsd_connection.parent = self
                                        self.nsr_last_reset_reason = None
                                        self.out_event_attach_calls = None
                                        self.postit_count_info = YList()
                                        self.postit_count_info.parent = self
                                        self.postit_count_info.name = 'postit_count_info'
                                        self.proc_scoped_sync_state = None
                                        self.qad_ac_ks_failure = None
                                        self.qad_ac_ks_received = None
                                        self.qad_init_drops = None
                                        self.qad_messages_received = None
                                        self.qad_messages_sent = None
                                        self.qad_processed = None
                                        self.qad_recv_drops = None
                                        self.qad_resumes = None
                                        self.qad_send_drops = None
                                        self.qad_send_failure = None
                                        self.qad_suspends = None
                                        self.qad_timeout_received = None
                                        self.qad_timeout_recvd = None
                                        self.qadack_sent = None
                                        self.qadoos_drops = None
                                        self.redcon_nsr_ready = None
                                        self.redcon_state_time = None
                                        self.sec_active_nsr_state = None
                                        self.sec_active_nsrtcp_phase_two_enter_time = None
                                        self.standby_nsr_mode_enter_time = YList()
                                        self.standby_nsr_mode_enter_time.parent = self
                                        self.standby_nsr_mode_enter_time.name = 'standby_nsr_mode_enter_time'
                                        self.te_connection = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection()
                                        self.te_connection.parent = self
                                        self.tep2p_auto_tunnel_enabled = None
                                        self.total_neighbors_with_pending_postits = None
                                        self.total_outstanding_postits = None
                                        self.updgen_handler_tm = None
                                        self.updgen_timer_id = None
                                        self.updgen_tree_timer_expiry = None
                                        self.updgen_tree_timer_left = None


                                    class Ipv4RibServer(object):
                                        """
                                        IPv4 RIB server global info
                                        
                                        .. attribute:: first_rib_connection_down_timestamp
                                        
                                        	First RIB connection Down event timestamp
                                        	**type**\:   :py:class:`FirstRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionDownTimestamp>`
                                        
                                        .. attribute:: first_rib_connection_up_timestamp
                                        
                                        	First RIB connection Up event timestamp
                                        	**type**\:   :py:class:`FirstRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionUpTimestamp>`
                                        
                                        .. attribute:: is_rib_connection_up
                                        
                                        	Is RIB Connection Up?
                                        	**type**\:  bool
                                        
                                        .. attribute:: last_rib_connection_down_age
                                        
                                        	Time since last RIB connection Down event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_rib_connection_down_timestamp
                                        
                                        	Last RIB connection Down event timestamp
                                        	**type**\:   :py:class:`LastRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionDownTimestamp>`
                                        
                                        .. attribute:: last_rib_connection_up_age
                                        
                                        	Time since last RIB connection Up event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_rib_connection_up_timestamp
                                        
                                        	Last RIB connection Up event timestamp
                                        	**type**\:   :py:class:`LastRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionUpTimestamp>`
                                        
                                        .. attribute:: rib_connection_down_count
                                        
                                        	Number of RIB connection Down events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_connection_up_count
                                        
                                        	Number of RIB connection Up events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.first_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionDownTimestamp()
                                            self.first_rib_connection_down_timestamp.parent = self
                                            self.first_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionUpTimestamp()
                                            self.first_rib_connection_up_timestamp.parent = self
                                            self.is_rib_connection_up = None
                                            self.last_rib_connection_down_age = None
                                            self.last_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionDownTimestamp()
                                            self.last_rib_connection_down_timestamp.parent = self
                                            self.last_rib_connection_up_age = None
                                            self.last_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionUpTimestamp()
                                            self.last_rib_connection_up_timestamp.parent = self
                                            self.rib_connection_down_count = None
                                            self.rib_connection_up_count = None


                                        class FirstRibConnectionUpTimestamp(object):
                                            """
                                            First RIB connection Up event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-rib-connection-up-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionUpTimestamp']['meta_info']


                                        class LastRibConnectionUpTimestamp(object):
                                            """
                                            Last RIB connection Up event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-rib-connection-up-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionUpTimestamp']['meta_info']


                                        class FirstRibConnectionDownTimestamp(object):
                                            """
                                            First RIB connection Down event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-rib-connection-down-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionDownTimestamp']['meta_info']


                                        class LastRibConnectionDownTimestamp(object):
                                            """
                                            Last RIB connection Down event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-rib-connection-down-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionDownTimestamp']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4rib-server'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.first_rib_connection_down_timestamp is not None and self.first_rib_connection_down_timestamp._has_data():
                                                return True

                                            if self.first_rib_connection_up_timestamp is not None and self.first_rib_connection_up_timestamp._has_data():
                                                return True

                                            if self.is_rib_connection_up is not None:
                                                return True

                                            if self.last_rib_connection_down_age is not None:
                                                return True

                                            if self.last_rib_connection_down_timestamp is not None and self.last_rib_connection_down_timestamp._has_data():
                                                return True

                                            if self.last_rib_connection_up_age is not None:
                                                return True

                                            if self.last_rib_connection_up_timestamp is not None and self.last_rib_connection_up_timestamp._has_data():
                                                return True

                                            if self.rib_connection_down_count is not None:
                                                return True

                                            if self.rib_connection_up_count is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer']['meta_info']


                                    class Ipv6RibServer(object):
                                        """
                                        IPv6 RIB server global info
                                        
                                        .. attribute:: first_rib_connection_down_timestamp
                                        
                                        	First RIB connection Down event timestamp
                                        	**type**\:   :py:class:`FirstRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionDownTimestamp>`
                                        
                                        .. attribute:: first_rib_connection_up_timestamp
                                        
                                        	First RIB connection Up event timestamp
                                        	**type**\:   :py:class:`FirstRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionUpTimestamp>`
                                        
                                        .. attribute:: is_rib_connection_up
                                        
                                        	Is RIB Connection Up?
                                        	**type**\:  bool
                                        
                                        .. attribute:: last_rib_connection_down_age
                                        
                                        	Time since last RIB connection Down event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_rib_connection_down_timestamp
                                        
                                        	Last RIB connection Down event timestamp
                                        	**type**\:   :py:class:`LastRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionDownTimestamp>`
                                        
                                        .. attribute:: last_rib_connection_up_age
                                        
                                        	Time since last RIB connection Up event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_rib_connection_up_timestamp
                                        
                                        	Last RIB connection Up event timestamp
                                        	**type**\:   :py:class:`LastRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionUpTimestamp>`
                                        
                                        .. attribute:: rib_connection_down_count
                                        
                                        	Number of RIB connection Down events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_connection_up_count
                                        
                                        	Number of RIB connection Up events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.first_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionDownTimestamp()
                                            self.first_rib_connection_down_timestamp.parent = self
                                            self.first_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionUpTimestamp()
                                            self.first_rib_connection_up_timestamp.parent = self
                                            self.is_rib_connection_up = None
                                            self.last_rib_connection_down_age = None
                                            self.last_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionDownTimestamp()
                                            self.last_rib_connection_down_timestamp.parent = self
                                            self.last_rib_connection_up_age = None
                                            self.last_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionUpTimestamp()
                                            self.last_rib_connection_up_timestamp.parent = self
                                            self.rib_connection_down_count = None
                                            self.rib_connection_up_count = None


                                        class FirstRibConnectionUpTimestamp(object):
                                            """
                                            First RIB connection Up event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-rib-connection-up-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionUpTimestamp']['meta_info']


                                        class LastRibConnectionUpTimestamp(object):
                                            """
                                            Last RIB connection Up event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-rib-connection-up-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionUpTimestamp']['meta_info']


                                        class FirstRibConnectionDownTimestamp(object):
                                            """
                                            First RIB connection Down event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-rib-connection-down-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionDownTimestamp']['meta_info']


                                        class LastRibConnectionDownTimestamp(object):
                                            """
                                            Last RIB connection Down event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-rib-connection-down-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionDownTimestamp']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6rib-server'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.first_rib_connection_down_timestamp is not None and self.first_rib_connection_down_timestamp._has_data():
                                                return True

                                            if self.first_rib_connection_up_timestamp is not None and self.first_rib_connection_up_timestamp._has_data():
                                                return True

                                            if self.is_rib_connection_up is not None:
                                                return True

                                            if self.last_rib_connection_down_age is not None:
                                                return True

                                            if self.last_rib_connection_down_timestamp is not None and self.last_rib_connection_down_timestamp._has_data():
                                                return True

                                            if self.last_rib_connection_up_age is not None:
                                                return True

                                            if self.last_rib_connection_up_timestamp is not None and self.last_rib_connection_up_timestamp._has_data():
                                                return True

                                            if self.rib_connection_down_count is not None:
                                                return True

                                            if self.rib_connection_up_count is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer']['meta_info']


                                    class TeConnection(object):
                                        """
                                        MPLS TE server connection info
                                        
                                        .. attribute:: connection_down_count
                                        
                                        	Number of connection down events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: connection_up_count
                                        
                                        	Number of connection Up events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: first_connection_down_timestamp
                                        
                                        	First connection Down event timestamp
                                        	**type**\:   :py:class:`FirstConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionDownTimestamp>`
                                        
                                        .. attribute:: first_connection_up_timestamp
                                        
                                        	First connection Up event timestamp
                                        	**type**\:   :py:class:`FirstConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionUpTimestamp>`
                                        
                                        .. attribute:: is_connection_up
                                        
                                        	Is Connection Up?
                                        	**type**\:  bool
                                        
                                        .. attribute:: last_connection_down_age
                                        
                                        	Time since last connection Down event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_connection_down_timestamp
                                        
                                        	Last connection Down event timestamp
                                        	**type**\:   :py:class:`LastConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionDownTimestamp>`
                                        
                                        .. attribute:: last_connection_up_age
                                        
                                        	Time since last connection Up event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_connection_up_timestamp
                                        
                                        	Last connection Up event timestamp
                                        	**type**\:   :py:class:`LastConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionUpTimestamp>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.connection_down_count = None
                                            self.connection_up_count = None
                                            self.first_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionDownTimestamp()
                                            self.first_connection_down_timestamp.parent = self
                                            self.first_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionUpTimestamp()
                                            self.first_connection_up_timestamp.parent = self
                                            self.is_connection_up = None
                                            self.last_connection_down_age = None
                                            self.last_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionDownTimestamp()
                                            self.last_connection_down_timestamp.parent = self
                                            self.last_connection_up_age = None
                                            self.last_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionUpTimestamp()
                                            self.last_connection_up_timestamp.parent = self


                                        class FirstConnectionUpTimestamp(object):
                                            """
                                            First connection Up event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-connection-up-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionUpTimestamp']['meta_info']


                                        class LastConnectionUpTimestamp(object):
                                            """
                                            Last connection Up event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-connection-up-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionUpTimestamp']['meta_info']


                                        class FirstConnectionDownTimestamp(object):
                                            """
                                            First connection Down event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-connection-down-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionDownTimestamp']['meta_info']


                                        class LastConnectionDownTimestamp(object):
                                            """
                                            Last connection Down event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-connection-down-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionDownTimestamp']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:te-connection'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.connection_down_count is not None:
                                                return True

                                            if self.connection_up_count is not None:
                                                return True

                                            if self.first_connection_down_timestamp is not None and self.first_connection_down_timestamp._has_data():
                                                return True

                                            if self.first_connection_up_timestamp is not None and self.first_connection_up_timestamp._has_data():
                                                return True

                                            if self.is_connection_up is not None:
                                                return True

                                            if self.last_connection_down_age is not None:
                                                return True

                                            if self.last_connection_down_timestamp is not None and self.last_connection_down_timestamp._has_data():
                                                return True

                                            if self.last_connection_up_age is not None:
                                                return True

                                            if self.last_connection_up_timestamp is not None and self.last_connection_up_timestamp._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection']['meta_info']


                                    class LsdConnection(object):
                                        """
                                        MPLS LSD server connection info
                                        
                                        .. attribute:: connection_down_count
                                        
                                        	Number of connection down events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: connection_up_count
                                        
                                        	Number of connection Up events
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: first_connection_down_timestamp
                                        
                                        	First connection Down event timestamp
                                        	**type**\:   :py:class:`FirstConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionDownTimestamp>`
                                        
                                        .. attribute:: first_connection_up_timestamp
                                        
                                        	First connection Up event timestamp
                                        	**type**\:   :py:class:`FirstConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionUpTimestamp>`
                                        
                                        .. attribute:: is_connection_up
                                        
                                        	Is Connection Up?
                                        	**type**\:  bool
                                        
                                        .. attribute:: last_connection_down_age
                                        
                                        	Time since last connection Down event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_connection_down_timestamp
                                        
                                        	Last connection Down event timestamp
                                        	**type**\:   :py:class:`LastConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionDownTimestamp>`
                                        
                                        .. attribute:: last_connection_up_age
                                        
                                        	Time since last connection Up event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_connection_up_timestamp
                                        
                                        	Last connection Up event timestamp
                                        	**type**\:   :py:class:`LastConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionUpTimestamp>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.connection_down_count = None
                                            self.connection_up_count = None
                                            self.first_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionDownTimestamp()
                                            self.first_connection_down_timestamp.parent = self
                                            self.first_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionUpTimestamp()
                                            self.first_connection_up_timestamp.parent = self
                                            self.is_connection_up = None
                                            self.last_connection_down_age = None
                                            self.last_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionDownTimestamp()
                                            self.last_connection_down_timestamp.parent = self
                                            self.last_connection_up_age = None
                                            self.last_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionUpTimestamp()
                                            self.last_connection_up_timestamp.parent = self


                                        class FirstConnectionUpTimestamp(object):
                                            """
                                            First connection Up event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-connection-up-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionUpTimestamp']['meta_info']


                                        class LastConnectionUpTimestamp(object):
                                            """
                                            Last connection Up event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-connection-up-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionUpTimestamp']['meta_info']


                                        class FirstConnectionDownTimestamp(object):
                                            """
                                            First connection Down event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-connection-down-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionDownTimestamp']['meta_info']


                                        class LastConnectionDownTimestamp(object):
                                            """
                                            Last connection Down event timestamp
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-connection-down-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionDownTimestamp']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:lsd-connection'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.connection_down_count is not None:
                                                return True

                                            if self.connection_up_count is not None:
                                                return True

                                            if self.first_connection_down_timestamp is not None and self.first_connection_down_timestamp._has_data():
                                                return True

                                            if self.first_connection_up_timestamp is not None and self.first_connection_up_timestamp._has_data():
                                                return True

                                            if self.is_connection_up is not None:
                                                return True

                                            if self.last_connection_down_age is not None:
                                                return True

                                            if self.last_connection_down_timestamp is not None and self.last_connection_down_timestamp._has_data():
                                                return True

                                            if self.last_connection_up_age is not None:
                                                return True

                                            if self.last_connection_up_timestamp is not None and self.last_connection_up_timestamp._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection']['meta_info']


                                    class DsNpl(object):
                                        """
                                        NSR related DS and NPL information
                                        
                                        .. attribute:: dir_service_conn_state
                                        
                                        	Current Directory Service connectionstate
                                        	**type**\:   :py:class:`BgpDsConnStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpDsConnStateEnum>`
                                        
                                        .. attribute:: dsissu_status_flag
                                        
                                        	DS ISSU status flag
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: issu_mgr_conn_state
                                        
                                        	Current ISSU Mgr connection state
                                        	**type**\:   :py:class:`BgpIsmConnStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpIsmConnStateEnum>`
                                        
                                        .. attribute:: issu_phase
                                        
                                        	Current ISSU Phase
                                        	**type**\:  str
                                        
                                        .. attribute:: issu_type_ng
                                        
                                        	ISSU type is Next Gen
                                        	**type**\:  bool
                                        
                                        .. attribute:: issuha_option
                                        
                                        	Current ISSU HA option
                                        	**type**\:  str
                                        
                                        .. attribute:: local_ds_handle
                                        
                                        	Local Directory Service handle
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: npl_endpoint
                                        
                                        	NPL endpoint information
                                        	**type**\: list of    :py:class:`NplEndpoint <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint>`
                                        
                                        .. attribute:: npl_priority_statistic
                                        
                                        	NPL priority statistics
                                        	**type**\: list of    :py:class:`NplPriorityStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic>`
                                        
                                        .. attribute:: service_name
                                        
                                        	Local DS service name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.dir_service_conn_state = None
                                            self.dsissu_status_flag = None
                                            self.issu_mgr_conn_state = None
                                            self.issu_phase = None
                                            self.issu_type_ng = None
                                            self.issuha_option = None
                                            self.local_ds_handle = None
                                            self.npl_endpoint = YList()
                                            self.npl_endpoint.parent = self
                                            self.npl_endpoint.name = 'npl_endpoint'
                                            self.npl_priority_statistic = YList()
                                            self.npl_priority_statistic.parent = self
                                            self.npl_priority_statistic.name = 'npl_priority_statistic'
                                            self.service_name = None


                                        class NplPriorityStatistic(object):
                                            """
                                            NPL priority statistics
                                            
                                            .. attribute:: num_recv
                                            
                                            	Total recvd
                                            	**type**\: list of    :py:class:`NumRecv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecv>`
                                            
                                            .. attribute:: num_recv_drop
                                            
                                            	Recv Errors/drops
                                            	**type**\: list of    :py:class:`NumRecvDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop>`
                                            
                                            .. attribute:: num_sent
                                            
                                            	Total sent
                                            	**type**\: list of    :py:class:`NumSent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSent>`
                                            
                                            .. attribute:: num_sent_drop
                                            
                                            	Sent Error/drops
                                            	**type**\: list of    :py:class:`NumSentDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.num_recv = YList()
                                                self.num_recv.parent = self
                                                self.num_recv.name = 'num_recv'
                                                self.num_recv_drop = YList()
                                                self.num_recv_drop.parent = self
                                                self.num_recv_drop.name = 'num_recv_drop'
                                                self.num_sent = YList()
                                                self.num_sent.parent = self
                                                self.num_sent.name = 'num_sent'
                                                self.num_sent_drop = YList()
                                                self.num_sent_drop.parent = self
                                                self.num_sent_drop.name = 'num_sent_drop'


                                            class NumSent(object):
                                                """
                                                Total sent
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:num-sent'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSent']['meta_info']


                                            class NumRecv(object):
                                                """
                                                Total recvd
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:num-recv'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecv']['meta_info']


                                            class NumSentDrop(object):
                                                """
                                                Sent Error/drops
                                                
                                                .. attribute:: nsr_pl_send_drop_array
                                                
                                                	nsr pl send drop array
                                                	**type**\: list of    :py:class:`NsrPlSendDropArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nsr_pl_send_drop_array = YList()
                                                    self.nsr_pl_send_drop_array.parent = self
                                                    self.nsr_pl_send_drop_array.name = 'nsr_pl_send_drop_array'


                                                class NsrPlSendDropArray(object):
                                                    """
                                                    nsr pl send drop array
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nsr-pl-send-drop-array'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:num-sent-drop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nsr_pl_send_drop_array is not None:
                                                        for child_ref in self.nsr_pl_send_drop_array:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop']['meta_info']


                                            class NumRecvDrop(object):
                                                """
                                                Recv Errors/drops
                                                
                                                .. attribute:: nsr_pl_recv_drop_array
                                                
                                                	nsr pl recv drop array
                                                	**type**\: list of    :py:class:`NsrPlRecvDropArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nsr_pl_recv_drop_array = YList()
                                                    self.nsr_pl_recv_drop_array.parent = self
                                                    self.nsr_pl_recv_drop_array.name = 'nsr_pl_recv_drop_array'


                                                class NsrPlRecvDropArray(object):
                                                    """
                                                    nsr pl recv drop array
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nsr-pl-recv-drop-array'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:num-recv-drop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nsr_pl_recv_drop_array is not None:
                                                        for child_ref in self.nsr_pl_recv_drop_array:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:npl-priority-statistic'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.num_recv is not None:
                                                    for child_ref in self.num_recv:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.num_recv_drop is not None:
                                                    for child_ref in self.num_recv_drop:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.num_sent is not None:
                                                    for child_ref in self.num_sent:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.num_sent_drop is not None:
                                                    for child_ref in self.num_sent_drop:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic']['meta_info']


                                        class NplEndpoint(object):
                                            """
                                            NPL endpoint information
                                            
                                            .. attribute:: endpoint
                                            
                                            	NCD endpoint bytestream
                                            	**type**\: list of    :py:class:`Endpoint <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint.Endpoint>`
                                            
                                            .. attribute:: endpoint_active_flag
                                            
                                            	Endpoint active flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: endpoint_handle
                                            
                                            	NCD endpoint handle
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: endpoint_issu_role
                                            
                                            	Endpoint's ISSU Role. Values are 'Primary', 'Secondary' and 'Tertiary'
                                            	**type**\:  str
                                            
                                            .. attribute:: endpoint_name
                                            
                                            	Endpoint name
                                            	**type**\:  str
                                            
                                            .. attribute:: endpoint_stale_flag
                                            
                                            	Endpoint stale flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: expected_sequence_num
                                            
                                            	Expected sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: msg_size
                                            
                                            	Message size for this entity
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: node_id
                                            
                                            	Node ID
                                            	**type**\:  str
                                            
                                            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                                            
                                            .. attribute:: sync_group_name
                                            
                                            	Syncgroup associated with this endpoint
                                            	**type**\:  str
                                            
                                            .. attribute:: wheel_id
                                            
                                            	Wheel ID for this endpoint
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.endpoint = YList()
                                                self.endpoint.parent = self
                                                self.endpoint.name = 'endpoint'
                                                self.endpoint_active_flag = None
                                                self.endpoint_handle = None
                                                self.endpoint_issu_role = None
                                                self.endpoint_name = None
                                                self.endpoint_stale_flag = None
                                                self.expected_sequence_num = None
                                                self.msg_size = None
                                                self.node_id = None
                                                self.sync_group_name = None
                                                self.wheel_id = None


                                            class Endpoint(object):
                                                """
                                                NCD endpoint bytestream
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:endpoint'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint.Endpoint']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:npl-endpoint'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.endpoint is not None:
                                                    for child_ref in self.endpoint:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.endpoint_active_flag is not None:
                                                    return True

                                                if self.endpoint_handle is not None:
                                                    return True

                                                if self.endpoint_issu_role is not None:
                                                    return True

                                                if self.endpoint_name is not None:
                                                    return True

                                                if self.endpoint_stale_flag is not None:
                                                    return True

                                                if self.expected_sequence_num is not None:
                                                    return True

                                                if self.msg_size is not None:
                                                    return True

                                                if self.node_id is not None:
                                                    return True

                                                if self.sync_group_name is not None:
                                                    return True

                                                if self.wheel_id is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ds-npl'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dir_service_conn_state is not None:
                                                return True

                                            if self.dsissu_status_flag is not None:
                                                return True

                                            if self.issu_mgr_conn_state is not None:
                                                return True

                                            if self.issu_phase is not None:
                                                return True

                                            if self.issu_type_ng is not None:
                                                return True

                                            if self.issuha_option is not None:
                                                return True

                                            if self.local_ds_handle is not None:
                                                return True

                                            if self.npl_endpoint is not None:
                                                for child_ref in self.npl_endpoint:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.npl_priority_statistic is not None:
                                                for child_ref in self.npl_priority_statistic:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.service_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl']['meta_info']


                                    class ActiveNsrModeEnterTime(object):
                                        """
                                        Time that each mode was entered (seconds since
                                        
                                        Jan 1 1970)
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.entry = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-nsr-mode-enter-time'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.entry is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrModeEnterTime']['meta_info']


                                    class StandbyNsrModeEnterTime(object):
                                        """
                                        Time that each mode was entered (seconds since
                                        
                                        Jan 1 1970)
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.entry = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:standby-nsr-mode-enter-time'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.entry is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.StandbyNsrModeEnterTime']['meta_info']


                                    class ActiveNsrfoTime(object):
                                        """
                                        Time that each thread isdone with its
                                        
                                        go\-activeprocessing (seconds since Jan 1 1970)
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.entry = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-nsrfo-time'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.entry is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrfoTime']['meta_info']


                                    class PostitCountInfo(object):
                                        """
                                        List of neighbors and their postit counts
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress>`
                                        
                                        .. attribute:: postit_count
                                        
                                        	Count of the number of postits for this nbr
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self.postit_count = None
                                            self.vrf_name = None


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:postit-count-info'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            if self.postit_count is not None:
                                                return True

                                            if self.vrf_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo']['meta_info']


                                    class IssuMilestone(object):
                                        """
                                        ISSU Milestones
                                        
                                        .. attribute:: milestone_met_timestamp
                                        
                                        	Milestone met timestamp
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: milestone_name
                                        
                                        	Milestone name
                                        	**type**\:  str
                                        
                                        	**length:** 0..64
                                        
                                        .. attribute:: milestone_start_timestamp
                                        
                                        	Milestone start timestamp
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.milestone_met_timestamp = None
                                            self.milestone_name = None
                                            self.milestone_start_timestamp = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:issu-milestone'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.milestone_met_timestamp is not None:
                                                return True

                                            if self.milestone_name is not None:
                                                return True

                                            if self.milestone_start_timestamp is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_.IssuMilestone']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:global'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.active_nsr_mode_enter_time is not None:
                                            for child_ref in self.active_nsr_mode_enter_time:
                                                if child_ref._has_data():
                                                    return True

                                        if self.active_nsr_state is not None:
                                            return True

                                        if self.active_nsrfo_time is not None:
                                            for child_ref in self.active_nsrfo_time:
                                                if child_ref._has_data():
                                                    return True

                                        if self.active_nsrtcp_phase_two_enter_time is not None:
                                            return True

                                        if self.bgp_te_infra_tunnel_type is not None:
                                            return True

                                        if self.brib_api_input_bytes is not None:
                                            return True

                                        if self.brib_api_input_messages is not None:
                                            return True

                                        if self.brib_api_input_prefixes_received is not None:
                                            return True

                                        if self.brib_api_input_processing_time is not None:
                                            return True

                                        if self.brib_api_input_withdrawn_prefixes is not None:
                                            return True

                                        if self.brib_api_output_bytes_generated is not None:
                                            return True

                                        if self.brib_api_output_bytes_sent is not None:
                                            return True

                                        if self.brib_api_output_calls is not None:
                                            return True

                                        if self.brib_api_output_generation_time is not None:
                                            return True

                                        if self.brib_api_output_messages_sent is not None:
                                            return True

                                        if self.brib_api_output_prefixes_advertised is not None:
                                            return True

                                        if self.brib_api_output_prefixes_withdrawn is not None:
                                            return True

                                        if self.brib_api_output_sending_time is not None:
                                            return True

                                        if self.configuration_items_processed is not None:
                                            return True

                                        if self.configuration_processing_time is not None:
                                            return True

                                        if self.current_clock_time is not None:
                                            return True

                                        if self.ds_npl is not None and self.ds_npl._has_data():
                                            return True

                                        if self.edm_processing_time is not None:
                                            return True

                                        if self.edm_requests_count is not None:
                                            return True

                                        if self.in_event_attach_calls is not None:
                                            return True

                                        if self.in_out_event_attach_calls is not None:
                                            return True

                                        if self.initial_sync_sessions_added is not None:
                                            return True

                                        if self.instance_node_role is not None:
                                            return True

                                        if self.io_handler_tm is not None:
                                            return True

                                        if self.io_timer_id is not None:
                                            return True

                                        if self.io_tree_timer_expiry is not None:
                                            return True

                                        if self.io_tree_timer_left is not None:
                                            return True

                                        if self.ipv4rib_server is not None and self.ipv4rib_server._has_data():
                                            return True

                                        if self.ipv6rib_server is not None and self.ipv6rib_server._has_data():
                                            return True

                                        if self.issu_milestone is not None:
                                            for child_ref in self.issu_milestone:
                                                if child_ref._has_data():
                                                    return True

                                        if self.issu_milestone_packed is not None:
                                            return True

                                        if self.lsd_connection is not None and self.lsd_connection._has_data():
                                            return True

                                        if self.nsr_last_reset_reason is not None:
                                            return True

                                        if self.out_event_attach_calls is not None:
                                            return True

                                        if self.postit_count_info is not None:
                                            for child_ref in self.postit_count_info:
                                                if child_ref._has_data():
                                                    return True

                                        if self.proc_scoped_sync_state is not None:
                                            return True

                                        if self.qad_ac_ks_failure is not None:
                                            return True

                                        if self.qad_ac_ks_received is not None:
                                            return True

                                        if self.qad_init_drops is not None:
                                            return True

                                        if self.qad_messages_received is not None:
                                            return True

                                        if self.qad_messages_sent is not None:
                                            return True

                                        if self.qad_processed is not None:
                                            return True

                                        if self.qad_recv_drops is not None:
                                            return True

                                        if self.qad_resumes is not None:
                                            return True

                                        if self.qad_send_drops is not None:
                                            return True

                                        if self.qad_send_failure is not None:
                                            return True

                                        if self.qad_suspends is not None:
                                            return True

                                        if self.qad_timeout_received is not None:
                                            return True

                                        if self.qad_timeout_recvd is not None:
                                            return True

                                        if self.qadack_sent is not None:
                                            return True

                                        if self.qadoos_drops is not None:
                                            return True

                                        if self.redcon_nsr_ready is not None:
                                            return True

                                        if self.redcon_state_time is not None:
                                            return True

                                        if self.sec_active_nsr_state is not None:
                                            return True

                                        if self.sec_active_nsrtcp_phase_two_enter_time is not None:
                                            return True

                                        if self.standby_nsr_mode_enter_time is not None:
                                            for child_ref in self.standby_nsr_mode_enter_time:
                                                if child_ref._has_data():
                                                    return True

                                        if self.te_connection is not None and self.te_connection._has_data():
                                            return True

                                        if self.tep2p_auto_tunnel_enabled is not None:
                                            return True

                                        if self.total_neighbors_with_pending_postits is not None:
                                            return True

                                        if self.total_outstanding_postits is not None:
                                            return True

                                        if self.updgen_handler_tm is not None:
                                            return True

                                        if self.updgen_timer_id is not None:
                                            return True

                                        if self.updgen_tree_timer_expiry is not None:
                                            return True

                                        if self.updgen_tree_timer_left is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global_']['meta_info']


                                class Vrf_(object):
                                    """
                                    VRF information
                                    
                                    .. attribute:: data_bytes_read
                                    
                                    	No. of bytes of data read
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: data_bytes_written
                                    
                                    	Number of bytes of data written
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: high_throttled_read_count
                                    
                                    	Number of socket reads for nbrs above high threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inbound_update_messages
                                    
                                    	Number of inbound update messages processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inbound_update_messages_time
                                    
                                    	Time spent processing imbound update messages (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: io_read_time
                                    
                                    	Time spent reading inbound data (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: io_write_time
                                    
                                    	Time spent writing outbound data (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: low_throttled_read_count
                                    
                                    	Number of socket reads for nbrs above low threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lpts_calls
                                    
                                    	Number of times LPTS socket opt set up
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lpts_set_up_time
                                    
                                    	Time spent setting up LPTS socket opt (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: read_calls_count
                                    
                                    	No. of calls to function to read inbound data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: read_messages_count
                                    
                                    	Number of BGP messages read
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: read_throttles_count
                                    
                                    	Number of partial read throttles
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subgroup_list_time
                                    
                                    	Time spent processing sub\-group message list (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: write_calls_count
                                    
                                    	No. of calls to function to write outbound data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_queue_calls_count
                                    
                                    	No. of Calls to function to process write queue
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_queue_messages_count
                                    
                                    	Number of write queue messages processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_queue_time
                                    
                                    	Time spent processing write queue (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_subgroup_calls_count
                                    
                                    	No. of calls to to funvction to process sub\-group message list
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_subgroup_messages_count
                                    
                                    	Number of sub\-group messages processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.data_bytes_read = None
                                        self.data_bytes_written = None
                                        self.high_throttled_read_count = None
                                        self.inbound_update_messages = None
                                        self.inbound_update_messages_time = None
                                        self.io_read_time = None
                                        self.io_write_time = None
                                        self.low_throttled_read_count = None
                                        self.lpts_calls = None
                                        self.lpts_set_up_time = None
                                        self.read_calls_count = None
                                        self.read_messages_count = None
                                        self.read_throttles_count = None
                                        self.subgroup_list_time = None
                                        self.write_calls_count = None
                                        self.write_queue_calls_count = None
                                        self.write_queue_messages_count = None
                                        self.write_queue_time = None
                                        self.write_subgroup_calls_count = None
                                        self.write_subgroup_messages_count = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:vrf'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.data_bytes_read is not None:
                                            return True

                                        if self.data_bytes_written is not None:
                                            return True

                                        if self.high_throttled_read_count is not None:
                                            return True

                                        if self.inbound_update_messages is not None:
                                            return True

                                        if self.inbound_update_messages_time is not None:
                                            return True

                                        if self.io_read_time is not None:
                                            return True

                                        if self.io_write_time is not None:
                                            return True

                                        if self.low_throttled_read_count is not None:
                                            return True

                                        if self.lpts_calls is not None:
                                            return True

                                        if self.lpts_set_up_time is not None:
                                            return True

                                        if self.read_calls_count is not None:
                                            return True

                                        if self.read_messages_count is not None:
                                            return True

                                        if self.read_throttles_count is not None:
                                            return True

                                        if self.subgroup_list_time is not None:
                                            return True

                                        if self.write_calls_count is not None:
                                            return True

                                        if self.write_queue_calls_count is not None:
                                            return True

                                        if self.write_queue_messages_count is not None:
                                            return True

                                        if self.write_queue_time is not None:
                                            return True

                                        if self.write_subgroup_calls_count is not None:
                                            return True

                                        if self.write_subgroup_messages_count is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Vrf_']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:performance-statistics'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.global_ is not None and self.global_._has_data():
                                        return True

                                    if self.vrf is not None and self.vrf._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:process-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.global_ is not None and self.global_._has_data():
                                    return True

                                if self.performance_statistics is not None and self.performance_statistics._has_data():
                                    return True

                                if self.process_instance is not None:
                                    return True

                                if self.vrf is not None and self.vrf._has_data():
                                    return True

                                if self.vrf_name is not None:
                                    return True

                                if self.vrf_totals is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo']['meta_info']


                        class Sessions(object):
                            """
                            The BGP session table
                            
                            .. attribute:: session
                            
                            	A BGP session table entry
                            	**type**\: list of    :py:class:`Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.session = YList()
                                self.session.parent = self
                                self.session.name = 'session'


                            class Session(object):
                                """
                                A BGP session table entry
                                
                                .. attribute:: neighbor_address  <key>
                                
                                	Neighbor address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: connection_local_address
                                
                                	Local address for the connection
                                	**type**\:   :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress>`
                                
                                .. attribute:: connection_remote_address
                                
                                	Remote address for the connection
                                	**type**\:   :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress>`
                                
                                .. attribute:: connection_state
                                
                                	State of connection
                                	**type**\:   :py:class:`BgpConnStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnStateEnum>`
                                
                                .. attribute:: description
                                
                                	Description
                                	**type**\:  str
                                
                                .. attribute:: is_local_address_configured
                                
                                	Local address configured for the neighbor connection
                                	**type**\:  bool
                                
                                .. attribute:: local_as
                                
                                	Local AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: messages_queued_in
                                
                                	No. of msgs on receive queue
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: messages_queued_out
                                
                                	No. of messages on send queue
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_enabled
                                
                                	Neighbor supports NSR
                                	**type**\:  bool
                                
                                .. attribute:: nsr_state
                                
                                	NSR state
                                	**type**\:   :py:class:`BgpSyncNbrNsrStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrStateEnum>`
                                
                                .. attribute:: postit_pending
                                
                                	Nbr has postits pending
                                	**type**\:  bool
                                
                                .. attribute:: remote_as
                                
                                	Remote AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: speaker_id
                                
                                	Speaker this neighbor is allocated to
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vrf_name
                                
                                	Name of the VRF
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.neighbor_address = None
                                    self.connection_local_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress()
                                    self.connection_local_address.parent = self
                                    self.connection_remote_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress()
                                    self.connection_remote_address.parent = self
                                    self.connection_state = None
                                    self.description = None
                                    self.is_local_address_configured = None
                                    self.local_as = None
                                    self.messages_queued_in = None
                                    self.messages_queued_out = None
                                    self.nsr_enabled = None
                                    self.nsr_state = None
                                    self.postit_pending = None
                                    self.remote_as = None
                                    self.speaker_id = None
                                    self.vrf_name = None


                                class ConnectionLocalAddress(object):
                                    """
                                    Local address for the connection
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpnvpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2VpnvplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4mdt_address = None
                                        self.ipv4mvpn_address = None
                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                        self.ipv4sr_policy_address.parent = self
                                        self.ipv4vpn_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                        self.ipv6sr_policy_address.parent = self
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_flowspec_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.l2vpn_evpn_address = None
                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2VpnvplsAddress()
                                        self.l2vpnvpls_address.parent = self
                                        self.ls_ls_address = None
                                        self.rt_constraint_address = None


                                    class L2VpnvplsAddress(object):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2VpnvplsAddress']['meta_info']


                                    class L2VpnMspwAddress(object):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2VpnMspwAddress']['meta_info']


                                    class Ipv4SrPolicyAddress(object):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress']['meta_info']


                                    class Ipv6SrPolicyAddress(object):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv6_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv6_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connection-local-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.afi is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv4_flowspec_address is not None:
                                            return True

                                        if self.ipv4_label_address is not None:
                                            return True

                                        if self.ipv4_mcast_address is not None:
                                            return True

                                        if self.ipv4_tunnel_address is not None:
                                            return True

                                        if self.ipv4mdt_address is not None:
                                            return True

                                        if self.ipv4mvpn_address is not None:
                                            return True

                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                            return True

                                        if self.ipv4vpn_address is not None:
                                            return True

                                        if self.ipv4vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv4vpna_mcastddress is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        if self.ipv6_flowspec_address is not None:
                                            return True

                                        if self.ipv6_label_address is not None:
                                            return True

                                        if self.ipv6_mcast_address is not None:
                                            return True

                                        if self.ipv6mvpn_address is not None:
                                            return True

                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                            return True

                                        if self.ipv6vpn_address is not None:
                                            return True

                                        if self.ipv6vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv6vpn_mcast_address is not None:
                                            return True

                                        if self.l2vpn_evpn_address is not None:
                                            return True

                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                            return True

                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                            return True

                                        if self.ls_ls_address is not None:
                                            return True

                                        if self.rt_constraint_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress']['meta_info']


                                class ConnectionRemoteAddress(object):
                                    """
                                    Remote address for the connection
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpnvpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2VpnvplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4mdt_address = None
                                        self.ipv4mvpn_address = None
                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                        self.ipv4sr_policy_address.parent = self
                                        self.ipv4vpn_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                        self.ipv6sr_policy_address.parent = self
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_flowspec_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.l2vpn_evpn_address = None
                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2VpnvplsAddress()
                                        self.l2vpnvpls_address.parent = self
                                        self.ls_ls_address = None
                                        self.rt_constraint_address = None


                                    class L2VpnvplsAddress(object):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2VpnvplsAddress']['meta_info']


                                    class L2VpnMspwAddress(object):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2VpnMspwAddress']['meta_info']


                                    class Ipv4SrPolicyAddress(object):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress']['meta_info']


                                    class Ipv6SrPolicyAddress(object):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv6_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv6_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connection-remote-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.afi is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv4_flowspec_address is not None:
                                            return True

                                        if self.ipv4_label_address is not None:
                                            return True

                                        if self.ipv4_mcast_address is not None:
                                            return True

                                        if self.ipv4_tunnel_address is not None:
                                            return True

                                        if self.ipv4mdt_address is not None:
                                            return True

                                        if self.ipv4mvpn_address is not None:
                                            return True

                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                            return True

                                        if self.ipv4vpn_address is not None:
                                            return True

                                        if self.ipv4vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv4vpna_mcastddress is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        if self.ipv6_flowspec_address is not None:
                                            return True

                                        if self.ipv6_label_address is not None:
                                            return True

                                        if self.ipv6_mcast_address is not None:
                                            return True

                                        if self.ipv6mvpn_address is not None:
                                            return True

                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                            return True

                                        if self.ipv6vpn_address is not None:
                                            return True

                                        if self.ipv6vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv6vpn_mcast_address is not None:
                                            return True

                                        if self.l2vpn_evpn_address is not None:
                                            return True

                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                            return True

                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                            return True

                                        if self.ls_ls_address is not None:
                                            return True

                                        if self.rt_constraint_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.neighbor_address is None:
                                        raise YPYModelError('Key property neighbor_address is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:session[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address = ' + str(self.neighbor_address) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.neighbor_address is not None:
                                        return True

                                    if self.connection_local_address is not None and self.connection_local_address._has_data():
                                        return True

                                    if self.connection_remote_address is not None and self.connection_remote_address._has_data():
                                        return True

                                    if self.connection_state is not None:
                                        return True

                                    if self.description is not None:
                                        return True

                                    if self.is_local_address_configured is not None:
                                        return True

                                    if self.local_as is not None:
                                        return True

                                    if self.messages_queued_in is not None:
                                        return True

                                    if self.messages_queued_out is not None:
                                        return True

                                    if self.nsr_enabled is not None:
                                        return True

                                    if self.nsr_state is not None:
                                        return True

                                    if self.postit_pending is not None:
                                        return True

                                    if self.remote_as is not None:
                                        return True

                                    if self.speaker_id is not None:
                                        return True

                                    if self.vrf_name is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sessions'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.session is not None:
                                    for child_ref in self.session:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions']['meta_info']


                        class Neighbors(object):
                            """
                            The BGP Neighbor table
                            
                            .. attribute:: neighbor
                            
                            	A BGP Neighbor table entry
                            	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.neighbor = YList()
                                self.neighbor.parent = self
                                self.neighbor.name = 'neighbor'


                            class Neighbor(object):
                                """
                                A BGP Neighbor table entry
                                
                                .. attribute:: neighbor_address  <key>
                                
                                	Neighbor address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: active_bmp_servers
                                
                                	BMP Servers to which the neighbor sends logs
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: actual_last_write_bytes
                                
                                	Actual size of last write
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: actual_last_write_reset_bytes
                                
                                	Actual size of last write before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: actual_second_last_write_bytes
                                
                                	Actual size of second last write
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: actual_second_last_write_reset_bytes
                                
                                	Actual size of second last write before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: af_data
                                
                                	Address family specific neighbor data
                                	**type**\: list of    :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData>`
                                
                                .. attribute:: attempted_last_write_bytes
                                
                                	Attempted size of last write
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: attempted_last_write_reset_bytes
                                
                                	Attempted size of last write before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: attempted_second_last_write_bytes
                                
                                	Attempted size of second last write
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: attempted_second_last_write_reset_bytes
                                
                                	Attempted size of second last write before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_minintervalval
                                
                                	BFD Mininterval for this peer
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_multiplierval
                                
                                	BFD Multiplier for this peer
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_session_created_state
                                
                                	BFD state for this peer
                                	**type**\:   :py:class:`BgpBfdStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdStateEnum>`
                                
                                .. attribute:: bfd_session_enable_mode
                                
                                	BFD enable mode for this peer
                                	**type**\:   :py:class:`BgpBfdEnableModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdEnableModeEnum>`
                                
                                .. attribute:: bfd_session_state
                                
                                	BFD state for this peer
                                	**type**\:   :py:class:`BgpBfdStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdStateEnum>`
                                
                                .. attribute:: bfd_state_ts
                                
                                	Timestamp since when nbr is in this bfd state
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bytes_read
                                
                                	Total bytes read
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: bytes_written
                                
                                	Total bytes written by write thread
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: configured_hold_time
                                
                                	Hold time (in secs) configured for this connection
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: configured_keepalive
                                
                                	Keepalive time (in secs) configured for this connection
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: configured_min_acc_hold_time
                                
                                	Minimum acceptable hold time from neighbor (in secs) configured for this connection
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: connect_retry_interval
                                
                                	Time (in secs) for connect retry timer
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: connection_admin_status
                                
                                	Administrative status of connection
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: connection_down_count
                                
                                	Number of times connection was dropped
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: connection_established_time
                                
                                	Time (in secs) that the connection has been established
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: connection_local_address
                                
                                	Local address for the connection
                                	**type**\:   :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress>`
                                
                                .. attribute:: connection_local_port
                                
                                	Local port for the connection
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: connection_remote_address
                                
                                	Remote address for the connection
                                	**type**\:   :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress>`
                                
                                .. attribute:: connection_remote_port
                                
                                	Remote port for the connection
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: connection_state
                                
                                	State of connection
                                	**type**\:   :py:class:`BgpConnStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnStateEnum>`
                                
                                .. attribute:: connection_up_count
                                
                                	Number of times the connection was established
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: count_last_write
                                
                                	Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: description
                                
                                	Description
                                	**type**\:  str
                                
                                .. attribute:: discard_as4_path
                                
                                	Discard AS4\_PATH in case there is a discrepancy in merging AS\_PATH and AS4\_PATH,retain ASPATH
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: discard_data_bytes
                                
                                	Remaining discard data (bytes) on Standby
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: dmz_link_bandwidth
                                
                                	Bandwidth of link to single\-hop eBGP peer
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: dynamic_neighbor
                                
                                	Dynamic neighbor
                                	**type**\:  bool
                                
                                .. attribute:: ebgp_recv_dmz
                                
                                	Receive Bandwidth of link to single\-hop eBGP peer
                                	**type**\:  bool
                                
                                .. attribute:: ebgp_send_dmz_mode
                                
                                	Ebgp send dmz link bw mode
                                	**type**\:   :py:class:`BgpEbgpSendDmzEnableModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableModeEnum>`
                                
                                .. attribute:: ebgp_time_to_live
                                
                                	Maximum number of hops for external BGP neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: egress_peer_engineering_enabled
                                
                                	Indicates if Egress Peer Engineering is enabled
                                	**type**\:  bool
                                
                                .. attribute:: error_notifies_received
                                
                                	Number of error notifications received on the connection
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: error_notifies_sent
                                
                                	Number of error notifications sent on the connection
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fpbsn_offset
                                
                                	First standby PDU boundary SeqNo offset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fssn_offset
                                
                                	First standby SeqNo offset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: gr_restart_time
                                
                                	Neighbor restart time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: gr_stale_path_time
                                
                                	Neighbor stale\-path time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: graceful_maintenance
                                
                                	Graceful Maintenance
                                	**type**\:   :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.GracefulMaintenance>`
                                
                                .. attribute:: graceful_restart_enabled_nbr
                                
                                	Neighbor supports graceful\-restart
                                	**type**\:  bool
                                
                                .. attribute:: has_internal_link
                                
                                	Internal link to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: hold_time
                                
                                	Hold time (in secs) negotiated for this connection
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: ignore_connected
                                
                                	If true, the VPN client isan IBGP CE peer
                                	**type**\:  bool
                                
                                .. attribute:: internal_vpn_client
                                
                                	If true, don't do NHconnected check for nbr
                                	**type**\:  bool
                                
                                .. attribute:: io_armed
                                
                                	If true, socket has beenauto\-armed for io control
                                	**type**\:  bool
                                
                                .. attribute:: is4_byte_as_capability_received
                                
                                	4\-byte AScapability received
                                	**type**\:  bool
                                
                                .. attribute:: is4_byte_as_capability_sent
                                
                                	4\-byte AScapability Snt
                                	**type**\:  bool
                                
                                .. attribute:: is_administratively_shut_down
                                
                                	Neighbor is administratively shut down
                                	**type**\:  bool
                                
                                .. attribute:: is_capability_negotiation_performed
                                
                                	Capability negotiation performed
                                	**type**\:  bool
                                
                                .. attribute:: is_capability_negotiation_suppressed
                                
                                	Capability negotiation suppressed
                                	**type**\:  bool
                                
                                .. attribute:: is_ebgp_multihop_bgpmpls_forwarding_disabled
                                
                                	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ebgp_peer_as_league
                                
                                	EBGP peer belongs to AS League
                                	**type**\:  bool
                                
                                .. attribute:: is_ebgp_peer_common_admin
                                
                                	EBGP peer with common administation
                                	**type**\:  bool
                                
                                .. attribute:: is_external_neighbor_not_directly_connected
                                
                                	External neighbor not directly connected
                                	**type**\:  bool
                                
                                .. attribute:: is_gr_aware
                                
                                	GR awareness received
                                	**type**\:  bool
                                
                                .. attribute:: is_local_address_configured
                                
                                	Local address configured for the neighbor connection
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_max_prefix_shutdown
                                
                                	Neighbor shut down because it exceeded max prfx count
                                	**type**\:  bool
                                
                                .. attribute:: is_out_of_memory_forced_up
                                
                                	Neighbor forced up during a low memory condition
                                	**type**\:  bool
                                
                                .. attribute:: is_out_of_memory_shutdown
                                
                                	Neighbor shut down during a SEVERE low memory condition
                                	**type**\:  bool
                                
                                .. attribute:: is_passive_close
                                
                                	If true, active socket canbe closed if passive openis received for a GRcapable neighbor
                                	**type**\:  bool
                                
                                .. attribute:: is_read_disabled
                                
                                	If true, socket read isdisabled
                                	**type**\:  bool
                                
                                .. attribute:: is_route_refresh_capability_received
                                
                                	Route refresh capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_route_refresh_old_capability_received
                                
                                	Route refresh old capability received
                                	**type**\:  bool
                                
                                .. attribute:: keep_alive_time
                                
                                	Keepalive time (in secs) negotiated for this connection
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: last_ackd_seq_no
                                
                                	SeqNo of the last Ackd byte
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_k_aerror_reset
                                
                                	Duration (in secs) since last time that an error was encountered after KA expiry
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_k_aexpiry_reset
                                
                                	Time (in secs) since last KA timer expiry before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_k_anotsent_reset
                                
                                	Duration (in secs) since last time that KA was not sent before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_k_astart_reset
                                
                                	Time (in secs) since the last KA timer start before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_notify_error_code
                                
                                	Code for the last error notification seen on the connection
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: last_notify_error_subcode
                                
                                	Error subcode of the last error notification seen on the connection
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: last_write_event
                                
                                	Time (in secs) since last write thread event
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: local_as
                                
                                	Local AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_as_dual_as
                                
                                	Local AS Dual\-AS option
                                	**type**\:  bool
                                
                                .. attribute:: local_as_dual_as_mode_native
                                
                                	Applies only if Local AS Dual\-AS option is enabled. Indicates if Dual\-AS mode is native
                                	**type**\:  bool
                                
                                .. attribute:: local_as_no_prepend
                                
                                	Option to not prepend the Local AS to announcements
                                	**type**\:  bool
                                
                                .. attribute:: local_as_replace_as
                                
                                	Local AS Replace\-AS option
                                	**type**\:  bool
                                
                                .. attribute:: message_statistics
                                
                                	Message statistics
                                	**type**\:   :py:class:`MessageStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics>`
                                
                                .. attribute:: messages_queued_in
                                
                                	No. of msgs on receive queue
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: messages_queued_out
                                
                                	No. of messages on send queue
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: messages_received
                                
                                	Number of messages received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: messages_sent
                                
                                	Number of messages sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: min_advertise_interval
                                
                                	Minimum advertisement interval, secs part
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: min_advertise_interval_msecs
                                
                                	Minimum advertisement interval, msecs part
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: min_origination_interval
                                
                                	Minimum origination interval (in secs)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: msg_log_in
                                
                                	Message in log count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: msg_log_out
                                
                                	Message out log count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: multi_protocol_capability_received
                                
                                	Multi\-protocol capability has been received
                                	**type**\:  bool
                                
                                .. attribute:: nbr_cluster_id
                                
                                	Cluster id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nbr_enforce_first_as
                                
                                	Neighbor enforce first AS
                                	**type**\:  bool
                                
                                .. attribute:: nbr_in_cluster
                                
                                	Type of cluster\_id\:undefined/number/Ip address
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: negotiated_protocol_version
                                
                                	Negotiated protocol version
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: neighbor_interface_handle
                                
                                	Interface Handle of Neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_local_as
                                
                                	Local AS configured on the neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_enabled
                                
                                	Neighbor supports NSR
                                	**type**\:  bool
                                
                                .. attribute:: nsr_state
                                
                                	NSR state
                                	**type**\:   :py:class:`BgpSyncNbrNsrStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrStateEnum>`
                                
                                .. attribute:: open_check_error_code
                                
                                	Open check error code
                                	**type**\:   :py:class:`BgpOpenCheckErrEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpOpenCheckErrEnum>`
                                
                                .. attribute:: peer_error_code
                                
                                	If peer closed, error received from transport
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: peer_reset_reason
                                
                                	Reason for last peer close event
                                	**type**\:   :py:class:`BgpPeerResetReasonIndexEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPeerResetReasonIndexEnum>`
                                
                                .. attribute:: performance_statistics
                                
                                	Performance statistics
                                	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.PerformanceStatistics>`
                                
                                .. attribute:: previous_connection_state
                                
                                	Previous state of connection
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: read_armed
                                
                                	If true, socket has beenauto\-armed for read
                                	**type**\:  bool
                                
                                .. attribute:: received_notification_info
                                
                                	Information on the last notification received
                                	**type**\:   :py:class:`ReceivedNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo>`
                                
                                .. attribute:: remote_as
                                
                                	Remote AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_as_number
                                
                                	Remote AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reset_notification_sent
                                
                                	Notification was sent during last reset
                                	**type**\:  bool
                                
                                .. attribute:: reset_reason
                                
                                	Reason for last connection reset
                                	**type**\:   :py:class:`BgpResetReasonIndexEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndexEnum>`
                                
                                .. attribute:: router_id
                                
                                	Router ID for the neighbor
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rpki_allow_invalid
                                
                                	Prefix v. allow invalid
                                	**type**\:  bool
                                
                                .. attribute:: rpki_disable
                                
                                	Prefix validation disabled
                                	**type**\:  bool
                                
                                .. attribute:: rpki_signal_ibgp
                                
                                	Prefix v. signal ibgp
                                	**type**\:  bool
                                
                                .. attribute:: rpki_use_validity
                                
                                	Prefix v. use validity
                                	**type**\:  bool
                                
                                .. attribute:: second_last_k_aexpiry_reset
                                
                                	Time (in secs) since second last KA timer expiry before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: second_last_k_astart_reset
                                
                                	Time (in secs) since the second last KA timer start before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: second_last_write_event
                                
                                	Time (in secs) since second last write thread event
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: send_notification_info
                                
                                	Information on the last notification sent
                                	**type**\:   :py:class:`SendNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo>`
                                
                                .. attribute:: socket_read_bytes
                                
                                	Total read bytes value insocket\-lib
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: speaker_id
                                
                                	Speaker this neighbor is allocated to
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: standby_rp
                                
                                	Standby RP socket inited for Active Open
                                	**type**\:  bool
                                
                                .. attribute:: suppress4_byte_as
                                
                                	Suppress 4byteas capability
                                	**type**\:  bool
                                
                                .. attribute:: tcp_init_sync_done_time_spec
                                
                                	Time when neighbor entered TCP Init Sync Done
                                	**type**\:   :py:class:`TcpInitSyncDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec>`
                                
                                .. attribute:: tcp_init_sync_phase_two_time_spec
                                
                                	Time when neighbor entered TCP Init Sync Phase Two
                                	**type**\:   :py:class:`TcpInitSyncPhaseTwoTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec>`
                                
                                .. attribute:: tcp_init_sync_time_spec
                                
                                	Time When neighbor entered TCP Init Sync
                                	**type**\:   :py:class:`TcpInitSyncTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncTimeSpec>`
                                
                                .. attribute:: tcp_session_open_mode
                                
                                	The TCP mode to be used to set up BGP session with the neighbor
                                	**type**\:   :py:class:`BgpTcpModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpModeEnum>`
                                
                                .. attribute:: tcpmss
                                
                                	Neighbor TCP Maximum Segment                     size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_last_cb
                                
                                	CB
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: time_last_cb_reset
                                
                                	Last CB before reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_last_fb
                                
                                	FB
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: time_since_connection_last_dropped
                                
                                	Time since the connection last went down (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: time_since_last_read
                                
                                	Time (in secs) since last read
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: time_since_last_read_reset
                                
                                	Time (in secs) since last read before last reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: time_since_last_update
                                
                                	Time (in secs) since last update message was received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: time_since_last_write
                                
                                	Time (in secs) since last write
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: time_since_last_write_reset
                                
                                	Time (in secs) since last write before last reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: time_since_second_last_write
                                
                                	Time (in secs) since second  last write
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: time_since_second_last_write_reset
                                
                                	Time (in secs) since last write before last reset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: tos_type
                                
                                	Precedence or DSCP type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_value
                                
                                	Precedence or DSCP value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ttl_security_enabled
                                
                                	TTL Security enabled
                                	**type**\:  bool
                                
                                .. attribute:: update_bytes_read
                                
                                	Total update bytes read
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: update_messages_in
                                
                                	No. of update msgs received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_messages_out
                                
                                	No. of update messages sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vrf_name
                                
                                	Name of the VRF
                                	**type**\:  str
                                
                                .. attribute:: write_armed
                                
                                	If true, socket has beenauto\-armed for write
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.neighbor_address = None
                                    self.active_bmp_servers = None
                                    self.actual_last_write_bytes = None
                                    self.actual_last_write_reset_bytes = None
                                    self.actual_second_last_write_bytes = None
                                    self.actual_second_last_write_reset_bytes = None
                                    self.af_data = YList()
                                    self.af_data.parent = self
                                    self.af_data.name = 'af_data'
                                    self.attempted_last_write_bytes = None
                                    self.attempted_last_write_reset_bytes = None
                                    self.attempted_second_last_write_bytes = None
                                    self.attempted_second_last_write_reset_bytes = None
                                    self.bfd_minintervalval = None
                                    self.bfd_multiplierval = None
                                    self.bfd_session_created_state = None
                                    self.bfd_session_enable_mode = None
                                    self.bfd_session_state = None
                                    self.bfd_state_ts = None
                                    self.bytes_read = None
                                    self.bytes_written = None
                                    self.configured_hold_time = None
                                    self.configured_keepalive = None
                                    self.configured_min_acc_hold_time = None
                                    self.connect_retry_interval = None
                                    self.connection_admin_status = None
                                    self.connection_down_count = None
                                    self.connection_established_time = None
                                    self.connection_local_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress()
                                    self.connection_local_address.parent = self
                                    self.connection_local_port = None
                                    self.connection_remote_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress()
                                    self.connection_remote_address.parent = self
                                    self.connection_remote_port = None
                                    self.connection_state = None
                                    self.connection_up_count = None
                                    self.count_last_write = None
                                    self.description = None
                                    self.discard_as4_path = None
                                    self.discard_data_bytes = None
                                    self.dmz_link_bandwidth = None
                                    self.dynamic_neighbor = None
                                    self.ebgp_recv_dmz = None
                                    self.ebgp_send_dmz_mode = None
                                    self.ebgp_time_to_live = None
                                    self.egress_peer_engineering_enabled = None
                                    self.error_notifies_received = None
                                    self.error_notifies_sent = None
                                    self.fpbsn_offset = None
                                    self.fssn_offset = None
                                    self.gr_restart_time = None
                                    self.gr_stale_path_time = None
                                    self.graceful_maintenance = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.GracefulMaintenance()
                                    self.graceful_maintenance.parent = self
                                    self.graceful_restart_enabled_nbr = None
                                    self.has_internal_link = None
                                    self.hold_time = None
                                    self.ignore_connected = None
                                    self.internal_vpn_client = None
                                    self.io_armed = None
                                    self.is4_byte_as_capability_received = None
                                    self.is4_byte_as_capability_sent = None
                                    self.is_administratively_shut_down = None
                                    self.is_capability_negotiation_performed = None
                                    self.is_capability_negotiation_suppressed = None
                                    self.is_ebgp_multihop_bgpmpls_forwarding_disabled = None
                                    self.is_ebgp_peer_as_league = None
                                    self.is_ebgp_peer_common_admin = None
                                    self.is_external_neighbor_not_directly_connected = None
                                    self.is_gr_aware = None
                                    self.is_local_address_configured = None
                                    self.is_neighbor_max_prefix_shutdown = None
                                    self.is_out_of_memory_forced_up = None
                                    self.is_out_of_memory_shutdown = None
                                    self.is_passive_close = None
                                    self.is_read_disabled = None
                                    self.is_route_refresh_capability_received = None
                                    self.is_route_refresh_old_capability_received = None
                                    self.keep_alive_time = None
                                    self.last_ackd_seq_no = None
                                    self.last_k_aerror_reset = None
                                    self.last_k_aexpiry_reset = None
                                    self.last_k_anotsent_reset = None
                                    self.last_k_astart_reset = None
                                    self.last_notify_error_code = None
                                    self.last_notify_error_subcode = None
                                    self.last_write_event = None
                                    self.local_as = None
                                    self.local_as_dual_as = None
                                    self.local_as_dual_as_mode_native = None
                                    self.local_as_no_prepend = None
                                    self.local_as_replace_as = None
                                    self.message_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics()
                                    self.message_statistics.parent = self
                                    self.messages_queued_in = None
                                    self.messages_queued_out = None
                                    self.messages_received = None
                                    self.messages_sent = None
                                    self.min_advertise_interval = None
                                    self.min_advertise_interval_msecs = None
                                    self.min_origination_interval = None
                                    self.msg_log_in = None
                                    self.msg_log_out = None
                                    self.multi_protocol_capability_received = None
                                    self.nbr_cluster_id = None
                                    self.nbr_enforce_first_as = None
                                    self.nbr_in_cluster = None
                                    self.negotiated_protocol_version = None
                                    self.neighbor_interface_handle = None
                                    self.neighbor_local_as = None
                                    self.nsr_enabled = None
                                    self.nsr_state = None
                                    self.open_check_error_code = None
                                    self.peer_error_code = None
                                    self.peer_reset_reason = None
                                    self.performance_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.PerformanceStatistics()
                                    self.performance_statistics.parent = self
                                    self.previous_connection_state = None
                                    self.read_armed = None
                                    self.received_notification_info = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo()
                                    self.received_notification_info.parent = self
                                    self.remote_as = None
                                    self.remote_as_number = None
                                    self.reset_notification_sent = None
                                    self.reset_reason = None
                                    self.router_id = None
                                    self.rpki_allow_invalid = None
                                    self.rpki_disable = None
                                    self.rpki_signal_ibgp = None
                                    self.rpki_use_validity = None
                                    self.second_last_k_aexpiry_reset = None
                                    self.second_last_k_astart_reset = None
                                    self.second_last_write_event = None
                                    self.send_notification_info = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo()
                                    self.send_notification_info.parent = self
                                    self.socket_read_bytes = None
                                    self.speaker_id = None
                                    self.standby_rp = None
                                    self.suppress4_byte_as = None
                                    self.tcp_init_sync_done_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec()
                                    self.tcp_init_sync_done_time_spec.parent = self
                                    self.tcp_init_sync_phase_two_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec()
                                    self.tcp_init_sync_phase_two_time_spec.parent = self
                                    self.tcp_init_sync_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncTimeSpec()
                                    self.tcp_init_sync_time_spec.parent = self
                                    self.tcp_session_open_mode = None
                                    self.tcpmss = None
                                    self.time_last_cb = None
                                    self.time_last_cb_reset = None
                                    self.time_last_fb = None
                                    self.time_since_connection_last_dropped = None
                                    self.time_since_last_read = None
                                    self.time_since_last_read_reset = None
                                    self.time_since_last_update = None
                                    self.time_since_last_write = None
                                    self.time_since_last_write_reset = None
                                    self.time_since_second_last_write = None
                                    self.time_since_second_last_write_reset = None
                                    self.tos_type = None
                                    self.tos_value = None
                                    self.ttl_security_enabled = None
                                    self.update_bytes_read = None
                                    self.update_messages_in = None
                                    self.update_messages_out = None
                                    self.vrf_name = None
                                    self.write_armed = None


                                class ConnectionLocalAddress(object):
                                    """
                                    Local address for the connection
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpnvpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnvplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4mdt_address = None
                                        self.ipv4mvpn_address = None
                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                        self.ipv4sr_policy_address.parent = self
                                        self.ipv4vpn_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                        self.ipv6sr_policy_address.parent = self
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_flowspec_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.l2vpn_evpn_address = None
                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnvplsAddress()
                                        self.l2vpnvpls_address.parent = self
                                        self.ls_ls_address = None
                                        self.rt_constraint_address = None


                                    class L2VpnvplsAddress(object):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnvplsAddress']['meta_info']


                                    class L2VpnMspwAddress(object):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress']['meta_info']


                                    class Ipv4SrPolicyAddress(object):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress']['meta_info']


                                    class Ipv6SrPolicyAddress(object):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv6_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv6_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connection-local-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.afi is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv4_flowspec_address is not None:
                                            return True

                                        if self.ipv4_label_address is not None:
                                            return True

                                        if self.ipv4_mcast_address is not None:
                                            return True

                                        if self.ipv4_tunnel_address is not None:
                                            return True

                                        if self.ipv4mdt_address is not None:
                                            return True

                                        if self.ipv4mvpn_address is not None:
                                            return True

                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                            return True

                                        if self.ipv4vpn_address is not None:
                                            return True

                                        if self.ipv4vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv4vpna_mcastddress is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        if self.ipv6_flowspec_address is not None:
                                            return True

                                        if self.ipv6_label_address is not None:
                                            return True

                                        if self.ipv6_mcast_address is not None:
                                            return True

                                        if self.ipv6mvpn_address is not None:
                                            return True

                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                            return True

                                        if self.ipv6vpn_address is not None:
                                            return True

                                        if self.ipv6vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv6vpn_mcast_address is not None:
                                            return True

                                        if self.l2vpn_evpn_address is not None:
                                            return True

                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                            return True

                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                            return True

                                        if self.ls_ls_address is not None:
                                            return True

                                        if self.rt_constraint_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress']['meta_info']


                                class ConnectionRemoteAddress(object):
                                    """
                                    Remote address for the connection
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpnvpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnvplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4mdt_address = None
                                        self.ipv4mvpn_address = None
                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                        self.ipv4sr_policy_address.parent = self
                                        self.ipv4vpn_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                        self.ipv6sr_policy_address.parent = self
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_flowspec_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.l2vpn_evpn_address = None
                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnvplsAddress()
                                        self.l2vpnvpls_address.parent = self
                                        self.ls_ls_address = None
                                        self.rt_constraint_address = None


                                    class L2VpnvplsAddress(object):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnvplsAddress']['meta_info']


                                    class L2VpnMspwAddress(object):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress']['meta_info']


                                    class Ipv4SrPolicyAddress(object):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress']['meta_info']


                                    class Ipv6SrPolicyAddress(object):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv6_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv6_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connection-remote-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.afi is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv4_flowspec_address is not None:
                                            return True

                                        if self.ipv4_label_address is not None:
                                            return True

                                        if self.ipv4_mcast_address is not None:
                                            return True

                                        if self.ipv4_tunnel_address is not None:
                                            return True

                                        if self.ipv4mdt_address is not None:
                                            return True

                                        if self.ipv4mvpn_address is not None:
                                            return True

                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                            return True

                                        if self.ipv4vpn_address is not None:
                                            return True

                                        if self.ipv4vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv4vpna_mcastddress is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        if self.ipv6_flowspec_address is not None:
                                            return True

                                        if self.ipv6_label_address is not None:
                                            return True

                                        if self.ipv6_mcast_address is not None:
                                            return True

                                        if self.ipv6mvpn_address is not None:
                                            return True

                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                            return True

                                        if self.ipv6vpn_address is not None:
                                            return True

                                        if self.ipv6vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv6vpn_mcast_address is not None:
                                            return True

                                        if self.l2vpn_evpn_address is not None:
                                            return True

                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                            return True

                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                            return True

                                        if self.ls_ls_address is not None:
                                            return True

                                        if self.rt_constraint_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress']['meta_info']


                                class SendNotificationInfo(object):
                                    """
                                    Information on the last notification sent
                                    
                                    .. attribute:: last_notification_data
                                    
                                    	Message data in last notification
                                    	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData>`
                                    
                                    .. attribute:: notification_error_code
                                    
                                    	Error code in last notification
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: notification_error_subcode
                                    
                                    	Error subcode in last notification
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: time_since_last_notification
                                    
                                    	Time since the last notification was sent or received (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.last_notification_data = YList()
                                        self.last_notification_data.parent = self
                                        self.last_notification_data.name = 'last_notification_data'
                                        self.notification_error_code = None
                                        self.notification_error_subcode = None
                                        self.time_since_last_notification = None


                                    class LastNotificationData(object):
                                        """
                                        Message data in last notification
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.entry = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-notification-data'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.entry is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:send-notification-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.last_notification_data is not None:
                                            for child_ref in self.last_notification_data:
                                                if child_ref._has_data():
                                                    return True

                                        if self.notification_error_code is not None:
                                            return True

                                        if self.notification_error_subcode is not None:
                                            return True

                                        if self.time_since_last_notification is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo']['meta_info']


                                class ReceivedNotificationInfo(object):
                                    """
                                    Information on the last notification received
                                    
                                    .. attribute:: last_notification_data
                                    
                                    	Message data in last notification
                                    	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData>`
                                    
                                    .. attribute:: notification_error_code
                                    
                                    	Error code in last notification
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: notification_error_subcode
                                    
                                    	Error subcode in last notification
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: time_since_last_notification
                                    
                                    	Time since the last notification was sent or received (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.last_notification_data = YList()
                                        self.last_notification_data.parent = self
                                        self.last_notification_data.name = 'last_notification_data'
                                        self.notification_error_code = None
                                        self.notification_error_subcode = None
                                        self.time_since_last_notification = None


                                    class LastNotificationData(object):
                                        """
                                        Message data in last notification
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.entry = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-notification-data'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.entry is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:received-notification-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.last_notification_data is not None:
                                            for child_ref in self.last_notification_data:
                                                if child_ref._has_data():
                                                    return True

                                        if self.notification_error_code is not None:
                                            return True

                                        if self.notification_error_subcode is not None:
                                            return True

                                        if self.time_since_last_notification is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo']['meta_info']


                                class PerformanceStatistics(object):
                                    """
                                    Performance statistics
                                    
                                    .. attribute:: active_collision
                                    
                                    	Number of Closed Active connections for this neighbor due to collision 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: actives
                                    
                                    	Number of retried Active opens for this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: control_to_read_thread_trigger
                                    
                                    	Number of times io\-control thread trigger read thread
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: control_to_write_thread_trigger
                                    
                                    	Number of times io\-control thread trigger write thread
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: data_bytes_read
                                    
                                    	No. of bytes of data read
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: data_bytes_written
                                    
                                    	No. of data bytes written
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: failed_post_actives
                                    
                                    	Number of Active Opens that failed in the Post Active State for this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: high_throttled_read
                                    
                                    	Num of socket reads after nbr crossed high threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inbound_update_messages
                                    
                                    	Number of inbound update messages processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inbound_update_messages_time
                                    
                                    	Time spent processing inbound update messages (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: io_read_time
                                    
                                    	Time spent reading inbound data (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: io_write_time
                                    
                                    	Time spent writing outbound data (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: last_nsr_scoped_sync
                                    
                                    	Last time NSR scoped syncwas done for the neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_sent_seq_no
                                    
                                    	Seq No of the last sent byte
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: low_throttled_read
                                    
                                    	Num socket reads after nbrs crossed low threshold
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_read_size
                                    
                                    	Size of largest socket (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: nbr_fd
                                    
                                    	Primary FD, per nbr
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: nbr_flags
                                    
                                    	Nbr flags, per thread
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: network_status
                                    
                                    	Socket status, TRUE if socket closed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_oper_down_count
                                    
                                    	Number of times NSR scoped sync has been done
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: passive_collision
                                    
                                    	Number of Closed Remote opens for this neighborneighbor due to collision 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: passives
                                    
                                    	Number of retried Passive opens for this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: read_calls_count
                                    
                                    	No. of calls to function to read inbound data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: read_messages_count
                                    
                                    	Number of BGP messages read
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: read_throttles
                                    
                                    	Number of partial read throttles
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rejected_passives
                                    
                                    	Number of rejected Passive opens for this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reset_flags
                                    
                                    	Reset flags, per thread
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reset_retries
                                    
                                    	Reset Retries, per nbr
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: subgroup_list_time
                                    
                                    	Time spent processing sub\-group message list  (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: sync_flags
                                    
                                    	Sync flags, per nbr
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: time_since_last_throttled_read
                                    
                                    	Time (in secs) since last read after being throttled
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: write_calls_count
                                    
                                    	No. of calls to function to write outbound data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_queue_calls_count
                                    
                                    	No. of calls to function to process write queue
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_queue_messages_count
                                    
                                    	Number of write queue messages processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_queue_time
                                    
                                    	Time spent processing write queue (milliseconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: write_subgroup_calls_count
                                    
                                    	No. of calls to function to process sub\-group message list
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_subgroup_messages_count
                                    
                                    	Number of sub\-group msgs processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.active_collision = None
                                        self.actives = None
                                        self.control_to_read_thread_trigger = None
                                        self.control_to_write_thread_trigger = None
                                        self.data_bytes_read = None
                                        self.data_bytes_written = None
                                        self.failed_post_actives = None
                                        self.high_throttled_read = None
                                        self.inbound_update_messages = None
                                        self.inbound_update_messages_time = None
                                        self.io_read_time = None
                                        self.io_write_time = None
                                        self.last_nsr_scoped_sync = None
                                        self.last_sent_seq_no = None
                                        self.low_throttled_read = None
                                        self.maximum_read_size = None
                                        self.nbr_fd = None
                                        self.nbr_flags = None
                                        self.network_status = None
                                        self.nsr_oper_down_count = None
                                        self.passive_collision = None
                                        self.passives = None
                                        self.read_calls_count = None
                                        self.read_messages_count = None
                                        self.read_throttles = None
                                        self.rejected_passives = None
                                        self.reset_flags = None
                                        self.reset_retries = None
                                        self.subgroup_list_time = None
                                        self.sync_flags = None
                                        self.time_since_last_throttled_read = None
                                        self.write_calls_count = None
                                        self.write_queue_calls_count = None
                                        self.write_queue_messages_count = None
                                        self.write_queue_time = None
                                        self.write_subgroup_calls_count = None
                                        self.write_subgroup_messages_count = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:performance-statistics'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.active_collision is not None:
                                            return True

                                        if self.actives is not None:
                                            return True

                                        if self.control_to_read_thread_trigger is not None:
                                            return True

                                        if self.control_to_write_thread_trigger is not None:
                                            return True

                                        if self.data_bytes_read is not None:
                                            return True

                                        if self.data_bytes_written is not None:
                                            return True

                                        if self.failed_post_actives is not None:
                                            return True

                                        if self.high_throttled_read is not None:
                                            return True

                                        if self.inbound_update_messages is not None:
                                            return True

                                        if self.inbound_update_messages_time is not None:
                                            return True

                                        if self.io_read_time is not None:
                                            return True

                                        if self.io_write_time is not None:
                                            return True

                                        if self.last_nsr_scoped_sync is not None:
                                            return True

                                        if self.last_sent_seq_no is not None:
                                            return True

                                        if self.low_throttled_read is not None:
                                            return True

                                        if self.maximum_read_size is not None:
                                            return True

                                        if self.nbr_fd is not None:
                                            return True

                                        if self.nbr_flags is not None:
                                            return True

                                        if self.network_status is not None:
                                            return True

                                        if self.nsr_oper_down_count is not None:
                                            return True

                                        if self.passive_collision is not None:
                                            return True

                                        if self.passives is not None:
                                            return True

                                        if self.read_calls_count is not None:
                                            return True

                                        if self.read_messages_count is not None:
                                            return True

                                        if self.read_throttles is not None:
                                            return True

                                        if self.rejected_passives is not None:
                                            return True

                                        if self.reset_flags is not None:
                                            return True

                                        if self.reset_retries is not None:
                                            return True

                                        if self.subgroup_list_time is not None:
                                            return True

                                        if self.sync_flags is not None:
                                            return True

                                        if self.time_since_last_throttled_read is not None:
                                            return True

                                        if self.write_calls_count is not None:
                                            return True

                                        if self.write_queue_calls_count is not None:
                                            return True

                                        if self.write_queue_messages_count is not None:
                                            return True

                                        if self.write_queue_time is not None:
                                            return True

                                        if self.write_subgroup_calls_count is not None:
                                            return True

                                        if self.write_subgroup_messages_count is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.PerformanceStatistics']['meta_info']


                                class MessageStatistics(object):
                                    """
                                    Message statistics
                                    
                                    .. attribute:: keepalive
                                    
                                    	Keepalive
                                    	**type**\:   :py:class:`Keepalive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive>`
                                    
                                    .. attribute:: notification
                                    
                                    	Notification
                                    	**type**\:   :py:class:`Notification <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification>`
                                    
                                    .. attribute:: open
                                    
                                    	Open
                                    	**type**\:   :py:class:`Open <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open>`
                                    
                                    .. attribute:: route_refresh
                                    
                                    	Route refresh
                                    	**type**\:   :py:class:`RouteRefresh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh>`
                                    
                                    .. attribute:: total
                                    
                                    	Total
                                    	**type**\:   :py:class:`Total <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total>`
                                    
                                    .. attribute:: update
                                    
                                    	Update
                                    	**type**\:   :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.keepalive = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive()
                                        self.keepalive.parent = self
                                        self.notification = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification()
                                        self.notification.parent = self
                                        self.open = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open()
                                        self.open.parent = self
                                        self.route_refresh = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh()
                                        self.route_refresh.parent = self
                                        self.total = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total()
                                        self.total.parent = self
                                        self.update = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update()
                                        self.update.parent = self


                                    class Open(object):
                                        """
                                        Open
                                        
                                        .. attribute:: rx
                                        
                                        	Receive
                                        	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx>`
                                        
                                        .. attribute:: tx
                                        
                                        	Transmit
                                        	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.rx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx()
                                            self.rx.parent = self
                                            self.tx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx()
                                            self.tx.parent = self


                                        class Tx(object):
                                            """
                                            Transmit
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.count = None
                                                self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec()
                                                self.last_time_spec.parent = self


                                            class LastTimeSpec(object):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.count is not None:
                                                    return True

                                                if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx']['meta_info']


                                        class Rx(object):
                                            """
                                            Receive
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.count = None
                                                self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec()
                                                self.last_time_spec.parent = self


                                            class LastTimeSpec(object):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.count is not None:
                                                    return True

                                                if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:open'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.rx is not None and self.rx._has_data():
                                                return True

                                            if self.tx is not None and self.tx._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open']['meta_info']


                                    class Notification(object):
                                        """
                                        Notification
                                        
                                        .. attribute:: rx
                                        
                                        	Receive
                                        	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx>`
                                        
                                        .. attribute:: tx
                                        
                                        	Transmit
                                        	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.rx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx()
                                            self.rx.parent = self
                                            self.tx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx()
                                            self.tx.parent = self


                                        class Tx(object):
                                            """
                                            Transmit
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.count = None
                                                self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec()
                                                self.last_time_spec.parent = self


                                            class LastTimeSpec(object):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.count is not None:
                                                    return True

                                                if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx']['meta_info']


                                        class Rx(object):
                                            """
                                            Receive
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.count = None
                                                self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec()
                                                self.last_time_spec.parent = self


                                            class LastTimeSpec(object):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.count is not None:
                                                    return True

                                                if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:notification'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.rx is not None and self.rx._has_data():
                                                return True

                                            if self.tx is not None and self.tx._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification']['meta_info']


                                    class Update(object):
                                        """
                                        Update
                                        
                                        .. attribute:: rx
                                        
                                        	Receive
                                        	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx>`
                                        
                                        .. attribute:: tx
                                        
                                        	Transmit
                                        	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.rx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx()
                                            self.rx.parent = self
                                            self.tx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx()
                                            self.tx.parent = self


                                        class Tx(object):
                                            """
                                            Transmit
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.count = None
                                                self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec()
                                                self.last_time_spec.parent = self


                                            class LastTimeSpec(object):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.count is not None:
                                                    return True

                                                if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx']['meta_info']


                                        class Rx(object):
                                            """
                                            Receive
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.count = None
                                                self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec()
                                                self.last_time_spec.parent = self


                                            class LastTimeSpec(object):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.count is not None:
                                                    return True

                                                if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.rx is not None and self.rx._has_data():
                                                return True

                                            if self.tx is not None and self.tx._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update']['meta_info']


                                    class Keepalive(object):
                                        """
                                        Keepalive
                                        
                                        .. attribute:: rx
                                        
                                        	Receive
                                        	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx>`
                                        
                                        .. attribute:: tx
                                        
                                        	Transmit
                                        	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.rx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx()
                                            self.rx.parent = self
                                            self.tx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx()
                                            self.tx.parent = self


                                        class Tx(object):
                                            """
                                            Transmit
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.count = None
                                                self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec()
                                                self.last_time_spec.parent = self


                                            class LastTimeSpec(object):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.count is not None:
                                                    return True

                                                if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx']['meta_info']


                                        class Rx(object):
                                            """
                                            Receive
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.count = None
                                                self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec()
                                                self.last_time_spec.parent = self


                                            class LastTimeSpec(object):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.count is not None:
                                                    return True

                                                if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:keepalive'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.rx is not None and self.rx._has_data():
                                                return True

                                            if self.tx is not None and self.tx._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive']['meta_info']


                                    class RouteRefresh(object):
                                        """
                                        Route refresh
                                        
                                        .. attribute:: rx
                                        
                                        	Receive
                                        	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx>`
                                        
                                        .. attribute:: tx
                                        
                                        	Transmit
                                        	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.rx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx()
                                            self.rx.parent = self
                                            self.tx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx()
                                            self.tx.parent = self


                                        class Tx(object):
                                            """
                                            Transmit
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.count = None
                                                self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec()
                                                self.last_time_spec.parent = self


                                            class LastTimeSpec(object):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.count is not None:
                                                    return True

                                                if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx']['meta_info']


                                        class Rx(object):
                                            """
                                            Receive
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.count = None
                                                self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec()
                                                self.last_time_spec.parent = self


                                            class LastTimeSpec(object):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.count is not None:
                                                    return True

                                                if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:route-refresh'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.rx is not None and self.rx._has_data():
                                                return True

                                            if self.tx is not None and self.tx._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh']['meta_info']


                                    class Total(object):
                                        """
                                        Total
                                        
                                        .. attribute:: rx
                                        
                                        	Receive
                                        	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx>`
                                        
                                        .. attribute:: tx
                                        
                                        	Transmit
                                        	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.rx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx()
                                            self.rx.parent = self
                                            self.tx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx()
                                            self.tx.parent = self


                                        class Tx(object):
                                            """
                                            Transmit
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.count = None
                                                self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec()
                                                self.last_time_spec.parent = self


                                            class LastTimeSpec(object):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.count is not None:
                                                    return True

                                                if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx']['meta_info']


                                        class Rx(object):
                                            """
                                            Receive
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.count = None
                                                self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec()
                                                self.last_time_spec.parent = self


                                            class LastTimeSpec(object):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.count is not None:
                                                    return True

                                                if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:total'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.rx is not None and self.rx._has_data():
                                                return True

                                            if self.tx is not None and self.tx._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:message-statistics'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.keepalive is not None and self.keepalive._has_data():
                                            return True

                                        if self.notification is not None and self.notification._has_data():
                                            return True

                                        if self.open is not None and self.open._has_data():
                                            return True

                                        if self.route_refresh is not None and self.route_refresh._has_data():
                                            return True

                                        if self.total is not None and self.total._has_data():
                                            return True

                                        if self.update is not None and self.update._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics']['meta_info']


                                class TcpInitSyncTimeSpec(object):
                                    """
                                    Time When neighbor entered TCP Init Sync
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tcp-init-sync-time-spec'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncTimeSpec']['meta_info']


                                class TcpInitSyncPhaseTwoTimeSpec(object):
                                    """
                                    Time when neighbor entered TCP Init Sync Phase
                                    Two
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tcp-init-sync-phase-two-time-spec'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec']['meta_info']


                                class TcpInitSyncDoneTimeSpec(object):
                                    """
                                    Time when neighbor entered TCP Init Sync Done
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tcp-init-sync-done-time-spec'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec']['meta_info']


                                class GracefulMaintenance(object):
                                    """
                                    Graceful Maintenance
                                    
                                    .. attribute:: gshut_active
                                    
                                    	Graceful Maintenance activated
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_exists
                                    
                                    	Graceful Maintenance enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_local_active
                                    
                                    	Graceful Maintenance locally activated
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_locpref
                                    
                                    	Graceful Maintenance Local Preference
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: gshut_locpref_set
                                    
                                    	Graceful Maintenance Local Preference set
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_prepends
                                    
                                    	Graceful Maintenance number of AS prepends
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.gshut_active = None
                                        self.gshut_exists = None
                                        self.gshut_local_active = None
                                        self.gshut_locpref = None
                                        self.gshut_locpref_set = None
                                        self.gshut_prepends = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:graceful-maintenance'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.gshut_active is not None:
                                            return True

                                        if self.gshut_exists is not None:
                                            return True

                                        if self.gshut_local_active is not None:
                                            return True

                                        if self.gshut_locpref is not None:
                                            return True

                                        if self.gshut_locpref_set is not None:
                                            return True

                                        if self.gshut_prepends is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.GracefulMaintenance']['meta_info']


                                class AfData(object):
                                    """
                                    Address family specific neighbor data
                                    
                                    .. attribute:: accept_own_enabled
                                    
                                    	Accept\-Own enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: acked_version
                                    
                                    	Version mapped from acked seqNo
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: address_family_long_lived_time
                                    
                                    	AF specific Long\-lived\-time config
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: advertise_afi
                                    
                                    	Encode in Advertise AFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_afi_def_vrf_imp_disable
                                    
                                    	Advertise of default VRF import disable
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_afi_disable
                                    
                                    	Encode in Advertise AFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_afi_eo_r_ready
                                    
                                    	EoR Can be sent for Advertise AFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_afi_reorg
                                    
                                    	Encode in Advertise AFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_afi_vrf_re_imp_disable
                                    
                                    	Advertise of VRF re\-import disable
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_evp_nv4afi_def_vrf_imp_disable
                                    
                                    	Advertise of v4 default VRF import disable
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_evp_nv4afi_vrf_re_imp_disable
                                    
                                    	Advertise of v4 VRF re\-import disable
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_evp_nv6afi_def_vrf_imp_disable
                                    
                                    	Advertise of v6 default VRF import disable
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_evp_nv6afi_vrf_re_imp_disable
                                    
                                    	Advertise of v6 VRF re\-import disable
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_local_labeled_route_unicast
                                    
                                    	Advertise routes with local\-label via Unicast SAFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_rt_type
                                    
                                    	Advertise RT type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: advertise_v4_flags
                                    
                                    	Advertise options for VPNV4
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: advertise_v6_flags
                                    
                                    	Advertise options for VPNV6
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: afrpki_allow_invalid
                                    
                                    	Prefix v. allow invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: afrpki_disable
                                    
                                    	Prefix validation disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: afrpki_signal_ibgp
                                    
                                    	Prefix v. signal ibgp
                                    	**type**\:  bool
                                    
                                    .. attribute:: afrpki_use_validity
                                    
                                    	Prefix v. use validity
                                    	**type**\:  bool
                                    
                                    .. attribute:: allow_as_in_count
                                    
                                    	Allowas\-in count config
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: always_use_next_hop_local
                                    
                                    	Local router always used for next\-hop
                                    	**type**\:  bool
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation type
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: eo_r_received_in_read_only
                                    
                                    	An EoR was received while in read\-only mode
                                    	**type**\:  bool
                                    
                                    .. attribute:: extended_community
                                    
                                    	Extended community attribute
                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunity>`
                                    
                                    .. attribute:: extended_community_standby
                                    
                                    	Extended community attribute
                                    	**type**\: list of    :py:class:`ExtendedCommunityStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby>`
                                    
                                    .. attribute:: filter_group_index
                                    
                                    	Filter group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: flowspec_redirect_validation_d_isable
                                    
                                    	Flowspec Redirect Validation Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flowspec_validation_d_isable
                                    
                                    	Flowspec Validation Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: import_reoriginate
                                    
                                    	Import Reoriginate enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: import_reoriginate_stitching
                                    
                                    	Import Reoriginate Stitching enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: import_stitching
                                    
                                    	Import Stitching enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_add_path_receive_capability_advertised
                                    
                                    	Addpath Receive capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_add_path_receive_capability_received
                                    
                                    	Addpath Receive capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_add_path_send_capability_advertised
                                    
                                    	Addpath Send capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_add_path_send_capability_received
                                    
                                    	Addpath Send capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_addpath_receive_operational
                                    
                                    	Addpath is operational on receive\-side
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_addpath_send_operational
                                    
                                    	Addpath is operational on send\-side
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_advertise_permanent_network
                                    
                                    	Advertise Permanent Network
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_advertised_graceful_restart
                                    
                                    	Graceful Restart Capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_advertised_orf_receive
                                    
                                    	Prefix based ORF receive mode capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_advertised_orf_send
                                    
                                    	Prefix based ORF send mode capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_aigp_set
                                    
                                    	AIGP set 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_allow_as_in_set
                                    
                                    	Allowas\-in set 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_as_override_set
                                    
                                    	As override set 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_default_originate_sent
                                    
                                    	Default origination update sent
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ext_nh_encoding_capability_received
                                    
                                    	Extended nexthop encoding capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ext_nh_encoding_capability_sent
                                    
                                    	Extended nexhop encoding capability Sent
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_graceful_restart_state_flag
                                    
                                    	Restart state flag enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_legacy_pe_rt
                                    
                                    	Nbr accepts route from legacy PE for RT\-Constraint AF 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_af_capable
                                    
                                    	Address family capability received from neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_ebgp_without_inbound_policy
                                    
                                    	eBGP neighbor with no configured inbound policy
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_ebgp_without_outbound_policy
                                    
                                    	eBGP neighbor with no configured outbound policy
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_route_reflector_client
                                    
                                    	Nbr is a route reflector client
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_orf_send_scheduled
                                    
                                    	Scheduled to send prefix based ORF
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_orf_sent
                                    
                                    	Outbound route filter sent to neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_orr_root_address_configured
                                    
                                    	ORR Root address configuredfor the neighbor connection
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_peer_orf_capable
                                    
                                    	Peer has outbound route filter capability
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_prefix_orf_present
                                    
                                    	Outbound route filter prefix ORF present
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_received_graceful_restart_capable
                                    
                                    	Graceful Restart Capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_received_orf_receive_capable
                                    
                                    	Prefix based ORF receive mode capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_received_orf_send_capable
                                    
                                    	Prefix based ORF send mode capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_rt_present
                                    
                                    	RT attribute list present
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_rt_present_standby
                                    
                                    	RT attribute list present
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_send_mcast_attr
                                    
                                    	Send Mcast Attr
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_soft_reconfiguration_inbound_allowed
                                    
                                    	Inbound soft reconfiguration allowed
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_update_deferred
                                    
                                    	Update deferred until ORF/route refresh received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_update_leaving
                                    
                                    	Nbr leaving update\-groupto another
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_update_throttled
                                    
                                    	Updates Throttled becausewrite limit is reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_use_soft_reconfiguration_always_on
                                    
                                    	Soft reconf overrides route refresh
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_restart_time
                                    
                                    	Local Restart time (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: long_lived_graceful_restart_capability_received
                                    
                                    	Long\-lived graceful\-restart capability received from the neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_accept
                                    
                                    	Maximum long\-lived graceful\-restart stale time acceptable from the neighbor (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_configured
                                    
                                    	Long\-lived graceful\-restart stale time is configured
                                    	**type**\:  bool
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_received
                                    
                                    	Long\-lived graceful\-restart stale time received from the neighbor (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_sent
                                    
                                    	Stale time sent in long\-lived graceful\-restart capability (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: max_prefix_discard_extra_paths
                                    
                                    	Discard extra paths when prefix limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: max_prefix_exceed_discard_paths
                                    
                                    	Did we discard extra paths when prefix limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: max_prefix_limit
                                    
                                    	Max limit for # of prefixes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: max_prefix_restart_time
                                    
                                    	Time interval (in minutes) after which peering session will be reestablished
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: minute
                                    
                                    .. attribute:: max_prefix_threshold_percent
                                    
                                    	Percentage of maximum no. of prefixes at which to generate warning
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: percentage
                                    
                                    .. attribute:: neighbor_af_performance_statistics
                                    
                                    	Neighbor AF statistics
                                    	**type**\:   :py:class:`NeighborAfPerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics>`
                                    
                                    .. attribute:: neighbor_default_originate
                                    
                                    	Neighbor originates default
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_long_lived_graceful_restart_capable
                                    
                                    	Treat neighbor as long\-lived graceful\-restart capable
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_long_lived_graceful_restart_time_remaining
                                    
                                    	Remaining long\-lived graceful\-restart time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_preserved_forwarding_state
                                    
                                    	Neighbor preserved forwarding state
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_preserved_long_lived_forwarding_state
                                    
                                    	Neighbor preserved long\-lived forwarding state
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_version
                                    
                                    	Neighbor version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: number_of_best_externalpaths
                                    
                                    	No. of best\-external paths from this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: number_of_bestpaths
                                    
                                    	No. of bestpaths from this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: orf_entries_received
                                    
                                    	Number of outbound route filter entries received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: orr_group_index
                                    
                                    	ORR Group Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: orr_group_name
                                    
                                    	ORR Group Name
                                    	**type**\:  str
                                    
                                    .. attribute:: outstanding_version
                                    
                                    	Version mapped from acked seqNo that was synced last
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: outstanding_version_max
                                    
                                    	Version mapped from acked seqNo that was synced last
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_accepted
                                    
                                    	No. of prefixes accepted
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_advertised
                                    
                                    	No. of prefixes advertised
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_be_advertised
                                    
                                    	No BE prefixes advertised
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_denied
                                    
                                    	No. of prefixes denied
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_denied_no_policy
                                    
                                    	No. of prefixes denied because there was no inbound policy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_denied_non_cumulative
                                    
                                    	No. of prefixes exactly denied (non cumulative)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_denied_orf_policy
                                    
                                    	No. of prefixes denied by prefix based ORF policy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_denied_policy
                                    
                                    	No. of prefixes denied by inbound policy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_denied_rt_permit
                                    
                                    	No. of prefixes denied because RT extended community is not imported
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_suppressed
                                    
                                    	No. of prefixes suppressed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_synced
                                    
                                    	Number of prefixes synced to standby
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_withdrawn
                                    
                                    	No. of prefixes withdrawn
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_withdrawn_not_found
                                    
                                    	No. of prefixes withdrawn but not found
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_acked_version
                                    
                                    	Version acked by the peer for refresh updates sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_target_version
                                    
                                    	Target version for refresh update generation
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_version
                                    
                                    	Version till which refresh updates have been generated
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remove_private_as_entire_aspath_from_inbound_updates
                                    
                                    	Private AS numbers removed from updates from this nbr only if the aspath has only private ASes
                                    	**type**\:  bool
                                    
                                    .. attribute:: remove_private_as_entire_aspath_from_updates
                                    
                                    	Private AS numbers removed from updates to thisnbr only if the aspath hasonly private ASes
                                    	**type**\:  bool
                                    
                                    .. attribute:: remove_private_as_from_inbound_updates
                                    
                                    	Private AS numbers removed from updates from this nbr
                                    	**type**\:  bool
                                    
                                    .. attribute:: remove_private_as_from_updates
                                    
                                    	Private AS numbers removed from updates to this nbr
                                    	**type**\:  bool
                                    
                                    .. attribute:: restart_time
                                    
                                    	Restart time advertised (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: rib_purge_timeout_value
                                    
                                    	RIB purge timeout time (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: route_policy_default_originate
                                    
                                    	Default\-originate route policy name
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_in
                                    
                                    	Incoming route policy name
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_out
                                    
                                    	Outgoing route policy name
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_prefix_orf
                                    
                                    	Prefix based ORF for incoming updates
                                    	**type**\:  str
                                    
                                    .. attribute:: route_refreshes_received
                                    
                                    	Number of route refresh requests received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_refreshes_sent
                                    
                                    	Number of route refresh requests sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: selective_multipath_eligible
                                    
                                    	Selective multipath eligible
                                    	**type**\:  bool
                                    
                                    .. attribute:: sent_community_to_neighbor
                                    
                                    	Community attribute sent to neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: sent_extended_community_to_neighbor
                                    
                                    	Extended community attribute sent to neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: sent_gshut_community_to_neighbor
                                    
                                    	GSHUT Community attribute sent to neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: stale_path_timeout
                                    
                                    	Stale path timeout time (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: synced_acked_version
                                    
                                    	Version mapped from acked seqNo that was synced last
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_group_number
                                    
                                    	Update group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: use_max_prefix_warning_only
                                    
                                    	Warning only when maximum prefix limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: vpn_update_gen_enabled
                                    
                                    	RT Nbr enabled for updategento another
                                    	**type**\:  bool
                                    
                                    .. attribute:: vpn_update_gen_trigger_enabled
                                    
                                    	RT Nbr enabled for updategento another
                                    	**type**\:  bool
                                    
                                    .. attribute:: weight
                                    
                                    	Weight for this AF
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.accept_own_enabled = None
                                        self.acked_version = None
                                        self.address_family_long_lived_time = None
                                        self.advertise_afi = None
                                        self.advertise_afi_def_vrf_imp_disable = None
                                        self.advertise_afi_disable = None
                                        self.advertise_afi_eo_r_ready = None
                                        self.advertise_afi_reorg = None
                                        self.advertise_afi_vrf_re_imp_disable = None
                                        self.advertise_evp_nv4afi_def_vrf_imp_disable = None
                                        self.advertise_evp_nv4afi_vrf_re_imp_disable = None
                                        self.advertise_evp_nv6afi_def_vrf_imp_disable = None
                                        self.advertise_evp_nv6afi_vrf_re_imp_disable = None
                                        self.advertise_local_labeled_route_unicast = None
                                        self.advertise_rt_type = None
                                        self.advertise_v4_flags = None
                                        self.advertise_v6_flags = None
                                        self.af_name = None
                                        self.afrpki_allow_invalid = None
                                        self.afrpki_disable = None
                                        self.afrpki_signal_ibgp = None
                                        self.afrpki_use_validity = None
                                        self.allow_as_in_count = None
                                        self.always_use_next_hop_local = None
                                        self.encapsulation_type = None
                                        self.eo_r_received_in_read_only = None
                                        self.extended_community = YList()
                                        self.extended_community.parent = self
                                        self.extended_community.name = 'extended_community'
                                        self.extended_community_standby = YList()
                                        self.extended_community_standby.parent = self
                                        self.extended_community_standby.name = 'extended_community_standby'
                                        self.filter_group_index = None
                                        self.flowspec_redirect_validation_d_isable = None
                                        self.flowspec_validation_d_isable = None
                                        self.import_reoriginate = None
                                        self.import_reoriginate_stitching = None
                                        self.import_stitching = None
                                        self.is_add_path_receive_capability_advertised = None
                                        self.is_add_path_receive_capability_received = None
                                        self.is_add_path_send_capability_advertised = None
                                        self.is_add_path_send_capability_received = None
                                        self.is_addpath_receive_operational = None
                                        self.is_addpath_send_operational = None
                                        self.is_advertise_permanent_network = None
                                        self.is_advertised_graceful_restart = None
                                        self.is_advertised_orf_receive = None
                                        self.is_advertised_orf_send = None
                                        self.is_aigp_set = None
                                        self.is_allow_as_in_set = None
                                        self.is_as_override_set = None
                                        self.is_default_originate_sent = None
                                        self.is_ext_nh_encoding_capability_received = None
                                        self.is_ext_nh_encoding_capability_sent = None
                                        self.is_graceful_restart_state_flag = None
                                        self.is_legacy_pe_rt = None
                                        self.is_neighbor_af_capable = None
                                        self.is_neighbor_ebgp_without_inbound_policy = None
                                        self.is_neighbor_ebgp_without_outbound_policy = None
                                        self.is_neighbor_route_reflector_client = None
                                        self.is_orf_send_scheduled = None
                                        self.is_orf_sent = None
                                        self.is_orr_root_address_configured = None
                                        self.is_peer_orf_capable = None
                                        self.is_prefix_orf_present = None
                                        self.is_received_graceful_restart_capable = None
                                        self.is_received_orf_receive_capable = None
                                        self.is_received_orf_send_capable = None
                                        self.is_rt_present = None
                                        self.is_rt_present_standby = None
                                        self.is_send_mcast_attr = None
                                        self.is_soft_reconfiguration_inbound_allowed = None
                                        self.is_update_deferred = None
                                        self.is_update_leaving = None
                                        self.is_update_throttled = None
                                        self.is_use_soft_reconfiguration_always_on = None
                                        self.local_restart_time = None
                                        self.long_lived_graceful_restart_capability_received = None
                                        self.long_lived_graceful_restart_stale_time_accept = None
                                        self.long_lived_graceful_restart_stale_time_configured = None
                                        self.long_lived_graceful_restart_stale_time_received = None
                                        self.long_lived_graceful_restart_stale_time_sent = None
                                        self.max_prefix_discard_extra_paths = None
                                        self.max_prefix_exceed_discard_paths = None
                                        self.max_prefix_limit = None
                                        self.max_prefix_restart_time = None
                                        self.max_prefix_threshold_percent = None
                                        self.neighbor_af_performance_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics()
                                        self.neighbor_af_performance_statistics.parent = self
                                        self.neighbor_default_originate = None
                                        self.neighbor_long_lived_graceful_restart_capable = None
                                        self.neighbor_long_lived_graceful_restart_time_remaining = None
                                        self.neighbor_preserved_forwarding_state = None
                                        self.neighbor_preserved_long_lived_forwarding_state = None
                                        self.neighbor_version = None
                                        self.number_of_best_externalpaths = None
                                        self.number_of_bestpaths = None
                                        self.orf_entries_received = None
                                        self.orr_group_index = None
                                        self.orr_group_name = None
                                        self.outstanding_version = None
                                        self.outstanding_version_max = None
                                        self.prefixes_accepted = None
                                        self.prefixes_advertised = None
                                        self.prefixes_be_advertised = None
                                        self.prefixes_denied = None
                                        self.prefixes_denied_no_policy = None
                                        self.prefixes_denied_non_cumulative = None
                                        self.prefixes_denied_orf_policy = None
                                        self.prefixes_denied_policy = None
                                        self.prefixes_denied_rt_permit = None
                                        self.prefixes_suppressed = None
                                        self.prefixes_synced = None
                                        self.prefixes_withdrawn = None
                                        self.prefixes_withdrawn_not_found = None
                                        self.refresh_acked_version = None
                                        self.refresh_target_version = None
                                        self.refresh_version = None
                                        self.remove_private_as_entire_aspath_from_inbound_updates = None
                                        self.remove_private_as_entire_aspath_from_updates = None
                                        self.remove_private_as_from_inbound_updates = None
                                        self.remove_private_as_from_updates = None
                                        self.restart_time = None
                                        self.rib_purge_timeout_value = None
                                        self.route_policy_default_originate = None
                                        self.route_policy_in = None
                                        self.route_policy_out = None
                                        self.route_policy_prefix_orf = None
                                        self.route_refreshes_received = None
                                        self.route_refreshes_sent = None
                                        self.selective_multipath_eligible = None
                                        self.sent_community_to_neighbor = None
                                        self.sent_extended_community_to_neighbor = None
                                        self.sent_gshut_community_to_neighbor = None
                                        self.stale_path_timeout = None
                                        self.synced_acked_version = None
                                        self.update_group_number = None
                                        self.use_max_prefix_warning_only = None
                                        self.vpn_update_gen_enabled = None
                                        self.vpn_update_gen_trigger_enabled = None
                                        self.weight = None


                                    class NeighborAfPerformanceStatistics(object):
                                        """
                                        Neighbor AF statistics
                                        
                                        .. attribute:: processed_messages
                                        
                                        	Number of messages processed from the neighbor's write queue
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sent_messages
                                        
                                        	Number of messages sent from the neighbor's write queue
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: split_horizon_update_blocked
                                        
                                        	No. of update messages with split\-horizon flag that were blocked
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: split_horizon_update_transmit
                                        
                                        	No. of update messages with split\-horizon flag that were sent out
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: split_horizon_withdraw_blocked
                                        
                                        	No. of withdraw messages with split\-horizon flag that were blocked
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: split_horizon_withdraw_transmit
                                        
                                        	No. of withdraw messages with split\-horizon flag that were sent out
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_pending_message_count
                                        
                                        	No. of sub\-group messages waiting to be sent out on this neighbor \-\- DEPRECATED \-\- 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.processed_messages = None
                                            self.sent_messages = None
                                            self.split_horizon_update_blocked = None
                                            self.split_horizon_update_transmit = None
                                            self.split_horizon_withdraw_blocked = None
                                            self.split_horizon_withdraw_transmit = None
                                            self.sub_group_pending_message_count = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-af-performance-statistics'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.processed_messages is not None:
                                                return True

                                            if self.sent_messages is not None:
                                                return True

                                            if self.split_horizon_update_blocked is not None:
                                                return True

                                            if self.split_horizon_update_transmit is not None:
                                                return True

                                            if self.split_horizon_withdraw_blocked is not None:
                                                return True

                                            if self.split_horizon_withdraw_transmit is not None:
                                                return True

                                            if self.sub_group_pending_message_count is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics']['meta_info']


                                    class ExtendedCommunity(object):
                                        """
                                        Extended community attribute
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.entry = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.entry is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunity']['meta_info']


                                    class ExtendedCommunityStandby(object):
                                        """
                                        Extended community attribute
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.entry = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community-standby'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.entry is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af-data'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.accept_own_enabled is not None:
                                            return True

                                        if self.acked_version is not None:
                                            return True

                                        if self.address_family_long_lived_time is not None:
                                            return True

                                        if self.advertise_afi is not None:
                                            return True

                                        if self.advertise_afi_def_vrf_imp_disable is not None:
                                            return True

                                        if self.advertise_afi_disable is not None:
                                            return True

                                        if self.advertise_afi_eo_r_ready is not None:
                                            return True

                                        if self.advertise_afi_reorg is not None:
                                            return True

                                        if self.advertise_afi_vrf_re_imp_disable is not None:
                                            return True

                                        if self.advertise_evp_nv4afi_def_vrf_imp_disable is not None:
                                            return True

                                        if self.advertise_evp_nv4afi_vrf_re_imp_disable is not None:
                                            return True

                                        if self.advertise_evp_nv6afi_def_vrf_imp_disable is not None:
                                            return True

                                        if self.advertise_evp_nv6afi_vrf_re_imp_disable is not None:
                                            return True

                                        if self.advertise_local_labeled_route_unicast is not None:
                                            return True

                                        if self.advertise_rt_type is not None:
                                            return True

                                        if self.advertise_v4_flags is not None:
                                            return True

                                        if self.advertise_v6_flags is not None:
                                            return True

                                        if self.af_name is not None:
                                            return True

                                        if self.afrpki_allow_invalid is not None:
                                            return True

                                        if self.afrpki_disable is not None:
                                            return True

                                        if self.afrpki_signal_ibgp is not None:
                                            return True

                                        if self.afrpki_use_validity is not None:
                                            return True

                                        if self.allow_as_in_count is not None:
                                            return True

                                        if self.always_use_next_hop_local is not None:
                                            return True

                                        if self.encapsulation_type is not None:
                                            return True

                                        if self.eo_r_received_in_read_only is not None:
                                            return True

                                        if self.extended_community is not None:
                                            for child_ref in self.extended_community:
                                                if child_ref._has_data():
                                                    return True

                                        if self.extended_community_standby is not None:
                                            for child_ref in self.extended_community_standby:
                                                if child_ref._has_data():
                                                    return True

                                        if self.filter_group_index is not None:
                                            return True

                                        if self.flowspec_redirect_validation_d_isable is not None:
                                            return True

                                        if self.flowspec_validation_d_isable is not None:
                                            return True

                                        if self.import_reoriginate is not None:
                                            return True

                                        if self.import_reoriginate_stitching is not None:
                                            return True

                                        if self.import_stitching is not None:
                                            return True

                                        if self.is_add_path_receive_capability_advertised is not None:
                                            return True

                                        if self.is_add_path_receive_capability_received is not None:
                                            return True

                                        if self.is_add_path_send_capability_advertised is not None:
                                            return True

                                        if self.is_add_path_send_capability_received is not None:
                                            return True

                                        if self.is_addpath_receive_operational is not None:
                                            return True

                                        if self.is_addpath_send_operational is not None:
                                            return True

                                        if self.is_advertise_permanent_network is not None:
                                            return True

                                        if self.is_advertised_graceful_restart is not None:
                                            return True

                                        if self.is_advertised_orf_receive is not None:
                                            return True

                                        if self.is_advertised_orf_send is not None:
                                            return True

                                        if self.is_aigp_set is not None:
                                            return True

                                        if self.is_allow_as_in_set is not None:
                                            return True

                                        if self.is_as_override_set is not None:
                                            return True

                                        if self.is_default_originate_sent is not None:
                                            return True

                                        if self.is_ext_nh_encoding_capability_received is not None:
                                            return True

                                        if self.is_ext_nh_encoding_capability_sent is not None:
                                            return True

                                        if self.is_graceful_restart_state_flag is not None:
                                            return True

                                        if self.is_legacy_pe_rt is not None:
                                            return True

                                        if self.is_neighbor_af_capable is not None:
                                            return True

                                        if self.is_neighbor_ebgp_without_inbound_policy is not None:
                                            return True

                                        if self.is_neighbor_ebgp_without_outbound_policy is not None:
                                            return True

                                        if self.is_neighbor_route_reflector_client is not None:
                                            return True

                                        if self.is_orf_send_scheduled is not None:
                                            return True

                                        if self.is_orf_sent is not None:
                                            return True

                                        if self.is_orr_root_address_configured is not None:
                                            return True

                                        if self.is_peer_orf_capable is not None:
                                            return True

                                        if self.is_prefix_orf_present is not None:
                                            return True

                                        if self.is_received_graceful_restart_capable is not None:
                                            return True

                                        if self.is_received_orf_receive_capable is not None:
                                            return True

                                        if self.is_received_orf_send_capable is not None:
                                            return True

                                        if self.is_rt_present is not None:
                                            return True

                                        if self.is_rt_present_standby is not None:
                                            return True

                                        if self.is_send_mcast_attr is not None:
                                            return True

                                        if self.is_soft_reconfiguration_inbound_allowed is not None:
                                            return True

                                        if self.is_update_deferred is not None:
                                            return True

                                        if self.is_update_leaving is not None:
                                            return True

                                        if self.is_update_throttled is not None:
                                            return True

                                        if self.is_use_soft_reconfiguration_always_on is not None:
                                            return True

                                        if self.local_restart_time is not None:
                                            return True

                                        if self.long_lived_graceful_restart_capability_received is not None:
                                            return True

                                        if self.long_lived_graceful_restart_stale_time_accept is not None:
                                            return True

                                        if self.long_lived_graceful_restart_stale_time_configured is not None:
                                            return True

                                        if self.long_lived_graceful_restart_stale_time_received is not None:
                                            return True

                                        if self.long_lived_graceful_restart_stale_time_sent is not None:
                                            return True

                                        if self.max_prefix_discard_extra_paths is not None:
                                            return True

                                        if self.max_prefix_exceed_discard_paths is not None:
                                            return True

                                        if self.max_prefix_limit is not None:
                                            return True

                                        if self.max_prefix_restart_time is not None:
                                            return True

                                        if self.max_prefix_threshold_percent is not None:
                                            return True

                                        if self.neighbor_af_performance_statistics is not None and self.neighbor_af_performance_statistics._has_data():
                                            return True

                                        if self.neighbor_default_originate is not None:
                                            return True

                                        if self.neighbor_long_lived_graceful_restart_capable is not None:
                                            return True

                                        if self.neighbor_long_lived_graceful_restart_time_remaining is not None:
                                            return True

                                        if self.neighbor_preserved_forwarding_state is not None:
                                            return True

                                        if self.neighbor_preserved_long_lived_forwarding_state is not None:
                                            return True

                                        if self.neighbor_version is not None:
                                            return True

                                        if self.number_of_best_externalpaths is not None:
                                            return True

                                        if self.number_of_bestpaths is not None:
                                            return True

                                        if self.orf_entries_received is not None:
                                            return True

                                        if self.orr_group_index is not None:
                                            return True

                                        if self.orr_group_name is not None:
                                            return True

                                        if self.outstanding_version is not None:
                                            return True

                                        if self.outstanding_version_max is not None:
                                            return True

                                        if self.prefixes_accepted is not None:
                                            return True

                                        if self.prefixes_advertised is not None:
                                            return True

                                        if self.prefixes_be_advertised is not None:
                                            return True

                                        if self.prefixes_denied is not None:
                                            return True

                                        if self.prefixes_denied_no_policy is not None:
                                            return True

                                        if self.prefixes_denied_non_cumulative is not None:
                                            return True

                                        if self.prefixes_denied_orf_policy is not None:
                                            return True

                                        if self.prefixes_denied_policy is not None:
                                            return True

                                        if self.prefixes_denied_rt_permit is not None:
                                            return True

                                        if self.prefixes_suppressed is not None:
                                            return True

                                        if self.prefixes_synced is not None:
                                            return True

                                        if self.prefixes_withdrawn is not None:
                                            return True

                                        if self.prefixes_withdrawn_not_found is not None:
                                            return True

                                        if self.refresh_acked_version is not None:
                                            return True

                                        if self.refresh_target_version is not None:
                                            return True

                                        if self.refresh_version is not None:
                                            return True

                                        if self.remove_private_as_entire_aspath_from_inbound_updates is not None:
                                            return True

                                        if self.remove_private_as_entire_aspath_from_updates is not None:
                                            return True

                                        if self.remove_private_as_from_inbound_updates is not None:
                                            return True

                                        if self.remove_private_as_from_updates is not None:
                                            return True

                                        if self.restart_time is not None:
                                            return True

                                        if self.rib_purge_timeout_value is not None:
                                            return True

                                        if self.route_policy_default_originate is not None:
                                            return True

                                        if self.route_policy_in is not None:
                                            return True

                                        if self.route_policy_out is not None:
                                            return True

                                        if self.route_policy_prefix_orf is not None:
                                            return True

                                        if self.route_refreshes_received is not None:
                                            return True

                                        if self.route_refreshes_sent is not None:
                                            return True

                                        if self.selective_multipath_eligible is not None:
                                            return True

                                        if self.sent_community_to_neighbor is not None:
                                            return True

                                        if self.sent_extended_community_to_neighbor is not None:
                                            return True

                                        if self.sent_gshut_community_to_neighbor is not None:
                                            return True

                                        if self.stale_path_timeout is not None:
                                            return True

                                        if self.synced_acked_version is not None:
                                            return True

                                        if self.update_group_number is not None:
                                            return True

                                        if self.use_max_prefix_warning_only is not None:
                                            return True

                                        if self.vpn_update_gen_enabled is not None:
                                            return True

                                        if self.vpn_update_gen_trigger_enabled is not None:
                                            return True

                                        if self.weight is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.neighbor_address is None:
                                        raise YPYModelError('Key property neighbor_address is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address = ' + str(self.neighbor_address) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.neighbor_address is not None:
                                        return True

                                    if self.active_bmp_servers is not None:
                                        return True

                                    if self.actual_last_write_bytes is not None:
                                        return True

                                    if self.actual_last_write_reset_bytes is not None:
                                        return True

                                    if self.actual_second_last_write_bytes is not None:
                                        return True

                                    if self.actual_second_last_write_reset_bytes is not None:
                                        return True

                                    if self.af_data is not None:
                                        for child_ref in self.af_data:
                                            if child_ref._has_data():
                                                return True

                                    if self.attempted_last_write_bytes is not None:
                                        return True

                                    if self.attempted_last_write_reset_bytes is not None:
                                        return True

                                    if self.attempted_second_last_write_bytes is not None:
                                        return True

                                    if self.attempted_second_last_write_reset_bytes is not None:
                                        return True

                                    if self.bfd_minintervalval is not None:
                                        return True

                                    if self.bfd_multiplierval is not None:
                                        return True

                                    if self.bfd_session_created_state is not None:
                                        return True

                                    if self.bfd_session_enable_mode is not None:
                                        return True

                                    if self.bfd_session_state is not None:
                                        return True

                                    if self.bfd_state_ts is not None:
                                        return True

                                    if self.bytes_read is not None:
                                        return True

                                    if self.bytes_written is not None:
                                        return True

                                    if self.configured_hold_time is not None:
                                        return True

                                    if self.configured_keepalive is not None:
                                        return True

                                    if self.configured_min_acc_hold_time is not None:
                                        return True

                                    if self.connect_retry_interval is not None:
                                        return True

                                    if self.connection_admin_status is not None:
                                        return True

                                    if self.connection_down_count is not None:
                                        return True

                                    if self.connection_established_time is not None:
                                        return True

                                    if self.connection_local_address is not None and self.connection_local_address._has_data():
                                        return True

                                    if self.connection_local_port is not None:
                                        return True

                                    if self.connection_remote_address is not None and self.connection_remote_address._has_data():
                                        return True

                                    if self.connection_remote_port is not None:
                                        return True

                                    if self.connection_state is not None:
                                        return True

                                    if self.connection_up_count is not None:
                                        return True

                                    if self.count_last_write is not None:
                                        return True

                                    if self.description is not None:
                                        return True

                                    if self.discard_as4_path is not None:
                                        return True

                                    if self.discard_data_bytes is not None:
                                        return True

                                    if self.dmz_link_bandwidth is not None:
                                        return True

                                    if self.dynamic_neighbor is not None:
                                        return True

                                    if self.ebgp_recv_dmz is not None:
                                        return True

                                    if self.ebgp_send_dmz_mode is not None:
                                        return True

                                    if self.ebgp_time_to_live is not None:
                                        return True

                                    if self.egress_peer_engineering_enabled is not None:
                                        return True

                                    if self.error_notifies_received is not None:
                                        return True

                                    if self.error_notifies_sent is not None:
                                        return True

                                    if self.fpbsn_offset is not None:
                                        return True

                                    if self.fssn_offset is not None:
                                        return True

                                    if self.gr_restart_time is not None:
                                        return True

                                    if self.gr_stale_path_time is not None:
                                        return True

                                    if self.graceful_maintenance is not None and self.graceful_maintenance._has_data():
                                        return True

                                    if self.graceful_restart_enabled_nbr is not None:
                                        return True

                                    if self.has_internal_link is not None:
                                        return True

                                    if self.hold_time is not None:
                                        return True

                                    if self.ignore_connected is not None:
                                        return True

                                    if self.internal_vpn_client is not None:
                                        return True

                                    if self.io_armed is not None:
                                        return True

                                    if self.is4_byte_as_capability_received is not None:
                                        return True

                                    if self.is4_byte_as_capability_sent is not None:
                                        return True

                                    if self.is_administratively_shut_down is not None:
                                        return True

                                    if self.is_capability_negotiation_performed is not None:
                                        return True

                                    if self.is_capability_negotiation_suppressed is not None:
                                        return True

                                    if self.is_ebgp_multihop_bgpmpls_forwarding_disabled is not None:
                                        return True

                                    if self.is_ebgp_peer_as_league is not None:
                                        return True

                                    if self.is_ebgp_peer_common_admin is not None:
                                        return True

                                    if self.is_external_neighbor_not_directly_connected is not None:
                                        return True

                                    if self.is_gr_aware is not None:
                                        return True

                                    if self.is_local_address_configured is not None:
                                        return True

                                    if self.is_neighbor_max_prefix_shutdown is not None:
                                        return True

                                    if self.is_out_of_memory_forced_up is not None:
                                        return True

                                    if self.is_out_of_memory_shutdown is not None:
                                        return True

                                    if self.is_passive_close is not None:
                                        return True

                                    if self.is_read_disabled is not None:
                                        return True

                                    if self.is_route_refresh_capability_received is not None:
                                        return True

                                    if self.is_route_refresh_old_capability_received is not None:
                                        return True

                                    if self.keep_alive_time is not None:
                                        return True

                                    if self.last_ackd_seq_no is not None:
                                        return True

                                    if self.last_k_aerror_reset is not None:
                                        return True

                                    if self.last_k_aexpiry_reset is not None:
                                        return True

                                    if self.last_k_anotsent_reset is not None:
                                        return True

                                    if self.last_k_astart_reset is not None:
                                        return True

                                    if self.last_notify_error_code is not None:
                                        return True

                                    if self.last_notify_error_subcode is not None:
                                        return True

                                    if self.last_write_event is not None:
                                        return True

                                    if self.local_as is not None:
                                        return True

                                    if self.local_as_dual_as is not None:
                                        return True

                                    if self.local_as_dual_as_mode_native is not None:
                                        return True

                                    if self.local_as_no_prepend is not None:
                                        return True

                                    if self.local_as_replace_as is not None:
                                        return True

                                    if self.message_statistics is not None and self.message_statistics._has_data():
                                        return True

                                    if self.messages_queued_in is not None:
                                        return True

                                    if self.messages_queued_out is not None:
                                        return True

                                    if self.messages_received is not None:
                                        return True

                                    if self.messages_sent is not None:
                                        return True

                                    if self.min_advertise_interval is not None:
                                        return True

                                    if self.min_advertise_interval_msecs is not None:
                                        return True

                                    if self.min_origination_interval is not None:
                                        return True

                                    if self.msg_log_in is not None:
                                        return True

                                    if self.msg_log_out is not None:
                                        return True

                                    if self.multi_protocol_capability_received is not None:
                                        return True

                                    if self.nbr_cluster_id is not None:
                                        return True

                                    if self.nbr_enforce_first_as is not None:
                                        return True

                                    if self.nbr_in_cluster is not None:
                                        return True

                                    if self.negotiated_protocol_version is not None:
                                        return True

                                    if self.neighbor_interface_handle is not None:
                                        return True

                                    if self.neighbor_local_as is not None:
                                        return True

                                    if self.nsr_enabled is not None:
                                        return True

                                    if self.nsr_state is not None:
                                        return True

                                    if self.open_check_error_code is not None:
                                        return True

                                    if self.peer_error_code is not None:
                                        return True

                                    if self.peer_reset_reason is not None:
                                        return True

                                    if self.performance_statistics is not None and self.performance_statistics._has_data():
                                        return True

                                    if self.previous_connection_state is not None:
                                        return True

                                    if self.read_armed is not None:
                                        return True

                                    if self.received_notification_info is not None and self.received_notification_info._has_data():
                                        return True

                                    if self.remote_as is not None:
                                        return True

                                    if self.remote_as_number is not None:
                                        return True

                                    if self.reset_notification_sent is not None:
                                        return True

                                    if self.reset_reason is not None:
                                        return True

                                    if self.router_id is not None:
                                        return True

                                    if self.rpki_allow_invalid is not None:
                                        return True

                                    if self.rpki_disable is not None:
                                        return True

                                    if self.rpki_signal_ibgp is not None:
                                        return True

                                    if self.rpki_use_validity is not None:
                                        return True

                                    if self.second_last_k_aexpiry_reset is not None:
                                        return True

                                    if self.second_last_k_astart_reset is not None:
                                        return True

                                    if self.second_last_write_event is not None:
                                        return True

                                    if self.send_notification_info is not None and self.send_notification_info._has_data():
                                        return True

                                    if self.socket_read_bytes is not None:
                                        return True

                                    if self.speaker_id is not None:
                                        return True

                                    if self.standby_rp is not None:
                                        return True

                                    if self.suppress4_byte_as is not None:
                                        return True

                                    if self.tcp_init_sync_done_time_spec is not None and self.tcp_init_sync_done_time_spec._has_data():
                                        return True

                                    if self.tcp_init_sync_phase_two_time_spec is not None and self.tcp_init_sync_phase_two_time_spec._has_data():
                                        return True

                                    if self.tcp_init_sync_time_spec is not None and self.tcp_init_sync_time_spec._has_data():
                                        return True

                                    if self.tcp_session_open_mode is not None:
                                        return True

                                    if self.tcpmss is not None:
                                        return True

                                    if self.time_last_cb is not None:
                                        return True

                                    if self.time_last_cb_reset is not None:
                                        return True

                                    if self.time_last_fb is not None:
                                        return True

                                    if self.time_since_connection_last_dropped is not None:
                                        return True

                                    if self.time_since_last_read is not None:
                                        return True

                                    if self.time_since_last_read_reset is not None:
                                        return True

                                    if self.time_since_last_update is not None:
                                        return True

                                    if self.time_since_last_write is not None:
                                        return True

                                    if self.time_since_last_write_reset is not None:
                                        return True

                                    if self.time_since_second_last_write is not None:
                                        return True

                                    if self.time_since_second_last_write_reset is not None:
                                        return True

                                    if self.tos_type is not None:
                                        return True

                                    if self.tos_value is not None:
                                        return True

                                    if self.ttl_security_enabled is not None:
                                        return True

                                    if self.update_bytes_read is not None:
                                        return True

                                    if self.update_messages_in is not None:
                                        return True

                                    if self.update_messages_out is not None:
                                        return True

                                    if self.vrf_name is not None:
                                        return True

                                    if self.write_armed is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbors'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.neighbor is not None:
                                    for child_ref in self.neighbor:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors']['meta_info']


                        class NextHopVrf(object):
                            """
                            A BGP Next\-hop VRF table entry
                            
                            .. attribute:: last_notification_processing_time
                            
                            	Processing time for the last notification
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_notificationication_time
                            
                            	Time since the last notification was received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_notification_bestpath_changes
                            
                            	Number of bestpath changes caused by notification which resulted in maximum processing
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_notification_bestpath_deletes
                            
                            	Number of bestpath deletes caused by notification which resulted in maximum processing
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_proc_notification_time
                            
                            	How long since the maximum processing time notifcation was received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_processing_time
                            
                            	Maximum time spent procesing a single batch notification
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total_processing_time
                            
                            	Total time spent in processing
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.last_notification_processing_time = None
                                self.last_notificationication_time = None
                                self.max_notification_bestpath_changes = None
                                self.max_notification_bestpath_deletes = None
                                self.max_proc_notification_time = None
                                self.maximum_processing_time = None
                                self.total_processing_time = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop-vrf'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.last_notification_processing_time is not None:
                                    return True

                                if self.last_notificationication_time is not None:
                                    return True

                                if self.max_notification_bestpath_changes is not None:
                                    return True

                                if self.max_notification_bestpath_deletes is not None:
                                    return True

                                if self.max_proc_notification_time is not None:
                                    return True

                                if self.maximum_processing_time is not None:
                                    return True

                                if self.total_processing_time is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NextHopVrf']['meta_info']


                        class NeighborRanges(object):
                            """
                            The BGP Dynamic Neighbor Range table
                            
                            .. attribute:: neighbor_range
                            
                            	A BGP Neighbor Range table entry
                            	**type**\: list of    :py:class:`NeighborRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.neighbor_range = YList()
                                self.neighbor_range.parent = self
                                self.neighbor_range.name = 'neighbor_range'


                            class NeighborRange(object):
                                """
                                A BGP Neighbor Range table entry
                                
                                .. attribute:: neighbor_range_address  <key>
                                
                                	Neighbor Range prefix
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                
                                ----
                                .. attribute:: active_bmp_servers
                                
                                	BMP Servers to which the neighbor sends logs
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: addpath_receive_disable
                                
                                	Addpath Receive Disabled
                                	**type**\:  bool
                                
                                .. attribute:: addpath_receive_enable
                                
                                	Addpath Receive enable
                                	**type**\:  bool
                                
                                .. attribute:: addpath_send_disable
                                
                                	Addpath Send Disabled
                                	**type**\:  bool
                                
                                .. attribute:: addpath_send_enable
                                
                                	Addpath Send enabled
                                	**type**\:  bool
                                
                                .. attribute:: af_data
                                
                                	Address family specific neighbor data
                                	**type**\: list of    :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData>`
                                
                                .. attribute:: attrf_group_name
                                
                                	Attrf Group Name
                                	**type**\:  str
                                
                                .. attribute:: bfd_minintervalval
                                
                                	BFD Mininterval for this peer
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_multiplierval
                                
                                	BFD Multiplier for this peer
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_session_enable_mode
                                
                                	BFD enable mode for this peer
                                	**type**\:   :py:class:`BgpBfdEnableModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdEnableModeEnum>`
                                
                                .. attribute:: cfg_local_address
                                
                                	Configured local address
                                	**type**\:   :py:class:`CfgLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress>`
                                
                                .. attribute:: configured_hold_time
                                
                                	Hold time (in secs) configured for this connection
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: configured_keepalive
                                
                                	Keepalive time (in secs) configured for this connection
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: configured_min_acc_hold_time
                                
                                	Minimum acceptable hold time from neighbor (in secs) configured for this connection
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: connection_local_address
                                
                                	Local address for the connection
                                	**type**\:   :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress>`
                                
                                .. attribute:: connection_remote_address
                                
                                	Remote address for the connection
                                	**type**\:   :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress>`
                                
                                .. attribute:: current_peers
                                
                                	Current Dynamic nbrs in range
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: description
                                
                                	Description
                                	**type**\:  str
                                
                                .. attribute:: discard_as4_path
                                
                                	Discard AS4\_PATH in case there is a discrepancy in merging AS\_PATH and AS4\_PATH,retain ASPATH
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: dmz_link_bandwidth
                                
                                	Bandwidth of link to single\-hop eBGP peer
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ebgp_recv_dmz
                                
                                	Receive Bandwidth of link to single\-hop eBGP peer
                                	**type**\:  bool
                                
                                .. attribute:: ebgp_send_dmz_mode
                                
                                	Ebgp send dmz link bw mode
                                	**type**\:   :py:class:`BgpEbgpSendDmzEnableModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableModeEnum>`
                                
                                .. attribute:: ebgp_time_to_live
                                
                                	Maximum number of hops for external BGP neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: egress_peer_engineering_enabled
                                
                                	Indicates if Egress Peer Engineering is enabled
                                	**type**\:  bool
                                
                                .. attribute:: gr_restart_time
                                
                                	Neighbor restart time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: gr_stale_path_time
                                
                                	Neighbor stale\-path time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: graceful_maintenance
                                
                                	Graceful Maintenance
                                	**type**\:   :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.GracefulMaintenance>`
                                
                                .. attribute:: graceful_restart_enabled_nbr
                                
                                	Neighbor supports graceful\-restart
                                	**type**\:  bool
                                
                                .. attribute:: has_internal_link
                                
                                	Internal link to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: idle_watch_time
                                
                                	Dynamic Neighbor idle\-watch time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: ignore_connected
                                
                                	If true, the VPN client isan IBGP CE peer
                                	**type**\:  bool
                                
                                .. attribute:: instance
                                
                                	Dynamic Neighbor Instance List
                                	**type**\: list of    :py:class:`Instance_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_>`
                                
                                .. attribute:: internal_vpn_client
                                
                                	If true, don't do NHconnected check for nbr
                                	**type**\:  bool
                                
                                .. attribute:: is_administratively_shut_down
                                
                                	Neighbor is administratively shut down
                                	**type**\:  bool
                                
                                .. attribute:: is_capability_negotiation_performed
                                
                                	Capability negotiation performed
                                	**type**\:  bool
                                
                                .. attribute:: is_ebgp_multihop_bgpmpls_forwarding_disabled
                                
                                	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_local_address_configured
                                
                                	Local address configured for the neighbor connection
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_max_prefix_shutdown
                                
                                	Neighbor shut down because it exceeded max prfx count
                                	**type**\:  bool
                                
                                .. attribute:: is_out_of_memory_forced_up
                                
                                	Neighbor forced up during a low memory condition
                                	**type**\:  bool
                                
                                .. attribute:: is_passive_close
                                
                                	If true, active socket canbe closed if passive openis received for a GRcapable neighbor
                                	**type**\:  bool
                                
                                .. attribute:: islocal_address_cfg
                                
                                	Local address configured
                                	**type**\:  bool
                                
                                .. attribute:: local_as
                                
                                	Local AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_as_dual_as
                                
                                	Local AS Dual\-AS option
                                	**type**\:  bool
                                
                                .. attribute:: local_as_dual_as_mode_native
                                
                                	Applies only if Local AS Dual\-AS option is enabled. Indicates if Dual\-AS mode is native
                                	**type**\:  bool
                                
                                .. attribute:: local_as_no_prepend
                                
                                	Option to not prepend the Local AS to announcements
                                	**type**\:  bool
                                
                                .. attribute:: local_as_replace_as
                                
                                	Local AS Replace\-AS option
                                	**type**\:  bool
                                
                                .. attribute:: max_peers
                                
                                	Max Dynamic nbrs in range
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: min_advertise_interval
                                
                                	Minimum advertisement interval, secs part
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: min_advertise_interval_msecs
                                
                                	Minimum advertisement interval, msecs part
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: min_origination_interval
                                
                                	Minimum origination interval (in secs)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: msg_buf_count
                                
                                	Message Buf Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: msg_bug_circular
                                
                                	Message Buf Circular
                                	**type**\:  bool
                                
                                .. attribute:: msg_log_in
                                
                                	Message in log count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: msg_log_out
                                
                                	Message out log count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nbr_cluster_id
                                
                                	Cluster id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nbr_enforce_first_as
                                
                                	Neighbor enforce first AS
                                	**type**\:  bool
                                
                                .. attribute:: nbr_in_cluster
                                
                                	Type of cluster\_id\:undefined/number/Ip address
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: nbr_rcv_size
                                
                                	Nbr Receive Size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nbr_send_size
                                
                                	Nbr Send Size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_local_as
                                
                                	Local AS configured on the neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_range_prefix_length
                                
                                	Neighbor Range Prefix Length
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: nsr_enabled
                                
                                	Neighbor supports NSR
                                	**type**\:  bool
                                
                                .. attribute:: oper_attrf_enable
                                
                                	Oper attrf Enable
                                	**type**\:  bool
                                
                                .. attribute:: range_inst_error
                                
                                	Error during instance creation
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: range_max_drop
                                
                                	open drop due to max peers
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: range_open_accepted
                                
                                	open accepted
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: range_open_match
                                
                                	Passive open matching range
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_as
                                
                                	Remote AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_as_list_name
                                
                                	Remote AS List Name
                                	**type**\:  str
                                
                                .. attribute:: remote_as_number
                                
                                	Remote AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rpki_allow_invalid
                                
                                	Prefix v. allow invalid
                                	**type**\:  bool
                                
                                .. attribute:: rpki_disable
                                
                                	Prefix validation disabled
                                	**type**\:  bool
                                
                                .. attribute:: rpki_signal_ibgp
                                
                                	Prefix v. signal ibgp
                                	**type**\:  bool
                                
                                .. attribute:: rpki_use_validity
                                
                                	Prefix v. use validity
                                	**type**\:  bool
                                
                                .. attribute:: speaker_id
                                
                                	Speaker this neighbor is allocated to
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: standby_rp
                                
                                	Standby RP socket inited for Active Open
                                	**type**\:  bool
                                
                                .. attribute:: suppress4_byte_as
                                
                                	Suppress 4byteas capability
                                	**type**\:  bool
                                
                                .. attribute:: syslog_enable
                                
                                	syslog enable
                                	**type**\:  bool
                                
                                .. attribute:: tcp_session_open_mode
                                
                                	The TCP mode to be used to set up BGP session with the neighbor
                                	**type**\:   :py:class:`BgpTcpModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpModeEnum>`
                                
                                .. attribute:: tcpmss
                                
                                	Neighbor TCP Maximum Segment                     size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tos_type
                                
                                	Precedence or DSCP type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_value
                                
                                	Precedence or DSCP value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ttl_security_enabled
                                
                                	TTL Security enabled
                                	**type**\:  bool
                                
                                .. attribute:: upd_errh_noreset
                                
                                	Update errh noreset
                                	**type**\:  bool
                                
                                .. attribute:: update_source
                                
                                	Update Source
                                	**type**\:  str
                                
                                .. attribute:: vrf_name
                                
                                	Name of the VRF
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.neighbor_range_address = None
                                    self.active_bmp_servers = None
                                    self.addpath_receive_disable = None
                                    self.addpath_receive_enable = None
                                    self.addpath_send_disable = None
                                    self.addpath_send_enable = None
                                    self.af_data = YList()
                                    self.af_data.parent = self
                                    self.af_data.name = 'af_data'
                                    self.attrf_group_name = None
                                    self.bfd_minintervalval = None
                                    self.bfd_multiplierval = None
                                    self.bfd_session_enable_mode = None
                                    self.cfg_local_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress()
                                    self.cfg_local_address.parent = self
                                    self.configured_hold_time = None
                                    self.configured_keepalive = None
                                    self.configured_min_acc_hold_time = None
                                    self.connection_local_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress()
                                    self.connection_local_address.parent = self
                                    self.connection_remote_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress()
                                    self.connection_remote_address.parent = self
                                    self.current_peers = None
                                    self.description = None
                                    self.discard_as4_path = None
                                    self.dmz_link_bandwidth = None
                                    self.ebgp_recv_dmz = None
                                    self.ebgp_send_dmz_mode = None
                                    self.ebgp_time_to_live = None
                                    self.egress_peer_engineering_enabled = None
                                    self.gr_restart_time = None
                                    self.gr_stale_path_time = None
                                    self.graceful_maintenance = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.GracefulMaintenance()
                                    self.graceful_maintenance.parent = self
                                    self.graceful_restart_enabled_nbr = None
                                    self.has_internal_link = None
                                    self.idle_watch_time = None
                                    self.ignore_connected = None
                                    self.instance = YList()
                                    self.instance.parent = self
                                    self.instance.name = 'instance'
                                    self.internal_vpn_client = None
                                    self.is_administratively_shut_down = None
                                    self.is_capability_negotiation_performed = None
                                    self.is_ebgp_multihop_bgpmpls_forwarding_disabled = None
                                    self.is_local_address_configured = None
                                    self.is_neighbor_max_prefix_shutdown = None
                                    self.is_out_of_memory_forced_up = None
                                    self.is_passive_close = None
                                    self.islocal_address_cfg = None
                                    self.local_as = None
                                    self.local_as_dual_as = None
                                    self.local_as_dual_as_mode_native = None
                                    self.local_as_no_prepend = None
                                    self.local_as_replace_as = None
                                    self.max_peers = None
                                    self.min_advertise_interval = None
                                    self.min_advertise_interval_msecs = None
                                    self.min_origination_interval = None
                                    self.msg_buf_count = None
                                    self.msg_bug_circular = None
                                    self.msg_log_in = None
                                    self.msg_log_out = None
                                    self.nbr_cluster_id = None
                                    self.nbr_enforce_first_as = None
                                    self.nbr_in_cluster = None
                                    self.nbr_rcv_size = None
                                    self.nbr_send_size = None
                                    self.neighbor_local_as = None
                                    self.neighbor_range_prefix_length = None
                                    self.nsr_enabled = None
                                    self.oper_attrf_enable = None
                                    self.range_inst_error = None
                                    self.range_max_drop = None
                                    self.range_open_accepted = None
                                    self.range_open_match = None
                                    self.remote_as = None
                                    self.remote_as_list_name = None
                                    self.remote_as_number = None
                                    self.rpki_allow_invalid = None
                                    self.rpki_disable = None
                                    self.rpki_signal_ibgp = None
                                    self.rpki_use_validity = None
                                    self.speaker_id = None
                                    self.standby_rp = None
                                    self.suppress4_byte_as = None
                                    self.syslog_enable = None
                                    self.tcp_session_open_mode = None
                                    self.tcpmss = None
                                    self.tos_type = None
                                    self.tos_value = None
                                    self.ttl_security_enabled = None
                                    self.upd_errh_noreset = None
                                    self.update_source = None
                                    self.vrf_name = None


                                class ConnectionLocalAddress(object):
                                    """
                                    Local address for the connection
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpnvpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnvplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4mdt_address = None
                                        self.ipv4mvpn_address = None
                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                        self.ipv4sr_policy_address.parent = self
                                        self.ipv4vpn_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                        self.ipv6sr_policy_address.parent = self
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_flowspec_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.l2vpn_evpn_address = None
                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnvplsAddress()
                                        self.l2vpnvpls_address.parent = self
                                        self.ls_ls_address = None
                                        self.rt_constraint_address = None


                                    class L2VpnvplsAddress(object):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnvplsAddress']['meta_info']


                                    class L2VpnMspwAddress(object):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnMspwAddress']['meta_info']


                                    class Ipv4SrPolicyAddress(object):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress']['meta_info']


                                    class Ipv6SrPolicyAddress(object):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv6_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv6_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connection-local-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.afi is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv4_flowspec_address is not None:
                                            return True

                                        if self.ipv4_label_address is not None:
                                            return True

                                        if self.ipv4_mcast_address is not None:
                                            return True

                                        if self.ipv4_tunnel_address is not None:
                                            return True

                                        if self.ipv4mdt_address is not None:
                                            return True

                                        if self.ipv4mvpn_address is not None:
                                            return True

                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                            return True

                                        if self.ipv4vpn_address is not None:
                                            return True

                                        if self.ipv4vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv4vpna_mcastddress is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        if self.ipv6_flowspec_address is not None:
                                            return True

                                        if self.ipv6_label_address is not None:
                                            return True

                                        if self.ipv6_mcast_address is not None:
                                            return True

                                        if self.ipv6mvpn_address is not None:
                                            return True

                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                            return True

                                        if self.ipv6vpn_address is not None:
                                            return True

                                        if self.ipv6vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv6vpn_mcast_address is not None:
                                            return True

                                        if self.l2vpn_evpn_address is not None:
                                            return True

                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                            return True

                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                            return True

                                        if self.ls_ls_address is not None:
                                            return True

                                        if self.rt_constraint_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress']['meta_info']


                                class ConnectionRemoteAddress(object):
                                    """
                                    Remote address for the connection
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpnvpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnvplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4mdt_address = None
                                        self.ipv4mvpn_address = None
                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                        self.ipv4sr_policy_address.parent = self
                                        self.ipv4vpn_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                        self.ipv6sr_policy_address.parent = self
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_flowspec_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.l2vpn_evpn_address = None
                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnvplsAddress()
                                        self.l2vpnvpls_address.parent = self
                                        self.ls_ls_address = None
                                        self.rt_constraint_address = None


                                    class L2VpnvplsAddress(object):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnvplsAddress']['meta_info']


                                    class L2VpnMspwAddress(object):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnMspwAddress']['meta_info']


                                    class Ipv4SrPolicyAddress(object):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress']['meta_info']


                                    class Ipv6SrPolicyAddress(object):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv6_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv6_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connection-remote-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.afi is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv4_flowspec_address is not None:
                                            return True

                                        if self.ipv4_label_address is not None:
                                            return True

                                        if self.ipv4_mcast_address is not None:
                                            return True

                                        if self.ipv4_tunnel_address is not None:
                                            return True

                                        if self.ipv4mdt_address is not None:
                                            return True

                                        if self.ipv4mvpn_address is not None:
                                            return True

                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                            return True

                                        if self.ipv4vpn_address is not None:
                                            return True

                                        if self.ipv4vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv4vpna_mcastddress is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        if self.ipv6_flowspec_address is not None:
                                            return True

                                        if self.ipv6_label_address is not None:
                                            return True

                                        if self.ipv6_mcast_address is not None:
                                            return True

                                        if self.ipv6mvpn_address is not None:
                                            return True

                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                            return True

                                        if self.ipv6vpn_address is not None:
                                            return True

                                        if self.ipv6vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv6vpn_mcast_address is not None:
                                            return True

                                        if self.l2vpn_evpn_address is not None:
                                            return True

                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                            return True

                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                            return True

                                        if self.ls_ls_address is not None:
                                            return True

                                        if self.rt_constraint_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress']['meta_info']


                                class GracefulMaintenance(object):
                                    """
                                    Graceful Maintenance
                                    
                                    .. attribute:: gshut_active
                                    
                                    	Graceful Maintenance activated
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_exists
                                    
                                    	Graceful Maintenance enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_local_active
                                    
                                    	Graceful Maintenance locally activated
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_locpref
                                    
                                    	Graceful Maintenance Local Preference
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: gshut_locpref_set
                                    
                                    	Graceful Maintenance Local Preference set
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_prepends
                                    
                                    	Graceful Maintenance number of AS prepends
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.gshut_active = None
                                        self.gshut_exists = None
                                        self.gshut_local_active = None
                                        self.gshut_locpref = None
                                        self.gshut_locpref_set = None
                                        self.gshut_prepends = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:graceful-maintenance'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.gshut_active is not None:
                                            return True

                                        if self.gshut_exists is not None:
                                            return True

                                        if self.gshut_local_active is not None:
                                            return True

                                        if self.gshut_locpref is not None:
                                            return True

                                        if self.gshut_locpref_set is not None:
                                            return True

                                        if self.gshut_prepends is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.GracefulMaintenance']['meta_info']


                                class CfgLocalAddress(object):
                                    """
                                    Configured local address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpnvpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnvplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4mdt_address = None
                                        self.ipv4mvpn_address = None
                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress()
                                        self.ipv4sr_policy_address.parent = self
                                        self.ipv4vpn_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress()
                                        self.ipv6sr_policy_address.parent = self
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_flowspec_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.l2vpn_evpn_address = None
                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnvplsAddress()
                                        self.l2vpnvpls_address.parent = self
                                        self.ls_ls_address = None
                                        self.rt_constraint_address = None


                                    class L2VpnvplsAddress(object):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnvplsAddress']['meta_info']


                                    class L2VpnMspwAddress(object):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnMspwAddress']['meta_info']


                                    class Ipv4SrPolicyAddress(object):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress']['meta_info']


                                    class Ipv6SrPolicyAddress(object):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv6_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv6_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cfg-local-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.afi is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv4_flowspec_address is not None:
                                            return True

                                        if self.ipv4_label_address is not None:
                                            return True

                                        if self.ipv4_mcast_address is not None:
                                            return True

                                        if self.ipv4_tunnel_address is not None:
                                            return True

                                        if self.ipv4mdt_address is not None:
                                            return True

                                        if self.ipv4mvpn_address is not None:
                                            return True

                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                            return True

                                        if self.ipv4vpn_address is not None:
                                            return True

                                        if self.ipv4vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv4vpna_mcastddress is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        if self.ipv6_flowspec_address is not None:
                                            return True

                                        if self.ipv6_label_address is not None:
                                            return True

                                        if self.ipv6_mcast_address is not None:
                                            return True

                                        if self.ipv6mvpn_address is not None:
                                            return True

                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                            return True

                                        if self.ipv6vpn_address is not None:
                                            return True

                                        if self.ipv6vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv6vpn_mcast_address is not None:
                                            return True

                                        if self.l2vpn_evpn_address is not None:
                                            return True

                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                            return True

                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                            return True

                                        if self.ls_ls_address is not None:
                                            return True

                                        if self.rt_constraint_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress']['meta_info']


                                class AfData(object):
                                    """
                                    Address family specific neighbor data
                                    
                                    .. attribute:: accept_own_enabled
                                    
                                    	Accept\-Own enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: address_family_long_lived_time
                                    
                                    	AF specific Long\-lived\-time config
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: advertise_afi
                                    
                                    	Encode in Advertise AFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_afi_disable
                                    
                                    	Encode in Advertise AFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_afi_local
                                    
                                    	Encode in Advertise AFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_afi_reorg
                                    
                                    	Encode in Advertise AFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_v4_flags
                                    
                                    	Advertise options for VPNV4
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: advertise_v6_flags
                                    
                                    	Advertise options for VPNV6
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: afrpki_allow_invalid
                                    
                                    	Prefix v. allow invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: afrpki_disable
                                    
                                    	Prefix validation disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: afrpki_signal_ibgp
                                    
                                    	Prefix v. signal ibgp
                                    	**type**\:  bool
                                    
                                    .. attribute:: afrpki_use_validity
                                    
                                    	Prefix v. use validity
                                    	**type**\:  bool
                                    
                                    .. attribute:: allow_as_in_count
                                    
                                    	Allowas\-in count config
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: always_use_next_hop_local
                                    
                                    	Local router always used for next\-hop
                                    	**type**\:  bool
                                    
                                    .. attribute:: extended_community
                                    
                                    	Extended community attribute
                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity>`
                                    
                                    .. attribute:: extended_community_standby
                                    
                                    	Extended community attribute
                                    	**type**\: list of    :py:class:`ExtendedCommunityStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby>`
                                    
                                    .. attribute:: flowspec_redirect_validation_d_isable
                                    
                                    	Flowspec Redirect Validation Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flowspec_validation_d_isable
                                    
                                    	Flowspec Validation Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: import_reoriginate
                                    
                                    	Import Reoriginate enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: import_reoriginate_stitching
                                    
                                    	Import Reoriginate Stitching enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: import_stitching
                                    
                                    	Import Stitching enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_add_path_receive_capability_advertised
                                    
                                    	Addpath Receive capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_add_path_receive_capability_received
                                    
                                    	Addpath Receive capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_add_path_send_capability_advertised
                                    
                                    	Addpath Send capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_add_path_send_capability_received
                                    
                                    	Addpath Send capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_addpath_receive_operational
                                    
                                    	Addpath is operational on receive\-side
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_addpath_send_operational
                                    
                                    	Addpath is operational on send\-side
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_advertise_permanent_network
                                    
                                    	Advertise Permanent Network
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_advertised_graceful_restart
                                    
                                    	Graceful Restart Capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_advertised_orf_receive
                                    
                                    	Prefix based ORF receive mode capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_advertised_orf_send
                                    
                                    	Prefix based ORF send mode capability advertised
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_aigp_set
                                    
                                    	AIGP set 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_allow_as_in_set
                                    
                                    	Allowas\-in set 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_as_override_set
                                    
                                    	As override set 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_graceful_restart_state_flag
                                    
                                    	Restart state flag enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_legacy_pe_rt
                                    
                                    	Nbr accepts route from legacy PE for RT\-Constraint AF 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_af_capable
                                    
                                    	Address family capability received from neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_ebgp_without_inbound_policy
                                    
                                    	eBGP neighbor with no configured inbound policy
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_ebgp_without_outbound_policy
                                    
                                    	eBGP neighbor with no configured outbound policy
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_route_reflector_client
                                    
                                    	Nbr is a route reflector client
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_orf_send_scheduled
                                    
                                    	Scheduled to send prefix based ORF
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_orf_sent
                                    
                                    	Outbound route filter sent to neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_orr_root_address_configured
                                    
                                    	ORR Root address configuredfor the neighbor connection
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_peer_orf_capable
                                    
                                    	Peer has outbound route filter capability
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_prefix_orf_present
                                    
                                    	Outbound route filter prefix ORF present
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_received_graceful_restart_capable
                                    
                                    	Graceful Restart Capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_received_orf_receive_capable
                                    
                                    	Prefix based ORF receive mode capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_received_orf_send_capable
                                    
                                    	Prefix based ORF send mode capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_rt_present
                                    
                                    	RT attribute list present
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_rt_present_standby
                                    
                                    	RT attribute list present
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_send_mcast_attr
                                    
                                    	Send Mcast Attr
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_soft_reconfiguration_inbound_allowed
                                    
                                    	Inbound soft reconfiguration allowed
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_update_deferred
                                    
                                    	Update deferred until ORF/route refresh received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_use_soft_reconfiguration_always_on
                                    
                                    	Soft reconf overrides route refresh
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_restart_time
                                    
                                    	Local Restart time (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: long_lived_graceful_restart_capability_received
                                    
                                    	Long\-lived graceful\-restart capability received from the neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_accept
                                    
                                    	Maximum long\-lived graceful\-restart stale time acceptable from the neighbor (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_configured
                                    
                                    	Long\-lived graceful\-restart stale time is configured
                                    	**type**\:  bool
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_received
                                    
                                    	Long\-lived graceful\-restart stale time received from the neighbor (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_sent
                                    
                                    	Stale time sent in long\-lived graceful\-restart capability (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: max_prefix_discard_extra_paths
                                    
                                    	Discard extra paths when prefix limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: max_prefix_exceed_discard_paths
                                    
                                    	Did we discard extra paths when prefix limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: max_prefix_limit
                                    
                                    	Max limit for # of prefixes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: max_prefix_restart_time
                                    
                                    	Time interval (in minutes) after which peering session will be reestablished
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: minute
                                    
                                    .. attribute:: max_prefix_threshold_percent
                                    
                                    	Percentage of maximum no. of prefixes at which to generate warning
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: percentage
                                    
                                    .. attribute:: neighbor_default_originate
                                    
                                    	Neighbor originates default
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_long_lived_graceful_restart_capable
                                    
                                    	Treat neighbor as long\-lived graceful\-restart capable
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_long_lived_graceful_restart_time_remaining
                                    
                                    	Remaining long\-lived graceful\-restart time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_preserved_forwarding_state
                                    
                                    	Neighbor preserved forwarding state
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_preserved_long_lived_forwarding_state
                                    
                                    	Neighbor preserved long\-lived forwarding state
                                    	**type**\:  bool
                                    
                                    .. attribute:: next_hop_unchanged
                                    
                                    	router does not change next\-hop
                                    	**type**\:  bool
                                    
                                    .. attribute:: orf_entries_received
                                    
                                    	Number of outbound route filter entries received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: orr_group_index
                                    
                                    	ORR Group Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: orr_group_name
                                    
                                    	ORR Group Name
                                    	**type**\:  str
                                    
                                    .. attribute:: remove_private_as_entire_aspath_from_inbound_updates
                                    
                                    	Private AS numbers removed from updates from this nbr only if the aspath has only private ASes
                                    	**type**\:  bool
                                    
                                    .. attribute:: remove_private_as_entire_aspath_from_updates
                                    
                                    	Private AS numbers removed from updates to thisnbr only if the aspath hasonly private ASes
                                    	**type**\:  bool
                                    
                                    .. attribute:: remove_private_as_from_inbound_updates
                                    
                                    	Private AS numbers removed from updates from this nbr
                                    	**type**\:  bool
                                    
                                    .. attribute:: remove_private_as_from_updates
                                    
                                    	Private AS numbers removed from updates to this nbr
                                    	**type**\:  bool
                                    
                                    .. attribute:: restart_time
                                    
                                    	Restart time advertised (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: rib_purge_timeout_value
                                    
                                    	RIB purge timeout time (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: route_policy_default_originate
                                    
                                    	Default\-originate route policy name
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_in
                                    
                                    	Incoming route policy name
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_out
                                    
                                    	Outgoing route policy name
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_prefix_orf
                                    
                                    	Prefix based ORF for incoming updates
                                    	**type**\:  str
                                    
                                    .. attribute:: selective_multipath_eligible
                                    
                                    	Selective multipath eligible
                                    	**type**\:  bool
                                    
                                    .. attribute:: sent_community_to_neighbor
                                    
                                    	Community attribute sent to neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: sent_extended_community_to_neighbor
                                    
                                    	Extended community attribute sent to neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: sent_gshut_community_to_neighbor
                                    
                                    	GSHUT Community attribute sent to neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: stale_path_timeout
                                    
                                    	Stale path timeout time (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: use_max_prefix_warning_only
                                    
                                    	Warning only when maximum prefix limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: vpn_update_gen_enabled
                                    
                                    	RT Nbr enabled for updategento another
                                    	**type**\:  bool
                                    
                                    .. attribute:: vpn_update_gen_trigger_enabled
                                    
                                    	RT Nbr enabled for updategento another
                                    	**type**\:  bool
                                    
                                    .. attribute:: weight
                                    
                                    	Weight for this AF
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.accept_own_enabled = None
                                        self.address_family_long_lived_time = None
                                        self.advertise_afi = None
                                        self.advertise_afi_disable = None
                                        self.advertise_afi_local = None
                                        self.advertise_afi_reorg = None
                                        self.advertise_v4_flags = None
                                        self.advertise_v6_flags = None
                                        self.af_name = None
                                        self.afrpki_allow_invalid = None
                                        self.afrpki_disable = None
                                        self.afrpki_signal_ibgp = None
                                        self.afrpki_use_validity = None
                                        self.allow_as_in_count = None
                                        self.always_use_next_hop_local = None
                                        self.extended_community = YList()
                                        self.extended_community.parent = self
                                        self.extended_community.name = 'extended_community'
                                        self.extended_community_standby = YList()
                                        self.extended_community_standby.parent = self
                                        self.extended_community_standby.name = 'extended_community_standby'
                                        self.flowspec_redirect_validation_d_isable = None
                                        self.flowspec_validation_d_isable = None
                                        self.import_reoriginate = None
                                        self.import_reoriginate_stitching = None
                                        self.import_stitching = None
                                        self.is_add_path_receive_capability_advertised = None
                                        self.is_add_path_receive_capability_received = None
                                        self.is_add_path_send_capability_advertised = None
                                        self.is_add_path_send_capability_received = None
                                        self.is_addpath_receive_operational = None
                                        self.is_addpath_send_operational = None
                                        self.is_advertise_permanent_network = None
                                        self.is_advertised_graceful_restart = None
                                        self.is_advertised_orf_receive = None
                                        self.is_advertised_orf_send = None
                                        self.is_aigp_set = None
                                        self.is_allow_as_in_set = None
                                        self.is_as_override_set = None
                                        self.is_graceful_restart_state_flag = None
                                        self.is_legacy_pe_rt = None
                                        self.is_neighbor_af_capable = None
                                        self.is_neighbor_ebgp_without_inbound_policy = None
                                        self.is_neighbor_ebgp_without_outbound_policy = None
                                        self.is_neighbor_route_reflector_client = None
                                        self.is_orf_send_scheduled = None
                                        self.is_orf_sent = None
                                        self.is_orr_root_address_configured = None
                                        self.is_peer_orf_capable = None
                                        self.is_prefix_orf_present = None
                                        self.is_received_graceful_restart_capable = None
                                        self.is_received_orf_receive_capable = None
                                        self.is_received_orf_send_capable = None
                                        self.is_rt_present = None
                                        self.is_rt_present_standby = None
                                        self.is_send_mcast_attr = None
                                        self.is_soft_reconfiguration_inbound_allowed = None
                                        self.is_update_deferred = None
                                        self.is_use_soft_reconfiguration_always_on = None
                                        self.local_restart_time = None
                                        self.long_lived_graceful_restart_capability_received = None
                                        self.long_lived_graceful_restart_stale_time_accept = None
                                        self.long_lived_graceful_restart_stale_time_configured = None
                                        self.long_lived_graceful_restart_stale_time_received = None
                                        self.long_lived_graceful_restart_stale_time_sent = None
                                        self.max_prefix_discard_extra_paths = None
                                        self.max_prefix_exceed_discard_paths = None
                                        self.max_prefix_limit = None
                                        self.max_prefix_restart_time = None
                                        self.max_prefix_threshold_percent = None
                                        self.neighbor_default_originate = None
                                        self.neighbor_long_lived_graceful_restart_capable = None
                                        self.neighbor_long_lived_graceful_restart_time_remaining = None
                                        self.neighbor_preserved_forwarding_state = None
                                        self.neighbor_preserved_long_lived_forwarding_state = None
                                        self.next_hop_unchanged = None
                                        self.orf_entries_received = None
                                        self.orr_group_index = None
                                        self.orr_group_name = None
                                        self.remove_private_as_entire_aspath_from_inbound_updates = None
                                        self.remove_private_as_entire_aspath_from_updates = None
                                        self.remove_private_as_from_inbound_updates = None
                                        self.remove_private_as_from_updates = None
                                        self.restart_time = None
                                        self.rib_purge_timeout_value = None
                                        self.route_policy_default_originate = None
                                        self.route_policy_in = None
                                        self.route_policy_out = None
                                        self.route_policy_prefix_orf = None
                                        self.selective_multipath_eligible = None
                                        self.sent_community_to_neighbor = None
                                        self.sent_extended_community_to_neighbor = None
                                        self.sent_gshut_community_to_neighbor = None
                                        self.stale_path_timeout = None
                                        self.use_max_prefix_warning_only = None
                                        self.vpn_update_gen_enabled = None
                                        self.vpn_update_gen_trigger_enabled = None
                                        self.weight = None


                                    class ExtendedCommunity(object):
                                        """
                                        Extended community attribute
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.entry = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.entry is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity']['meta_info']


                                    class ExtendedCommunityStandby(object):
                                        """
                                        Extended community attribute
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.entry = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community-standby'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.entry is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af-data'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.accept_own_enabled is not None:
                                            return True

                                        if self.address_family_long_lived_time is not None:
                                            return True

                                        if self.advertise_afi is not None:
                                            return True

                                        if self.advertise_afi_disable is not None:
                                            return True

                                        if self.advertise_afi_local is not None:
                                            return True

                                        if self.advertise_afi_reorg is not None:
                                            return True

                                        if self.advertise_v4_flags is not None:
                                            return True

                                        if self.advertise_v6_flags is not None:
                                            return True

                                        if self.af_name is not None:
                                            return True

                                        if self.afrpki_allow_invalid is not None:
                                            return True

                                        if self.afrpki_disable is not None:
                                            return True

                                        if self.afrpki_signal_ibgp is not None:
                                            return True

                                        if self.afrpki_use_validity is not None:
                                            return True

                                        if self.allow_as_in_count is not None:
                                            return True

                                        if self.always_use_next_hop_local is not None:
                                            return True

                                        if self.extended_community is not None:
                                            for child_ref in self.extended_community:
                                                if child_ref._has_data():
                                                    return True

                                        if self.extended_community_standby is not None:
                                            for child_ref in self.extended_community_standby:
                                                if child_ref._has_data():
                                                    return True

                                        if self.flowspec_redirect_validation_d_isable is not None:
                                            return True

                                        if self.flowspec_validation_d_isable is not None:
                                            return True

                                        if self.import_reoriginate is not None:
                                            return True

                                        if self.import_reoriginate_stitching is not None:
                                            return True

                                        if self.import_stitching is not None:
                                            return True

                                        if self.is_add_path_receive_capability_advertised is not None:
                                            return True

                                        if self.is_add_path_receive_capability_received is not None:
                                            return True

                                        if self.is_add_path_send_capability_advertised is not None:
                                            return True

                                        if self.is_add_path_send_capability_received is not None:
                                            return True

                                        if self.is_addpath_receive_operational is not None:
                                            return True

                                        if self.is_addpath_send_operational is not None:
                                            return True

                                        if self.is_advertise_permanent_network is not None:
                                            return True

                                        if self.is_advertised_graceful_restart is not None:
                                            return True

                                        if self.is_advertised_orf_receive is not None:
                                            return True

                                        if self.is_advertised_orf_send is not None:
                                            return True

                                        if self.is_aigp_set is not None:
                                            return True

                                        if self.is_allow_as_in_set is not None:
                                            return True

                                        if self.is_as_override_set is not None:
                                            return True

                                        if self.is_graceful_restart_state_flag is not None:
                                            return True

                                        if self.is_legacy_pe_rt is not None:
                                            return True

                                        if self.is_neighbor_af_capable is not None:
                                            return True

                                        if self.is_neighbor_ebgp_without_inbound_policy is not None:
                                            return True

                                        if self.is_neighbor_ebgp_without_outbound_policy is not None:
                                            return True

                                        if self.is_neighbor_route_reflector_client is not None:
                                            return True

                                        if self.is_orf_send_scheduled is not None:
                                            return True

                                        if self.is_orf_sent is not None:
                                            return True

                                        if self.is_orr_root_address_configured is not None:
                                            return True

                                        if self.is_peer_orf_capable is not None:
                                            return True

                                        if self.is_prefix_orf_present is not None:
                                            return True

                                        if self.is_received_graceful_restart_capable is not None:
                                            return True

                                        if self.is_received_orf_receive_capable is not None:
                                            return True

                                        if self.is_received_orf_send_capable is not None:
                                            return True

                                        if self.is_rt_present is not None:
                                            return True

                                        if self.is_rt_present_standby is not None:
                                            return True

                                        if self.is_send_mcast_attr is not None:
                                            return True

                                        if self.is_soft_reconfiguration_inbound_allowed is not None:
                                            return True

                                        if self.is_update_deferred is not None:
                                            return True

                                        if self.is_use_soft_reconfiguration_always_on is not None:
                                            return True

                                        if self.local_restart_time is not None:
                                            return True

                                        if self.long_lived_graceful_restart_capability_received is not None:
                                            return True

                                        if self.long_lived_graceful_restart_stale_time_accept is not None:
                                            return True

                                        if self.long_lived_graceful_restart_stale_time_configured is not None:
                                            return True

                                        if self.long_lived_graceful_restart_stale_time_received is not None:
                                            return True

                                        if self.long_lived_graceful_restart_stale_time_sent is not None:
                                            return True

                                        if self.max_prefix_discard_extra_paths is not None:
                                            return True

                                        if self.max_prefix_exceed_discard_paths is not None:
                                            return True

                                        if self.max_prefix_limit is not None:
                                            return True

                                        if self.max_prefix_restart_time is not None:
                                            return True

                                        if self.max_prefix_threshold_percent is not None:
                                            return True

                                        if self.neighbor_default_originate is not None:
                                            return True

                                        if self.neighbor_long_lived_graceful_restart_capable is not None:
                                            return True

                                        if self.neighbor_long_lived_graceful_restart_time_remaining is not None:
                                            return True

                                        if self.neighbor_preserved_forwarding_state is not None:
                                            return True

                                        if self.neighbor_preserved_long_lived_forwarding_state is not None:
                                            return True

                                        if self.next_hop_unchanged is not None:
                                            return True

                                        if self.orf_entries_received is not None:
                                            return True

                                        if self.orr_group_index is not None:
                                            return True

                                        if self.orr_group_name is not None:
                                            return True

                                        if self.remove_private_as_entire_aspath_from_inbound_updates is not None:
                                            return True

                                        if self.remove_private_as_entire_aspath_from_updates is not None:
                                            return True

                                        if self.remove_private_as_from_inbound_updates is not None:
                                            return True

                                        if self.remove_private_as_from_updates is not None:
                                            return True

                                        if self.restart_time is not None:
                                            return True

                                        if self.rib_purge_timeout_value is not None:
                                            return True

                                        if self.route_policy_default_originate is not None:
                                            return True

                                        if self.route_policy_in is not None:
                                            return True

                                        if self.route_policy_out is not None:
                                            return True

                                        if self.route_policy_prefix_orf is not None:
                                            return True

                                        if self.selective_multipath_eligible is not None:
                                            return True

                                        if self.sent_community_to_neighbor is not None:
                                            return True

                                        if self.sent_extended_community_to_neighbor is not None:
                                            return True

                                        if self.sent_gshut_community_to_neighbor is not None:
                                            return True

                                        if self.stale_path_timeout is not None:
                                            return True

                                        if self.use_max_prefix_warning_only is not None:
                                            return True

                                        if self.vpn_update_gen_enabled is not None:
                                            return True

                                        if self.vpn_update_gen_trigger_enabled is not None:
                                            return True

                                        if self.weight is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData']['meta_info']


                                class Instance_(object):
                                    """
                                    Dynamic Neighbor Instance List
                                    
                                    .. attribute:: connection_state
                                    
                                    	State of connection
                                    	**type**\:   :py:class:`BgpConnStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnStateEnum>`
                                    
                                    .. attribute:: idle_watch_timer_remaining_value
                                    
                                    	Idle watch timer remaining time
                                    	**type**\:   :py:class:`IdleWatchTimerRemainingValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.IdleWatchTimerRemainingValue>`
                                    
                                    .. attribute:: is_idle_watch_timer_running
                                    
                                    	Is idle watch timer running
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Dynamic Neighbor address
                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress>`
                                    
                                    .. attribute:: neighbor_age
                                    
                                    	Neighbor age
                                    	**type**\:   :py:class:`NeighborAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAge>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.connection_state = None
                                        self.idle_watch_timer_remaining_value = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.IdleWatchTimerRemainingValue()
                                        self.idle_watch_timer_remaining_value.parent = self
                                        self.is_idle_watch_timer_running = None
                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress()
                                        self.neighbor_address.parent = self
                                        self.neighbor_age = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAge()
                                        self.neighbor_age.parent = self


                                    class NeighborAddress(object):
                                        """
                                        Dynamic Neighbor address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress']['meta_info']


                                    class NeighborAge(object):
                                        """
                                        Neighbor age
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-age'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAge']['meta_info']


                                    class IdleWatchTimerRemainingValue(object):
                                        """
                                        Idle watch timer remaining time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:idle-watch-timer-remaining-value'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.IdleWatchTimerRemainingValue']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:instance'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.connection_state is not None:
                                            return True

                                        if self.idle_watch_timer_remaining_value is not None and self.idle_watch_timer_remaining_value._has_data():
                                            return True

                                        if self.is_idle_watch_timer_running is not None:
                                            return True

                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                            return True

                                        if self.neighbor_age is not None and self.neighbor_age._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.neighbor_range_address is None:
                                        raise YPYModelError('Key property neighbor_range_address is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-range[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-range-address = ' + str(self.neighbor_range_address) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.neighbor_range_address is not None:
                                        return True

                                    if self.active_bmp_servers is not None:
                                        return True

                                    if self.addpath_receive_disable is not None:
                                        return True

                                    if self.addpath_receive_enable is not None:
                                        return True

                                    if self.addpath_send_disable is not None:
                                        return True

                                    if self.addpath_send_enable is not None:
                                        return True

                                    if self.af_data is not None:
                                        for child_ref in self.af_data:
                                            if child_ref._has_data():
                                                return True

                                    if self.attrf_group_name is not None:
                                        return True

                                    if self.bfd_minintervalval is not None:
                                        return True

                                    if self.bfd_multiplierval is not None:
                                        return True

                                    if self.bfd_session_enable_mode is not None:
                                        return True

                                    if self.cfg_local_address is not None and self.cfg_local_address._has_data():
                                        return True

                                    if self.configured_hold_time is not None:
                                        return True

                                    if self.configured_keepalive is not None:
                                        return True

                                    if self.configured_min_acc_hold_time is not None:
                                        return True

                                    if self.connection_local_address is not None and self.connection_local_address._has_data():
                                        return True

                                    if self.connection_remote_address is not None and self.connection_remote_address._has_data():
                                        return True

                                    if self.current_peers is not None:
                                        return True

                                    if self.description is not None:
                                        return True

                                    if self.discard_as4_path is not None:
                                        return True

                                    if self.dmz_link_bandwidth is not None:
                                        return True

                                    if self.ebgp_recv_dmz is not None:
                                        return True

                                    if self.ebgp_send_dmz_mode is not None:
                                        return True

                                    if self.ebgp_time_to_live is not None:
                                        return True

                                    if self.egress_peer_engineering_enabled is not None:
                                        return True

                                    if self.gr_restart_time is not None:
                                        return True

                                    if self.gr_stale_path_time is not None:
                                        return True

                                    if self.graceful_maintenance is not None and self.graceful_maintenance._has_data():
                                        return True

                                    if self.graceful_restart_enabled_nbr is not None:
                                        return True

                                    if self.has_internal_link is not None:
                                        return True

                                    if self.idle_watch_time is not None:
                                        return True

                                    if self.ignore_connected is not None:
                                        return True

                                    if self.instance is not None:
                                        for child_ref in self.instance:
                                            if child_ref._has_data():
                                                return True

                                    if self.internal_vpn_client is not None:
                                        return True

                                    if self.is_administratively_shut_down is not None:
                                        return True

                                    if self.is_capability_negotiation_performed is not None:
                                        return True

                                    if self.is_ebgp_multihop_bgpmpls_forwarding_disabled is not None:
                                        return True

                                    if self.is_local_address_configured is not None:
                                        return True

                                    if self.is_neighbor_max_prefix_shutdown is not None:
                                        return True

                                    if self.is_out_of_memory_forced_up is not None:
                                        return True

                                    if self.is_passive_close is not None:
                                        return True

                                    if self.islocal_address_cfg is not None:
                                        return True

                                    if self.local_as is not None:
                                        return True

                                    if self.local_as_dual_as is not None:
                                        return True

                                    if self.local_as_dual_as_mode_native is not None:
                                        return True

                                    if self.local_as_no_prepend is not None:
                                        return True

                                    if self.local_as_replace_as is not None:
                                        return True

                                    if self.max_peers is not None:
                                        return True

                                    if self.min_advertise_interval is not None:
                                        return True

                                    if self.min_advertise_interval_msecs is not None:
                                        return True

                                    if self.min_origination_interval is not None:
                                        return True

                                    if self.msg_buf_count is not None:
                                        return True

                                    if self.msg_bug_circular is not None:
                                        return True

                                    if self.msg_log_in is not None:
                                        return True

                                    if self.msg_log_out is not None:
                                        return True

                                    if self.nbr_cluster_id is not None:
                                        return True

                                    if self.nbr_enforce_first_as is not None:
                                        return True

                                    if self.nbr_in_cluster is not None:
                                        return True

                                    if self.nbr_rcv_size is not None:
                                        return True

                                    if self.nbr_send_size is not None:
                                        return True

                                    if self.neighbor_local_as is not None:
                                        return True

                                    if self.neighbor_range_prefix_length is not None:
                                        return True

                                    if self.nsr_enabled is not None:
                                        return True

                                    if self.oper_attrf_enable is not None:
                                        return True

                                    if self.range_inst_error is not None:
                                        return True

                                    if self.range_max_drop is not None:
                                        return True

                                    if self.range_open_accepted is not None:
                                        return True

                                    if self.range_open_match is not None:
                                        return True

                                    if self.remote_as is not None:
                                        return True

                                    if self.remote_as_list_name is not None:
                                        return True

                                    if self.remote_as_number is not None:
                                        return True

                                    if self.rpki_allow_invalid is not None:
                                        return True

                                    if self.rpki_disable is not None:
                                        return True

                                    if self.rpki_signal_ibgp is not None:
                                        return True

                                    if self.rpki_use_validity is not None:
                                        return True

                                    if self.speaker_id is not None:
                                        return True

                                    if self.standby_rp is not None:
                                        return True

                                    if self.suppress4_byte_as is not None:
                                        return True

                                    if self.syslog_enable is not None:
                                        return True

                                    if self.tcp_session_open_mode is not None:
                                        return True

                                    if self.tcpmss is not None:
                                        return True

                                    if self.tos_type is not None:
                                        return True

                                    if self.tos_value is not None:
                                        return True

                                    if self.ttl_security_enabled is not None:
                                        return True

                                    if self.upd_errh_noreset is not None:
                                        return True

                                    if self.update_source is not None:
                                        return True

                                    if self.vrf_name is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-ranges'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.neighbor_range is not None:
                                    for child_ref in self.neighbor_range:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges']['meta_info']


                        class MessageLogs(object):
                            """
                            The BGP Neighbor Message table
                            
                            .. attribute:: message_log
                            
                            	A BGP Message log entry
                            	**type**\: list of    :py:class:`MessageLog <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.message_log = YList()
                                self.message_log.parent = self
                                self.message_log.name = 'message_log'


                            class MessageLog(object):
                                """
                                A BGP Message log entry
                                
                                .. attribute:: direction
                                
                                	Direction
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: neighbor_message
                                
                                	Array of Neighbor Messages in one direction
                                	**type**\: list of    :py:class:`NeighborMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.direction = None
                                    self.neighbor_address = None
                                    self.neighbor_message = YList()
                                    self.neighbor_message.parent = self
                                    self.neighbor_message.name = 'neighbor_message'


                                class NeighborMessage(object):
                                    """
                                    Array of Neighbor Messages in one direction
                                    
                                    .. attribute:: logged_message_data
                                    
                                    	Raw Message data in binary format
                                    	**type**\: list of    :py:class:`LoggedMessageData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData>`
                                    
                                    .. attribute:: message_data_length
                                    
                                    	Message data length
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: message_timestamp
                                    
                                    	message received time\: time elapsed since 00\:00 \:00 UTC, January 1, 1970
                                    	**type**\:   :py:class:`MessageTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp>`
                                    
                                    .. attribute:: message_type_received
                                    
                                    	Type of messages Received
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: total_logged_message_count
                                    
                                    	Total logged messages count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.logged_message_data = YList()
                                        self.logged_message_data.parent = self
                                        self.logged_message_data.name = 'logged_message_data'
                                        self.message_data_length = None
                                        self.message_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp()
                                        self.message_timestamp.parent = self
                                        self.message_type_received = None
                                        self.total_logged_message_count = None


                                    class MessageTimestamp(object):
                                        """
                                        message received time\: time elapsed since 00\:00
                                        \:00 UTC, January 1, 1970
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:message-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp']['meta_info']


                                    class LoggedMessageData(object):
                                        """
                                        Raw Message data in binary format
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.entry = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:logged-message-data'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.entry is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-message'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.logged_message_data is not None:
                                            for child_ref in self.logged_message_data:
                                                if child_ref._has_data():
                                                    return True

                                        if self.message_data_length is not None:
                                            return True

                                        if self.message_timestamp is not None and self.message_timestamp._has_data():
                                            return True

                                        if self.message_type_received is not None:
                                            return True

                                        if self.total_logged_message_count is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:message-log'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.direction is not None:
                                        return True

                                    if self.neighbor_address is not None:
                                        return True

                                    if self.neighbor_message is not None:
                                        for child_ref in self.neighbor_message:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:message-logs'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.message_log is not None:
                                    for child_ref in self.message_log:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.vrf_name is None:
                                raise YPYModelError('Key property vrf_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:vrf[Cisco-IOS-XR-ipv4-bgp-oper:vrf-name = ' + str(self.vrf_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.vrf_name is not None:
                                return True

                            if self.afs is not None and self.afs._has_data():
                                return True

                            if self.bmp is not None and self.bmp._has_data():
                                return True

                            if self.global_process_info is not None and self.global_process_info._has_data():
                                return True

                            if self.information is not None and self.information._has_data():
                                return True

                            if self.message_logs is not None and self.message_logs._has_data():
                                return True

                            if self.neighbor_ranges is not None and self.neighbor_ranges._has_data():
                                return True

                            if self.neighbors is not None and self.neighbors._has_data():
                                return True

                            if self.next_hop_vrf is not None and self.next_hop_vrf._has_data():
                                return True

                            if self.postits is not None and self.postits._has_data():
                                return True

                            if self.process_info is not None and self.process_info._has_data():
                                return True

                            if self.sessions is not None and self.sessions._has_data():
                                return True

                            if self.update_inbound_error_neighbors is not None and self.update_inbound_error_neighbors._has_data():
                                return True

                            if self.update_inbound_error_vrf is not None and self.update_inbound_error_vrf._has_data():
                                return True

                            if self.update_inbound_filter_neighbors is not None and self.update_inbound_filter_neighbors._has_data():
                                return True

                            if self.update_inbound_filter_vrf is not None and self.update_inbound_filter_vrf._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:vrfs'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.vrf is not None:
                            for child_ref in self.vrf:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Vrfs']['meta_info']


                class DefaultVrf(object):
                    """
                    Default VRF related operational data
                    
                    .. attribute:: afs
                    
                    	BGP address family table
                    	**type**\:   :py:class:`Afs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs>`
                    
                    .. attribute:: bmp
                    
                    	BMP related Operational Data
                    	**type**\:   :py:class:`Bmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp>`
                    
                    .. attribute:: global_process_info
                    
                    	The Global Process information table
                    	**type**\:   :py:class:`GlobalProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo>`
                    
                    .. attribute:: information
                    
                    	Meta data for VRF
                    	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Information>`
                    
                    .. attribute:: message_logs
                    
                    	The BGP Neighbor Message table
                    	**type**\:   :py:class:`MessageLogs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs>`
                    
                    .. attribute:: neighbor_ranges
                    
                    	The BGP Dynamic Neighbor Range table
                    	**type**\:   :py:class:`NeighborRanges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges>`
                    
                    .. attribute:: neighbors
                    
                    	The BGP Neighbor table
                    	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors>`
                    
                    .. attribute:: next_hop_vrf
                    
                    	A BGP Next\-hop VRF table entry
                    	**type**\:   :py:class:`NextHopVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NextHopVrf>`
                    
                    .. attribute:: postits
                    
                    	The BGP Neighbor table
                    	**type**\:   :py:class:`Postits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits>`
                    
                    .. attribute:: process_info
                    
                    	A Process instance table entry
                    	**type**\:   :py:class:`ProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo>`
                    
                    .. attribute:: sessions
                    
                    	The BGP session table
                    	**type**\:   :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions>`
                    
                    .. attribute:: update_inbound_error_neighbors
                    
                    	Update inbound error information for all neighbors
                    	**type**\:   :py:class:`UpdateInboundErrorNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors>`
                    
                    .. attribute:: update_inbound_error_vrf
                    
                    	Update inbound error information for the VRF
                    	**type**\:   :py:class:`UpdateInboundErrorVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorVrf>`
                    
                    .. attribute:: update_inbound_filter_neighbors
                    
                    	Update inbound filtering information for all neighbors
                    	**type**\:   :py:class:`UpdateInboundFilterNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors>`
                    
                    .. attribute:: update_inbound_filter_vrf
                    
                    	Update inbound filtering information for the VRF
                    	**type**\:   :py:class:`UpdateInboundFilterVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterVrf>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2015-08-27'

                    def __init__(self):
                        self.parent = None
                        self.afs = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs()
                        self.afs.parent = self
                        self.bmp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp()
                        self.bmp.parent = self
                        self.global_process_info = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo()
                        self.global_process_info.parent = self
                        self.information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Information()
                        self.information.parent = self
                        self.message_logs = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs()
                        self.message_logs.parent = self
                        self.neighbor_ranges = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges()
                        self.neighbor_ranges.parent = self
                        self.neighbors = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors()
                        self.neighbors.parent = self
                        self.next_hop_vrf = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NextHopVrf()
                        self.next_hop_vrf.parent = self
                        self.postits = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits()
                        self.postits.parent = self
                        self.process_info = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo()
                        self.process_info.parent = self
                        self.sessions = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions()
                        self.sessions.parent = self
                        self.update_inbound_error_neighbors = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors()
                        self.update_inbound_error_neighbors.parent = self
                        self.update_inbound_error_vrf = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorVrf()
                        self.update_inbound_error_vrf.parent = self
                        self.update_inbound_filter_neighbors = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors()
                        self.update_inbound_filter_neighbors.parent = self
                        self.update_inbound_filter_vrf = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterVrf()
                        self.update_inbound_filter_vrf.parent = self


                    class UpdateInboundErrorVrf(object):
                        """
                        Update inbound error information for the VRF
                        
                        .. attribute:: last_update_malformed_age
                        
                        	Time since last malformed messages received event (in seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: last_update_malformed_timestamp
                        
                        	Last malformed messages received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                        	**type**\:   :py:class:`LastUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp>`
                        
                        .. attribute:: update_malformed_message_count
                        
                        	Malformed messages count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_malformed_neighbor_count
                        
                        	Count of neighbors that received malformed messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_vrf_name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.last_update_malformed_age = None
                            self.last_update_malformed_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp()
                            self.last_update_malformed_timestamp.parent = self
                            self.update_malformed_message_count = None
                            self.update_malformed_neighbor_count = None
                            self.update_vrf_name = None


                        class LastUpdateMalformedTimestamp(object):
                            """
                            Last malformed messages received time\: time
                            elapsed since 00\:00\:00 UTC, January 1, 1970
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.nanoseconds = None
                                self.seconds = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-malformed-timestamp'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.nanoseconds is not None:
                                    return True

                                if self.seconds is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-inbound-error-vrf'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.last_update_malformed_age is not None:
                                return True

                            if self.last_update_malformed_timestamp is not None and self.last_update_malformed_timestamp._has_data():
                                return True

                            if self.update_malformed_message_count is not None:
                                return True

                            if self.update_malformed_neighbor_count is not None:
                                return True

                            if self.update_vrf_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorVrf']['meta_info']


                    class Afs(object):
                        """
                        BGP address family table
                        
                        .. attribute:: af
                        
                        	A particular address family
                        	**type**\: list of    :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.af = YList()
                            self.af.parent = self
                            self.af.name = 'af'


                        class Af(object):
                            """
                            A particular address family
                            
                            .. attribute:: af_name  <key>
                            
                            	Address family
                            	**type**\:   :py:class:`BgpAddressFamilyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamilyEnum>`
                            
                            .. attribute:: advertised_path_counts
                            
                            	The BGP Advertised paths table (bestpath)
                            	**type**\:   :py:class:`AdvertisedPathCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathCounts>`
                            
                            .. attribute:: advertised_path_xr
                            
                            	The BGP Advertised path table (bestpath)
                            	**type**\:   :py:class:`AdvertisedPathXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr>`
                            
                            .. attribute:: advertised_paths
                            
                            	The BGP Advertised paths table (add\-paths)
                            	**type**\:   :py:class:`AdvertisedPaths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths>`
                            
                            .. attribute:: af_process_info
                            
                            	A BGP Process address family table entry
                            	**type**\:   :py:class:`AfProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo>`
                            
                            .. attribute:: attributes
                            
                            	The BGP Attribute table
                            	**type**\:   :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes>`
                            
                            .. attribute:: bmp_paths
                            
                            	The paths in BMP Table
                            	**type**\:   :py:class:`BmpPaths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths>`
                            
                            .. attribute:: convergence
                            
                            	A BGP Convergence table entry
                            	**type**\:   :py:class:`Convergence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Convergence>`
                            
                            .. attribute:: dampenings
                            
                            	The BGP Dampening table
                            	**type**\:   :py:class:`Dampenings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings>`
                            
                            .. attribute:: epes
                            
                            	The BGP Egress Engineering table
                            	**type**\:   :py:class:`Epes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes>`
                            
                            .. attribute:: global_af_process_info
                            
                            	The Global Address Family Process information table
                            	**type**\:   :py:class:`GlobalAfProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo>`
                            
                            .. attribute:: neighbor_af_table
                            
                            	The BGP Neighbor AF table
                            	**type**\:   :py:class:`NeighborAfTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable>`
                            
                            .. attribute:: network_all_rds
                            
                            	The BGP Network Lookup Table
                            	**type**\:   :py:class:`NetworkAllRds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds>`
                            
                            .. attribute:: network_lookup_all_rds
                            
                            	The BGP Network Lookup Table
                            	**type**\:   :py:class:`NetworkLookupAllRds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds>`
                            
                            .. attribute:: network_prefixes
                            
                            	The BGP Network Lookup table
                            	**type**\:   :py:class:`NetworkPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes>`
                            
                            .. attribute:: networks
                            
                            	The BGP Network Table
                            	**type**\:   :py:class:`Networks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks>`
                            
                            .. attribute:: next_hop_address_families
                            
                            	Address family of nexthop table
                            	**type**\:   :py:class:`NextHopAddressFamilies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies>`
                            
                            .. attribute:: path_labeled_table
                            
                            	The BGP Path Labeled Table
                            	**type**\:   :py:class:`PathLabeledTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable>`
                            
                            .. attribute:: path_table
                            
                            	The BGP Path Table
                            	**type**\:   :py:class:`PathTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable>`
                            
                            .. attribute:: path_used_table
                            
                            	The BGP Path Used Table
                            	**type**\:   :py:class:`PathUsedTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable>`
                            
                            .. attribute:: policies
                            
                            	The BGP Policy Table
                            	**type**\:   :py:class:`Policies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies>`
                            
                            .. attribute:: prefix_filters
                            
                            	The BGP Prefix Filter table
                            	**type**\:   :py:class:`PrefixFilters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters>`
                            
                            .. attribute:: rpc_sets
                            
                            	BGP next\-hop set table
                            	**type**\:   :py:class:`RpcSets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets>`
                            
                            .. attribute:: rt_set_counters
                            
                            	The RT\-set counter table
                            	**type**\:   :py:class:`RtSetCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters>`
                            
                            .. attribute:: sourced_networks
                            
                            	The BGP Convergence table
                            	**type**\:   :py:class:`SourcedNetworks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks>`
                            
                            .. attribute:: update_generation_address_family
                            
                            	Update generation for address\-family
                            	**type**\:   :py:class:`UpdateGenerationAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily>`
                            
                            .. attribute:: update_generation_filter_groups
                            
                            	Update generation for all filter\-groups under a sub\-group
                            	**type**\:   :py:class:`UpdateGenerationFilterGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups>`
                            
                            .. attribute:: update_generation_neighbors
                            
                            	Update generation for all neighbors
                            	**type**\:   :py:class:`UpdateGenerationNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors>`
                            
                            .. attribute:: update_generation_sub_groups
                            
                            	Update generation for all sub\-groups
                            	**type**\:   :py:class:`UpdateGenerationSubGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups>`
                            
                            .. attribute:: update_generation_update_groups
                            
                            	Update generation for all update\-groups
                            	**type**\:   :py:class:`UpdateGenerationUpdateGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups>`
                            
                            .. attribute:: update_groups
                            
                            	The BGP Update group table
                            	**type**\:   :py:class:`UpdateGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.af_name = None
                                self.advertised_path_counts = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathCounts()
                                self.advertised_path_counts.parent = self
                                self.advertised_path_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr()
                                self.advertised_path_xr.parent = self
                                self.advertised_paths = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths()
                                self.advertised_paths.parent = self
                                self.af_process_info = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo()
                                self.af_process_info.parent = self
                                self.attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes()
                                self.attributes.parent = self
                                self.bmp_paths = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths()
                                self.bmp_paths.parent = self
                                self.convergence = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Convergence()
                                self.convergence.parent = self
                                self.dampenings = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings()
                                self.dampenings.parent = self
                                self.epes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes()
                                self.epes.parent = self
                                self.global_af_process_info = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo()
                                self.global_af_process_info.parent = self
                                self.neighbor_af_table = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable()
                                self.neighbor_af_table.parent = self
                                self.network_all_rds = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds()
                                self.network_all_rds.parent = self
                                self.network_lookup_all_rds = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds()
                                self.network_lookup_all_rds.parent = self
                                self.network_prefixes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes()
                                self.network_prefixes.parent = self
                                self.networks = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks()
                                self.networks.parent = self
                                self.next_hop_address_families = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies()
                                self.next_hop_address_families.parent = self
                                self.path_labeled_table = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable()
                                self.path_labeled_table.parent = self
                                self.path_table = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable()
                                self.path_table.parent = self
                                self.path_used_table = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable()
                                self.path_used_table.parent = self
                                self.policies = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies()
                                self.policies.parent = self
                                self.prefix_filters = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters()
                                self.prefix_filters.parent = self
                                self.rpc_sets = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets()
                                self.rpc_sets.parent = self
                                self.rt_set_counters = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters()
                                self.rt_set_counters.parent = self
                                self.sourced_networks = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks()
                                self.sourced_networks.parent = self
                                self.update_generation_address_family = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily()
                                self.update_generation_address_family.parent = self
                                self.update_generation_filter_groups = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups()
                                self.update_generation_filter_groups.parent = self
                                self.update_generation_neighbors = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors()
                                self.update_generation_neighbors.parent = self
                                self.update_generation_sub_groups = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups()
                                self.update_generation_sub_groups.parent = self
                                self.update_generation_update_groups = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups()
                                self.update_generation_update_groups.parent = self
                                self.update_groups = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups()
                                self.update_groups.parent = self


                            class NetworkLookupAllRds(object):
                                """
                                The BGP Network Lookup Table
                                
                                .. attribute:: network_lookup_all_rd
                                
                                	The BGP Network Lookup table
                                	**type**\: list of    :py:class:`NetworkLookupAllRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.network_lookup_all_rd = YList()
                                    self.network_lookup_all_rd.parent = self
                                    self.network_lookup_all_rd.name = 'network_lookup_all_rd'


                                class NetworkLookupAllRd(object):
                                    """
                                    The BGP Network Lookup table
                                    
                                    .. attribute:: network_prefix  <key>
                                    
                                    	Network 
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: network_lookup_rds
                                    
                                    	The BGP Network Lookup table
                                    	**type**\:   :py:class:`NetworkLookupRds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.network_prefix = None
                                        self.network_lookup_rds = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds()
                                        self.network_lookup_rds.parent = self


                                    class NetworkLookupRds(object):
                                        """
                                        The BGP Network Lookup table
                                        
                                        .. attribute:: network_lookup_rd
                                        
                                        	A BGP Network table entry
                                        	**type**\: list of    :py:class:`NetworkLookupRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.network_lookup_rd = YList()
                                            self.network_lookup_rd.parent = self
                                            self.network_lookup_rd.name = 'network_lookup_rd'


                                        class NetworkLookupRd(object):
                                            """
                                            A BGP Network table entry
                                            
                                            .. attribute:: rd  <key>
                                            
                                            	Route Distinguisher value
                                            	**type**\:  str
                                            
                                            .. attribute:: active_path_element
                                            
                                            	Path element list received from Active inst
                                            	**type**\: list of    :py:class:`ActivePathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement>`
                                            
                                            .. attribute:: active_process_instance_path
                                            
                                            	Active's paths for this net 
                                            	**type**\: list of    :py:class:`ActiveProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath>`
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix>`
                                            
                                            .. attribute:: bit
                                            
                                            	Bit
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: flags
                                            
                                            	Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: gateway_array
                                            
                                            	Gateway array ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_inconsistent_paths
                                            
                                            	Net has inconsistent paths
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_lbl_retained
                                            
                                            	Net has label retained
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_label
                                            
                                            	Net has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_net_aggregation_suppressed
                                            
                                            	Net suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_net_ldp_signaled
                                            
                                            	L2VPN Net LDP signaled  aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_network
                                            
                                            	Permanent Network
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_element
                                            
                                            	Local path element list
                                            	**type**\: list of    :py:class:`LocalPathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement>`
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: local_process_instance_path
                                            
                                            	Local (to process instance) paths for this net 
                                            	**type**\: list of    :py:class:`LocalProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath>`
                                            
                                            .. attribute:: net_backup_available
                                            
                                            	Net has backup path
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_backup_label_rewrite_available
                                            
                                            	Net has label rewrite for backup path
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_eibgp_multipath
                                            
                                            	Net has EIBGP multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_extended_flags
                                            
                                            	Net extended flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: net_flags
                                            
                                            	Flags associated with                            net
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: net_local_label
                                            
                                            	Local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: net_local_label_rewrite
                                            
                                            	Net label has rewrite
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_local_label_srgb
                                            
                                            	Net label allocated fromSegment routing global block
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_multipath
                                            
                                            	Net has multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: num_of_path
                                            
                                            	Number of path for this net
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: process_instance_id
                                            
                                            	Process instance ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: resilient_nexthop_set
                                            
                                            	Resilient nexthop set ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	RIB install failed
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: table_brib_version
                                            
                                            	Table version # for updates
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: table_version
                                            
                                            	Table version # for net
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: version
                                            
                                            	Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: version_age
                                            
                                            	Version age
                                            	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionAge>`
                                            
                                            .. attribute:: version_timestamp
                                            
                                            	Version timestamp
                                            	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionTimestamp>`
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.rd = None
                                                self.active_path_element = YList()
                                                self.active_path_element.parent = self
                                                self.active_path_element.name = 'active_path_element'
                                                self.active_process_instance_path = YList()
                                                self.active_process_instance_path.parent = self
                                                self.active_process_instance_path.name = 'active_process_instance_path'
                                                self.add_path_orr_bitfield = YList()
                                                self.add_path_orr_bitfield.parent = self
                                                self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                self.advertisedto_pe = None
                                                self.af_name = None
                                                self.best_path_orr_bitfield = YList()
                                                self.best_path_orr_bitfield.parent = self
                                                self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self.bit = None
                                                self.flags = None
                                                self.gateway_array = None
                                                self.has_inconsistent_paths = None
                                                self.has_lbl_retained = None
                                                self.has_local_label = None
                                                self.is_net_aggregation_suppressed = None
                                                self.is_net_ldp_signaled = None
                                                self.is_permanent_network = None
                                                self.local_path_element = YList()
                                                self.local_path_element.parent = self
                                                self.local_path_element.name = 'local_path_element'
                                                self.local_peers_advertised_to = YList()
                                                self.local_peers_advertised_to.parent = self
                                                self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                self.local_process_instance_path = YList()
                                                self.local_process_instance_path.parent = self
                                                self.local_process_instance_path.name = 'local_process_instance_path'
                                                self.net_backup_available = None
                                                self.net_backup_label_rewrite_available = None
                                                self.net_eibgp_multipath = None
                                                self.net_extended_flags = None
                                                self.net_flags = None
                                                self.net_local_label = None
                                                self.net_local_label_rewrite = None
                                                self.net_local_label_srgb = None
                                                self.net_multipath = None
                                                self.num_of_path = None
                                                self.pe_peers_advertised_to = YList()
                                                self.pe_peers_advertised_to.parent = self
                                                self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                self.process_instance_id = None
                                                self.resilient_nexthop_set = None
                                                self.rib_failed = None
                                                self.route_distinguisher = None
                                                self.table_brib_version = None
                                                self.table_version = None
                                                self.version = None
                                                self.version_age = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionAge()
                                                self.version_age.parent = self
                                                self.version_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionTimestamp()
                                                self.version_timestamp.parent = self
                                                self.vrf_name = None


                                            class BgpPrefix(object):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self.prefix_length = None


                                                class Prefix(object):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.prefix is not None and self.prefix._has_data():
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BgpPrefix']['meta_info']


                                            class VersionTimestamp(object):
                                                """
                                                Version timestamp
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionTimestamp']['meta_info']


                                            class VersionAge(object):
                                                """
                                                Version age
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-age'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.VersionAge']['meta_info']


                                            class LocalPeersAdvertisedTo(object):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPeersAdvertisedTo']['meta_info']


                                            class PePeersAdvertisedTo(object):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.PePeersAdvertisedTo']['meta_info']


                                            class BestPathOrrBitfield(object):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.BestPathOrrBitfield']['meta_info']


                                            class AddPathOrrBitfield(object):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.AddPathOrrBitfield']['meta_info']


                                            class LocalProcessInstancePath(object):
                                                """
                                                Local (to process instance) paths for this net 
                                                
                                                .. attribute:: af_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: attributes_after_policy_in
                                                
                                                	Attributes after inbound policy applied
                                                	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn>`
                                                
                                                .. attribute:: label_fail
                                                
                                                	LSD label allocation failed 
                                                	**type**\:  bool
                                                
                                                .. attribute:: label_o_or_version
                                                
                                                	Label Version when OOR happens
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_oor
                                                
                                                	LSD label space is exhausted
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address_xr
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr>`
                                                
                                                .. attribute:: no_path
                                                
                                                	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                                	**type**\:  bool
                                                
                                                .. attribute:: path_information
                                                
                                                	Path information
                                                	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation>`
                                                
                                                .. attribute:: prefix_version
                                                
                                                	Version of BGP Prefix Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: process_instance_id
                                                
                                                	Process instance ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: source_route_distinguisher
                                                
                                                	Source Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: source_vrf_name
                                                
                                                	Name of the source VRF
                                                	**type**\:  str
                                                
                                                .. attribute:: srcaf_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: vrf_name
                                                
                                                	Name of the VRF
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.af_name = None
                                                    self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn()
                                                    self.attributes_after_policy_in.parent = self
                                                    self.label_fail = None
                                                    self.label_o_or_version = None
                                                    self.label_oor = None
                                                    self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr()
                                                    self.neighbor_address_xr.parent = self
                                                    self.no_path = None
                                                    self.path_information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation()
                                                    self.path_information.parent = self
                                                    self.prefix_version = None
                                                    self.process_instance_id = None
                                                    self.route_distinguisher = None
                                                    self.source_route_distinguisher = None
                                                    self.source_vrf_name = None
                                                    self.srcaf_name = None
                                                    self.vrf_name = None


                                                class NeighborAddressXr(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.NeighborAddressXr']['meta_info']


                                                class PathInformation(object):
                                                    """
                                                    Path information
                                                    
                                                    .. attribute:: accept_own_path
                                                    
                                                    	Accept Own
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: accept_own_self_originated_p_ath
                                                    
                                                    	Accept\-Own self\-originated
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: add_path_orr_bitfield
                                                    
                                                    	ORR Add path Bitfields
                                                    	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                    
                                                    .. attribute:: advertisedto_pe
                                                    
                                                    	Net could be advertised                          to PE peers
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: aigp_metric
                                                    
                                                    	Total AIGP metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: best_path_comp_stage
                                                    
                                                    	Stage where the path lost to the best path or group best
                                                    	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                                    
                                                    .. attribute:: best_path_comp_winner
                                                    
                                                    	Neighbor address of the path which won best path comparison
                                                    	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                    
                                                    .. attribute:: best_path_id
                                                    
                                                    	Best path ID; DEPRECATED BYLocalPathId
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: best_path_id_comp_winner
                                                    
                                                    	Path ID of the path which won best path comparison
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: best_path_orr_bitfield
                                                    
                                                    	ORR Best path Bitfields
                                                    	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                    
                                                    .. attribute:: bgp_prefix
                                                    
                                                    	BGP prefix
                                                    	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix>`
                                                    
                                                    .. attribute:: dampen_penalty
                                                    
                                                    	Dampening penalty
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Mvpn Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                    
                                                    .. attribute:: fspec_invalid_path
                                                    
                                                    	Is Fspec invalid path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: graceful_shutdown
                                                    
                                                    	Marked for graceful shutdown
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: gw_addr
                                                    
                                                    	Path GW Address
                                                    	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.GwAddr>`
                                                    
                                                    .. attribute:: halflife_time
                                                    
                                                    	Half\-life time for the penalty
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_esi
                                                    
                                                    	Path has EVPN ESI
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_gw_addr
                                                    
                                                    	Path has GW Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_local_net_label
                                                    
                                                    	Path has local label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mdt_group_addr
                                                    
                                                    	Path has MDT Group Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_extcomm
                                                    
                                                    	Path has MVPN EXTCOMM feedback
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_nbr_addr
                                                    
                                                    	Path has Mvpn nbr Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_nexthop_addr
                                                    
                                                    	Path has MVPN nexthop Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_pmsi
                                                    
                                                    	Path has MVPN PMSI feedback
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_rcvd_label
                                                    
                                                    	Path has received label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_second_label
                                                    
                                                    	Path has second received label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ibgp_signaled_validity
                                                    
                                                    	IBGP signalled validation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: igp_metric
                                                    
                                                    	IGP metric to the gateway
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_aggregation_suppressed
                                                    
                                                    	Path suppressed due to aggregation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_best
                                                    
                                                    	Best available path within AS
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_best_path
                                                    
                                                    	Best available path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_import_dampened
                                                    
                                                    	net import dampened
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_import_suspect
                                                    
                                                    	net import suspect
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_internal_path
                                                    
                                                    	Received over an internal link
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_best
                                                    
                                                    	Partial best path within distributed speaker
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_additional_path
                                                    
                                                    	Path is an additional\-path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_advertised_local_as_only
                                                    
                                                    	Not advertised outside local AS
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_af_install_eligible
                                                    
                                                    	Path can be installed in AF RIB
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_backup
                                                    
                                                    	Path is a backup path 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_backup_protect_multipath
                                                    
                                                    	Path is a backup path to protect multipaths
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_best_external
                                                    
                                                    	Path is a best external path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_damped
                                                    
                                                    	Path suppressed due to dampening
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_confederation_peer
                                                    
                                                    	Path received from confederation peer
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_network_command
                                                    
                                                    	Path sourced by network command
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_redistribute_command
                                                    
                                                    	Path sourced by redistribute command
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_route_reflector
                                                    
                                                    	Path received from route reflector
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_history_held
                                                    
                                                    	Path entry held to remember history
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_imp_candidate
                                                    
                                                    	Path is a candidate for multipath import
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_imported
                                                    
                                                    	Path is imported
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_local_aggregate
                                                    
                                                    	Path is a locally created aggregate
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_locally_sourced
                                                    
                                                    	Path sourced locally
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_long_lived_stale
                                                    
                                                    	Long lived stale routes learnt before neighbor restarts
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_multipath
                                                    
                                                    	Path is one of multipath best routes
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_nexthop_discarded
                                                    
                                                    	Path is redirected to Null0
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_not_advertised
                                                    
                                                    	Not advertised to any peer
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_not_advertised_to_ebg_ps
                                                    
                                                    	Not advertised to EBGPs
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_received_only
                                                    
                                                    	Path is received only
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_reoriginated
                                                    
                                                    	Path is reoriginated
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_reoriginated_stitching
                                                    
                                                    	Path is reoriginated with stitching RTs
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_stale
                                                    
                                                    	Stale routes learnt before neighbor restarts
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_synced_with_igp
                                                    
                                                    	Path synchronized with IGP
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_valid
                                                    
                                                    	Path attributes are usable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_vpn_only
                                                    
                                                    	Path is not in the vrf
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_permanent_path
                                                    
                                                    	Path is of type Permanent path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_received_path_not_modified
                                                    
                                                    	Received path used without modification
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_spkr_as_best
                                                    
                                                    	Best available path within AS in speaker
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2vpn_circuit_status_value
                                                    
                                                    	L2VPN Circuit Status Value
                                                    	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                    
                                                    .. attribute:: l2vpn_evpn_esi
                                                    
                                                    	L2VPN EVPN ESI
                                                    	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi>`
                                                    
                                                    .. attribute:: l2vpn_size
                                                    
                                                    	Path block size
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: labeled_unicast_safi_path
                                                    
                                                    	Path was learnt by labeled\-unicast SAFI
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: local_label
                                                    
                                                    	Path local label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_nh
                                                    
                                                    	Path has local nexthop
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: local_path_id
                                                    
                                                    	Local path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_peers_advertised_to
                                                    
                                                    	Local peers that this prefix has been advertised to
                                                    	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                    
                                                    .. attribute:: maximum_suppress_time
                                                    
                                                    	Maximum duration to suppress a stable route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mdt_group_addr
                                                    
                                                    	IPv4 MDT Group Address for the path
                                                    	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                    
                                                    .. attribute:: mvpn_nbr_addr
                                                    
                                                    	Mvpn nbr Address for the path
                                                    	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                    
                                                    .. attribute:: mvpn_nexthop_addr
                                                    
                                                    	Mvpn nexthop Address for the path
                                                    	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                    
                                                    .. attribute:: mvpn_path_flags
                                                    
                                                    	Mvpn path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: mvpn_pmsi_flags
                                                    
                                                    	Mvpn PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: mvpn_pmsi_label
                                                    
                                                    	Mvpn PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mvpn_pmsi_type
                                                    
                                                    	Mvpn PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: mvpn_pmsi_value
                                                    
                                                    	Mvpn PMSI Value
                                                    	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                    
                                                    .. attribute:: mvpn_sfs_path
                                                    
                                                    	Is MVPN single forwarder PE path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress>`
                                                    
                                                    .. attribute:: neighbor_router_id
                                                    
                                                    	Router ID of the neighbor for the path
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: next_hop
                                                    
                                                    	Next hop
                                                    	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop>`
                                                    
                                                    .. attribute:: nhte_tunnel
                                                    
                                                    	NH TE tunnel information
                                                    	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhteTunnel>`
                                                    
                                                    .. attribute:: path_flags
                                                    
                                                    	Flags associated with path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: path_flap_count
                                                    
                                                    	Number of times this route has flapped
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_import_flags
                                                    
                                                    	Path import flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_rt_set_id
                                                    
                                                    	RT\-set id of the path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_rt_set_route_count
                                                    
                                                    	Count in RT\-set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_table_version
                                                    
                                                    	Table version # for pelem
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_weight
                                                    
                                                    	Weight for the path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pe_peers_advertised_to
                                                    
                                                    	PE peers that this prefix has been advertised to
                                                    	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                    
                                                    .. attribute:: rcvd_label
                                                    
                                                    	Path received label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rcvd_path_id
                                                    
                                                    	Received path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: reuse_value
                                                    
                                                    	Value to start reusing a route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rib_failed
                                                    
                                                    	Is net failed installed                          in RIB
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: route_type
                                                    
                                                    	Route Type of path
                                                    	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                                    
                                                    .. attribute:: rpki_origin_as_validation_disabled
                                                    
                                                    	RPKI originAS V. Disabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rt_set_limit_enabled
                                                    
                                                    	Path subject to RT\-set net limit
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_label
                                                    
                                                    	Path second received label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: seconds_since_first_flap
                                                    
                                                    	Seconds since route first flapped
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: show_rpki_origin_as_validity
                                                    
                                                    	Display validity state ?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: sn_rpki_origin_as_validity
                                                    
                                                    	RPKI origin validation state
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: suppress_penalty
                                                    
                                                    	Value to start suppressing a route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: time_to_unsuppress
                                                    
                                                    	Seconds until route is unsuppressed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.accept_own_path = None
                                                        self.accept_own_self_originated_p_ath = None
                                                        self.add_path_orr_bitfield = YList()
                                                        self.add_path_orr_bitfield.parent = self
                                                        self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                        self.advertisedto_pe = None
                                                        self.aigp_metric = None
                                                        self.best_path_comp_stage = None
                                                        self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner()
                                                        self.best_path_comp_winner.parent = self
                                                        self.best_path_id = None
                                                        self.best_path_id_comp_winner = None
                                                        self.best_path_orr_bitfield = YList()
                                                        self.best_path_orr_bitfield.parent = self
                                                        self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                        self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix()
                                                        self.bgp_prefix.parent = self
                                                        self.dampen_penalty = None
                                                        self.extended_community = YList()
                                                        self.extended_community.parent = self
                                                        self.extended_community.name = 'extended_community'
                                                        self.fspec_invalid_path = None
                                                        self.graceful_shutdown = None
                                                        self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.GwAddr()
                                                        self.gw_addr.parent = self
                                                        self.halflife_time = None
                                                        self.has_esi = None
                                                        self.has_gw_addr = None
                                                        self.has_local_net_label = None
                                                        self.has_mdt_group_addr = None
                                                        self.has_mvpn_extcomm = None
                                                        self.has_mvpn_nbr_addr = None
                                                        self.has_mvpn_nexthop_addr = None
                                                        self.has_mvpn_pmsi = None
                                                        self.has_rcvd_label = None
                                                        self.has_second_label = None
                                                        self.ibgp_signaled_validity = None
                                                        self.igp_metric = None
                                                        self.is_aggregation_suppressed = None
                                                        self.is_as_best = None
                                                        self.is_best_path = None
                                                        self.is_import_dampened = None
                                                        self.is_import_suspect = None
                                                        self.is_internal_path = None
                                                        self.is_partial_best = None
                                                        self.is_path_additional_path = None
                                                        self.is_path_advertised_local_as_only = None
                                                        self.is_path_af_install_eligible = None
                                                        self.is_path_backup = None
                                                        self.is_path_backup_protect_multipath = None
                                                        self.is_path_best_external = None
                                                        self.is_path_damped = None
                                                        self.is_path_from_confederation_peer = None
                                                        self.is_path_from_network_command = None
                                                        self.is_path_from_redistribute_command = None
                                                        self.is_path_from_route_reflector = None
                                                        self.is_path_history_held = None
                                                        self.is_path_imp_candidate = None
                                                        self.is_path_imported = None
                                                        self.is_path_local_aggregate = None
                                                        self.is_path_locally_sourced = None
                                                        self.is_path_long_lived_stale = None
                                                        self.is_path_multipath = None
                                                        self.is_path_nexthop_discarded = None
                                                        self.is_path_not_advertised = None
                                                        self.is_path_not_advertised_to_ebg_ps = None
                                                        self.is_path_received_only = None
                                                        self.is_path_reoriginated = None
                                                        self.is_path_reoriginated_stitching = None
                                                        self.is_path_stale = None
                                                        self.is_path_synced_with_igp = None
                                                        self.is_path_valid = None
                                                        self.is_path_vpn_only = None
                                                        self.is_permanent_path = None
                                                        self.is_received_path_not_modified = None
                                                        self.is_spkr_as_best = None
                                                        self.l2vpn_circuit_status_value = YList()
                                                        self.l2vpn_circuit_status_value.parent = self
                                                        self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                        self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi()
                                                        self.l2vpn_evpn_esi.parent = self
                                                        self.l2vpn_size = None
                                                        self.labeled_unicast_safi_path = None
                                                        self.local_label = None
                                                        self.local_nh = None
                                                        self.local_path_id = None
                                                        self.local_peers_advertised_to = YList()
                                                        self.local_peers_advertised_to.parent = self
                                                        self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                        self.maximum_suppress_time = None
                                                        self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr()
                                                        self.mdt_group_addr.parent = self
                                                        self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                        self.mvpn_nbr_addr.parent = self
                                                        self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                        self.mvpn_nexthop_addr.parent = self
                                                        self.mvpn_path_flags = None
                                                        self.mvpn_pmsi_flags = None
                                                        self.mvpn_pmsi_label = None
                                                        self.mvpn_pmsi_type = None
                                                        self.mvpn_pmsi_value = YList()
                                                        self.mvpn_pmsi_value.parent = self
                                                        self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                        self.mvpn_sfs_path = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.neighbor_router_id = None
                                                        self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop()
                                                        self.next_hop.parent = self
                                                        self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhteTunnel()
                                                        self.nhte_tunnel.parent = self
                                                        self.path_flags = None
                                                        self.path_flap_count = None
                                                        self.path_import_flags = None
                                                        self.path_rt_set_id = None
                                                        self.path_rt_set_route_count = None
                                                        self.path_table_version = None
                                                        self.path_weight = None
                                                        self.pe_peers_advertised_to = YList()
                                                        self.pe_peers_advertised_to.parent = self
                                                        self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                        self.rcvd_label = None
                                                        self.rcvd_path_id = None
                                                        self.reuse_value = None
                                                        self.rib_failed = None
                                                        self.route_type = None
                                                        self.rpki_origin_as_validation_disabled = None
                                                        self.rt_set_limit_enabled = None
                                                        self.second_label = None
                                                        self.seconds_since_first_flap = None
                                                        self.show_rpki_origin_as_validity = None
                                                        self.sn_rpki_origin_as_validity = None
                                                        self.suppress_penalty = None
                                                        self.time_to_unsuppress = None


                                                    class BgpPrefix(object):
                                                        """
                                                        BGP prefix
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Prefix
                                                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                            self.prefix.parent = self
                                                            self.prefix_length = None


                                                        class Prefix(object):
                                                            """
                                                            Prefix
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.prefix is not None and self.prefix._has_data():
                                                                return True

                                                            if self.prefix_length is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BgpPrefix']['meta_info']


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NeighborAddress']['meta_info']


                                                    class NextHop(object):
                                                        """
                                                        Next hop
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NextHop']['meta_info']


                                                    class NhteTunnel(object):
                                                        """
                                                        NH TE tunnel information
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	Binding label for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_te_tunnel
                                                        
                                                        	NH TE Tunnel info is present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_info_stale
                                                        
                                                        	Tunnel is stale
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_registered
                                                        
                                                        	Tunnel registered flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_up
                                                        
                                                        	Tunnel Up flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: last_tunnel_update
                                                        
                                                        	Time since the last rib update happened
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_if_handle
                                                        
                                                        	Interface handle for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_name
                                                        
                                                        	tunnel name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        .. attribute:: tunnel_type
                                                        
                                                        	tunnel type
                                                        	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                        
                                                        .. attribute:: tunnel_v6_enabled
                                                        
                                                        	IPv6 enabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_v6_required
                                                        
                                                        	Tunnel need IPv6
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.binding_label = None
                                                            self.has_te_tunnel = None
                                                            self.is_tunnel_info_stale = None
                                                            self.is_tunnel_registered = None
                                                            self.is_tunnel_up = None
                                                            self.last_tunnel_update = None
                                                            self.tunnel_if_handle = None
                                                            self.tunnel_name = None
                                                            self.tunnel_type = None
                                                            self.tunnel_v6_enabled = None
                                                            self.tunnel_v6_required = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.binding_label is not None:
                                                                return True

                                                            if self.has_te_tunnel is not None:
                                                                return True

                                                            if self.is_tunnel_info_stale is not None:
                                                                return True

                                                            if self.is_tunnel_registered is not None:
                                                                return True

                                                            if self.is_tunnel_up is not None:
                                                                return True

                                                            if self.last_tunnel_update is not None:
                                                                return True

                                                            if self.tunnel_if_handle is not None:
                                                                return True

                                                            if self.tunnel_name is not None:
                                                                return True

                                                            if self.tunnel_type is not None:
                                                                return True

                                                            if self.tunnel_v6_enabled is not None:
                                                                return True

                                                            if self.tunnel_v6_required is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.NhteTunnel']['meta_info']


                                                    class MdtGroupAddr(object):
                                                        """
                                                        IPv4 MDT Group Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr']['meta_info']


                                                    class L2VpnEvpnEsi(object):
                                                        """
                                                        L2VPN EVPN ESI
                                                        
                                                        .. attribute:: esi
                                                        
                                                        	esi
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.esi = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.esi is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi']['meta_info']


                                                    class GwAddr(object):
                                                        """
                                                        Path GW Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_address = None
                                                            self.ipv6_address = None
                                                            self.len = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.len is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.GwAddr']['meta_info']


                                                    class BestPathCompWinner(object):
                                                        """
                                                        Neighbor address of the path which won best path
                                                        comparison
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner']['meta_info']


                                                    class MvpnNbrAddr(object):
                                                        """
                                                        Mvpn nbr Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr']['meta_info']


                                                    class MvpnNexthopAddr(object):
                                                        """
                                                        Mvpn nexthop Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr']['meta_info']


                                                    class L2VpnCircuitStatusValue(object):
                                                        """
                                                        L2VPN Circuit Status Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                                    class MvpnPmsiValue(object):
                                                        """
                                                        Mvpn PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue']['meta_info']


                                                    class ExtendedCommunity(object):
                                                        """
                                                        Mvpn Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity']['meta_info']


                                                    class LocalPeersAdvertisedTo(object):
                                                        """
                                                        Local peers that this prefix has been advertised
                                                        to
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.is_neighbor = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.update_group_number = None


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.is_neighbor is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.update_group_number is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                                    class PePeersAdvertisedTo(object):
                                                        """
                                                        PE peers that this prefix has been advertised to
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.is_neighbor = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.update_group_number = None


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.is_neighbor is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.update_group_number is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo']['meta_info']


                                                    class BestPathOrrBitfield(object):
                                                        """
                                                        ORR Best path Bitfields
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.is_neighbor = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.update_group_number = None


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.is_neighbor is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.update_group_number is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield']['meta_info']


                                                    class AddPathOrrBitfield(object):
                                                        """
                                                        ORR Add path Bitfields
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.is_neighbor = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.update_group_number = None


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.is_neighbor is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.update_group_number is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.accept_own_path is not None:
                                                            return True

                                                        if self.accept_own_self_originated_p_ath is not None:
                                                            return True

                                                        if self.add_path_orr_bitfield is not None:
                                                            for child_ref in self.add_path_orr_bitfield:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.advertisedto_pe is not None:
                                                            return True

                                                        if self.aigp_metric is not None:
                                                            return True

                                                        if self.best_path_comp_stage is not None:
                                                            return True

                                                        if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                            return True

                                                        if self.best_path_id is not None:
                                                            return True

                                                        if self.best_path_id_comp_winner is not None:
                                                            return True

                                                        if self.best_path_orr_bitfield is not None:
                                                            for child_ref in self.best_path_orr_bitfield:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                            return True

                                                        if self.dampen_penalty is not None:
                                                            return True

                                                        if self.extended_community is not None:
                                                            for child_ref in self.extended_community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.fspec_invalid_path is not None:
                                                            return True

                                                        if self.graceful_shutdown is not None:
                                                            return True

                                                        if self.gw_addr is not None and self.gw_addr._has_data():
                                                            return True

                                                        if self.halflife_time is not None:
                                                            return True

                                                        if self.has_esi is not None:
                                                            return True

                                                        if self.has_gw_addr is not None:
                                                            return True

                                                        if self.has_local_net_label is not None:
                                                            return True

                                                        if self.has_mdt_group_addr is not None:
                                                            return True

                                                        if self.has_mvpn_extcomm is not None:
                                                            return True

                                                        if self.has_mvpn_nbr_addr is not None:
                                                            return True

                                                        if self.has_mvpn_nexthop_addr is not None:
                                                            return True

                                                        if self.has_mvpn_pmsi is not None:
                                                            return True

                                                        if self.has_rcvd_label is not None:
                                                            return True

                                                        if self.has_second_label is not None:
                                                            return True

                                                        if self.ibgp_signaled_validity is not None:
                                                            return True

                                                        if self.igp_metric is not None:
                                                            return True

                                                        if self.is_aggregation_suppressed is not None:
                                                            return True

                                                        if self.is_as_best is not None:
                                                            return True

                                                        if self.is_best_path is not None:
                                                            return True

                                                        if self.is_import_dampened is not None:
                                                            return True

                                                        if self.is_import_suspect is not None:
                                                            return True

                                                        if self.is_internal_path is not None:
                                                            return True

                                                        if self.is_partial_best is not None:
                                                            return True

                                                        if self.is_path_additional_path is not None:
                                                            return True

                                                        if self.is_path_advertised_local_as_only is not None:
                                                            return True

                                                        if self.is_path_af_install_eligible is not None:
                                                            return True

                                                        if self.is_path_backup is not None:
                                                            return True

                                                        if self.is_path_backup_protect_multipath is not None:
                                                            return True

                                                        if self.is_path_best_external is not None:
                                                            return True

                                                        if self.is_path_damped is not None:
                                                            return True

                                                        if self.is_path_from_confederation_peer is not None:
                                                            return True

                                                        if self.is_path_from_network_command is not None:
                                                            return True

                                                        if self.is_path_from_redistribute_command is not None:
                                                            return True

                                                        if self.is_path_from_route_reflector is not None:
                                                            return True

                                                        if self.is_path_history_held is not None:
                                                            return True

                                                        if self.is_path_imp_candidate is not None:
                                                            return True

                                                        if self.is_path_imported is not None:
                                                            return True

                                                        if self.is_path_local_aggregate is not None:
                                                            return True

                                                        if self.is_path_locally_sourced is not None:
                                                            return True

                                                        if self.is_path_long_lived_stale is not None:
                                                            return True

                                                        if self.is_path_multipath is not None:
                                                            return True

                                                        if self.is_path_nexthop_discarded is not None:
                                                            return True

                                                        if self.is_path_not_advertised is not None:
                                                            return True

                                                        if self.is_path_not_advertised_to_ebg_ps is not None:
                                                            return True

                                                        if self.is_path_received_only is not None:
                                                            return True

                                                        if self.is_path_reoriginated is not None:
                                                            return True

                                                        if self.is_path_reoriginated_stitching is not None:
                                                            return True

                                                        if self.is_path_stale is not None:
                                                            return True

                                                        if self.is_path_synced_with_igp is not None:
                                                            return True

                                                        if self.is_path_valid is not None:
                                                            return True

                                                        if self.is_path_vpn_only is not None:
                                                            return True

                                                        if self.is_permanent_path is not None:
                                                            return True

                                                        if self.is_received_path_not_modified is not None:
                                                            return True

                                                        if self.is_spkr_as_best is not None:
                                                            return True

                                                        if self.l2vpn_circuit_status_value is not None:
                                                            for child_ref in self.l2vpn_circuit_status_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                            return True

                                                        if self.l2vpn_size is not None:
                                                            return True

                                                        if self.labeled_unicast_safi_path is not None:
                                                            return True

                                                        if self.local_label is not None:
                                                            return True

                                                        if self.local_nh is not None:
                                                            return True

                                                        if self.local_path_id is not None:
                                                            return True

                                                        if self.local_peers_advertised_to is not None:
                                                            for child_ref in self.local_peers_advertised_to:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.maximum_suppress_time is not None:
                                                            return True

                                                        if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                            return True

                                                        if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                            return True

                                                        if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                            return True

                                                        if self.mvpn_path_flags is not None:
                                                            return True

                                                        if self.mvpn_pmsi_flags is not None:
                                                            return True

                                                        if self.mvpn_pmsi_label is not None:
                                                            return True

                                                        if self.mvpn_pmsi_type is not None:
                                                            return True

                                                        if self.mvpn_pmsi_value is not None:
                                                            for child_ref in self.mvpn_pmsi_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.mvpn_sfs_path is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.neighbor_router_id is not None:
                                                            return True

                                                        if self.next_hop is not None and self.next_hop._has_data():
                                                            return True

                                                        if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                            return True

                                                        if self.path_flags is not None:
                                                            return True

                                                        if self.path_flap_count is not None:
                                                            return True

                                                        if self.path_import_flags is not None:
                                                            return True

                                                        if self.path_rt_set_id is not None:
                                                            return True

                                                        if self.path_rt_set_route_count is not None:
                                                            return True

                                                        if self.path_table_version is not None:
                                                            return True

                                                        if self.path_weight is not None:
                                                            return True

                                                        if self.pe_peers_advertised_to is not None:
                                                            for child_ref in self.pe_peers_advertised_to:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.rcvd_label is not None:
                                                            return True

                                                        if self.rcvd_path_id is not None:
                                                            return True

                                                        if self.reuse_value is not None:
                                                            return True

                                                        if self.rib_failed is not None:
                                                            return True

                                                        if self.route_type is not None:
                                                            return True

                                                        if self.rpki_origin_as_validation_disabled is not None:
                                                            return True

                                                        if self.rt_set_limit_enabled is not None:
                                                            return True

                                                        if self.second_label is not None:
                                                            return True

                                                        if self.seconds_since_first_flap is not None:
                                                            return True

                                                        if self.show_rpki_origin_as_validity is not None:
                                                            return True

                                                        if self.sn_rpki_origin_as_validity is not None:
                                                            return True

                                                        if self.suppress_penalty is not None:
                                                            return True

                                                        if self.time_to_unsuppress is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.PathInformation']['meta_info']


                                                class AttributesAfterPolicyIn(object):
                                                    """
                                                    Attributes after inbound policy applied
                                                    
                                                    .. attribute:: attr_set
                                                    
                                                    	ATTR\_SET attribute
                                                    	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                    
                                                    .. attribute:: attribute_key_number
                                                    
                                                    	Attribute key number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_config
                                                    
                                                    	Attribute reuse ID Configured
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: attribute_reuse_id_current
                                                    
                                                    	Attribute reuse ID current ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_keys
                                                    
                                                    	Attribute reuse ID allocated keys
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_max_id
                                                    
                                                    	Attribute reuse ID maximum ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_node
                                                    
                                                    	Attribute reuse ID nodes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_recover_sec
                                                    
                                                    	Attribute reuse ID timer in seconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: common_attributes
                                                    
                                                    	Common attributes
                                                    	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                    
                                                    .. attribute:: is_application_gateway_present
                                                    
                                                    	Application gateway present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path2_byte
                                                    
                                                    	AS path encoded as 2\-byte
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_attr_set_present
                                                    
                                                    	BGP ATTR\_SET attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ribrnh_present
                                                    
                                                    	RIB RNH Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_rnh_present
                                                    
                                                    	RNH Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ribrnh_encap
                                                    
                                                    	RIB RNH Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ribrnh_ip
                                                    
                                                    	RIB RNH IP Address
                                                    	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                    
                                                    .. attribute:: ribrnh_mac
                                                    
                                                    	RIB RNH MAC Address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    .. attribute:: ribrnh_table
                                                    
                                                    	RIB RNH Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ribrnh_vni
                                                    
                                                    	RIB RNH Vni
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ribrnhip_table
                                                    
                                                    	RIB RNH IP Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rnh_addr
                                                    
                                                    	RNH Address
                                                    	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                    
                                                    .. attribute:: rnh_addr_len
                                                    
                                                    	RNH Address Length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rnh_len
                                                    
                                                    	RNH Length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: rnh_type
                                                    
                                                    	RNH Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: set_aigp_inbound_igp
                                                    
                                                    	AIGP set by policy inbound IGP 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: set_aigp_inbound_metric
                                                    
                                                    	AIGP set by policy inbound metric
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: vpn_distinguisher
                                                    
                                                    	VPN Distinguisher
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                        self.attr_set.parent = self
                                                        self.attribute_key_number = None
                                                        self.attribute_reuse_id_config = None
                                                        self.attribute_reuse_id_current = None
                                                        self.attribute_reuse_id_keys = None
                                                        self.attribute_reuse_id_max_id = None
                                                        self.attribute_reuse_id_node = None
                                                        self.attribute_reuse_id_recover_sec = None
                                                        self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                        self.common_attributes.parent = self
                                                        self.is_application_gateway_present = None
                                                        self.is_as_path2_byte = None
                                                        self.is_attr_set_present = None
                                                        self.is_ribrnh_present = None
                                                        self.is_rnh_present = None
                                                        self.ribrnh_encap = None
                                                        self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                        self.ribrnh_ip.parent = self
                                                        self.ribrnh_mac = None
                                                        self.ribrnh_table = None
                                                        self.ribrnh_vni = None
                                                        self.ribrnhip_table = None
                                                        self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                        self.rnh_addr.parent = self
                                                        self.rnh_addr_len = None
                                                        self.rnh_len = None
                                                        self.rnh_type = None
                                                        self.set_aigp_inbound_igp = None
                                                        self.set_aigp_inbound_metric = None
                                                        self.vpn_distinguisher = None


                                                    class CommonAttributes(object):
                                                        """
                                                        Common attributes
                                                        
                                                        .. attribute:: aggregator_address
                                                        
                                                        	Address where aggregation was performed
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: aggregator_as
                                                        
                                                        	AS where aggregation was last performed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: aigp_metric_value
                                                        
                                                        	AIGP metric value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: as_path
                                                        
                                                        	AS path attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: cluster
                                                        
                                                        	Cluster list attribute
                                                        	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                        
                                                        .. attribute:: community
                                                        
                                                        	Community attribute
                                                        	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                        
                                                        .. attribute:: connector_type
                                                        
                                                        	Connector Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: connector_value
                                                        
                                                        	Connector Value
                                                        	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                        
                                                        .. attribute:: extended_community_flags
                                                        
                                                        	Extended community Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: is_aggregator_present
                                                        
                                                        	Aggregator attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_aigp_present
                                                        
                                                        	AIGP Present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path_present
                                                        
                                                        	AS path attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_atomic_aggregate_present
                                                        
                                                        	Atomic aggregate attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_community_present
                                                        
                                                        	Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_connector_present
                                                        
                                                        	Connector present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_extended_community_present
                                                        
                                                        	Extended community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_label_index_present
                                                        
                                                        	Label Index attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_local_pref_present
                                                        
                                                        	Local Preference attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ls_attribute_present
                                                        
                                                        	BGP LS attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_metric_present
                                                        
                                                        	Metric attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_origin_present
                                                        
                                                        	Origin attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pe_distinguisher_label_present
                                                        
                                                        	PE distinguisher label  attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pmsi_present
                                                        
                                                        	PMSI Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pppmp_present
                                                        
                                                        	PPMP Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ssa_present
                                                        
                                                        	SSA attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_encap_present
                                                        
                                                        	Tunnel Encap attribute present 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2tpv3_cookie
                                                        
                                                        	L2TPv3 Cookie
                                                        	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                        
                                                        .. attribute:: l2tpv3_session_id
                                                        
                                                        	L2TPv3 session id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: label_index_attr
                                                        
                                                        	Label Index attribute
                                                        	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                        
                                                        .. attribute:: local_preference
                                                        
                                                        	Local preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ls_attr
                                                        
                                                        	BGP LS attribute
                                                        	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: neighbor_as
                                                        
                                                        	Neighbor AS number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: origin
                                                        
                                                        	Origin
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: originator
                                                        
                                                        	Originator attribute
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: pe_distinguisher_label
                                                        
                                                        	PE distinguisher label attribute
                                                        	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                        
                                                        .. attribute:: pmsi_flags
                                                        
                                                        	PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pmsi_label
                                                        
                                                        	PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pmsi_type
                                                        
                                                        	PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pmsi_value
                                                        
                                                        	PMSI Value
                                                        	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                        
                                                        .. attribute:: ppm_pvalue
                                                        
                                                        	PPMP Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: sr_policy_allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                        
                                                        .. attribute:: sr_policy_binding_sid
                                                        
                                                        	SR Policy Binding sid
                                                        	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                        
                                                        .. attribute:: sr_policy_explicit_path
                                                        
                                                        	SR Policy Explicit paths
                                                        	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                        
                                                        .. attribute:: sr_policy_preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: sr_tunnel_request_state
                                                        
                                                        	SR Tunnel Request State
                                                        	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                        
                                                        .. attribute:: sr_tunnel_state
                                                        
                                                        	SR Tunnel State
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encap Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: unknown_attribute
                                                        
                                                        	Unknown attributes
                                                        	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.aggregator_address = None
                                                            self.aggregator_as = None
                                                            self.aigp_metric_value = None
                                                            self.as_path = None
                                                            self.cluster = YList()
                                                            self.cluster.parent = self
                                                            self.cluster.name = 'cluster'
                                                            self.community = YList()
                                                            self.community.parent = self
                                                            self.community.name = 'community'
                                                            self.connector_type = None
                                                            self.connector_value = YList()
                                                            self.connector_value.parent = self
                                                            self.connector_value.name = 'connector_value'
                                                            self.extended_community = YList()
                                                            self.extended_community.parent = self
                                                            self.extended_community.name = 'extended_community'
                                                            self.extended_community_flags = None
                                                            self.is_aggregator_present = None
                                                            self.is_aigp_present = None
                                                            self.is_as_path_present = None
                                                            self.is_atomic_aggregate_present = None
                                                            self.is_community_present = None
                                                            self.is_connector_present = None
                                                            self.is_extended_community_present = None
                                                            self.is_label_index_present = None
                                                            self.is_local_pref_present = None
                                                            self.is_ls_attribute_present = None
                                                            self.is_metric_present = None
                                                            self.is_origin_present = None
                                                            self.is_pe_distinguisher_label_present = None
                                                            self.is_pmsi_present = None
                                                            self.is_pppmp_present = None
                                                            self.is_ssa_present = None
                                                            self.is_tunnel_encap_present = None
                                                            self.l2tpv3_cookie = YList()
                                                            self.l2tpv3_cookie.parent = self
                                                            self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                            self.l2tpv3_session_id = None
                                                            self.label_index_attr = YList()
                                                            self.label_index_attr.parent = self
                                                            self.label_index_attr.name = 'label_index_attr'
                                                            self.local_preference = None
                                                            self.ls_attr = YList()
                                                            self.ls_attr.parent = self
                                                            self.ls_attr.name = 'ls_attr'
                                                            self.metric = None
                                                            self.neighbor_as = None
                                                            self.origin = None
                                                            self.originator = None
                                                            self.pe_distinguisher_label = YList()
                                                            self.pe_distinguisher_label.parent = self
                                                            self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                            self.pmsi_flags = None
                                                            self.pmsi_label = None
                                                            self.pmsi_type = None
                                                            self.pmsi_value = YList()
                                                            self.pmsi_value.parent = self
                                                            self.pmsi_value.name = 'pmsi_value'
                                                            self.ppm_pvalue = None
                                                            self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                            self.sr_policy_allocated_binding_sid.parent = self
                                                            self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                            self.sr_policy_binding_sid.parent = self
                                                            self.sr_policy_explicit_path = YList()
                                                            self.sr_policy_explicit_path.parent = self
                                                            self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                            self.sr_policy_preference = None
                                                            self.sr_tunnel_request_state = None
                                                            self.sr_tunnel_state = None
                                                            self.tunnel_encap_type = None
                                                            self.unknown_attribute = YList()
                                                            self.unknown_attribute.parent = self
                                                            self.unknown_attribute.name = 'unknown_attribute'


                                                        class SrPolicyBindingSid(object):
                                                            """
                                                            SR Policy Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_address = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                        class SrPolicyAllocatedBindingSid(object):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_address = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                        class Community(object):
                                                            """
                                                            Community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                        class ExtendedCommunity(object):
                                                            """
                                                            Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                        class UnknownAttribute(object):
                                                            """
                                                            Unknown attributes
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                        class Cluster(object):
                                                            """
                                                            Cluster list attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                        class L2Tpv3Cookie(object):
                                                            """
                                                            L2TPv3 Cookie
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                        class ConnectorValue(object):
                                                            """
                                                            Connector Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                        class PmsiValue(object):
                                                            """
                                                            PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                        class LsAttr(object):
                                                            """
                                                            BGP LS attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                        class LabelIndexAttr(object):
                                                            """
                                                            Label Index attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                        class PeDistinguisherLabel(object):
                                                            """
                                                            PE distinguisher label attribute
                                                            
                                                            .. attribute:: label
                                                            
                                                            	Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pe_address
                                                            
                                                            	 PE address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.label = None
                                                                self.pe_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.label is not None:
                                                                    return True

                                                                if self.pe_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                        class SrPolicyExplicitPath(object):
                                                            """
                                                            SR Policy Explicit paths
                                                            
                                                            .. attribute:: sid
                                                            
                                                            	Sidlist for explicit path
                                                            	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of explicit path
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.sid = YList()
                                                                self.sid.parent = self
                                                                self.sid.name = 'sid'
                                                                self.weight = None


                                                            class Sid(object):
                                                                """
                                                                Sidlist for explicit path
                                                                
                                                                .. attribute:: ipv4
                                                                
                                                                	IP Address sid
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6
                                                                
                                                                	IPv6 address sid
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label sid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Sid Type
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4 = None
                                                                    self.ipv6 = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4 is not None:
                                                                        return True

                                                                    if self.ipv6 is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.sid is not None:
                                                                    for child_ref in self.sid:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.weight is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.aggregator_address is not None:
                                                                return True

                                                            if self.aggregator_as is not None:
                                                                return True

                                                            if self.aigp_metric_value is not None:
                                                                return True

                                                            if self.as_path is not None:
                                                                return True

                                                            if self.cluster is not None:
                                                                for child_ref in self.cluster:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.community is not None:
                                                                for child_ref in self.community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.connector_type is not None:
                                                                return True

                                                            if self.connector_value is not None:
                                                                for child_ref in self.connector_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.extended_community is not None:
                                                                for child_ref in self.extended_community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.extended_community_flags is not None:
                                                                return True

                                                            if self.is_aggregator_present is not None:
                                                                return True

                                                            if self.is_aigp_present is not None:
                                                                return True

                                                            if self.is_as_path_present is not None:
                                                                return True

                                                            if self.is_atomic_aggregate_present is not None:
                                                                return True

                                                            if self.is_community_present is not None:
                                                                return True

                                                            if self.is_connector_present is not None:
                                                                return True

                                                            if self.is_extended_community_present is not None:
                                                                return True

                                                            if self.is_label_index_present is not None:
                                                                return True

                                                            if self.is_local_pref_present is not None:
                                                                return True

                                                            if self.is_ls_attribute_present is not None:
                                                                return True

                                                            if self.is_metric_present is not None:
                                                                return True

                                                            if self.is_origin_present is not None:
                                                                return True

                                                            if self.is_pe_distinguisher_label_present is not None:
                                                                return True

                                                            if self.is_pmsi_present is not None:
                                                                return True

                                                            if self.is_pppmp_present is not None:
                                                                return True

                                                            if self.is_ssa_present is not None:
                                                                return True

                                                            if self.is_tunnel_encap_present is not None:
                                                                return True

                                                            if self.l2tpv3_cookie is not None:
                                                                for child_ref in self.l2tpv3_cookie:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.l2tpv3_session_id is not None:
                                                                return True

                                                            if self.label_index_attr is not None:
                                                                for child_ref in self.label_index_attr:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.local_preference is not None:
                                                                return True

                                                            if self.ls_attr is not None:
                                                                for child_ref in self.ls_attr:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.neighbor_as is not None:
                                                                return True

                                                            if self.origin is not None:
                                                                return True

                                                            if self.originator is not None:
                                                                return True

                                                            if self.pe_distinguisher_label is not None:
                                                                for child_ref in self.pe_distinguisher_label:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.pmsi_flags is not None:
                                                                return True

                                                            if self.pmsi_label is not None:
                                                                return True

                                                            if self.pmsi_type is not None:
                                                                return True

                                                            if self.pmsi_value is not None:
                                                                for child_ref in self.pmsi_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.ppm_pvalue is not None:
                                                                return True

                                                            if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                                return True

                                                            if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                                return True

                                                            if self.sr_policy_explicit_path is not None:
                                                                for child_ref in self.sr_policy_explicit_path:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.sr_policy_preference is not None:
                                                                return True

                                                            if self.sr_tunnel_request_state is not None:
                                                                return True

                                                            if self.sr_tunnel_state is not None:
                                                                return True

                                                            if self.tunnel_encap_type is not None:
                                                                return True

                                                            if self.unknown_attribute is not None:
                                                                for child_ref in self.unknown_attribute:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                                    class AttrSet(object):
                                                        """
                                                        ATTR\_SET attribute
                                                        
                                                        .. attribute:: aggregator_address
                                                        
                                                        	Address where aggregation was performed
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: aggregator_as
                                                        
                                                        	AS where aggregation was last performed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: aigp_metric_value
                                                        
                                                        	AIGP metric value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: as_path
                                                        
                                                        	AS path attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: cluster
                                                        
                                                        	Cluster list attribute
                                                        	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                        
                                                        .. attribute:: community
                                                        
                                                        	Community attribute
                                                        	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                        
                                                        .. attribute:: connector_type
                                                        
                                                        	Connector Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: connector_value
                                                        
                                                        	Connector Value
                                                        	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                        
                                                        .. attribute:: extended_community_flags
                                                        
                                                        	Extended community Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: is_aggregator_present
                                                        
                                                        	Aggregator attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_aigp_present
                                                        
                                                        	AIGP Present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path_present
                                                        
                                                        	AS path attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_atomic_aggregate_present
                                                        
                                                        	Atomic aggregate attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_community_present
                                                        
                                                        	Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_connector_present
                                                        
                                                        	Connector present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_extended_community_present
                                                        
                                                        	Extended community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_label_index_present
                                                        
                                                        	Label Index attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_local_pref_present
                                                        
                                                        	Local Preference attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ls_attribute_present
                                                        
                                                        	BGP LS attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_metric_present
                                                        
                                                        	Metric attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_origin_present
                                                        
                                                        	Origin attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pe_distinguisher_label_present
                                                        
                                                        	PE distinguisher label  attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pmsi_present
                                                        
                                                        	PMSI Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pppmp_present
                                                        
                                                        	PPMP Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ssa_present
                                                        
                                                        	SSA attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_encap_present
                                                        
                                                        	Tunnel Encap attribute present 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2tpv3_cookie
                                                        
                                                        	L2TPv3 Cookie
                                                        	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                        
                                                        .. attribute:: l2tpv3_session_id
                                                        
                                                        	L2TPv3 session id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: label_index_attr
                                                        
                                                        	Label Index attribute
                                                        	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                        
                                                        .. attribute:: local_preference
                                                        
                                                        	Local preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ls_attr
                                                        
                                                        	BGP LS attribute
                                                        	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: neighbor_as
                                                        
                                                        	Neighbor AS number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: origin
                                                        
                                                        	Origin
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: originator
                                                        
                                                        	Originator attribute
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: pe_distinguisher_label
                                                        
                                                        	PE distinguisher label attribute
                                                        	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                        
                                                        .. attribute:: pmsi_flags
                                                        
                                                        	PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pmsi_label
                                                        
                                                        	PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pmsi_type
                                                        
                                                        	PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pmsi_value
                                                        
                                                        	PMSI Value
                                                        	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                        
                                                        .. attribute:: ppm_pvalue
                                                        
                                                        	PPMP Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: sr_policy_allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                        
                                                        .. attribute:: sr_policy_binding_sid
                                                        
                                                        	SR Policy Binding sid
                                                        	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                        
                                                        .. attribute:: sr_policy_explicit_path
                                                        
                                                        	SR Policy Explicit paths
                                                        	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                        
                                                        .. attribute:: sr_policy_preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: sr_tunnel_request_state
                                                        
                                                        	SR Tunnel Request State
                                                        	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                        
                                                        .. attribute:: sr_tunnel_state
                                                        
                                                        	SR Tunnel State
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encap Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: unknown_attribute
                                                        
                                                        	Unknown attributes
                                                        	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.aggregator_address = None
                                                            self.aggregator_as = None
                                                            self.aigp_metric_value = None
                                                            self.as_path = None
                                                            self.cluster = YList()
                                                            self.cluster.parent = self
                                                            self.cluster.name = 'cluster'
                                                            self.community = YList()
                                                            self.community.parent = self
                                                            self.community.name = 'community'
                                                            self.connector_type = None
                                                            self.connector_value = YList()
                                                            self.connector_value.parent = self
                                                            self.connector_value.name = 'connector_value'
                                                            self.extended_community = YList()
                                                            self.extended_community.parent = self
                                                            self.extended_community.name = 'extended_community'
                                                            self.extended_community_flags = None
                                                            self.is_aggregator_present = None
                                                            self.is_aigp_present = None
                                                            self.is_as_path_present = None
                                                            self.is_atomic_aggregate_present = None
                                                            self.is_community_present = None
                                                            self.is_connector_present = None
                                                            self.is_extended_community_present = None
                                                            self.is_label_index_present = None
                                                            self.is_local_pref_present = None
                                                            self.is_ls_attribute_present = None
                                                            self.is_metric_present = None
                                                            self.is_origin_present = None
                                                            self.is_pe_distinguisher_label_present = None
                                                            self.is_pmsi_present = None
                                                            self.is_pppmp_present = None
                                                            self.is_ssa_present = None
                                                            self.is_tunnel_encap_present = None
                                                            self.l2tpv3_cookie = YList()
                                                            self.l2tpv3_cookie.parent = self
                                                            self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                            self.l2tpv3_session_id = None
                                                            self.label_index_attr = YList()
                                                            self.label_index_attr.parent = self
                                                            self.label_index_attr.name = 'label_index_attr'
                                                            self.local_preference = None
                                                            self.ls_attr = YList()
                                                            self.ls_attr.parent = self
                                                            self.ls_attr.name = 'ls_attr'
                                                            self.metric = None
                                                            self.neighbor_as = None
                                                            self.origin = None
                                                            self.originator = None
                                                            self.pe_distinguisher_label = YList()
                                                            self.pe_distinguisher_label.parent = self
                                                            self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                            self.pmsi_flags = None
                                                            self.pmsi_label = None
                                                            self.pmsi_type = None
                                                            self.pmsi_value = YList()
                                                            self.pmsi_value.parent = self
                                                            self.pmsi_value.name = 'pmsi_value'
                                                            self.ppm_pvalue = None
                                                            self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                            self.sr_policy_allocated_binding_sid.parent = self
                                                            self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                            self.sr_policy_binding_sid.parent = self
                                                            self.sr_policy_explicit_path = YList()
                                                            self.sr_policy_explicit_path.parent = self
                                                            self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                            self.sr_policy_preference = None
                                                            self.sr_tunnel_request_state = None
                                                            self.sr_tunnel_state = None
                                                            self.tunnel_encap_type = None
                                                            self.unknown_attribute = YList()
                                                            self.unknown_attribute.parent = self
                                                            self.unknown_attribute.name = 'unknown_attribute'


                                                        class SrPolicyBindingSid(object):
                                                            """
                                                            SR Policy Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_address = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                        class SrPolicyAllocatedBindingSid(object):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_address = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                        class Community(object):
                                                            """
                                                            Community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                        class ExtendedCommunity(object):
                                                            """
                                                            Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                        class UnknownAttribute(object):
                                                            """
                                                            Unknown attributes
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                        class Cluster(object):
                                                            """
                                                            Cluster list attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                        class L2Tpv3Cookie(object):
                                                            """
                                                            L2TPv3 Cookie
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                        class ConnectorValue(object):
                                                            """
                                                            Connector Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                        class PmsiValue(object):
                                                            """
                                                            PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                        class LsAttr(object):
                                                            """
                                                            BGP LS attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                        class LabelIndexAttr(object):
                                                            """
                                                            Label Index attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                        class PeDistinguisherLabel(object):
                                                            """
                                                            PE distinguisher label attribute
                                                            
                                                            .. attribute:: label
                                                            
                                                            	Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pe_address
                                                            
                                                            	 PE address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.label = None
                                                                self.pe_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.label is not None:
                                                                    return True

                                                                if self.pe_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                        class SrPolicyExplicitPath(object):
                                                            """
                                                            SR Policy Explicit paths
                                                            
                                                            .. attribute:: sid
                                                            
                                                            	Sidlist for explicit path
                                                            	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of explicit path
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.sid = YList()
                                                                self.sid.parent = self
                                                                self.sid.name = 'sid'
                                                                self.weight = None


                                                            class Sid(object):
                                                                """
                                                                Sidlist for explicit path
                                                                
                                                                .. attribute:: ipv4
                                                                
                                                                	IP Address sid
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6
                                                                
                                                                	IPv6 address sid
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label sid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Sid Type
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4 = None
                                                                    self.ipv6 = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4 is not None:
                                                                        return True

                                                                    if self.ipv6 is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.sid is not None:
                                                                    for child_ref in self.sid:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.weight is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.aggregator_address is not None:
                                                                return True

                                                            if self.aggregator_as is not None:
                                                                return True

                                                            if self.aigp_metric_value is not None:
                                                                return True

                                                            if self.as_path is not None:
                                                                return True

                                                            if self.cluster is not None:
                                                                for child_ref in self.cluster:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.community is not None:
                                                                for child_ref in self.community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.connector_type is not None:
                                                                return True

                                                            if self.connector_value is not None:
                                                                for child_ref in self.connector_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.extended_community is not None:
                                                                for child_ref in self.extended_community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.extended_community_flags is not None:
                                                                return True

                                                            if self.is_aggregator_present is not None:
                                                                return True

                                                            if self.is_aigp_present is not None:
                                                                return True

                                                            if self.is_as_path_present is not None:
                                                                return True

                                                            if self.is_atomic_aggregate_present is not None:
                                                                return True

                                                            if self.is_community_present is not None:
                                                                return True

                                                            if self.is_connector_present is not None:
                                                                return True

                                                            if self.is_extended_community_present is not None:
                                                                return True

                                                            if self.is_label_index_present is not None:
                                                                return True

                                                            if self.is_local_pref_present is not None:
                                                                return True

                                                            if self.is_ls_attribute_present is not None:
                                                                return True

                                                            if self.is_metric_present is not None:
                                                                return True

                                                            if self.is_origin_present is not None:
                                                                return True

                                                            if self.is_pe_distinguisher_label_present is not None:
                                                                return True

                                                            if self.is_pmsi_present is not None:
                                                                return True

                                                            if self.is_pppmp_present is not None:
                                                                return True

                                                            if self.is_ssa_present is not None:
                                                                return True

                                                            if self.is_tunnel_encap_present is not None:
                                                                return True

                                                            if self.l2tpv3_cookie is not None:
                                                                for child_ref in self.l2tpv3_cookie:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.l2tpv3_session_id is not None:
                                                                return True

                                                            if self.label_index_attr is not None:
                                                                for child_ref in self.label_index_attr:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.local_preference is not None:
                                                                return True

                                                            if self.ls_attr is not None:
                                                                for child_ref in self.ls_attr:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.neighbor_as is not None:
                                                                return True

                                                            if self.origin is not None:
                                                                return True

                                                            if self.originator is not None:
                                                                return True

                                                            if self.pe_distinguisher_label is not None:
                                                                for child_ref in self.pe_distinguisher_label:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.pmsi_flags is not None:
                                                                return True

                                                            if self.pmsi_label is not None:
                                                                return True

                                                            if self.pmsi_type is not None:
                                                                return True

                                                            if self.pmsi_value is not None:
                                                                for child_ref in self.pmsi_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.ppm_pvalue is not None:
                                                                return True

                                                            if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                                return True

                                                            if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                                return True

                                                            if self.sr_policy_explicit_path is not None:
                                                                for child_ref in self.sr_policy_explicit_path:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.sr_policy_preference is not None:
                                                                return True

                                                            if self.sr_tunnel_request_state is not None:
                                                                return True

                                                            if self.sr_tunnel_state is not None:
                                                                return True

                                                            if self.tunnel_encap_type is not None:
                                                                return True

                                                            if self.unknown_attribute is not None:
                                                                for child_ref in self.unknown_attribute:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                                    class RnhAddr(object):
                                                        """
                                                        RNH Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                        
                                                        .. attribute:: mac_address
                                                        
                                                        	MAC Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_address = None
                                                            self.ipv6_address = None
                                                            self.len = None
                                                            self.mac_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.len is not None:
                                                                return True

                                                            if self.mac_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                                    class RibrnhIp(object):
                                                        """
                                                        RIB RNH IP Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.attr_set is not None and self.attr_set._has_data():
                                                            return True

                                                        if self.attribute_key_number is not None:
                                                            return True

                                                        if self.attribute_reuse_id_config is not None:
                                                            return True

                                                        if self.attribute_reuse_id_current is not None:
                                                            return True

                                                        if self.attribute_reuse_id_keys is not None:
                                                            return True

                                                        if self.attribute_reuse_id_max_id is not None:
                                                            return True

                                                        if self.attribute_reuse_id_node is not None:
                                                            return True

                                                        if self.attribute_reuse_id_recover_sec is not None:
                                                            return True

                                                        if self.common_attributes is not None and self.common_attributes._has_data():
                                                            return True

                                                        if self.is_application_gateway_present is not None:
                                                            return True

                                                        if self.is_as_path2_byte is not None:
                                                            return True

                                                        if self.is_attr_set_present is not None:
                                                            return True

                                                        if self.is_ribrnh_present is not None:
                                                            return True

                                                        if self.is_rnh_present is not None:
                                                            return True

                                                        if self.ribrnh_encap is not None:
                                                            return True

                                                        if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                            return True

                                                        if self.ribrnh_mac is not None:
                                                            return True

                                                        if self.ribrnh_table is not None:
                                                            return True

                                                        if self.ribrnh_vni is not None:
                                                            return True

                                                        if self.ribrnhip_table is not None:
                                                            return True

                                                        if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                            return True

                                                        if self.rnh_addr_len is not None:
                                                            return True

                                                        if self.rnh_len is not None:
                                                            return True

                                                        if self.rnh_type is not None:
                                                            return True

                                                        if self.set_aigp_inbound_igp is not None:
                                                            return True

                                                        if self.set_aigp_inbound_metric is not None:
                                                            return True

                                                        if self.vpn_distinguisher is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath.AttributesAfterPolicyIn']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-process-instance-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.af_name is not None:
                                                        return True

                                                    if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                        return True

                                                    if self.label_fail is not None:
                                                        return True

                                                    if self.label_o_or_version is not None:
                                                        return True

                                                    if self.label_oor is not None:
                                                        return True

                                                    if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                        return True

                                                    if self.no_path is not None:
                                                        return True

                                                    if self.path_information is not None and self.path_information._has_data():
                                                        return True

                                                    if self.prefix_version is not None:
                                                        return True

                                                    if self.process_instance_id is not None:
                                                        return True

                                                    if self.route_distinguisher is not None:
                                                        return True

                                                    if self.source_route_distinguisher is not None:
                                                        return True

                                                    if self.source_vrf_name is not None:
                                                        return True

                                                    if self.srcaf_name is not None:
                                                        return True

                                                    if self.vrf_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalProcessInstancePath']['meta_info']


                                            class ActiveProcessInstancePath(object):
                                                """
                                                Active's paths for this net 
                                                
                                                .. attribute:: af_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: attributes_after_policy_in
                                                
                                                	Attributes after inbound policy applied
                                                	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn>`
                                                
                                                .. attribute:: label_fail
                                                
                                                	LSD label allocation failed 
                                                	**type**\:  bool
                                                
                                                .. attribute:: label_o_or_version
                                                
                                                	Label Version when OOR happens
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_oor
                                                
                                                	LSD label space is exhausted
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address_xr
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr>`
                                                
                                                .. attribute:: no_path
                                                
                                                	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                                	**type**\:  bool
                                                
                                                .. attribute:: path_information
                                                
                                                	Path information
                                                	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation>`
                                                
                                                .. attribute:: prefix_version
                                                
                                                	Version of BGP Prefix Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: process_instance_id
                                                
                                                	Process instance ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: source_route_distinguisher
                                                
                                                	Source Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: source_vrf_name
                                                
                                                	Name of the source VRF
                                                	**type**\:  str
                                                
                                                .. attribute:: srcaf_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: vrf_name
                                                
                                                	Name of the VRF
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.af_name = None
                                                    self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn()
                                                    self.attributes_after_policy_in.parent = self
                                                    self.label_fail = None
                                                    self.label_o_or_version = None
                                                    self.label_oor = None
                                                    self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr()
                                                    self.neighbor_address_xr.parent = self
                                                    self.no_path = None
                                                    self.path_information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation()
                                                    self.path_information.parent = self
                                                    self.prefix_version = None
                                                    self.process_instance_id = None
                                                    self.route_distinguisher = None
                                                    self.source_route_distinguisher = None
                                                    self.source_vrf_name = None
                                                    self.srcaf_name = None
                                                    self.vrf_name = None


                                                class NeighborAddressXr(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.NeighborAddressXr']['meta_info']


                                                class PathInformation(object):
                                                    """
                                                    Path information
                                                    
                                                    .. attribute:: accept_own_path
                                                    
                                                    	Accept Own
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: accept_own_self_originated_p_ath
                                                    
                                                    	Accept\-Own self\-originated
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: add_path_orr_bitfield
                                                    
                                                    	ORR Add path Bitfields
                                                    	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                    
                                                    .. attribute:: advertisedto_pe
                                                    
                                                    	Net could be advertised                          to PE peers
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: aigp_metric
                                                    
                                                    	Total AIGP metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: best_path_comp_stage
                                                    
                                                    	Stage where the path lost to the best path or group best
                                                    	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                                    
                                                    .. attribute:: best_path_comp_winner
                                                    
                                                    	Neighbor address of the path which won best path comparison
                                                    	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                    
                                                    .. attribute:: best_path_id
                                                    
                                                    	Best path ID; DEPRECATED BYLocalPathId
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: best_path_id_comp_winner
                                                    
                                                    	Path ID of the path which won best path comparison
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: best_path_orr_bitfield
                                                    
                                                    	ORR Best path Bitfields
                                                    	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                    
                                                    .. attribute:: bgp_prefix
                                                    
                                                    	BGP prefix
                                                    	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix>`
                                                    
                                                    .. attribute:: dampen_penalty
                                                    
                                                    	Dampening penalty
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Mvpn Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                    
                                                    .. attribute:: fspec_invalid_path
                                                    
                                                    	Is Fspec invalid path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: graceful_shutdown
                                                    
                                                    	Marked for graceful shutdown
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: gw_addr
                                                    
                                                    	Path GW Address
                                                    	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.GwAddr>`
                                                    
                                                    .. attribute:: halflife_time
                                                    
                                                    	Half\-life time for the penalty
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_esi
                                                    
                                                    	Path has EVPN ESI
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_gw_addr
                                                    
                                                    	Path has GW Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_local_net_label
                                                    
                                                    	Path has local label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mdt_group_addr
                                                    
                                                    	Path has MDT Group Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_extcomm
                                                    
                                                    	Path has MVPN EXTCOMM feedback
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_nbr_addr
                                                    
                                                    	Path has Mvpn nbr Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_nexthop_addr
                                                    
                                                    	Path has MVPN nexthop Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_pmsi
                                                    
                                                    	Path has MVPN PMSI feedback
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_rcvd_label
                                                    
                                                    	Path has received label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_second_label
                                                    
                                                    	Path has second received label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ibgp_signaled_validity
                                                    
                                                    	IBGP signalled validation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: igp_metric
                                                    
                                                    	IGP metric to the gateway
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_aggregation_suppressed
                                                    
                                                    	Path suppressed due to aggregation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_best
                                                    
                                                    	Best available path within AS
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_best_path
                                                    
                                                    	Best available path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_import_dampened
                                                    
                                                    	net import dampened
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_import_suspect
                                                    
                                                    	net import suspect
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_internal_path
                                                    
                                                    	Received over an internal link
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_best
                                                    
                                                    	Partial best path within distributed speaker
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_additional_path
                                                    
                                                    	Path is an additional\-path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_advertised_local_as_only
                                                    
                                                    	Not advertised outside local AS
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_af_install_eligible
                                                    
                                                    	Path can be installed in AF RIB
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_backup
                                                    
                                                    	Path is a backup path 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_backup_protect_multipath
                                                    
                                                    	Path is a backup path to protect multipaths
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_best_external
                                                    
                                                    	Path is a best external path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_damped
                                                    
                                                    	Path suppressed due to dampening
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_confederation_peer
                                                    
                                                    	Path received from confederation peer
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_network_command
                                                    
                                                    	Path sourced by network command
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_redistribute_command
                                                    
                                                    	Path sourced by redistribute command
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_route_reflector
                                                    
                                                    	Path received from route reflector
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_history_held
                                                    
                                                    	Path entry held to remember history
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_imp_candidate
                                                    
                                                    	Path is a candidate for multipath import
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_imported
                                                    
                                                    	Path is imported
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_local_aggregate
                                                    
                                                    	Path is a locally created aggregate
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_locally_sourced
                                                    
                                                    	Path sourced locally
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_long_lived_stale
                                                    
                                                    	Long lived stale routes learnt before neighbor restarts
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_multipath
                                                    
                                                    	Path is one of multipath best routes
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_nexthop_discarded
                                                    
                                                    	Path is redirected to Null0
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_not_advertised
                                                    
                                                    	Not advertised to any peer
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_not_advertised_to_ebg_ps
                                                    
                                                    	Not advertised to EBGPs
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_received_only
                                                    
                                                    	Path is received only
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_reoriginated
                                                    
                                                    	Path is reoriginated
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_reoriginated_stitching
                                                    
                                                    	Path is reoriginated with stitching RTs
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_stale
                                                    
                                                    	Stale routes learnt before neighbor restarts
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_synced_with_igp
                                                    
                                                    	Path synchronized with IGP
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_valid
                                                    
                                                    	Path attributes are usable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_vpn_only
                                                    
                                                    	Path is not in the vrf
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_permanent_path
                                                    
                                                    	Path is of type Permanent path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_received_path_not_modified
                                                    
                                                    	Received path used without modification
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_spkr_as_best
                                                    
                                                    	Best available path within AS in speaker
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2vpn_circuit_status_value
                                                    
                                                    	L2VPN Circuit Status Value
                                                    	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                    
                                                    .. attribute:: l2vpn_evpn_esi
                                                    
                                                    	L2VPN EVPN ESI
                                                    	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi>`
                                                    
                                                    .. attribute:: l2vpn_size
                                                    
                                                    	Path block size
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: labeled_unicast_safi_path
                                                    
                                                    	Path was learnt by labeled\-unicast SAFI
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: local_label
                                                    
                                                    	Path local label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_nh
                                                    
                                                    	Path has local nexthop
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: local_path_id
                                                    
                                                    	Local path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_peers_advertised_to
                                                    
                                                    	Local peers that this prefix has been advertised to
                                                    	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                    
                                                    .. attribute:: maximum_suppress_time
                                                    
                                                    	Maximum duration to suppress a stable route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mdt_group_addr
                                                    
                                                    	IPv4 MDT Group Address for the path
                                                    	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                    
                                                    .. attribute:: mvpn_nbr_addr
                                                    
                                                    	Mvpn nbr Address for the path
                                                    	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                    
                                                    .. attribute:: mvpn_nexthop_addr
                                                    
                                                    	Mvpn nexthop Address for the path
                                                    	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                    
                                                    .. attribute:: mvpn_path_flags
                                                    
                                                    	Mvpn path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: mvpn_pmsi_flags
                                                    
                                                    	Mvpn PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: mvpn_pmsi_label
                                                    
                                                    	Mvpn PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mvpn_pmsi_type
                                                    
                                                    	Mvpn PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: mvpn_pmsi_value
                                                    
                                                    	Mvpn PMSI Value
                                                    	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                    
                                                    .. attribute:: mvpn_sfs_path
                                                    
                                                    	Is MVPN single forwarder PE path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress>`
                                                    
                                                    .. attribute:: neighbor_router_id
                                                    
                                                    	Router ID of the neighbor for the path
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: next_hop
                                                    
                                                    	Next hop
                                                    	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop>`
                                                    
                                                    .. attribute:: nhte_tunnel
                                                    
                                                    	NH TE tunnel information
                                                    	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhteTunnel>`
                                                    
                                                    .. attribute:: path_flags
                                                    
                                                    	Flags associated with path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: path_flap_count
                                                    
                                                    	Number of times this route has flapped
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_import_flags
                                                    
                                                    	Path import flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_rt_set_id
                                                    
                                                    	RT\-set id of the path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_rt_set_route_count
                                                    
                                                    	Count in RT\-set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_table_version
                                                    
                                                    	Table version # for pelem
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_weight
                                                    
                                                    	Weight for the path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pe_peers_advertised_to
                                                    
                                                    	PE peers that this prefix has been advertised to
                                                    	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                    
                                                    .. attribute:: rcvd_label
                                                    
                                                    	Path received label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rcvd_path_id
                                                    
                                                    	Received path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: reuse_value
                                                    
                                                    	Value to start reusing a route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rib_failed
                                                    
                                                    	Is net failed installed                          in RIB
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: route_type
                                                    
                                                    	Route Type of path
                                                    	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                                    
                                                    .. attribute:: rpki_origin_as_validation_disabled
                                                    
                                                    	RPKI originAS V. Disabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rt_set_limit_enabled
                                                    
                                                    	Path subject to RT\-set net limit
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_label
                                                    
                                                    	Path second received label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: seconds_since_first_flap
                                                    
                                                    	Seconds since route first flapped
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: show_rpki_origin_as_validity
                                                    
                                                    	Display validity state ?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: sn_rpki_origin_as_validity
                                                    
                                                    	RPKI origin validation state
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: suppress_penalty
                                                    
                                                    	Value to start suppressing a route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: time_to_unsuppress
                                                    
                                                    	Seconds until route is unsuppressed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.accept_own_path = None
                                                        self.accept_own_self_originated_p_ath = None
                                                        self.add_path_orr_bitfield = YList()
                                                        self.add_path_orr_bitfield.parent = self
                                                        self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                        self.advertisedto_pe = None
                                                        self.aigp_metric = None
                                                        self.best_path_comp_stage = None
                                                        self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner()
                                                        self.best_path_comp_winner.parent = self
                                                        self.best_path_id = None
                                                        self.best_path_id_comp_winner = None
                                                        self.best_path_orr_bitfield = YList()
                                                        self.best_path_orr_bitfield.parent = self
                                                        self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                        self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix()
                                                        self.bgp_prefix.parent = self
                                                        self.dampen_penalty = None
                                                        self.extended_community = YList()
                                                        self.extended_community.parent = self
                                                        self.extended_community.name = 'extended_community'
                                                        self.fspec_invalid_path = None
                                                        self.graceful_shutdown = None
                                                        self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.GwAddr()
                                                        self.gw_addr.parent = self
                                                        self.halflife_time = None
                                                        self.has_esi = None
                                                        self.has_gw_addr = None
                                                        self.has_local_net_label = None
                                                        self.has_mdt_group_addr = None
                                                        self.has_mvpn_extcomm = None
                                                        self.has_mvpn_nbr_addr = None
                                                        self.has_mvpn_nexthop_addr = None
                                                        self.has_mvpn_pmsi = None
                                                        self.has_rcvd_label = None
                                                        self.has_second_label = None
                                                        self.ibgp_signaled_validity = None
                                                        self.igp_metric = None
                                                        self.is_aggregation_suppressed = None
                                                        self.is_as_best = None
                                                        self.is_best_path = None
                                                        self.is_import_dampened = None
                                                        self.is_import_suspect = None
                                                        self.is_internal_path = None
                                                        self.is_partial_best = None
                                                        self.is_path_additional_path = None
                                                        self.is_path_advertised_local_as_only = None
                                                        self.is_path_af_install_eligible = None
                                                        self.is_path_backup = None
                                                        self.is_path_backup_protect_multipath = None
                                                        self.is_path_best_external = None
                                                        self.is_path_damped = None
                                                        self.is_path_from_confederation_peer = None
                                                        self.is_path_from_network_command = None
                                                        self.is_path_from_redistribute_command = None
                                                        self.is_path_from_route_reflector = None
                                                        self.is_path_history_held = None
                                                        self.is_path_imp_candidate = None
                                                        self.is_path_imported = None
                                                        self.is_path_local_aggregate = None
                                                        self.is_path_locally_sourced = None
                                                        self.is_path_long_lived_stale = None
                                                        self.is_path_multipath = None
                                                        self.is_path_nexthop_discarded = None
                                                        self.is_path_not_advertised = None
                                                        self.is_path_not_advertised_to_ebg_ps = None
                                                        self.is_path_received_only = None
                                                        self.is_path_reoriginated = None
                                                        self.is_path_reoriginated_stitching = None
                                                        self.is_path_stale = None
                                                        self.is_path_synced_with_igp = None
                                                        self.is_path_valid = None
                                                        self.is_path_vpn_only = None
                                                        self.is_permanent_path = None
                                                        self.is_received_path_not_modified = None
                                                        self.is_spkr_as_best = None
                                                        self.l2vpn_circuit_status_value = YList()
                                                        self.l2vpn_circuit_status_value.parent = self
                                                        self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                        self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi()
                                                        self.l2vpn_evpn_esi.parent = self
                                                        self.l2vpn_size = None
                                                        self.labeled_unicast_safi_path = None
                                                        self.local_label = None
                                                        self.local_nh = None
                                                        self.local_path_id = None
                                                        self.local_peers_advertised_to = YList()
                                                        self.local_peers_advertised_to.parent = self
                                                        self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                        self.maximum_suppress_time = None
                                                        self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr()
                                                        self.mdt_group_addr.parent = self
                                                        self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                        self.mvpn_nbr_addr.parent = self
                                                        self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                        self.mvpn_nexthop_addr.parent = self
                                                        self.mvpn_path_flags = None
                                                        self.mvpn_pmsi_flags = None
                                                        self.mvpn_pmsi_label = None
                                                        self.mvpn_pmsi_type = None
                                                        self.mvpn_pmsi_value = YList()
                                                        self.mvpn_pmsi_value.parent = self
                                                        self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                        self.mvpn_sfs_path = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.neighbor_router_id = None
                                                        self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop()
                                                        self.next_hop.parent = self
                                                        self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhteTunnel()
                                                        self.nhte_tunnel.parent = self
                                                        self.path_flags = None
                                                        self.path_flap_count = None
                                                        self.path_import_flags = None
                                                        self.path_rt_set_id = None
                                                        self.path_rt_set_route_count = None
                                                        self.path_table_version = None
                                                        self.path_weight = None
                                                        self.pe_peers_advertised_to = YList()
                                                        self.pe_peers_advertised_to.parent = self
                                                        self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                        self.rcvd_label = None
                                                        self.rcvd_path_id = None
                                                        self.reuse_value = None
                                                        self.rib_failed = None
                                                        self.route_type = None
                                                        self.rpki_origin_as_validation_disabled = None
                                                        self.rt_set_limit_enabled = None
                                                        self.second_label = None
                                                        self.seconds_since_first_flap = None
                                                        self.show_rpki_origin_as_validity = None
                                                        self.sn_rpki_origin_as_validity = None
                                                        self.suppress_penalty = None
                                                        self.time_to_unsuppress = None


                                                    class BgpPrefix(object):
                                                        """
                                                        BGP prefix
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Prefix
                                                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                            self.prefix.parent = self
                                                            self.prefix_length = None


                                                        class Prefix(object):
                                                            """
                                                            Prefix
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.prefix is not None and self.prefix._has_data():
                                                                return True

                                                            if self.prefix_length is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BgpPrefix']['meta_info']


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NeighborAddress']['meta_info']


                                                    class NextHop(object):
                                                        """
                                                        Next hop
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NextHop']['meta_info']


                                                    class NhteTunnel(object):
                                                        """
                                                        NH TE tunnel information
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	Binding label for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_te_tunnel
                                                        
                                                        	NH TE Tunnel info is present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_info_stale
                                                        
                                                        	Tunnel is stale
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_registered
                                                        
                                                        	Tunnel registered flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_up
                                                        
                                                        	Tunnel Up flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: last_tunnel_update
                                                        
                                                        	Time since the last rib update happened
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_if_handle
                                                        
                                                        	Interface handle for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_name
                                                        
                                                        	tunnel name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        .. attribute:: tunnel_type
                                                        
                                                        	tunnel type
                                                        	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                        
                                                        .. attribute:: tunnel_v6_enabled
                                                        
                                                        	IPv6 enabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_v6_required
                                                        
                                                        	Tunnel need IPv6
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.binding_label = None
                                                            self.has_te_tunnel = None
                                                            self.is_tunnel_info_stale = None
                                                            self.is_tunnel_registered = None
                                                            self.is_tunnel_up = None
                                                            self.last_tunnel_update = None
                                                            self.tunnel_if_handle = None
                                                            self.tunnel_name = None
                                                            self.tunnel_type = None
                                                            self.tunnel_v6_enabled = None
                                                            self.tunnel_v6_required = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.binding_label is not None:
                                                                return True

                                                            if self.has_te_tunnel is not None:
                                                                return True

                                                            if self.is_tunnel_info_stale is not None:
                                                                return True

                                                            if self.is_tunnel_registered is not None:
                                                                return True

                                                            if self.is_tunnel_up is not None:
                                                                return True

                                                            if self.last_tunnel_update is not None:
                                                                return True

                                                            if self.tunnel_if_handle is not None:
                                                                return True

                                                            if self.tunnel_name is not None:
                                                                return True

                                                            if self.tunnel_type is not None:
                                                                return True

                                                            if self.tunnel_v6_enabled is not None:
                                                                return True

                                                            if self.tunnel_v6_required is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.NhteTunnel']['meta_info']


                                                    class MdtGroupAddr(object):
                                                        """
                                                        IPv4 MDT Group Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr']['meta_info']


                                                    class L2VpnEvpnEsi(object):
                                                        """
                                                        L2VPN EVPN ESI
                                                        
                                                        .. attribute:: esi
                                                        
                                                        	esi
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.esi = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.esi is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi']['meta_info']


                                                    class GwAddr(object):
                                                        """
                                                        Path GW Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_address = None
                                                            self.ipv6_address = None
                                                            self.len = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.len is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.GwAddr']['meta_info']


                                                    class BestPathCompWinner(object):
                                                        """
                                                        Neighbor address of the path which won best path
                                                        comparison
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner']['meta_info']


                                                    class MvpnNbrAddr(object):
                                                        """
                                                        Mvpn nbr Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr']['meta_info']


                                                    class MvpnNexthopAddr(object):
                                                        """
                                                        Mvpn nexthop Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr']['meta_info']


                                                    class L2VpnCircuitStatusValue(object):
                                                        """
                                                        L2VPN Circuit Status Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                                    class MvpnPmsiValue(object):
                                                        """
                                                        Mvpn PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue']['meta_info']


                                                    class ExtendedCommunity(object):
                                                        """
                                                        Mvpn Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity']['meta_info']


                                                    class LocalPeersAdvertisedTo(object):
                                                        """
                                                        Local peers that this prefix has been advertised
                                                        to
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.is_neighbor = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.update_group_number = None


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.is_neighbor is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.update_group_number is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                                    class PePeersAdvertisedTo(object):
                                                        """
                                                        PE peers that this prefix has been advertised to
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.is_neighbor = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.update_group_number = None


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.is_neighbor is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.update_group_number is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo']['meta_info']


                                                    class BestPathOrrBitfield(object):
                                                        """
                                                        ORR Best path Bitfields
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.is_neighbor = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.update_group_number = None


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.is_neighbor is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.update_group_number is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield']['meta_info']


                                                    class AddPathOrrBitfield(object):
                                                        """
                                                        ORR Add path Bitfields
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.is_neighbor = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.update_group_number = None


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.is_neighbor is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.update_group_number is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.accept_own_path is not None:
                                                            return True

                                                        if self.accept_own_self_originated_p_ath is not None:
                                                            return True

                                                        if self.add_path_orr_bitfield is not None:
                                                            for child_ref in self.add_path_orr_bitfield:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.advertisedto_pe is not None:
                                                            return True

                                                        if self.aigp_metric is not None:
                                                            return True

                                                        if self.best_path_comp_stage is not None:
                                                            return True

                                                        if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                            return True

                                                        if self.best_path_id is not None:
                                                            return True

                                                        if self.best_path_id_comp_winner is not None:
                                                            return True

                                                        if self.best_path_orr_bitfield is not None:
                                                            for child_ref in self.best_path_orr_bitfield:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                            return True

                                                        if self.dampen_penalty is not None:
                                                            return True

                                                        if self.extended_community is not None:
                                                            for child_ref in self.extended_community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.fspec_invalid_path is not None:
                                                            return True

                                                        if self.graceful_shutdown is not None:
                                                            return True

                                                        if self.gw_addr is not None and self.gw_addr._has_data():
                                                            return True

                                                        if self.halflife_time is not None:
                                                            return True

                                                        if self.has_esi is not None:
                                                            return True

                                                        if self.has_gw_addr is not None:
                                                            return True

                                                        if self.has_local_net_label is not None:
                                                            return True

                                                        if self.has_mdt_group_addr is not None:
                                                            return True

                                                        if self.has_mvpn_extcomm is not None:
                                                            return True

                                                        if self.has_mvpn_nbr_addr is not None:
                                                            return True

                                                        if self.has_mvpn_nexthop_addr is not None:
                                                            return True

                                                        if self.has_mvpn_pmsi is not None:
                                                            return True

                                                        if self.has_rcvd_label is not None:
                                                            return True

                                                        if self.has_second_label is not None:
                                                            return True

                                                        if self.ibgp_signaled_validity is not None:
                                                            return True

                                                        if self.igp_metric is not None:
                                                            return True

                                                        if self.is_aggregation_suppressed is not None:
                                                            return True

                                                        if self.is_as_best is not None:
                                                            return True

                                                        if self.is_best_path is not None:
                                                            return True

                                                        if self.is_import_dampened is not None:
                                                            return True

                                                        if self.is_import_suspect is not None:
                                                            return True

                                                        if self.is_internal_path is not None:
                                                            return True

                                                        if self.is_partial_best is not None:
                                                            return True

                                                        if self.is_path_additional_path is not None:
                                                            return True

                                                        if self.is_path_advertised_local_as_only is not None:
                                                            return True

                                                        if self.is_path_af_install_eligible is not None:
                                                            return True

                                                        if self.is_path_backup is not None:
                                                            return True

                                                        if self.is_path_backup_protect_multipath is not None:
                                                            return True

                                                        if self.is_path_best_external is not None:
                                                            return True

                                                        if self.is_path_damped is not None:
                                                            return True

                                                        if self.is_path_from_confederation_peer is not None:
                                                            return True

                                                        if self.is_path_from_network_command is not None:
                                                            return True

                                                        if self.is_path_from_redistribute_command is not None:
                                                            return True

                                                        if self.is_path_from_route_reflector is not None:
                                                            return True

                                                        if self.is_path_history_held is not None:
                                                            return True

                                                        if self.is_path_imp_candidate is not None:
                                                            return True

                                                        if self.is_path_imported is not None:
                                                            return True

                                                        if self.is_path_local_aggregate is not None:
                                                            return True

                                                        if self.is_path_locally_sourced is not None:
                                                            return True

                                                        if self.is_path_long_lived_stale is not None:
                                                            return True

                                                        if self.is_path_multipath is not None:
                                                            return True

                                                        if self.is_path_nexthop_discarded is not None:
                                                            return True

                                                        if self.is_path_not_advertised is not None:
                                                            return True

                                                        if self.is_path_not_advertised_to_ebg_ps is not None:
                                                            return True

                                                        if self.is_path_received_only is not None:
                                                            return True

                                                        if self.is_path_reoriginated is not None:
                                                            return True

                                                        if self.is_path_reoriginated_stitching is not None:
                                                            return True

                                                        if self.is_path_stale is not None:
                                                            return True

                                                        if self.is_path_synced_with_igp is not None:
                                                            return True

                                                        if self.is_path_valid is not None:
                                                            return True

                                                        if self.is_path_vpn_only is not None:
                                                            return True

                                                        if self.is_permanent_path is not None:
                                                            return True

                                                        if self.is_received_path_not_modified is not None:
                                                            return True

                                                        if self.is_spkr_as_best is not None:
                                                            return True

                                                        if self.l2vpn_circuit_status_value is not None:
                                                            for child_ref in self.l2vpn_circuit_status_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                            return True

                                                        if self.l2vpn_size is not None:
                                                            return True

                                                        if self.labeled_unicast_safi_path is not None:
                                                            return True

                                                        if self.local_label is not None:
                                                            return True

                                                        if self.local_nh is not None:
                                                            return True

                                                        if self.local_path_id is not None:
                                                            return True

                                                        if self.local_peers_advertised_to is not None:
                                                            for child_ref in self.local_peers_advertised_to:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.maximum_suppress_time is not None:
                                                            return True

                                                        if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                            return True

                                                        if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                            return True

                                                        if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                            return True

                                                        if self.mvpn_path_flags is not None:
                                                            return True

                                                        if self.mvpn_pmsi_flags is not None:
                                                            return True

                                                        if self.mvpn_pmsi_label is not None:
                                                            return True

                                                        if self.mvpn_pmsi_type is not None:
                                                            return True

                                                        if self.mvpn_pmsi_value is not None:
                                                            for child_ref in self.mvpn_pmsi_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.mvpn_sfs_path is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.neighbor_router_id is not None:
                                                            return True

                                                        if self.next_hop is not None and self.next_hop._has_data():
                                                            return True

                                                        if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                            return True

                                                        if self.path_flags is not None:
                                                            return True

                                                        if self.path_flap_count is not None:
                                                            return True

                                                        if self.path_import_flags is not None:
                                                            return True

                                                        if self.path_rt_set_id is not None:
                                                            return True

                                                        if self.path_rt_set_route_count is not None:
                                                            return True

                                                        if self.path_table_version is not None:
                                                            return True

                                                        if self.path_weight is not None:
                                                            return True

                                                        if self.pe_peers_advertised_to is not None:
                                                            for child_ref in self.pe_peers_advertised_to:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.rcvd_label is not None:
                                                            return True

                                                        if self.rcvd_path_id is not None:
                                                            return True

                                                        if self.reuse_value is not None:
                                                            return True

                                                        if self.rib_failed is not None:
                                                            return True

                                                        if self.route_type is not None:
                                                            return True

                                                        if self.rpki_origin_as_validation_disabled is not None:
                                                            return True

                                                        if self.rt_set_limit_enabled is not None:
                                                            return True

                                                        if self.second_label is not None:
                                                            return True

                                                        if self.seconds_since_first_flap is not None:
                                                            return True

                                                        if self.show_rpki_origin_as_validity is not None:
                                                            return True

                                                        if self.sn_rpki_origin_as_validity is not None:
                                                            return True

                                                        if self.suppress_penalty is not None:
                                                            return True

                                                        if self.time_to_unsuppress is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.PathInformation']['meta_info']


                                                class AttributesAfterPolicyIn(object):
                                                    """
                                                    Attributes after inbound policy applied
                                                    
                                                    .. attribute:: attr_set
                                                    
                                                    	ATTR\_SET attribute
                                                    	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                    
                                                    .. attribute:: attribute_key_number
                                                    
                                                    	Attribute key number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_config
                                                    
                                                    	Attribute reuse ID Configured
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: attribute_reuse_id_current
                                                    
                                                    	Attribute reuse ID current ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_keys
                                                    
                                                    	Attribute reuse ID allocated keys
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_max_id
                                                    
                                                    	Attribute reuse ID maximum ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_node
                                                    
                                                    	Attribute reuse ID nodes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_recover_sec
                                                    
                                                    	Attribute reuse ID timer in seconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: common_attributes
                                                    
                                                    	Common attributes
                                                    	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                    
                                                    .. attribute:: is_application_gateway_present
                                                    
                                                    	Application gateway present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path2_byte
                                                    
                                                    	AS path encoded as 2\-byte
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_attr_set_present
                                                    
                                                    	BGP ATTR\_SET attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ribrnh_present
                                                    
                                                    	RIB RNH Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_rnh_present
                                                    
                                                    	RNH Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ribrnh_encap
                                                    
                                                    	RIB RNH Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ribrnh_ip
                                                    
                                                    	RIB RNH IP Address
                                                    	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                    
                                                    .. attribute:: ribrnh_mac
                                                    
                                                    	RIB RNH MAC Address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    .. attribute:: ribrnh_table
                                                    
                                                    	RIB RNH Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ribrnh_vni
                                                    
                                                    	RIB RNH Vni
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ribrnhip_table
                                                    
                                                    	RIB RNH IP Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rnh_addr
                                                    
                                                    	RNH Address
                                                    	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                    
                                                    .. attribute:: rnh_addr_len
                                                    
                                                    	RNH Address Length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rnh_len
                                                    
                                                    	RNH Length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: rnh_type
                                                    
                                                    	RNH Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: set_aigp_inbound_igp
                                                    
                                                    	AIGP set by policy inbound IGP 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: set_aigp_inbound_metric
                                                    
                                                    	AIGP set by policy inbound metric
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: vpn_distinguisher
                                                    
                                                    	VPN Distinguisher
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                        self.attr_set.parent = self
                                                        self.attribute_key_number = None
                                                        self.attribute_reuse_id_config = None
                                                        self.attribute_reuse_id_current = None
                                                        self.attribute_reuse_id_keys = None
                                                        self.attribute_reuse_id_max_id = None
                                                        self.attribute_reuse_id_node = None
                                                        self.attribute_reuse_id_recover_sec = None
                                                        self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                        self.common_attributes.parent = self
                                                        self.is_application_gateway_present = None
                                                        self.is_as_path2_byte = None
                                                        self.is_attr_set_present = None
                                                        self.is_ribrnh_present = None
                                                        self.is_rnh_present = None
                                                        self.ribrnh_encap = None
                                                        self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                        self.ribrnh_ip.parent = self
                                                        self.ribrnh_mac = None
                                                        self.ribrnh_table = None
                                                        self.ribrnh_vni = None
                                                        self.ribrnhip_table = None
                                                        self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                        self.rnh_addr.parent = self
                                                        self.rnh_addr_len = None
                                                        self.rnh_len = None
                                                        self.rnh_type = None
                                                        self.set_aigp_inbound_igp = None
                                                        self.set_aigp_inbound_metric = None
                                                        self.vpn_distinguisher = None


                                                    class CommonAttributes(object):
                                                        """
                                                        Common attributes
                                                        
                                                        .. attribute:: aggregator_address
                                                        
                                                        	Address where aggregation was performed
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: aggregator_as
                                                        
                                                        	AS where aggregation was last performed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: aigp_metric_value
                                                        
                                                        	AIGP metric value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: as_path
                                                        
                                                        	AS path attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: cluster
                                                        
                                                        	Cluster list attribute
                                                        	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                        
                                                        .. attribute:: community
                                                        
                                                        	Community attribute
                                                        	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                        
                                                        .. attribute:: connector_type
                                                        
                                                        	Connector Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: connector_value
                                                        
                                                        	Connector Value
                                                        	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                        
                                                        .. attribute:: extended_community_flags
                                                        
                                                        	Extended community Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: is_aggregator_present
                                                        
                                                        	Aggregator attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_aigp_present
                                                        
                                                        	AIGP Present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path_present
                                                        
                                                        	AS path attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_atomic_aggregate_present
                                                        
                                                        	Atomic aggregate attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_community_present
                                                        
                                                        	Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_connector_present
                                                        
                                                        	Connector present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_extended_community_present
                                                        
                                                        	Extended community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_label_index_present
                                                        
                                                        	Label Index attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_local_pref_present
                                                        
                                                        	Local Preference attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ls_attribute_present
                                                        
                                                        	BGP LS attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_metric_present
                                                        
                                                        	Metric attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_origin_present
                                                        
                                                        	Origin attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pe_distinguisher_label_present
                                                        
                                                        	PE distinguisher label  attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pmsi_present
                                                        
                                                        	PMSI Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pppmp_present
                                                        
                                                        	PPMP Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ssa_present
                                                        
                                                        	SSA attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_encap_present
                                                        
                                                        	Tunnel Encap attribute present 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2tpv3_cookie
                                                        
                                                        	L2TPv3 Cookie
                                                        	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                        
                                                        .. attribute:: l2tpv3_session_id
                                                        
                                                        	L2TPv3 session id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: label_index_attr
                                                        
                                                        	Label Index attribute
                                                        	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                        
                                                        .. attribute:: local_preference
                                                        
                                                        	Local preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ls_attr
                                                        
                                                        	BGP LS attribute
                                                        	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: neighbor_as
                                                        
                                                        	Neighbor AS number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: origin
                                                        
                                                        	Origin
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: originator
                                                        
                                                        	Originator attribute
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: pe_distinguisher_label
                                                        
                                                        	PE distinguisher label attribute
                                                        	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                        
                                                        .. attribute:: pmsi_flags
                                                        
                                                        	PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pmsi_label
                                                        
                                                        	PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pmsi_type
                                                        
                                                        	PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pmsi_value
                                                        
                                                        	PMSI Value
                                                        	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                        
                                                        .. attribute:: ppm_pvalue
                                                        
                                                        	PPMP Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: sr_policy_allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                        
                                                        .. attribute:: sr_policy_binding_sid
                                                        
                                                        	SR Policy Binding sid
                                                        	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                        
                                                        .. attribute:: sr_policy_explicit_path
                                                        
                                                        	SR Policy Explicit paths
                                                        	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                        
                                                        .. attribute:: sr_policy_preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: sr_tunnel_request_state
                                                        
                                                        	SR Tunnel Request State
                                                        	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                        
                                                        .. attribute:: sr_tunnel_state
                                                        
                                                        	SR Tunnel State
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encap Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: unknown_attribute
                                                        
                                                        	Unknown attributes
                                                        	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.aggregator_address = None
                                                            self.aggregator_as = None
                                                            self.aigp_metric_value = None
                                                            self.as_path = None
                                                            self.cluster = YList()
                                                            self.cluster.parent = self
                                                            self.cluster.name = 'cluster'
                                                            self.community = YList()
                                                            self.community.parent = self
                                                            self.community.name = 'community'
                                                            self.connector_type = None
                                                            self.connector_value = YList()
                                                            self.connector_value.parent = self
                                                            self.connector_value.name = 'connector_value'
                                                            self.extended_community = YList()
                                                            self.extended_community.parent = self
                                                            self.extended_community.name = 'extended_community'
                                                            self.extended_community_flags = None
                                                            self.is_aggregator_present = None
                                                            self.is_aigp_present = None
                                                            self.is_as_path_present = None
                                                            self.is_atomic_aggregate_present = None
                                                            self.is_community_present = None
                                                            self.is_connector_present = None
                                                            self.is_extended_community_present = None
                                                            self.is_label_index_present = None
                                                            self.is_local_pref_present = None
                                                            self.is_ls_attribute_present = None
                                                            self.is_metric_present = None
                                                            self.is_origin_present = None
                                                            self.is_pe_distinguisher_label_present = None
                                                            self.is_pmsi_present = None
                                                            self.is_pppmp_present = None
                                                            self.is_ssa_present = None
                                                            self.is_tunnel_encap_present = None
                                                            self.l2tpv3_cookie = YList()
                                                            self.l2tpv3_cookie.parent = self
                                                            self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                            self.l2tpv3_session_id = None
                                                            self.label_index_attr = YList()
                                                            self.label_index_attr.parent = self
                                                            self.label_index_attr.name = 'label_index_attr'
                                                            self.local_preference = None
                                                            self.ls_attr = YList()
                                                            self.ls_attr.parent = self
                                                            self.ls_attr.name = 'ls_attr'
                                                            self.metric = None
                                                            self.neighbor_as = None
                                                            self.origin = None
                                                            self.originator = None
                                                            self.pe_distinguisher_label = YList()
                                                            self.pe_distinguisher_label.parent = self
                                                            self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                            self.pmsi_flags = None
                                                            self.pmsi_label = None
                                                            self.pmsi_type = None
                                                            self.pmsi_value = YList()
                                                            self.pmsi_value.parent = self
                                                            self.pmsi_value.name = 'pmsi_value'
                                                            self.ppm_pvalue = None
                                                            self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                            self.sr_policy_allocated_binding_sid.parent = self
                                                            self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                            self.sr_policy_binding_sid.parent = self
                                                            self.sr_policy_explicit_path = YList()
                                                            self.sr_policy_explicit_path.parent = self
                                                            self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                            self.sr_policy_preference = None
                                                            self.sr_tunnel_request_state = None
                                                            self.sr_tunnel_state = None
                                                            self.tunnel_encap_type = None
                                                            self.unknown_attribute = YList()
                                                            self.unknown_attribute.parent = self
                                                            self.unknown_attribute.name = 'unknown_attribute'


                                                        class SrPolicyBindingSid(object):
                                                            """
                                                            SR Policy Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_address = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                        class SrPolicyAllocatedBindingSid(object):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_address = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                        class Community(object):
                                                            """
                                                            Community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                        class ExtendedCommunity(object):
                                                            """
                                                            Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                        class UnknownAttribute(object):
                                                            """
                                                            Unknown attributes
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                        class Cluster(object):
                                                            """
                                                            Cluster list attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                        class L2Tpv3Cookie(object):
                                                            """
                                                            L2TPv3 Cookie
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                        class ConnectorValue(object):
                                                            """
                                                            Connector Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                        class PmsiValue(object):
                                                            """
                                                            PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                        class LsAttr(object):
                                                            """
                                                            BGP LS attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                        class LabelIndexAttr(object):
                                                            """
                                                            Label Index attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                        class PeDistinguisherLabel(object):
                                                            """
                                                            PE distinguisher label attribute
                                                            
                                                            .. attribute:: label
                                                            
                                                            	Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pe_address
                                                            
                                                            	 PE address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.label = None
                                                                self.pe_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.label is not None:
                                                                    return True

                                                                if self.pe_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                        class SrPolicyExplicitPath(object):
                                                            """
                                                            SR Policy Explicit paths
                                                            
                                                            .. attribute:: sid
                                                            
                                                            	Sidlist for explicit path
                                                            	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of explicit path
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.sid = YList()
                                                                self.sid.parent = self
                                                                self.sid.name = 'sid'
                                                                self.weight = None


                                                            class Sid(object):
                                                                """
                                                                Sidlist for explicit path
                                                                
                                                                .. attribute:: ipv4
                                                                
                                                                	IP Address sid
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6
                                                                
                                                                	IPv6 address sid
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label sid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Sid Type
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4 = None
                                                                    self.ipv6 = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4 is not None:
                                                                        return True

                                                                    if self.ipv6 is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.sid is not None:
                                                                    for child_ref in self.sid:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.weight is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.aggregator_address is not None:
                                                                return True

                                                            if self.aggregator_as is not None:
                                                                return True

                                                            if self.aigp_metric_value is not None:
                                                                return True

                                                            if self.as_path is not None:
                                                                return True

                                                            if self.cluster is not None:
                                                                for child_ref in self.cluster:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.community is not None:
                                                                for child_ref in self.community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.connector_type is not None:
                                                                return True

                                                            if self.connector_value is not None:
                                                                for child_ref in self.connector_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.extended_community is not None:
                                                                for child_ref in self.extended_community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.extended_community_flags is not None:
                                                                return True

                                                            if self.is_aggregator_present is not None:
                                                                return True

                                                            if self.is_aigp_present is not None:
                                                                return True

                                                            if self.is_as_path_present is not None:
                                                                return True

                                                            if self.is_atomic_aggregate_present is not None:
                                                                return True

                                                            if self.is_community_present is not None:
                                                                return True

                                                            if self.is_connector_present is not None:
                                                                return True

                                                            if self.is_extended_community_present is not None:
                                                                return True

                                                            if self.is_label_index_present is not None:
                                                                return True

                                                            if self.is_local_pref_present is not None:
                                                                return True

                                                            if self.is_ls_attribute_present is not None:
                                                                return True

                                                            if self.is_metric_present is not None:
                                                                return True

                                                            if self.is_origin_present is not None:
                                                                return True

                                                            if self.is_pe_distinguisher_label_present is not None:
                                                                return True

                                                            if self.is_pmsi_present is not None:
                                                                return True

                                                            if self.is_pppmp_present is not None:
                                                                return True

                                                            if self.is_ssa_present is not None:
                                                                return True

                                                            if self.is_tunnel_encap_present is not None:
                                                                return True

                                                            if self.l2tpv3_cookie is not None:
                                                                for child_ref in self.l2tpv3_cookie:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.l2tpv3_session_id is not None:
                                                                return True

                                                            if self.label_index_attr is not None:
                                                                for child_ref in self.label_index_attr:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.local_preference is not None:
                                                                return True

                                                            if self.ls_attr is not None:
                                                                for child_ref in self.ls_attr:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.neighbor_as is not None:
                                                                return True

                                                            if self.origin is not None:
                                                                return True

                                                            if self.originator is not None:
                                                                return True

                                                            if self.pe_distinguisher_label is not None:
                                                                for child_ref in self.pe_distinguisher_label:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.pmsi_flags is not None:
                                                                return True

                                                            if self.pmsi_label is not None:
                                                                return True

                                                            if self.pmsi_type is not None:
                                                                return True

                                                            if self.pmsi_value is not None:
                                                                for child_ref in self.pmsi_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.ppm_pvalue is not None:
                                                                return True

                                                            if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                                return True

                                                            if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                                return True

                                                            if self.sr_policy_explicit_path is not None:
                                                                for child_ref in self.sr_policy_explicit_path:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.sr_policy_preference is not None:
                                                                return True

                                                            if self.sr_tunnel_request_state is not None:
                                                                return True

                                                            if self.sr_tunnel_state is not None:
                                                                return True

                                                            if self.tunnel_encap_type is not None:
                                                                return True

                                                            if self.unknown_attribute is not None:
                                                                for child_ref in self.unknown_attribute:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                                    class AttrSet(object):
                                                        """
                                                        ATTR\_SET attribute
                                                        
                                                        .. attribute:: aggregator_address
                                                        
                                                        	Address where aggregation was performed
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: aggregator_as
                                                        
                                                        	AS where aggregation was last performed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: aigp_metric_value
                                                        
                                                        	AIGP metric value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: as_path
                                                        
                                                        	AS path attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: cluster
                                                        
                                                        	Cluster list attribute
                                                        	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                        
                                                        .. attribute:: community
                                                        
                                                        	Community attribute
                                                        	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                        
                                                        .. attribute:: connector_type
                                                        
                                                        	Connector Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: connector_value
                                                        
                                                        	Connector Value
                                                        	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                        
                                                        .. attribute:: extended_community_flags
                                                        
                                                        	Extended community Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: is_aggregator_present
                                                        
                                                        	Aggregator attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_aigp_present
                                                        
                                                        	AIGP Present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path_present
                                                        
                                                        	AS path attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_atomic_aggregate_present
                                                        
                                                        	Atomic aggregate attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_community_present
                                                        
                                                        	Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_connector_present
                                                        
                                                        	Connector present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_extended_community_present
                                                        
                                                        	Extended community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_label_index_present
                                                        
                                                        	Label Index attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_local_pref_present
                                                        
                                                        	Local Preference attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ls_attribute_present
                                                        
                                                        	BGP LS attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_metric_present
                                                        
                                                        	Metric attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_origin_present
                                                        
                                                        	Origin attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pe_distinguisher_label_present
                                                        
                                                        	PE distinguisher label  attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pmsi_present
                                                        
                                                        	PMSI Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pppmp_present
                                                        
                                                        	PPMP Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ssa_present
                                                        
                                                        	SSA attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_encap_present
                                                        
                                                        	Tunnel Encap attribute present 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2tpv3_cookie
                                                        
                                                        	L2TPv3 Cookie
                                                        	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                        
                                                        .. attribute:: l2tpv3_session_id
                                                        
                                                        	L2TPv3 session id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: label_index_attr
                                                        
                                                        	Label Index attribute
                                                        	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                        
                                                        .. attribute:: local_preference
                                                        
                                                        	Local preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ls_attr
                                                        
                                                        	BGP LS attribute
                                                        	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: neighbor_as
                                                        
                                                        	Neighbor AS number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: origin
                                                        
                                                        	Origin
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: originator
                                                        
                                                        	Originator attribute
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: pe_distinguisher_label
                                                        
                                                        	PE distinguisher label attribute
                                                        	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                        
                                                        .. attribute:: pmsi_flags
                                                        
                                                        	PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pmsi_label
                                                        
                                                        	PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pmsi_type
                                                        
                                                        	PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pmsi_value
                                                        
                                                        	PMSI Value
                                                        	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                        
                                                        .. attribute:: ppm_pvalue
                                                        
                                                        	PPMP Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: sr_policy_allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                        
                                                        .. attribute:: sr_policy_binding_sid
                                                        
                                                        	SR Policy Binding sid
                                                        	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                        
                                                        .. attribute:: sr_policy_explicit_path
                                                        
                                                        	SR Policy Explicit paths
                                                        	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                        
                                                        .. attribute:: sr_policy_preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: sr_tunnel_request_state
                                                        
                                                        	SR Tunnel Request State
                                                        	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                        
                                                        .. attribute:: sr_tunnel_state
                                                        
                                                        	SR Tunnel State
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encap Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: unknown_attribute
                                                        
                                                        	Unknown attributes
                                                        	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.aggregator_address = None
                                                            self.aggregator_as = None
                                                            self.aigp_metric_value = None
                                                            self.as_path = None
                                                            self.cluster = YList()
                                                            self.cluster.parent = self
                                                            self.cluster.name = 'cluster'
                                                            self.community = YList()
                                                            self.community.parent = self
                                                            self.community.name = 'community'
                                                            self.connector_type = None
                                                            self.connector_value = YList()
                                                            self.connector_value.parent = self
                                                            self.connector_value.name = 'connector_value'
                                                            self.extended_community = YList()
                                                            self.extended_community.parent = self
                                                            self.extended_community.name = 'extended_community'
                                                            self.extended_community_flags = None
                                                            self.is_aggregator_present = None
                                                            self.is_aigp_present = None
                                                            self.is_as_path_present = None
                                                            self.is_atomic_aggregate_present = None
                                                            self.is_community_present = None
                                                            self.is_connector_present = None
                                                            self.is_extended_community_present = None
                                                            self.is_label_index_present = None
                                                            self.is_local_pref_present = None
                                                            self.is_ls_attribute_present = None
                                                            self.is_metric_present = None
                                                            self.is_origin_present = None
                                                            self.is_pe_distinguisher_label_present = None
                                                            self.is_pmsi_present = None
                                                            self.is_pppmp_present = None
                                                            self.is_ssa_present = None
                                                            self.is_tunnel_encap_present = None
                                                            self.l2tpv3_cookie = YList()
                                                            self.l2tpv3_cookie.parent = self
                                                            self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                            self.l2tpv3_session_id = None
                                                            self.label_index_attr = YList()
                                                            self.label_index_attr.parent = self
                                                            self.label_index_attr.name = 'label_index_attr'
                                                            self.local_preference = None
                                                            self.ls_attr = YList()
                                                            self.ls_attr.parent = self
                                                            self.ls_attr.name = 'ls_attr'
                                                            self.metric = None
                                                            self.neighbor_as = None
                                                            self.origin = None
                                                            self.originator = None
                                                            self.pe_distinguisher_label = YList()
                                                            self.pe_distinguisher_label.parent = self
                                                            self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                            self.pmsi_flags = None
                                                            self.pmsi_label = None
                                                            self.pmsi_type = None
                                                            self.pmsi_value = YList()
                                                            self.pmsi_value.parent = self
                                                            self.pmsi_value.name = 'pmsi_value'
                                                            self.ppm_pvalue = None
                                                            self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                            self.sr_policy_allocated_binding_sid.parent = self
                                                            self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                            self.sr_policy_binding_sid.parent = self
                                                            self.sr_policy_explicit_path = YList()
                                                            self.sr_policy_explicit_path.parent = self
                                                            self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                            self.sr_policy_preference = None
                                                            self.sr_tunnel_request_state = None
                                                            self.sr_tunnel_state = None
                                                            self.tunnel_encap_type = None
                                                            self.unknown_attribute = YList()
                                                            self.unknown_attribute.parent = self
                                                            self.unknown_attribute.name = 'unknown_attribute'


                                                        class SrPolicyBindingSid(object):
                                                            """
                                                            SR Policy Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_address = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                        class SrPolicyAllocatedBindingSid(object):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_address = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                        class Community(object):
                                                            """
                                                            Community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                        class ExtendedCommunity(object):
                                                            """
                                                            Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                        class UnknownAttribute(object):
                                                            """
                                                            Unknown attributes
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                        class Cluster(object):
                                                            """
                                                            Cluster list attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                        class L2Tpv3Cookie(object):
                                                            """
                                                            L2TPv3 Cookie
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                        class ConnectorValue(object):
                                                            """
                                                            Connector Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                        class PmsiValue(object):
                                                            """
                                                            PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                        class LsAttr(object):
                                                            """
                                                            BGP LS attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                        class LabelIndexAttr(object):
                                                            """
                                                            Label Index attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                        class PeDistinguisherLabel(object):
                                                            """
                                                            PE distinguisher label attribute
                                                            
                                                            .. attribute:: label
                                                            
                                                            	Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pe_address
                                                            
                                                            	 PE address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.label = None
                                                                self.pe_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.label is not None:
                                                                    return True

                                                                if self.pe_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                        class SrPolicyExplicitPath(object):
                                                            """
                                                            SR Policy Explicit paths
                                                            
                                                            .. attribute:: sid
                                                            
                                                            	Sidlist for explicit path
                                                            	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of explicit path
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.sid = YList()
                                                                self.sid.parent = self
                                                                self.sid.name = 'sid'
                                                                self.weight = None


                                                            class Sid(object):
                                                                """
                                                                Sidlist for explicit path
                                                                
                                                                .. attribute:: ipv4
                                                                
                                                                	IP Address sid
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6
                                                                
                                                                	IPv6 address sid
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label sid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Sid Type
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4 = None
                                                                    self.ipv6 = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4 is not None:
                                                                        return True

                                                                    if self.ipv6 is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.sid is not None:
                                                                    for child_ref in self.sid:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.weight is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.aggregator_address is not None:
                                                                return True

                                                            if self.aggregator_as is not None:
                                                                return True

                                                            if self.aigp_metric_value is not None:
                                                                return True

                                                            if self.as_path is not None:
                                                                return True

                                                            if self.cluster is not None:
                                                                for child_ref in self.cluster:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.community is not None:
                                                                for child_ref in self.community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.connector_type is not None:
                                                                return True

                                                            if self.connector_value is not None:
                                                                for child_ref in self.connector_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.extended_community is not None:
                                                                for child_ref in self.extended_community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.extended_community_flags is not None:
                                                                return True

                                                            if self.is_aggregator_present is not None:
                                                                return True

                                                            if self.is_aigp_present is not None:
                                                                return True

                                                            if self.is_as_path_present is not None:
                                                                return True

                                                            if self.is_atomic_aggregate_present is not None:
                                                                return True

                                                            if self.is_community_present is not None:
                                                                return True

                                                            if self.is_connector_present is not None:
                                                                return True

                                                            if self.is_extended_community_present is not None:
                                                                return True

                                                            if self.is_label_index_present is not None:
                                                                return True

                                                            if self.is_local_pref_present is not None:
                                                                return True

                                                            if self.is_ls_attribute_present is not None:
                                                                return True

                                                            if self.is_metric_present is not None:
                                                                return True

                                                            if self.is_origin_present is not None:
                                                                return True

                                                            if self.is_pe_distinguisher_label_present is not None:
                                                                return True

                                                            if self.is_pmsi_present is not None:
                                                                return True

                                                            if self.is_pppmp_present is not None:
                                                                return True

                                                            if self.is_ssa_present is not None:
                                                                return True

                                                            if self.is_tunnel_encap_present is not None:
                                                                return True

                                                            if self.l2tpv3_cookie is not None:
                                                                for child_ref in self.l2tpv3_cookie:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.l2tpv3_session_id is not None:
                                                                return True

                                                            if self.label_index_attr is not None:
                                                                for child_ref in self.label_index_attr:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.local_preference is not None:
                                                                return True

                                                            if self.ls_attr is not None:
                                                                for child_ref in self.ls_attr:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.neighbor_as is not None:
                                                                return True

                                                            if self.origin is not None:
                                                                return True

                                                            if self.originator is not None:
                                                                return True

                                                            if self.pe_distinguisher_label is not None:
                                                                for child_ref in self.pe_distinguisher_label:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.pmsi_flags is not None:
                                                                return True

                                                            if self.pmsi_label is not None:
                                                                return True

                                                            if self.pmsi_type is not None:
                                                                return True

                                                            if self.pmsi_value is not None:
                                                                for child_ref in self.pmsi_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.ppm_pvalue is not None:
                                                                return True

                                                            if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                                return True

                                                            if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                                return True

                                                            if self.sr_policy_explicit_path is not None:
                                                                for child_ref in self.sr_policy_explicit_path:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.sr_policy_preference is not None:
                                                                return True

                                                            if self.sr_tunnel_request_state is not None:
                                                                return True

                                                            if self.sr_tunnel_state is not None:
                                                                return True

                                                            if self.tunnel_encap_type is not None:
                                                                return True

                                                            if self.unknown_attribute is not None:
                                                                for child_ref in self.unknown_attribute:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                                    class RnhAddr(object):
                                                        """
                                                        RNH Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                        
                                                        .. attribute:: mac_address
                                                        
                                                        	MAC Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_address = None
                                                            self.ipv6_address = None
                                                            self.len = None
                                                            self.mac_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.len is not None:
                                                                return True

                                                            if self.mac_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                                    class RibrnhIp(object):
                                                        """
                                                        RIB RNH IP Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.attr_set is not None and self.attr_set._has_data():
                                                            return True

                                                        if self.attribute_key_number is not None:
                                                            return True

                                                        if self.attribute_reuse_id_config is not None:
                                                            return True

                                                        if self.attribute_reuse_id_current is not None:
                                                            return True

                                                        if self.attribute_reuse_id_keys is not None:
                                                            return True

                                                        if self.attribute_reuse_id_max_id is not None:
                                                            return True

                                                        if self.attribute_reuse_id_node is not None:
                                                            return True

                                                        if self.attribute_reuse_id_recover_sec is not None:
                                                            return True

                                                        if self.common_attributes is not None and self.common_attributes._has_data():
                                                            return True

                                                        if self.is_application_gateway_present is not None:
                                                            return True

                                                        if self.is_as_path2_byte is not None:
                                                            return True

                                                        if self.is_attr_set_present is not None:
                                                            return True

                                                        if self.is_ribrnh_present is not None:
                                                            return True

                                                        if self.is_rnh_present is not None:
                                                            return True

                                                        if self.ribrnh_encap is not None:
                                                            return True

                                                        if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                            return True

                                                        if self.ribrnh_mac is not None:
                                                            return True

                                                        if self.ribrnh_table is not None:
                                                            return True

                                                        if self.ribrnh_vni is not None:
                                                            return True

                                                        if self.ribrnhip_table is not None:
                                                            return True

                                                        if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                            return True

                                                        if self.rnh_addr_len is not None:
                                                            return True

                                                        if self.rnh_len is not None:
                                                            return True

                                                        if self.rnh_type is not None:
                                                            return True

                                                        if self.set_aigp_inbound_igp is not None:
                                                            return True

                                                        if self.set_aigp_inbound_metric is not None:
                                                            return True

                                                        if self.vpn_distinguisher is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath.AttributesAfterPolicyIn']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-process-instance-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.af_name is not None:
                                                        return True

                                                    if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                        return True

                                                    if self.label_fail is not None:
                                                        return True

                                                    if self.label_o_or_version is not None:
                                                        return True

                                                    if self.label_oor is not None:
                                                        return True

                                                    if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                        return True

                                                    if self.no_path is not None:
                                                        return True

                                                    if self.path_information is not None and self.path_information._has_data():
                                                        return True

                                                    if self.prefix_version is not None:
                                                        return True

                                                    if self.process_instance_id is not None:
                                                        return True

                                                    if self.route_distinguisher is not None:
                                                        return True

                                                    if self.source_route_distinguisher is not None:
                                                        return True

                                                    if self.source_vrf_name is not None:
                                                        return True

                                                    if self.srcaf_name is not None:
                                                        return True

                                                    if self.vrf_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActiveProcessInstancePath']['meta_info']


                                            class LocalPathElement(object):
                                                """
                                                Local path element list
                                                
                                                .. attribute:: is_perm_path_pelem
                                                
                                                	Pelem for permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: nhte_tunnel
                                                
                                                	NH TE tunnel information
                                                	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.NhteTunnel>`
                                                
                                                .. attribute:: pelem_flags
                                                
                                                	Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_gw_metric
                                                
                                                	Gateway metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_no_addpath_table_attr_version
                                                
                                                	No\-addpath Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_no_bestpath_table_attr_version
                                                
                                                	No\-bestpath Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_flags
                                                
                                                	Path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pelem_path_id
                                                
                                                	Local Path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_neighbor_addr
                                                
                                                	Path neighbor address
                                                	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr>`
                                                
                                                .. attribute:: pelem_path_nexthop
                                                
                                                	Path nexthop address
                                                	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop>`
                                                
                                                .. attribute:: pelem_path_peer_path_id
                                                
                                                	Path peer path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_table_attr_version
                                                
                                                	Path Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_table_attr_version
                                                
                                                	Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_version
                                                
                                                	Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_perm_path_pelem = None
                                                    self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.NhteTunnel()
                                                    self.nhte_tunnel.parent = self
                                                    self.pelem_flags = None
                                                    self.pelem_gw_metric = None
                                                    self.pelem_no_addpath_table_attr_version = None
                                                    self.pelem_no_bestpath_table_attr_version = None
                                                    self.pelem_path_flags = None
                                                    self.pelem_path_id = None
                                                    self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr()
                                                    self.pelem_path_neighbor_addr.parent = self
                                                    self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop()
                                                    self.pelem_path_nexthop.parent = self
                                                    self.pelem_path_peer_path_id = None
                                                    self.pelem_path_table_attr_version = None
                                                    self.pelem_table_attr_version = None
                                                    self.pelem_version = None


                                                class PelemPathNexthop(object):
                                                    """
                                                    Path nexthop address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-nexthop'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNexthop']['meta_info']


                                                class NhteTunnel(object):
                                                    """
                                                    NH TE tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_te_tunnel
                                                    
                                                    	NH TE Tunnel info is present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last rib update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	tunnel name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	tunnel type
                                                    	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.binding_label = None
                                                        self.has_te_tunnel = None
                                                        self.is_tunnel_info_stale = None
                                                        self.is_tunnel_registered = None
                                                        self.is_tunnel_up = None
                                                        self.last_tunnel_update = None
                                                        self.tunnel_if_handle = None
                                                        self.tunnel_name = None
                                                        self.tunnel_type = None
                                                        self.tunnel_v6_enabled = None
                                                        self.tunnel_v6_required = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.binding_label is not None:
                                                            return True

                                                        if self.has_te_tunnel is not None:
                                                            return True

                                                        if self.is_tunnel_info_stale is not None:
                                                            return True

                                                        if self.is_tunnel_registered is not None:
                                                            return True

                                                        if self.is_tunnel_up is not None:
                                                            return True

                                                        if self.last_tunnel_update is not None:
                                                            return True

                                                        if self.tunnel_if_handle is not None:
                                                            return True

                                                        if self.tunnel_name is not None:
                                                            return True

                                                        if self.tunnel_type is not None:
                                                            return True

                                                        if self.tunnel_v6_enabled is not None:
                                                            return True

                                                        if self.tunnel_v6_required is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.NhteTunnel']['meta_info']


                                                class PelemPathNeighborAddr(object):
                                                    """
                                                    Path neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-neighbor-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement.PelemPathNeighborAddr']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-path-element'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_perm_path_pelem is not None:
                                                        return True

                                                    if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                        return True

                                                    if self.pelem_flags is not None:
                                                        return True

                                                    if self.pelem_gw_metric is not None:
                                                        return True

                                                    if self.pelem_no_addpath_table_attr_version is not None:
                                                        return True

                                                    if self.pelem_no_bestpath_table_attr_version is not None:
                                                        return True

                                                    if self.pelem_path_flags is not None:
                                                        return True

                                                    if self.pelem_path_id is not None:
                                                        return True

                                                    if self.pelem_path_neighbor_addr is not None and self.pelem_path_neighbor_addr._has_data():
                                                        return True

                                                    if self.pelem_path_nexthop is not None and self.pelem_path_nexthop._has_data():
                                                        return True

                                                    if self.pelem_path_peer_path_id is not None:
                                                        return True

                                                    if self.pelem_path_table_attr_version is not None:
                                                        return True

                                                    if self.pelem_table_attr_version is not None:
                                                        return True

                                                    if self.pelem_version is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.LocalPathElement']['meta_info']


                                            class ActivePathElement(object):
                                                """
                                                Path element list received from Active inst
                                                
                                                .. attribute:: is_perm_path_pelem
                                                
                                                	Pelem for permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: nhte_tunnel
                                                
                                                	NH TE tunnel information
                                                	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.NhteTunnel>`
                                                
                                                .. attribute:: pelem_flags
                                                
                                                	Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_gw_metric
                                                
                                                	Gateway metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_no_addpath_table_attr_version
                                                
                                                	No\-addpath Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_no_bestpath_table_attr_version
                                                
                                                	No\-bestpath Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_flags
                                                
                                                	Path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pelem_path_id
                                                
                                                	Local Path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_neighbor_addr
                                                
                                                	Path neighbor address
                                                	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr>`
                                                
                                                .. attribute:: pelem_path_nexthop
                                                
                                                	Path nexthop address
                                                	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop>`
                                                
                                                .. attribute:: pelem_path_peer_path_id
                                                
                                                	Path peer path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_table_attr_version
                                                
                                                	Path Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_table_attr_version
                                                
                                                	Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_version
                                                
                                                	Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_perm_path_pelem = None
                                                    self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.NhteTunnel()
                                                    self.nhte_tunnel.parent = self
                                                    self.pelem_flags = None
                                                    self.pelem_gw_metric = None
                                                    self.pelem_no_addpath_table_attr_version = None
                                                    self.pelem_no_bestpath_table_attr_version = None
                                                    self.pelem_path_flags = None
                                                    self.pelem_path_id = None
                                                    self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr()
                                                    self.pelem_path_neighbor_addr.parent = self
                                                    self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop()
                                                    self.pelem_path_nexthop.parent = self
                                                    self.pelem_path_peer_path_id = None
                                                    self.pelem_path_table_attr_version = None
                                                    self.pelem_table_attr_version = None
                                                    self.pelem_version = None


                                                class PelemPathNexthop(object):
                                                    """
                                                    Path nexthop address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-nexthop'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNexthop']['meta_info']


                                                class NhteTunnel(object):
                                                    """
                                                    NH TE tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_te_tunnel
                                                    
                                                    	NH TE Tunnel info is present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last rib update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	tunnel name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	tunnel type
                                                    	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.binding_label = None
                                                        self.has_te_tunnel = None
                                                        self.is_tunnel_info_stale = None
                                                        self.is_tunnel_registered = None
                                                        self.is_tunnel_up = None
                                                        self.last_tunnel_update = None
                                                        self.tunnel_if_handle = None
                                                        self.tunnel_name = None
                                                        self.tunnel_type = None
                                                        self.tunnel_v6_enabled = None
                                                        self.tunnel_v6_required = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.binding_label is not None:
                                                            return True

                                                        if self.has_te_tunnel is not None:
                                                            return True

                                                        if self.is_tunnel_info_stale is not None:
                                                            return True

                                                        if self.is_tunnel_registered is not None:
                                                            return True

                                                        if self.is_tunnel_up is not None:
                                                            return True

                                                        if self.last_tunnel_update is not None:
                                                            return True

                                                        if self.tunnel_if_handle is not None:
                                                            return True

                                                        if self.tunnel_name is not None:
                                                            return True

                                                        if self.tunnel_type is not None:
                                                            return True

                                                        if self.tunnel_v6_enabled is not None:
                                                            return True

                                                        if self.tunnel_v6_required is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.NhteTunnel']['meta_info']


                                                class PelemPathNeighborAddr(object):
                                                    """
                                                    Path neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-neighbor-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement.PelemPathNeighborAddr']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-path-element'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_perm_path_pelem is not None:
                                                        return True

                                                    if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                        return True

                                                    if self.pelem_flags is not None:
                                                        return True

                                                    if self.pelem_gw_metric is not None:
                                                        return True

                                                    if self.pelem_no_addpath_table_attr_version is not None:
                                                        return True

                                                    if self.pelem_no_bestpath_table_attr_version is not None:
                                                        return True

                                                    if self.pelem_path_flags is not None:
                                                        return True

                                                    if self.pelem_path_id is not None:
                                                        return True

                                                    if self.pelem_path_neighbor_addr is not None and self.pelem_path_neighbor_addr._has_data():
                                                        return True

                                                    if self.pelem_path_nexthop is not None and self.pelem_path_nexthop._has_data():
                                                        return True

                                                    if self.pelem_path_peer_path_id is not None:
                                                        return True

                                                    if self.pelem_path_table_attr_version is not None:
                                                        return True

                                                    if self.pelem_table_attr_version is not None:
                                                        return True

                                                    if self.pelem_version is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd.ActivePathElement']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.rd is None:
                                                    raise YPYModelError('Key property rd is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-lookup-rd[Cisco-IOS-XR-ipv4-bgp-oper:rd = ' + str(self.rd) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.rd is not None:
                                                    return True

                                                if self.active_path_element is not None:
                                                    for child_ref in self.active_path_element:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.active_process_instance_path is not None:
                                                    for child_ref in self.active_process_instance_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.add_path_orr_bitfield is not None:
                                                    for child_ref in self.add_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.advertisedto_pe is not None:
                                                    return True

                                                if self.af_name is not None:
                                                    return True

                                                if self.best_path_orr_bitfield is not None:
                                                    for child_ref in self.best_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                    return True

                                                if self.bit is not None:
                                                    return True

                                                if self.flags is not None:
                                                    return True

                                                if self.gateway_array is not None:
                                                    return True

                                                if self.has_inconsistent_paths is not None:
                                                    return True

                                                if self.has_lbl_retained is not None:
                                                    return True

                                                if self.has_local_label is not None:
                                                    return True

                                                if self.is_net_aggregation_suppressed is not None:
                                                    return True

                                                if self.is_net_ldp_signaled is not None:
                                                    return True

                                                if self.is_permanent_network is not None:
                                                    return True

                                                if self.local_path_element is not None:
                                                    for child_ref in self.local_path_element:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_peers_advertised_to is not None:
                                                    for child_ref in self.local_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_process_instance_path is not None:
                                                    for child_ref in self.local_process_instance_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.net_backup_available is not None:
                                                    return True

                                                if self.net_backup_label_rewrite_available is not None:
                                                    return True

                                                if self.net_eibgp_multipath is not None:
                                                    return True

                                                if self.net_extended_flags is not None:
                                                    return True

                                                if self.net_flags is not None:
                                                    return True

                                                if self.net_local_label is not None:
                                                    return True

                                                if self.net_local_label_rewrite is not None:
                                                    return True

                                                if self.net_local_label_srgb is not None:
                                                    return True

                                                if self.net_multipath is not None:
                                                    return True

                                                if self.num_of_path is not None:
                                                    return True

                                                if self.pe_peers_advertised_to is not None:
                                                    for child_ref in self.pe_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.process_instance_id is not None:
                                                    return True

                                                if self.resilient_nexthop_set is not None:
                                                    return True

                                                if self.rib_failed is not None:
                                                    return True

                                                if self.route_distinguisher is not None:
                                                    return True

                                                if self.table_brib_version is not None:
                                                    return True

                                                if self.table_version is not None:
                                                    return True

                                                if self.version is not None:
                                                    return True

                                                if self.version_age is not None and self.version_age._has_data():
                                                    return True

                                                if self.version_timestamp is not None and self.version_timestamp._has_data():
                                                    return True

                                                if self.vrf_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds.NetworkLookupRd']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-lookup-rds'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.network_lookup_rd is not None:
                                                for child_ref in self.network_lookup_rd:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd.NetworkLookupRds']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.network_prefix is None:
                                            raise YPYModelError('Key property network_prefix is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-lookup-all-rd[Cisco-IOS-XR-ipv4-bgp-oper:network-prefix = ' + str(self.network_prefix) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.network_prefix is not None:
                                            return True

                                        if self.network_lookup_rds is not None and self.network_lookup_rds._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds.NetworkLookupAllRd']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-lookup-all-rds'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.network_lookup_all_rd is not None:
                                        for child_ref in self.network_lookup_all_rd:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkLookupAllRds']['meta_info']


                            class Policies(object):
                                """
                                The BGP Policy Table
                                
                                .. attribute:: policy
                                
                                	A BGP Policy table entry
                                	**type**\: list of    :py:class:`Policy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.policy = YList()
                                    self.policy.parent = self
                                    self.policy.name = 'policy'


                                class Policy(object):
                                    """
                                    A BGP Policy table entry
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: attributes_after_policy_in
                                    
                                    	Attributes after inbound policy
                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn>`
                                    
                                    .. attribute:: attributes_after_policy_out
                                    
                                    	Attributes after outbound policy
                                    	**type**\:   :py:class:`AttributesAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut>`
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr>`
                                    
                                    .. attribute:: network
                                    
                                    	Network Prefix in Hex format
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: no_path
                                    
                                    	No path exists All 'sp\_path\_in' fields except 'sp\_path\_in\->bag\_prefix' are invalid.  All 'sp\_path\_out' fields are invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_info_after_policy_in
                                    
                                    	Path information after inbound policy
                                    	**type**\:   :py:class:`PathInfoAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn>`
                                    
                                    .. attribute:: path_info_after_policy_out
                                    
                                    	Path information after outbound policy
                                    	**type**\:   :py:class:`PathInfoAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_route_distinguisher
                                    
                                    	Source Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn()
                                        self.attributes_after_policy_in.parent = self
                                        self.attributes_after_policy_out = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut()
                                        self.attributes_after_policy_out.parent = self
                                        self.neighbor_address = None
                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr()
                                        self.neighbor_address_xr.parent = self
                                        self.network = None
                                        self.no_path = None
                                        self.path_info_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn()
                                        self.path_info_after_policy_in.parent = self
                                        self.path_info_after_policy_out = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut()
                                        self.path_info_after_policy_out.parent = self
                                        self.prefix_length = None
                                        self.rd = None
                                        self.route_distinguisher = None
                                        self.source_route_distinguisher = None
                                        self.vrf_name = None


                                    class NeighborAddressXr(object):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr']['meta_info']


                                    class PathInfoAfterPolicyIn(object):
                                        """
                                        Path information after inbound policy
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_own_self_originated_p_ath
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\:  bool
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield>`
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner>`
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix>`
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity>`
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\:  bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\:  bool
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr>`
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_esi
                                        
                                        	Path has EVPN ESI
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_rcvd_label
                                        
                                        	Path has received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\:  bool
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebg_ps
                                        
                                        	Not advertised to EBGPs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue>`
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2VpnEvpnEsi>`
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr>`
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue>`
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress>`
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop>`
                                        
                                        .. attribute:: nhte_tunnel
                                        
                                        	NH TE tunnel information
                                        	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhteTunnel>`
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\:  bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.accept_own_path = None
                                            self.accept_own_self_originated_p_ath = None
                                            self.add_path_orr_bitfield = YList()
                                            self.add_path_orr_bitfield.parent = self
                                            self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                            self.advertisedto_pe = None
                                            self.aigp_metric = None
                                            self.best_path_comp_stage = None
                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self.best_path_id = None
                                            self.best_path_id_comp_winner = None
                                            self.best_path_orr_bitfield = YList()
                                            self.best_path_orr_bitfield.parent = self
                                            self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self.dampen_penalty = None
                                            self.extended_community = YList()
                                            self.extended_community.parent = self
                                            self.extended_community.name = 'extended_community'
                                            self.fspec_invalid_path = None
                                            self.graceful_shutdown = None
                                            self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr()
                                            self.gw_addr.parent = self
                                            self.halflife_time = None
                                            self.has_esi = None
                                            self.has_gw_addr = None
                                            self.has_local_net_label = None
                                            self.has_mdt_group_addr = None
                                            self.has_mvpn_extcomm = None
                                            self.has_mvpn_nbr_addr = None
                                            self.has_mvpn_nexthop_addr = None
                                            self.has_mvpn_pmsi = None
                                            self.has_rcvd_label = None
                                            self.has_second_label = None
                                            self.ibgp_signaled_validity = None
                                            self.igp_metric = None
                                            self.is_aggregation_suppressed = None
                                            self.is_as_best = None
                                            self.is_best_path = None
                                            self.is_import_dampened = None
                                            self.is_import_suspect = None
                                            self.is_internal_path = None
                                            self.is_partial_best = None
                                            self.is_path_additional_path = None
                                            self.is_path_advertised_local_as_only = None
                                            self.is_path_af_install_eligible = None
                                            self.is_path_backup = None
                                            self.is_path_backup_protect_multipath = None
                                            self.is_path_best_external = None
                                            self.is_path_damped = None
                                            self.is_path_from_confederation_peer = None
                                            self.is_path_from_network_command = None
                                            self.is_path_from_redistribute_command = None
                                            self.is_path_from_route_reflector = None
                                            self.is_path_history_held = None
                                            self.is_path_imp_candidate = None
                                            self.is_path_imported = None
                                            self.is_path_local_aggregate = None
                                            self.is_path_locally_sourced = None
                                            self.is_path_long_lived_stale = None
                                            self.is_path_multipath = None
                                            self.is_path_nexthop_discarded = None
                                            self.is_path_not_advertised = None
                                            self.is_path_not_advertised_to_ebg_ps = None
                                            self.is_path_received_only = None
                                            self.is_path_reoriginated = None
                                            self.is_path_reoriginated_stitching = None
                                            self.is_path_stale = None
                                            self.is_path_synced_with_igp = None
                                            self.is_path_valid = None
                                            self.is_path_vpn_only = None
                                            self.is_permanent_path = None
                                            self.is_received_path_not_modified = None
                                            self.is_spkr_as_best = None
                                            self.l2vpn_circuit_status_value = YList()
                                            self.l2vpn_circuit_status_value.parent = self
                                            self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                            self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2VpnEvpnEsi()
                                            self.l2vpn_evpn_esi.parent = self
                                            self.l2vpn_size = None
                                            self.labeled_unicast_safi_path = None
                                            self.local_label = None
                                            self.local_nh = None
                                            self.local_path_id = None
                                            self.local_peers_advertised_to = YList()
                                            self.local_peers_advertised_to.parent = self
                                            self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                            self.maximum_suppress_time = None
                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self.mvpn_path_flags = None
                                            self.mvpn_pmsi_flags = None
                                            self.mvpn_pmsi_label = None
                                            self.mvpn_pmsi_type = None
                                            self.mvpn_pmsi_value = YList()
                                            self.mvpn_pmsi_value.parent = self
                                            self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                            self.mvpn_sfs_path = None
                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self.neighbor_router_id = None
                                            self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop()
                                            self.next_hop.parent = self
                                            self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhteTunnel()
                                            self.nhte_tunnel.parent = self
                                            self.path_flags = None
                                            self.path_flap_count = None
                                            self.path_import_flags = None
                                            self.path_rt_set_id = None
                                            self.path_rt_set_route_count = None
                                            self.path_table_version = None
                                            self.path_weight = None
                                            self.pe_peers_advertised_to = YList()
                                            self.pe_peers_advertised_to.parent = self
                                            self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                            self.rcvd_label = None
                                            self.rcvd_path_id = None
                                            self.reuse_value = None
                                            self.rib_failed = None
                                            self.route_type = None
                                            self.rpki_origin_as_validation_disabled = None
                                            self.rt_set_limit_enabled = None
                                            self.second_label = None
                                            self.seconds_since_first_flap = None
                                            self.show_rpki_origin_as_validity = None
                                            self.sn_rpki_origin_as_validity = None
                                            self.suppress_penalty = None
                                            self.time_to_unsuppress = None


                                        class BgpPrefix(object):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self.prefix_length = None


                                            class Prefix(object):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.prefix is not None and self.prefix._has_data():
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix']['meta_info']


                                        class NeighborAddress(object):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress']['meta_info']


                                        class NextHop(object):
                                            """
                                            Next hop
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop']['meta_info']


                                        class NhteTunnel(object):
                                            """
                                            NH TE tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_te_tunnel
                                            
                                            	NH TE Tunnel info is present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last rib update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	tunnel name
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	tunnel type
                                            	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.binding_label = None
                                                self.has_te_tunnel = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.is_tunnel_up = None
                                                self.last_tunnel_update = None
                                                self.tunnel_if_handle = None
                                                self.tunnel_name = None
                                                self.tunnel_type = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_v6_required = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.binding_label is not None:
                                                    return True

                                                if self.has_te_tunnel is not None:
                                                    return True

                                                if self.is_tunnel_info_stale is not None:
                                                    return True

                                                if self.is_tunnel_registered is not None:
                                                    return True

                                                if self.is_tunnel_up is not None:
                                                    return True

                                                if self.last_tunnel_update is not None:
                                                    return True

                                                if self.tunnel_if_handle is not None:
                                                    return True

                                                if self.tunnel_name is not None:
                                                    return True

                                                if self.tunnel_type is not None:
                                                    return True

                                                if self.tunnel_v6_enabled is not None:
                                                    return True

                                                if self.tunnel_v6_required is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhteTunnel']['meta_info']


                                        class MdtGroupAddr(object):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr']['meta_info']


                                        class L2VpnEvpnEsi(object):
                                            """
                                            L2VPN EVPN ESI
                                            
                                            .. attribute:: esi
                                            
                                            	esi
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.esi = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.esi is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2VpnEvpnEsi']['meta_info']


                                        class GwAddr(object):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.len = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.len is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr']['meta_info']


                                        class BestPathCompWinner(object):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner']['meta_info']


                                        class MvpnNbrAddr(object):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr']['meta_info']


                                        class MvpnNexthopAddr(object):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr']['meta_info']


                                        class L2VpnCircuitStatusValue(object):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue']['meta_info']


                                        class MvpnPmsiValue(object):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue']['meta_info']


                                        class ExtendedCommunity(object):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity']['meta_info']


                                        class LocalPeersAdvertisedTo(object):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo']['meta_info']


                                        class PePeersAdvertisedTo(object):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo']['meta_info']


                                        class BestPathOrrBitfield(object):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield']['meta_info']


                                        class AddPathOrrBitfield(object):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-info-after-policy-in'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.accept_own_path is not None:
                                                return True

                                            if self.accept_own_self_originated_p_ath is not None:
                                                return True

                                            if self.add_path_orr_bitfield is not None:
                                                for child_ref in self.add_path_orr_bitfield:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.advertisedto_pe is not None:
                                                return True

                                            if self.aigp_metric is not None:
                                                return True

                                            if self.best_path_comp_stage is not None:
                                                return True

                                            if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                return True

                                            if self.best_path_id is not None:
                                                return True

                                            if self.best_path_id_comp_winner is not None:
                                                return True

                                            if self.best_path_orr_bitfield is not None:
                                                for child_ref in self.best_path_orr_bitfield:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                return True

                                            if self.dampen_penalty is not None:
                                                return True

                                            if self.extended_community is not None:
                                                for child_ref in self.extended_community:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.fspec_invalid_path is not None:
                                                return True

                                            if self.graceful_shutdown is not None:
                                                return True

                                            if self.gw_addr is not None and self.gw_addr._has_data():
                                                return True

                                            if self.halflife_time is not None:
                                                return True

                                            if self.has_esi is not None:
                                                return True

                                            if self.has_gw_addr is not None:
                                                return True

                                            if self.has_local_net_label is not None:
                                                return True

                                            if self.has_mdt_group_addr is not None:
                                                return True

                                            if self.has_mvpn_extcomm is not None:
                                                return True

                                            if self.has_mvpn_nbr_addr is not None:
                                                return True

                                            if self.has_mvpn_nexthop_addr is not None:
                                                return True

                                            if self.has_mvpn_pmsi is not None:
                                                return True

                                            if self.has_rcvd_label is not None:
                                                return True

                                            if self.has_second_label is not None:
                                                return True

                                            if self.ibgp_signaled_validity is not None:
                                                return True

                                            if self.igp_metric is not None:
                                                return True

                                            if self.is_aggregation_suppressed is not None:
                                                return True

                                            if self.is_as_best is not None:
                                                return True

                                            if self.is_best_path is not None:
                                                return True

                                            if self.is_import_dampened is not None:
                                                return True

                                            if self.is_import_suspect is not None:
                                                return True

                                            if self.is_internal_path is not None:
                                                return True

                                            if self.is_partial_best is not None:
                                                return True

                                            if self.is_path_additional_path is not None:
                                                return True

                                            if self.is_path_advertised_local_as_only is not None:
                                                return True

                                            if self.is_path_af_install_eligible is not None:
                                                return True

                                            if self.is_path_backup is not None:
                                                return True

                                            if self.is_path_backup_protect_multipath is not None:
                                                return True

                                            if self.is_path_best_external is not None:
                                                return True

                                            if self.is_path_damped is not None:
                                                return True

                                            if self.is_path_from_confederation_peer is not None:
                                                return True

                                            if self.is_path_from_network_command is not None:
                                                return True

                                            if self.is_path_from_redistribute_command is not None:
                                                return True

                                            if self.is_path_from_route_reflector is not None:
                                                return True

                                            if self.is_path_history_held is not None:
                                                return True

                                            if self.is_path_imp_candidate is not None:
                                                return True

                                            if self.is_path_imported is not None:
                                                return True

                                            if self.is_path_local_aggregate is not None:
                                                return True

                                            if self.is_path_locally_sourced is not None:
                                                return True

                                            if self.is_path_long_lived_stale is not None:
                                                return True

                                            if self.is_path_multipath is not None:
                                                return True

                                            if self.is_path_nexthop_discarded is not None:
                                                return True

                                            if self.is_path_not_advertised is not None:
                                                return True

                                            if self.is_path_not_advertised_to_ebg_ps is not None:
                                                return True

                                            if self.is_path_received_only is not None:
                                                return True

                                            if self.is_path_reoriginated is not None:
                                                return True

                                            if self.is_path_reoriginated_stitching is not None:
                                                return True

                                            if self.is_path_stale is not None:
                                                return True

                                            if self.is_path_synced_with_igp is not None:
                                                return True

                                            if self.is_path_valid is not None:
                                                return True

                                            if self.is_path_vpn_only is not None:
                                                return True

                                            if self.is_permanent_path is not None:
                                                return True

                                            if self.is_received_path_not_modified is not None:
                                                return True

                                            if self.is_spkr_as_best is not None:
                                                return True

                                            if self.l2vpn_circuit_status_value is not None:
                                                for child_ref in self.l2vpn_circuit_status_value:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                return True

                                            if self.l2vpn_size is not None:
                                                return True

                                            if self.labeled_unicast_safi_path is not None:
                                                return True

                                            if self.local_label is not None:
                                                return True

                                            if self.local_nh is not None:
                                                return True

                                            if self.local_path_id is not None:
                                                return True

                                            if self.local_peers_advertised_to is not None:
                                                for child_ref in self.local_peers_advertised_to:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.maximum_suppress_time is not None:
                                                return True

                                            if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                return True

                                            if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                return True

                                            if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                return True

                                            if self.mvpn_path_flags is not None:
                                                return True

                                            if self.mvpn_pmsi_flags is not None:
                                                return True

                                            if self.mvpn_pmsi_label is not None:
                                                return True

                                            if self.mvpn_pmsi_type is not None:
                                                return True

                                            if self.mvpn_pmsi_value is not None:
                                                for child_ref in self.mvpn_pmsi_value:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.mvpn_sfs_path is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            if self.neighbor_router_id is not None:
                                                return True

                                            if self.next_hop is not None and self.next_hop._has_data():
                                                return True

                                            if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                return True

                                            if self.path_flags is not None:
                                                return True

                                            if self.path_flap_count is not None:
                                                return True

                                            if self.path_import_flags is not None:
                                                return True

                                            if self.path_rt_set_id is not None:
                                                return True

                                            if self.path_rt_set_route_count is not None:
                                                return True

                                            if self.path_table_version is not None:
                                                return True

                                            if self.path_weight is not None:
                                                return True

                                            if self.pe_peers_advertised_to is not None:
                                                for child_ref in self.pe_peers_advertised_to:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.rcvd_label is not None:
                                                return True

                                            if self.rcvd_path_id is not None:
                                                return True

                                            if self.reuse_value is not None:
                                                return True

                                            if self.rib_failed is not None:
                                                return True

                                            if self.route_type is not None:
                                                return True

                                            if self.rpki_origin_as_validation_disabled is not None:
                                                return True

                                            if self.rt_set_limit_enabled is not None:
                                                return True

                                            if self.second_label is not None:
                                                return True

                                            if self.seconds_since_first_flap is not None:
                                                return True

                                            if self.show_rpki_origin_as_validity is not None:
                                                return True

                                            if self.sn_rpki_origin_as_validity is not None:
                                                return True

                                            if self.suppress_penalty is not None:
                                                return True

                                            if self.time_to_unsuppress is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn']['meta_info']


                                    class PathInfoAfterPolicyOut(object):
                                        """
                                        Path information after outbound policy
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_own_self_originated_p_ath
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\:  bool
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield>`
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner>`
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix>`
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity>`
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\:  bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\:  bool
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr>`
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_esi
                                        
                                        	Path has EVPN ESI
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_rcvd_label
                                        
                                        	Path has received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\:  bool
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebg_ps
                                        
                                        	Not advertised to EBGPs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue>`
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2VpnEvpnEsi>`
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr>`
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue>`
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress>`
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop>`
                                        
                                        .. attribute:: nhte_tunnel
                                        
                                        	NH TE tunnel information
                                        	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhteTunnel>`
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\:  bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.accept_own_path = None
                                            self.accept_own_self_originated_p_ath = None
                                            self.add_path_orr_bitfield = YList()
                                            self.add_path_orr_bitfield.parent = self
                                            self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                            self.advertisedto_pe = None
                                            self.aigp_metric = None
                                            self.best_path_comp_stage = None
                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self.best_path_id = None
                                            self.best_path_id_comp_winner = None
                                            self.best_path_orr_bitfield = YList()
                                            self.best_path_orr_bitfield.parent = self
                                            self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self.dampen_penalty = None
                                            self.extended_community = YList()
                                            self.extended_community.parent = self
                                            self.extended_community.name = 'extended_community'
                                            self.fspec_invalid_path = None
                                            self.graceful_shutdown = None
                                            self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr()
                                            self.gw_addr.parent = self
                                            self.halflife_time = None
                                            self.has_esi = None
                                            self.has_gw_addr = None
                                            self.has_local_net_label = None
                                            self.has_mdt_group_addr = None
                                            self.has_mvpn_extcomm = None
                                            self.has_mvpn_nbr_addr = None
                                            self.has_mvpn_nexthop_addr = None
                                            self.has_mvpn_pmsi = None
                                            self.has_rcvd_label = None
                                            self.has_second_label = None
                                            self.ibgp_signaled_validity = None
                                            self.igp_metric = None
                                            self.is_aggregation_suppressed = None
                                            self.is_as_best = None
                                            self.is_best_path = None
                                            self.is_import_dampened = None
                                            self.is_import_suspect = None
                                            self.is_internal_path = None
                                            self.is_partial_best = None
                                            self.is_path_additional_path = None
                                            self.is_path_advertised_local_as_only = None
                                            self.is_path_af_install_eligible = None
                                            self.is_path_backup = None
                                            self.is_path_backup_protect_multipath = None
                                            self.is_path_best_external = None
                                            self.is_path_damped = None
                                            self.is_path_from_confederation_peer = None
                                            self.is_path_from_network_command = None
                                            self.is_path_from_redistribute_command = None
                                            self.is_path_from_route_reflector = None
                                            self.is_path_history_held = None
                                            self.is_path_imp_candidate = None
                                            self.is_path_imported = None
                                            self.is_path_local_aggregate = None
                                            self.is_path_locally_sourced = None
                                            self.is_path_long_lived_stale = None
                                            self.is_path_multipath = None
                                            self.is_path_nexthop_discarded = None
                                            self.is_path_not_advertised = None
                                            self.is_path_not_advertised_to_ebg_ps = None
                                            self.is_path_received_only = None
                                            self.is_path_reoriginated = None
                                            self.is_path_reoriginated_stitching = None
                                            self.is_path_stale = None
                                            self.is_path_synced_with_igp = None
                                            self.is_path_valid = None
                                            self.is_path_vpn_only = None
                                            self.is_permanent_path = None
                                            self.is_received_path_not_modified = None
                                            self.is_spkr_as_best = None
                                            self.l2vpn_circuit_status_value = YList()
                                            self.l2vpn_circuit_status_value.parent = self
                                            self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                            self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2VpnEvpnEsi()
                                            self.l2vpn_evpn_esi.parent = self
                                            self.l2vpn_size = None
                                            self.labeled_unicast_safi_path = None
                                            self.local_label = None
                                            self.local_nh = None
                                            self.local_path_id = None
                                            self.local_peers_advertised_to = YList()
                                            self.local_peers_advertised_to.parent = self
                                            self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                            self.maximum_suppress_time = None
                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self.mvpn_path_flags = None
                                            self.mvpn_pmsi_flags = None
                                            self.mvpn_pmsi_label = None
                                            self.mvpn_pmsi_type = None
                                            self.mvpn_pmsi_value = YList()
                                            self.mvpn_pmsi_value.parent = self
                                            self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                            self.mvpn_sfs_path = None
                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self.neighbor_router_id = None
                                            self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop()
                                            self.next_hop.parent = self
                                            self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhteTunnel()
                                            self.nhte_tunnel.parent = self
                                            self.path_flags = None
                                            self.path_flap_count = None
                                            self.path_import_flags = None
                                            self.path_rt_set_id = None
                                            self.path_rt_set_route_count = None
                                            self.path_table_version = None
                                            self.path_weight = None
                                            self.pe_peers_advertised_to = YList()
                                            self.pe_peers_advertised_to.parent = self
                                            self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                            self.rcvd_label = None
                                            self.rcvd_path_id = None
                                            self.reuse_value = None
                                            self.rib_failed = None
                                            self.route_type = None
                                            self.rpki_origin_as_validation_disabled = None
                                            self.rt_set_limit_enabled = None
                                            self.second_label = None
                                            self.seconds_since_first_flap = None
                                            self.show_rpki_origin_as_validity = None
                                            self.sn_rpki_origin_as_validity = None
                                            self.suppress_penalty = None
                                            self.time_to_unsuppress = None


                                        class BgpPrefix(object):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self.prefix_length = None


                                            class Prefix(object):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.prefix is not None and self.prefix._has_data():
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix']['meta_info']


                                        class NeighborAddress(object):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress']['meta_info']


                                        class NextHop(object):
                                            """
                                            Next hop
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop']['meta_info']


                                        class NhteTunnel(object):
                                            """
                                            NH TE tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_te_tunnel
                                            
                                            	NH TE Tunnel info is present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last rib update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	tunnel name
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	tunnel type
                                            	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.binding_label = None
                                                self.has_te_tunnel = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.is_tunnel_up = None
                                                self.last_tunnel_update = None
                                                self.tunnel_if_handle = None
                                                self.tunnel_name = None
                                                self.tunnel_type = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_v6_required = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.binding_label is not None:
                                                    return True

                                                if self.has_te_tunnel is not None:
                                                    return True

                                                if self.is_tunnel_info_stale is not None:
                                                    return True

                                                if self.is_tunnel_registered is not None:
                                                    return True

                                                if self.is_tunnel_up is not None:
                                                    return True

                                                if self.last_tunnel_update is not None:
                                                    return True

                                                if self.tunnel_if_handle is not None:
                                                    return True

                                                if self.tunnel_name is not None:
                                                    return True

                                                if self.tunnel_type is not None:
                                                    return True

                                                if self.tunnel_v6_enabled is not None:
                                                    return True

                                                if self.tunnel_v6_required is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhteTunnel']['meta_info']


                                        class MdtGroupAddr(object):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr']['meta_info']


                                        class L2VpnEvpnEsi(object):
                                            """
                                            L2VPN EVPN ESI
                                            
                                            .. attribute:: esi
                                            
                                            	esi
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.esi = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.esi is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2VpnEvpnEsi']['meta_info']


                                        class GwAddr(object):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.len = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.len is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr']['meta_info']


                                        class BestPathCompWinner(object):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner']['meta_info']


                                        class MvpnNbrAddr(object):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr']['meta_info']


                                        class MvpnNexthopAddr(object):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr']['meta_info']


                                        class L2VpnCircuitStatusValue(object):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue']['meta_info']


                                        class MvpnPmsiValue(object):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue']['meta_info']


                                        class ExtendedCommunity(object):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity']['meta_info']


                                        class LocalPeersAdvertisedTo(object):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo']['meta_info']


                                        class PePeersAdvertisedTo(object):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo']['meta_info']


                                        class BestPathOrrBitfield(object):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield']['meta_info']


                                        class AddPathOrrBitfield(object):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-info-after-policy-out'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.accept_own_path is not None:
                                                return True

                                            if self.accept_own_self_originated_p_ath is not None:
                                                return True

                                            if self.add_path_orr_bitfield is not None:
                                                for child_ref in self.add_path_orr_bitfield:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.advertisedto_pe is not None:
                                                return True

                                            if self.aigp_metric is not None:
                                                return True

                                            if self.best_path_comp_stage is not None:
                                                return True

                                            if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                return True

                                            if self.best_path_id is not None:
                                                return True

                                            if self.best_path_id_comp_winner is not None:
                                                return True

                                            if self.best_path_orr_bitfield is not None:
                                                for child_ref in self.best_path_orr_bitfield:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                return True

                                            if self.dampen_penalty is not None:
                                                return True

                                            if self.extended_community is not None:
                                                for child_ref in self.extended_community:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.fspec_invalid_path is not None:
                                                return True

                                            if self.graceful_shutdown is not None:
                                                return True

                                            if self.gw_addr is not None and self.gw_addr._has_data():
                                                return True

                                            if self.halflife_time is not None:
                                                return True

                                            if self.has_esi is not None:
                                                return True

                                            if self.has_gw_addr is not None:
                                                return True

                                            if self.has_local_net_label is not None:
                                                return True

                                            if self.has_mdt_group_addr is not None:
                                                return True

                                            if self.has_mvpn_extcomm is not None:
                                                return True

                                            if self.has_mvpn_nbr_addr is not None:
                                                return True

                                            if self.has_mvpn_nexthop_addr is not None:
                                                return True

                                            if self.has_mvpn_pmsi is not None:
                                                return True

                                            if self.has_rcvd_label is not None:
                                                return True

                                            if self.has_second_label is not None:
                                                return True

                                            if self.ibgp_signaled_validity is not None:
                                                return True

                                            if self.igp_metric is not None:
                                                return True

                                            if self.is_aggregation_suppressed is not None:
                                                return True

                                            if self.is_as_best is not None:
                                                return True

                                            if self.is_best_path is not None:
                                                return True

                                            if self.is_import_dampened is not None:
                                                return True

                                            if self.is_import_suspect is not None:
                                                return True

                                            if self.is_internal_path is not None:
                                                return True

                                            if self.is_partial_best is not None:
                                                return True

                                            if self.is_path_additional_path is not None:
                                                return True

                                            if self.is_path_advertised_local_as_only is not None:
                                                return True

                                            if self.is_path_af_install_eligible is not None:
                                                return True

                                            if self.is_path_backup is not None:
                                                return True

                                            if self.is_path_backup_protect_multipath is not None:
                                                return True

                                            if self.is_path_best_external is not None:
                                                return True

                                            if self.is_path_damped is not None:
                                                return True

                                            if self.is_path_from_confederation_peer is not None:
                                                return True

                                            if self.is_path_from_network_command is not None:
                                                return True

                                            if self.is_path_from_redistribute_command is not None:
                                                return True

                                            if self.is_path_from_route_reflector is not None:
                                                return True

                                            if self.is_path_history_held is not None:
                                                return True

                                            if self.is_path_imp_candidate is not None:
                                                return True

                                            if self.is_path_imported is not None:
                                                return True

                                            if self.is_path_local_aggregate is not None:
                                                return True

                                            if self.is_path_locally_sourced is not None:
                                                return True

                                            if self.is_path_long_lived_stale is not None:
                                                return True

                                            if self.is_path_multipath is not None:
                                                return True

                                            if self.is_path_nexthop_discarded is not None:
                                                return True

                                            if self.is_path_not_advertised is not None:
                                                return True

                                            if self.is_path_not_advertised_to_ebg_ps is not None:
                                                return True

                                            if self.is_path_received_only is not None:
                                                return True

                                            if self.is_path_reoriginated is not None:
                                                return True

                                            if self.is_path_reoriginated_stitching is not None:
                                                return True

                                            if self.is_path_stale is not None:
                                                return True

                                            if self.is_path_synced_with_igp is not None:
                                                return True

                                            if self.is_path_valid is not None:
                                                return True

                                            if self.is_path_vpn_only is not None:
                                                return True

                                            if self.is_permanent_path is not None:
                                                return True

                                            if self.is_received_path_not_modified is not None:
                                                return True

                                            if self.is_spkr_as_best is not None:
                                                return True

                                            if self.l2vpn_circuit_status_value is not None:
                                                for child_ref in self.l2vpn_circuit_status_value:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                return True

                                            if self.l2vpn_size is not None:
                                                return True

                                            if self.labeled_unicast_safi_path is not None:
                                                return True

                                            if self.local_label is not None:
                                                return True

                                            if self.local_nh is not None:
                                                return True

                                            if self.local_path_id is not None:
                                                return True

                                            if self.local_peers_advertised_to is not None:
                                                for child_ref in self.local_peers_advertised_to:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.maximum_suppress_time is not None:
                                                return True

                                            if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                return True

                                            if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                return True

                                            if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                return True

                                            if self.mvpn_path_flags is not None:
                                                return True

                                            if self.mvpn_pmsi_flags is not None:
                                                return True

                                            if self.mvpn_pmsi_label is not None:
                                                return True

                                            if self.mvpn_pmsi_type is not None:
                                                return True

                                            if self.mvpn_pmsi_value is not None:
                                                for child_ref in self.mvpn_pmsi_value:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.mvpn_sfs_path is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            if self.neighbor_router_id is not None:
                                                return True

                                            if self.next_hop is not None and self.next_hop._has_data():
                                                return True

                                            if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                return True

                                            if self.path_flags is not None:
                                                return True

                                            if self.path_flap_count is not None:
                                                return True

                                            if self.path_import_flags is not None:
                                                return True

                                            if self.path_rt_set_id is not None:
                                                return True

                                            if self.path_rt_set_route_count is not None:
                                                return True

                                            if self.path_table_version is not None:
                                                return True

                                            if self.path_weight is not None:
                                                return True

                                            if self.pe_peers_advertised_to is not None:
                                                for child_ref in self.pe_peers_advertised_to:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.rcvd_label is not None:
                                                return True

                                            if self.rcvd_path_id is not None:
                                                return True

                                            if self.reuse_value is not None:
                                                return True

                                            if self.rib_failed is not None:
                                                return True

                                            if self.route_type is not None:
                                                return True

                                            if self.rpki_origin_as_validation_disabled is not None:
                                                return True

                                            if self.rt_set_limit_enabled is not None:
                                                return True

                                            if self.second_label is not None:
                                                return True

                                            if self.seconds_since_first_flap is not None:
                                                return True

                                            if self.show_rpki_origin_as_validity is not None:
                                                return True

                                            if self.sn_rpki_origin_as_validity is not None:
                                                return True

                                            if self.suppress_penalty is not None:
                                                return True

                                            if self.time_to_unsuppress is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut']['meta_info']


                                    class AttributesAfterPolicyIn(object):
                                        """
                                        Attributes after inbound policy
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet>`
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes>`
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp>`
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr>`
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\:  bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet()
                                            self.attr_set.parent = self
                                            self.attribute_key_number = None
                                            self.attribute_reuse_id_config = None
                                            self.attribute_reuse_id_current = None
                                            self.attribute_reuse_id_keys = None
                                            self.attribute_reuse_id_max_id = None
                                            self.attribute_reuse_id_node = None
                                            self.attribute_reuse_id_recover_sec = None
                                            self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self.is_application_gateway_present = None
                                            self.is_as_path2_byte = None
                                            self.is_attr_set_present = None
                                            self.is_ribrnh_present = None
                                            self.is_rnh_present = None
                                            self.ribrnh_encap = None
                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self.ribrnh_mac = None
                                            self.ribrnh_table = None
                                            self.ribrnh_vni = None
                                            self.ribrnhip_table = None
                                            self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self.rnh_addr_len = None
                                            self.rnh_len = None
                                            self.rnh_type = None
                                            self.set_aigp_inbound_igp = None
                                            self.set_aigp_inbound_metric = None
                                            self.vpn_distinguisher = None


                                        class CommonAttributes(object):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_encap_present
                                            
                                            	Tunnel Encap attribute present 
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_policy_allocated_binding_sid
                                            
                                            	SR Policy allocated Binding sid by the router
                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                            
                                            .. attribute:: sr_policy_binding_sid
                                            
                                            	SR Policy Binding sid
                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                            
                                            .. attribute:: sr_policy_explicit_path
                                            
                                            	SR Policy Explicit paths
                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                            
                                            .. attribute:: sr_policy_preference
                                            
                                            	SR Policy Preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_tunnel_request_state
                                            
                                            	SR Tunnel Request State
                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                            
                                            .. attribute:: sr_tunnel_state
                                            
                                            	SR Tunnel State
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap_type
                                            
                                            	Tunnel Encap Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.aggregator_address = None
                                                self.aggregator_as = None
                                                self.aigp_metric_value = None
                                                self.as_path = None
                                                self.cluster = YList()
                                                self.cluster.parent = self
                                                self.cluster.name = 'cluster'
                                                self.community = YList()
                                                self.community.parent = self
                                                self.community.name = 'community'
                                                self.connector_type = None
                                                self.connector_value = YList()
                                                self.connector_value.parent = self
                                                self.connector_value.name = 'connector_value'
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.extended_community_flags = None
                                                self.is_aggregator_present = None
                                                self.is_aigp_present = None
                                                self.is_as_path_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_community_present = None
                                                self.is_connector_present = None
                                                self.is_extended_community_present = None
                                                self.is_label_index_present = None
                                                self.is_local_pref_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_metric_present = None
                                                self.is_origin_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_ssa_present = None
                                                self.is_tunnel_encap_present = None
                                                self.l2tpv3_cookie = YList()
                                                self.l2tpv3_cookie.parent = self
                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                self.l2tpv3_session_id = None
                                                self.label_index_attr = YList()
                                                self.label_index_attr.parent = self
                                                self.label_index_attr.name = 'label_index_attr'
                                                self.local_preference = None
                                                self.ls_attr = YList()
                                                self.ls_attr.parent = self
                                                self.ls_attr.name = 'ls_attr'
                                                self.metric = None
                                                self.neighbor_as = None
                                                self.origin = None
                                                self.originator = None
                                                self.pe_distinguisher_label = YList()
                                                self.pe_distinguisher_label.parent = self
                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.pmsi_type = None
                                                self.pmsi_value = YList()
                                                self.pmsi_value.parent = self
                                                self.pmsi_value.name = 'pmsi_value'
                                                self.ppm_pvalue = None
                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                self.sr_policy_allocated_binding_sid.parent = self
                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                self.sr_policy_binding_sid.parent = self
                                                self.sr_policy_explicit_path = YList()
                                                self.sr_policy_explicit_path.parent = self
                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                self.sr_policy_preference = None
                                                self.sr_tunnel_request_state = None
                                                self.sr_tunnel_state = None
                                                self.tunnel_encap_type = None
                                                self.unknown_attribute = YList()
                                                self.unknown_attribute.parent = self
                                                self.unknown_attribute.name = 'unknown_attribute'


                                            class SrPolicyBindingSid(object):
                                                """
                                                SR Policy Binding sid
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                            class SrPolicyAllocatedBindingSid(object):
                                                """
                                                SR Policy allocated Binding sid by the router
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                            class Community(object):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                            class UnknownAttribute(object):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                            class Cluster(object):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                            class L2Tpv3Cookie(object):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                            class ConnectorValue(object):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                            class PmsiValue(object):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                            class LsAttr(object):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                            class LabelIndexAttr(object):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                            class PeDistinguisherLabel(object):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.label = None
                                                    self.pe_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.label is not None:
                                                        return True

                                                    if self.pe_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                            class SrPolicyExplicitPath(object):
                                                """
                                                SR Policy Explicit paths
                                                
                                                .. attribute:: sid
                                                
                                                	Sidlist for explicit path
                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                
                                                .. attribute:: weight
                                                
                                                	Weight of explicit path
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.sid = YList()
                                                    self.sid.parent = self
                                                    self.sid.name = 'sid'
                                                    self.weight = None


                                                class Sid(object):
                                                    """
                                                    Sidlist for explicit path
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IP Address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label sid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Sid Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4 is not None:
                                                            return True

                                                        if self.ipv6 is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.sid is not None:
                                                        for child_ref in self.sid:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.weight is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.aggregator_address is not None:
                                                    return True

                                                if self.aggregator_as is not None:
                                                    return True

                                                if self.aigp_metric_value is not None:
                                                    return True

                                                if self.as_path is not None:
                                                    return True

                                                if self.cluster is not None:
                                                    for child_ref in self.cluster:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.community is not None:
                                                    for child_ref in self.community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.connector_type is not None:
                                                    return True

                                                if self.connector_value is not None:
                                                    for child_ref in self.connector_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community_flags is not None:
                                                    return True

                                                if self.is_aggregator_present is not None:
                                                    return True

                                                if self.is_aigp_present is not None:
                                                    return True

                                                if self.is_as_path_present is not None:
                                                    return True

                                                if self.is_atomic_aggregate_present is not None:
                                                    return True

                                                if self.is_community_present is not None:
                                                    return True

                                                if self.is_connector_present is not None:
                                                    return True

                                                if self.is_extended_community_present is not None:
                                                    return True

                                                if self.is_label_index_present is not None:
                                                    return True

                                                if self.is_local_pref_present is not None:
                                                    return True

                                                if self.is_ls_attribute_present is not None:
                                                    return True

                                                if self.is_metric_present is not None:
                                                    return True

                                                if self.is_origin_present is not None:
                                                    return True

                                                if self.is_pe_distinguisher_label_present is not None:
                                                    return True

                                                if self.is_pmsi_present is not None:
                                                    return True

                                                if self.is_pppmp_present is not None:
                                                    return True

                                                if self.is_ssa_present is not None:
                                                    return True

                                                if self.is_tunnel_encap_present is not None:
                                                    return True

                                                if self.l2tpv3_cookie is not None:
                                                    for child_ref in self.l2tpv3_cookie:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2tpv3_session_id is not None:
                                                    return True

                                                if self.label_index_attr is not None:
                                                    for child_ref in self.label_index_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_preference is not None:
                                                    return True

                                                if self.ls_attr is not None:
                                                    for child_ref in self.ls_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.metric is not None:
                                                    return True

                                                if self.neighbor_as is not None:
                                                    return True

                                                if self.origin is not None:
                                                    return True

                                                if self.originator is not None:
                                                    return True

                                                if self.pe_distinguisher_label is not None:
                                                    for child_ref in self.pe_distinguisher_label:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.pmsi_flags is not None:
                                                    return True

                                                if self.pmsi_label is not None:
                                                    return True

                                                if self.pmsi_type is not None:
                                                    return True

                                                if self.pmsi_value is not None:
                                                    for child_ref in self.pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.ppm_pvalue is not None:
                                                    return True

                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_explicit_path is not None:
                                                    for child_ref in self.sr_policy_explicit_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.sr_policy_preference is not None:
                                                    return True

                                                if self.sr_tunnel_request_state is not None:
                                                    return True

                                                if self.sr_tunnel_state is not None:
                                                    return True

                                                if self.tunnel_encap_type is not None:
                                                    return True

                                                if self.unknown_attribute is not None:
                                                    for child_ref in self.unknown_attribute:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                        class AttrSet(object):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_encap_present
                                            
                                            	Tunnel Encap attribute present 
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_policy_allocated_binding_sid
                                            
                                            	SR Policy allocated Binding sid by the router
                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                            
                                            .. attribute:: sr_policy_binding_sid
                                            
                                            	SR Policy Binding sid
                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                            
                                            .. attribute:: sr_policy_explicit_path
                                            
                                            	SR Policy Explicit paths
                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                            
                                            .. attribute:: sr_policy_preference
                                            
                                            	SR Policy Preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_tunnel_request_state
                                            
                                            	SR Tunnel Request State
                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                            
                                            .. attribute:: sr_tunnel_state
                                            
                                            	SR Tunnel State
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap_type
                                            
                                            	Tunnel Encap Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.aggregator_address = None
                                                self.aggregator_as = None
                                                self.aigp_metric_value = None
                                                self.as_path = None
                                                self.cluster = YList()
                                                self.cluster.parent = self
                                                self.cluster.name = 'cluster'
                                                self.community = YList()
                                                self.community.parent = self
                                                self.community.name = 'community'
                                                self.connector_type = None
                                                self.connector_value = YList()
                                                self.connector_value.parent = self
                                                self.connector_value.name = 'connector_value'
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.extended_community_flags = None
                                                self.is_aggregator_present = None
                                                self.is_aigp_present = None
                                                self.is_as_path_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_community_present = None
                                                self.is_connector_present = None
                                                self.is_extended_community_present = None
                                                self.is_label_index_present = None
                                                self.is_local_pref_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_metric_present = None
                                                self.is_origin_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_ssa_present = None
                                                self.is_tunnel_encap_present = None
                                                self.l2tpv3_cookie = YList()
                                                self.l2tpv3_cookie.parent = self
                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                self.l2tpv3_session_id = None
                                                self.label_index_attr = YList()
                                                self.label_index_attr.parent = self
                                                self.label_index_attr.name = 'label_index_attr'
                                                self.local_preference = None
                                                self.ls_attr = YList()
                                                self.ls_attr.parent = self
                                                self.ls_attr.name = 'ls_attr'
                                                self.metric = None
                                                self.neighbor_as = None
                                                self.origin = None
                                                self.originator = None
                                                self.pe_distinguisher_label = YList()
                                                self.pe_distinguisher_label.parent = self
                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.pmsi_type = None
                                                self.pmsi_value = YList()
                                                self.pmsi_value.parent = self
                                                self.pmsi_value.name = 'pmsi_value'
                                                self.ppm_pvalue = None
                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                self.sr_policy_allocated_binding_sid.parent = self
                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                self.sr_policy_binding_sid.parent = self
                                                self.sr_policy_explicit_path = YList()
                                                self.sr_policy_explicit_path.parent = self
                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                self.sr_policy_preference = None
                                                self.sr_tunnel_request_state = None
                                                self.sr_tunnel_state = None
                                                self.tunnel_encap_type = None
                                                self.unknown_attribute = YList()
                                                self.unknown_attribute.parent = self
                                                self.unknown_attribute.name = 'unknown_attribute'


                                            class SrPolicyBindingSid(object):
                                                """
                                                SR Policy Binding sid
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                            class SrPolicyAllocatedBindingSid(object):
                                                """
                                                SR Policy allocated Binding sid by the router
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                            class Community(object):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                            class UnknownAttribute(object):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                            class Cluster(object):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                            class L2Tpv3Cookie(object):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                            class ConnectorValue(object):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                            class PmsiValue(object):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                            class LsAttr(object):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                            class LabelIndexAttr(object):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                            class PeDistinguisherLabel(object):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.label = None
                                                    self.pe_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.label is not None:
                                                        return True

                                                    if self.pe_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                            class SrPolicyExplicitPath(object):
                                                """
                                                SR Policy Explicit paths
                                                
                                                .. attribute:: sid
                                                
                                                	Sidlist for explicit path
                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                
                                                .. attribute:: weight
                                                
                                                	Weight of explicit path
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.sid = YList()
                                                    self.sid.parent = self
                                                    self.sid.name = 'sid'
                                                    self.weight = None


                                                class Sid(object):
                                                    """
                                                    Sidlist for explicit path
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IP Address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label sid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Sid Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4 is not None:
                                                            return True

                                                        if self.ipv6 is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.sid is not None:
                                                        for child_ref in self.sid:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.weight is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.aggregator_address is not None:
                                                    return True

                                                if self.aggregator_as is not None:
                                                    return True

                                                if self.aigp_metric_value is not None:
                                                    return True

                                                if self.as_path is not None:
                                                    return True

                                                if self.cluster is not None:
                                                    for child_ref in self.cluster:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.community is not None:
                                                    for child_ref in self.community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.connector_type is not None:
                                                    return True

                                                if self.connector_value is not None:
                                                    for child_ref in self.connector_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community_flags is not None:
                                                    return True

                                                if self.is_aggregator_present is not None:
                                                    return True

                                                if self.is_aigp_present is not None:
                                                    return True

                                                if self.is_as_path_present is not None:
                                                    return True

                                                if self.is_atomic_aggregate_present is not None:
                                                    return True

                                                if self.is_community_present is not None:
                                                    return True

                                                if self.is_connector_present is not None:
                                                    return True

                                                if self.is_extended_community_present is not None:
                                                    return True

                                                if self.is_label_index_present is not None:
                                                    return True

                                                if self.is_local_pref_present is not None:
                                                    return True

                                                if self.is_ls_attribute_present is not None:
                                                    return True

                                                if self.is_metric_present is not None:
                                                    return True

                                                if self.is_origin_present is not None:
                                                    return True

                                                if self.is_pe_distinguisher_label_present is not None:
                                                    return True

                                                if self.is_pmsi_present is not None:
                                                    return True

                                                if self.is_pppmp_present is not None:
                                                    return True

                                                if self.is_ssa_present is not None:
                                                    return True

                                                if self.is_tunnel_encap_present is not None:
                                                    return True

                                                if self.l2tpv3_cookie is not None:
                                                    for child_ref in self.l2tpv3_cookie:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2tpv3_session_id is not None:
                                                    return True

                                                if self.label_index_attr is not None:
                                                    for child_ref in self.label_index_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_preference is not None:
                                                    return True

                                                if self.ls_attr is not None:
                                                    for child_ref in self.ls_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.metric is not None:
                                                    return True

                                                if self.neighbor_as is not None:
                                                    return True

                                                if self.origin is not None:
                                                    return True

                                                if self.originator is not None:
                                                    return True

                                                if self.pe_distinguisher_label is not None:
                                                    for child_ref in self.pe_distinguisher_label:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.pmsi_flags is not None:
                                                    return True

                                                if self.pmsi_label is not None:
                                                    return True

                                                if self.pmsi_type is not None:
                                                    return True

                                                if self.pmsi_value is not None:
                                                    for child_ref in self.pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.ppm_pvalue is not None:
                                                    return True

                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_explicit_path is not None:
                                                    for child_ref in self.sr_policy_explicit_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.sr_policy_preference is not None:
                                                    return True

                                                if self.sr_tunnel_request_state is not None:
                                                    return True

                                                if self.sr_tunnel_state is not None:
                                                    return True

                                                if self.tunnel_encap_type is not None:
                                                    return True

                                                if self.unknown_attribute is not None:
                                                    for child_ref in self.unknown_attribute:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                        class RnhAddr(object):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.len = None
                                                self.mac_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.len is not None:
                                                    return True

                                                if self.mac_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                        class RibrnhIp(object):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.attr_set is not None and self.attr_set._has_data():
                                                return True

                                            if self.attribute_key_number is not None:
                                                return True

                                            if self.attribute_reuse_id_config is not None:
                                                return True

                                            if self.attribute_reuse_id_current is not None:
                                                return True

                                            if self.attribute_reuse_id_keys is not None:
                                                return True

                                            if self.attribute_reuse_id_max_id is not None:
                                                return True

                                            if self.attribute_reuse_id_node is not None:
                                                return True

                                            if self.attribute_reuse_id_recover_sec is not None:
                                                return True

                                            if self.common_attributes is not None and self.common_attributes._has_data():
                                                return True

                                            if self.is_application_gateway_present is not None:
                                                return True

                                            if self.is_as_path2_byte is not None:
                                                return True

                                            if self.is_attr_set_present is not None:
                                                return True

                                            if self.is_ribrnh_present is not None:
                                                return True

                                            if self.is_rnh_present is not None:
                                                return True

                                            if self.ribrnh_encap is not None:
                                                return True

                                            if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                return True

                                            if self.ribrnh_mac is not None:
                                                return True

                                            if self.ribrnh_table is not None:
                                                return True

                                            if self.ribrnh_vni is not None:
                                                return True

                                            if self.ribrnhip_table is not None:
                                                return True

                                            if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                return True

                                            if self.rnh_addr_len is not None:
                                                return True

                                            if self.rnh_len is not None:
                                                return True

                                            if self.rnh_type is not None:
                                                return True

                                            if self.set_aigp_inbound_igp is not None:
                                                return True

                                            if self.set_aigp_inbound_metric is not None:
                                                return True

                                            if self.vpn_distinguisher is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn']['meta_info']


                                    class AttributesAfterPolicyOut(object):
                                        """
                                        Attributes after outbound policy
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet>`
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes>`
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp>`
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr>`
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\:  bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet()
                                            self.attr_set.parent = self
                                            self.attribute_key_number = None
                                            self.attribute_reuse_id_config = None
                                            self.attribute_reuse_id_current = None
                                            self.attribute_reuse_id_keys = None
                                            self.attribute_reuse_id_max_id = None
                                            self.attribute_reuse_id_node = None
                                            self.attribute_reuse_id_recover_sec = None
                                            self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self.is_application_gateway_present = None
                                            self.is_as_path2_byte = None
                                            self.is_attr_set_present = None
                                            self.is_ribrnh_present = None
                                            self.is_rnh_present = None
                                            self.ribrnh_encap = None
                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self.ribrnh_mac = None
                                            self.ribrnh_table = None
                                            self.ribrnh_vni = None
                                            self.ribrnhip_table = None
                                            self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self.rnh_addr_len = None
                                            self.rnh_len = None
                                            self.rnh_type = None
                                            self.set_aigp_inbound_igp = None
                                            self.set_aigp_inbound_metric = None
                                            self.vpn_distinguisher = None


                                        class CommonAttributes(object):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_encap_present
                                            
                                            	Tunnel Encap attribute present 
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_policy_allocated_binding_sid
                                            
                                            	SR Policy allocated Binding sid by the router
                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                            
                                            .. attribute:: sr_policy_binding_sid
                                            
                                            	SR Policy Binding sid
                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyBindingSid>`
                                            
                                            .. attribute:: sr_policy_explicit_path
                                            
                                            	SR Policy Explicit paths
                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyExplicitPath>`
                                            
                                            .. attribute:: sr_policy_preference
                                            
                                            	SR Policy Preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_tunnel_request_state
                                            
                                            	SR Tunnel Request State
                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                            
                                            .. attribute:: sr_tunnel_state
                                            
                                            	SR Tunnel State
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap_type
                                            
                                            	Tunnel Encap Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.aggregator_address = None
                                                self.aggregator_as = None
                                                self.aigp_metric_value = None
                                                self.as_path = None
                                                self.cluster = YList()
                                                self.cluster.parent = self
                                                self.cluster.name = 'cluster'
                                                self.community = YList()
                                                self.community.parent = self
                                                self.community.name = 'community'
                                                self.connector_type = None
                                                self.connector_value = YList()
                                                self.connector_value.parent = self
                                                self.connector_value.name = 'connector_value'
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.extended_community_flags = None
                                                self.is_aggregator_present = None
                                                self.is_aigp_present = None
                                                self.is_as_path_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_community_present = None
                                                self.is_connector_present = None
                                                self.is_extended_community_present = None
                                                self.is_label_index_present = None
                                                self.is_local_pref_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_metric_present = None
                                                self.is_origin_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_ssa_present = None
                                                self.is_tunnel_encap_present = None
                                                self.l2tpv3_cookie = YList()
                                                self.l2tpv3_cookie.parent = self
                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                self.l2tpv3_session_id = None
                                                self.label_index_attr = YList()
                                                self.label_index_attr.parent = self
                                                self.label_index_attr.name = 'label_index_attr'
                                                self.local_preference = None
                                                self.ls_attr = YList()
                                                self.ls_attr.parent = self
                                                self.ls_attr.name = 'ls_attr'
                                                self.metric = None
                                                self.neighbor_as = None
                                                self.origin = None
                                                self.originator = None
                                                self.pe_distinguisher_label = YList()
                                                self.pe_distinguisher_label.parent = self
                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.pmsi_type = None
                                                self.pmsi_value = YList()
                                                self.pmsi_value.parent = self
                                                self.pmsi_value.name = 'pmsi_value'
                                                self.ppm_pvalue = None
                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                self.sr_policy_allocated_binding_sid.parent = self
                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyBindingSid()
                                                self.sr_policy_binding_sid.parent = self
                                                self.sr_policy_explicit_path = YList()
                                                self.sr_policy_explicit_path.parent = self
                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                self.sr_policy_preference = None
                                                self.sr_tunnel_request_state = None
                                                self.sr_tunnel_state = None
                                                self.tunnel_encap_type = None
                                                self.unknown_attribute = YList()
                                                self.unknown_attribute.parent = self
                                                self.unknown_attribute.name = 'unknown_attribute'


                                            class SrPolicyBindingSid(object):
                                                """
                                                SR Policy Binding sid
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                            class SrPolicyAllocatedBindingSid(object):
                                                """
                                                SR Policy allocated Binding sid by the router
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                            class Community(object):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity']['meta_info']


                                            class UnknownAttribute(object):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute']['meta_info']


                                            class Cluster(object):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster']['meta_info']


                                            class L2Tpv3Cookie(object):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                            class ConnectorValue(object):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue']['meta_info']


                                            class PmsiValue(object):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue']['meta_info']


                                            class LsAttr(object):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr']['meta_info']


                                            class LabelIndexAttr(object):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr']['meta_info']


                                            class PeDistinguisherLabel(object):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.label = None
                                                    self.pe_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.label is not None:
                                                        return True

                                                    if self.pe_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                            class SrPolicyExplicitPath(object):
                                                """
                                                SR Policy Explicit paths
                                                
                                                .. attribute:: sid
                                                
                                                	Sidlist for explicit path
                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                
                                                .. attribute:: weight
                                                
                                                	Weight of explicit path
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.sid = YList()
                                                    self.sid.parent = self
                                                    self.sid.name = 'sid'
                                                    self.weight = None


                                                class Sid(object):
                                                    """
                                                    Sidlist for explicit path
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IP Address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label sid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Sid Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4 is not None:
                                                            return True

                                                        if self.ipv6 is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.sid is not None:
                                                        for child_ref in self.sid:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.weight is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.aggregator_address is not None:
                                                    return True

                                                if self.aggregator_as is not None:
                                                    return True

                                                if self.aigp_metric_value is not None:
                                                    return True

                                                if self.as_path is not None:
                                                    return True

                                                if self.cluster is not None:
                                                    for child_ref in self.cluster:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.community is not None:
                                                    for child_ref in self.community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.connector_type is not None:
                                                    return True

                                                if self.connector_value is not None:
                                                    for child_ref in self.connector_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community_flags is not None:
                                                    return True

                                                if self.is_aggregator_present is not None:
                                                    return True

                                                if self.is_aigp_present is not None:
                                                    return True

                                                if self.is_as_path_present is not None:
                                                    return True

                                                if self.is_atomic_aggregate_present is not None:
                                                    return True

                                                if self.is_community_present is not None:
                                                    return True

                                                if self.is_connector_present is not None:
                                                    return True

                                                if self.is_extended_community_present is not None:
                                                    return True

                                                if self.is_label_index_present is not None:
                                                    return True

                                                if self.is_local_pref_present is not None:
                                                    return True

                                                if self.is_ls_attribute_present is not None:
                                                    return True

                                                if self.is_metric_present is not None:
                                                    return True

                                                if self.is_origin_present is not None:
                                                    return True

                                                if self.is_pe_distinguisher_label_present is not None:
                                                    return True

                                                if self.is_pmsi_present is not None:
                                                    return True

                                                if self.is_pppmp_present is not None:
                                                    return True

                                                if self.is_ssa_present is not None:
                                                    return True

                                                if self.is_tunnel_encap_present is not None:
                                                    return True

                                                if self.l2tpv3_cookie is not None:
                                                    for child_ref in self.l2tpv3_cookie:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2tpv3_session_id is not None:
                                                    return True

                                                if self.label_index_attr is not None:
                                                    for child_ref in self.label_index_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_preference is not None:
                                                    return True

                                                if self.ls_attr is not None:
                                                    for child_ref in self.ls_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.metric is not None:
                                                    return True

                                                if self.neighbor_as is not None:
                                                    return True

                                                if self.origin is not None:
                                                    return True

                                                if self.originator is not None:
                                                    return True

                                                if self.pe_distinguisher_label is not None:
                                                    for child_ref in self.pe_distinguisher_label:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.pmsi_flags is not None:
                                                    return True

                                                if self.pmsi_label is not None:
                                                    return True

                                                if self.pmsi_type is not None:
                                                    return True

                                                if self.pmsi_value is not None:
                                                    for child_ref in self.pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.ppm_pvalue is not None:
                                                    return True

                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_explicit_path is not None:
                                                    for child_ref in self.sr_policy_explicit_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.sr_policy_preference is not None:
                                                    return True

                                                if self.sr_tunnel_request_state is not None:
                                                    return True

                                                if self.sr_tunnel_state is not None:
                                                    return True

                                                if self.tunnel_encap_type is not None:
                                                    return True

                                                if self.unknown_attribute is not None:
                                                    for child_ref in self.unknown_attribute:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes']['meta_info']


                                        class AttrSet(object):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_encap_present
                                            
                                            	Tunnel Encap attribute present 
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_policy_allocated_binding_sid
                                            
                                            	SR Policy allocated Binding sid by the router
                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyAllocatedBindingSid>`
                                            
                                            .. attribute:: sr_policy_binding_sid
                                            
                                            	SR Policy Binding sid
                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyBindingSid>`
                                            
                                            .. attribute:: sr_policy_explicit_path
                                            
                                            	SR Policy Explicit paths
                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyExplicitPath>`
                                            
                                            .. attribute:: sr_policy_preference
                                            
                                            	SR Policy Preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_tunnel_request_state
                                            
                                            	SR Tunnel Request State
                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                            
                                            .. attribute:: sr_tunnel_state
                                            
                                            	SR Tunnel State
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap_type
                                            
                                            	Tunnel Encap Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.aggregator_address = None
                                                self.aggregator_as = None
                                                self.aigp_metric_value = None
                                                self.as_path = None
                                                self.cluster = YList()
                                                self.cluster.parent = self
                                                self.cluster.name = 'cluster'
                                                self.community = YList()
                                                self.community.parent = self
                                                self.community.name = 'community'
                                                self.connector_type = None
                                                self.connector_value = YList()
                                                self.connector_value.parent = self
                                                self.connector_value.name = 'connector_value'
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.extended_community_flags = None
                                                self.is_aggregator_present = None
                                                self.is_aigp_present = None
                                                self.is_as_path_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_community_present = None
                                                self.is_connector_present = None
                                                self.is_extended_community_present = None
                                                self.is_label_index_present = None
                                                self.is_local_pref_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_metric_present = None
                                                self.is_origin_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_ssa_present = None
                                                self.is_tunnel_encap_present = None
                                                self.l2tpv3_cookie = YList()
                                                self.l2tpv3_cookie.parent = self
                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                self.l2tpv3_session_id = None
                                                self.label_index_attr = YList()
                                                self.label_index_attr.parent = self
                                                self.label_index_attr.name = 'label_index_attr'
                                                self.local_preference = None
                                                self.ls_attr = YList()
                                                self.ls_attr.parent = self
                                                self.ls_attr.name = 'ls_attr'
                                                self.metric = None
                                                self.neighbor_as = None
                                                self.origin = None
                                                self.originator = None
                                                self.pe_distinguisher_label = YList()
                                                self.pe_distinguisher_label.parent = self
                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.pmsi_type = None
                                                self.pmsi_value = YList()
                                                self.pmsi_value.parent = self
                                                self.pmsi_value.name = 'pmsi_value'
                                                self.ppm_pvalue = None
                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyAllocatedBindingSid()
                                                self.sr_policy_allocated_binding_sid.parent = self
                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyBindingSid()
                                                self.sr_policy_binding_sid.parent = self
                                                self.sr_policy_explicit_path = YList()
                                                self.sr_policy_explicit_path.parent = self
                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                self.sr_policy_preference = None
                                                self.sr_tunnel_request_state = None
                                                self.sr_tunnel_state = None
                                                self.tunnel_encap_type = None
                                                self.unknown_attribute = YList()
                                                self.unknown_attribute.parent = self
                                                self.unknown_attribute.name = 'unknown_attribute'


                                            class SrPolicyBindingSid(object):
                                                """
                                                SR Policy Binding sid
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyBindingSid']['meta_info']


                                            class SrPolicyAllocatedBindingSid(object):
                                                """
                                                SR Policy allocated Binding sid by the router
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                            class Community(object):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity']['meta_info']


                                            class UnknownAttribute(object):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute']['meta_info']


                                            class Cluster(object):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster']['meta_info']


                                            class L2Tpv3Cookie(object):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie']['meta_info']


                                            class ConnectorValue(object):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue']['meta_info']


                                            class PmsiValue(object):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue']['meta_info']


                                            class LsAttr(object):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr']['meta_info']


                                            class LabelIndexAttr(object):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr']['meta_info']


                                            class PeDistinguisherLabel(object):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.label = None
                                                    self.pe_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.label is not None:
                                                        return True

                                                    if self.pe_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel']['meta_info']


                                            class SrPolicyExplicitPath(object):
                                                """
                                                SR Policy Explicit paths
                                                
                                                .. attribute:: sid
                                                
                                                	Sidlist for explicit path
                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyExplicitPath.Sid>`
                                                
                                                .. attribute:: weight
                                                
                                                	Weight of explicit path
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.sid = YList()
                                                    self.sid.parent = self
                                                    self.sid.name = 'sid'
                                                    self.weight = None


                                                class Sid(object):
                                                    """
                                                    Sidlist for explicit path
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IP Address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label sid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Sid Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4 is not None:
                                                            return True

                                                        if self.ipv6 is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.sid is not None:
                                                        for child_ref in self.sid:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.weight is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.SrPolicyExplicitPath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.aggregator_address is not None:
                                                    return True

                                                if self.aggregator_as is not None:
                                                    return True

                                                if self.aigp_metric_value is not None:
                                                    return True

                                                if self.as_path is not None:
                                                    return True

                                                if self.cluster is not None:
                                                    for child_ref in self.cluster:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.community is not None:
                                                    for child_ref in self.community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.connector_type is not None:
                                                    return True

                                                if self.connector_value is not None:
                                                    for child_ref in self.connector_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community_flags is not None:
                                                    return True

                                                if self.is_aggregator_present is not None:
                                                    return True

                                                if self.is_aigp_present is not None:
                                                    return True

                                                if self.is_as_path_present is not None:
                                                    return True

                                                if self.is_atomic_aggregate_present is not None:
                                                    return True

                                                if self.is_community_present is not None:
                                                    return True

                                                if self.is_connector_present is not None:
                                                    return True

                                                if self.is_extended_community_present is not None:
                                                    return True

                                                if self.is_label_index_present is not None:
                                                    return True

                                                if self.is_local_pref_present is not None:
                                                    return True

                                                if self.is_ls_attribute_present is not None:
                                                    return True

                                                if self.is_metric_present is not None:
                                                    return True

                                                if self.is_origin_present is not None:
                                                    return True

                                                if self.is_pe_distinguisher_label_present is not None:
                                                    return True

                                                if self.is_pmsi_present is not None:
                                                    return True

                                                if self.is_pppmp_present is not None:
                                                    return True

                                                if self.is_ssa_present is not None:
                                                    return True

                                                if self.is_tunnel_encap_present is not None:
                                                    return True

                                                if self.l2tpv3_cookie is not None:
                                                    for child_ref in self.l2tpv3_cookie:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2tpv3_session_id is not None:
                                                    return True

                                                if self.label_index_attr is not None:
                                                    for child_ref in self.label_index_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_preference is not None:
                                                    return True

                                                if self.ls_attr is not None:
                                                    for child_ref in self.ls_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.metric is not None:
                                                    return True

                                                if self.neighbor_as is not None:
                                                    return True

                                                if self.origin is not None:
                                                    return True

                                                if self.originator is not None:
                                                    return True

                                                if self.pe_distinguisher_label is not None:
                                                    for child_ref in self.pe_distinguisher_label:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.pmsi_flags is not None:
                                                    return True

                                                if self.pmsi_label is not None:
                                                    return True

                                                if self.pmsi_type is not None:
                                                    return True

                                                if self.pmsi_value is not None:
                                                    for child_ref in self.pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.ppm_pvalue is not None:
                                                    return True

                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_explicit_path is not None:
                                                    for child_ref in self.sr_policy_explicit_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.sr_policy_preference is not None:
                                                    return True

                                                if self.sr_tunnel_request_state is not None:
                                                    return True

                                                if self.sr_tunnel_state is not None:
                                                    return True

                                                if self.tunnel_encap_type is not None:
                                                    return True

                                                if self.unknown_attribute is not None:
                                                    for child_ref in self.unknown_attribute:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet']['meta_info']


                                        class RnhAddr(object):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.len = None
                                                self.mac_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.len is not None:
                                                    return True

                                                if self.mac_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr']['meta_info']


                                        class RibrnhIp(object):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-out'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.attr_set is not None and self.attr_set._has_data():
                                                return True

                                            if self.attribute_key_number is not None:
                                                return True

                                            if self.attribute_reuse_id_config is not None:
                                                return True

                                            if self.attribute_reuse_id_current is not None:
                                                return True

                                            if self.attribute_reuse_id_keys is not None:
                                                return True

                                            if self.attribute_reuse_id_max_id is not None:
                                                return True

                                            if self.attribute_reuse_id_node is not None:
                                                return True

                                            if self.attribute_reuse_id_recover_sec is not None:
                                                return True

                                            if self.common_attributes is not None and self.common_attributes._has_data():
                                                return True

                                            if self.is_application_gateway_present is not None:
                                                return True

                                            if self.is_as_path2_byte is not None:
                                                return True

                                            if self.is_attr_set_present is not None:
                                                return True

                                            if self.is_ribrnh_present is not None:
                                                return True

                                            if self.is_rnh_present is not None:
                                                return True

                                            if self.ribrnh_encap is not None:
                                                return True

                                            if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                return True

                                            if self.ribrnh_mac is not None:
                                                return True

                                            if self.ribrnh_table is not None:
                                                return True

                                            if self.ribrnh_vni is not None:
                                                return True

                                            if self.ribrnhip_table is not None:
                                                return True

                                            if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                return True

                                            if self.rnh_addr_len is not None:
                                                return True

                                            if self.rnh_len is not None:
                                                return True

                                            if self.rnh_type is not None:
                                                return True

                                            if self.set_aigp_inbound_igp is not None:
                                                return True

                                            if self.set_aigp_inbound_metric is not None:
                                                return True

                                            if self.vpn_distinguisher is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:policy'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                            return True

                                        if self.attributes_after_policy_out is not None and self.attributes_after_policy_out._has_data():
                                            return True

                                        if self.neighbor_address is not None:
                                            return True

                                        if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                            return True

                                        if self.network is not None:
                                            return True

                                        if self.no_path is not None:
                                            return True

                                        if self.path_info_after_policy_in is not None and self.path_info_after_policy_in._has_data():
                                            return True

                                        if self.path_info_after_policy_out is not None and self.path_info_after_policy_out._has_data():
                                            return True

                                        if self.prefix_length is not None:
                                            return True

                                        if self.rd is not None:
                                            return True

                                        if self.route_distinguisher is not None:
                                            return True

                                        if self.source_route_distinguisher is not None:
                                            return True

                                        if self.vrf_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:policies'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.policy is not None:
                                        for child_ref in self.policy:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies']['meta_info']


                            class Convergence(object):
                                """
                                A BGP Convergence table entry
                                
                                .. attribute:: af_name
                                
                                	Address family identifier
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: are_write_queues_empty
                                
                                	All neighbor write queues are empty
                                	**type**\:  bool
                                
                                .. attribute:: has_converged
                                
                                	Convergence has been reached
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.are_write_queues_empty = None
                                    self.has_converged = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:convergence'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.are_write_queues_empty is not None:
                                        return True

                                    if self.has_converged is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Convergence']['meta_info']


                            class AfProcessInfo(object):
                                """
                                A BGP Process address family table entry
                                
                                .. attribute:: af_name
                                
                                	Address family id
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: global_
                                
                                	Global information
                                	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_>`
                                
                                .. attribute:: performance_statistics
                                
                                	Performance statistics
                                	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics>`
                                
                                .. attribute:: process_instance
                                
                                	ID for the BGP process instance
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Vrf>`
                                
                                .. attribute:: vrf_name
                                
                                	Name of the VRF
                                	**type**\:  str
                                
                                .. attribute:: vrf_totals
                                
                                	per VRF information aggregated across all VRFs
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.global_ = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_()
                                    self.global_.parent = self
                                    self.performance_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics()
                                    self.performance_statistics.parent = self
                                    self.process_instance = None
                                    self.vrf = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Vrf()
                                    self.vrf.parent = self
                                    self.vrf_name = None
                                    self.vrf_totals = None


                                class Global_(object):
                                    """
                                    Global information
                                    
                                    .. attribute:: freed_rd_count
                                    
                                    	Activity\: Number of RDs freed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: import_bgp_version
                                    
                                    	BGP version when Import thread is last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: import_last_trigger
                                    
                                    	Timestamp when Import thread is last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: import_triggers
                                    
                                    	Import thread triggers
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: import_version
                                    
                                    	Version updated by import thread
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: imported_paths_memory
                                    
                                    	Total imported paths memory
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: imported_paths_num
                                    
                                    	Total impoorted paths 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_bgp_version
                                    
                                    	BGP version when label thread is last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_last_trigger
                                    
                                    	Timestamp when Label thread is last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: label_triggers
                                    
                                    	Label thread triggers
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_version
                                    
                                    	Version updated by label thread
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_import_version
                                    
                                    	Import thread version when last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_label_version
                                    
                                    	Label thread version when last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_rib_version
                                    
                                    	RIB thread version when last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_networks_freed_num
                                    
                                    	Total local networks freed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_networks_malloced_num
                                    
                                    	Total local networks malloced
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_networks_memory
                                    
                                    	Total local networks memory
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_networks_num
                                    
                                    	Total local networks
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_paths_freed_num
                                    
                                    	Total local paths freed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_paths_malloced_num
                                    
                                    	Total local paths malloced
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_paths_memory
                                    
                                    	Total local paths memory
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_paths_num
                                    
                                    	Total local paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: malloced_rd_count
                                    
                                    	Activity\: Number of RDs malloced
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: max_active_pelem_version
                                    
                                    	Maximum Active Pelem Version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: merged_table_version
                                    
                                    	Merged Table Version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: multipath_network_entry_count
                                    
                                    	Number of multipath network entries
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: multipath_network_entry_memory
                                    
                                    	Memory (in bytes) used bymultipath network entries
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: multipath_paths_count
                                    
                                    	Number of multipath paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: multipath_paths_memory
                                    
                                    	Memory (in bytes) used bymultimpath paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: networks_freed_num
                                    
                                    	Total networks freed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: networks_malloced_num
                                    
                                    	Total networks malloced
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: networks_memory
                                    
                                    	Total networks memory
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: networks_num
                                    
                                    	Total Num of networks
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_init_sync_pfx
                                    
                                    	Num of prefix synced during Initsync
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_elems_freed_num
                                    
                                    	Total path\-elems freed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_elems_malloced_num
                                    
                                    	Total path\-elems malloced
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_elems_memory
                                    
                                    	Total path\-elems memory
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_elems_num
                                    
                                    	Total Num of path\-elems
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: paths_freed_num
                                    
                                    	Total paths freed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: paths_malloced_num
                                    
                                    	Total paths malloced
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: paths_memory
                                    
                                    	Total paths memory
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: paths_num
                                    
                                    	Total Num of paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rd_memory
                                    
                                    	Memory (in bytes) used by RD data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: rib_ack_requests
                                    
                                    	Counter for RIB ack requests
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_acked_table_version
                                    
                                    	Table version acked by RIB
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_acks_received
                                    
                                    	Counter for RIB ack received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_brib_received_version
                                    
                                    	Version received from 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_install
                                    
                                    	RIB install info
                                    	**type**\:   :py:class:`RibInstall <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall>`
                                    
                                    .. attribute:: rib_last_trigger
                                    
                                    	Timestamp when RIB thread is last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: rib_slow_acks
                                    
                                    	Counter for slow RIB acks
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_triggers
                                    
                                    	RIB thread triggers
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ribbgp_version
                                    
                                    	BGP version when RIB thread is last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_download_go_active_done_pending
                                    
                                    	Route Download Go Active Done Pending
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: router_state
                                    
                                    	Router state
                                    	**type**\:   :py:class:`BgpRtrStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRtrStateEnum>`
                                    
                                    .. attribute:: send_version
                                    
                                    	Version for sending updates to peers
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: standby_version
                                    
                                    	Version updated by sync thread
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_brib_version
                                    
                                    	Version sent to RIB/bRIB
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_version
                                    
                                    	BGP table version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_r_ds_num
                                    
                                    	Total Num of RDs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_remote_r_ds_num
                                    
                                    	Total Num of remote RDs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_same_r_ds_num
                                    
                                    	Total Num of same RDs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: trigger_import
                                    
                                    	Trigger import
                                    	**type**\:   :py:class:`TriggerImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport>`
                                    
                                    .. attribute:: trigger_label
                                    
                                    	Trigger label
                                    	**type**\:   :py:class:`TriggerLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel>`
                                    
                                    .. attribute:: trigger_rib
                                    
                                    	Trigger RIB
                                    	**type**\:   :py:class:`TriggerRib <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib>`
                                    
                                    .. attribute:: trigger_update
                                    
                                    	Trigger update
                                    	**type**\:   :py:class:`TriggerUpdate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate>`
                                    
                                    .. attribute:: update_gen_bgp_version
                                    
                                    	BGP version when Update generation thread is last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_gen_last_trigger
                                    
                                    	Timestamp when Update generation thread is last triggered
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: update_triggers
                                    
                                    	Update thread triggers
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_wait_install_enabled
                                    
                                    	Update wait\-install enabled
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version_wrap_done_time_spec
                                    
                                    	Version Wrap handle Done timestamp
                                    	**type**\:   :py:class:`VersionWrapDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapDoneTimeSpec>`
                                    
                                    .. attribute:: version_wrap_start_time_spec
                                    
                                    	Version Wrap handle start timestamp
                                    	**type**\:   :py:class:`VersionWrapStartTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapStartTimeSpec>`
                                    
                                    .. attribute:: version_wrap_time_spec
                                    
                                    	Version Wrap timestamp
                                    	**type**\:   :py:class:`VersionWrapTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapTimeSpec>`
                                    
                                    .. attribute:: version_wrapped
                                    
                                    	Number of times Version Wrap happened
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version_wrapped_tid
                                    
                                    	Version Wrapped trigger tid
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.freed_rd_count = None
                                        self.import_bgp_version = None
                                        self.import_last_trigger = None
                                        self.import_triggers = None
                                        self.import_version = None
                                        self.imported_paths_memory = None
                                        self.imported_paths_num = None
                                        self.label_bgp_version = None
                                        self.label_last_trigger = None
                                        self.label_triggers = None
                                        self.label_version = None
                                        self.last_import_version = None
                                        self.last_label_version = None
                                        self.last_rib_version = None
                                        self.local_networks_freed_num = None
                                        self.local_networks_malloced_num = None
                                        self.local_networks_memory = None
                                        self.local_networks_num = None
                                        self.local_paths_freed_num = None
                                        self.local_paths_malloced_num = None
                                        self.local_paths_memory = None
                                        self.local_paths_num = None
                                        self.malloced_rd_count = None
                                        self.max_active_pelem_version = None
                                        self.merged_table_version = None
                                        self.multipath_network_entry_count = None
                                        self.multipath_network_entry_memory = None
                                        self.multipath_paths_count = None
                                        self.multipath_paths_memory = None
                                        self.networks_freed_num = None
                                        self.networks_malloced_num = None
                                        self.networks_memory = None
                                        self.networks_num = None
                                        self.num_init_sync_pfx = None
                                        self.path_elems_freed_num = None
                                        self.path_elems_malloced_num = None
                                        self.path_elems_memory = None
                                        self.path_elems_num = None
                                        self.paths_freed_num = None
                                        self.paths_malloced_num = None
                                        self.paths_memory = None
                                        self.paths_num = None
                                        self.rd_memory = None
                                        self.rib_ack_requests = None
                                        self.rib_acked_table_version = None
                                        self.rib_acks_received = None
                                        self.rib_brib_received_version = None
                                        self.rib_install = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall()
                                        self.rib_install.parent = self
                                        self.rib_last_trigger = None
                                        self.rib_slow_acks = None
                                        self.rib_triggers = None
                                        self.ribbgp_version = None
                                        self.route_download_go_active_done_pending = None
                                        self.router_state = None
                                        self.send_version = None
                                        self.standby_version = None
                                        self.table_brib_version = None
                                        self.table_version = None
                                        self.total_r_ds_num = None
                                        self.total_remote_r_ds_num = None
                                        self.total_same_r_ds_num = None
                                        self.trigger_import = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport()
                                        self.trigger_import.parent = self
                                        self.trigger_label = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel()
                                        self.trigger_label.parent = self
                                        self.trigger_rib = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib()
                                        self.trigger_rib.parent = self
                                        self.trigger_update = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate()
                                        self.trigger_update.parent = self
                                        self.update_gen_bgp_version = None
                                        self.update_gen_last_trigger = None
                                        self.update_triggers = None
                                        self.update_wait_install_enabled = None
                                        self.version_wrap_done_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapDoneTimeSpec()
                                        self.version_wrap_done_time_spec.parent = self
                                        self.version_wrap_start_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapStartTimeSpec()
                                        self.version_wrap_start_time_spec.parent = self
                                        self.version_wrap_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapTimeSpec()
                                        self.version_wrap_time_spec.parent = self
                                        self.version_wrapped = None
                                        self.version_wrapped_tid = None


                                    class VersionWrapTimeSpec(object):
                                        """
                                        Version Wrap timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-wrap-time-spec'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapTimeSpec']['meta_info']


                                    class VersionWrapStartTimeSpec(object):
                                        """
                                        Version Wrap handle start timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-wrap-start-time-spec'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapStartTimeSpec']['meta_info']


                                    class VersionWrapDoneTimeSpec(object):
                                        """
                                        Version Wrap handle Done timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-wrap-done-time-spec'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.VersionWrapDoneTimeSpec']['meta_info']


                                    class TriggerRib(object):
                                        """
                                        Trigger RIB
                                        
                                        .. attribute:: statistic
                                        
                                        	statistic
                                        	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic>`
                                        
                                        .. attribute:: triggers
                                        
                                        	Triggers
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.statistic = YList()
                                            self.statistic.parent = self
                                            self.statistic.name = 'statistic'
                                            self.triggers = None


                                        class Statistic(object):
                                            """
                                            statistic
                                            
                                            .. attribute:: trigger_table_version
                                            
                                            	TriggerTableVersion
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: trigger_time_spec
                                            
                                            	trigger time spec
                                            	**type**\:   :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic.TriggerTimeSpec>`
                                            
                                            .. attribute:: trigger_version
                                            
                                            	TriggerVersion
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.trigger_table_version = None
                                                self.trigger_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic.TriggerTimeSpec()
                                                self.trigger_time_spec.parent = self
                                                self.trigger_version = None


                                            class TriggerTimeSpec(object):
                                                """
                                                trigger time spec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:trigger-time-spec'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic.TriggerTimeSpec']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:statistic'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.trigger_table_version is not None:
                                                    return True

                                                if self.trigger_time_spec is not None and self.trigger_time_spec._has_data():
                                                    return True

                                                if self.trigger_version is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib.Statistic']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:trigger-rib'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.statistic is not None:
                                                for child_ref in self.statistic:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.triggers is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerRib']['meta_info']


                                    class TriggerImport(object):
                                        """
                                        Trigger import
                                        
                                        .. attribute:: statistic
                                        
                                        	statistic
                                        	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic>`
                                        
                                        .. attribute:: triggers
                                        
                                        	Triggers
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.statistic = YList()
                                            self.statistic.parent = self
                                            self.statistic.name = 'statistic'
                                            self.triggers = None


                                        class Statistic(object):
                                            """
                                            statistic
                                            
                                            .. attribute:: trigger_table_version
                                            
                                            	TriggerTableVersion
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: trigger_time_spec
                                            
                                            	trigger time spec
                                            	**type**\:   :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic.TriggerTimeSpec>`
                                            
                                            .. attribute:: trigger_version
                                            
                                            	TriggerVersion
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.trigger_table_version = None
                                                self.trigger_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic.TriggerTimeSpec()
                                                self.trigger_time_spec.parent = self
                                                self.trigger_version = None


                                            class TriggerTimeSpec(object):
                                                """
                                                trigger time spec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:trigger-time-spec'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic.TriggerTimeSpec']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:statistic'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.trigger_table_version is not None:
                                                    return True

                                                if self.trigger_time_spec is not None and self.trigger_time_spec._has_data():
                                                    return True

                                                if self.trigger_version is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport.Statistic']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:trigger-import'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.statistic is not None:
                                                for child_ref in self.statistic:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.triggers is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerImport']['meta_info']


                                    class TriggerUpdate(object):
                                        """
                                        Trigger update
                                        
                                        .. attribute:: statistic
                                        
                                        	statistic
                                        	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic>`
                                        
                                        .. attribute:: triggers
                                        
                                        	Triggers
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.statistic = YList()
                                            self.statistic.parent = self
                                            self.statistic.name = 'statistic'
                                            self.triggers = None


                                        class Statistic(object):
                                            """
                                            statistic
                                            
                                            .. attribute:: trigger_table_version
                                            
                                            	TriggerTableVersion
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: trigger_time_spec
                                            
                                            	trigger time spec
                                            	**type**\:   :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic.TriggerTimeSpec>`
                                            
                                            .. attribute:: trigger_version
                                            
                                            	TriggerVersion
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.trigger_table_version = None
                                                self.trigger_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic.TriggerTimeSpec()
                                                self.trigger_time_spec.parent = self
                                                self.trigger_version = None


                                            class TriggerTimeSpec(object):
                                                """
                                                trigger time spec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:trigger-time-spec'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic.TriggerTimeSpec']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:statistic'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.trigger_table_version is not None:
                                                    return True

                                                if self.trigger_time_spec is not None and self.trigger_time_spec._has_data():
                                                    return True

                                                if self.trigger_version is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate.Statistic']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:trigger-update'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.statistic is not None:
                                                for child_ref in self.statistic:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.triggers is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerUpdate']['meta_info']


                                    class TriggerLabel(object):
                                        """
                                        Trigger label
                                        
                                        .. attribute:: statistic
                                        
                                        	statistic
                                        	**type**\: list of    :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic>`
                                        
                                        .. attribute:: triggers
                                        
                                        	Triggers
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.statistic = YList()
                                            self.statistic.parent = self
                                            self.statistic.name = 'statistic'
                                            self.triggers = None


                                        class Statistic(object):
                                            """
                                            statistic
                                            
                                            .. attribute:: trigger_table_version
                                            
                                            	TriggerTableVersion
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: trigger_time_spec
                                            
                                            	trigger time spec
                                            	**type**\:   :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic.TriggerTimeSpec>`
                                            
                                            .. attribute:: trigger_version
                                            
                                            	TriggerVersion
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.trigger_table_version = None
                                                self.trigger_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic.TriggerTimeSpec()
                                                self.trigger_time_spec.parent = self
                                                self.trigger_version = None


                                            class TriggerTimeSpec(object):
                                                """
                                                trigger time spec
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:trigger-time-spec'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic.TriggerTimeSpec']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:statistic'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.trigger_table_version is not None:
                                                    return True

                                                if self.trigger_time_spec is not None and self.trigger_time_spec._has_data():
                                                    return True

                                                if self.trigger_version is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel.Statistic']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:trigger-label'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.statistic is not None:
                                                for child_ref in self.statistic:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.triggers is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.TriggerLabel']['meta_info']


                                    class RibInstall(object):
                                        """
                                        RIB install info
                                        
                                        .. attribute:: install_time
                                        
                                        	RIB install time
                                        	**type**\:   :py:class:`InstallTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall.InstallTime>`
                                        
                                        .. attribute:: installed_count
                                        
                                        	Installed routes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: modified_count
                                        
                                        	Modified routes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: start_version
                                        
                                        	Start version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: target_version
                                        
                                        	Target version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_time
                                        
                                        	RIB update time
                                        	**type**\:   :py:class:`UpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall.UpdateTime>`
                                        
                                        .. attribute:: withdrawn_count
                                        
                                        	Withdrawn routes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.install_time = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall.InstallTime()
                                            self.install_time.parent = self
                                            self.installed_count = None
                                            self.modified_count = None
                                            self.start_version = None
                                            self.target_version = None
                                            self.update_time = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall.UpdateTime()
                                            self.update_time.parent = self
                                            self.withdrawn_count = None


                                        class UpdateTime(object):
                                            """
                                            RIB update time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-time'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall.UpdateTime']['meta_info']


                                        class InstallTime(object):
                                            """
                                            RIB install time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:install-time'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall.InstallTime']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rib-install'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.install_time is not None and self.install_time._has_data():
                                                return True

                                            if self.installed_count is not None:
                                                return True

                                            if self.modified_count is not None:
                                                return True

                                            if self.start_version is not None:
                                                return True

                                            if self.target_version is not None:
                                                return True

                                            if self.update_time is not None and self.update_time._has_data():
                                                return True

                                            if self.withdrawn_count is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_.RibInstall']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:global'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.freed_rd_count is not None:
                                            return True

                                        if self.import_bgp_version is not None:
                                            return True

                                        if self.import_last_trigger is not None:
                                            return True

                                        if self.import_triggers is not None:
                                            return True

                                        if self.import_version is not None:
                                            return True

                                        if self.imported_paths_memory is not None:
                                            return True

                                        if self.imported_paths_num is not None:
                                            return True

                                        if self.label_bgp_version is not None:
                                            return True

                                        if self.label_last_trigger is not None:
                                            return True

                                        if self.label_triggers is not None:
                                            return True

                                        if self.label_version is not None:
                                            return True

                                        if self.last_import_version is not None:
                                            return True

                                        if self.last_label_version is not None:
                                            return True

                                        if self.last_rib_version is not None:
                                            return True

                                        if self.local_networks_freed_num is not None:
                                            return True

                                        if self.local_networks_malloced_num is not None:
                                            return True

                                        if self.local_networks_memory is not None:
                                            return True

                                        if self.local_networks_num is not None:
                                            return True

                                        if self.local_paths_freed_num is not None:
                                            return True

                                        if self.local_paths_malloced_num is not None:
                                            return True

                                        if self.local_paths_memory is not None:
                                            return True

                                        if self.local_paths_num is not None:
                                            return True

                                        if self.malloced_rd_count is not None:
                                            return True

                                        if self.max_active_pelem_version is not None:
                                            return True

                                        if self.merged_table_version is not None:
                                            return True

                                        if self.multipath_network_entry_count is not None:
                                            return True

                                        if self.multipath_network_entry_memory is not None:
                                            return True

                                        if self.multipath_paths_count is not None:
                                            return True

                                        if self.multipath_paths_memory is not None:
                                            return True

                                        if self.networks_freed_num is not None:
                                            return True

                                        if self.networks_malloced_num is not None:
                                            return True

                                        if self.networks_memory is not None:
                                            return True

                                        if self.networks_num is not None:
                                            return True

                                        if self.num_init_sync_pfx is not None:
                                            return True

                                        if self.path_elems_freed_num is not None:
                                            return True

                                        if self.path_elems_malloced_num is not None:
                                            return True

                                        if self.path_elems_memory is not None:
                                            return True

                                        if self.path_elems_num is not None:
                                            return True

                                        if self.paths_freed_num is not None:
                                            return True

                                        if self.paths_malloced_num is not None:
                                            return True

                                        if self.paths_memory is not None:
                                            return True

                                        if self.paths_num is not None:
                                            return True

                                        if self.rd_memory is not None:
                                            return True

                                        if self.rib_ack_requests is not None:
                                            return True

                                        if self.rib_acked_table_version is not None:
                                            return True

                                        if self.rib_acks_received is not None:
                                            return True

                                        if self.rib_brib_received_version is not None:
                                            return True

                                        if self.rib_install is not None and self.rib_install._has_data():
                                            return True

                                        if self.rib_last_trigger is not None:
                                            return True

                                        if self.rib_slow_acks is not None:
                                            return True

                                        if self.rib_triggers is not None:
                                            return True

                                        if self.ribbgp_version is not None:
                                            return True

                                        if self.route_download_go_active_done_pending is not None:
                                            return True

                                        if self.router_state is not None:
                                            return True

                                        if self.send_version is not None:
                                            return True

                                        if self.standby_version is not None:
                                            return True

                                        if self.table_brib_version is not None:
                                            return True

                                        if self.table_version is not None:
                                            return True

                                        if self.total_r_ds_num is not None:
                                            return True

                                        if self.total_remote_r_ds_num is not None:
                                            return True

                                        if self.total_same_r_ds_num is not None:
                                            return True

                                        if self.trigger_import is not None and self.trigger_import._has_data():
                                            return True

                                        if self.trigger_label is not None and self.trigger_label._has_data():
                                            return True

                                        if self.trigger_rib is not None and self.trigger_rib._has_data():
                                            return True

                                        if self.trigger_update is not None and self.trigger_update._has_data():
                                            return True

                                        if self.update_gen_bgp_version is not None:
                                            return True

                                        if self.update_gen_last_trigger is not None:
                                            return True

                                        if self.update_triggers is not None:
                                            return True

                                        if self.update_wait_install_enabled is not None:
                                            return True

                                        if self.version_wrap_done_time_spec is not None and self.version_wrap_done_time_spec._has_data():
                                            return True

                                        if self.version_wrap_start_time_spec is not None and self.version_wrap_start_time_spec._has_data():
                                            return True

                                        if self.version_wrap_time_spec is not None and self.version_wrap_time_spec._has_data():
                                            return True

                                        if self.version_wrapped is not None:
                                            return True

                                        if self.version_wrapped_tid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global_']['meta_info']


                                class Vrf(object):
                                    """
                                    VRF information
                                    
                                    .. attribute:: add_path_install_disable
                                    
                                    	Additional paths installation is disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: add_path_install_enable
                                    
                                    	Additional paths installation is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: any_ebgp_neighbor_missing_policy
                                    
                                    	Is there any neighbor which is missing either inbound or outbound or both routing policy for this address family?
                                    	**type**\:  bool
                                    
                                    .. attribute:: asbr
                                    
                                    	Router is an ASBR for this AF
                                    	**type**\:  bool
                                    
                                    .. attribute:: attribute_download
                                    
                                    	Attribute download is 
                                    	**type**\:  bool
                                    
                                    .. attribute:: best_external
                                    
                                    	Best External is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: best_external_disable
                                    
                                    	Best External is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: bmp_network_entry_count
                                    
                                    	Number of BMP net entries
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_path_memory
                                    
                                    	Memory (in bytes) used by path data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: bmp_paths_count
                                    
                                    	Total Number of BMP paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_prefix_memory
                                    
                                    	Memory (in bytes) used by prefix data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: damped_path_count
                                    
                                    	Number of dampened paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: freed_path_count
                                    
                                    	Activity\: Number of paths freed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: freed_path_elem_count
                                    
                                    	Activity\: Number of pathelems freed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: freed_prefix_count
                                    
                                    	Activity\: Number of prefixes freed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: history_path_count
                                    
                                    	Number of history paths (for dampening)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ibgp_nexthop_self_count
                                    
                                    	Number of iBGP sessions configured with nh\-self
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: imported_path_memory
                                    
                                    	Memory (in bytes) used by imported paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: imported_paths
                                    
                                    	Number of imported paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_route_reflector
                                    
                                    	Router is an RR for this AF
                                    	**type**\:  bool
                                    
                                    .. attribute:: label_retain
                                    
                                    	Label retention is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: label_retainvalue
                                    
                                    	Label retention value enabled
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_path_memory
                                    
                                    	Memory (in bytes) used by local paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: local_paths
                                    
                                    	Number of local paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: malloced_path_count
                                    
                                    	Activity\: Number of paths malloced
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: malloced_path_elem_count
                                    
                                    	Activity\: Number of path elems malloced
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: malloced_prefix_count
                                    
                                    	Activity\: Number of prefixes malloced
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: network_entry_count
                                    
                                    	Number of network entries
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_elem_memory
                                    
                                    	Memory (in bytes) used by pathelem data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: path_elems_count
                                    
                                    	Number of path elems
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_memory
                                    
                                    	Memory (in bytes) used by path data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: paths_count
                                    
                                    	Number of paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefix_memory
                                    
                                    	Memory (in bytes) used by prefix data
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: received_path_count
                                    
                                    	Number of (unused) received paths for inbound soft reconfiguration
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: retain_rt_all
                                    
                                    	Retain\-RT\-All enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_target_download
                                    
                                    	Route Target download is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: tbl_bitf_size
                                    
                                    	Bitfield size on table
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: tbl_chunk_bitf_size
                                    
                                    	Chunk Bitfield size on table
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: use_igpsr_label
                                    
                                    	Use IGP SR label for resolution
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.add_path_install_disable = None
                                        self.add_path_install_enable = None
                                        self.any_ebgp_neighbor_missing_policy = None
                                        self.asbr = None
                                        self.attribute_download = None
                                        self.best_external = None
                                        self.best_external_disable = None
                                        self.bmp_network_entry_count = None
                                        self.bmp_path_memory = None
                                        self.bmp_paths_count = None
                                        self.bmp_prefix_memory = None
                                        self.damped_path_count = None
                                        self.freed_path_count = None
                                        self.freed_path_elem_count = None
                                        self.freed_prefix_count = None
                                        self.history_path_count = None
                                        self.ibgp_nexthop_self_count = None
                                        self.imported_path_memory = None
                                        self.imported_paths = None
                                        self.is_route_reflector = None
                                        self.label_retain = None
                                        self.label_retainvalue = None
                                        self.local_path_memory = None
                                        self.local_paths = None
                                        self.malloced_path_count = None
                                        self.malloced_path_elem_count = None
                                        self.malloced_prefix_count = None
                                        self.network_entry_count = None
                                        self.path_elem_memory = None
                                        self.path_elems_count = None
                                        self.path_memory = None
                                        self.paths_count = None
                                        self.prefix_memory = None
                                        self.received_path_count = None
                                        self.retain_rt_all = None
                                        self.route_target_download = None
                                        self.tbl_bitf_size = None
                                        self.tbl_chunk_bitf_size = None
                                        self.use_igpsr_label = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:vrf'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.add_path_install_disable is not None:
                                            return True

                                        if self.add_path_install_enable is not None:
                                            return True

                                        if self.any_ebgp_neighbor_missing_policy is not None:
                                            return True

                                        if self.asbr is not None:
                                            return True

                                        if self.attribute_download is not None:
                                            return True

                                        if self.best_external is not None:
                                            return True

                                        if self.best_external_disable is not None:
                                            return True

                                        if self.bmp_network_entry_count is not None:
                                            return True

                                        if self.bmp_path_memory is not None:
                                            return True

                                        if self.bmp_paths_count is not None:
                                            return True

                                        if self.bmp_prefix_memory is not None:
                                            return True

                                        if self.damped_path_count is not None:
                                            return True

                                        if self.freed_path_count is not None:
                                            return True

                                        if self.freed_path_elem_count is not None:
                                            return True

                                        if self.freed_prefix_count is not None:
                                            return True

                                        if self.history_path_count is not None:
                                            return True

                                        if self.ibgp_nexthop_self_count is not None:
                                            return True

                                        if self.imported_path_memory is not None:
                                            return True

                                        if self.imported_paths is not None:
                                            return True

                                        if self.is_route_reflector is not None:
                                            return True

                                        if self.label_retain is not None:
                                            return True

                                        if self.label_retainvalue is not None:
                                            return True

                                        if self.local_path_memory is not None:
                                            return True

                                        if self.local_paths is not None:
                                            return True

                                        if self.malloced_path_count is not None:
                                            return True

                                        if self.malloced_path_elem_count is not None:
                                            return True

                                        if self.malloced_prefix_count is not None:
                                            return True

                                        if self.network_entry_count is not None:
                                            return True

                                        if self.path_elem_memory is not None:
                                            return True

                                        if self.path_elems_count is not None:
                                            return True

                                        if self.path_memory is not None:
                                            return True

                                        if self.paths_count is not None:
                                            return True

                                        if self.prefix_memory is not None:
                                            return True

                                        if self.received_path_count is not None:
                                            return True

                                        if self.retain_rt_all is not None:
                                            return True

                                        if self.route_target_download is not None:
                                            return True

                                        if self.tbl_bitf_size is not None:
                                            return True

                                        if self.tbl_chunk_bitf_size is not None:
                                            return True

                                        if self.use_igpsr_label is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Vrf']['meta_info']


                                class PerformanceStatistics(object):
                                    """
                                    Performance statistics
                                    
                                    .. attribute:: global_
                                    
                                    	Global information
                                    	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_>`
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.global_ = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_()
                                        self.global_.parent = self
                                        self.vrf = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf()
                                        self.vrf.parent = self


                                    class Global_(object):
                                        """
                                        Global information
                                        
                                        .. attribute:: first_nbr_up_time
                                        
                                        	Time when first peer came up (seconds since Jan 1 1970)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: has_converged
                                        
                                        	TRUE if process has converged
                                        	**type**\:  bool
                                        
                                        .. attribute:: mode_enter_time
                                        
                                        	Time that each mode was entered (seconds since  Jan 1 1970)
                                        	**type**\: list of    :py:class:`ModeEnterTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.ModeEnterTime>`
                                        
                                        .. attribute:: total_pim_callback_add
                                        
                                        	Total number of Pim callbacks for add
                                        	**type**\: list of    :py:class:`TotalPimCallbackAdd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAdd>`
                                        
                                        .. attribute:: total_pim_callback_add_local
                                        
                                        	Total number of Pim callbacks for local add
                                        	**type**\: list of    :py:class:`TotalPimCallbackAddLocal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAddLocal>`
                                        
                                        .. attribute:: total_pim_callback_batch
                                        
                                        	Total number of Pim callback batches
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_pim_callback_del
                                        
                                        	Total number of Pim callbacks for del
                                        	**type**\: list of    :py:class:`TotalPimCallbackDel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDel>`
                                        
                                        .. attribute:: total_pim_callback_del_local
                                        
                                        	Total number of Pim callbacks for Local del
                                        	**type**\: list of    :py:class:`TotalPimCallbackDelLocal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDelLocal>`
                                        
                                        .. attribute:: total_pim_callbacks
                                        
                                        	Total number of PIM callbacks
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_pim_install
                                        
                                        	Total number of install to PIM
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_pim_install_add
                                        
                                        	Total number of install to PIM for add
                                        	**type**\: list of    :py:class:`TotalPimInstallAdd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallAdd>`
                                        
                                        .. attribute:: total_pim_install_del
                                        
                                        	Total number of install to PIM for del
                                        	**type**\: list of    :py:class:`TotalPimInstallDel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallDel>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.first_nbr_up_time = None
                                            self.has_converged = None
                                            self.mode_enter_time = YList()
                                            self.mode_enter_time.parent = self
                                            self.mode_enter_time.name = 'mode_enter_time'
                                            self.total_pim_callback_add = YList()
                                            self.total_pim_callback_add.parent = self
                                            self.total_pim_callback_add.name = 'total_pim_callback_add'
                                            self.total_pim_callback_add_local = YList()
                                            self.total_pim_callback_add_local.parent = self
                                            self.total_pim_callback_add_local.name = 'total_pim_callback_add_local'
                                            self.total_pim_callback_batch = None
                                            self.total_pim_callback_del = YList()
                                            self.total_pim_callback_del.parent = self
                                            self.total_pim_callback_del.name = 'total_pim_callback_del'
                                            self.total_pim_callback_del_local = YList()
                                            self.total_pim_callback_del_local.parent = self
                                            self.total_pim_callback_del_local.name = 'total_pim_callback_del_local'
                                            self.total_pim_callbacks = None
                                            self.total_pim_install = None
                                            self.total_pim_install_add = YList()
                                            self.total_pim_install_add.parent = self
                                            self.total_pim_install_add.name = 'total_pim_install_add'
                                            self.total_pim_install_del = YList()
                                            self.total_pim_install_del.parent = self
                                            self.total_pim_install_del.name = 'total_pim_install_del'


                                        class ModeEnterTime(object):
                                            """
                                            Time that each mode was entered (seconds since
                                            
                                            Jan 1 1970)
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mode-enter-time'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.ModeEnterTime']['meta_info']


                                        class TotalPimInstallAdd(object):
                                            """
                                            Total number of install to PIM for add
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:total-pim-install-add'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallAdd']['meta_info']


                                        class TotalPimInstallDel(object):
                                            """
                                            Total number of install to PIM for del
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:total-pim-install-del'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimInstallDel']['meta_info']


                                        class TotalPimCallbackAdd(object):
                                            """
                                            Total number of Pim callbacks for add
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:total-pim-callback-add'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAdd']['meta_info']


                                        class TotalPimCallbackDel(object):
                                            """
                                            Total number of Pim callbacks for del
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:total-pim-callback-del'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDel']['meta_info']


                                        class TotalPimCallbackAddLocal(object):
                                            """
                                            Total number of Pim callbacks for local add
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:total-pim-callback-add-local'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackAddLocal']['meta_info']


                                        class TotalPimCallbackDelLocal(object):
                                            """
                                            Total number of Pim callbacks for Local del
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:total-pim-callback-del-local'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_.TotalPimCallbackDelLocal']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:global'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.first_nbr_up_time is not None:
                                                return True

                                            if self.has_converged is not None:
                                                return True

                                            if self.mode_enter_time is not None:
                                                for child_ref in self.mode_enter_time:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.total_pim_callback_add is not None:
                                                for child_ref in self.total_pim_callback_add:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.total_pim_callback_add_local is not None:
                                                for child_ref in self.total_pim_callback_add_local:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.total_pim_callback_batch is not None:
                                                return True

                                            if self.total_pim_callback_del is not None:
                                                for child_ref in self.total_pim_callback_del:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.total_pim_callback_del_local is not None:
                                                for child_ref in self.total_pim_callback_del_local:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.total_pim_callbacks is not None:
                                                return True

                                            if self.total_pim_install is not None:
                                                return True

                                            if self.total_pim_install_add is not None:
                                                for child_ref in self.total_pim_install_add:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.total_pim_install_del is not None:
                                                for child_ref in self.total_pim_install_del:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global_']['meta_info']


                                    class Vrf(object):
                                        """
                                        VRF information
                                        
                                        .. attribute:: attributes_recover_from_rib
                                        
                                        	No. of attributes recovered from RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attributes_removed_from_rib
                                        
                                        	No. of attributes withdrawn from RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attributes_sent_to_rib
                                        
                                        	No. of attributes sent to RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: first_rib_table_full_timestamp
                                        
                                        	Timestamp when RIB table was full for the first time
                                        	**type**\:   :py:class:`FirstRibTableFullTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableFullTimestamp>`
                                        
                                        .. attribute:: first_rib_table_full_version
                                        
                                        	Version when RIB table was full for the first time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: first_rib_table_has_space_timestamp
                                        
                                        	Timestamp when RIB table had space for the first time
                                        	**type**\:   :py:class:`FirstRibTableHasSpaceTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableHasSpaceTimestamp>`
                                        
                                        .. attribute:: first_rib_table_has_space_version
                                        
                                        	Version when RIB table had space for the first time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_added_path_count
                                        
                                        	Number of imported paths added
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_calls
                                        
                                        	Number of calls to import processing function
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_dest_net_processed_count
                                        
                                        	Number of destination nets processed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_removed_path_count
                                        
                                        	Number of imported paths removed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_replaced_path_count
                                        
                                        	Number of imported paths 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_src_net_processed_count
                                        
                                        	Number of source nets processed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_time
                                        
                                        	Time spent in import processing (milliseconds) Note time accounted against source nets
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: is_rib_table_full
                                        
                                        	Indicates if RIB table is in prefix\-limit state
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_added_count
                                        
                                        	Number of labels requested
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_calls
                                        
                                        	No. of calls to label allocation processing function
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_release_count
                                        
                                        	Number of labels released
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_rewrite_count
                                        
                                        	Number of label rewrites created
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_time
                                        
                                        	Time spent running label processing (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: last_rib_table_full_age
                                        
                                        	Time since RIB table was full for the last time (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_rib_table_full_timestamp
                                        
                                        	Timestamp when RIB table was full for the last time
                                        	**type**\:   :py:class:`LastRibTableFullTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableFullTimestamp>`
                                        
                                        .. attribute:: last_rib_table_full_version
                                        
                                        	Version when RIB table was full for the last time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_rib_table_has_space_age
                                        
                                        	Times since RIB table had space for the last time (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_rib_table_has_space_timestamp
                                        
                                        	Timestamp when RIB table had space for the last time
                                        	**type**\:   :py:class:`LastRibTableHasSpaceTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableHasSpaceTimestamp>`
                                        
                                        .. attribute:: last_rib_table_has_space_version
                                        
                                        	Version when RIB table had space for the last time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_removed_from_rib
                                        
                                        	No. of prefixes withdrawn from RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_resent_to_rib
                                        
                                        	No. of prefixes re\-sent to RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_sent_to_rib
                                        
                                        	No. of prefixes sent to RIB
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_table_full_version
                                        
                                        	Version when RIB table became full (from non\-full)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_tbl_del_calls
                                        
                                        	No. of rib update skipped on account of table delete
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_tbl_invalid_calls
                                        
                                        	No. of  rib update skipped due to table invalid
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_tbl_local_label
                                        
                                        	No. of rib update skipped. due to no local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_tbl_retry
                                        
                                        	No. of table rib retires
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_tbl_skip_calls
                                        
                                        	No. of rib update skipped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_trigger
                                        
                                        	Rib trigger enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: rib_update_calls
                                        
                                        	No. of calls to RIB update function
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_update_time
                                        
                                        	Time spent sending RIB updates (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: scanner_runs
                                        
                                        	# of times scanner has run
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: scanner_time
                                        
                                        	Time spent running scanner (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: subgroup_count
                                        
                                        	No. of update subgroup
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_label_retain
                                        
                                        	Time last label retentiontriggered 
                                        	**type**\:   :py:class:`TimeLabelRetain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeLabelRetain>`
                                        
                                        .. attribute:: time_last_update_sent
                                        
                                        	Time last update was sent (seconds since Jan 1 1970)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_rib_coverged
                                        
                                        	Time last RIB ack was sent 
                                        	**type**\:   :py:class:`TimeRibCoverged <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibCoverged>`
                                        
                                        .. attribute:: time_rib_down
                                        
                                        	Time last RIB down wassent. This field is deprecated
                                        	**type**\:   :py:class:`TimeRibDown <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibDown>`
                                        
                                        .. attribute:: update_generation_be_prefixes_count
                                        
                                        	No. of be prefixes updates generated for
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_calls
                                        
                                        	No. of calls to update generation function
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_messages_count
                                        
                                        	No. of update messages generated
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_prefixes_count
                                        
                                        	No. of prefixes updates generated for
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_time
                                        
                                        	Time spent generating updates (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: update_group_count
                                        
                                        	No. of update group
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf_flags
                                        
                                        	VRF flags for debug display
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.attributes_recover_from_rib = None
                                            self.attributes_removed_from_rib = None
                                            self.attributes_sent_to_rib = None
                                            self.first_rib_table_full_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableFullTimestamp()
                                            self.first_rib_table_full_timestamp.parent = self
                                            self.first_rib_table_full_version = None
                                            self.first_rib_table_has_space_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableHasSpaceTimestamp()
                                            self.first_rib_table_has_space_timestamp.parent = self
                                            self.first_rib_table_has_space_version = None
                                            self.import_added_path_count = None
                                            self.import_calls = None
                                            self.import_dest_net_processed_count = None
                                            self.import_removed_path_count = None
                                            self.import_replaced_path_count = None
                                            self.import_src_net_processed_count = None
                                            self.import_time = None
                                            self.is_rib_table_full = None
                                            self.label_added_count = None
                                            self.label_calls = None
                                            self.label_release_count = None
                                            self.label_rewrite_count = None
                                            self.label_time = None
                                            self.last_rib_table_full_age = None
                                            self.last_rib_table_full_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableFullTimestamp()
                                            self.last_rib_table_full_timestamp.parent = self
                                            self.last_rib_table_full_version = None
                                            self.last_rib_table_has_space_age = None
                                            self.last_rib_table_has_space_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableHasSpaceTimestamp()
                                            self.last_rib_table_has_space_timestamp.parent = self
                                            self.last_rib_table_has_space_version = None
                                            self.prefixes_removed_from_rib = None
                                            self.prefixes_resent_to_rib = None
                                            self.prefixes_sent_to_rib = None
                                            self.rib_table_full_version = None
                                            self.rib_tbl_del_calls = None
                                            self.rib_tbl_invalid_calls = None
                                            self.rib_tbl_local_label = None
                                            self.rib_tbl_retry = None
                                            self.rib_tbl_skip_calls = None
                                            self.rib_trigger = None
                                            self.rib_update_calls = None
                                            self.rib_update_time = None
                                            self.scanner_runs = None
                                            self.scanner_time = None
                                            self.subgroup_count = None
                                            self.time_label_retain = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeLabelRetain()
                                            self.time_label_retain.parent = self
                                            self.time_last_update_sent = None
                                            self.time_rib_coverged = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibCoverged()
                                            self.time_rib_coverged.parent = self
                                            self.time_rib_down = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibDown()
                                            self.time_rib_down.parent = self
                                            self.update_generation_be_prefixes_count = None
                                            self.update_generation_calls = None
                                            self.update_generation_messages_count = None
                                            self.update_generation_prefixes_count = None
                                            self.update_generation_time = None
                                            self.update_group_count = None
                                            self.vrf_flags = None


                                        class TimeRibCoverged(object):
                                            """
                                            Time last RIB ack was sent 
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:time-rib-coverged'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibCoverged']['meta_info']


                                        class TimeRibDown(object):
                                            """
                                            Time last RIB down wassent. This field is
                                            deprecated
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:time-rib-down'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibDown']['meta_info']


                                        class FirstRibTableFullTimestamp(object):
                                            """
                                            Timestamp when RIB table was full for the first
                                            time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-rib-table-full-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableFullTimestamp']['meta_info']


                                        class LastRibTableFullTimestamp(object):
                                            """
                                            Timestamp when RIB table was full for the last
                                            time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-rib-table-full-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableFullTimestamp']['meta_info']


                                        class FirstRibTableHasSpaceTimestamp(object):
                                            """
                                            Timestamp when RIB table had space for the first
                                            time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-rib-table-has-space-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableHasSpaceTimestamp']['meta_info']


                                        class LastRibTableHasSpaceTimestamp(object):
                                            """
                                            Timestamp when RIB table had space for the last
                                            time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-rib-table-has-space-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableHasSpaceTimestamp']['meta_info']


                                        class TimeLabelRetain(object):
                                            """
                                            Time last label retentiontriggered 
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:time-label-retain'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeLabelRetain']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:vrf'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.attributes_recover_from_rib is not None:
                                                return True

                                            if self.attributes_removed_from_rib is not None:
                                                return True

                                            if self.attributes_sent_to_rib is not None:
                                                return True

                                            if self.first_rib_table_full_timestamp is not None and self.first_rib_table_full_timestamp._has_data():
                                                return True

                                            if self.first_rib_table_full_version is not None:
                                                return True

                                            if self.first_rib_table_has_space_timestamp is not None and self.first_rib_table_has_space_timestamp._has_data():
                                                return True

                                            if self.first_rib_table_has_space_version is not None:
                                                return True

                                            if self.import_added_path_count is not None:
                                                return True

                                            if self.import_calls is not None:
                                                return True

                                            if self.import_dest_net_processed_count is not None:
                                                return True

                                            if self.import_removed_path_count is not None:
                                                return True

                                            if self.import_replaced_path_count is not None:
                                                return True

                                            if self.import_src_net_processed_count is not None:
                                                return True

                                            if self.import_time is not None:
                                                return True

                                            if self.is_rib_table_full is not None:
                                                return True

                                            if self.label_added_count is not None:
                                                return True

                                            if self.label_calls is not None:
                                                return True

                                            if self.label_release_count is not None:
                                                return True

                                            if self.label_rewrite_count is not None:
                                                return True

                                            if self.label_time is not None:
                                                return True

                                            if self.last_rib_table_full_age is not None:
                                                return True

                                            if self.last_rib_table_full_timestamp is not None and self.last_rib_table_full_timestamp._has_data():
                                                return True

                                            if self.last_rib_table_full_version is not None:
                                                return True

                                            if self.last_rib_table_has_space_age is not None:
                                                return True

                                            if self.last_rib_table_has_space_timestamp is not None and self.last_rib_table_has_space_timestamp._has_data():
                                                return True

                                            if self.last_rib_table_has_space_version is not None:
                                                return True

                                            if self.prefixes_removed_from_rib is not None:
                                                return True

                                            if self.prefixes_resent_to_rib is not None:
                                                return True

                                            if self.prefixes_sent_to_rib is not None:
                                                return True

                                            if self.rib_table_full_version is not None:
                                                return True

                                            if self.rib_tbl_del_calls is not None:
                                                return True

                                            if self.rib_tbl_invalid_calls is not None:
                                                return True

                                            if self.rib_tbl_local_label is not None:
                                                return True

                                            if self.rib_tbl_retry is not None:
                                                return True

                                            if self.rib_tbl_skip_calls is not None:
                                                return True

                                            if self.rib_trigger is not None:
                                                return True

                                            if self.rib_update_calls is not None:
                                                return True

                                            if self.rib_update_time is not None:
                                                return True

                                            if self.scanner_runs is not None:
                                                return True

                                            if self.scanner_time is not None:
                                                return True

                                            if self.subgroup_count is not None:
                                                return True

                                            if self.time_label_retain is not None and self.time_label_retain._has_data():
                                                return True

                                            if self.time_last_update_sent is not None:
                                                return True

                                            if self.time_rib_coverged is not None and self.time_rib_coverged._has_data():
                                                return True

                                            if self.time_rib_down is not None and self.time_rib_down._has_data():
                                                return True

                                            if self.update_generation_be_prefixes_count is not None:
                                                return True

                                            if self.update_generation_calls is not None:
                                                return True

                                            if self.update_generation_messages_count is not None:
                                                return True

                                            if self.update_generation_prefixes_count is not None:
                                                return True

                                            if self.update_generation_time is not None:
                                                return True

                                            if self.update_group_count is not None:
                                                return True

                                            if self.vrf_flags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:performance-statistics'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.global_ is not None and self.global_._has_data():
                                            return True

                                        if self.vrf is not None and self.vrf._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af-process-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.global_ is not None and self.global_._has_data():
                                        return True

                                    if self.performance_statistics is not None and self.performance_statistics._has_data():
                                        return True

                                    if self.process_instance is not None:
                                        return True

                                    if self.vrf is not None and self.vrf._has_data():
                                        return True

                                    if self.vrf_name is not None:
                                        return True

                                    if self.vrf_totals is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo']['meta_info']


                            class PathUsedTable(object):
                                """
                                The BGP Path Used Table
                                
                                .. attribute:: path
                                
                                	A BGP path table entry
                                	**type**\: list of    :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.path = YList()
                                    self.path.parent = self
                                    self.path.name = 'path'


                                class Path(object):
                                    """
                                    A BGP path table entry
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: attributes_after_policy_in
                                    
                                    	Attributes after inbound policy applied
                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn>`
                                    
                                    .. attribute:: label_fail
                                    
                                    	LSD label allocation failed 
                                    	**type**\:  bool
                                    
                                    .. attribute:: label_o_or_version
                                    
                                    	Label Version when OOR happens
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_oor
                                    
                                    	LSD label space is exhausted
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor adddress
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr>`
                                    
                                    .. attribute:: network
                                    
                                    	Network Prefix in Hex format
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: no_path
                                    
                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_id
                                    
                                    	Received Path ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: path_information
                                    
                                    	Path information
                                    	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: prefix_version
                                    
                                    	Version of BGP Prefix Table
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: route_type
                                    
                                    	Route Type
                                    	**type**\:   :py:class:`BgpRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRouteEnum>`
                                    
                                    .. attribute:: source_rd
                                    
                                    	Source Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: source_route_distinguisher
                                    
                                    	Source Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_vrf_name
                                    
                                    	Name of the source VRF
                                    	**type**\:  str
                                    
                                    .. attribute:: srcaf_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn()
                                        self.attributes_after_policy_in.parent = self
                                        self.label_fail = None
                                        self.label_o_or_version = None
                                        self.label_oor = None
                                        self.neighbor_address = None
                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr()
                                        self.neighbor_address_xr.parent = self
                                        self.network = None
                                        self.no_path = None
                                        self.path_id = None
                                        self.path_information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation()
                                        self.path_information.parent = self
                                        self.prefix_length = None
                                        self.prefix_version = None
                                        self.process_instance_id = None
                                        self.rd = None
                                        self.route_distinguisher = None
                                        self.route_type = None
                                        self.source_rd = None
                                        self.source_route_distinguisher = None
                                        self.source_vrf_name = None
                                        self.srcaf_name = None
                                        self.vrf_name = None


                                    class NeighborAddressXr(object):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.NeighborAddressXr']['meta_info']


                                    class PathInformation(object):
                                        """
                                        Path information
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_own_self_originated_p_ath
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\:  bool
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield>`
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner>`
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix>`
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity>`
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\:  bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\:  bool
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr>`
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_esi
                                        
                                        	Path has EVPN ESI
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_rcvd_label
                                        
                                        	Path has received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\:  bool
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebg_ps
                                        
                                        	Not advertised to EBGPs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.L2VpnCircuitStatusValue>`
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.L2VpnEvpnEsi>`
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr>`
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue>`
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress>`
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop>`
                                        
                                        .. attribute:: nhte_tunnel
                                        
                                        	NH TE tunnel information
                                        	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhteTunnel>`
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\:  bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.accept_own_path = None
                                            self.accept_own_self_originated_p_ath = None
                                            self.add_path_orr_bitfield = YList()
                                            self.add_path_orr_bitfield.parent = self
                                            self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                            self.advertisedto_pe = None
                                            self.aigp_metric = None
                                            self.best_path_comp_stage = None
                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self.best_path_id = None
                                            self.best_path_id_comp_winner = None
                                            self.best_path_orr_bitfield = YList()
                                            self.best_path_orr_bitfield.parent = self
                                            self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self.dampen_penalty = None
                                            self.extended_community = YList()
                                            self.extended_community.parent = self
                                            self.extended_community.name = 'extended_community'
                                            self.fspec_invalid_path = None
                                            self.graceful_shutdown = None
                                            self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr()
                                            self.gw_addr.parent = self
                                            self.halflife_time = None
                                            self.has_esi = None
                                            self.has_gw_addr = None
                                            self.has_local_net_label = None
                                            self.has_mdt_group_addr = None
                                            self.has_mvpn_extcomm = None
                                            self.has_mvpn_nbr_addr = None
                                            self.has_mvpn_nexthop_addr = None
                                            self.has_mvpn_pmsi = None
                                            self.has_rcvd_label = None
                                            self.has_second_label = None
                                            self.ibgp_signaled_validity = None
                                            self.igp_metric = None
                                            self.is_aggregation_suppressed = None
                                            self.is_as_best = None
                                            self.is_best_path = None
                                            self.is_import_dampened = None
                                            self.is_import_suspect = None
                                            self.is_internal_path = None
                                            self.is_partial_best = None
                                            self.is_path_additional_path = None
                                            self.is_path_advertised_local_as_only = None
                                            self.is_path_af_install_eligible = None
                                            self.is_path_backup = None
                                            self.is_path_backup_protect_multipath = None
                                            self.is_path_best_external = None
                                            self.is_path_damped = None
                                            self.is_path_from_confederation_peer = None
                                            self.is_path_from_network_command = None
                                            self.is_path_from_redistribute_command = None
                                            self.is_path_from_route_reflector = None
                                            self.is_path_history_held = None
                                            self.is_path_imp_candidate = None
                                            self.is_path_imported = None
                                            self.is_path_local_aggregate = None
                                            self.is_path_locally_sourced = None
                                            self.is_path_long_lived_stale = None
                                            self.is_path_multipath = None
                                            self.is_path_nexthop_discarded = None
                                            self.is_path_not_advertised = None
                                            self.is_path_not_advertised_to_ebg_ps = None
                                            self.is_path_received_only = None
                                            self.is_path_reoriginated = None
                                            self.is_path_reoriginated_stitching = None
                                            self.is_path_stale = None
                                            self.is_path_synced_with_igp = None
                                            self.is_path_valid = None
                                            self.is_path_vpn_only = None
                                            self.is_permanent_path = None
                                            self.is_received_path_not_modified = None
                                            self.is_spkr_as_best = None
                                            self.l2vpn_circuit_status_value = YList()
                                            self.l2vpn_circuit_status_value.parent = self
                                            self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                            self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.L2VpnEvpnEsi()
                                            self.l2vpn_evpn_esi.parent = self
                                            self.l2vpn_size = None
                                            self.labeled_unicast_safi_path = None
                                            self.local_label = None
                                            self.local_nh = None
                                            self.local_path_id = None
                                            self.local_peers_advertised_to = YList()
                                            self.local_peers_advertised_to.parent = self
                                            self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                            self.maximum_suppress_time = None
                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self.mvpn_path_flags = None
                                            self.mvpn_pmsi_flags = None
                                            self.mvpn_pmsi_label = None
                                            self.mvpn_pmsi_type = None
                                            self.mvpn_pmsi_value = YList()
                                            self.mvpn_pmsi_value.parent = self
                                            self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                            self.mvpn_sfs_path = None
                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self.neighbor_router_id = None
                                            self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop()
                                            self.next_hop.parent = self
                                            self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhteTunnel()
                                            self.nhte_tunnel.parent = self
                                            self.path_flags = None
                                            self.path_flap_count = None
                                            self.path_import_flags = None
                                            self.path_rt_set_id = None
                                            self.path_rt_set_route_count = None
                                            self.path_table_version = None
                                            self.path_weight = None
                                            self.pe_peers_advertised_to = YList()
                                            self.pe_peers_advertised_to.parent = self
                                            self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                            self.rcvd_label = None
                                            self.rcvd_path_id = None
                                            self.reuse_value = None
                                            self.rib_failed = None
                                            self.route_type = None
                                            self.rpki_origin_as_validation_disabled = None
                                            self.rt_set_limit_enabled = None
                                            self.second_label = None
                                            self.seconds_since_first_flap = None
                                            self.show_rpki_origin_as_validity = None
                                            self.sn_rpki_origin_as_validity = None
                                            self.suppress_penalty = None
                                            self.time_to_unsuppress = None


                                        class BgpPrefix(object):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self.prefix_length = None


                                            class Prefix(object):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.prefix is not None and self.prefix._has_data():
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix']['meta_info']


                                        class NeighborAddress(object):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress']['meta_info']


                                        class NextHop(object):
                                            """
                                            Next hop
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop']['meta_info']


                                        class NhteTunnel(object):
                                            """
                                            NH TE tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_te_tunnel
                                            
                                            	NH TE Tunnel info is present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last rib update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	tunnel name
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	tunnel type
                                            	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.binding_label = None
                                                self.has_te_tunnel = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.is_tunnel_up = None
                                                self.last_tunnel_update = None
                                                self.tunnel_if_handle = None
                                                self.tunnel_name = None
                                                self.tunnel_type = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_v6_required = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.binding_label is not None:
                                                    return True

                                                if self.has_te_tunnel is not None:
                                                    return True

                                                if self.is_tunnel_info_stale is not None:
                                                    return True

                                                if self.is_tunnel_registered is not None:
                                                    return True

                                                if self.is_tunnel_up is not None:
                                                    return True

                                                if self.last_tunnel_update is not None:
                                                    return True

                                                if self.tunnel_if_handle is not None:
                                                    return True

                                                if self.tunnel_name is not None:
                                                    return True

                                                if self.tunnel_type is not None:
                                                    return True

                                                if self.tunnel_v6_enabled is not None:
                                                    return True

                                                if self.tunnel_v6_required is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhteTunnel']['meta_info']


                                        class MdtGroupAddr(object):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr']['meta_info']


                                        class L2VpnEvpnEsi(object):
                                            """
                                            L2VPN EVPN ESI
                                            
                                            .. attribute:: esi
                                            
                                            	esi
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.esi = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.esi is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.L2VpnEvpnEsi']['meta_info']


                                        class GwAddr(object):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.len = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.len is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr']['meta_info']


                                        class BestPathCompWinner(object):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner']['meta_info']


                                        class MvpnNbrAddr(object):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr']['meta_info']


                                        class MvpnNexthopAddr(object):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr']['meta_info']


                                        class L2VpnCircuitStatusValue(object):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                        class MvpnPmsiValue(object):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue']['meta_info']


                                        class ExtendedCommunity(object):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity']['meta_info']


                                        class LocalPeersAdvertisedTo(object):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                        class PePeersAdvertisedTo(object):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo']['meta_info']


                                        class BestPathOrrBitfield(object):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield']['meta_info']


                                        class AddPathOrrBitfield(object):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.accept_own_path is not None:
                                                return True

                                            if self.accept_own_self_originated_p_ath is not None:
                                                return True

                                            if self.add_path_orr_bitfield is not None:
                                                for child_ref in self.add_path_orr_bitfield:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.advertisedto_pe is not None:
                                                return True

                                            if self.aigp_metric is not None:
                                                return True

                                            if self.best_path_comp_stage is not None:
                                                return True

                                            if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                return True

                                            if self.best_path_id is not None:
                                                return True

                                            if self.best_path_id_comp_winner is not None:
                                                return True

                                            if self.best_path_orr_bitfield is not None:
                                                for child_ref in self.best_path_orr_bitfield:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                return True

                                            if self.dampen_penalty is not None:
                                                return True

                                            if self.extended_community is not None:
                                                for child_ref in self.extended_community:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.fspec_invalid_path is not None:
                                                return True

                                            if self.graceful_shutdown is not None:
                                                return True

                                            if self.gw_addr is not None and self.gw_addr._has_data():
                                                return True

                                            if self.halflife_time is not None:
                                                return True

                                            if self.has_esi is not None:
                                                return True

                                            if self.has_gw_addr is not None:
                                                return True

                                            if self.has_local_net_label is not None:
                                                return True

                                            if self.has_mdt_group_addr is not None:
                                                return True

                                            if self.has_mvpn_extcomm is not None:
                                                return True

                                            if self.has_mvpn_nbr_addr is not None:
                                                return True

                                            if self.has_mvpn_nexthop_addr is not None:
                                                return True

                                            if self.has_mvpn_pmsi is not None:
                                                return True

                                            if self.has_rcvd_label is not None:
                                                return True

                                            if self.has_second_label is not None:
                                                return True

                                            if self.ibgp_signaled_validity is not None:
                                                return True

                                            if self.igp_metric is not None:
                                                return True

                                            if self.is_aggregation_suppressed is not None:
                                                return True

                                            if self.is_as_best is not None:
                                                return True

                                            if self.is_best_path is not None:
                                                return True

                                            if self.is_import_dampened is not None:
                                                return True

                                            if self.is_import_suspect is not None:
                                                return True

                                            if self.is_internal_path is not None:
                                                return True

                                            if self.is_partial_best is not None:
                                                return True

                                            if self.is_path_additional_path is not None:
                                                return True

                                            if self.is_path_advertised_local_as_only is not None:
                                                return True

                                            if self.is_path_af_install_eligible is not None:
                                                return True

                                            if self.is_path_backup is not None:
                                                return True

                                            if self.is_path_backup_protect_multipath is not None:
                                                return True

                                            if self.is_path_best_external is not None:
                                                return True

                                            if self.is_path_damped is not None:
                                                return True

                                            if self.is_path_from_confederation_peer is not None:
                                                return True

                                            if self.is_path_from_network_command is not None:
                                                return True

                                            if self.is_path_from_redistribute_command is not None:
                                                return True

                                            if self.is_path_from_route_reflector is not None:
                                                return True

                                            if self.is_path_history_held is not None:
                                                return True

                                            if self.is_path_imp_candidate is not None:
                                                return True

                                            if self.is_path_imported is not None:
                                                return True

                                            if self.is_path_local_aggregate is not None:
                                                return True

                                            if self.is_path_locally_sourced is not None:
                                                return True

                                            if self.is_path_long_lived_stale is not None:
                                                return True

                                            if self.is_path_multipath is not None:
                                                return True

                                            if self.is_path_nexthop_discarded is not None:
                                                return True

                                            if self.is_path_not_advertised is not None:
                                                return True

                                            if self.is_path_not_advertised_to_ebg_ps is not None:
                                                return True

                                            if self.is_path_received_only is not None:
                                                return True

                                            if self.is_path_reoriginated is not None:
                                                return True

                                            if self.is_path_reoriginated_stitching is not None:
                                                return True

                                            if self.is_path_stale is not None:
                                                return True

                                            if self.is_path_synced_with_igp is not None:
                                                return True

                                            if self.is_path_valid is not None:
                                                return True

                                            if self.is_path_vpn_only is not None:
                                                return True

                                            if self.is_permanent_path is not None:
                                                return True

                                            if self.is_received_path_not_modified is not None:
                                                return True

                                            if self.is_spkr_as_best is not None:
                                                return True

                                            if self.l2vpn_circuit_status_value is not None:
                                                for child_ref in self.l2vpn_circuit_status_value:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                return True

                                            if self.l2vpn_size is not None:
                                                return True

                                            if self.labeled_unicast_safi_path is not None:
                                                return True

                                            if self.local_label is not None:
                                                return True

                                            if self.local_nh is not None:
                                                return True

                                            if self.local_path_id is not None:
                                                return True

                                            if self.local_peers_advertised_to is not None:
                                                for child_ref in self.local_peers_advertised_to:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.maximum_suppress_time is not None:
                                                return True

                                            if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                return True

                                            if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                return True

                                            if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                return True

                                            if self.mvpn_path_flags is not None:
                                                return True

                                            if self.mvpn_pmsi_flags is not None:
                                                return True

                                            if self.mvpn_pmsi_label is not None:
                                                return True

                                            if self.mvpn_pmsi_type is not None:
                                                return True

                                            if self.mvpn_pmsi_value is not None:
                                                for child_ref in self.mvpn_pmsi_value:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.mvpn_sfs_path is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            if self.neighbor_router_id is not None:
                                                return True

                                            if self.next_hop is not None and self.next_hop._has_data():
                                                return True

                                            if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                return True

                                            if self.path_flags is not None:
                                                return True

                                            if self.path_flap_count is not None:
                                                return True

                                            if self.path_import_flags is not None:
                                                return True

                                            if self.path_rt_set_id is not None:
                                                return True

                                            if self.path_rt_set_route_count is not None:
                                                return True

                                            if self.path_table_version is not None:
                                                return True

                                            if self.path_weight is not None:
                                                return True

                                            if self.pe_peers_advertised_to is not None:
                                                for child_ref in self.pe_peers_advertised_to:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.rcvd_label is not None:
                                                return True

                                            if self.rcvd_path_id is not None:
                                                return True

                                            if self.reuse_value is not None:
                                                return True

                                            if self.rib_failed is not None:
                                                return True

                                            if self.route_type is not None:
                                                return True

                                            if self.rpki_origin_as_validation_disabled is not None:
                                                return True

                                            if self.rt_set_limit_enabled is not None:
                                                return True

                                            if self.second_label is not None:
                                                return True

                                            if self.seconds_since_first_flap is not None:
                                                return True

                                            if self.show_rpki_origin_as_validity is not None:
                                                return True

                                            if self.sn_rpki_origin_as_validity is not None:
                                                return True

                                            if self.suppress_penalty is not None:
                                                return True

                                            if self.time_to_unsuppress is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation']['meta_info']


                                    class AttributesAfterPolicyIn(object):
                                        """
                                        Attributes after inbound policy applied
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet>`
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes>`
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp>`
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr>`
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\:  bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet()
                                            self.attr_set.parent = self
                                            self.attribute_key_number = None
                                            self.attribute_reuse_id_config = None
                                            self.attribute_reuse_id_current = None
                                            self.attribute_reuse_id_keys = None
                                            self.attribute_reuse_id_max_id = None
                                            self.attribute_reuse_id_node = None
                                            self.attribute_reuse_id_recover_sec = None
                                            self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self.is_application_gateway_present = None
                                            self.is_as_path2_byte = None
                                            self.is_attr_set_present = None
                                            self.is_ribrnh_present = None
                                            self.is_rnh_present = None
                                            self.ribrnh_encap = None
                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self.ribrnh_mac = None
                                            self.ribrnh_table = None
                                            self.ribrnh_vni = None
                                            self.ribrnhip_table = None
                                            self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self.rnh_addr_len = None
                                            self.rnh_len = None
                                            self.rnh_type = None
                                            self.set_aigp_inbound_igp = None
                                            self.set_aigp_inbound_metric = None
                                            self.vpn_distinguisher = None


                                        class CommonAttributes(object):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_encap_present
                                            
                                            	Tunnel Encap attribute present 
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_policy_allocated_binding_sid
                                            
                                            	SR Policy allocated Binding sid by the router
                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                            
                                            .. attribute:: sr_policy_binding_sid
                                            
                                            	SR Policy Binding sid
                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                            
                                            .. attribute:: sr_policy_explicit_path
                                            
                                            	SR Policy Explicit paths
                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                            
                                            .. attribute:: sr_policy_preference
                                            
                                            	SR Policy Preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_tunnel_request_state
                                            
                                            	SR Tunnel Request State
                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                            
                                            .. attribute:: sr_tunnel_state
                                            
                                            	SR Tunnel State
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap_type
                                            
                                            	Tunnel Encap Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.aggregator_address = None
                                                self.aggregator_as = None
                                                self.aigp_metric_value = None
                                                self.as_path = None
                                                self.cluster = YList()
                                                self.cluster.parent = self
                                                self.cluster.name = 'cluster'
                                                self.community = YList()
                                                self.community.parent = self
                                                self.community.name = 'community'
                                                self.connector_type = None
                                                self.connector_value = YList()
                                                self.connector_value.parent = self
                                                self.connector_value.name = 'connector_value'
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.extended_community_flags = None
                                                self.is_aggregator_present = None
                                                self.is_aigp_present = None
                                                self.is_as_path_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_community_present = None
                                                self.is_connector_present = None
                                                self.is_extended_community_present = None
                                                self.is_label_index_present = None
                                                self.is_local_pref_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_metric_present = None
                                                self.is_origin_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_ssa_present = None
                                                self.is_tunnel_encap_present = None
                                                self.l2tpv3_cookie = YList()
                                                self.l2tpv3_cookie.parent = self
                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                self.l2tpv3_session_id = None
                                                self.label_index_attr = YList()
                                                self.label_index_attr.parent = self
                                                self.label_index_attr.name = 'label_index_attr'
                                                self.local_preference = None
                                                self.ls_attr = YList()
                                                self.ls_attr.parent = self
                                                self.ls_attr.name = 'ls_attr'
                                                self.metric = None
                                                self.neighbor_as = None
                                                self.origin = None
                                                self.originator = None
                                                self.pe_distinguisher_label = YList()
                                                self.pe_distinguisher_label.parent = self
                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.pmsi_type = None
                                                self.pmsi_value = YList()
                                                self.pmsi_value.parent = self
                                                self.pmsi_value.name = 'pmsi_value'
                                                self.ppm_pvalue = None
                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                self.sr_policy_allocated_binding_sid.parent = self
                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                self.sr_policy_binding_sid.parent = self
                                                self.sr_policy_explicit_path = YList()
                                                self.sr_policy_explicit_path.parent = self
                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                self.sr_policy_preference = None
                                                self.sr_tunnel_request_state = None
                                                self.sr_tunnel_state = None
                                                self.tunnel_encap_type = None
                                                self.unknown_attribute = YList()
                                                self.unknown_attribute.parent = self
                                                self.unknown_attribute.name = 'unknown_attribute'


                                            class SrPolicyBindingSid(object):
                                                """
                                                SR Policy Binding sid
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                            class SrPolicyAllocatedBindingSid(object):
                                                """
                                                SR Policy allocated Binding sid by the router
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                            class Community(object):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                            class UnknownAttribute(object):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                            class Cluster(object):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                            class L2Tpv3Cookie(object):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                            class ConnectorValue(object):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                            class PmsiValue(object):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                            class LsAttr(object):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                            class LabelIndexAttr(object):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                            class PeDistinguisherLabel(object):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.label = None
                                                    self.pe_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.label is not None:
                                                        return True

                                                    if self.pe_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                            class SrPolicyExplicitPath(object):
                                                """
                                                SR Policy Explicit paths
                                                
                                                .. attribute:: sid
                                                
                                                	Sidlist for explicit path
                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                
                                                .. attribute:: weight
                                                
                                                	Weight of explicit path
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.sid = YList()
                                                    self.sid.parent = self
                                                    self.sid.name = 'sid'
                                                    self.weight = None


                                                class Sid(object):
                                                    """
                                                    Sidlist for explicit path
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IP Address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label sid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Sid Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4 is not None:
                                                            return True

                                                        if self.ipv6 is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.sid is not None:
                                                        for child_ref in self.sid:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.weight is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.aggregator_address is not None:
                                                    return True

                                                if self.aggregator_as is not None:
                                                    return True

                                                if self.aigp_metric_value is not None:
                                                    return True

                                                if self.as_path is not None:
                                                    return True

                                                if self.cluster is not None:
                                                    for child_ref in self.cluster:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.community is not None:
                                                    for child_ref in self.community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.connector_type is not None:
                                                    return True

                                                if self.connector_value is not None:
                                                    for child_ref in self.connector_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community_flags is not None:
                                                    return True

                                                if self.is_aggregator_present is not None:
                                                    return True

                                                if self.is_aigp_present is not None:
                                                    return True

                                                if self.is_as_path_present is not None:
                                                    return True

                                                if self.is_atomic_aggregate_present is not None:
                                                    return True

                                                if self.is_community_present is not None:
                                                    return True

                                                if self.is_connector_present is not None:
                                                    return True

                                                if self.is_extended_community_present is not None:
                                                    return True

                                                if self.is_label_index_present is not None:
                                                    return True

                                                if self.is_local_pref_present is not None:
                                                    return True

                                                if self.is_ls_attribute_present is not None:
                                                    return True

                                                if self.is_metric_present is not None:
                                                    return True

                                                if self.is_origin_present is not None:
                                                    return True

                                                if self.is_pe_distinguisher_label_present is not None:
                                                    return True

                                                if self.is_pmsi_present is not None:
                                                    return True

                                                if self.is_pppmp_present is not None:
                                                    return True

                                                if self.is_ssa_present is not None:
                                                    return True

                                                if self.is_tunnel_encap_present is not None:
                                                    return True

                                                if self.l2tpv3_cookie is not None:
                                                    for child_ref in self.l2tpv3_cookie:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2tpv3_session_id is not None:
                                                    return True

                                                if self.label_index_attr is not None:
                                                    for child_ref in self.label_index_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_preference is not None:
                                                    return True

                                                if self.ls_attr is not None:
                                                    for child_ref in self.ls_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.metric is not None:
                                                    return True

                                                if self.neighbor_as is not None:
                                                    return True

                                                if self.origin is not None:
                                                    return True

                                                if self.originator is not None:
                                                    return True

                                                if self.pe_distinguisher_label is not None:
                                                    for child_ref in self.pe_distinguisher_label:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.pmsi_flags is not None:
                                                    return True

                                                if self.pmsi_label is not None:
                                                    return True

                                                if self.pmsi_type is not None:
                                                    return True

                                                if self.pmsi_value is not None:
                                                    for child_ref in self.pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.ppm_pvalue is not None:
                                                    return True

                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_explicit_path is not None:
                                                    for child_ref in self.sr_policy_explicit_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.sr_policy_preference is not None:
                                                    return True

                                                if self.sr_tunnel_request_state is not None:
                                                    return True

                                                if self.sr_tunnel_state is not None:
                                                    return True

                                                if self.tunnel_encap_type is not None:
                                                    return True

                                                if self.unknown_attribute is not None:
                                                    for child_ref in self.unknown_attribute:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                        class AttrSet(object):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_encap_present
                                            
                                            	Tunnel Encap attribute present 
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_policy_allocated_binding_sid
                                            
                                            	SR Policy allocated Binding sid by the router
                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                            
                                            .. attribute:: sr_policy_binding_sid
                                            
                                            	SR Policy Binding sid
                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                            
                                            .. attribute:: sr_policy_explicit_path
                                            
                                            	SR Policy Explicit paths
                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                            
                                            .. attribute:: sr_policy_preference
                                            
                                            	SR Policy Preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_tunnel_request_state
                                            
                                            	SR Tunnel Request State
                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                            
                                            .. attribute:: sr_tunnel_state
                                            
                                            	SR Tunnel State
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap_type
                                            
                                            	Tunnel Encap Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.aggregator_address = None
                                                self.aggregator_as = None
                                                self.aigp_metric_value = None
                                                self.as_path = None
                                                self.cluster = YList()
                                                self.cluster.parent = self
                                                self.cluster.name = 'cluster'
                                                self.community = YList()
                                                self.community.parent = self
                                                self.community.name = 'community'
                                                self.connector_type = None
                                                self.connector_value = YList()
                                                self.connector_value.parent = self
                                                self.connector_value.name = 'connector_value'
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.extended_community_flags = None
                                                self.is_aggregator_present = None
                                                self.is_aigp_present = None
                                                self.is_as_path_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_community_present = None
                                                self.is_connector_present = None
                                                self.is_extended_community_present = None
                                                self.is_label_index_present = None
                                                self.is_local_pref_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_metric_present = None
                                                self.is_origin_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_ssa_present = None
                                                self.is_tunnel_encap_present = None
                                                self.l2tpv3_cookie = YList()
                                                self.l2tpv3_cookie.parent = self
                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                self.l2tpv3_session_id = None
                                                self.label_index_attr = YList()
                                                self.label_index_attr.parent = self
                                                self.label_index_attr.name = 'label_index_attr'
                                                self.local_preference = None
                                                self.ls_attr = YList()
                                                self.ls_attr.parent = self
                                                self.ls_attr.name = 'ls_attr'
                                                self.metric = None
                                                self.neighbor_as = None
                                                self.origin = None
                                                self.originator = None
                                                self.pe_distinguisher_label = YList()
                                                self.pe_distinguisher_label.parent = self
                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.pmsi_type = None
                                                self.pmsi_value = YList()
                                                self.pmsi_value.parent = self
                                                self.pmsi_value.name = 'pmsi_value'
                                                self.ppm_pvalue = None
                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                self.sr_policy_allocated_binding_sid.parent = self
                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                self.sr_policy_binding_sid.parent = self
                                                self.sr_policy_explicit_path = YList()
                                                self.sr_policy_explicit_path.parent = self
                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                self.sr_policy_preference = None
                                                self.sr_tunnel_request_state = None
                                                self.sr_tunnel_state = None
                                                self.tunnel_encap_type = None
                                                self.unknown_attribute = YList()
                                                self.unknown_attribute.parent = self
                                                self.unknown_attribute.name = 'unknown_attribute'


                                            class SrPolicyBindingSid(object):
                                                """
                                                SR Policy Binding sid
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                            class SrPolicyAllocatedBindingSid(object):
                                                """
                                                SR Policy allocated Binding sid by the router
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                            class Community(object):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                            class UnknownAttribute(object):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                            class Cluster(object):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                            class L2Tpv3Cookie(object):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                            class ConnectorValue(object):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                            class PmsiValue(object):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                            class LsAttr(object):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                            class LabelIndexAttr(object):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                            class PeDistinguisherLabel(object):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.label = None
                                                    self.pe_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.label is not None:
                                                        return True

                                                    if self.pe_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                            class SrPolicyExplicitPath(object):
                                                """
                                                SR Policy Explicit paths
                                                
                                                .. attribute:: sid
                                                
                                                	Sidlist for explicit path
                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                
                                                .. attribute:: weight
                                                
                                                	Weight of explicit path
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.sid = YList()
                                                    self.sid.parent = self
                                                    self.sid.name = 'sid'
                                                    self.weight = None


                                                class Sid(object):
                                                    """
                                                    Sidlist for explicit path
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IP Address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label sid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Sid Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4 is not None:
                                                            return True

                                                        if self.ipv6 is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.sid is not None:
                                                        for child_ref in self.sid:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.weight is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.aggregator_address is not None:
                                                    return True

                                                if self.aggregator_as is not None:
                                                    return True

                                                if self.aigp_metric_value is not None:
                                                    return True

                                                if self.as_path is not None:
                                                    return True

                                                if self.cluster is not None:
                                                    for child_ref in self.cluster:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.community is not None:
                                                    for child_ref in self.community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.connector_type is not None:
                                                    return True

                                                if self.connector_value is not None:
                                                    for child_ref in self.connector_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community_flags is not None:
                                                    return True

                                                if self.is_aggregator_present is not None:
                                                    return True

                                                if self.is_aigp_present is not None:
                                                    return True

                                                if self.is_as_path_present is not None:
                                                    return True

                                                if self.is_atomic_aggregate_present is not None:
                                                    return True

                                                if self.is_community_present is not None:
                                                    return True

                                                if self.is_connector_present is not None:
                                                    return True

                                                if self.is_extended_community_present is not None:
                                                    return True

                                                if self.is_label_index_present is not None:
                                                    return True

                                                if self.is_local_pref_present is not None:
                                                    return True

                                                if self.is_ls_attribute_present is not None:
                                                    return True

                                                if self.is_metric_present is not None:
                                                    return True

                                                if self.is_origin_present is not None:
                                                    return True

                                                if self.is_pe_distinguisher_label_present is not None:
                                                    return True

                                                if self.is_pmsi_present is not None:
                                                    return True

                                                if self.is_pppmp_present is not None:
                                                    return True

                                                if self.is_ssa_present is not None:
                                                    return True

                                                if self.is_tunnel_encap_present is not None:
                                                    return True

                                                if self.l2tpv3_cookie is not None:
                                                    for child_ref in self.l2tpv3_cookie:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2tpv3_session_id is not None:
                                                    return True

                                                if self.label_index_attr is not None:
                                                    for child_ref in self.label_index_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_preference is not None:
                                                    return True

                                                if self.ls_attr is not None:
                                                    for child_ref in self.ls_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.metric is not None:
                                                    return True

                                                if self.neighbor_as is not None:
                                                    return True

                                                if self.origin is not None:
                                                    return True

                                                if self.originator is not None:
                                                    return True

                                                if self.pe_distinguisher_label is not None:
                                                    for child_ref in self.pe_distinguisher_label:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.pmsi_flags is not None:
                                                    return True

                                                if self.pmsi_label is not None:
                                                    return True

                                                if self.pmsi_type is not None:
                                                    return True

                                                if self.pmsi_value is not None:
                                                    for child_ref in self.pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.ppm_pvalue is not None:
                                                    return True

                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_explicit_path is not None:
                                                    for child_ref in self.sr_policy_explicit_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.sr_policy_preference is not None:
                                                    return True

                                                if self.sr_tunnel_request_state is not None:
                                                    return True

                                                if self.sr_tunnel_state is not None:
                                                    return True

                                                if self.tunnel_encap_type is not None:
                                                    return True

                                                if self.unknown_attribute is not None:
                                                    for child_ref in self.unknown_attribute:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                        class RnhAddr(object):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.len = None
                                                self.mac_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.len is not None:
                                                    return True

                                                if self.mac_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                        class RibrnhIp(object):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.attr_set is not None and self.attr_set._has_data():
                                                return True

                                            if self.attribute_key_number is not None:
                                                return True

                                            if self.attribute_reuse_id_config is not None:
                                                return True

                                            if self.attribute_reuse_id_current is not None:
                                                return True

                                            if self.attribute_reuse_id_keys is not None:
                                                return True

                                            if self.attribute_reuse_id_max_id is not None:
                                                return True

                                            if self.attribute_reuse_id_node is not None:
                                                return True

                                            if self.attribute_reuse_id_recover_sec is not None:
                                                return True

                                            if self.common_attributes is not None and self.common_attributes._has_data():
                                                return True

                                            if self.is_application_gateway_present is not None:
                                                return True

                                            if self.is_as_path2_byte is not None:
                                                return True

                                            if self.is_attr_set_present is not None:
                                                return True

                                            if self.is_ribrnh_present is not None:
                                                return True

                                            if self.is_rnh_present is not None:
                                                return True

                                            if self.ribrnh_encap is not None:
                                                return True

                                            if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                return True

                                            if self.ribrnh_mac is not None:
                                                return True

                                            if self.ribrnh_table is not None:
                                                return True

                                            if self.ribrnh_vni is not None:
                                                return True

                                            if self.ribrnhip_table is not None:
                                                return True

                                            if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                return True

                                            if self.rnh_addr_len is not None:
                                                return True

                                            if self.rnh_len is not None:
                                                return True

                                            if self.rnh_type is not None:
                                                return True

                                            if self.set_aigp_inbound_igp is not None:
                                                return True

                                            if self.set_aigp_inbound_metric is not None:
                                                return True

                                            if self.vpn_distinguisher is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                            return True

                                        if self.label_fail is not None:
                                            return True

                                        if self.label_o_or_version is not None:
                                            return True

                                        if self.label_oor is not None:
                                            return True

                                        if self.neighbor_address is not None:
                                            return True

                                        if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                            return True

                                        if self.network is not None:
                                            return True

                                        if self.no_path is not None:
                                            return True

                                        if self.path_id is not None:
                                            return True

                                        if self.path_information is not None and self.path_information._has_data():
                                            return True

                                        if self.prefix_length is not None:
                                            return True

                                        if self.prefix_version is not None:
                                            return True

                                        if self.process_instance_id is not None:
                                            return True

                                        if self.rd is not None:
                                            return True

                                        if self.route_distinguisher is not None:
                                            return True

                                        if self.route_type is not None:
                                            return True

                                        if self.source_rd is not None:
                                            return True

                                        if self.source_route_distinguisher is not None:
                                            return True

                                        if self.source_vrf_name is not None:
                                            return True

                                        if self.srcaf_name is not None:
                                            return True

                                        if self.vrf_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-used-table'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.path is not None:
                                        for child_ref in self.path:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable']['meta_info']


                            class RpcSets(object):
                                """
                                BGP next\-hop set table
                                
                                .. attribute:: rpc_set
                                
                                	A BGP next\-hop set
                                	**type**\: list of    :py:class:`RpcSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.rpc_set = YList()
                                    self.rpc_set.parent = self
                                    self.rpc_set.name = 'rpc_set'


                                class RpcSet(object):
                                    """
                                    A BGP next\-hop set
                                    
                                    .. attribute:: rpc_set_index  <key>
                                    
                                    	Nexthop set index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: label
                                    
                                    	Label assigned to the RPCnext\-hop set
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hop
                                    
                                    	List of multipath next\-hops
                                    	**type**\: list of    :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop>`
                                    
                                    .. attribute:: next_hop_xr
                                    
                                    	Number of multipath next\-hops
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ref_count
                                    
                                    	Refcount
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.rpc_set_index = None
                                        self.label = None
                                        self.next_hop = YList()
                                        self.next_hop.parent = self
                                        self.next_hop.name = 'next_hop'
                                        self.next_hop_xr = None
                                        self.ref_count = None


                                    class NextHop(object):
                                        """
                                        List of multipath next\-hops
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.rpc_set_index is None:
                                            raise YPYModelError('Key property rpc_set_index is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rpc-set[Cisco-IOS-XR-ipv4-bgp-oper:rpc-set-index = ' + str(self.rpc_set_index) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.rpc_set_index is not None:
                                            return True

                                        if self.label is not None:
                                            return True

                                        if self.next_hop is not None:
                                            for child_ref in self.next_hop:
                                                if child_ref._has_data():
                                                    return True

                                        if self.next_hop_xr is not None:
                                            return True

                                        if self.ref_count is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rpc-sets'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.rpc_set is not None:
                                        for child_ref in self.rpc_set:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets']['meta_info']


                            class GlobalAfProcessInfo(object):
                                """
                                The Global Address Family Process information
                                table
                                
                                .. attribute:: af_name
                                
                                	Address family id
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: global_
                                
                                	Global information
                                	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_>`
                                
                                .. attribute:: is_nsr_enabled
                                
                                	Non\-stop routing enabled
                                	**type**\:  bool
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Vrf>`
                                
                                .. attribute:: vrf_name
                                
                                	Name of the VRF
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.af_name = None
                                    self.global_ = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_()
                                    self.global_.parent = self
                                    self.is_nsr_enabled = None
                                    self.vrf = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Vrf()
                                    self.vrf.parent = self
                                    self.vrf_name = None


                                class Global_(object):
                                    """
                                    Global information
                                    
                                    .. attribute:: gblafrpki_allow_invalid
                                    
                                    	Prefix v. allow invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: gblafrpki_disable
                                    
                                    	Prefix validation disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: gblafrpki_signal_ibgp
                                    
                                    	Prefix v. signal ibgp
                                    	**type**\:  bool
                                    
                                    .. attribute:: gblafrpki_use_validity
                                    
                                    	Prefix v. use validity
                                    	**type**\:  bool
                                    
                                    .. attribute:: global_mcast_enabled
                                    
                                    	Is global table mcast enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: inter_as_install_enabled
                                    
                                    	Is inter\-AS install to pim on ASBR enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_perm_net_cfg
                                    
                                    	Permanent Network Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: nh_tunnel_version
                                    
                                    	NH Tunnel Version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: perm_nbr_count
                                    
                                    	Count of neighbors configured with perm net
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_del_count
                                    
                                    	Count of removed perm paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_existing_count
                                    
                                    	Count of existing perm paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_insert_count
                                    
                                    	Count of inserted perm paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_rpl_process_count
                                    
                                    	Count of perm nets processed in RPL
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_rpl_query_count
                                    
                                    	Count of perm nets given by RPL
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_stale_del_count
                                    
                                    	Count of stale perm paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_stale_mark_count
                                    
                                    	Count of stale marked perm paths
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_path_refresh_count
                                    
                                    	Count of perm paths refreshed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_pelem_all_bump_count
                                    
                                    	Count of bumped perm pelems
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_pelem_bump_count
                                    
                                    	Count of bumped perm pelems
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_pelem_free_count
                                    
                                    	Count of freed perm pelems
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rib_ack_requests
                                    
                                    	Counter for RIB ack requests
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_acks_received
                                    
                                    	Counter for RIB ack received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_install
                                    
                                    	RIB install info
                                    	**type**\:   :py:class:`RibInstall <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall>`
                                    
                                    .. attribute:: rib_perm_path_found_count
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rib_perm_path_not_found_count
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rib_perm_pelem_found_count
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rib_perm_pelem_not_found_count
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rib_reg_path_found_count
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rib_slow_acks
                                    
                                    	Counter for slow RIB acks
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: scan_prefixes
                                    
                                    	Total prefixes of address\-family scanned
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: scan_segment_prefixes
                                    
                                    	Number of prefixes scanned in a segment of address\-family
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: scan_segments
                                    
                                    	Number of segments to scan all prefixes of address\-family
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: scanner_period
                                    
                                    	Period (in seconds) of address\-family scanner runs
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: segmented_mcast_enabled
                                    
                                    	Is segmented mcast enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: syncgrp_version
                                    
                                    	Sync\-group Version
                                    	**type**\: list of    :py:class:`SyncgrpVersion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.SyncgrpVersion>`
                                    
                                    .. attribute:: update_wait_install_enabled
                                    
                                    	Update wait\-install enabled
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.gblafrpki_allow_invalid = None
                                        self.gblafrpki_disable = None
                                        self.gblafrpki_signal_ibgp = None
                                        self.gblafrpki_use_validity = None
                                        self.global_mcast_enabled = None
                                        self.inter_as_install_enabled = None
                                        self.is_perm_net_cfg = None
                                        self.nh_tunnel_version = None
                                        self.perm_nbr_count = None
                                        self.perm_net_del_count = None
                                        self.perm_net_existing_count = None
                                        self.perm_net_insert_count = None
                                        self.perm_net_rpl_process_count = None
                                        self.perm_net_rpl_query_count = None
                                        self.perm_net_stale_del_count = None
                                        self.perm_net_stale_mark_count = None
                                        self.perm_path_refresh_count = None
                                        self.perm_pelem_all_bump_count = None
                                        self.perm_pelem_bump_count = None
                                        self.perm_pelem_free_count = None
                                        self.rib_ack_requests = None
                                        self.rib_acks_received = None
                                        self.rib_install = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall()
                                        self.rib_install.parent = self
                                        self.rib_perm_path_found_count = None
                                        self.rib_perm_path_not_found_count = None
                                        self.rib_perm_pelem_found_count = None
                                        self.rib_perm_pelem_not_found_count = None
                                        self.rib_reg_path_found_count = None
                                        self.rib_slow_acks = None
                                        self.scan_prefixes = None
                                        self.scan_segment_prefixes = None
                                        self.scan_segments = None
                                        self.scanner_period = None
                                        self.segmented_mcast_enabled = None
                                        self.syncgrp_version = YList()
                                        self.syncgrp_version.parent = self
                                        self.syncgrp_version.name = 'syncgrp_version'
                                        self.update_wait_install_enabled = None


                                    class RibInstall(object):
                                        """
                                        RIB install info
                                        
                                        .. attribute:: install_time
                                        
                                        	RIB install time
                                        	**type**\:   :py:class:`InstallTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.InstallTime>`
                                        
                                        .. attribute:: installed_count
                                        
                                        	Installed routes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: modified_count
                                        
                                        	Modified routes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: start_version
                                        
                                        	Start version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: target_version
                                        
                                        	Target version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_time
                                        
                                        	RIB update time
                                        	**type**\:   :py:class:`UpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.UpdateTime>`
                                        
                                        .. attribute:: withdrawn_count
                                        
                                        	Withdrawn routes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.install_time = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.InstallTime()
                                            self.install_time.parent = self
                                            self.installed_count = None
                                            self.modified_count = None
                                            self.start_version = None
                                            self.target_version = None
                                            self.update_time = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.UpdateTime()
                                            self.update_time.parent = self
                                            self.withdrawn_count = None


                                        class UpdateTime(object):
                                            """
                                            RIB update time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-time'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.UpdateTime']['meta_info']


                                        class InstallTime(object):
                                            """
                                            RIB install time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:install-time'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall.InstallTime']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rib-install'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.install_time is not None and self.install_time._has_data():
                                                return True

                                            if self.installed_count is not None:
                                                return True

                                            if self.modified_count is not None:
                                                return True

                                            if self.start_version is not None:
                                                return True

                                            if self.target_version is not None:
                                                return True

                                            if self.update_time is not None and self.update_time._has_data():
                                                return True

                                            if self.withdrawn_count is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.RibInstall']['meta_info']


                                    class SyncgrpVersion(object):
                                        """
                                        Sync\-group Version
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.entry = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:syncgrp-version'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.entry is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_.SyncgrpVersion']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:global'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.gblafrpki_allow_invalid is not None:
                                            return True

                                        if self.gblafrpki_disable is not None:
                                            return True

                                        if self.gblafrpki_signal_ibgp is not None:
                                            return True

                                        if self.gblafrpki_use_validity is not None:
                                            return True

                                        if self.global_mcast_enabled is not None:
                                            return True

                                        if self.inter_as_install_enabled is not None:
                                            return True

                                        if self.is_perm_net_cfg is not None:
                                            return True

                                        if self.nh_tunnel_version is not None:
                                            return True

                                        if self.perm_nbr_count is not None:
                                            return True

                                        if self.perm_net_del_count is not None:
                                            return True

                                        if self.perm_net_existing_count is not None:
                                            return True

                                        if self.perm_net_insert_count is not None:
                                            return True

                                        if self.perm_net_rpl_process_count is not None:
                                            return True

                                        if self.perm_net_rpl_query_count is not None:
                                            return True

                                        if self.perm_net_stale_del_count is not None:
                                            return True

                                        if self.perm_net_stale_mark_count is not None:
                                            return True

                                        if self.perm_path_refresh_count is not None:
                                            return True

                                        if self.perm_pelem_all_bump_count is not None:
                                            return True

                                        if self.perm_pelem_bump_count is not None:
                                            return True

                                        if self.perm_pelem_free_count is not None:
                                            return True

                                        if self.rib_ack_requests is not None:
                                            return True

                                        if self.rib_acks_received is not None:
                                            return True

                                        if self.rib_install is not None and self.rib_install._has_data():
                                            return True

                                        if self.rib_perm_path_found_count is not None:
                                            return True

                                        if self.rib_perm_path_not_found_count is not None:
                                            return True

                                        if self.rib_perm_pelem_found_count is not None:
                                            return True

                                        if self.rib_perm_pelem_not_found_count is not None:
                                            return True

                                        if self.rib_reg_path_found_count is not None:
                                            return True

                                        if self.rib_slow_acks is not None:
                                            return True

                                        if self.scan_prefixes is not None:
                                            return True

                                        if self.scan_segment_prefixes is not None:
                                            return True

                                        if self.scan_segments is not None:
                                            return True

                                        if self.scanner_period is not None:
                                            return True

                                        if self.segmented_mcast_enabled is not None:
                                            return True

                                        if self.syncgrp_version is not None:
                                            for child_ref in self.syncgrp_version:
                                                if child_ref._has_data():
                                                    return True

                                        if self.update_wait_install_enabled is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global_']['meta_info']


                                class Vrf(object):
                                    """
                                    VRF information
                                    
                                    .. attribute:: aggregates_distance
                                    
                                    	Dist for aggregate routes (local)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: client_reflection_enabled
                                    
                                    	Client reflection enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: dampening_enabled
                                    
                                    	Dampening enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: dynamic_med_enabled
                                    
                                    	Update generation enabled for MED change
                                    	**type**\:  bool
                                    
                                    .. attribute:: dynamic_med_interval
                                    
                                    	Delay in update generation after a MED change (in minutes)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: minute
                                    
                                    .. attribute:: dynamic_med_periodic_timer_running
                                    
                                    	Dynamic MED periodic timer running
                                    	**type**\:  bool
                                    
                                    .. attribute:: dynamic_med_periodic_timer_value
                                    
                                    	Dynamic MED periodic timer value (in seconds) left on the timer
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: dynamic_med_timer_running
                                    
                                    	Dynamic MED timer running
                                    	**type**\:  bool
                                    
                                    .. attribute:: dynamic_med_timer_value
                                    
                                    	Dynamic MED timer value (in seconds) left on the timer
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: ebgp_distance
                                    
                                    	Distance for eBGP routes (external)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: ibgp_distance
                                    
                                    	Distance for iBGP routes (internal)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: is_rib_table_full
                                    
                                    	Indicates if RIB table is in prefix\-limit state
                                    	**type**\:  bool
                                    
                                    .. attribute:: nexthop_resolution_minimum_prefix_length
                                    
                                    	Nexthop resoultion minimum prefix\-length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nexthop_resolution_minimum_prefix_length_configured
                                    
                                    	Is nexthop resoultion minimum prefix\-length configured ?
                                    	**type**\:  bool
                                    
                                    .. attribute:: nsr_conv_version
                                    
                                    	NSR conv version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_is_conv
                                    
                                    	NSR is converged
                                    	**type**\:  bool
                                    
                                    .. attribute:: rd_version
                                    
                                    	RD version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_acked_table_version
                                    
                                    	Table version acked by RIB
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_convergence_version
                                    
                                    	Last convergence version received from RIB
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_has_converged
                                    
                                    	Received convergence notification from RIB
                                    	**type**\:  bool
                                    
                                    .. attribute:: rib_table_full_version
                                    
                                    	Version when RIB table became full (from non\-full)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_version
                                    
                                    	Table version synced to RIB
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: selective_ebgp_multipath_enabled
                                    
                                    	Selective eBGP multipath isenabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: selective_eibgp_multipath_enabled
                                    
                                    	Selective eiBGP multipath isenabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: selective_ibgp_multipath_enabled
                                    
                                    	Selective iBGP multipath isenabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: table_id
                                    
                                    	Table ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_is_active
                                    
                                    	Table state is active
                                    	**type**\:  bool
                                    
                                    .. attribute:: table_version
                                    
                                    	Table version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.aggregates_distance = None
                                        self.client_reflection_enabled = None
                                        self.dampening_enabled = None
                                        self.dynamic_med_enabled = None
                                        self.dynamic_med_interval = None
                                        self.dynamic_med_periodic_timer_running = None
                                        self.dynamic_med_periodic_timer_value = None
                                        self.dynamic_med_timer_running = None
                                        self.dynamic_med_timer_value = None
                                        self.ebgp_distance = None
                                        self.ibgp_distance = None
                                        self.is_rib_table_full = None
                                        self.nexthop_resolution_minimum_prefix_length = None
                                        self.nexthop_resolution_minimum_prefix_length_configured = None
                                        self.nsr_conv_version = None
                                        self.nsr_is_conv = None
                                        self.rd_version = None
                                        self.rib_acked_table_version = None
                                        self.rib_convergence_version = None
                                        self.rib_has_converged = None
                                        self.rib_table_full_version = None
                                        self.rib_version = None
                                        self.selective_ebgp_multipath_enabled = None
                                        self.selective_eibgp_multipath_enabled = None
                                        self.selective_ibgp_multipath_enabled = None
                                        self.table_id = None
                                        self.table_is_active = None
                                        self.table_version = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:vrf'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.aggregates_distance is not None:
                                            return True

                                        if self.client_reflection_enabled is not None:
                                            return True

                                        if self.dampening_enabled is not None:
                                            return True

                                        if self.dynamic_med_enabled is not None:
                                            return True

                                        if self.dynamic_med_interval is not None:
                                            return True

                                        if self.dynamic_med_periodic_timer_running is not None:
                                            return True

                                        if self.dynamic_med_periodic_timer_value is not None:
                                            return True

                                        if self.dynamic_med_timer_running is not None:
                                            return True

                                        if self.dynamic_med_timer_value is not None:
                                            return True

                                        if self.ebgp_distance is not None:
                                            return True

                                        if self.ibgp_distance is not None:
                                            return True

                                        if self.is_rib_table_full is not None:
                                            return True

                                        if self.nexthop_resolution_minimum_prefix_length is not None:
                                            return True

                                        if self.nexthop_resolution_minimum_prefix_length_configured is not None:
                                            return True

                                        if self.nsr_conv_version is not None:
                                            return True

                                        if self.nsr_is_conv is not None:
                                            return True

                                        if self.rd_version is not None:
                                            return True

                                        if self.rib_acked_table_version is not None:
                                            return True

                                        if self.rib_convergence_version is not None:
                                            return True

                                        if self.rib_has_converged is not None:
                                            return True

                                        if self.rib_table_full_version is not None:
                                            return True

                                        if self.rib_version is not None:
                                            return True

                                        if self.selective_ebgp_multipath_enabled is not None:
                                            return True

                                        if self.selective_eibgp_multipath_enabled is not None:
                                            return True

                                        if self.selective_ibgp_multipath_enabled is not None:
                                            return True

                                        if self.table_id is not None:
                                            return True

                                        if self.table_is_active is not None:
                                            return True

                                        if self.table_version is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Vrf']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:global-af-process-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.af_name is not None:
                                        return True

                                    if self.global_ is not None and self.global_._has_data():
                                        return True

                                    if self.is_nsr_enabled is not None:
                                        return True

                                    if self.vrf is not None and self.vrf._has_data():
                                        return True

                                    if self.vrf_name is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo']['meta_info']


                            class NetworkPrefixes(object):
                                """
                                The BGP Network Lookup table
                                
                                .. attribute:: network_prefix
                                
                                	A BGP Network Lookup prefix entry
                                	**type**\: list of    :py:class:`NetworkPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.network_prefix = YList()
                                    self.network_prefix.parent = self
                                    self.network_prefix.name = 'network_prefix'


                                class NetworkPrefix(object):
                                    """
                                    A BGP Network Lookup prefix entry
                                    
                                    .. attribute:: active_path_element
                                    
                                    	Path element list received from Active inst
                                    	**type**\: list of    :py:class:`ActivePathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement>`
                                    
                                    .. attribute:: active_process_instance_path
                                    
                                    	Active's paths for this net 
                                    	**type**\: list of    :py:class:`ActiveProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath>`
                                    
                                    .. attribute:: add_path_orr_bitfield
                                    
                                    	ORR Add path Bitfields
                                    	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield>`
                                    
                                    .. attribute:: advertisedto_pe
                                    
                                    	Net could be advertised                          to PE peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: best_path_orr_bitfield
                                    
                                    	ORR Best path Bitfields
                                    	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield>`
                                    
                                    .. attribute:: bgp_prefix
                                    
                                    	BGP prefix
                                    	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix>`
                                    
                                    .. attribute:: bit
                                    
                                    	Bit
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: flags
                                    
                                    	Flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: gateway_array
                                    
                                    	Gateway array ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: has_inconsistent_paths
                                    
                                    	Net has inconsistent paths
                                    	**type**\:  bool
                                    
                                    .. attribute:: has_lbl_retained
                                    
                                    	Net has label retained
                                    	**type**\:  bool
                                    
                                    .. attribute:: has_local_label
                                    
                                    	Net has local label
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_net_aggregation_suppressed
                                    
                                    	Net suppressed due to aggregation
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_net_ldp_signaled
                                    
                                    	L2VPN Net LDP signaled  aggregation
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_permanent_network
                                    
                                    	Permanent Network
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_path_element
                                    
                                    	Local path element list
                                    	**type**\: list of    :py:class:`LocalPathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement>`
                                    
                                    .. attribute:: local_peers_advertised_to
                                    
                                    	Local peers that this prefix has been advertised to
                                    	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo>`
                                    
                                    .. attribute:: local_process_instance_path
                                    
                                    	Local (to process instance) paths for this net 
                                    	**type**\: list of    :py:class:`LocalProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath>`
                                    
                                    .. attribute:: net_backup_available
                                    
                                    	Net has backup path
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_backup_label_rewrite_available
                                    
                                    	Net has label rewrite for backup path
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_eibgp_multipath
                                    
                                    	Net has EIBGP multipaths
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_extended_flags
                                    
                                    	Net extended flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: net_flags
                                    
                                    	Flags associated with                            net
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: net_local_label
                                    
                                    	Local label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: net_local_label_rewrite
                                    
                                    	Net label has rewrite
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_local_label_srgb
                                    
                                    	Net label allocated fromSegment routing global block
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_multipath
                                    
                                    	Net has multipaths
                                    	**type**\:  bool
                                    
                                    .. attribute:: network_prefix
                                    
                                    	Network prefix
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: num_of_path
                                    
                                    	Number of path for this net
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pe_peers_advertised_to
                                    
                                    	PE peers that this prefix has been advertised to
                                    	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo>`
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: resilient_nexthop_set
                                    
                                    	Resilient nexthop set ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_failed
                                    
                                    	RIB install failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: table_brib_version
                                    
                                    	Table version # for updates
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_version
                                    
                                    	Table version # for net
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version
                                    
                                    	Version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version_age
                                    
                                    	Version age
                                    	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionAge>`
                                    
                                    .. attribute:: version_timestamp
                                    
                                    	Version timestamp
                                    	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionTimestamp>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.active_path_element = YList()
                                        self.active_path_element.parent = self
                                        self.active_path_element.name = 'active_path_element'
                                        self.active_process_instance_path = YList()
                                        self.active_process_instance_path.parent = self
                                        self.active_process_instance_path.name = 'active_process_instance_path'
                                        self.add_path_orr_bitfield = YList()
                                        self.add_path_orr_bitfield.parent = self
                                        self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                        self.advertisedto_pe = None
                                        self.af_name = None
                                        self.best_path_orr_bitfield = YList()
                                        self.best_path_orr_bitfield.parent = self
                                        self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                        self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix()
                                        self.bgp_prefix.parent = self
                                        self.bit = None
                                        self.flags = None
                                        self.gateway_array = None
                                        self.has_inconsistent_paths = None
                                        self.has_lbl_retained = None
                                        self.has_local_label = None
                                        self.is_net_aggregation_suppressed = None
                                        self.is_net_ldp_signaled = None
                                        self.is_permanent_network = None
                                        self.local_path_element = YList()
                                        self.local_path_element.parent = self
                                        self.local_path_element.name = 'local_path_element'
                                        self.local_peers_advertised_to = YList()
                                        self.local_peers_advertised_to.parent = self
                                        self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                        self.local_process_instance_path = YList()
                                        self.local_process_instance_path.parent = self
                                        self.local_process_instance_path.name = 'local_process_instance_path'
                                        self.net_backup_available = None
                                        self.net_backup_label_rewrite_available = None
                                        self.net_eibgp_multipath = None
                                        self.net_extended_flags = None
                                        self.net_flags = None
                                        self.net_local_label = None
                                        self.net_local_label_rewrite = None
                                        self.net_local_label_srgb = None
                                        self.net_multipath = None
                                        self.network_prefix = None
                                        self.num_of_path = None
                                        self.pe_peers_advertised_to = YList()
                                        self.pe_peers_advertised_to.parent = self
                                        self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                        self.process_instance_id = None
                                        self.rd = None
                                        self.resilient_nexthop_set = None
                                        self.rib_failed = None
                                        self.route_distinguisher = None
                                        self.table_brib_version = None
                                        self.table_version = None
                                        self.version = None
                                        self.version_age = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionAge()
                                        self.version_age.parent = self
                                        self.version_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionTimestamp()
                                        self.version_timestamp.parent = self
                                        self.vrf_name = None


                                    class BgpPrefix(object):
                                        """
                                        BGP prefix
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix()
                                            self.prefix.parent = self
                                            self.prefix_length = None


                                        class Prefix(object):
                                            """
                                            Prefix
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix.Prefix']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.prefix is not None and self.prefix._has_data():
                                                return True

                                            if self.prefix_length is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BgpPrefix']['meta_info']


                                    class VersionTimestamp(object):
                                        """
                                        Version timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionTimestamp']['meta_info']


                                    class VersionAge(object):
                                        """
                                        Version age
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-age'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.VersionAge']['meta_info']


                                    class LocalPeersAdvertisedTo(object):
                                        """
                                        Local peers that this prefix has been advertised
                                        to
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress>`
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.is_neighbor = None
                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self.update_group_number = None


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.is_neighbor is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            if self.update_group_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPeersAdvertisedTo']['meta_info']


                                    class PePeersAdvertisedTo(object):
                                        """
                                        PE peers that this prefix has been advertised to
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress>`
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.is_neighbor = None
                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self.update_group_number = None


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.is_neighbor is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            if self.update_group_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.PePeersAdvertisedTo']['meta_info']


                                    class BestPathOrrBitfield(object):
                                        """
                                        ORR Best path Bitfields
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress>`
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.is_neighbor = None
                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self.update_group_number = None


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.is_neighbor is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            if self.update_group_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.BestPathOrrBitfield']['meta_info']


                                    class AddPathOrrBitfield(object):
                                        """
                                        ORR Add path Bitfields
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress>`
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.is_neighbor = None
                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self.update_group_number = None


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.is_neighbor is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            if self.update_group_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.AddPathOrrBitfield']['meta_info']


                                    class LocalProcessInstancePath(object):
                                        """
                                        Local (to process instance) paths for this net 
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation>`
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self.label_fail = None
                                            self.label_o_or_version = None
                                            self.label_oor = None
                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self.no_path = None
                                            self.path_information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation()
                                            self.path_information.parent = self
                                            self.prefix_version = None
                                            self.process_instance_id = None
                                            self.route_distinguisher = None
                                            self.source_route_distinguisher = None
                                            self.source_vrf_name = None
                                            self.srcaf_name = None
                                            self.vrf_name = None


                                        class NeighborAddressXr(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.NeighborAddressXr']['meta_info']


                                        class PathInformation(object):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_esi
                                            
                                            	Path has EVPN ESI
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_rcvd_label
                                            
                                            	Path has received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebg_ps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi>`
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop>`
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhteTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_p_ath = None
                                                self.add_path_orr_bitfield = YList()
                                                self.add_path_orr_bitfield.parent = self
                                                self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                self.advertisedto_pe = None
                                                self.aigp_metric = None
                                                self.best_path_comp_stage = None
                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self.best_path_id = None
                                                self.best_path_id_comp_winner = None
                                                self.best_path_orr_bitfield = YList()
                                                self.best_path_orr_bitfield.parent = self
                                                self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self.dampen_penalty = None
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.fspec_invalid_path = None
                                                self.graceful_shutdown = None
                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self.halflife_time = None
                                                self.has_esi = None
                                                self.has_gw_addr = None
                                                self.has_local_net_label = None
                                                self.has_mdt_group_addr = None
                                                self.has_mvpn_extcomm = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.has_rcvd_label = None
                                                self.has_second_label = None
                                                self.ibgp_signaled_validity = None
                                                self.igp_metric = None
                                                self.is_aggregation_suppressed = None
                                                self.is_as_best = None
                                                self.is_best_path = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_internal_path = None
                                                self.is_partial_best = None
                                                self.is_path_additional_path = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_af_install_eligible = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_damped = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_history_held = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_imported = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_multipath = None
                                                self.is_path_nexthop_discarded = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebg_ps = None
                                                self.is_path_received_only = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_stale = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_valid = None
                                                self.is_path_vpn_only = None
                                                self.is_permanent_path = None
                                                self.is_received_path_not_modified = None
                                                self.is_spkr_as_best = None
                                                self.l2vpn_circuit_status_value = YList()
                                                self.l2vpn_circuit_status_value.parent = self
                                                self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi()
                                                self.l2vpn_evpn_esi.parent = self
                                                self.l2vpn_size = None
                                                self.labeled_unicast_safi_path = None
                                                self.local_label = None
                                                self.local_nh = None
                                                self.local_path_id = None
                                                self.local_peers_advertised_to = YList()
                                                self.local_peers_advertised_to.parent = self
                                                self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                self.maximum_suppress_time = None
                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self.mvpn_path_flags = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_value = YList()
                                                self.mvpn_pmsi_value.parent = self
                                                self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                self.mvpn_sfs_path = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.neighbor_router_id = None
                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.path_flags = None
                                                self.path_flap_count = None
                                                self.path_import_flags = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.path_table_version = None
                                                self.path_weight = None
                                                self.pe_peers_advertised_to = YList()
                                                self.pe_peers_advertised_to.parent = self
                                                self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                self.rcvd_label = None
                                                self.rcvd_path_id = None
                                                self.reuse_value = None
                                                self.rib_failed = None
                                                self.route_type = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.rt_set_limit_enabled = None
                                                self.second_label = None
                                                self.seconds_since_first_flap = None
                                                self.show_rpki_origin_as_validity = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.suppress_penalty = None
                                                self.time_to_unsuppress = None


                                            class BgpPrefix(object):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self.prefix_length = None


                                                class Prefix(object):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.prefix is not None and self.prefix._has_data():
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BgpPrefix']['meta_info']


                                            class NeighborAddress(object):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NeighborAddress']['meta_info']


                                            class NextHop(object):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NextHop']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.NhteTunnel']['meta_info']


                                            class MdtGroupAddr(object):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MdtGroupAddr']['meta_info']


                                            class L2VpnEvpnEsi(object):
                                                """
                                                L2VPN EVPN ESI
                                                
                                                .. attribute:: esi
                                                
                                                	esi
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.esi = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.esi is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi']['meta_info']


                                            class GwAddr(object):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.GwAddr']['meta_info']


                                            class BestPathCompWinner(object):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathCompWinner']['meta_info']


                                            class MvpnNbrAddr(object):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNbrAddr']['meta_info']


                                            class MvpnNexthopAddr(object):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr']['meta_info']


                                            class L2VpnCircuitStatusValue(object):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                            class MvpnPmsiValue(object):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.MvpnPmsiValue']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.ExtendedCommunity']['meta_info']


                                            class LocalPeersAdvertisedTo(object):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                            class PePeersAdvertisedTo(object):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo']['meta_info']


                                            class BestPathOrrBitfield(object):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield']['meta_info']


                                            class AddPathOrrBitfield(object):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.accept_own_path is not None:
                                                    return True

                                                if self.accept_own_self_originated_p_ath is not None:
                                                    return True

                                                if self.add_path_orr_bitfield is not None:
                                                    for child_ref in self.add_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.advertisedto_pe is not None:
                                                    return True

                                                if self.aigp_metric is not None:
                                                    return True

                                                if self.best_path_comp_stage is not None:
                                                    return True

                                                if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                    return True

                                                if self.best_path_id is not None:
                                                    return True

                                                if self.best_path_id_comp_winner is not None:
                                                    return True

                                                if self.best_path_orr_bitfield is not None:
                                                    for child_ref in self.best_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                    return True

                                                if self.dampen_penalty is not None:
                                                    return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.fspec_invalid_path is not None:
                                                    return True

                                                if self.graceful_shutdown is not None:
                                                    return True

                                                if self.gw_addr is not None and self.gw_addr._has_data():
                                                    return True

                                                if self.halflife_time is not None:
                                                    return True

                                                if self.has_esi is not None:
                                                    return True

                                                if self.has_gw_addr is not None:
                                                    return True

                                                if self.has_local_net_label is not None:
                                                    return True

                                                if self.has_mdt_group_addr is not None:
                                                    return True

                                                if self.has_mvpn_extcomm is not None:
                                                    return True

                                                if self.has_mvpn_nbr_addr is not None:
                                                    return True

                                                if self.has_mvpn_nexthop_addr is not None:
                                                    return True

                                                if self.has_mvpn_pmsi is not None:
                                                    return True

                                                if self.has_rcvd_label is not None:
                                                    return True

                                                if self.has_second_label is not None:
                                                    return True

                                                if self.ibgp_signaled_validity is not None:
                                                    return True

                                                if self.igp_metric is not None:
                                                    return True

                                                if self.is_aggregation_suppressed is not None:
                                                    return True

                                                if self.is_as_best is not None:
                                                    return True

                                                if self.is_best_path is not None:
                                                    return True

                                                if self.is_import_dampened is not None:
                                                    return True

                                                if self.is_import_suspect is not None:
                                                    return True

                                                if self.is_internal_path is not None:
                                                    return True

                                                if self.is_partial_best is not None:
                                                    return True

                                                if self.is_path_additional_path is not None:
                                                    return True

                                                if self.is_path_advertised_local_as_only is not None:
                                                    return True

                                                if self.is_path_af_install_eligible is not None:
                                                    return True

                                                if self.is_path_backup is not None:
                                                    return True

                                                if self.is_path_backup_protect_multipath is not None:
                                                    return True

                                                if self.is_path_best_external is not None:
                                                    return True

                                                if self.is_path_damped is not None:
                                                    return True

                                                if self.is_path_from_confederation_peer is not None:
                                                    return True

                                                if self.is_path_from_network_command is not None:
                                                    return True

                                                if self.is_path_from_redistribute_command is not None:
                                                    return True

                                                if self.is_path_from_route_reflector is not None:
                                                    return True

                                                if self.is_path_history_held is not None:
                                                    return True

                                                if self.is_path_imp_candidate is not None:
                                                    return True

                                                if self.is_path_imported is not None:
                                                    return True

                                                if self.is_path_local_aggregate is not None:
                                                    return True

                                                if self.is_path_locally_sourced is not None:
                                                    return True

                                                if self.is_path_long_lived_stale is not None:
                                                    return True

                                                if self.is_path_multipath is not None:
                                                    return True

                                                if self.is_path_nexthop_discarded is not None:
                                                    return True

                                                if self.is_path_not_advertised is not None:
                                                    return True

                                                if self.is_path_not_advertised_to_ebg_ps is not None:
                                                    return True

                                                if self.is_path_received_only is not None:
                                                    return True

                                                if self.is_path_reoriginated is not None:
                                                    return True

                                                if self.is_path_reoriginated_stitching is not None:
                                                    return True

                                                if self.is_path_stale is not None:
                                                    return True

                                                if self.is_path_synced_with_igp is not None:
                                                    return True

                                                if self.is_path_valid is not None:
                                                    return True

                                                if self.is_path_vpn_only is not None:
                                                    return True

                                                if self.is_permanent_path is not None:
                                                    return True

                                                if self.is_received_path_not_modified is not None:
                                                    return True

                                                if self.is_spkr_as_best is not None:
                                                    return True

                                                if self.l2vpn_circuit_status_value is not None:
                                                    for child_ref in self.l2vpn_circuit_status_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                    return True

                                                if self.l2vpn_size is not None:
                                                    return True

                                                if self.labeled_unicast_safi_path is not None:
                                                    return True

                                                if self.local_label is not None:
                                                    return True

                                                if self.local_nh is not None:
                                                    return True

                                                if self.local_path_id is not None:
                                                    return True

                                                if self.local_peers_advertised_to is not None:
                                                    for child_ref in self.local_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.maximum_suppress_time is not None:
                                                    return True

                                                if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                    return True

                                                if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                    return True

                                                if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                    return True

                                                if self.mvpn_path_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_label is not None:
                                                    return True

                                                if self.mvpn_pmsi_type is not None:
                                                    return True

                                                if self.mvpn_pmsi_value is not None:
                                                    for child_ref in self.mvpn_pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.mvpn_sfs_path is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.neighbor_router_id is not None:
                                                    return True

                                                if self.next_hop is not None and self.next_hop._has_data():
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.path_flags is not None:
                                                    return True

                                                if self.path_flap_count is not None:
                                                    return True

                                                if self.path_import_flags is not None:
                                                    return True

                                                if self.path_rt_set_id is not None:
                                                    return True

                                                if self.path_rt_set_route_count is not None:
                                                    return True

                                                if self.path_table_version is not None:
                                                    return True

                                                if self.path_weight is not None:
                                                    return True

                                                if self.pe_peers_advertised_to is not None:
                                                    for child_ref in self.pe_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.rcvd_label is not None:
                                                    return True

                                                if self.rcvd_path_id is not None:
                                                    return True

                                                if self.reuse_value is not None:
                                                    return True

                                                if self.rib_failed is not None:
                                                    return True

                                                if self.route_type is not None:
                                                    return True

                                                if self.rpki_origin_as_validation_disabled is not None:
                                                    return True

                                                if self.rt_set_limit_enabled is not None:
                                                    return True

                                                if self.second_label is not None:
                                                    return True

                                                if self.seconds_since_first_flap is not None:
                                                    return True

                                                if self.show_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.sn_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.suppress_penalty is not None:
                                                    return True

                                                if self.time_to_unsuppress is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.PathInformation']['meta_info']


                                        class AttributesAfterPolicyIn(object):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self.is_application_gateway_present = None
                                                self.is_as_path2_byte = None
                                                self.is_attr_set_present = None
                                                self.is_ribrnh_present = None
                                                self.is_rnh_present = None
                                                self.ribrnh_encap = None
                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self.ribrnh_mac = None
                                                self.ribrnh_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnhip_table = None
                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self.rnh_addr_len = None
                                                self.rnh_len = None
                                                self.rnh_type = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.vpn_distinguisher = None


                                            class CommonAttributes(object):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                            class AttrSet(object):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                            class RnhAddr(object):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None
                                                    self.mac_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    if self.mac_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                            class RibrnhIp(object):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.attr_set is not None and self.attr_set._has_data():
                                                    return True

                                                if self.attribute_key_number is not None:
                                                    return True

                                                if self.attribute_reuse_id_config is not None:
                                                    return True

                                                if self.attribute_reuse_id_current is not None:
                                                    return True

                                                if self.attribute_reuse_id_keys is not None:
                                                    return True

                                                if self.attribute_reuse_id_max_id is not None:
                                                    return True

                                                if self.attribute_reuse_id_node is not None:
                                                    return True

                                                if self.attribute_reuse_id_recover_sec is not None:
                                                    return True

                                                if self.common_attributes is not None and self.common_attributes._has_data():
                                                    return True

                                                if self.is_application_gateway_present is not None:
                                                    return True

                                                if self.is_as_path2_byte is not None:
                                                    return True

                                                if self.is_attr_set_present is not None:
                                                    return True

                                                if self.is_ribrnh_present is not None:
                                                    return True

                                                if self.is_rnh_present is not None:
                                                    return True

                                                if self.ribrnh_encap is not None:
                                                    return True

                                                if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                    return True

                                                if self.ribrnh_mac is not None:
                                                    return True

                                                if self.ribrnh_table is not None:
                                                    return True

                                                if self.ribrnh_vni is not None:
                                                    return True

                                                if self.ribrnhip_table is not None:
                                                    return True

                                                if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                    return True

                                                if self.rnh_addr_len is not None:
                                                    return True

                                                if self.rnh_len is not None:
                                                    return True

                                                if self.rnh_type is not None:
                                                    return True

                                                if self.set_aigp_inbound_igp is not None:
                                                    return True

                                                if self.set_aigp_inbound_metric is not None:
                                                    return True

                                                if self.vpn_distinguisher is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath.AttributesAfterPolicyIn']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-process-instance-path'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                return True

                                            if self.label_fail is not None:
                                                return True

                                            if self.label_o_or_version is not None:
                                                return True

                                            if self.label_oor is not None:
                                                return True

                                            if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                return True

                                            if self.no_path is not None:
                                                return True

                                            if self.path_information is not None and self.path_information._has_data():
                                                return True

                                            if self.prefix_version is not None:
                                                return True

                                            if self.process_instance_id is not None:
                                                return True

                                            if self.route_distinguisher is not None:
                                                return True

                                            if self.source_route_distinguisher is not None:
                                                return True

                                            if self.source_vrf_name is not None:
                                                return True

                                            if self.srcaf_name is not None:
                                                return True

                                            if self.vrf_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalProcessInstancePath']['meta_info']


                                    class ActiveProcessInstancePath(object):
                                        """
                                        Active's paths for this net 
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation>`
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self.label_fail = None
                                            self.label_o_or_version = None
                                            self.label_oor = None
                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self.no_path = None
                                            self.path_information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation()
                                            self.path_information.parent = self
                                            self.prefix_version = None
                                            self.process_instance_id = None
                                            self.route_distinguisher = None
                                            self.source_route_distinguisher = None
                                            self.source_vrf_name = None
                                            self.srcaf_name = None
                                            self.vrf_name = None


                                        class NeighborAddressXr(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.NeighborAddressXr']['meta_info']


                                        class PathInformation(object):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_esi
                                            
                                            	Path has EVPN ESI
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_rcvd_label
                                            
                                            	Path has received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebg_ps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi>`
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop>`
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhteTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_p_ath = None
                                                self.add_path_orr_bitfield = YList()
                                                self.add_path_orr_bitfield.parent = self
                                                self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                self.advertisedto_pe = None
                                                self.aigp_metric = None
                                                self.best_path_comp_stage = None
                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self.best_path_id = None
                                                self.best_path_id_comp_winner = None
                                                self.best_path_orr_bitfield = YList()
                                                self.best_path_orr_bitfield.parent = self
                                                self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self.dampen_penalty = None
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.fspec_invalid_path = None
                                                self.graceful_shutdown = None
                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self.halflife_time = None
                                                self.has_esi = None
                                                self.has_gw_addr = None
                                                self.has_local_net_label = None
                                                self.has_mdt_group_addr = None
                                                self.has_mvpn_extcomm = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.has_rcvd_label = None
                                                self.has_second_label = None
                                                self.ibgp_signaled_validity = None
                                                self.igp_metric = None
                                                self.is_aggregation_suppressed = None
                                                self.is_as_best = None
                                                self.is_best_path = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_internal_path = None
                                                self.is_partial_best = None
                                                self.is_path_additional_path = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_af_install_eligible = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_damped = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_history_held = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_imported = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_multipath = None
                                                self.is_path_nexthop_discarded = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebg_ps = None
                                                self.is_path_received_only = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_stale = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_valid = None
                                                self.is_path_vpn_only = None
                                                self.is_permanent_path = None
                                                self.is_received_path_not_modified = None
                                                self.is_spkr_as_best = None
                                                self.l2vpn_circuit_status_value = YList()
                                                self.l2vpn_circuit_status_value.parent = self
                                                self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi()
                                                self.l2vpn_evpn_esi.parent = self
                                                self.l2vpn_size = None
                                                self.labeled_unicast_safi_path = None
                                                self.local_label = None
                                                self.local_nh = None
                                                self.local_path_id = None
                                                self.local_peers_advertised_to = YList()
                                                self.local_peers_advertised_to.parent = self
                                                self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                self.maximum_suppress_time = None
                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self.mvpn_path_flags = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_value = YList()
                                                self.mvpn_pmsi_value.parent = self
                                                self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                self.mvpn_sfs_path = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.neighbor_router_id = None
                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.path_flags = None
                                                self.path_flap_count = None
                                                self.path_import_flags = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.path_table_version = None
                                                self.path_weight = None
                                                self.pe_peers_advertised_to = YList()
                                                self.pe_peers_advertised_to.parent = self
                                                self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                self.rcvd_label = None
                                                self.rcvd_path_id = None
                                                self.reuse_value = None
                                                self.rib_failed = None
                                                self.route_type = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.rt_set_limit_enabled = None
                                                self.second_label = None
                                                self.seconds_since_first_flap = None
                                                self.show_rpki_origin_as_validity = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.suppress_penalty = None
                                                self.time_to_unsuppress = None


                                            class BgpPrefix(object):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self.prefix_length = None


                                                class Prefix(object):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.prefix is not None and self.prefix._has_data():
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BgpPrefix']['meta_info']


                                            class NeighborAddress(object):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NeighborAddress']['meta_info']


                                            class NextHop(object):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NextHop']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.NhteTunnel']['meta_info']


                                            class MdtGroupAddr(object):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MdtGroupAddr']['meta_info']


                                            class L2VpnEvpnEsi(object):
                                                """
                                                L2VPN EVPN ESI
                                                
                                                .. attribute:: esi
                                                
                                                	esi
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.esi = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.esi is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi']['meta_info']


                                            class GwAddr(object):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.GwAddr']['meta_info']


                                            class BestPathCompWinner(object):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathCompWinner']['meta_info']


                                            class MvpnNbrAddr(object):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr']['meta_info']


                                            class MvpnNexthopAddr(object):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr']['meta_info']


                                            class L2VpnCircuitStatusValue(object):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                            class MvpnPmsiValue(object):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.ExtendedCommunity']['meta_info']


                                            class LocalPeersAdvertisedTo(object):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                            class PePeersAdvertisedTo(object):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo']['meta_info']


                                            class BestPathOrrBitfield(object):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield']['meta_info']


                                            class AddPathOrrBitfield(object):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.accept_own_path is not None:
                                                    return True

                                                if self.accept_own_self_originated_p_ath is not None:
                                                    return True

                                                if self.add_path_orr_bitfield is not None:
                                                    for child_ref in self.add_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.advertisedto_pe is not None:
                                                    return True

                                                if self.aigp_metric is not None:
                                                    return True

                                                if self.best_path_comp_stage is not None:
                                                    return True

                                                if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                    return True

                                                if self.best_path_id is not None:
                                                    return True

                                                if self.best_path_id_comp_winner is not None:
                                                    return True

                                                if self.best_path_orr_bitfield is not None:
                                                    for child_ref in self.best_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                    return True

                                                if self.dampen_penalty is not None:
                                                    return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.fspec_invalid_path is not None:
                                                    return True

                                                if self.graceful_shutdown is not None:
                                                    return True

                                                if self.gw_addr is not None and self.gw_addr._has_data():
                                                    return True

                                                if self.halflife_time is not None:
                                                    return True

                                                if self.has_esi is not None:
                                                    return True

                                                if self.has_gw_addr is not None:
                                                    return True

                                                if self.has_local_net_label is not None:
                                                    return True

                                                if self.has_mdt_group_addr is not None:
                                                    return True

                                                if self.has_mvpn_extcomm is not None:
                                                    return True

                                                if self.has_mvpn_nbr_addr is not None:
                                                    return True

                                                if self.has_mvpn_nexthop_addr is not None:
                                                    return True

                                                if self.has_mvpn_pmsi is not None:
                                                    return True

                                                if self.has_rcvd_label is not None:
                                                    return True

                                                if self.has_second_label is not None:
                                                    return True

                                                if self.ibgp_signaled_validity is not None:
                                                    return True

                                                if self.igp_metric is not None:
                                                    return True

                                                if self.is_aggregation_suppressed is not None:
                                                    return True

                                                if self.is_as_best is not None:
                                                    return True

                                                if self.is_best_path is not None:
                                                    return True

                                                if self.is_import_dampened is not None:
                                                    return True

                                                if self.is_import_suspect is not None:
                                                    return True

                                                if self.is_internal_path is not None:
                                                    return True

                                                if self.is_partial_best is not None:
                                                    return True

                                                if self.is_path_additional_path is not None:
                                                    return True

                                                if self.is_path_advertised_local_as_only is not None:
                                                    return True

                                                if self.is_path_af_install_eligible is not None:
                                                    return True

                                                if self.is_path_backup is not None:
                                                    return True

                                                if self.is_path_backup_protect_multipath is not None:
                                                    return True

                                                if self.is_path_best_external is not None:
                                                    return True

                                                if self.is_path_damped is not None:
                                                    return True

                                                if self.is_path_from_confederation_peer is not None:
                                                    return True

                                                if self.is_path_from_network_command is not None:
                                                    return True

                                                if self.is_path_from_redistribute_command is not None:
                                                    return True

                                                if self.is_path_from_route_reflector is not None:
                                                    return True

                                                if self.is_path_history_held is not None:
                                                    return True

                                                if self.is_path_imp_candidate is not None:
                                                    return True

                                                if self.is_path_imported is not None:
                                                    return True

                                                if self.is_path_local_aggregate is not None:
                                                    return True

                                                if self.is_path_locally_sourced is not None:
                                                    return True

                                                if self.is_path_long_lived_stale is not None:
                                                    return True

                                                if self.is_path_multipath is not None:
                                                    return True

                                                if self.is_path_nexthop_discarded is not None:
                                                    return True

                                                if self.is_path_not_advertised is not None:
                                                    return True

                                                if self.is_path_not_advertised_to_ebg_ps is not None:
                                                    return True

                                                if self.is_path_received_only is not None:
                                                    return True

                                                if self.is_path_reoriginated is not None:
                                                    return True

                                                if self.is_path_reoriginated_stitching is not None:
                                                    return True

                                                if self.is_path_stale is not None:
                                                    return True

                                                if self.is_path_synced_with_igp is not None:
                                                    return True

                                                if self.is_path_valid is not None:
                                                    return True

                                                if self.is_path_vpn_only is not None:
                                                    return True

                                                if self.is_permanent_path is not None:
                                                    return True

                                                if self.is_received_path_not_modified is not None:
                                                    return True

                                                if self.is_spkr_as_best is not None:
                                                    return True

                                                if self.l2vpn_circuit_status_value is not None:
                                                    for child_ref in self.l2vpn_circuit_status_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                    return True

                                                if self.l2vpn_size is not None:
                                                    return True

                                                if self.labeled_unicast_safi_path is not None:
                                                    return True

                                                if self.local_label is not None:
                                                    return True

                                                if self.local_nh is not None:
                                                    return True

                                                if self.local_path_id is not None:
                                                    return True

                                                if self.local_peers_advertised_to is not None:
                                                    for child_ref in self.local_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.maximum_suppress_time is not None:
                                                    return True

                                                if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                    return True

                                                if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                    return True

                                                if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                    return True

                                                if self.mvpn_path_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_label is not None:
                                                    return True

                                                if self.mvpn_pmsi_type is not None:
                                                    return True

                                                if self.mvpn_pmsi_value is not None:
                                                    for child_ref in self.mvpn_pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.mvpn_sfs_path is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.neighbor_router_id is not None:
                                                    return True

                                                if self.next_hop is not None and self.next_hop._has_data():
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.path_flags is not None:
                                                    return True

                                                if self.path_flap_count is not None:
                                                    return True

                                                if self.path_import_flags is not None:
                                                    return True

                                                if self.path_rt_set_id is not None:
                                                    return True

                                                if self.path_rt_set_route_count is not None:
                                                    return True

                                                if self.path_table_version is not None:
                                                    return True

                                                if self.path_weight is not None:
                                                    return True

                                                if self.pe_peers_advertised_to is not None:
                                                    for child_ref in self.pe_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.rcvd_label is not None:
                                                    return True

                                                if self.rcvd_path_id is not None:
                                                    return True

                                                if self.reuse_value is not None:
                                                    return True

                                                if self.rib_failed is not None:
                                                    return True

                                                if self.route_type is not None:
                                                    return True

                                                if self.rpki_origin_as_validation_disabled is not None:
                                                    return True

                                                if self.rt_set_limit_enabled is not None:
                                                    return True

                                                if self.second_label is not None:
                                                    return True

                                                if self.seconds_since_first_flap is not None:
                                                    return True

                                                if self.show_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.sn_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.suppress_penalty is not None:
                                                    return True

                                                if self.time_to_unsuppress is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.PathInformation']['meta_info']


                                        class AttributesAfterPolicyIn(object):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self.is_application_gateway_present = None
                                                self.is_as_path2_byte = None
                                                self.is_attr_set_present = None
                                                self.is_ribrnh_present = None
                                                self.is_rnh_present = None
                                                self.ribrnh_encap = None
                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self.ribrnh_mac = None
                                                self.ribrnh_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnhip_table = None
                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self.rnh_addr_len = None
                                                self.rnh_len = None
                                                self.rnh_type = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.vpn_distinguisher = None


                                            class CommonAttributes(object):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                            class AttrSet(object):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                            class RnhAddr(object):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None
                                                    self.mac_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    if self.mac_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                            class RibrnhIp(object):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.attr_set is not None and self.attr_set._has_data():
                                                    return True

                                                if self.attribute_key_number is not None:
                                                    return True

                                                if self.attribute_reuse_id_config is not None:
                                                    return True

                                                if self.attribute_reuse_id_current is not None:
                                                    return True

                                                if self.attribute_reuse_id_keys is not None:
                                                    return True

                                                if self.attribute_reuse_id_max_id is not None:
                                                    return True

                                                if self.attribute_reuse_id_node is not None:
                                                    return True

                                                if self.attribute_reuse_id_recover_sec is not None:
                                                    return True

                                                if self.common_attributes is not None and self.common_attributes._has_data():
                                                    return True

                                                if self.is_application_gateway_present is not None:
                                                    return True

                                                if self.is_as_path2_byte is not None:
                                                    return True

                                                if self.is_attr_set_present is not None:
                                                    return True

                                                if self.is_ribrnh_present is not None:
                                                    return True

                                                if self.is_rnh_present is not None:
                                                    return True

                                                if self.ribrnh_encap is not None:
                                                    return True

                                                if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                    return True

                                                if self.ribrnh_mac is not None:
                                                    return True

                                                if self.ribrnh_table is not None:
                                                    return True

                                                if self.ribrnh_vni is not None:
                                                    return True

                                                if self.ribrnhip_table is not None:
                                                    return True

                                                if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                    return True

                                                if self.rnh_addr_len is not None:
                                                    return True

                                                if self.rnh_len is not None:
                                                    return True

                                                if self.rnh_type is not None:
                                                    return True

                                                if self.set_aigp_inbound_igp is not None:
                                                    return True

                                                if self.set_aigp_inbound_metric is not None:
                                                    return True

                                                if self.vpn_distinguisher is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath.AttributesAfterPolicyIn']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-process-instance-path'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                return True

                                            if self.label_fail is not None:
                                                return True

                                            if self.label_o_or_version is not None:
                                                return True

                                            if self.label_oor is not None:
                                                return True

                                            if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                return True

                                            if self.no_path is not None:
                                                return True

                                            if self.path_information is not None and self.path_information._has_data():
                                                return True

                                            if self.prefix_version is not None:
                                                return True

                                            if self.process_instance_id is not None:
                                                return True

                                            if self.route_distinguisher is not None:
                                                return True

                                            if self.source_route_distinguisher is not None:
                                                return True

                                            if self.source_vrf_name is not None:
                                                return True

                                            if self.srcaf_name is not None:
                                                return True

                                            if self.vrf_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActiveProcessInstancePath']['meta_info']


                                    class LocalPathElement(object):
                                        """
                                        Local path element list
                                        
                                        .. attribute:: is_perm_path_pelem
                                        
                                        	Pelem for permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: nhte_tunnel
                                        
                                        	NH TE tunnel information
                                        	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.NhteTunnel>`
                                        
                                        .. attribute:: pelem_flags
                                        
                                        	Flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_gw_metric
                                        
                                        	Gateway metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_addpath_table_attr_version
                                        
                                        	No\-addpath Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_bestpath_table_attr_version
                                        
                                        	No\-bestpath Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_flags
                                        
                                        	Path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: pelem_path_id
                                        
                                        	Local Path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_neighbor_addr
                                        
                                        	Path neighbor address
                                        	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr>`
                                        
                                        .. attribute:: pelem_path_nexthop
                                        
                                        	Path nexthop address
                                        	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop>`
                                        
                                        .. attribute:: pelem_path_peer_path_id
                                        
                                        	Path peer path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_table_attr_version
                                        
                                        	Path Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_table_attr_version
                                        
                                        	Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_version
                                        
                                        	Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.is_perm_path_pelem = None
                                            self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.NhteTunnel()
                                            self.nhte_tunnel.parent = self
                                            self.pelem_flags = None
                                            self.pelem_gw_metric = None
                                            self.pelem_no_addpath_table_attr_version = None
                                            self.pelem_no_bestpath_table_attr_version = None
                                            self.pelem_path_flags = None
                                            self.pelem_path_id = None
                                            self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr()
                                            self.pelem_path_neighbor_addr.parent = self
                                            self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop()
                                            self.pelem_path_nexthop.parent = self
                                            self.pelem_path_peer_path_id = None
                                            self.pelem_path_table_attr_version = None
                                            self.pelem_table_attr_version = None
                                            self.pelem_version = None


                                        class PelemPathNexthop(object):
                                            """
                                            Path nexthop address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-nexthop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNexthop']['meta_info']


                                        class NhteTunnel(object):
                                            """
                                            NH TE tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_te_tunnel
                                            
                                            	NH TE Tunnel info is present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last rib update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	tunnel name
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	tunnel type
                                            	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.binding_label = None
                                                self.has_te_tunnel = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.is_tunnel_up = None
                                                self.last_tunnel_update = None
                                                self.tunnel_if_handle = None
                                                self.tunnel_name = None
                                                self.tunnel_type = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_v6_required = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.binding_label is not None:
                                                    return True

                                                if self.has_te_tunnel is not None:
                                                    return True

                                                if self.is_tunnel_info_stale is not None:
                                                    return True

                                                if self.is_tunnel_registered is not None:
                                                    return True

                                                if self.is_tunnel_up is not None:
                                                    return True

                                                if self.last_tunnel_update is not None:
                                                    return True

                                                if self.tunnel_if_handle is not None:
                                                    return True

                                                if self.tunnel_name is not None:
                                                    return True

                                                if self.tunnel_type is not None:
                                                    return True

                                                if self.tunnel_v6_enabled is not None:
                                                    return True

                                                if self.tunnel_v6_required is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.NhteTunnel']['meta_info']


                                        class PelemPathNeighborAddr(object):
                                            """
                                            Path neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-neighbor-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement.PelemPathNeighborAddr']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-path-element'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.is_perm_path_pelem is not None:
                                                return True

                                            if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                return True

                                            if self.pelem_flags is not None:
                                                return True

                                            if self.pelem_gw_metric is not None:
                                                return True

                                            if self.pelem_no_addpath_table_attr_version is not None:
                                                return True

                                            if self.pelem_no_bestpath_table_attr_version is not None:
                                                return True

                                            if self.pelem_path_flags is not None:
                                                return True

                                            if self.pelem_path_id is not None:
                                                return True

                                            if self.pelem_path_neighbor_addr is not None and self.pelem_path_neighbor_addr._has_data():
                                                return True

                                            if self.pelem_path_nexthop is not None and self.pelem_path_nexthop._has_data():
                                                return True

                                            if self.pelem_path_peer_path_id is not None:
                                                return True

                                            if self.pelem_path_table_attr_version is not None:
                                                return True

                                            if self.pelem_table_attr_version is not None:
                                                return True

                                            if self.pelem_version is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.LocalPathElement']['meta_info']


                                    class ActivePathElement(object):
                                        """
                                        Path element list received from Active inst
                                        
                                        .. attribute:: is_perm_path_pelem
                                        
                                        	Pelem for permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: nhte_tunnel
                                        
                                        	NH TE tunnel information
                                        	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.NhteTunnel>`
                                        
                                        .. attribute:: pelem_flags
                                        
                                        	Flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_gw_metric
                                        
                                        	Gateway metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_addpath_table_attr_version
                                        
                                        	No\-addpath Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_bestpath_table_attr_version
                                        
                                        	No\-bestpath Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_flags
                                        
                                        	Path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: pelem_path_id
                                        
                                        	Local Path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_neighbor_addr
                                        
                                        	Path neighbor address
                                        	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr>`
                                        
                                        .. attribute:: pelem_path_nexthop
                                        
                                        	Path nexthop address
                                        	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop>`
                                        
                                        .. attribute:: pelem_path_peer_path_id
                                        
                                        	Path peer path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_table_attr_version
                                        
                                        	Path Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_table_attr_version
                                        
                                        	Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_version
                                        
                                        	Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.is_perm_path_pelem = None
                                            self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.NhteTunnel()
                                            self.nhte_tunnel.parent = self
                                            self.pelem_flags = None
                                            self.pelem_gw_metric = None
                                            self.pelem_no_addpath_table_attr_version = None
                                            self.pelem_no_bestpath_table_attr_version = None
                                            self.pelem_path_flags = None
                                            self.pelem_path_id = None
                                            self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr()
                                            self.pelem_path_neighbor_addr.parent = self
                                            self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop()
                                            self.pelem_path_nexthop.parent = self
                                            self.pelem_path_peer_path_id = None
                                            self.pelem_path_table_attr_version = None
                                            self.pelem_table_attr_version = None
                                            self.pelem_version = None


                                        class PelemPathNexthop(object):
                                            """
                                            Path nexthop address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-nexthop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNexthop']['meta_info']


                                        class NhteTunnel(object):
                                            """
                                            NH TE tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_te_tunnel
                                            
                                            	NH TE Tunnel info is present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last rib update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	tunnel name
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	tunnel type
                                            	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.binding_label = None
                                                self.has_te_tunnel = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.is_tunnel_up = None
                                                self.last_tunnel_update = None
                                                self.tunnel_if_handle = None
                                                self.tunnel_name = None
                                                self.tunnel_type = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_v6_required = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.binding_label is not None:
                                                    return True

                                                if self.has_te_tunnel is not None:
                                                    return True

                                                if self.is_tunnel_info_stale is not None:
                                                    return True

                                                if self.is_tunnel_registered is not None:
                                                    return True

                                                if self.is_tunnel_up is not None:
                                                    return True

                                                if self.last_tunnel_update is not None:
                                                    return True

                                                if self.tunnel_if_handle is not None:
                                                    return True

                                                if self.tunnel_name is not None:
                                                    return True

                                                if self.tunnel_type is not None:
                                                    return True

                                                if self.tunnel_v6_enabled is not None:
                                                    return True

                                                if self.tunnel_v6_required is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.NhteTunnel']['meta_info']


                                        class PelemPathNeighborAddr(object):
                                            """
                                            Path neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-neighbor-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement.PelemPathNeighborAddr']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-path-element'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.is_perm_path_pelem is not None:
                                                return True

                                            if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                return True

                                            if self.pelem_flags is not None:
                                                return True

                                            if self.pelem_gw_metric is not None:
                                                return True

                                            if self.pelem_no_addpath_table_attr_version is not None:
                                                return True

                                            if self.pelem_no_bestpath_table_attr_version is not None:
                                                return True

                                            if self.pelem_path_flags is not None:
                                                return True

                                            if self.pelem_path_id is not None:
                                                return True

                                            if self.pelem_path_neighbor_addr is not None and self.pelem_path_neighbor_addr._has_data():
                                                return True

                                            if self.pelem_path_nexthop is not None and self.pelem_path_nexthop._has_data():
                                                return True

                                            if self.pelem_path_peer_path_id is not None:
                                                return True

                                            if self.pelem_path_table_attr_version is not None:
                                                return True

                                            if self.pelem_table_attr_version is not None:
                                                return True

                                            if self.pelem_version is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix.ActivePathElement']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-prefix'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.active_path_element is not None:
                                            for child_ref in self.active_path_element:
                                                if child_ref._has_data():
                                                    return True

                                        if self.active_process_instance_path is not None:
                                            for child_ref in self.active_process_instance_path:
                                                if child_ref._has_data():
                                                    return True

                                        if self.add_path_orr_bitfield is not None:
                                            for child_ref in self.add_path_orr_bitfield:
                                                if child_ref._has_data():
                                                    return True

                                        if self.advertisedto_pe is not None:
                                            return True

                                        if self.af_name is not None:
                                            return True

                                        if self.best_path_orr_bitfield is not None:
                                            for child_ref in self.best_path_orr_bitfield:
                                                if child_ref._has_data():
                                                    return True

                                        if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                            return True

                                        if self.bit is not None:
                                            return True

                                        if self.flags is not None:
                                            return True

                                        if self.gateway_array is not None:
                                            return True

                                        if self.has_inconsistent_paths is not None:
                                            return True

                                        if self.has_lbl_retained is not None:
                                            return True

                                        if self.has_local_label is not None:
                                            return True

                                        if self.is_net_aggregation_suppressed is not None:
                                            return True

                                        if self.is_net_ldp_signaled is not None:
                                            return True

                                        if self.is_permanent_network is not None:
                                            return True

                                        if self.local_path_element is not None:
                                            for child_ref in self.local_path_element:
                                                if child_ref._has_data():
                                                    return True

                                        if self.local_peers_advertised_to is not None:
                                            for child_ref in self.local_peers_advertised_to:
                                                if child_ref._has_data():
                                                    return True

                                        if self.local_process_instance_path is not None:
                                            for child_ref in self.local_process_instance_path:
                                                if child_ref._has_data():
                                                    return True

                                        if self.net_backup_available is not None:
                                            return True

                                        if self.net_backup_label_rewrite_available is not None:
                                            return True

                                        if self.net_eibgp_multipath is not None:
                                            return True

                                        if self.net_extended_flags is not None:
                                            return True

                                        if self.net_flags is not None:
                                            return True

                                        if self.net_local_label is not None:
                                            return True

                                        if self.net_local_label_rewrite is not None:
                                            return True

                                        if self.net_local_label_srgb is not None:
                                            return True

                                        if self.net_multipath is not None:
                                            return True

                                        if self.network_prefix is not None:
                                            return True

                                        if self.num_of_path is not None:
                                            return True

                                        if self.pe_peers_advertised_to is not None:
                                            for child_ref in self.pe_peers_advertised_to:
                                                if child_ref._has_data():
                                                    return True

                                        if self.process_instance_id is not None:
                                            return True

                                        if self.rd is not None:
                                            return True

                                        if self.resilient_nexthop_set is not None:
                                            return True

                                        if self.rib_failed is not None:
                                            return True

                                        if self.route_distinguisher is not None:
                                            return True

                                        if self.table_brib_version is not None:
                                            return True

                                        if self.table_version is not None:
                                            return True

                                        if self.version is not None:
                                            return True

                                        if self.version_age is not None and self.version_age._has_data():
                                            return True

                                        if self.version_timestamp is not None and self.version_timestamp._has_data():
                                            return True

                                        if self.vrf_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes.NetworkPrefix']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-prefixes'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.network_prefix is not None:
                                        for child_ref in self.network_prefix:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkPrefixes']['meta_info']


                            class AdvertisedPathXr(object):
                                """
                                The BGP Advertised path table (bestpath)
                                
                                .. attribute:: advertised_path
                                
                                	A BGP Advertised path table entry (bestpath)
                                	**type**\: list of    :py:class:`AdvertisedPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.advertised_path = YList()
                                    self.advertised_path.parent = self
                                    self.advertised_path.name = 'advertised_path'


                                class AdvertisedPath(object):
                                    """
                                    A BGP Advertised path table entry (bestpath)
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: attributes_after_policy_in
                                    
                                    	Attributes after inbound policy applied
                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn>`
                                    
                                    .. attribute:: label_fail
                                    
                                    	LSD label allocation failed 
                                    	**type**\:  bool
                                    
                                    .. attribute:: label_o_or_version
                                    
                                    	Label Version when OOR happens
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_oor
                                    
                                    	LSD label space is exhausted
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr>`
                                    
                                    .. attribute:: network
                                    
                                    	Network Prefix in Hex format
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: no_path
                                    
                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_information
                                    
                                    	Path information
                                    	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: prefix_version
                                    
                                    	Version of BGP Prefix Table
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_route_distinguisher
                                    
                                    	Source Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_vrf_name
                                    
                                    	Name of the source VRF
                                    	**type**\:  str
                                    
                                    .. attribute:: srcaf_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn()
                                        self.attributes_after_policy_in.parent = self
                                        self.label_fail = None
                                        self.label_o_or_version = None
                                        self.label_oor = None
                                        self.neighbor_address = None
                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr()
                                        self.neighbor_address_xr.parent = self
                                        self.network = None
                                        self.no_path = None
                                        self.path_information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation()
                                        self.path_information.parent = self
                                        self.prefix_length = None
                                        self.prefix_version = None
                                        self.process_instance_id = None
                                        self.rd = None
                                        self.route_distinguisher = None
                                        self.source_route_distinguisher = None
                                        self.source_vrf_name = None
                                        self.srcaf_name = None
                                        self.vrf_name = None


                                    class NeighborAddressXr(object):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.NeighborAddressXr']['meta_info']


                                    class PathInformation(object):
                                        """
                                        Path information
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_own_self_originated_p_ath
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\:  bool
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield>`
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner>`
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix>`
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity>`
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\:  bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\:  bool
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr>`
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_esi
                                        
                                        	Path has EVPN ESI
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_rcvd_label
                                        
                                        	Path has received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\:  bool
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebg_ps
                                        
                                        	Not advertised to EBGPs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2VpnCircuitStatusValue>`
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2VpnEvpnEsi>`
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr>`
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue>`
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress>`
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop>`
                                        
                                        .. attribute:: nhte_tunnel
                                        
                                        	NH TE tunnel information
                                        	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhteTunnel>`
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\:  bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.accept_own_path = None
                                            self.accept_own_self_originated_p_ath = None
                                            self.add_path_orr_bitfield = YList()
                                            self.add_path_orr_bitfield.parent = self
                                            self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                            self.advertisedto_pe = None
                                            self.aigp_metric = None
                                            self.best_path_comp_stage = None
                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self.best_path_id = None
                                            self.best_path_id_comp_winner = None
                                            self.best_path_orr_bitfield = YList()
                                            self.best_path_orr_bitfield.parent = self
                                            self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self.dampen_penalty = None
                                            self.extended_community = YList()
                                            self.extended_community.parent = self
                                            self.extended_community.name = 'extended_community'
                                            self.fspec_invalid_path = None
                                            self.graceful_shutdown = None
                                            self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr()
                                            self.gw_addr.parent = self
                                            self.halflife_time = None
                                            self.has_esi = None
                                            self.has_gw_addr = None
                                            self.has_local_net_label = None
                                            self.has_mdt_group_addr = None
                                            self.has_mvpn_extcomm = None
                                            self.has_mvpn_nbr_addr = None
                                            self.has_mvpn_nexthop_addr = None
                                            self.has_mvpn_pmsi = None
                                            self.has_rcvd_label = None
                                            self.has_second_label = None
                                            self.ibgp_signaled_validity = None
                                            self.igp_metric = None
                                            self.is_aggregation_suppressed = None
                                            self.is_as_best = None
                                            self.is_best_path = None
                                            self.is_import_dampened = None
                                            self.is_import_suspect = None
                                            self.is_internal_path = None
                                            self.is_partial_best = None
                                            self.is_path_additional_path = None
                                            self.is_path_advertised_local_as_only = None
                                            self.is_path_af_install_eligible = None
                                            self.is_path_backup = None
                                            self.is_path_backup_protect_multipath = None
                                            self.is_path_best_external = None
                                            self.is_path_damped = None
                                            self.is_path_from_confederation_peer = None
                                            self.is_path_from_network_command = None
                                            self.is_path_from_redistribute_command = None
                                            self.is_path_from_route_reflector = None
                                            self.is_path_history_held = None
                                            self.is_path_imp_candidate = None
                                            self.is_path_imported = None
                                            self.is_path_local_aggregate = None
                                            self.is_path_locally_sourced = None
                                            self.is_path_long_lived_stale = None
                                            self.is_path_multipath = None
                                            self.is_path_nexthop_discarded = None
                                            self.is_path_not_advertised = None
                                            self.is_path_not_advertised_to_ebg_ps = None
                                            self.is_path_received_only = None
                                            self.is_path_reoriginated = None
                                            self.is_path_reoriginated_stitching = None
                                            self.is_path_stale = None
                                            self.is_path_synced_with_igp = None
                                            self.is_path_valid = None
                                            self.is_path_vpn_only = None
                                            self.is_permanent_path = None
                                            self.is_received_path_not_modified = None
                                            self.is_spkr_as_best = None
                                            self.l2vpn_circuit_status_value = YList()
                                            self.l2vpn_circuit_status_value.parent = self
                                            self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                            self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2VpnEvpnEsi()
                                            self.l2vpn_evpn_esi.parent = self
                                            self.l2vpn_size = None
                                            self.labeled_unicast_safi_path = None
                                            self.local_label = None
                                            self.local_nh = None
                                            self.local_path_id = None
                                            self.local_peers_advertised_to = YList()
                                            self.local_peers_advertised_to.parent = self
                                            self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                            self.maximum_suppress_time = None
                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self.mvpn_path_flags = None
                                            self.mvpn_pmsi_flags = None
                                            self.mvpn_pmsi_label = None
                                            self.mvpn_pmsi_type = None
                                            self.mvpn_pmsi_value = YList()
                                            self.mvpn_pmsi_value.parent = self
                                            self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                            self.mvpn_sfs_path = None
                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self.neighbor_router_id = None
                                            self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop()
                                            self.next_hop.parent = self
                                            self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhteTunnel()
                                            self.nhte_tunnel.parent = self
                                            self.path_flags = None
                                            self.path_flap_count = None
                                            self.path_import_flags = None
                                            self.path_rt_set_id = None
                                            self.path_rt_set_route_count = None
                                            self.path_table_version = None
                                            self.path_weight = None
                                            self.pe_peers_advertised_to = YList()
                                            self.pe_peers_advertised_to.parent = self
                                            self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                            self.rcvd_label = None
                                            self.rcvd_path_id = None
                                            self.reuse_value = None
                                            self.rib_failed = None
                                            self.route_type = None
                                            self.rpki_origin_as_validation_disabled = None
                                            self.rt_set_limit_enabled = None
                                            self.second_label = None
                                            self.seconds_since_first_flap = None
                                            self.show_rpki_origin_as_validity = None
                                            self.sn_rpki_origin_as_validity = None
                                            self.suppress_penalty = None
                                            self.time_to_unsuppress = None


                                        class BgpPrefix(object):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self.prefix_length = None


                                            class Prefix(object):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.prefix is not None and self.prefix._has_data():
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix']['meta_info']


                                        class NeighborAddress(object):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress']['meta_info']


                                        class NextHop(object):
                                            """
                                            Next hop
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop']['meta_info']


                                        class NhteTunnel(object):
                                            """
                                            NH TE tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_te_tunnel
                                            
                                            	NH TE Tunnel info is present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last rib update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	tunnel name
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	tunnel type
                                            	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.binding_label = None
                                                self.has_te_tunnel = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.is_tunnel_up = None
                                                self.last_tunnel_update = None
                                                self.tunnel_if_handle = None
                                                self.tunnel_name = None
                                                self.tunnel_type = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_v6_required = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.binding_label is not None:
                                                    return True

                                                if self.has_te_tunnel is not None:
                                                    return True

                                                if self.is_tunnel_info_stale is not None:
                                                    return True

                                                if self.is_tunnel_registered is not None:
                                                    return True

                                                if self.is_tunnel_up is not None:
                                                    return True

                                                if self.last_tunnel_update is not None:
                                                    return True

                                                if self.tunnel_if_handle is not None:
                                                    return True

                                                if self.tunnel_name is not None:
                                                    return True

                                                if self.tunnel_type is not None:
                                                    return True

                                                if self.tunnel_v6_enabled is not None:
                                                    return True

                                                if self.tunnel_v6_required is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhteTunnel']['meta_info']


                                        class MdtGroupAddr(object):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr']['meta_info']


                                        class L2VpnEvpnEsi(object):
                                            """
                                            L2VPN EVPN ESI
                                            
                                            .. attribute:: esi
                                            
                                            	esi
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.esi = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.esi is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2VpnEvpnEsi']['meta_info']


                                        class GwAddr(object):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.len = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.len is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr']['meta_info']


                                        class BestPathCompWinner(object):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner']['meta_info']


                                        class MvpnNbrAddr(object):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr']['meta_info']


                                        class MvpnNexthopAddr(object):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr']['meta_info']


                                        class L2VpnCircuitStatusValue(object):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                        class MvpnPmsiValue(object):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue']['meta_info']


                                        class ExtendedCommunity(object):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity']['meta_info']


                                        class LocalPeersAdvertisedTo(object):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                        class PePeersAdvertisedTo(object):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo']['meta_info']


                                        class BestPathOrrBitfield(object):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield']['meta_info']


                                        class AddPathOrrBitfield(object):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.accept_own_path is not None:
                                                return True

                                            if self.accept_own_self_originated_p_ath is not None:
                                                return True

                                            if self.add_path_orr_bitfield is not None:
                                                for child_ref in self.add_path_orr_bitfield:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.advertisedto_pe is not None:
                                                return True

                                            if self.aigp_metric is not None:
                                                return True

                                            if self.best_path_comp_stage is not None:
                                                return True

                                            if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                return True

                                            if self.best_path_id is not None:
                                                return True

                                            if self.best_path_id_comp_winner is not None:
                                                return True

                                            if self.best_path_orr_bitfield is not None:
                                                for child_ref in self.best_path_orr_bitfield:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                return True

                                            if self.dampen_penalty is not None:
                                                return True

                                            if self.extended_community is not None:
                                                for child_ref in self.extended_community:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.fspec_invalid_path is not None:
                                                return True

                                            if self.graceful_shutdown is not None:
                                                return True

                                            if self.gw_addr is not None and self.gw_addr._has_data():
                                                return True

                                            if self.halflife_time is not None:
                                                return True

                                            if self.has_esi is not None:
                                                return True

                                            if self.has_gw_addr is not None:
                                                return True

                                            if self.has_local_net_label is not None:
                                                return True

                                            if self.has_mdt_group_addr is not None:
                                                return True

                                            if self.has_mvpn_extcomm is not None:
                                                return True

                                            if self.has_mvpn_nbr_addr is not None:
                                                return True

                                            if self.has_mvpn_nexthop_addr is not None:
                                                return True

                                            if self.has_mvpn_pmsi is not None:
                                                return True

                                            if self.has_rcvd_label is not None:
                                                return True

                                            if self.has_second_label is not None:
                                                return True

                                            if self.ibgp_signaled_validity is not None:
                                                return True

                                            if self.igp_metric is not None:
                                                return True

                                            if self.is_aggregation_suppressed is not None:
                                                return True

                                            if self.is_as_best is not None:
                                                return True

                                            if self.is_best_path is not None:
                                                return True

                                            if self.is_import_dampened is not None:
                                                return True

                                            if self.is_import_suspect is not None:
                                                return True

                                            if self.is_internal_path is not None:
                                                return True

                                            if self.is_partial_best is not None:
                                                return True

                                            if self.is_path_additional_path is not None:
                                                return True

                                            if self.is_path_advertised_local_as_only is not None:
                                                return True

                                            if self.is_path_af_install_eligible is not None:
                                                return True

                                            if self.is_path_backup is not None:
                                                return True

                                            if self.is_path_backup_protect_multipath is not None:
                                                return True

                                            if self.is_path_best_external is not None:
                                                return True

                                            if self.is_path_damped is not None:
                                                return True

                                            if self.is_path_from_confederation_peer is not None:
                                                return True

                                            if self.is_path_from_network_command is not None:
                                                return True

                                            if self.is_path_from_redistribute_command is not None:
                                                return True

                                            if self.is_path_from_route_reflector is not None:
                                                return True

                                            if self.is_path_history_held is not None:
                                                return True

                                            if self.is_path_imp_candidate is not None:
                                                return True

                                            if self.is_path_imported is not None:
                                                return True

                                            if self.is_path_local_aggregate is not None:
                                                return True

                                            if self.is_path_locally_sourced is not None:
                                                return True

                                            if self.is_path_long_lived_stale is not None:
                                                return True

                                            if self.is_path_multipath is not None:
                                                return True

                                            if self.is_path_nexthop_discarded is not None:
                                                return True

                                            if self.is_path_not_advertised is not None:
                                                return True

                                            if self.is_path_not_advertised_to_ebg_ps is not None:
                                                return True

                                            if self.is_path_received_only is not None:
                                                return True

                                            if self.is_path_reoriginated is not None:
                                                return True

                                            if self.is_path_reoriginated_stitching is not None:
                                                return True

                                            if self.is_path_stale is not None:
                                                return True

                                            if self.is_path_synced_with_igp is not None:
                                                return True

                                            if self.is_path_valid is not None:
                                                return True

                                            if self.is_path_vpn_only is not None:
                                                return True

                                            if self.is_permanent_path is not None:
                                                return True

                                            if self.is_received_path_not_modified is not None:
                                                return True

                                            if self.is_spkr_as_best is not None:
                                                return True

                                            if self.l2vpn_circuit_status_value is not None:
                                                for child_ref in self.l2vpn_circuit_status_value:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                return True

                                            if self.l2vpn_size is not None:
                                                return True

                                            if self.labeled_unicast_safi_path is not None:
                                                return True

                                            if self.local_label is not None:
                                                return True

                                            if self.local_nh is not None:
                                                return True

                                            if self.local_path_id is not None:
                                                return True

                                            if self.local_peers_advertised_to is not None:
                                                for child_ref in self.local_peers_advertised_to:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.maximum_suppress_time is not None:
                                                return True

                                            if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                return True

                                            if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                return True

                                            if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                return True

                                            if self.mvpn_path_flags is not None:
                                                return True

                                            if self.mvpn_pmsi_flags is not None:
                                                return True

                                            if self.mvpn_pmsi_label is not None:
                                                return True

                                            if self.mvpn_pmsi_type is not None:
                                                return True

                                            if self.mvpn_pmsi_value is not None:
                                                for child_ref in self.mvpn_pmsi_value:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.mvpn_sfs_path is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            if self.neighbor_router_id is not None:
                                                return True

                                            if self.next_hop is not None and self.next_hop._has_data():
                                                return True

                                            if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                return True

                                            if self.path_flags is not None:
                                                return True

                                            if self.path_flap_count is not None:
                                                return True

                                            if self.path_import_flags is not None:
                                                return True

                                            if self.path_rt_set_id is not None:
                                                return True

                                            if self.path_rt_set_route_count is not None:
                                                return True

                                            if self.path_table_version is not None:
                                                return True

                                            if self.path_weight is not None:
                                                return True

                                            if self.pe_peers_advertised_to is not None:
                                                for child_ref in self.pe_peers_advertised_to:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.rcvd_label is not None:
                                                return True

                                            if self.rcvd_path_id is not None:
                                                return True

                                            if self.reuse_value is not None:
                                                return True

                                            if self.rib_failed is not None:
                                                return True

                                            if self.route_type is not None:
                                                return True

                                            if self.rpki_origin_as_validation_disabled is not None:
                                                return True

                                            if self.rt_set_limit_enabled is not None:
                                                return True

                                            if self.second_label is not None:
                                                return True

                                            if self.seconds_since_first_flap is not None:
                                                return True

                                            if self.show_rpki_origin_as_validity is not None:
                                                return True

                                            if self.sn_rpki_origin_as_validity is not None:
                                                return True

                                            if self.suppress_penalty is not None:
                                                return True

                                            if self.time_to_unsuppress is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation']['meta_info']


                                    class AttributesAfterPolicyIn(object):
                                        """
                                        Attributes after inbound policy applied
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet>`
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes>`
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp>`
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr>`
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\:  bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet()
                                            self.attr_set.parent = self
                                            self.attribute_key_number = None
                                            self.attribute_reuse_id_config = None
                                            self.attribute_reuse_id_current = None
                                            self.attribute_reuse_id_keys = None
                                            self.attribute_reuse_id_max_id = None
                                            self.attribute_reuse_id_node = None
                                            self.attribute_reuse_id_recover_sec = None
                                            self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self.is_application_gateway_present = None
                                            self.is_as_path2_byte = None
                                            self.is_attr_set_present = None
                                            self.is_ribrnh_present = None
                                            self.is_rnh_present = None
                                            self.ribrnh_encap = None
                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self.ribrnh_mac = None
                                            self.ribrnh_table = None
                                            self.ribrnh_vni = None
                                            self.ribrnhip_table = None
                                            self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self.rnh_addr_len = None
                                            self.rnh_len = None
                                            self.rnh_type = None
                                            self.set_aigp_inbound_igp = None
                                            self.set_aigp_inbound_metric = None
                                            self.vpn_distinguisher = None


                                        class CommonAttributes(object):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_encap_present
                                            
                                            	Tunnel Encap attribute present 
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_policy_allocated_binding_sid
                                            
                                            	SR Policy allocated Binding sid by the router
                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                            
                                            .. attribute:: sr_policy_binding_sid
                                            
                                            	SR Policy Binding sid
                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                            
                                            .. attribute:: sr_policy_explicit_path
                                            
                                            	SR Policy Explicit paths
                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                            
                                            .. attribute:: sr_policy_preference
                                            
                                            	SR Policy Preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_tunnel_request_state
                                            
                                            	SR Tunnel Request State
                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                            
                                            .. attribute:: sr_tunnel_state
                                            
                                            	SR Tunnel State
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap_type
                                            
                                            	Tunnel Encap Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.aggregator_address = None
                                                self.aggregator_as = None
                                                self.aigp_metric_value = None
                                                self.as_path = None
                                                self.cluster = YList()
                                                self.cluster.parent = self
                                                self.cluster.name = 'cluster'
                                                self.community = YList()
                                                self.community.parent = self
                                                self.community.name = 'community'
                                                self.connector_type = None
                                                self.connector_value = YList()
                                                self.connector_value.parent = self
                                                self.connector_value.name = 'connector_value'
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.extended_community_flags = None
                                                self.is_aggregator_present = None
                                                self.is_aigp_present = None
                                                self.is_as_path_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_community_present = None
                                                self.is_connector_present = None
                                                self.is_extended_community_present = None
                                                self.is_label_index_present = None
                                                self.is_local_pref_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_metric_present = None
                                                self.is_origin_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_ssa_present = None
                                                self.is_tunnel_encap_present = None
                                                self.l2tpv3_cookie = YList()
                                                self.l2tpv3_cookie.parent = self
                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                self.l2tpv3_session_id = None
                                                self.label_index_attr = YList()
                                                self.label_index_attr.parent = self
                                                self.label_index_attr.name = 'label_index_attr'
                                                self.local_preference = None
                                                self.ls_attr = YList()
                                                self.ls_attr.parent = self
                                                self.ls_attr.name = 'ls_attr'
                                                self.metric = None
                                                self.neighbor_as = None
                                                self.origin = None
                                                self.originator = None
                                                self.pe_distinguisher_label = YList()
                                                self.pe_distinguisher_label.parent = self
                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.pmsi_type = None
                                                self.pmsi_value = YList()
                                                self.pmsi_value.parent = self
                                                self.pmsi_value.name = 'pmsi_value'
                                                self.ppm_pvalue = None
                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                self.sr_policy_allocated_binding_sid.parent = self
                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                self.sr_policy_binding_sid.parent = self
                                                self.sr_policy_explicit_path = YList()
                                                self.sr_policy_explicit_path.parent = self
                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                self.sr_policy_preference = None
                                                self.sr_tunnel_request_state = None
                                                self.sr_tunnel_state = None
                                                self.tunnel_encap_type = None
                                                self.unknown_attribute = YList()
                                                self.unknown_attribute.parent = self
                                                self.unknown_attribute.name = 'unknown_attribute'


                                            class SrPolicyBindingSid(object):
                                                """
                                                SR Policy Binding sid
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                            class SrPolicyAllocatedBindingSid(object):
                                                """
                                                SR Policy allocated Binding sid by the router
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                            class Community(object):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                            class UnknownAttribute(object):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                            class Cluster(object):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                            class L2Tpv3Cookie(object):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                            class ConnectorValue(object):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                            class PmsiValue(object):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                            class LsAttr(object):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                            class LabelIndexAttr(object):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                            class PeDistinguisherLabel(object):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.label = None
                                                    self.pe_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.label is not None:
                                                        return True

                                                    if self.pe_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                            class SrPolicyExplicitPath(object):
                                                """
                                                SR Policy Explicit paths
                                                
                                                .. attribute:: sid
                                                
                                                	Sidlist for explicit path
                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                
                                                .. attribute:: weight
                                                
                                                	Weight of explicit path
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.sid = YList()
                                                    self.sid.parent = self
                                                    self.sid.name = 'sid'
                                                    self.weight = None


                                                class Sid(object):
                                                    """
                                                    Sidlist for explicit path
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IP Address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label sid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Sid Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4 is not None:
                                                            return True

                                                        if self.ipv6 is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.sid is not None:
                                                        for child_ref in self.sid:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.weight is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.aggregator_address is not None:
                                                    return True

                                                if self.aggregator_as is not None:
                                                    return True

                                                if self.aigp_metric_value is not None:
                                                    return True

                                                if self.as_path is not None:
                                                    return True

                                                if self.cluster is not None:
                                                    for child_ref in self.cluster:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.community is not None:
                                                    for child_ref in self.community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.connector_type is not None:
                                                    return True

                                                if self.connector_value is not None:
                                                    for child_ref in self.connector_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community_flags is not None:
                                                    return True

                                                if self.is_aggregator_present is not None:
                                                    return True

                                                if self.is_aigp_present is not None:
                                                    return True

                                                if self.is_as_path_present is not None:
                                                    return True

                                                if self.is_atomic_aggregate_present is not None:
                                                    return True

                                                if self.is_community_present is not None:
                                                    return True

                                                if self.is_connector_present is not None:
                                                    return True

                                                if self.is_extended_community_present is not None:
                                                    return True

                                                if self.is_label_index_present is not None:
                                                    return True

                                                if self.is_local_pref_present is not None:
                                                    return True

                                                if self.is_ls_attribute_present is not None:
                                                    return True

                                                if self.is_metric_present is not None:
                                                    return True

                                                if self.is_origin_present is not None:
                                                    return True

                                                if self.is_pe_distinguisher_label_present is not None:
                                                    return True

                                                if self.is_pmsi_present is not None:
                                                    return True

                                                if self.is_pppmp_present is not None:
                                                    return True

                                                if self.is_ssa_present is not None:
                                                    return True

                                                if self.is_tunnel_encap_present is not None:
                                                    return True

                                                if self.l2tpv3_cookie is not None:
                                                    for child_ref in self.l2tpv3_cookie:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2tpv3_session_id is not None:
                                                    return True

                                                if self.label_index_attr is not None:
                                                    for child_ref in self.label_index_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_preference is not None:
                                                    return True

                                                if self.ls_attr is not None:
                                                    for child_ref in self.ls_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.metric is not None:
                                                    return True

                                                if self.neighbor_as is not None:
                                                    return True

                                                if self.origin is not None:
                                                    return True

                                                if self.originator is not None:
                                                    return True

                                                if self.pe_distinguisher_label is not None:
                                                    for child_ref in self.pe_distinguisher_label:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.pmsi_flags is not None:
                                                    return True

                                                if self.pmsi_label is not None:
                                                    return True

                                                if self.pmsi_type is not None:
                                                    return True

                                                if self.pmsi_value is not None:
                                                    for child_ref in self.pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.ppm_pvalue is not None:
                                                    return True

                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_explicit_path is not None:
                                                    for child_ref in self.sr_policy_explicit_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.sr_policy_preference is not None:
                                                    return True

                                                if self.sr_tunnel_request_state is not None:
                                                    return True

                                                if self.sr_tunnel_state is not None:
                                                    return True

                                                if self.tunnel_encap_type is not None:
                                                    return True

                                                if self.unknown_attribute is not None:
                                                    for child_ref in self.unknown_attribute:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                        class AttrSet(object):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_encap_present
                                            
                                            	Tunnel Encap attribute present 
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_policy_allocated_binding_sid
                                            
                                            	SR Policy allocated Binding sid by the router
                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                            
                                            .. attribute:: sr_policy_binding_sid
                                            
                                            	SR Policy Binding sid
                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                            
                                            .. attribute:: sr_policy_explicit_path
                                            
                                            	SR Policy Explicit paths
                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                            
                                            .. attribute:: sr_policy_preference
                                            
                                            	SR Policy Preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_tunnel_request_state
                                            
                                            	SR Tunnel Request State
                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                            
                                            .. attribute:: sr_tunnel_state
                                            
                                            	SR Tunnel State
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap_type
                                            
                                            	Tunnel Encap Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.aggregator_address = None
                                                self.aggregator_as = None
                                                self.aigp_metric_value = None
                                                self.as_path = None
                                                self.cluster = YList()
                                                self.cluster.parent = self
                                                self.cluster.name = 'cluster'
                                                self.community = YList()
                                                self.community.parent = self
                                                self.community.name = 'community'
                                                self.connector_type = None
                                                self.connector_value = YList()
                                                self.connector_value.parent = self
                                                self.connector_value.name = 'connector_value'
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.extended_community_flags = None
                                                self.is_aggregator_present = None
                                                self.is_aigp_present = None
                                                self.is_as_path_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_community_present = None
                                                self.is_connector_present = None
                                                self.is_extended_community_present = None
                                                self.is_label_index_present = None
                                                self.is_local_pref_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_metric_present = None
                                                self.is_origin_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_ssa_present = None
                                                self.is_tunnel_encap_present = None
                                                self.l2tpv3_cookie = YList()
                                                self.l2tpv3_cookie.parent = self
                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                self.l2tpv3_session_id = None
                                                self.label_index_attr = YList()
                                                self.label_index_attr.parent = self
                                                self.label_index_attr.name = 'label_index_attr'
                                                self.local_preference = None
                                                self.ls_attr = YList()
                                                self.ls_attr.parent = self
                                                self.ls_attr.name = 'ls_attr'
                                                self.metric = None
                                                self.neighbor_as = None
                                                self.origin = None
                                                self.originator = None
                                                self.pe_distinguisher_label = YList()
                                                self.pe_distinguisher_label.parent = self
                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.pmsi_type = None
                                                self.pmsi_value = YList()
                                                self.pmsi_value.parent = self
                                                self.pmsi_value.name = 'pmsi_value'
                                                self.ppm_pvalue = None
                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                self.sr_policy_allocated_binding_sid.parent = self
                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                self.sr_policy_binding_sid.parent = self
                                                self.sr_policy_explicit_path = YList()
                                                self.sr_policy_explicit_path.parent = self
                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                self.sr_policy_preference = None
                                                self.sr_tunnel_request_state = None
                                                self.sr_tunnel_state = None
                                                self.tunnel_encap_type = None
                                                self.unknown_attribute = YList()
                                                self.unknown_attribute.parent = self
                                                self.unknown_attribute.name = 'unknown_attribute'


                                            class SrPolicyBindingSid(object):
                                                """
                                                SR Policy Binding sid
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                            class SrPolicyAllocatedBindingSid(object):
                                                """
                                                SR Policy allocated Binding sid by the router
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                            class Community(object):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                            class UnknownAttribute(object):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                            class Cluster(object):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                            class L2Tpv3Cookie(object):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                            class ConnectorValue(object):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                            class PmsiValue(object):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                            class LsAttr(object):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                            class LabelIndexAttr(object):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                            class PeDistinguisherLabel(object):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.label = None
                                                    self.pe_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.label is not None:
                                                        return True

                                                    if self.pe_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                            class SrPolicyExplicitPath(object):
                                                """
                                                SR Policy Explicit paths
                                                
                                                .. attribute:: sid
                                                
                                                	Sidlist for explicit path
                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                
                                                .. attribute:: weight
                                                
                                                	Weight of explicit path
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.sid = YList()
                                                    self.sid.parent = self
                                                    self.sid.name = 'sid'
                                                    self.weight = None


                                                class Sid(object):
                                                    """
                                                    Sidlist for explicit path
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IP Address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label sid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Sid Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4 is not None:
                                                            return True

                                                        if self.ipv6 is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.sid is not None:
                                                        for child_ref in self.sid:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.weight is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.aggregator_address is not None:
                                                    return True

                                                if self.aggregator_as is not None:
                                                    return True

                                                if self.aigp_metric_value is not None:
                                                    return True

                                                if self.as_path is not None:
                                                    return True

                                                if self.cluster is not None:
                                                    for child_ref in self.cluster:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.community is not None:
                                                    for child_ref in self.community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.connector_type is not None:
                                                    return True

                                                if self.connector_value is not None:
                                                    for child_ref in self.connector_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community_flags is not None:
                                                    return True

                                                if self.is_aggregator_present is not None:
                                                    return True

                                                if self.is_aigp_present is not None:
                                                    return True

                                                if self.is_as_path_present is not None:
                                                    return True

                                                if self.is_atomic_aggregate_present is not None:
                                                    return True

                                                if self.is_community_present is not None:
                                                    return True

                                                if self.is_connector_present is not None:
                                                    return True

                                                if self.is_extended_community_present is not None:
                                                    return True

                                                if self.is_label_index_present is not None:
                                                    return True

                                                if self.is_local_pref_present is not None:
                                                    return True

                                                if self.is_ls_attribute_present is not None:
                                                    return True

                                                if self.is_metric_present is not None:
                                                    return True

                                                if self.is_origin_present is not None:
                                                    return True

                                                if self.is_pe_distinguisher_label_present is not None:
                                                    return True

                                                if self.is_pmsi_present is not None:
                                                    return True

                                                if self.is_pppmp_present is not None:
                                                    return True

                                                if self.is_ssa_present is not None:
                                                    return True

                                                if self.is_tunnel_encap_present is not None:
                                                    return True

                                                if self.l2tpv3_cookie is not None:
                                                    for child_ref in self.l2tpv3_cookie:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2tpv3_session_id is not None:
                                                    return True

                                                if self.label_index_attr is not None:
                                                    for child_ref in self.label_index_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_preference is not None:
                                                    return True

                                                if self.ls_attr is not None:
                                                    for child_ref in self.ls_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.metric is not None:
                                                    return True

                                                if self.neighbor_as is not None:
                                                    return True

                                                if self.origin is not None:
                                                    return True

                                                if self.originator is not None:
                                                    return True

                                                if self.pe_distinguisher_label is not None:
                                                    for child_ref in self.pe_distinguisher_label:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.pmsi_flags is not None:
                                                    return True

                                                if self.pmsi_label is not None:
                                                    return True

                                                if self.pmsi_type is not None:
                                                    return True

                                                if self.pmsi_value is not None:
                                                    for child_ref in self.pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.ppm_pvalue is not None:
                                                    return True

                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_explicit_path is not None:
                                                    for child_ref in self.sr_policy_explicit_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.sr_policy_preference is not None:
                                                    return True

                                                if self.sr_tunnel_request_state is not None:
                                                    return True

                                                if self.sr_tunnel_state is not None:
                                                    return True

                                                if self.tunnel_encap_type is not None:
                                                    return True

                                                if self.unknown_attribute is not None:
                                                    for child_ref in self.unknown_attribute:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                        class RnhAddr(object):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.len = None
                                                self.mac_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.len is not None:
                                                    return True

                                                if self.mac_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                        class RibrnhIp(object):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.attr_set is not None and self.attr_set._has_data():
                                                return True

                                            if self.attribute_key_number is not None:
                                                return True

                                            if self.attribute_reuse_id_config is not None:
                                                return True

                                            if self.attribute_reuse_id_current is not None:
                                                return True

                                            if self.attribute_reuse_id_keys is not None:
                                                return True

                                            if self.attribute_reuse_id_max_id is not None:
                                                return True

                                            if self.attribute_reuse_id_node is not None:
                                                return True

                                            if self.attribute_reuse_id_recover_sec is not None:
                                                return True

                                            if self.common_attributes is not None and self.common_attributes._has_data():
                                                return True

                                            if self.is_application_gateway_present is not None:
                                                return True

                                            if self.is_as_path2_byte is not None:
                                                return True

                                            if self.is_attr_set_present is not None:
                                                return True

                                            if self.is_ribrnh_present is not None:
                                                return True

                                            if self.is_rnh_present is not None:
                                                return True

                                            if self.ribrnh_encap is not None:
                                                return True

                                            if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                return True

                                            if self.ribrnh_mac is not None:
                                                return True

                                            if self.ribrnh_table is not None:
                                                return True

                                            if self.ribrnh_vni is not None:
                                                return True

                                            if self.ribrnhip_table is not None:
                                                return True

                                            if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                return True

                                            if self.rnh_addr_len is not None:
                                                return True

                                            if self.rnh_len is not None:
                                                return True

                                            if self.rnh_type is not None:
                                                return True

                                            if self.set_aigp_inbound_igp is not None:
                                                return True

                                            if self.set_aigp_inbound_metric is not None:
                                                return True

                                            if self.vpn_distinguisher is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertised-path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                            return True

                                        if self.label_fail is not None:
                                            return True

                                        if self.label_o_or_version is not None:
                                            return True

                                        if self.label_oor is not None:
                                            return True

                                        if self.neighbor_address is not None:
                                            return True

                                        if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                            return True

                                        if self.network is not None:
                                            return True

                                        if self.no_path is not None:
                                            return True

                                        if self.path_information is not None and self.path_information._has_data():
                                            return True

                                        if self.prefix_length is not None:
                                            return True

                                        if self.prefix_version is not None:
                                            return True

                                        if self.process_instance_id is not None:
                                            return True

                                        if self.rd is not None:
                                            return True

                                        if self.route_distinguisher is not None:
                                            return True

                                        if self.source_route_distinguisher is not None:
                                            return True

                                        if self.source_vrf_name is not None:
                                            return True

                                        if self.srcaf_name is not None:
                                            return True

                                        if self.vrf_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertised-path-xr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.advertised_path is not None:
                                        for child_ref in self.advertised_path:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr']['meta_info']


                            class SourcedNetworks(object):
                                """
                                The BGP Convergence table
                                
                                .. attribute:: sourced_network
                                
                                	A BGP network command table entry
                                	**type**\: list of    :py:class:`SourcedNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.sourced_network = YList()
                                    self.sourced_network.parent = self
                                    self.sourced_network.name = 'sourced_network'


                                class SourcedNetwork(object):
                                    """
                                    A BGP network command table entry
                                    
                                    .. attribute:: network  <key>
                                    
                                    	Network in prefix/length format
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    
                                    ----
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: is_backdoor
                                    
                                    	TRUE if net is a backdoor route
                                    	**type**\:  bool
                                    
                                    .. attribute:: sourced_prefix
                                    
                                    	Prefix length
                                    	**type**\:   :py:class:`SourcedPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.network = None
                                        self.af_name = None
                                        self.is_backdoor = None
                                        self.sourced_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix()
                                        self.sourced_prefix.parent = self


                                    class SourcedPrefix(object):
                                        """
                                        Prefix length
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix()
                                            self.prefix.parent = self
                                            self.prefix_length = None


                                        class Prefix(object):
                                            """
                                            Prefix
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sourced-prefix'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.prefix is not None and self.prefix._has_data():
                                                return True

                                            if self.prefix_length is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.network is None:
                                            raise YPYModelError('Key property network is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sourced-network[Cisco-IOS-XR-ipv4-bgp-oper:network = ' + str(self.network) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.network is not None:
                                            return True

                                        if self.af_name is not None:
                                            return True

                                        if self.is_backdoor is not None:
                                            return True

                                        if self.sourced_prefix is not None and self.sourced_prefix._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sourced-networks'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.sourced_network is not None:
                                        for child_ref in self.sourced_network:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks']['meta_info']


                            class UpdateGroups(object):
                                """
                                The BGP Update group table
                                
                                .. attribute:: update_group
                                
                                	A BGP Update group table entry
                                	**type**\: list of    :py:class:`UpdateGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.update_group = YList()
                                    self.update_group.parent = self
                                    self.update_group.name = 'update_group'


                                class UpdateGroup(object):
                                    """
                                    A BGP Update group table entry
                                    
                                    .. attribute:: accepts_legacy_pe_rt_route
                                    
                                    	accept\-legacy\-pe\-RT route
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_local_labeled_route_unicast
                                    
                                    	Advertise routes with local\-label via Unicast SAFI
                                    	**type**\:  bool
                                    
                                    .. attribute:: advertise_rt_type
                                    
                                    	Advertise RT type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: as_override
                                    
                                    	AS Override option
                                    	**type**\:  bool
                                    
                                    .. attribute:: desync_count
                                    
                                    	Number of times the update has been desynchronized
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: disable_def_vrf_imp_advertisement
                                    
                                    	Disable advertising default VRF  imported routes
                                    	**type**\:  bool
                                    
                                    .. attribute:: disable_native_advertisement
                                    
                                    	Disable advertising native routes
                                    	**type**\:  bool
                                    
                                    .. attribute:: disable_vrf_re_imp_advertisement
                                    
                                    	Disable advertising VRF re\-imported routes
                                    	**type**\:  bool
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation type
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ext_nh_encoding
                                    
                                    	Extended nexthop encoding cap received
                                    	**type**\:  bool
                                    
                                    .. attribute:: filter_group_id
                                    
                                    	Filter group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: gshut_active
                                    
                                    	GSHUT active
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_locpref
                                    
                                    	GSHUT local preference
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: gshut_locpref_set
                                    
                                    	GSHUT local preference set
                                    	**type**\:  bool
                                    
                                    .. attribute:: gshut_prepends
                                    
                                    	GSHUT AS prepends
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: has_orf_receive_capability
                                    
                                    	ORF receive capability
                                    	**type**\:  bool
                                    
                                    .. attribute:: is4_byte_as_peer
                                    
                                    	4\-byte AS capable peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_addpath_capable
                                    
                                    	Add\-path capable peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_adv_capable
                                    
                                    	Send tranlsated paths
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_adv_perm_net_capable
                                    
                                    	Advertise Permanent\-Net capable peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_adv_reorg_capable
                                    
                                    	Send Re\-orig paths
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_aigp_capable
                                    
                                    	AIGP capable peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_aigp_cost_community_capable
                                    
                                    	Send AIGP cost community to peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_aigp_med_capable
                                    
                                    	Send AIGP cost in MED
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_client_reflection_disabled
                                    
                                    	True if client\-to\-client reflection is disabled 
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_common_admin_peers
                                    
                                    	Common admin peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_directly_connected_ebgp_v6_peers
                                    
                                    	Directly connected EBGP v6 peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_internal_peers
                                    
                                    	Internal peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_labeled_afi_enabled
                                    
                                    	Update group has labeled AFI enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_llgr_capable
                                    
                                    	Send Long\-lived Stale paths
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_orr_root_address_configured
                                    
                                    	ORR Root address configuredfor the neighbor connection
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_route_reflector_client
                                    
                                    	Route\-reflector client
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_send_mcast_attr_enabled
                                    
                                    	Send mcast attribute enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_unlabeled_afi_enabled
                                    
                                    	Update group has unlabeled AFI enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_as
                                    
                                    	Local AS number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_as_replace_as
                                    
                                    	Local AS Replace\-AS option
                                    	**type**\:  bool
                                    
                                    .. attribute:: minimum_advertisement_interval
                                    
                                    	Minimum advertisement interval, secs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: minimum_advertisement_interval_msecs
                                    
                                    	Minimum advertisement interval, msecs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: neighbor
                                    
                                    	Neighbors in this update group which are not in any sub\-group
                                    	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor>`
                                    
                                    .. attribute:: orr_group_index
                                    
                                    	ORR Group Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: orr_group_name
                                    
                                    	ORR Group Name
                                    	**type**\:  str
                                    
                                    .. attribute:: performance_statistics
                                    
                                    	Performance statistics
                                    	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics>`
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: refresh_subgrp_count
                                    
                                    	Current count of refresh subgroups
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_as
                                    
                                    	Remote AS number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_policy_out
                                    
                                    	Outbound route policy name
                                    	**type**\:  str
                                    
                                    .. attribute:: session_af_name
                                    
                                    	Neighbor session Address family
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: should_remove_private_a_ss
                                    
                                    	Remove private AS numbers
                                    	**type**\:  bool
                                    
                                    .. attribute:: should_remove_private_as_ent_path
                                    
                                    	Remove private AS numbersif the entire path consistsof private ASes
                                    	**type**\:  bool
                                    
                                    .. attribute:: should_send_communities
                                    
                                    	Send communities
                                    	**type**\:  bool
                                    
                                    .. attribute:: should_send_ext_communities
                                    
                                    	Send Extended communities
                                    	**type**\:  bool
                                    
                                    .. attribute:: should_send_gshut_community
                                    
                                    	Send GSHUT community
                                    	**type**\:  bool
                                    
                                    .. attribute:: should_send_stitching_rt
                                    
                                    	Send Stitching RT
                                    	**type**\:  bool
                                    
                                    .. attribute:: soo
                                    
                                    	Site\-of\-origin option
                                    	**type**\:  bool
                                    
                                    .. attribute:: soo_value
                                    
                                    	Site\-of\-origin value
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: split_horizon
                                    
                                    	Split horizon check
                                    	**type**\:  bool
                                    
                                    .. attribute:: subgrp_merge_count
                                    
                                    	Number of times sub\-groups have been merged
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_group_af_name
                                    
                                    	Address family for update group
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: update_group_id
                                    
                                    	Update group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: update_group_number
                                    
                                    	Update group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_sub_group
                                    
                                    	Update sub\-group list
                                    	**type**\: list of    :py:class:`UpdateSubGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup>`
                                    
                                    .. attribute:: updates_formatted
                                    
                                    	Number of updates formatted
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: updates_replicated
                                    
                                    	No. of updates replicated
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: updgrp_cluster_id
                                    
                                    	Cluster ID (populated ifclient\-to\-client reflectionis disabled)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: updgrp_cluster_type
                                    
                                    	Cluster ID type\:undefined/number/Ip address
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: use_next_hop_self
                                    
                                    	Next hop self
                                    	**type**\:  bool
                                    
                                    .. attribute:: use_next_hop_unchanged_mpath
                                    
                                    	Next\-hop\-unchanged multipath
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.accepts_legacy_pe_rt_route = None
                                        self.advertise_local_labeled_route_unicast = None
                                        self.advertise_rt_type = None
                                        self.as_override = None
                                        self.desync_count = None
                                        self.disable_def_vrf_imp_advertisement = None
                                        self.disable_native_advertisement = None
                                        self.disable_vrf_re_imp_advertisement = None
                                        self.encapsulation_type = None
                                        self.ext_nh_encoding = None
                                        self.filter_group_id = None
                                        self.gshut_active = None
                                        self.gshut_locpref = None
                                        self.gshut_locpref_set = None
                                        self.gshut_prepends = None
                                        self.has_orf_receive_capability = None
                                        self.is4_byte_as_peer = None
                                        self.is_addpath_capable = None
                                        self.is_adv_capable = None
                                        self.is_adv_perm_net_capable = None
                                        self.is_adv_reorg_capable = None
                                        self.is_aigp_capable = None
                                        self.is_aigp_cost_community_capable = None
                                        self.is_aigp_med_capable = None
                                        self.is_client_reflection_disabled = None
                                        self.is_common_admin_peers = None
                                        self.is_directly_connected_ebgp_v6_peers = None
                                        self.is_internal_peers = None
                                        self.is_labeled_afi_enabled = None
                                        self.is_llgr_capable = None
                                        self.is_orr_root_address_configured = None
                                        self.is_route_reflector_client = None
                                        self.is_send_mcast_attr_enabled = None
                                        self.is_unlabeled_afi_enabled = None
                                        self.local_as = None
                                        self.local_as_replace_as = None
                                        self.minimum_advertisement_interval = None
                                        self.minimum_advertisement_interval_msecs = None
                                        self.neighbor = YList()
                                        self.neighbor.parent = self
                                        self.neighbor.name = 'neighbor'
                                        self.orr_group_index = None
                                        self.orr_group_name = None
                                        self.performance_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics()
                                        self.performance_statistics.parent = self
                                        self.process_instance_id = None
                                        self.refresh_subgrp_count = None
                                        self.remote_as = None
                                        self.route_policy_out = None
                                        self.session_af_name = None
                                        self.should_remove_private_a_ss = None
                                        self.should_remove_private_as_ent_path = None
                                        self.should_send_communities = None
                                        self.should_send_ext_communities = None
                                        self.should_send_gshut_community = None
                                        self.should_send_stitching_rt = None
                                        self.soo = None
                                        self.soo_value = None
                                        self.split_horizon = None
                                        self.subgrp_merge_count = None
                                        self.update_group_af_name = None
                                        self.update_group_id = None
                                        self.update_group_number = None
                                        self.update_sub_group = YList()
                                        self.update_sub_group.parent = self
                                        self.update_sub_group.name = 'update_sub_group'
                                        self.updates_formatted = None
                                        self.updates_replicated = None
                                        self.updgrp_cluster_id = None
                                        self.updgrp_cluster_type = None
                                        self.use_next_hop_self = None
                                        self.use_next_hop_unchanged_mpath = None


                                    class PerformanceStatistics(object):
                                        """
                                        Performance statistics
                                        
                                        .. attribute:: update_generation_be_prefixes_count
                                        
                                        	No. of be prefixes updates generated for
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_calls
                                        
                                        	No. of calls to update generation function
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_messages_count
                                        
                                        	No. of update messages generated
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_prefixes_count
                                        
                                        	No. of prefixes updates generated for
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_time
                                        
                                        	Time spent generating updates (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: updgen_timer_process_time
                                        
                                        	Timestamp when update timer processed for updgrp
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: updgen_timer_start_time
                                        
                                        	Timestamp when update timer started for updgrp
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: updgen_timer_stop_time
                                        
                                        	Timestamp when update timer stopped for updgrp
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.update_generation_be_prefixes_count = None
                                            self.update_generation_calls = None
                                            self.update_generation_messages_count = None
                                            self.update_generation_prefixes_count = None
                                            self.update_generation_time = None
                                            self.updgen_timer_process_time = None
                                            self.updgen_timer_start_time = None
                                            self.updgen_timer_stop_time = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:performance-statistics'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.update_generation_be_prefixes_count is not None:
                                                return True

                                            if self.update_generation_calls is not None:
                                                return True

                                            if self.update_generation_messages_count is not None:
                                                return True

                                            if self.update_generation_prefixes_count is not None:
                                                return True

                                            if self.update_generation_time is not None:
                                                return True

                                            if self.updgen_timer_process_time is not None:
                                                return True

                                            if self.updgen_timer_start_time is not None:
                                                return True

                                            if self.updgen_timer_stop_time is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics']['meta_info']


                                    class Neighbor(object):
                                        """
                                        Neighbors in this update group which are not in
                                        any sub\-group
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor']['meta_info']


                                    class UpdateSubGroup(object):
                                        """
                                        Update sub\-group list
                                        
                                        .. attribute:: filter_group
                                        
                                        	Update sub\-group fgrp\-num
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: neighbor
                                        
                                        	Neighbors in this subgrp not in any filtergrp
                                        	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor>`
                                        
                                        .. attribute:: update_filter_group
                                        
                                        	Update f\-group list
                                        	**type**\: list of    :py:class:`UpdateFilterGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup>`
                                        
                                        .. attribute:: update_sub_group_number
                                        
                                        	Update sub\-group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: wait_for_eo_rs
                                        
                                        	Wait for  RT Nbr EoRs
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.filter_group = None
                                            self.neighbor = YList()
                                            self.neighbor.parent = self
                                            self.neighbor.name = 'neighbor'
                                            self.update_filter_group = YList()
                                            self.update_filter_group.parent = self
                                            self.update_filter_group.name = 'update_filter_group'
                                            self.update_sub_group_number = None
                                            self.wait_for_eo_rs = None


                                        class UpdateFilterGroup(object):
                                            """
                                            Update f\-group list
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity>`
                                            
                                            .. attribute:: fgroup_advertised_prefixes
                                            
                                            	Number of prefixes advertised to filtergroup in last update walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_created_message_elements
                                            
                                            	Number of message elems created for filtergroup
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_deleted_message_elements
                                            
                                            	Number of message elems deleted
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_flags
                                            
                                            	Flags per filter group
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fgroup_neighbors
                                            
                                            	Nbrs per filter group
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: fgroup_queued_message_elements
                                            
                                            	Number of message elems queued
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_skipped_prefixes
                                            
                                            	Number of prefixes skipped for filtergroup in last update walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_suppressed_prefixes
                                            
                                            	Number of prefixes suppressed for filtergroup in last update walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_total_advertised_prefixes
                                            
                                            	Number of prefixes advertised to filtergroup in all update walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_total_non_optimised_prefixes
                                            
                                            	Number of prefixes  non\-optm from filtergroupin all update walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_total_withdrawn_prefixes
                                            
                                            	Number of prefixes withdrawn f`rom filtergroupin all update walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_withdrawn_prefixes
                                            
                                            	Number of prefixes withdrawn f`rom filtergroupin last update walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_rt_present
                                            
                                            	RT attribute list present
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor
                                            
                                            	Neighbors in this update sub\-group
                                            	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor>`
                                            
                                            .. attribute:: rts
                                            
                                            	RT count per filter group
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_filter_group_number
                                            
                                            	Update sub\-group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.fgroup_advertised_prefixes = None
                                                self.fgroup_created_message_elements = None
                                                self.fgroup_deleted_message_elements = None
                                                self.fgroup_flags = None
                                                self.fgroup_neighbors = None
                                                self.fgroup_queued_message_elements = None
                                                self.fgroup_skipped_prefixes = None
                                                self.fgroup_suppressed_prefixes = None
                                                self.fgroup_total_advertised_prefixes = None
                                                self.fgroup_total_non_optimised_prefixes = None
                                                self.fgroup_total_withdrawn_prefixes = None
                                                self.fgroup_withdrawn_prefixes = None
                                                self.is_rt_present = None
                                                self.neighbor = YList()
                                                self.neighbor.parent = self
                                                self.neighbor.name = 'neighbor'
                                                self.rts = None
                                                self.update_filter_group_number = None


                                            class ExtendedCommunity(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity']['meta_info']


                                            class Neighbor(object):
                                                """
                                                Neighbors in this update sub\-group
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-filter-group'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.fgroup_advertised_prefixes is not None:
                                                    return True

                                                if self.fgroup_created_message_elements is not None:
                                                    return True

                                                if self.fgroup_deleted_message_elements is not None:
                                                    return True

                                                if self.fgroup_flags is not None:
                                                    return True

                                                if self.fgroup_neighbors is not None:
                                                    return True

                                                if self.fgroup_queued_message_elements is not None:
                                                    return True

                                                if self.fgroup_skipped_prefixes is not None:
                                                    return True

                                                if self.fgroup_suppressed_prefixes is not None:
                                                    return True

                                                if self.fgroup_total_advertised_prefixes is not None:
                                                    return True

                                                if self.fgroup_total_non_optimised_prefixes is not None:
                                                    return True

                                                if self.fgroup_total_withdrawn_prefixes is not None:
                                                    return True

                                                if self.fgroup_withdrawn_prefixes is not None:
                                                    return True

                                                if self.is_rt_present is not None:
                                                    return True

                                                if self.neighbor is not None:
                                                    for child_ref in self.neighbor:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.rts is not None:
                                                    return True

                                                if self.update_filter_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup']['meta_info']


                                        class Neighbor(object):
                                            """
                                            Neighbors in this subgrp not in any filtergrp
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-sub-group'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.filter_group is not None:
                                                return True

                                            if self.neighbor is not None:
                                                for child_ref in self.neighbor:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.update_filter_group is not None:
                                                for child_ref in self.update_filter_group:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.update_sub_group_number is not None:
                                                return True

                                            if self.wait_for_eo_rs is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-group'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.accepts_legacy_pe_rt_route is not None:
                                            return True

                                        if self.advertise_local_labeled_route_unicast is not None:
                                            return True

                                        if self.advertise_rt_type is not None:
                                            return True

                                        if self.as_override is not None:
                                            return True

                                        if self.desync_count is not None:
                                            return True

                                        if self.disable_def_vrf_imp_advertisement is not None:
                                            return True

                                        if self.disable_native_advertisement is not None:
                                            return True

                                        if self.disable_vrf_re_imp_advertisement is not None:
                                            return True

                                        if self.encapsulation_type is not None:
                                            return True

                                        if self.ext_nh_encoding is not None:
                                            return True

                                        if self.filter_group_id is not None:
                                            return True

                                        if self.gshut_active is not None:
                                            return True

                                        if self.gshut_locpref is not None:
                                            return True

                                        if self.gshut_locpref_set is not None:
                                            return True

                                        if self.gshut_prepends is not None:
                                            return True

                                        if self.has_orf_receive_capability is not None:
                                            return True

                                        if self.is4_byte_as_peer is not None:
                                            return True

                                        if self.is_addpath_capable is not None:
                                            return True

                                        if self.is_adv_capable is not None:
                                            return True

                                        if self.is_adv_perm_net_capable is not None:
                                            return True

                                        if self.is_adv_reorg_capable is not None:
                                            return True

                                        if self.is_aigp_capable is not None:
                                            return True

                                        if self.is_aigp_cost_community_capable is not None:
                                            return True

                                        if self.is_aigp_med_capable is not None:
                                            return True

                                        if self.is_client_reflection_disabled is not None:
                                            return True

                                        if self.is_common_admin_peers is not None:
                                            return True

                                        if self.is_directly_connected_ebgp_v6_peers is not None:
                                            return True

                                        if self.is_internal_peers is not None:
                                            return True

                                        if self.is_labeled_afi_enabled is not None:
                                            return True

                                        if self.is_llgr_capable is not None:
                                            return True

                                        if self.is_orr_root_address_configured is not None:
                                            return True

                                        if self.is_route_reflector_client is not None:
                                            return True

                                        if self.is_send_mcast_attr_enabled is not None:
                                            return True

                                        if self.is_unlabeled_afi_enabled is not None:
                                            return True

                                        if self.local_as is not None:
                                            return True

                                        if self.local_as_replace_as is not None:
                                            return True

                                        if self.minimum_advertisement_interval is not None:
                                            return True

                                        if self.minimum_advertisement_interval_msecs is not None:
                                            return True

                                        if self.neighbor is not None:
                                            for child_ref in self.neighbor:
                                                if child_ref._has_data():
                                                    return True

                                        if self.orr_group_index is not None:
                                            return True

                                        if self.orr_group_name is not None:
                                            return True

                                        if self.performance_statistics is not None and self.performance_statistics._has_data():
                                            return True

                                        if self.process_instance_id is not None:
                                            return True

                                        if self.refresh_subgrp_count is not None:
                                            return True

                                        if self.remote_as is not None:
                                            return True

                                        if self.route_policy_out is not None:
                                            return True

                                        if self.session_af_name is not None:
                                            return True

                                        if self.should_remove_private_a_ss is not None:
                                            return True

                                        if self.should_remove_private_as_ent_path is not None:
                                            return True

                                        if self.should_send_communities is not None:
                                            return True

                                        if self.should_send_ext_communities is not None:
                                            return True

                                        if self.should_send_gshut_community is not None:
                                            return True

                                        if self.should_send_stitching_rt is not None:
                                            return True

                                        if self.soo is not None:
                                            return True

                                        if self.soo_value is not None:
                                            return True

                                        if self.split_horizon is not None:
                                            return True

                                        if self.subgrp_merge_count is not None:
                                            return True

                                        if self.update_group_af_name is not None:
                                            return True

                                        if self.update_group_id is not None:
                                            return True

                                        if self.update_group_number is not None:
                                            return True

                                        if self.update_sub_group is not None:
                                            for child_ref in self.update_sub_group:
                                                if child_ref._has_data():
                                                    return True

                                        if self.updates_formatted is not None:
                                            return True

                                        if self.updates_replicated is not None:
                                            return True

                                        if self.updgrp_cluster_id is not None:
                                            return True

                                        if self.updgrp_cluster_type is not None:
                                            return True

                                        if self.use_next_hop_self is not None:
                                            return True

                                        if self.use_next_hop_unchanged_mpath is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-groups'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.update_group is not None:
                                        for child_ref in self.update_group:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups']['meta_info']


                            class UpdateGenerationSubGroups(object):
                                """
                                Update generation for all sub\-groups
                                
                                .. attribute:: update_generation_sub_group
                                
                                	Update generation for sub\-group
                                	**type**\: list of    :py:class:`UpdateGenerationSubGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.update_generation_sub_group = YList()
                                    self.update_generation_sub_group.parent = self
                                    self.update_generation_sub_group.name = 'update_generation_sub_group'


                                class UpdateGenerationSubGroup(object):
                                    """
                                    Update generation for sub\-group
                                    
                                    .. attribute:: configured_update_limit_sub_group
                                    
                                    	Configured update limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: creation_timestamp
                                    
                                    	Creation time
                                    	**type**\:   :py:class:`CreationTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp>`
                                    
                                    .. attribute:: current_update_limit_sub_group
                                    
                                    	Current update limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: eo_r_attempted
                                    
                                    	Sending EoR has been attempted
                                    	**type**\:  bool
                                    
                                    .. attribute:: filter_group_count
                                    
                                    	Filter\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: first_update_walk_end_timestamp
                                    
                                    	First update walk end time
                                    	**type**\:   :py:class:`FirstUpdateWalkEndTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp>`
                                    
                                    .. attribute:: first_update_walk_start_timestamp
                                    
                                    	First update walk start time
                                    	**type**\:   :py:class:`FirstUpdateWalkStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp>`
                                    
                                    .. attribute:: io_write_event_pending
                                    
                                    	Is IO write event pending
                                    	**type**\:  bool
                                    
                                    .. attribute:: last_merge_timestamp
                                    
                                    	Last merge time
                                    	**type**\:   :py:class:`LastMergeTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp>`
                                    
                                    .. attribute:: last_merged_sub_group_index
                                    
                                    	Last merged sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_update_queued_age
                                    
                                    	Time since last update queued event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_queued_timestamp
                                    
                                    	Last update queued time
                                    	**type**\:   :py:class:`LastUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp>`
                                    
                                    .. attribute:: last_update_walk_end_age
                                    
                                    	Time since last update walk end event
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_update_walk_end_timestamp
                                    
                                    	Last update walk end time
                                    	**type**\:   :py:class:`LastUpdateWalkEndTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp>`
                                    
                                    .. attribute:: last_update_walk_start_timestamp
                                    
                                    	Last update walk start time
                                    	**type**\:   :py:class:`LastUpdateWalkStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp>`
                                    
                                    .. attribute:: merge_count
                                    
                                    	Merge count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_count
                                    
                                    	Neighbor count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_resume_version
                                    
                                    	Next resume version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_version
                                    
                                    	NSR version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: parent_sub_group_id
                                    
                                    	Parent Sub\-group identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: parent_sub_group_index
                                    
                                    	Parent Sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pending_target_version
                                    
                                    	Pending target version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_id
                                    
                                    	ProcessID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_count
                                    
                                    	Refresh sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_id
                                    
                                    	Sub\-group ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sub_group_id_xr
                                    
                                    	Sub\-group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_index
                                    
                                    	Sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sub_group_index_xr
                                    
                                    	Sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_default_route_sent
                                    
                                    	Is default route sent
                                    	**type**\:  bool
                                    
                                    .. attribute:: update_group_af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: update_group_index
                                    
                                    	Update\-group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: update_group_index_xr
                                    
                                    	Update\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_main_table_version
                                    
                                    	Main table version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages
                                    
                                    	OutQueue messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_size
                                    
                                    	OutQueue size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_refresh_target_version
                                    
                                    	Refresh target version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_statistics
                                    
                                    	Update statistics
                                    	**type**\:   :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics>`
                                    
                                    .. attribute:: update_throttled
                                    
                                    	Is update throttled
                                    	**type**\:  bool
                                    
                                    .. attribute:: update_vrf_name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    .. attribute:: update_vrf_table_rib_version
                                    
                                    	VRF Table RIB version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version
                                    
                                    	Version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.configured_update_limit_sub_group = None
                                        self.creation_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp()
                                        self.creation_timestamp.parent = self
                                        self.current_update_limit_sub_group = None
                                        self.eo_r_attempted = None
                                        self.filter_group_count = None
                                        self.first_update_walk_end_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp()
                                        self.first_update_walk_end_timestamp.parent = self
                                        self.first_update_walk_start_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp()
                                        self.first_update_walk_start_timestamp.parent = self
                                        self.io_write_event_pending = None
                                        self.last_merge_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp()
                                        self.last_merge_timestamp.parent = self
                                        self.last_merged_sub_group_index = None
                                        self.last_update_queued_age = None
                                        self.last_update_queued_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp()
                                        self.last_update_queued_timestamp.parent = self
                                        self.last_update_walk_end_age = None
                                        self.last_update_walk_end_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp()
                                        self.last_update_walk_end_timestamp.parent = self
                                        self.last_update_walk_start_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp()
                                        self.last_update_walk_start_timestamp.parent = self
                                        self.merge_count = None
                                        self.neighbor_count = None
                                        self.next_resume_version = None
                                        self.nsr_version = None
                                        self.parent_sub_group_id = None
                                        self.parent_sub_group_index = None
                                        self.pending_target_version = None
                                        self.process_id = None
                                        self.refresh_sub_group_count = None
                                        self.sub_group_id = None
                                        self.sub_group_id_xr = None
                                        self.sub_group_index = None
                                        self.sub_group_index_xr = None
                                        self.update_default_route_sent = None
                                        self.update_group_af_name = None
                                        self.update_group_index = None
                                        self.update_group_index_xr = None
                                        self.update_main_table_version = None
                                        self.update_out_queue_messages = None
                                        self.update_out_queue_size = None
                                        self.update_refresh_target_version = None
                                        self.update_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics()
                                        self.update_statistics.parent = self
                                        self.update_throttled = None
                                        self.update_vrf_name = None
                                        self.update_vrf_table_rib_version = None
                                        self.version = None


                                    class CreationTimestamp(object):
                                        """
                                        Creation time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:creation-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp']['meta_info']


                                    class LastMergeTimestamp(object):
                                        """
                                        Last merge time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-merge-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp']['meta_info']


                                    class FirstUpdateWalkStartTimestamp(object):
                                        """
                                        First update walk start time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-update-walk-start-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp']['meta_info']


                                    class FirstUpdateWalkEndTimestamp(object):
                                        """
                                        First update walk end time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-update-walk-end-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp']['meta_info']


                                    class LastUpdateWalkStartTimestamp(object):
                                        """
                                        Last update walk start time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-walk-start-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp']['meta_info']


                                    class LastUpdateWalkEndTimestamp(object):
                                        """
                                        Last update walk end time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-walk-end-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp']['meta_info']


                                    class LastUpdateQueuedTimestamp(object):
                                        """
                                        Last update queued time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-queued-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp']['meta_info']


                                    class UpdateStatistics(object):
                                        """
                                        Update statistics
                                        
                                        .. attribute:: last_update_cleard_age
                                        
                                        	Time since last Clear event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_cleared_timestamp
                                        
                                        	Last Cleared time
                                        	**type**\:   :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp>`
                                        
                                        .. attribute:: last_update_discard_age
                                        
                                        	Time since last Discard event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_discard_timestamp
                                        
                                        	Last Discarded time
                                        	**type**\:   :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                        
                                        .. attribute:: last_update_memory_allocation_fail_age
                                        
                                        	Time since last memory allocation failure event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_memory_allocation_fail_timestamp
                                        
                                        	Memory allocation failure time
                                        	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                        
                                        .. attribute:: last_update_recovery_age
                                        
                                        	Time since last Recovery event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_recovery_timestamp
                                        
                                        	Last Recovery time
                                        	**type**\:   :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                        
                                        .. attribute:: last_update_throttle_age
                                        
                                        	Time since last Throttle event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_throttle_timestamp
                                        
                                        	Last Throttled time
                                        	**type**\:   :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                        
                                        .. attribute:: update_memory_allocation_fail_count
                                        
                                        	Memory allocation failure count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cleared
                                        
                                        	OutQueue Cleared Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cumulative
                                        
                                        	OutQueue Cumulative Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_discarded
                                        
                                        	OutQueue Discarded Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_high
                                        
                                        	OutQueue High Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size_cleared
                                        
                                        	OutQueue Cleared Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_cumulative
                                        
                                        	OutQueue Cumulative Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_discarded
                                        
                                        	OutQueue Discarded Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_high
                                        
                                        	OutQueue Hi Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_recovery_count
                                        
                                        	Recovery Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_throttle_count
                                        
                                        	Throttle Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.last_update_cleard_age = None
                                            self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp()
                                            self.last_update_cleared_timestamp.parent = self
                                            self.last_update_discard_age = None
                                            self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp()
                                            self.last_update_discard_timestamp.parent = self
                                            self.last_update_memory_allocation_fail_age = None
                                            self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                            self.last_update_memory_allocation_fail_timestamp.parent = self
                                            self.last_update_recovery_age = None
                                            self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                            self.last_update_recovery_timestamp.parent = self
                                            self.last_update_throttle_age = None
                                            self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp()
                                            self.last_update_throttle_timestamp.parent = self
                                            self.update_memory_allocation_fail_count = None
                                            self.update_out_queue_messages_cleared = None
                                            self.update_out_queue_messages_cumulative = None
                                            self.update_out_queue_messages_discarded = None
                                            self.update_out_queue_messages_high = None
                                            self.update_out_queue_size_cleared = None
                                            self.update_out_queue_size_cumulative = None
                                            self.update_out_queue_size_discarded = None
                                            self.update_out_queue_size_high = None
                                            self.update_recovery_count = None
                                            self.update_throttle_count = None


                                        class LastUpdateDiscardTimestamp(object):
                                            """
                                            Last Discarded time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-discard-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp']['meta_info']


                                        class LastUpdateClearedTimestamp(object):
                                            """
                                            Last Cleared time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-cleared-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp']['meta_info']


                                        class LastUpdateThrottleTimestamp(object):
                                            """
                                            Last Throttled time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-throttle-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp']['meta_info']


                                        class LastUpdateRecoveryTimestamp(object):
                                            """
                                            Last Recovery time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-recovery-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp']['meta_info']


                                        class LastUpdateMemoryAllocationFailTimestamp(object):
                                            """
                                            Memory allocation failure time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-memory-allocation-fail-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-statistics'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.last_update_cleard_age is not None:
                                                return True

                                            if self.last_update_cleared_timestamp is not None and self.last_update_cleared_timestamp._has_data():
                                                return True

                                            if self.last_update_discard_age is not None:
                                                return True

                                            if self.last_update_discard_timestamp is not None and self.last_update_discard_timestamp._has_data():
                                                return True

                                            if self.last_update_memory_allocation_fail_age is not None:
                                                return True

                                            if self.last_update_memory_allocation_fail_timestamp is not None and self.last_update_memory_allocation_fail_timestamp._has_data():
                                                return True

                                            if self.last_update_recovery_age is not None:
                                                return True

                                            if self.last_update_recovery_timestamp is not None and self.last_update_recovery_timestamp._has_data():
                                                return True

                                            if self.last_update_throttle_age is not None:
                                                return True

                                            if self.last_update_throttle_timestamp is not None and self.last_update_throttle_timestamp._has_data():
                                                return True

                                            if self.update_memory_allocation_fail_count is not None:
                                                return True

                                            if self.update_out_queue_messages_cleared is not None:
                                                return True

                                            if self.update_out_queue_messages_cumulative is not None:
                                                return True

                                            if self.update_out_queue_messages_discarded is not None:
                                                return True

                                            if self.update_out_queue_messages_high is not None:
                                                return True

                                            if self.update_out_queue_size_cleared is not None:
                                                return True

                                            if self.update_out_queue_size_cumulative is not None:
                                                return True

                                            if self.update_out_queue_size_discarded is not None:
                                                return True

                                            if self.update_out_queue_size_high is not None:
                                                return True

                                            if self.update_recovery_count is not None:
                                                return True

                                            if self.update_throttle_count is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-sub-group'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.configured_update_limit_sub_group is not None:
                                            return True

                                        if self.creation_timestamp is not None and self.creation_timestamp._has_data():
                                            return True

                                        if self.current_update_limit_sub_group is not None:
                                            return True

                                        if self.eo_r_attempted is not None:
                                            return True

                                        if self.filter_group_count is not None:
                                            return True

                                        if self.first_update_walk_end_timestamp is not None and self.first_update_walk_end_timestamp._has_data():
                                            return True

                                        if self.first_update_walk_start_timestamp is not None and self.first_update_walk_start_timestamp._has_data():
                                            return True

                                        if self.io_write_event_pending is not None:
                                            return True

                                        if self.last_merge_timestamp is not None and self.last_merge_timestamp._has_data():
                                            return True

                                        if self.last_merged_sub_group_index is not None:
                                            return True

                                        if self.last_update_queued_age is not None:
                                            return True

                                        if self.last_update_queued_timestamp is not None and self.last_update_queued_timestamp._has_data():
                                            return True

                                        if self.last_update_walk_end_age is not None:
                                            return True

                                        if self.last_update_walk_end_timestamp is not None and self.last_update_walk_end_timestamp._has_data():
                                            return True

                                        if self.last_update_walk_start_timestamp is not None and self.last_update_walk_start_timestamp._has_data():
                                            return True

                                        if self.merge_count is not None:
                                            return True

                                        if self.neighbor_count is not None:
                                            return True

                                        if self.next_resume_version is not None:
                                            return True

                                        if self.nsr_version is not None:
                                            return True

                                        if self.parent_sub_group_id is not None:
                                            return True

                                        if self.parent_sub_group_index is not None:
                                            return True

                                        if self.pending_target_version is not None:
                                            return True

                                        if self.process_id is not None:
                                            return True

                                        if self.refresh_sub_group_count is not None:
                                            return True

                                        if self.sub_group_id is not None:
                                            return True

                                        if self.sub_group_id_xr is not None:
                                            return True

                                        if self.sub_group_index is not None:
                                            return True

                                        if self.sub_group_index_xr is not None:
                                            return True

                                        if self.update_default_route_sent is not None:
                                            return True

                                        if self.update_group_af_name is not None:
                                            return True

                                        if self.update_group_index is not None:
                                            return True

                                        if self.update_group_index_xr is not None:
                                            return True

                                        if self.update_main_table_version is not None:
                                            return True

                                        if self.update_out_queue_messages is not None:
                                            return True

                                        if self.update_out_queue_size is not None:
                                            return True

                                        if self.update_refresh_target_version is not None:
                                            return True

                                        if self.update_statistics is not None and self.update_statistics._has_data():
                                            return True

                                        if self.update_throttled is not None:
                                            return True

                                        if self.update_vrf_name is not None:
                                            return True

                                        if self.update_vrf_table_rib_version is not None:
                                            return True

                                        if self.version is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-sub-groups'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.update_generation_sub_group is not None:
                                        for child_ref in self.update_generation_sub_group:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups']['meta_info']


                            class NextHopAddressFamilies(object):
                                """
                                Address family of nexthop table
                                
                                .. attribute:: next_hop_address_family
                                
                                	Nexthop Address family
                                	**type**\: list of    :py:class:`NextHopAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.next_hop_address_family = YList()
                                    self.next_hop_address_family.parent = self
                                    self.next_hop_address_family.name = 'next_hop_address_family'


                                class NextHopAddressFamily(object):
                                    """
                                    Nexthop Address family
                                    
                                    .. attribute:: next_hop_af_name  <key>
                                    
                                    	Address family
                                    	**type**\:   :py:class:`BgpAddressFamilyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamilyEnum>`
                                    
                                    .. attribute:: next_hop_af_vrf_af
                                    
                                    	A BGP Next\-hop VRF AF table entry
                                    	**type**\:   :py:class:`NextHopAfVrfAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf>`
                                    
                                    .. attribute:: next_hop_afs
                                    
                                    	The BGP Next\-hop table
                                    	**type**\:   :py:class:`NextHopAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.next_hop_af_name = None
                                        self.next_hop_af_vrf_af = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf()
                                        self.next_hop_af_vrf_af.parent = self
                                        self.next_hop_afs = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs()
                                        self.next_hop_afs.parent = self


                                    class NextHopAfVrfAf(object):
                                        """
                                        A BGP Next\-hop VRF AF table entry
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: critical_trigger_delay
                                        
                                        	Trigger delay for critical event processing
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_downloaded_version
                                        
                                        	Version of the EPE table downloaded
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_label_version
                                        
                                        	Version of the EPE label walk
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_standby_version
                                        
                                        	Version of the EPE table processed by sync thread
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_table_version
                                        
                                        	Version of the EPE table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: gwaf_name
                                        
                                        	GW Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: nh_nexthop_version
                                        
                                        	NH version for gw\_ctx
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nh_rib_up
                                        
                                        	Whether the VRF is active
                                        	**type**\:  bool
                                        
                                        .. attribute:: nh_rib_version
                                        
                                        	RIB version for gw\_ctx
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nh_table_id
                                        
                                        	Gateway context table id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: non_critical_trigger_delay
                                        
                                        	Trigger delay for non\-critical event processing
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: performance_statistics
                                        
                                        	Performance statistics
                                        	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics>`
                                        
                                        .. attribute:: table_active
                                        
                                        	Whether the VRF is active
                                        	**type**\:  bool
                                        
                                        .. attribute:: total_nexthops
                                        
                                        	Total number of nexthops
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.critical_trigger_delay = None
                                            self.epe_downloaded_version = None
                                            self.epe_label_version = None
                                            self.epe_standby_version = None
                                            self.epe_table_version = None
                                            self.gwaf_name = None
                                            self.nh_nexthop_version = None
                                            self.nh_rib_up = None
                                            self.nh_rib_version = None
                                            self.nh_table_id = None
                                            self.non_critical_trigger_delay = None
                                            self.performance_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics()
                                            self.performance_statistics.parent = self
                                            self.table_active = None
                                            self.total_nexthops = None


                                        class PerformanceStatistics(object):
                                            """
                                            Performance statistics
                                            
                                            .. attribute:: critical_notf_count
                                            
                                            	Number of critical event notifications from RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_notf_bestpath_changes
                                            
                                            	Number of bestpath changes due to last notification
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_notf_bestpath_deletes
                                            
                                            	Number of bestpath deletes due to last notification
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nexthops_removed_from_rib
                                            
                                            	No. of nexthops withdrawn from RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nexthops_resent_to_rib
                                            
                                            	No. of nexthops re\-sent to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nexthops_sent_to_rib
                                            
                                            	No. of nexthops sent to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_batch_finish_calls
                                            
                                            	NH batch finish calls
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_flush_timer_calls
                                            
                                            	NH flush timer calls
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_last_a_sync_reg_ts
                                            
                                            	NH Last async Register TS
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_last_a_sync_un_reg_ts
                                            
                                            	NH Last async UnRegister TS
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_last_batch_finish_ts
                                            
                                            	NH Last batch finish TS
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_last_flush_timer_ts
                                            
                                            	NH Last flush timer TS
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_last_sync_reg_ts
                                            
                                            	NH Last sync Register TS
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_peak_registrations
                                            
                                            	NH Registration List Count Peak
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_pending_registrations
                                            
                                            	NH Registration List Count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_sync_reg_calls
                                            
                                            	NH sync register calls
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nha_sync_reg_calls
                                            
                                            	NH async register calls
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nha_sync_un_reg_calls
                                            
                                            	NH async unregister calls
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nhrib_update_calls
                                            
                                            	No. of calls to RIB update function
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nhrib_update_time
                                            
                                            	Time spent sending RIB updates (milliseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: noncritical_notf_count
                                            
                                            	Number of non\-critical event notifications from RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_sync_registers_failed
                                            
                                            	No. of sync registers with RIB that failed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: riba_sync_registers_failed
                                            
                                            	No. of async registers with RIB that failed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribnh_reg_failed_for_no_rib_conn
                                            
                                            	No. of nh registers failed because of no rib conn
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribnh_reg_failed_for_no_tbl_id
                                            
                                            	No. of nh registers failed because of no tbl\-id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_walk_backup_creates
                                            
                                            	No. of times backup tid created during tunnel walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_walk_gw_not_found
                                            
                                            	No. of times gw was not found during tunnel walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_walk_nh_not_found
                                            
                                            	No. of times nexthop was not found during tunnel walk
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.critical_notf_count = None
                                                self.last_notf_bestpath_changes = None
                                                self.last_notf_bestpath_deletes = None
                                                self.nexthops_removed_from_rib = None
                                                self.nexthops_resent_to_rib = None
                                                self.nexthops_sent_to_rib = None
                                                self.nh_batch_finish_calls = None
                                                self.nh_flush_timer_calls = None
                                                self.nh_last_a_sync_reg_ts = None
                                                self.nh_last_a_sync_un_reg_ts = None
                                                self.nh_last_batch_finish_ts = None
                                                self.nh_last_flush_timer_ts = None
                                                self.nh_last_sync_reg_ts = None
                                                self.nh_peak_registrations = None
                                                self.nh_pending_registrations = None
                                                self.nh_sync_reg_calls = None
                                                self.nha_sync_reg_calls = None
                                                self.nha_sync_un_reg_calls = None
                                                self.nhrib_update_calls = None
                                                self.nhrib_update_time = None
                                                self.noncritical_notf_count = None
                                                self.rib_sync_registers_failed = None
                                                self.riba_sync_registers_failed = None
                                                self.ribnh_reg_failed_for_no_rib_conn = None
                                                self.ribnh_reg_failed_for_no_tbl_id = None
                                                self.tunnel_walk_backup_creates = None
                                                self.tunnel_walk_gw_not_found = None
                                                self.tunnel_walk_nh_not_found = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:performance-statistics'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.critical_notf_count is not None:
                                                    return True

                                                if self.last_notf_bestpath_changes is not None:
                                                    return True

                                                if self.last_notf_bestpath_deletes is not None:
                                                    return True

                                                if self.nexthops_removed_from_rib is not None:
                                                    return True

                                                if self.nexthops_resent_to_rib is not None:
                                                    return True

                                                if self.nexthops_sent_to_rib is not None:
                                                    return True

                                                if self.nh_batch_finish_calls is not None:
                                                    return True

                                                if self.nh_flush_timer_calls is not None:
                                                    return True

                                                if self.nh_last_a_sync_reg_ts is not None:
                                                    return True

                                                if self.nh_last_a_sync_un_reg_ts is not None:
                                                    return True

                                                if self.nh_last_batch_finish_ts is not None:
                                                    return True

                                                if self.nh_last_flush_timer_ts is not None:
                                                    return True

                                                if self.nh_last_sync_reg_ts is not None:
                                                    return True

                                                if self.nh_peak_registrations is not None:
                                                    return True

                                                if self.nh_pending_registrations is not None:
                                                    return True

                                                if self.nh_sync_reg_calls is not None:
                                                    return True

                                                if self.nha_sync_reg_calls is not None:
                                                    return True

                                                if self.nha_sync_un_reg_calls is not None:
                                                    return True

                                                if self.nhrib_update_calls is not None:
                                                    return True

                                                if self.nhrib_update_time is not None:
                                                    return True

                                                if self.noncritical_notf_count is not None:
                                                    return True

                                                if self.rib_sync_registers_failed is not None:
                                                    return True

                                                if self.riba_sync_registers_failed is not None:
                                                    return True

                                                if self.ribnh_reg_failed_for_no_rib_conn is not None:
                                                    return True

                                                if self.ribnh_reg_failed_for_no_tbl_id is not None:
                                                    return True

                                                if self.tunnel_walk_backup_creates is not None:
                                                    return True

                                                if self.tunnel_walk_gw_not_found is not None:
                                                    return True

                                                if self.tunnel_walk_nh_not_found is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop-af-vrf-af'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.critical_trigger_delay is not None:
                                                return True

                                            if self.epe_downloaded_version is not None:
                                                return True

                                            if self.epe_label_version is not None:
                                                return True

                                            if self.epe_standby_version is not None:
                                                return True

                                            if self.epe_table_version is not None:
                                                return True

                                            if self.gwaf_name is not None:
                                                return True

                                            if self.nh_nexthop_version is not None:
                                                return True

                                            if self.nh_rib_up is not None:
                                                return True

                                            if self.nh_rib_version is not None:
                                                return True

                                            if self.nh_table_id is not None:
                                                return True

                                            if self.non_critical_trigger_delay is not None:
                                                return True

                                            if self.performance_statistics is not None and self.performance_statistics._has_data():
                                                return True

                                            if self.table_active is not None:
                                                return True

                                            if self.total_nexthops is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf']['meta_info']


                                    class NextHopAfs(object):
                                        """
                                        The BGP Next\-hop table
                                        
                                        .. attribute:: next_hop_af
                                        
                                        	A BGP Next hop entry
                                        	**type**\: list of    :py:class:`NextHopAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.next_hop_af = YList()
                                            self.next_hop_af.parent = self
                                            self.next_hop_af.name = 'next_hop_af'


                                        class NextHopAf(object):
                                            """
                                            A BGP Next hop entry
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: attribute_set
                                            
                                            	Attribute Set Name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address List
                                            	**type**\: list of    :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress>`
                                            
                                            .. attribute:: next_hop_address
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: nexthop_address
                                            
                                            	Nexthop address
                                            	**type**\:   :py:class:`NexthopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress>`
                                            
                                            .. attribute:: nexthop_aigp_metric
                                            
                                            	AIGP metrice of nexthop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nexthop_gateway_info
                                            
                                            	Gateway related info, includingOptimal Route Reflector Gateways
                                            	**type**\: list of    :py:class:`NexthopGatewayInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo>`
                                            
                                            .. attribute:: nexthop_gateway_prefix_connected
                                            
                                            	Is Gateway resolved through Connected route ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: nexthop_gateway_prefix_length
                                            
                                            	Gateway prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nexthop_gateway_reachable
                                            
                                            	Is Gateway reachable ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: nexthop_internal_info
                                            
                                            	Internal nexthop info
                                            	**type**\:   :py:class:`NexthopInternalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo>`
                                            
                                            .. attribute:: nexthop_pending_registration
                                            
                                            	Nexthop registration is pending
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nexthop_reference_count
                                            
                                            	Number of neighbors/prefixes referencing this nexthop
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_first_hop_if_handle
                                            
                                            	First\-hop interface handle
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                            
                                            .. attribute:: nh_reference_count_total
                                            
                                            	Number of neighbors/prefixes referencing this nexthop (AFs)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhteTunnel>`
                                            
                                            .. attribute:: rib_nexthop_id
                                            
                                            	RIB Nexthop Id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.af_name = None
                                                self.attribute_set = None
                                                self.neighbor_address = YList()
                                                self.neighbor_address.parent = self
                                                self.neighbor_address.name = 'neighbor_address'
                                                self.next_hop_address = None
                                                self.nexthop_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress()
                                                self.nexthop_address.parent = self
                                                self.nexthop_aigp_metric = None
                                                self.nexthop_gateway_info = YList()
                                                self.nexthop_gateway_info.parent = self
                                                self.nexthop_gateway_info.name = 'nexthop_gateway_info'
                                                self.nexthop_gateway_prefix_connected = None
                                                self.nexthop_gateway_prefix_length = None
                                                self.nexthop_gateway_reachable = None
                                                self.nexthop_internal_info = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo()
                                                self.nexthop_internal_info.parent = self
                                                self.nexthop_pending_registration = None
                                                self.nexthop_reference_count = None
                                                self.nh_first_hop_if_handle = None
                                                self.nh_reference_count_total = None
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.rib_nexthop_id = None


                                            class NexthopAddress(object):
                                                """
                                                Nexthop address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhteTunnel']['meta_info']


                                            class NexthopInternalInfo(object):
                                                """
                                                Internal nexthop info
                                                
                                                .. attribute:: gateway_flags
                                                
                                                	Gateway flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_address
                                                
                                                	Nexthop address
                                                	**type**\:   :py:class:`NexthopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress>`
                                                
                                                .. attribute:: nexthop_af_user_bits
                                                
                                                	Bitmask indicating the AFs which share the nexthop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_flags
                                                
                                                	Nexthop flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_gateway_internal_info
                                                
                                                	Internal nexthop Gateway info
                                                	**type**\: list of    :py:class:`NexthopGatewayInternalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo>`
                                                
                                                .. attribute:: nexthop_id
                                                
                                                	Comm librray ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_if_handle
                                                
                                                	Nexthop ifhandle
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_label
                                                
                                                	Nexthop label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_metrice
                                                
                                                	Nexthop metrices
                                                	**type**\: list of    :py:class:`NexthopMetrice <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice>`
                                                
                                                .. attribute:: nexthop_refcount
                                                
                                                	Nexthop refcounts
                                                	**type**\: list of    :py:class:`NexthopRefcount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount>`
                                                
                                                .. attribute:: nexthop_version
                                                
                                                	Table version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.gateway_flags = None
                                                    self.nexthop_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress()
                                                    self.nexthop_address.parent = self
                                                    self.nexthop_af_user_bits = None
                                                    self.nexthop_flags = None
                                                    self.nexthop_gateway_internal_info = YList()
                                                    self.nexthop_gateway_internal_info.parent = self
                                                    self.nexthop_gateway_internal_info.name = 'nexthop_gateway_internal_info'
                                                    self.nexthop_id = None
                                                    self.nexthop_if_handle = None
                                                    self.nexthop_label = None
                                                    self.nexthop_metrice = YList()
                                                    self.nexthop_metrice.parent = self
                                                    self.nexthop_metrice.name = 'nexthop_metrice'
                                                    self.nexthop_refcount = YList()
                                                    self.nexthop_refcount.parent = self
                                                    self.nexthop_refcount.name = 'nexthop_refcount'
                                                    self.nexthop_version = None


                                                class NexthopAddress(object):
                                                    """
                                                    Nexthop address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress']['meta_info']


                                                class NexthopMetrice(object):
                                                    """
                                                    Nexthop metrices
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-metrice'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice']['meta_info']


                                                class NexthopRefcount(object):
                                                    """
                                                    Nexthop refcounts
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-refcount'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount']['meta_info']


                                                class NexthopGatewayInternalInfo(object):
                                                    """
                                                    Internal nexthop Gateway info
                                                    
                                                    .. attribute:: gateway_flags
                                                    
                                                    	Gateway flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: registration_since
                                                    
                                                    	Time since registration
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: registration_type
                                                    
                                                    	Nexthop registration type
                                                    	**type**\:   :py:class:`BgpNhValidateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpNhValidateEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.gateway_flags = None
                                                        self.registration_since = None
                                                        self.registration_type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-gateway-internal-info'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.gateway_flags is not None:
                                                            return True

                                                        if self.registration_since is not None:
                                                            return True

                                                        if self.registration_type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-internal-info'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.gateway_flags is not None:
                                                        return True

                                                    if self.nexthop_address is not None and self.nexthop_address._has_data():
                                                        return True

                                                    if self.nexthop_af_user_bits is not None:
                                                        return True

                                                    if self.nexthop_flags is not None:
                                                        return True

                                                    if self.nexthop_gateway_internal_info is not None:
                                                        for child_ref in self.nexthop_gateway_internal_info:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.nexthop_id is not None:
                                                        return True

                                                    if self.nexthop_if_handle is not None:
                                                        return True

                                                    if self.nexthop_label is not None:
                                                        return True

                                                    if self.nexthop_metrice is not None:
                                                        for child_ref in self.nexthop_metrice:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.nexthop_refcount is not None:
                                                        for child_ref in self.nexthop_refcount:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.nexthop_version is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo']['meta_info']


                                            class NexthopGatewayInfo(object):
                                                """
                                                Gateway related info, includingOptimal Route
                                                Reflector Gateways
                                                
                                                .. attribute:: critical_events
                                                
                                                	Number of critical events received from RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_event_since
                                                
                                                	Time since the last event sent to or received from RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_event_type
                                                
                                                	Last nexthop event type
                                                	**type**\:   :py:class:`BgpNhEventEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpNhEventEnum>`
                                                
                                                .. attribute:: last_rib_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_update_type
                                                
                                                	Last nexthop update type
                                                	**type**\:   :py:class:`BgpNhUpdateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpNhUpdateEnum>`
                                                
                                                .. attribute:: nexthop_af_invalid_bits
                                                
                                                	Bitmask indicating the AFs which have been invalidated for the nexthop
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: nexthop_metric
                                                
                                                	IGP metric for nexthop
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_mpls_enabled
                                                
                                                	TRUE if MPLS is configured for IAS/CsC application
                                                	**type**\:  bool
                                                
                                                .. attribute:: nexthop_mpls_interfaces
                                                
                                                	Number of interfaces on which MPLS is enabled
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_mpls_label
                                                
                                                	Local label allocated for IAS/CsC application
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_route
                                                
                                                	Route resolving the nethop
                                                	**type**\:   :py:class:`NexthopRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute>`
                                                
                                                .. attribute:: nexthop_route_path
                                                
                                                	Nexthops of the resolving route
                                                	**type**\: list of    :py:class:`NexthopRoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath>`
                                                
                                                .. attribute:: nexthop_route_path_count
                                                
                                                	Number of paths in the resolving route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_route_prefix_length
                                                
                                                	Prefix length of the route resolving the nexthop
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nexthop_route_protocol
                                                
                                                	Protocol that resolves the route to the nexthop
                                                	**type**\:  str
                                                
                                                .. attribute:: nexthop_status
                                                
                                                	Nexthop status
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nexthop_tableid
                                                
                                                	Nexthop Table id
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: non_critical_events
                                                
                                                	Number of non\-critical events received from RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.critical_events = None
                                                    self.last_event_since = None
                                                    self.last_event_type = None
                                                    self.last_rib_update = None
                                                    self.last_update_type = None
                                                    self.nexthop_af_invalid_bits = None
                                                    self.nexthop_metric = None
                                                    self.nexthop_mpls_enabled = None
                                                    self.nexthop_mpls_interfaces = None
                                                    self.nexthop_mpls_label = None
                                                    self.nexthop_route = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute()
                                                    self.nexthop_route.parent = self
                                                    self.nexthop_route_path = YList()
                                                    self.nexthop_route_path.parent = self
                                                    self.nexthop_route_path.name = 'nexthop_route_path'
                                                    self.nexthop_route_path_count = None
                                                    self.nexthop_route_prefix_length = None
                                                    self.nexthop_route_protocol = None
                                                    self.nexthop_status = None
                                                    self.nexthop_tableid = None
                                                    self.non_critical_events = None


                                                class NexthopRoute(object):
                                                    """
                                                    Route resolving the nethop
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-route'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute']['meta_info']


                                                class NexthopRoutePath(object):
                                                    """
                                                    Nexthops of the resolving route
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-route-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-gateway-info'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.critical_events is not None:
                                                        return True

                                                    if self.last_event_since is not None:
                                                        return True

                                                    if self.last_event_type is not None:
                                                        return True

                                                    if self.last_rib_update is not None:
                                                        return True

                                                    if self.last_update_type is not None:
                                                        return True

                                                    if self.nexthop_af_invalid_bits is not None:
                                                        return True

                                                    if self.nexthop_metric is not None:
                                                        return True

                                                    if self.nexthop_mpls_enabled is not None:
                                                        return True

                                                    if self.nexthop_mpls_interfaces is not None:
                                                        return True

                                                    if self.nexthop_mpls_label is not None:
                                                        return True

                                                    if self.nexthop_route is not None and self.nexthop_route._has_data():
                                                        return True

                                                    if self.nexthop_route_path is not None:
                                                        for child_ref in self.nexthop_route_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.nexthop_route_path_count is not None:
                                                        return True

                                                    if self.nexthop_route_prefix_length is not None:
                                                        return True

                                                    if self.nexthop_route_protocol is not None:
                                                        return True

                                                    if self.nexthop_status is not None:
                                                        return True

                                                    if self.nexthop_tableid is not None:
                                                        return True

                                                    if self.non_critical_events is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo']['meta_info']


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address List
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop-af'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.af_name is not None:
                                                    return True

                                                if self.attribute_set is not None:
                                                    return True

                                                if self.neighbor_address is not None:
                                                    for child_ref in self.neighbor_address:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.next_hop_address is not None:
                                                    return True

                                                if self.nexthop_address is not None and self.nexthop_address._has_data():
                                                    return True

                                                if self.nexthop_aigp_metric is not None:
                                                    return True

                                                if self.nexthop_gateway_info is not None:
                                                    for child_ref in self.nexthop_gateway_info:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.nexthop_gateway_prefix_connected is not None:
                                                    return True

                                                if self.nexthop_gateway_prefix_length is not None:
                                                    return True

                                                if self.nexthop_gateway_reachable is not None:
                                                    return True

                                                if self.nexthop_internal_info is not None and self.nexthop_internal_info._has_data():
                                                    return True

                                                if self.nexthop_pending_registration is not None:
                                                    return True

                                                if self.nexthop_reference_count is not None:
                                                    return True

                                                if self.nh_first_hop_if_handle is not None:
                                                    return True

                                                if self.nh_reference_count_total is not None:
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.rib_nexthop_id is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop-afs'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.next_hop_af is not None:
                                                for child_ref in self.next_hop_af:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.next_hop_af_name is None:
                                            raise YPYModelError('Key property next_hop_af_name is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop-address-family[Cisco-IOS-XR-ipv4-bgp-oper:next-hop-af-name = ' + str(self.next_hop_af_name) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.next_hop_af_name is not None:
                                            return True

                                        if self.next_hop_af_vrf_af is not None and self.next_hop_af_vrf_af._has_data():
                                            return True

                                        if self.next_hop_afs is not None and self.next_hop_afs._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop-address-families'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.next_hop_address_family is not None:
                                        for child_ref in self.next_hop_address_family:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies']['meta_info']


                            class RtSetCounters(object):
                                """
                                The RT\-set counter table
                                
                                .. attribute:: rt_set_counter
                                
                                	One RT\-set counter table entry
                                	**type**\: list of    :py:class:`RtSetCounter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.rt_set_counter = YList()
                                    self.rt_set_counter.parent = self
                                    self.rt_set_counter.name = 'rt_set_counter'


                                class RtSetCounter(object):
                                    """
                                    One RT\-set counter table entry
                                    
                                    .. attribute:: rt_set_id  <key>
                                    
                                    	RTSet ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: route_target_set
                                    
                                    	Route Target set
                                    	**type**\:   :py:class:`RouteTargetSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.rt_set_id = None
                                        self.route_target_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet()
                                        self.route_target_set.parent = self


                                    class RouteTargetSet(object):
                                        """
                                        Route Target set
                                        
                                        .. attribute:: rt_set
                                        
                                        	Set of route targets
                                        	**type**\: list of    :py:class:`RtSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet>`
                                        
                                        .. attribute:: rt_set_id
                                        
                                        	Identifier of the rtset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rt_set_len
                                        
                                        	Length in bytes of set of route targets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rt_set_net_count
                                        
                                        	Count of nets with paths with the rtset
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.rt_set = YList()
                                            self.rt_set.parent = self
                                            self.rt_set.name = 'rt_set'
                                            self.rt_set_id = None
                                            self.rt_set_len = None
                                            self.rt_set_net_count = None


                                        class RtSet(object):
                                            """
                                            Set of route targets
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rt-set'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:route-target-set'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.rt_set is not None:
                                                for child_ref in self.rt_set:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.rt_set_id is not None:
                                                return True

                                            if self.rt_set_len is not None:
                                                return True

                                            if self.rt_set_net_count is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.rt_set_id is None:
                                            raise YPYModelError('Key property rt_set_id is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rt-set-counter[Cisco-IOS-XR-ipv4-bgp-oper:rt-set-id = ' + str(self.rt_set_id) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.rt_set_id is not None:
                                            return True

                                        if self.route_target_set is not None and self.route_target_set._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rt-set-counters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.rt_set_counter is not None:
                                        for child_ref in self.rt_set_counter:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters']['meta_info']


                            class BmpPaths(object):
                                """
                                The paths in BMP Table
                                
                                .. attribute:: bmp_path
                                
                                	A BMP path table entry
                                	**type**\: list of    :py:class:`BmpPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.bmp_path = YList()
                                    self.bmp_path.parent = self
                                    self.bmp_path.name = 'bmp_path'


                                class BmpPath(object):
                                    """
                                    A BMP path table entry
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: bgp_prefix
                                    
                                    	BGP prefix
                                    	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix>`
                                    
                                    .. attribute:: bmp_net_flags
                                    
                                    	Flags associated with net
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_net_version
                                    
                                    	Net's version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_path
                                    
                                    	List of paths under the BMP net
                                    	**type**\: list of    :py:class:`BmpPath_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_>`
                                    
                                    .. attribute:: has_local_label
                                    
                                    	Net has local label
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_local_label
                                    
                                    	Local label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: network
                                    
                                    	Network Prefix in Hex format
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: num_of_path
                                    
                                    	Number of path for the net
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: version_age
                                    
                                    	Net Version bump age
                                    	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionAge>`
                                    
                                    .. attribute:: version_timestamp
                                    
                                    	Net Version bump timestamp
                                    	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix()
                                        self.bgp_prefix.parent = self
                                        self.bmp_net_flags = None
                                        self.bmp_net_version = None
                                        self.bmp_path = YList()
                                        self.bmp_path.parent = self
                                        self.bmp_path.name = 'bmp_path'
                                        self.has_local_label = None
                                        self.net_local_label = None
                                        self.network = None
                                        self.num_of_path = None
                                        self.prefix_length = None
                                        self.version_age = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionAge()
                                        self.version_age.parent = self
                                        self.version_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp()
                                        self.version_timestamp.parent = self


                                    class BgpPrefix(object):
                                        """
                                        BGP prefix
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix()
                                            self.prefix.parent = self
                                            self.prefix_length = None


                                        class Prefix(object):
                                            """
                                            Prefix
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.prefix is not None and self.prefix._has_data():
                                                return True

                                            if self.prefix_length is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix']['meta_info']


                                    class VersionTimestamp(object):
                                        """
                                        Net Version bump timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp']['meta_info']


                                    class VersionAge(object):
                                        """
                                        Net Version bump age
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-age'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionAge']['meta_info']


                                    class BmpPath_(object):
                                        """
                                        List of paths under the BMP net
                                        
                                        .. attribute:: bmp_nbr_bit_map
                                        
                                        	Paths Nbr bmp bit map
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_path_adv_bit_map
                                        
                                        	Path's Adv bit map
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: bmp_path_flags
                                        
                                        	Flags associated with path
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_path_snd_bit_map
                                        
                                        	Path's pending snd bit map
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: bpath_pointer
                                        
                                        	BGP Path pointer
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: local_path
                                        
                                        	Is path originated locally?
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress>`
                                        
                                        .. attribute:: received_label
                                        
                                        	Label received from peer
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bmp_nbr_bit_map = None
                                            self.bmp_path_adv_bit_map = None
                                            self.bmp_path_flags = None
                                            self.bmp_path_snd_bit_map = None
                                            self.bpath_pointer = None
                                            self.local_path = None
                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self.received_label = None


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-path'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bmp_nbr_bit_map is not None:
                                                return True

                                            if self.bmp_path_adv_bit_map is not None:
                                                return True

                                            if self.bmp_path_flags is not None:
                                                return True

                                            if self.bmp_path_snd_bit_map is not None:
                                                return True

                                            if self.bpath_pointer is not None:
                                                return True

                                            if self.local_path is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            if self.received_label is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                            return True

                                        if self.bmp_net_flags is not None:
                                            return True

                                        if self.bmp_net_version is not None:
                                            return True

                                        if self.bmp_path is not None:
                                            for child_ref in self.bmp_path:
                                                if child_ref._has_data():
                                                    return True

                                        if self.has_local_label is not None:
                                            return True

                                        if self.net_local_label is not None:
                                            return True

                                        if self.network is not None:
                                            return True

                                        if self.num_of_path is not None:
                                            return True

                                        if self.prefix_length is not None:
                                            return True

                                        if self.version_age is not None and self.version_age._has_data():
                                            return True

                                        if self.version_timestamp is not None and self.version_timestamp._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-paths'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bmp_path is not None:
                                        for child_ref in self.bmp_path:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths']['meta_info']


                            class UpdateGenerationUpdateGroups(object):
                                """
                                Update generation for all update\-groups
                                
                                .. attribute:: update_generation_update_group
                                
                                	Update generation for update\-group
                                	**type**\: list of    :py:class:`UpdateGenerationUpdateGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.update_generation_update_group = YList()
                                    self.update_generation_update_group.parent = self
                                    self.update_generation_update_group.name = 'update_generation_update_group'


                                class UpdateGenerationUpdateGroup(object):
                                    """
                                    Update generation for update\-group
                                    
                                    .. attribute:: update_group_index  <key>
                                    
                                    	Update\-group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: filter_group_count
                                    
                                    	Filter\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_permanent
                                    
                                    	Permanent UG check
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_update_timer_running
                                    
                                    	Is update timer running
                                    	**type**\:  bool
                                    
                                    .. attribute:: last_update_timer_delay_value
                                    
                                    	Last update timer delay value
                                    	**type**\:   :py:class:`LastUpdateTimerDelayValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue>`
                                    
                                    .. attribute:: last_update_timer_expiry_age
                                    
                                    	Time since last update timer expiry event
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_update_timer_expiry_timestamp
                                    
                                    	Last update timer expiry time
                                    	**type**\:   :py:class:`LastUpdateTimerExpiryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp>`
                                    
                                    .. attribute:: last_update_timer_remaining_value
                                    
                                    	Update timer remaining time
                                    	**type**\:   :py:class:`LastUpdateTimerRemainingValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue>`
                                    
                                    .. attribute:: last_update_timer_start_timestamp
                                    
                                    	Last update timer start time
                                    	**type**\:   :py:class:`LastUpdateTimerStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp>`
                                    
                                    .. attribute:: last_update_timer_stop_timestamp
                                    
                                    	Last update timer stop time
                                    	**type**\:   :py:class:`LastUpdateTimerStopTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp>`
                                    
                                    .. attribute:: neighbor_count
                                    
                                    	Neighbor count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_leaving_count
                                    
                                    	Count of neighbors leaving the update\-group
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_session_af_name
                                    
                                    	Neighbor session address family
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: perm_pelem_allowed
                                    
                                    	Count of Perm Pelems allowed by updgen
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: perm_pelem_encountered
                                    
                                    	Count of Perm Pelems seen by updgen
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: perm_pelem_exp_wdr
                                    
                                    	Count of Perm Pelems explicitly wdrn by updgen
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: perm_pelem_not_allowed
                                    
                                    	Count of Perm Pelems not allowed by updgen
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: perm_pelem_spur_wdr
                                    
                                    	Count of Perm Pelems Spurious withdraws by updgen
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_id
                                    
                                    	ProcessID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_count
                                    
                                    	Refresh sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_throttled_count
                                    
                                    	Throttled refresh sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_throttled_count
                                    
                                    	Throttled sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_generation_recovery_pending
                                    
                                    	Is update generation recovery pending
                                    	**type**\:  bool
                                    
                                    .. attribute:: update_group_af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: update_group_flags2
                                    
                                    	Update\-group internal flags2
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_group_index_xr
                                    
                                    	Update\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages
                                    
                                    	OutQueue Messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_size
                                    
                                    	OutQueue Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_statistics
                                    
                                    	Update statistics
                                    	**type**\:   :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics>`
                                    
                                    .. attribute:: update_sub_group_count
                                    
                                    	Sub\-group count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_vrf_name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.update_group_index = None
                                        self.filter_group_count = None
                                        self.is_permanent = None
                                        self.is_update_timer_running = None
                                        self.last_update_timer_delay_value = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue()
                                        self.last_update_timer_delay_value.parent = self
                                        self.last_update_timer_expiry_age = None
                                        self.last_update_timer_expiry_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp()
                                        self.last_update_timer_expiry_timestamp.parent = self
                                        self.last_update_timer_remaining_value = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue()
                                        self.last_update_timer_remaining_value.parent = self
                                        self.last_update_timer_start_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp()
                                        self.last_update_timer_start_timestamp.parent = self
                                        self.last_update_timer_stop_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp()
                                        self.last_update_timer_stop_timestamp.parent = self
                                        self.neighbor_count = None
                                        self.neighbor_leaving_count = None
                                        self.neighbor_session_af_name = None
                                        self.perm_pelem_allowed = None
                                        self.perm_pelem_encountered = None
                                        self.perm_pelem_exp_wdr = None
                                        self.perm_pelem_not_allowed = None
                                        self.perm_pelem_spur_wdr = None
                                        self.process_id = None
                                        self.refresh_sub_group_count = None
                                        self.refresh_sub_group_throttled_count = None
                                        self.sub_group_throttled_count = None
                                        self.update_generation_recovery_pending = None
                                        self.update_group_af_name = None
                                        self.update_group_flags2 = None
                                        self.update_group_index_xr = None
                                        self.update_out_queue_messages = None
                                        self.update_out_queue_size = None
                                        self.update_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics()
                                        self.update_statistics.parent = self
                                        self.update_sub_group_count = None
                                        self.update_vrf_name = None


                                    class LastUpdateTimerStartTimestamp(object):
                                        """
                                        Last update timer start time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-timer-start-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp']['meta_info']


                                    class LastUpdateTimerStopTimestamp(object):
                                        """
                                        Last update timer stop time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-timer-stop-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp']['meta_info']


                                    class LastUpdateTimerExpiryTimestamp(object):
                                        """
                                        Last update timer expiry time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-timer-expiry-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp']['meta_info']


                                    class LastUpdateTimerRemainingValue(object):
                                        """
                                        Update timer remaining time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-timer-remaining-value'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue']['meta_info']


                                    class LastUpdateTimerDelayValue(object):
                                        """
                                        Last update timer delay value
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-timer-delay-value'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue']['meta_info']


                                    class UpdateStatistics(object):
                                        """
                                        Update statistics
                                        
                                        .. attribute:: last_update_cleard_age
                                        
                                        	Time since last Clear event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_cleared_timestamp
                                        
                                        	Last Cleared time
                                        	**type**\:   :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp>`
                                        
                                        .. attribute:: last_update_discard_age
                                        
                                        	Time since last Discard event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_discard_timestamp
                                        
                                        	Last Discarded time
                                        	**type**\:   :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                        
                                        .. attribute:: last_update_memory_allocation_fail_age
                                        
                                        	Time since last memory allocation failure event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_memory_allocation_fail_timestamp
                                        
                                        	Memory allocation failure time
                                        	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                        
                                        .. attribute:: last_update_recovery_age
                                        
                                        	Time since last Recovery event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_recovery_timestamp
                                        
                                        	Last Recovery time
                                        	**type**\:   :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                        
                                        .. attribute:: last_update_throttle_age
                                        
                                        	Time since last Throttle event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_throttle_timestamp
                                        
                                        	Last Throttled time
                                        	**type**\:   :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                        
                                        .. attribute:: update_memory_allocation_fail_count
                                        
                                        	Memory allocation failure count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cleared
                                        
                                        	OutQueue Cleared Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cumulative
                                        
                                        	OutQueue Cumulative Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_discarded
                                        
                                        	OutQueue Discarded Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_high
                                        
                                        	OutQueue High Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size_cleared
                                        
                                        	OutQueue Cleared Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_cumulative
                                        
                                        	OutQueue Cumulative Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_discarded
                                        
                                        	OutQueue Discarded Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_high
                                        
                                        	OutQueue Hi Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_recovery_count
                                        
                                        	Recovery Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_throttle_count
                                        
                                        	Throttle Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.last_update_cleard_age = None
                                            self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp()
                                            self.last_update_cleared_timestamp.parent = self
                                            self.last_update_discard_age = None
                                            self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp()
                                            self.last_update_discard_timestamp.parent = self
                                            self.last_update_memory_allocation_fail_age = None
                                            self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                            self.last_update_memory_allocation_fail_timestamp.parent = self
                                            self.last_update_recovery_age = None
                                            self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                            self.last_update_recovery_timestamp.parent = self
                                            self.last_update_throttle_age = None
                                            self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp()
                                            self.last_update_throttle_timestamp.parent = self
                                            self.update_memory_allocation_fail_count = None
                                            self.update_out_queue_messages_cleared = None
                                            self.update_out_queue_messages_cumulative = None
                                            self.update_out_queue_messages_discarded = None
                                            self.update_out_queue_messages_high = None
                                            self.update_out_queue_size_cleared = None
                                            self.update_out_queue_size_cumulative = None
                                            self.update_out_queue_size_discarded = None
                                            self.update_out_queue_size_high = None
                                            self.update_recovery_count = None
                                            self.update_throttle_count = None


                                        class LastUpdateDiscardTimestamp(object):
                                            """
                                            Last Discarded time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-discard-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp']['meta_info']


                                        class LastUpdateClearedTimestamp(object):
                                            """
                                            Last Cleared time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-cleared-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp']['meta_info']


                                        class LastUpdateThrottleTimestamp(object):
                                            """
                                            Last Throttled time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-throttle-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp']['meta_info']


                                        class LastUpdateRecoveryTimestamp(object):
                                            """
                                            Last Recovery time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-recovery-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp']['meta_info']


                                        class LastUpdateMemoryAllocationFailTimestamp(object):
                                            """
                                            Memory allocation failure time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-memory-allocation-fail-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-statistics'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.last_update_cleard_age is not None:
                                                return True

                                            if self.last_update_cleared_timestamp is not None and self.last_update_cleared_timestamp._has_data():
                                                return True

                                            if self.last_update_discard_age is not None:
                                                return True

                                            if self.last_update_discard_timestamp is not None and self.last_update_discard_timestamp._has_data():
                                                return True

                                            if self.last_update_memory_allocation_fail_age is not None:
                                                return True

                                            if self.last_update_memory_allocation_fail_timestamp is not None and self.last_update_memory_allocation_fail_timestamp._has_data():
                                                return True

                                            if self.last_update_recovery_age is not None:
                                                return True

                                            if self.last_update_recovery_timestamp is not None and self.last_update_recovery_timestamp._has_data():
                                                return True

                                            if self.last_update_throttle_age is not None:
                                                return True

                                            if self.last_update_throttle_timestamp is not None and self.last_update_throttle_timestamp._has_data():
                                                return True

                                            if self.update_memory_allocation_fail_count is not None:
                                                return True

                                            if self.update_out_queue_messages_cleared is not None:
                                                return True

                                            if self.update_out_queue_messages_cumulative is not None:
                                                return True

                                            if self.update_out_queue_messages_discarded is not None:
                                                return True

                                            if self.update_out_queue_messages_high is not None:
                                                return True

                                            if self.update_out_queue_size_cleared is not None:
                                                return True

                                            if self.update_out_queue_size_cumulative is not None:
                                                return True

                                            if self.update_out_queue_size_discarded is not None:
                                                return True

                                            if self.update_out_queue_size_high is not None:
                                                return True

                                            if self.update_recovery_count is not None:
                                                return True

                                            if self.update_throttle_count is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.update_group_index is None:
                                            raise YPYModelError('Key property update_group_index is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-update-group[Cisco-IOS-XR-ipv4-bgp-oper:update-group-index = ' + str(self.update_group_index) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.update_group_index is not None:
                                            return True

                                        if self.filter_group_count is not None:
                                            return True

                                        if self.is_permanent is not None:
                                            return True

                                        if self.is_update_timer_running is not None:
                                            return True

                                        if self.last_update_timer_delay_value is not None and self.last_update_timer_delay_value._has_data():
                                            return True

                                        if self.last_update_timer_expiry_age is not None:
                                            return True

                                        if self.last_update_timer_expiry_timestamp is not None and self.last_update_timer_expiry_timestamp._has_data():
                                            return True

                                        if self.last_update_timer_remaining_value is not None and self.last_update_timer_remaining_value._has_data():
                                            return True

                                        if self.last_update_timer_start_timestamp is not None and self.last_update_timer_start_timestamp._has_data():
                                            return True

                                        if self.last_update_timer_stop_timestamp is not None and self.last_update_timer_stop_timestamp._has_data():
                                            return True

                                        if self.neighbor_count is not None:
                                            return True

                                        if self.neighbor_leaving_count is not None:
                                            return True

                                        if self.neighbor_session_af_name is not None:
                                            return True

                                        if self.perm_pelem_allowed is not None:
                                            return True

                                        if self.perm_pelem_encountered is not None:
                                            return True

                                        if self.perm_pelem_exp_wdr is not None:
                                            return True

                                        if self.perm_pelem_not_allowed is not None:
                                            return True

                                        if self.perm_pelem_spur_wdr is not None:
                                            return True

                                        if self.process_id is not None:
                                            return True

                                        if self.refresh_sub_group_count is not None:
                                            return True

                                        if self.refresh_sub_group_throttled_count is not None:
                                            return True

                                        if self.sub_group_throttled_count is not None:
                                            return True

                                        if self.update_generation_recovery_pending is not None:
                                            return True

                                        if self.update_group_af_name is not None:
                                            return True

                                        if self.update_group_flags2 is not None:
                                            return True

                                        if self.update_group_index_xr is not None:
                                            return True

                                        if self.update_out_queue_messages is not None:
                                            return True

                                        if self.update_out_queue_size is not None:
                                            return True

                                        if self.update_statistics is not None and self.update_statistics._has_data():
                                            return True

                                        if self.update_sub_group_count is not None:
                                            return True

                                        if self.update_vrf_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-update-groups'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.update_generation_update_group is not None:
                                        for child_ref in self.update_generation_update_group:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups']['meta_info']


                            class UpdateGenerationFilterGroups(object):
                                """
                                Update generation for all filter\-groups under
                                a sub\-group
                                
                                .. attribute:: update_generation_filter_group
                                
                                	Update generation for filter\-group
                                	**type**\: list of    :py:class:`UpdateGenerationFilterGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.update_generation_filter_group = YList()
                                    self.update_generation_filter_group.parent = self
                                    self.update_generation_filter_group.name = 'update_generation_filter_group'


                                class UpdateGenerationFilterGroup(object):
                                    """
                                    Update generation for filter\-group
                                    
                                    .. attribute:: filter_group_index
                                    
                                    	Filter\-group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: neighbor_count
                                    
                                    	Neighbor count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: parent_filter_group_index
                                    
                                    	Parent Filter\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: parent_sub_group_id
                                    
                                    	Parent Sub\-group identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: parent_sub_group_index
                                    
                                    	Parent Sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_id
                                    
                                    	ProcessID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_id
                                    
                                    	Sub\-group ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sub_group_id_xr
                                    
                                    	Sub\-group identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_index
                                    
                                    	Sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sub_group_index_xr
                                    
                                    	Sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_filter_group_index
                                    
                                    	Filter\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_group_af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: update_group_index
                                    
                                    	Update\-group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: update_group_index_xr
                                    
                                    	Update\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_vrf_name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.filter_group_index = None
                                        self.neighbor_count = None
                                        self.parent_filter_group_index = None
                                        self.parent_sub_group_id = None
                                        self.parent_sub_group_index = None
                                        self.process_id = None
                                        self.sub_group_id = None
                                        self.sub_group_id_xr = None
                                        self.sub_group_index = None
                                        self.sub_group_index_xr = None
                                        self.update_filter_group_index = None
                                        self.update_group_af_name = None
                                        self.update_group_index = None
                                        self.update_group_index_xr = None
                                        self.update_vrf_name = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-filter-group'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.filter_group_index is not None:
                                            return True

                                        if self.neighbor_count is not None:
                                            return True

                                        if self.parent_filter_group_index is not None:
                                            return True

                                        if self.parent_sub_group_id is not None:
                                            return True

                                        if self.parent_sub_group_index is not None:
                                            return True

                                        if self.process_id is not None:
                                            return True

                                        if self.sub_group_id is not None:
                                            return True

                                        if self.sub_group_id_xr is not None:
                                            return True

                                        if self.sub_group_index is not None:
                                            return True

                                        if self.sub_group_index_xr is not None:
                                            return True

                                        if self.update_filter_group_index is not None:
                                            return True

                                        if self.update_group_af_name is not None:
                                            return True

                                        if self.update_group_index is not None:
                                            return True

                                        if self.update_group_index_xr is not None:
                                            return True

                                        if self.update_vrf_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-filter-groups'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.update_generation_filter_group is not None:
                                        for child_ref in self.update_generation_filter_group:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups']['meta_info']


                            class Networks(object):
                                """
                                The BGP Network Table
                                
                                .. attribute:: network
                                
                                	A BGP Network table entry
                                	**type**\: list of    :py:class:`Network <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.network = YList()
                                    self.network.parent = self
                                    self.network.name = 'network'


                                class Network(object):
                                    """
                                    A BGP Network table entry
                                    
                                    .. attribute:: active_path_element
                                    
                                    	Path element list received from Active inst
                                    	**type**\: list of    :py:class:`ActivePathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement>`
                                    
                                    .. attribute:: active_process_instance_path
                                    
                                    	Active's paths for this net 
                                    	**type**\: list of    :py:class:`ActiveProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath>`
                                    
                                    .. attribute:: add_path_orr_bitfield
                                    
                                    	ORR Add path Bitfields
                                    	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield>`
                                    
                                    .. attribute:: advertisedto_pe
                                    
                                    	Net could be advertised                          to PE peers
                                    	**type**\:  bool
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: best_path_orr_bitfield
                                    
                                    	ORR Best path Bitfields
                                    	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield>`
                                    
                                    .. attribute:: bgp_prefix
                                    
                                    	BGP prefix
                                    	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix>`
                                    
                                    .. attribute:: bit
                                    
                                    	Bit
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: flags
                                    
                                    	Flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: gateway_array
                                    
                                    	Gateway array ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: has_inconsistent_paths
                                    
                                    	Net has inconsistent paths
                                    	**type**\:  bool
                                    
                                    .. attribute:: has_lbl_retained
                                    
                                    	Net has label retained
                                    	**type**\:  bool
                                    
                                    .. attribute:: has_local_label
                                    
                                    	Net has local label
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_net_aggregation_suppressed
                                    
                                    	Net suppressed due to aggregation
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_net_ldp_signaled
                                    
                                    	L2VPN Net LDP signaled  aggregation
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_permanent_network
                                    
                                    	Permanent Network
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_path_element
                                    
                                    	Local path element list
                                    	**type**\: list of    :py:class:`LocalPathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement>`
                                    
                                    .. attribute:: local_peers_advertised_to
                                    
                                    	Local peers that this prefix has been advertised to
                                    	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo>`
                                    
                                    .. attribute:: local_process_instance_path
                                    
                                    	Local (to process instance) paths for this net 
                                    	**type**\: list of    :py:class:`LocalProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath>`
                                    
                                    .. attribute:: net_backup_available
                                    
                                    	Net has backup path
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_backup_label_rewrite_available
                                    
                                    	Net has label rewrite for backup path
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_eibgp_multipath
                                    
                                    	Net has EIBGP multipaths
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_extended_flags
                                    
                                    	Net extended flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: net_flags
                                    
                                    	Flags associated with                            net
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: net_local_label
                                    
                                    	Local label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: net_local_label_rewrite
                                    
                                    	Net label has rewrite
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_local_label_srgb
                                    
                                    	Net label allocated fromSegment routing global block
                                    	**type**\:  bool
                                    
                                    .. attribute:: net_multipath
                                    
                                    	Net has multipaths
                                    	**type**\:  bool
                                    
                                    .. attribute:: network
                                    
                                    	Network in prefix/length format
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    
                                    ----
                                    .. attribute:: num_of_path
                                    
                                    	Number of path for this net
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pe_peers_advertised_to
                                    
                                    	PE peers that this prefix has been advertised to
                                    	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo>`
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: resilient_nexthop_set
                                    
                                    	Resilient nexthop set ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_failed
                                    
                                    	RIB install failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: table_brib_version
                                    
                                    	Table version # for updates
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_version
                                    
                                    	Table version # for net
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version
                                    
                                    	Version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version_age
                                    
                                    	Version age
                                    	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.VersionAge>`
                                    
                                    .. attribute:: version_timestamp
                                    
                                    	Version timestamp
                                    	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.VersionTimestamp>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.active_path_element = YList()
                                        self.active_path_element.parent = self
                                        self.active_path_element.name = 'active_path_element'
                                        self.active_process_instance_path = YList()
                                        self.active_process_instance_path.parent = self
                                        self.active_process_instance_path.name = 'active_process_instance_path'
                                        self.add_path_orr_bitfield = YList()
                                        self.add_path_orr_bitfield.parent = self
                                        self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                        self.advertisedto_pe = None
                                        self.af_name = None
                                        self.best_path_orr_bitfield = YList()
                                        self.best_path_orr_bitfield.parent = self
                                        self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                        self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix()
                                        self.bgp_prefix.parent = self
                                        self.bit = None
                                        self.flags = None
                                        self.gateway_array = None
                                        self.has_inconsistent_paths = None
                                        self.has_lbl_retained = None
                                        self.has_local_label = None
                                        self.is_net_aggregation_suppressed = None
                                        self.is_net_ldp_signaled = None
                                        self.is_permanent_network = None
                                        self.local_path_element = YList()
                                        self.local_path_element.parent = self
                                        self.local_path_element.name = 'local_path_element'
                                        self.local_peers_advertised_to = YList()
                                        self.local_peers_advertised_to.parent = self
                                        self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                        self.local_process_instance_path = YList()
                                        self.local_process_instance_path.parent = self
                                        self.local_process_instance_path.name = 'local_process_instance_path'
                                        self.net_backup_available = None
                                        self.net_backup_label_rewrite_available = None
                                        self.net_eibgp_multipath = None
                                        self.net_extended_flags = None
                                        self.net_flags = None
                                        self.net_local_label = None
                                        self.net_local_label_rewrite = None
                                        self.net_local_label_srgb = None
                                        self.net_multipath = None
                                        self.network = None
                                        self.num_of_path = None
                                        self.pe_peers_advertised_to = YList()
                                        self.pe_peers_advertised_to.parent = self
                                        self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                        self.process_instance_id = None
                                        self.rd = None
                                        self.resilient_nexthop_set = None
                                        self.rib_failed = None
                                        self.route_distinguisher = None
                                        self.table_brib_version = None
                                        self.table_version = None
                                        self.version = None
                                        self.version_age = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.VersionAge()
                                        self.version_age.parent = self
                                        self.version_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.VersionTimestamp()
                                        self.version_timestamp.parent = self
                                        self.vrf_name = None


                                    class BgpPrefix(object):
                                        """
                                        BGP prefix
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix()
                                            self.prefix.parent = self
                                            self.prefix_length = None


                                        class Prefix(object):
                                            """
                                            Prefix
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.prefix is not None and self.prefix._has_data():
                                                return True

                                            if self.prefix_length is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix']['meta_info']


                                    class VersionTimestamp(object):
                                        """
                                        Version timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.VersionTimestamp']['meta_info']


                                    class VersionAge(object):
                                        """
                                        Version age
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-age'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.VersionAge']['meta_info']


                                    class LocalPeersAdvertisedTo(object):
                                        """
                                        Local peers that this prefix has been advertised
                                        to
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress>`
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.is_neighbor = None
                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self.update_group_number = None


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.is_neighbor is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            if self.update_group_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo']['meta_info']


                                    class PePeersAdvertisedTo(object):
                                        """
                                        PE peers that this prefix has been advertised to
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress>`
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.is_neighbor = None
                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self.update_group_number = None


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.is_neighbor is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            if self.update_group_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo']['meta_info']


                                    class BestPathOrrBitfield(object):
                                        """
                                        ORR Best path Bitfields
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress>`
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.is_neighbor = None
                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self.update_group_number = None


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.is_neighbor is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            if self.update_group_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield']['meta_info']


                                    class AddPathOrrBitfield(object):
                                        """
                                        ORR Add path Bitfields
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress>`
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.is_neighbor = None
                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self.update_group_number = None


                                        class NeighborAddress(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.is_neighbor is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            if self.update_group_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield']['meta_info']


                                    class LocalProcessInstancePath(object):
                                        """
                                        Local (to process instance) paths for this net 
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation>`
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self.label_fail = None
                                            self.label_o_or_version = None
                                            self.label_oor = None
                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self.no_path = None
                                            self.path_information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation()
                                            self.path_information.parent = self
                                            self.prefix_version = None
                                            self.process_instance_id = None
                                            self.route_distinguisher = None
                                            self.source_route_distinguisher = None
                                            self.source_vrf_name = None
                                            self.srcaf_name = None
                                            self.vrf_name = None


                                        class NeighborAddressXr(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.NeighborAddressXr']['meta_info']


                                        class PathInformation(object):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_esi
                                            
                                            	Path has EVPN ESI
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_rcvd_label
                                            
                                            	Path has received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebg_ps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi>`
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop>`
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhteTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_p_ath = None
                                                self.add_path_orr_bitfield = YList()
                                                self.add_path_orr_bitfield.parent = self
                                                self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                self.advertisedto_pe = None
                                                self.aigp_metric = None
                                                self.best_path_comp_stage = None
                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self.best_path_id = None
                                                self.best_path_id_comp_winner = None
                                                self.best_path_orr_bitfield = YList()
                                                self.best_path_orr_bitfield.parent = self
                                                self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self.dampen_penalty = None
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.fspec_invalid_path = None
                                                self.graceful_shutdown = None
                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self.halflife_time = None
                                                self.has_esi = None
                                                self.has_gw_addr = None
                                                self.has_local_net_label = None
                                                self.has_mdt_group_addr = None
                                                self.has_mvpn_extcomm = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.has_rcvd_label = None
                                                self.has_second_label = None
                                                self.ibgp_signaled_validity = None
                                                self.igp_metric = None
                                                self.is_aggregation_suppressed = None
                                                self.is_as_best = None
                                                self.is_best_path = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_internal_path = None
                                                self.is_partial_best = None
                                                self.is_path_additional_path = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_af_install_eligible = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_damped = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_history_held = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_imported = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_multipath = None
                                                self.is_path_nexthop_discarded = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebg_ps = None
                                                self.is_path_received_only = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_stale = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_valid = None
                                                self.is_path_vpn_only = None
                                                self.is_permanent_path = None
                                                self.is_received_path_not_modified = None
                                                self.is_spkr_as_best = None
                                                self.l2vpn_circuit_status_value = YList()
                                                self.l2vpn_circuit_status_value.parent = self
                                                self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi()
                                                self.l2vpn_evpn_esi.parent = self
                                                self.l2vpn_size = None
                                                self.labeled_unicast_safi_path = None
                                                self.local_label = None
                                                self.local_nh = None
                                                self.local_path_id = None
                                                self.local_peers_advertised_to = YList()
                                                self.local_peers_advertised_to.parent = self
                                                self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                self.maximum_suppress_time = None
                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self.mvpn_path_flags = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_value = YList()
                                                self.mvpn_pmsi_value.parent = self
                                                self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                self.mvpn_sfs_path = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.neighbor_router_id = None
                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.path_flags = None
                                                self.path_flap_count = None
                                                self.path_import_flags = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.path_table_version = None
                                                self.path_weight = None
                                                self.pe_peers_advertised_to = YList()
                                                self.pe_peers_advertised_to.parent = self
                                                self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                self.rcvd_label = None
                                                self.rcvd_path_id = None
                                                self.reuse_value = None
                                                self.rib_failed = None
                                                self.route_type = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.rt_set_limit_enabled = None
                                                self.second_label = None
                                                self.seconds_since_first_flap = None
                                                self.show_rpki_origin_as_validity = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.suppress_penalty = None
                                                self.time_to_unsuppress = None


                                            class BgpPrefix(object):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self.prefix_length = None


                                                class Prefix(object):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.prefix is not None and self.prefix._has_data():
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix']['meta_info']


                                            class NeighborAddress(object):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress']['meta_info']


                                            class NextHop(object):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhteTunnel']['meta_info']


                                            class MdtGroupAddr(object):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr']['meta_info']


                                            class L2VpnEvpnEsi(object):
                                                """
                                                L2VPN EVPN ESI
                                                
                                                .. attribute:: esi
                                                
                                                	esi
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.esi = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.esi is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi']['meta_info']


                                            class GwAddr(object):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr']['meta_info']


                                            class BestPathCompWinner(object):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner']['meta_info']


                                            class MvpnNbrAddr(object):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr']['meta_info']


                                            class MvpnNexthopAddr(object):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr']['meta_info']


                                            class L2VpnCircuitStatusValue(object):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                            class MvpnPmsiValue(object):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity']['meta_info']


                                            class LocalPeersAdvertisedTo(object):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                            class PePeersAdvertisedTo(object):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo']['meta_info']


                                            class BestPathOrrBitfield(object):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield']['meta_info']


                                            class AddPathOrrBitfield(object):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.accept_own_path is not None:
                                                    return True

                                                if self.accept_own_self_originated_p_ath is not None:
                                                    return True

                                                if self.add_path_orr_bitfield is not None:
                                                    for child_ref in self.add_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.advertisedto_pe is not None:
                                                    return True

                                                if self.aigp_metric is not None:
                                                    return True

                                                if self.best_path_comp_stage is not None:
                                                    return True

                                                if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                    return True

                                                if self.best_path_id is not None:
                                                    return True

                                                if self.best_path_id_comp_winner is not None:
                                                    return True

                                                if self.best_path_orr_bitfield is not None:
                                                    for child_ref in self.best_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                    return True

                                                if self.dampen_penalty is not None:
                                                    return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.fspec_invalid_path is not None:
                                                    return True

                                                if self.graceful_shutdown is not None:
                                                    return True

                                                if self.gw_addr is not None and self.gw_addr._has_data():
                                                    return True

                                                if self.halflife_time is not None:
                                                    return True

                                                if self.has_esi is not None:
                                                    return True

                                                if self.has_gw_addr is not None:
                                                    return True

                                                if self.has_local_net_label is not None:
                                                    return True

                                                if self.has_mdt_group_addr is not None:
                                                    return True

                                                if self.has_mvpn_extcomm is not None:
                                                    return True

                                                if self.has_mvpn_nbr_addr is not None:
                                                    return True

                                                if self.has_mvpn_nexthop_addr is not None:
                                                    return True

                                                if self.has_mvpn_pmsi is not None:
                                                    return True

                                                if self.has_rcvd_label is not None:
                                                    return True

                                                if self.has_second_label is not None:
                                                    return True

                                                if self.ibgp_signaled_validity is not None:
                                                    return True

                                                if self.igp_metric is not None:
                                                    return True

                                                if self.is_aggregation_suppressed is not None:
                                                    return True

                                                if self.is_as_best is not None:
                                                    return True

                                                if self.is_best_path is not None:
                                                    return True

                                                if self.is_import_dampened is not None:
                                                    return True

                                                if self.is_import_suspect is not None:
                                                    return True

                                                if self.is_internal_path is not None:
                                                    return True

                                                if self.is_partial_best is not None:
                                                    return True

                                                if self.is_path_additional_path is not None:
                                                    return True

                                                if self.is_path_advertised_local_as_only is not None:
                                                    return True

                                                if self.is_path_af_install_eligible is not None:
                                                    return True

                                                if self.is_path_backup is not None:
                                                    return True

                                                if self.is_path_backup_protect_multipath is not None:
                                                    return True

                                                if self.is_path_best_external is not None:
                                                    return True

                                                if self.is_path_damped is not None:
                                                    return True

                                                if self.is_path_from_confederation_peer is not None:
                                                    return True

                                                if self.is_path_from_network_command is not None:
                                                    return True

                                                if self.is_path_from_redistribute_command is not None:
                                                    return True

                                                if self.is_path_from_route_reflector is not None:
                                                    return True

                                                if self.is_path_history_held is not None:
                                                    return True

                                                if self.is_path_imp_candidate is not None:
                                                    return True

                                                if self.is_path_imported is not None:
                                                    return True

                                                if self.is_path_local_aggregate is not None:
                                                    return True

                                                if self.is_path_locally_sourced is not None:
                                                    return True

                                                if self.is_path_long_lived_stale is not None:
                                                    return True

                                                if self.is_path_multipath is not None:
                                                    return True

                                                if self.is_path_nexthop_discarded is not None:
                                                    return True

                                                if self.is_path_not_advertised is not None:
                                                    return True

                                                if self.is_path_not_advertised_to_ebg_ps is not None:
                                                    return True

                                                if self.is_path_received_only is not None:
                                                    return True

                                                if self.is_path_reoriginated is not None:
                                                    return True

                                                if self.is_path_reoriginated_stitching is not None:
                                                    return True

                                                if self.is_path_stale is not None:
                                                    return True

                                                if self.is_path_synced_with_igp is not None:
                                                    return True

                                                if self.is_path_valid is not None:
                                                    return True

                                                if self.is_path_vpn_only is not None:
                                                    return True

                                                if self.is_permanent_path is not None:
                                                    return True

                                                if self.is_received_path_not_modified is not None:
                                                    return True

                                                if self.is_spkr_as_best is not None:
                                                    return True

                                                if self.l2vpn_circuit_status_value is not None:
                                                    for child_ref in self.l2vpn_circuit_status_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                    return True

                                                if self.l2vpn_size is not None:
                                                    return True

                                                if self.labeled_unicast_safi_path is not None:
                                                    return True

                                                if self.local_label is not None:
                                                    return True

                                                if self.local_nh is not None:
                                                    return True

                                                if self.local_path_id is not None:
                                                    return True

                                                if self.local_peers_advertised_to is not None:
                                                    for child_ref in self.local_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.maximum_suppress_time is not None:
                                                    return True

                                                if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                    return True

                                                if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                    return True

                                                if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                    return True

                                                if self.mvpn_path_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_label is not None:
                                                    return True

                                                if self.mvpn_pmsi_type is not None:
                                                    return True

                                                if self.mvpn_pmsi_value is not None:
                                                    for child_ref in self.mvpn_pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.mvpn_sfs_path is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.neighbor_router_id is not None:
                                                    return True

                                                if self.next_hop is not None and self.next_hop._has_data():
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.path_flags is not None:
                                                    return True

                                                if self.path_flap_count is not None:
                                                    return True

                                                if self.path_import_flags is not None:
                                                    return True

                                                if self.path_rt_set_id is not None:
                                                    return True

                                                if self.path_rt_set_route_count is not None:
                                                    return True

                                                if self.path_table_version is not None:
                                                    return True

                                                if self.path_weight is not None:
                                                    return True

                                                if self.pe_peers_advertised_to is not None:
                                                    for child_ref in self.pe_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.rcvd_label is not None:
                                                    return True

                                                if self.rcvd_path_id is not None:
                                                    return True

                                                if self.reuse_value is not None:
                                                    return True

                                                if self.rib_failed is not None:
                                                    return True

                                                if self.route_type is not None:
                                                    return True

                                                if self.rpki_origin_as_validation_disabled is not None:
                                                    return True

                                                if self.rt_set_limit_enabled is not None:
                                                    return True

                                                if self.second_label is not None:
                                                    return True

                                                if self.seconds_since_first_flap is not None:
                                                    return True

                                                if self.show_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.sn_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.suppress_penalty is not None:
                                                    return True

                                                if self.time_to_unsuppress is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation']['meta_info']


                                        class AttributesAfterPolicyIn(object):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self.is_application_gateway_present = None
                                                self.is_as_path2_byte = None
                                                self.is_attr_set_present = None
                                                self.is_ribrnh_present = None
                                                self.is_rnh_present = None
                                                self.ribrnh_encap = None
                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self.ribrnh_mac = None
                                                self.ribrnh_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnhip_table = None
                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self.rnh_addr_len = None
                                                self.rnh_len = None
                                                self.rnh_type = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.vpn_distinguisher = None


                                            class CommonAttributes(object):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                            class AttrSet(object):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                            class RnhAddr(object):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None
                                                    self.mac_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    if self.mac_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                            class RibrnhIp(object):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.attr_set is not None and self.attr_set._has_data():
                                                    return True

                                                if self.attribute_key_number is not None:
                                                    return True

                                                if self.attribute_reuse_id_config is not None:
                                                    return True

                                                if self.attribute_reuse_id_current is not None:
                                                    return True

                                                if self.attribute_reuse_id_keys is not None:
                                                    return True

                                                if self.attribute_reuse_id_max_id is not None:
                                                    return True

                                                if self.attribute_reuse_id_node is not None:
                                                    return True

                                                if self.attribute_reuse_id_recover_sec is not None:
                                                    return True

                                                if self.common_attributes is not None and self.common_attributes._has_data():
                                                    return True

                                                if self.is_application_gateway_present is not None:
                                                    return True

                                                if self.is_as_path2_byte is not None:
                                                    return True

                                                if self.is_attr_set_present is not None:
                                                    return True

                                                if self.is_ribrnh_present is not None:
                                                    return True

                                                if self.is_rnh_present is not None:
                                                    return True

                                                if self.ribrnh_encap is not None:
                                                    return True

                                                if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                    return True

                                                if self.ribrnh_mac is not None:
                                                    return True

                                                if self.ribrnh_table is not None:
                                                    return True

                                                if self.ribrnh_vni is not None:
                                                    return True

                                                if self.ribrnhip_table is not None:
                                                    return True

                                                if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                    return True

                                                if self.rnh_addr_len is not None:
                                                    return True

                                                if self.rnh_len is not None:
                                                    return True

                                                if self.rnh_type is not None:
                                                    return True

                                                if self.set_aigp_inbound_igp is not None:
                                                    return True

                                                if self.set_aigp_inbound_metric is not None:
                                                    return True

                                                if self.vpn_distinguisher is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-process-instance-path'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                return True

                                            if self.label_fail is not None:
                                                return True

                                            if self.label_o_or_version is not None:
                                                return True

                                            if self.label_oor is not None:
                                                return True

                                            if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                return True

                                            if self.no_path is not None:
                                                return True

                                            if self.path_information is not None and self.path_information._has_data():
                                                return True

                                            if self.prefix_version is not None:
                                                return True

                                            if self.process_instance_id is not None:
                                                return True

                                            if self.route_distinguisher is not None:
                                                return True

                                            if self.source_route_distinguisher is not None:
                                                return True

                                            if self.source_vrf_name is not None:
                                                return True

                                            if self.srcaf_name is not None:
                                                return True

                                            if self.vrf_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath']['meta_info']


                                    class ActiveProcessInstancePath(object):
                                        """
                                        Active's paths for this net 
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation>`
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self.label_fail = None
                                            self.label_o_or_version = None
                                            self.label_oor = None
                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self.no_path = None
                                            self.path_information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation()
                                            self.path_information.parent = self
                                            self.prefix_version = None
                                            self.process_instance_id = None
                                            self.route_distinguisher = None
                                            self.source_route_distinguisher = None
                                            self.source_vrf_name = None
                                            self.srcaf_name = None
                                            self.vrf_name = None


                                        class NeighborAddressXr(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.NeighborAddressXr']['meta_info']


                                        class PathInformation(object):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_esi
                                            
                                            	Path has EVPN ESI
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_rcvd_label
                                            
                                            	Path has received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebg_ps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi>`
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop>`
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhteTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_p_ath = None
                                                self.add_path_orr_bitfield = YList()
                                                self.add_path_orr_bitfield.parent = self
                                                self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                self.advertisedto_pe = None
                                                self.aigp_metric = None
                                                self.best_path_comp_stage = None
                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self.best_path_id = None
                                                self.best_path_id_comp_winner = None
                                                self.best_path_orr_bitfield = YList()
                                                self.best_path_orr_bitfield.parent = self
                                                self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self.dampen_penalty = None
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.fspec_invalid_path = None
                                                self.graceful_shutdown = None
                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self.halflife_time = None
                                                self.has_esi = None
                                                self.has_gw_addr = None
                                                self.has_local_net_label = None
                                                self.has_mdt_group_addr = None
                                                self.has_mvpn_extcomm = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.has_rcvd_label = None
                                                self.has_second_label = None
                                                self.ibgp_signaled_validity = None
                                                self.igp_metric = None
                                                self.is_aggregation_suppressed = None
                                                self.is_as_best = None
                                                self.is_best_path = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_internal_path = None
                                                self.is_partial_best = None
                                                self.is_path_additional_path = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_af_install_eligible = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_damped = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_history_held = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_imported = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_multipath = None
                                                self.is_path_nexthop_discarded = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebg_ps = None
                                                self.is_path_received_only = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_stale = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_valid = None
                                                self.is_path_vpn_only = None
                                                self.is_permanent_path = None
                                                self.is_received_path_not_modified = None
                                                self.is_spkr_as_best = None
                                                self.l2vpn_circuit_status_value = YList()
                                                self.l2vpn_circuit_status_value.parent = self
                                                self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi()
                                                self.l2vpn_evpn_esi.parent = self
                                                self.l2vpn_size = None
                                                self.labeled_unicast_safi_path = None
                                                self.local_label = None
                                                self.local_nh = None
                                                self.local_path_id = None
                                                self.local_peers_advertised_to = YList()
                                                self.local_peers_advertised_to.parent = self
                                                self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                self.maximum_suppress_time = None
                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self.mvpn_path_flags = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_value = YList()
                                                self.mvpn_pmsi_value.parent = self
                                                self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                self.mvpn_sfs_path = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.neighbor_router_id = None
                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.path_flags = None
                                                self.path_flap_count = None
                                                self.path_import_flags = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.path_table_version = None
                                                self.path_weight = None
                                                self.pe_peers_advertised_to = YList()
                                                self.pe_peers_advertised_to.parent = self
                                                self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                self.rcvd_label = None
                                                self.rcvd_path_id = None
                                                self.reuse_value = None
                                                self.rib_failed = None
                                                self.route_type = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.rt_set_limit_enabled = None
                                                self.second_label = None
                                                self.seconds_since_first_flap = None
                                                self.show_rpki_origin_as_validity = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.suppress_penalty = None
                                                self.time_to_unsuppress = None


                                            class BgpPrefix(object):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self.prefix_length = None


                                                class Prefix(object):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.prefix is not None and self.prefix._has_data():
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix']['meta_info']


                                            class NeighborAddress(object):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress']['meta_info']


                                            class NextHop(object):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhteTunnel']['meta_info']


                                            class MdtGroupAddr(object):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr']['meta_info']


                                            class L2VpnEvpnEsi(object):
                                                """
                                                L2VPN EVPN ESI
                                                
                                                .. attribute:: esi
                                                
                                                	esi
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.esi = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.esi is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi']['meta_info']


                                            class GwAddr(object):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr']['meta_info']


                                            class BestPathCompWinner(object):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner']['meta_info']


                                            class MvpnNbrAddr(object):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr']['meta_info']


                                            class MvpnNexthopAddr(object):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr']['meta_info']


                                            class L2VpnCircuitStatusValue(object):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                            class MvpnPmsiValue(object):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity']['meta_info']


                                            class LocalPeersAdvertisedTo(object):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                            class PePeersAdvertisedTo(object):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo']['meta_info']


                                            class BestPathOrrBitfield(object):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield']['meta_info']


                                            class AddPathOrrBitfield(object):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.accept_own_path is not None:
                                                    return True

                                                if self.accept_own_self_originated_p_ath is not None:
                                                    return True

                                                if self.add_path_orr_bitfield is not None:
                                                    for child_ref in self.add_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.advertisedto_pe is not None:
                                                    return True

                                                if self.aigp_metric is not None:
                                                    return True

                                                if self.best_path_comp_stage is not None:
                                                    return True

                                                if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                    return True

                                                if self.best_path_id is not None:
                                                    return True

                                                if self.best_path_id_comp_winner is not None:
                                                    return True

                                                if self.best_path_orr_bitfield is not None:
                                                    for child_ref in self.best_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                    return True

                                                if self.dampen_penalty is not None:
                                                    return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.fspec_invalid_path is not None:
                                                    return True

                                                if self.graceful_shutdown is not None:
                                                    return True

                                                if self.gw_addr is not None and self.gw_addr._has_data():
                                                    return True

                                                if self.halflife_time is not None:
                                                    return True

                                                if self.has_esi is not None:
                                                    return True

                                                if self.has_gw_addr is not None:
                                                    return True

                                                if self.has_local_net_label is not None:
                                                    return True

                                                if self.has_mdt_group_addr is not None:
                                                    return True

                                                if self.has_mvpn_extcomm is not None:
                                                    return True

                                                if self.has_mvpn_nbr_addr is not None:
                                                    return True

                                                if self.has_mvpn_nexthop_addr is not None:
                                                    return True

                                                if self.has_mvpn_pmsi is not None:
                                                    return True

                                                if self.has_rcvd_label is not None:
                                                    return True

                                                if self.has_second_label is not None:
                                                    return True

                                                if self.ibgp_signaled_validity is not None:
                                                    return True

                                                if self.igp_metric is not None:
                                                    return True

                                                if self.is_aggregation_suppressed is not None:
                                                    return True

                                                if self.is_as_best is not None:
                                                    return True

                                                if self.is_best_path is not None:
                                                    return True

                                                if self.is_import_dampened is not None:
                                                    return True

                                                if self.is_import_suspect is not None:
                                                    return True

                                                if self.is_internal_path is not None:
                                                    return True

                                                if self.is_partial_best is not None:
                                                    return True

                                                if self.is_path_additional_path is not None:
                                                    return True

                                                if self.is_path_advertised_local_as_only is not None:
                                                    return True

                                                if self.is_path_af_install_eligible is not None:
                                                    return True

                                                if self.is_path_backup is not None:
                                                    return True

                                                if self.is_path_backup_protect_multipath is not None:
                                                    return True

                                                if self.is_path_best_external is not None:
                                                    return True

                                                if self.is_path_damped is not None:
                                                    return True

                                                if self.is_path_from_confederation_peer is not None:
                                                    return True

                                                if self.is_path_from_network_command is not None:
                                                    return True

                                                if self.is_path_from_redistribute_command is not None:
                                                    return True

                                                if self.is_path_from_route_reflector is not None:
                                                    return True

                                                if self.is_path_history_held is not None:
                                                    return True

                                                if self.is_path_imp_candidate is not None:
                                                    return True

                                                if self.is_path_imported is not None:
                                                    return True

                                                if self.is_path_local_aggregate is not None:
                                                    return True

                                                if self.is_path_locally_sourced is not None:
                                                    return True

                                                if self.is_path_long_lived_stale is not None:
                                                    return True

                                                if self.is_path_multipath is not None:
                                                    return True

                                                if self.is_path_nexthop_discarded is not None:
                                                    return True

                                                if self.is_path_not_advertised is not None:
                                                    return True

                                                if self.is_path_not_advertised_to_ebg_ps is not None:
                                                    return True

                                                if self.is_path_received_only is not None:
                                                    return True

                                                if self.is_path_reoriginated is not None:
                                                    return True

                                                if self.is_path_reoriginated_stitching is not None:
                                                    return True

                                                if self.is_path_stale is not None:
                                                    return True

                                                if self.is_path_synced_with_igp is not None:
                                                    return True

                                                if self.is_path_valid is not None:
                                                    return True

                                                if self.is_path_vpn_only is not None:
                                                    return True

                                                if self.is_permanent_path is not None:
                                                    return True

                                                if self.is_received_path_not_modified is not None:
                                                    return True

                                                if self.is_spkr_as_best is not None:
                                                    return True

                                                if self.l2vpn_circuit_status_value is not None:
                                                    for child_ref in self.l2vpn_circuit_status_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                    return True

                                                if self.l2vpn_size is not None:
                                                    return True

                                                if self.labeled_unicast_safi_path is not None:
                                                    return True

                                                if self.local_label is not None:
                                                    return True

                                                if self.local_nh is not None:
                                                    return True

                                                if self.local_path_id is not None:
                                                    return True

                                                if self.local_peers_advertised_to is not None:
                                                    for child_ref in self.local_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.maximum_suppress_time is not None:
                                                    return True

                                                if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                    return True

                                                if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                    return True

                                                if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                    return True

                                                if self.mvpn_path_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_label is not None:
                                                    return True

                                                if self.mvpn_pmsi_type is not None:
                                                    return True

                                                if self.mvpn_pmsi_value is not None:
                                                    for child_ref in self.mvpn_pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.mvpn_sfs_path is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.neighbor_router_id is not None:
                                                    return True

                                                if self.next_hop is not None and self.next_hop._has_data():
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.path_flags is not None:
                                                    return True

                                                if self.path_flap_count is not None:
                                                    return True

                                                if self.path_import_flags is not None:
                                                    return True

                                                if self.path_rt_set_id is not None:
                                                    return True

                                                if self.path_rt_set_route_count is not None:
                                                    return True

                                                if self.path_table_version is not None:
                                                    return True

                                                if self.path_weight is not None:
                                                    return True

                                                if self.pe_peers_advertised_to is not None:
                                                    for child_ref in self.pe_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.rcvd_label is not None:
                                                    return True

                                                if self.rcvd_path_id is not None:
                                                    return True

                                                if self.reuse_value is not None:
                                                    return True

                                                if self.rib_failed is not None:
                                                    return True

                                                if self.route_type is not None:
                                                    return True

                                                if self.rpki_origin_as_validation_disabled is not None:
                                                    return True

                                                if self.rt_set_limit_enabled is not None:
                                                    return True

                                                if self.second_label is not None:
                                                    return True

                                                if self.seconds_since_first_flap is not None:
                                                    return True

                                                if self.show_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.sn_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.suppress_penalty is not None:
                                                    return True

                                                if self.time_to_unsuppress is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation']['meta_info']


                                        class AttributesAfterPolicyIn(object):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self.is_application_gateway_present = None
                                                self.is_as_path2_byte = None
                                                self.is_attr_set_present = None
                                                self.is_ribrnh_present = None
                                                self.is_rnh_present = None
                                                self.ribrnh_encap = None
                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self.ribrnh_mac = None
                                                self.ribrnh_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnhip_table = None
                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self.rnh_addr_len = None
                                                self.rnh_len = None
                                                self.rnh_type = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.vpn_distinguisher = None


                                            class CommonAttributes(object):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                            class AttrSet(object):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                            class RnhAddr(object):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None
                                                    self.mac_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    if self.mac_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                            class RibrnhIp(object):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.attr_set is not None and self.attr_set._has_data():
                                                    return True

                                                if self.attribute_key_number is not None:
                                                    return True

                                                if self.attribute_reuse_id_config is not None:
                                                    return True

                                                if self.attribute_reuse_id_current is not None:
                                                    return True

                                                if self.attribute_reuse_id_keys is not None:
                                                    return True

                                                if self.attribute_reuse_id_max_id is not None:
                                                    return True

                                                if self.attribute_reuse_id_node is not None:
                                                    return True

                                                if self.attribute_reuse_id_recover_sec is not None:
                                                    return True

                                                if self.common_attributes is not None and self.common_attributes._has_data():
                                                    return True

                                                if self.is_application_gateway_present is not None:
                                                    return True

                                                if self.is_as_path2_byte is not None:
                                                    return True

                                                if self.is_attr_set_present is not None:
                                                    return True

                                                if self.is_ribrnh_present is not None:
                                                    return True

                                                if self.is_rnh_present is not None:
                                                    return True

                                                if self.ribrnh_encap is not None:
                                                    return True

                                                if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                    return True

                                                if self.ribrnh_mac is not None:
                                                    return True

                                                if self.ribrnh_table is not None:
                                                    return True

                                                if self.ribrnh_vni is not None:
                                                    return True

                                                if self.ribrnhip_table is not None:
                                                    return True

                                                if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                    return True

                                                if self.rnh_addr_len is not None:
                                                    return True

                                                if self.rnh_len is not None:
                                                    return True

                                                if self.rnh_type is not None:
                                                    return True

                                                if self.set_aigp_inbound_igp is not None:
                                                    return True

                                                if self.set_aigp_inbound_metric is not None:
                                                    return True

                                                if self.vpn_distinguisher is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-process-instance-path'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                return True

                                            if self.label_fail is not None:
                                                return True

                                            if self.label_o_or_version is not None:
                                                return True

                                            if self.label_oor is not None:
                                                return True

                                            if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                return True

                                            if self.no_path is not None:
                                                return True

                                            if self.path_information is not None and self.path_information._has_data():
                                                return True

                                            if self.prefix_version is not None:
                                                return True

                                            if self.process_instance_id is not None:
                                                return True

                                            if self.route_distinguisher is not None:
                                                return True

                                            if self.source_route_distinguisher is not None:
                                                return True

                                            if self.source_vrf_name is not None:
                                                return True

                                            if self.srcaf_name is not None:
                                                return True

                                            if self.vrf_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath']['meta_info']


                                    class LocalPathElement(object):
                                        """
                                        Local path element list
                                        
                                        .. attribute:: is_perm_path_pelem
                                        
                                        	Pelem for permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: nhte_tunnel
                                        
                                        	NH TE tunnel information
                                        	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.NhteTunnel>`
                                        
                                        .. attribute:: pelem_flags
                                        
                                        	Flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_gw_metric
                                        
                                        	Gateway metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_addpath_table_attr_version
                                        
                                        	No\-addpath Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_bestpath_table_attr_version
                                        
                                        	No\-bestpath Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_flags
                                        
                                        	Path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: pelem_path_id
                                        
                                        	Local Path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_neighbor_addr
                                        
                                        	Path neighbor address
                                        	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr>`
                                        
                                        .. attribute:: pelem_path_nexthop
                                        
                                        	Path nexthop address
                                        	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop>`
                                        
                                        .. attribute:: pelem_path_peer_path_id
                                        
                                        	Path peer path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_table_attr_version
                                        
                                        	Path Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_table_attr_version
                                        
                                        	Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_version
                                        
                                        	Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.is_perm_path_pelem = None
                                            self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.NhteTunnel()
                                            self.nhte_tunnel.parent = self
                                            self.pelem_flags = None
                                            self.pelem_gw_metric = None
                                            self.pelem_no_addpath_table_attr_version = None
                                            self.pelem_no_bestpath_table_attr_version = None
                                            self.pelem_path_flags = None
                                            self.pelem_path_id = None
                                            self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr()
                                            self.pelem_path_neighbor_addr.parent = self
                                            self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop()
                                            self.pelem_path_nexthop.parent = self
                                            self.pelem_path_peer_path_id = None
                                            self.pelem_path_table_attr_version = None
                                            self.pelem_table_attr_version = None
                                            self.pelem_version = None


                                        class PelemPathNexthop(object):
                                            """
                                            Path nexthop address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-nexthop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop']['meta_info']


                                        class NhteTunnel(object):
                                            """
                                            NH TE tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_te_tunnel
                                            
                                            	NH TE Tunnel info is present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last rib update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	tunnel name
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	tunnel type
                                            	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.binding_label = None
                                                self.has_te_tunnel = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.is_tunnel_up = None
                                                self.last_tunnel_update = None
                                                self.tunnel_if_handle = None
                                                self.tunnel_name = None
                                                self.tunnel_type = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_v6_required = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.binding_label is not None:
                                                    return True

                                                if self.has_te_tunnel is not None:
                                                    return True

                                                if self.is_tunnel_info_stale is not None:
                                                    return True

                                                if self.is_tunnel_registered is not None:
                                                    return True

                                                if self.is_tunnel_up is not None:
                                                    return True

                                                if self.last_tunnel_update is not None:
                                                    return True

                                                if self.tunnel_if_handle is not None:
                                                    return True

                                                if self.tunnel_name is not None:
                                                    return True

                                                if self.tunnel_type is not None:
                                                    return True

                                                if self.tunnel_v6_enabled is not None:
                                                    return True

                                                if self.tunnel_v6_required is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.NhteTunnel']['meta_info']


                                        class PelemPathNeighborAddr(object):
                                            """
                                            Path neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-neighbor-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-path-element'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.is_perm_path_pelem is not None:
                                                return True

                                            if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                return True

                                            if self.pelem_flags is not None:
                                                return True

                                            if self.pelem_gw_metric is not None:
                                                return True

                                            if self.pelem_no_addpath_table_attr_version is not None:
                                                return True

                                            if self.pelem_no_bestpath_table_attr_version is not None:
                                                return True

                                            if self.pelem_path_flags is not None:
                                                return True

                                            if self.pelem_path_id is not None:
                                                return True

                                            if self.pelem_path_neighbor_addr is not None and self.pelem_path_neighbor_addr._has_data():
                                                return True

                                            if self.pelem_path_nexthop is not None and self.pelem_path_nexthop._has_data():
                                                return True

                                            if self.pelem_path_peer_path_id is not None:
                                                return True

                                            if self.pelem_path_table_attr_version is not None:
                                                return True

                                            if self.pelem_table_attr_version is not None:
                                                return True

                                            if self.pelem_version is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement']['meta_info']


                                    class ActivePathElement(object):
                                        """
                                        Path element list received from Active inst
                                        
                                        .. attribute:: is_perm_path_pelem
                                        
                                        	Pelem for permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: nhte_tunnel
                                        
                                        	NH TE tunnel information
                                        	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.NhteTunnel>`
                                        
                                        .. attribute:: pelem_flags
                                        
                                        	Flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_gw_metric
                                        
                                        	Gateway metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_addpath_table_attr_version
                                        
                                        	No\-addpath Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_bestpath_table_attr_version
                                        
                                        	No\-bestpath Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_flags
                                        
                                        	Path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: pelem_path_id
                                        
                                        	Local Path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_neighbor_addr
                                        
                                        	Path neighbor address
                                        	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr>`
                                        
                                        .. attribute:: pelem_path_nexthop
                                        
                                        	Path nexthop address
                                        	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop>`
                                        
                                        .. attribute:: pelem_path_peer_path_id
                                        
                                        	Path peer path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_table_attr_version
                                        
                                        	Path Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_table_attr_version
                                        
                                        	Table Attr version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_version
                                        
                                        	Version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.is_perm_path_pelem = None
                                            self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.NhteTunnel()
                                            self.nhte_tunnel.parent = self
                                            self.pelem_flags = None
                                            self.pelem_gw_metric = None
                                            self.pelem_no_addpath_table_attr_version = None
                                            self.pelem_no_bestpath_table_attr_version = None
                                            self.pelem_path_flags = None
                                            self.pelem_path_id = None
                                            self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr()
                                            self.pelem_path_neighbor_addr.parent = self
                                            self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop()
                                            self.pelem_path_nexthop.parent = self
                                            self.pelem_path_peer_path_id = None
                                            self.pelem_path_table_attr_version = None
                                            self.pelem_table_attr_version = None
                                            self.pelem_version = None


                                        class PelemPathNexthop(object):
                                            """
                                            Path nexthop address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-nexthop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop']['meta_info']


                                        class NhteTunnel(object):
                                            """
                                            NH TE tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_te_tunnel
                                            
                                            	NH TE Tunnel info is present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last rib update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	tunnel name
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	tunnel type
                                            	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.binding_label = None
                                                self.has_te_tunnel = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.is_tunnel_up = None
                                                self.last_tunnel_update = None
                                                self.tunnel_if_handle = None
                                                self.tunnel_name = None
                                                self.tunnel_type = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_v6_required = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.binding_label is not None:
                                                    return True

                                                if self.has_te_tunnel is not None:
                                                    return True

                                                if self.is_tunnel_info_stale is not None:
                                                    return True

                                                if self.is_tunnel_registered is not None:
                                                    return True

                                                if self.is_tunnel_up is not None:
                                                    return True

                                                if self.last_tunnel_update is not None:
                                                    return True

                                                if self.tunnel_if_handle is not None:
                                                    return True

                                                if self.tunnel_name is not None:
                                                    return True

                                                if self.tunnel_type is not None:
                                                    return True

                                                if self.tunnel_v6_enabled is not None:
                                                    return True

                                                if self.tunnel_v6_required is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.NhteTunnel']['meta_info']


                                        class PelemPathNeighborAddr(object):
                                            """
                                            Path neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-neighbor-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-path-element'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.is_perm_path_pelem is not None:
                                                return True

                                            if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                return True

                                            if self.pelem_flags is not None:
                                                return True

                                            if self.pelem_gw_metric is not None:
                                                return True

                                            if self.pelem_no_addpath_table_attr_version is not None:
                                                return True

                                            if self.pelem_no_bestpath_table_attr_version is not None:
                                                return True

                                            if self.pelem_path_flags is not None:
                                                return True

                                            if self.pelem_path_id is not None:
                                                return True

                                            if self.pelem_path_neighbor_addr is not None and self.pelem_path_neighbor_addr._has_data():
                                                return True

                                            if self.pelem_path_nexthop is not None and self.pelem_path_nexthop._has_data():
                                                return True

                                            if self.pelem_path_peer_path_id is not None:
                                                return True

                                            if self.pelem_path_table_attr_version is not None:
                                                return True

                                            if self.pelem_table_attr_version is not None:
                                                return True

                                            if self.pelem_version is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.active_path_element is not None:
                                            for child_ref in self.active_path_element:
                                                if child_ref._has_data():
                                                    return True

                                        if self.active_process_instance_path is not None:
                                            for child_ref in self.active_process_instance_path:
                                                if child_ref._has_data():
                                                    return True

                                        if self.add_path_orr_bitfield is not None:
                                            for child_ref in self.add_path_orr_bitfield:
                                                if child_ref._has_data():
                                                    return True

                                        if self.advertisedto_pe is not None:
                                            return True

                                        if self.af_name is not None:
                                            return True

                                        if self.best_path_orr_bitfield is not None:
                                            for child_ref in self.best_path_orr_bitfield:
                                                if child_ref._has_data():
                                                    return True

                                        if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                            return True

                                        if self.bit is not None:
                                            return True

                                        if self.flags is not None:
                                            return True

                                        if self.gateway_array is not None:
                                            return True

                                        if self.has_inconsistent_paths is not None:
                                            return True

                                        if self.has_lbl_retained is not None:
                                            return True

                                        if self.has_local_label is not None:
                                            return True

                                        if self.is_net_aggregation_suppressed is not None:
                                            return True

                                        if self.is_net_ldp_signaled is not None:
                                            return True

                                        if self.is_permanent_network is not None:
                                            return True

                                        if self.local_path_element is not None:
                                            for child_ref in self.local_path_element:
                                                if child_ref._has_data():
                                                    return True

                                        if self.local_peers_advertised_to is not None:
                                            for child_ref in self.local_peers_advertised_to:
                                                if child_ref._has_data():
                                                    return True

                                        if self.local_process_instance_path is not None:
                                            for child_ref in self.local_process_instance_path:
                                                if child_ref._has_data():
                                                    return True

                                        if self.net_backup_available is not None:
                                            return True

                                        if self.net_backup_label_rewrite_available is not None:
                                            return True

                                        if self.net_eibgp_multipath is not None:
                                            return True

                                        if self.net_extended_flags is not None:
                                            return True

                                        if self.net_flags is not None:
                                            return True

                                        if self.net_local_label is not None:
                                            return True

                                        if self.net_local_label_rewrite is not None:
                                            return True

                                        if self.net_local_label_srgb is not None:
                                            return True

                                        if self.net_multipath is not None:
                                            return True

                                        if self.network is not None:
                                            return True

                                        if self.num_of_path is not None:
                                            return True

                                        if self.pe_peers_advertised_to is not None:
                                            for child_ref in self.pe_peers_advertised_to:
                                                if child_ref._has_data():
                                                    return True

                                        if self.process_instance_id is not None:
                                            return True

                                        if self.rd is not None:
                                            return True

                                        if self.resilient_nexthop_set is not None:
                                            return True

                                        if self.rib_failed is not None:
                                            return True

                                        if self.route_distinguisher is not None:
                                            return True

                                        if self.table_brib_version is not None:
                                            return True

                                        if self.table_version is not None:
                                            return True

                                        if self.version is not None:
                                            return True

                                        if self.version_age is not None and self.version_age._has_data():
                                            return True

                                        if self.version_timestamp is not None and self.version_timestamp._has_data():
                                            return True

                                        if self.vrf_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:networks'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.network is not None:
                                        for child_ref in self.network:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks']['meta_info']


                            class PathTable(object):
                                """
                                The BGP Path Table
                                
                                .. attribute:: path
                                
                                	A BGP path table entry
                                	**type**\: list of    :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.path = YList()
                                    self.path.parent = self
                                    self.path.name = 'path'


                                class Path(object):
                                    """
                                    A BGP path table entry
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: attributes_after_policy_in
                                    
                                    	Attributes after inbound policy applied
                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn>`
                                    
                                    .. attribute:: label_fail
                                    
                                    	LSD label allocation failed 
                                    	**type**\:  bool
                                    
                                    .. attribute:: label_o_or_version
                                    
                                    	Label Version when OOR happens
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_oor
                                    
                                    	LSD label space is exhausted
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor adddress
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr>`
                                    
                                    .. attribute:: network
                                    
                                    	Network Prefix in Hex format
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: no_path
                                    
                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_id
                                    
                                    	Received Path ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: path_information
                                    
                                    	Path information
                                    	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: prefix_version
                                    
                                    	Version of BGP Prefix Table
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: route_type
                                    
                                    	Route Type
                                    	**type**\:   :py:class:`BgpRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRouteEnum>`
                                    
                                    .. attribute:: source_rd
                                    
                                    	Source Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: source_route_distinguisher
                                    
                                    	Source Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_vrf_name
                                    
                                    	Name of the source VRF
                                    	**type**\:  str
                                    
                                    .. attribute:: srcaf_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn()
                                        self.attributes_after_policy_in.parent = self
                                        self.label_fail = None
                                        self.label_o_or_version = None
                                        self.label_oor = None
                                        self.neighbor_address = None
                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr()
                                        self.neighbor_address_xr.parent = self
                                        self.network = None
                                        self.no_path = None
                                        self.path_id = None
                                        self.path_information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation()
                                        self.path_information.parent = self
                                        self.prefix_length = None
                                        self.prefix_version = None
                                        self.process_instance_id = None
                                        self.rd = None
                                        self.route_distinguisher = None
                                        self.route_type = None
                                        self.source_rd = None
                                        self.source_route_distinguisher = None
                                        self.source_vrf_name = None
                                        self.srcaf_name = None
                                        self.vrf_name = None


                                    class NeighborAddressXr(object):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.NeighborAddressXr']['meta_info']


                                    class PathInformation(object):
                                        """
                                        Path information
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_own_self_originated_p_ath
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\:  bool
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield>`
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner>`
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix>`
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity>`
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\:  bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\:  bool
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.GwAddr>`
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_esi
                                        
                                        	Path has EVPN ESI
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_rcvd_label
                                        
                                        	Path has received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\:  bool
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebg_ps
                                        
                                        	Not advertised to EBGPs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.L2VpnCircuitStatusValue>`
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.L2VpnEvpnEsi>`
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr>`
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue>`
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress>`
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop>`
                                        
                                        .. attribute:: nhte_tunnel
                                        
                                        	NH TE tunnel information
                                        	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhteTunnel>`
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\:  bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.accept_own_path = None
                                            self.accept_own_self_originated_p_ath = None
                                            self.add_path_orr_bitfield = YList()
                                            self.add_path_orr_bitfield.parent = self
                                            self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                            self.advertisedto_pe = None
                                            self.aigp_metric = None
                                            self.best_path_comp_stage = None
                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self.best_path_id = None
                                            self.best_path_id_comp_winner = None
                                            self.best_path_orr_bitfield = YList()
                                            self.best_path_orr_bitfield.parent = self
                                            self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self.dampen_penalty = None
                                            self.extended_community = YList()
                                            self.extended_community.parent = self
                                            self.extended_community.name = 'extended_community'
                                            self.fspec_invalid_path = None
                                            self.graceful_shutdown = None
                                            self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.GwAddr()
                                            self.gw_addr.parent = self
                                            self.halflife_time = None
                                            self.has_esi = None
                                            self.has_gw_addr = None
                                            self.has_local_net_label = None
                                            self.has_mdt_group_addr = None
                                            self.has_mvpn_extcomm = None
                                            self.has_mvpn_nbr_addr = None
                                            self.has_mvpn_nexthop_addr = None
                                            self.has_mvpn_pmsi = None
                                            self.has_rcvd_label = None
                                            self.has_second_label = None
                                            self.ibgp_signaled_validity = None
                                            self.igp_metric = None
                                            self.is_aggregation_suppressed = None
                                            self.is_as_best = None
                                            self.is_best_path = None
                                            self.is_import_dampened = None
                                            self.is_import_suspect = None
                                            self.is_internal_path = None
                                            self.is_partial_best = None
                                            self.is_path_additional_path = None
                                            self.is_path_advertised_local_as_only = None
                                            self.is_path_af_install_eligible = None
                                            self.is_path_backup = None
                                            self.is_path_backup_protect_multipath = None
                                            self.is_path_best_external = None
                                            self.is_path_damped = None
                                            self.is_path_from_confederation_peer = None
                                            self.is_path_from_network_command = None
                                            self.is_path_from_redistribute_command = None
                                            self.is_path_from_route_reflector = None
                                            self.is_path_history_held = None
                                            self.is_path_imp_candidate = None
                                            self.is_path_imported = None
                                            self.is_path_local_aggregate = None
                                            self.is_path_locally_sourced = None
                                            self.is_path_long_lived_stale = None
                                            self.is_path_multipath = None
                                            self.is_path_nexthop_discarded = None
                                            self.is_path_not_advertised = None
                                            self.is_path_not_advertised_to_ebg_ps = None
                                            self.is_path_received_only = None
                                            self.is_path_reoriginated = None
                                            self.is_path_reoriginated_stitching = None
                                            self.is_path_stale = None
                                            self.is_path_synced_with_igp = None
                                            self.is_path_valid = None
                                            self.is_path_vpn_only = None
                                            self.is_permanent_path = None
                                            self.is_received_path_not_modified = None
                                            self.is_spkr_as_best = None
                                            self.l2vpn_circuit_status_value = YList()
                                            self.l2vpn_circuit_status_value.parent = self
                                            self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                            self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.L2VpnEvpnEsi()
                                            self.l2vpn_evpn_esi.parent = self
                                            self.l2vpn_size = None
                                            self.labeled_unicast_safi_path = None
                                            self.local_label = None
                                            self.local_nh = None
                                            self.local_path_id = None
                                            self.local_peers_advertised_to = YList()
                                            self.local_peers_advertised_to.parent = self
                                            self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                            self.maximum_suppress_time = None
                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self.mvpn_path_flags = None
                                            self.mvpn_pmsi_flags = None
                                            self.mvpn_pmsi_label = None
                                            self.mvpn_pmsi_type = None
                                            self.mvpn_pmsi_value = YList()
                                            self.mvpn_pmsi_value.parent = self
                                            self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                            self.mvpn_sfs_path = None
                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self.neighbor_router_id = None
                                            self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop()
                                            self.next_hop.parent = self
                                            self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhteTunnel()
                                            self.nhte_tunnel.parent = self
                                            self.path_flags = None
                                            self.path_flap_count = None
                                            self.path_import_flags = None
                                            self.path_rt_set_id = None
                                            self.path_rt_set_route_count = None
                                            self.path_table_version = None
                                            self.path_weight = None
                                            self.pe_peers_advertised_to = YList()
                                            self.pe_peers_advertised_to.parent = self
                                            self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                            self.rcvd_label = None
                                            self.rcvd_path_id = None
                                            self.reuse_value = None
                                            self.rib_failed = None
                                            self.route_type = None
                                            self.rpki_origin_as_validation_disabled = None
                                            self.rt_set_limit_enabled = None
                                            self.second_label = None
                                            self.seconds_since_first_flap = None
                                            self.show_rpki_origin_as_validity = None
                                            self.sn_rpki_origin_as_validity = None
                                            self.suppress_penalty = None
                                            self.time_to_unsuppress = None


                                        class BgpPrefix(object):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self.prefix_length = None


                                            class Prefix(object):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.prefix is not None and self.prefix._has_data():
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix']['meta_info']


                                        class NeighborAddress(object):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress']['meta_info']


                                        class NextHop(object):
                                            """
                                            Next hop
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop']['meta_info']


                                        class NhteTunnel(object):
                                            """
                                            NH TE tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_te_tunnel
                                            
                                            	NH TE Tunnel info is present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last rib update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	tunnel name
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	tunnel type
                                            	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.binding_label = None
                                                self.has_te_tunnel = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.is_tunnel_up = None
                                                self.last_tunnel_update = None
                                                self.tunnel_if_handle = None
                                                self.tunnel_name = None
                                                self.tunnel_type = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_v6_required = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.binding_label is not None:
                                                    return True

                                                if self.has_te_tunnel is not None:
                                                    return True

                                                if self.is_tunnel_info_stale is not None:
                                                    return True

                                                if self.is_tunnel_registered is not None:
                                                    return True

                                                if self.is_tunnel_up is not None:
                                                    return True

                                                if self.last_tunnel_update is not None:
                                                    return True

                                                if self.tunnel_if_handle is not None:
                                                    return True

                                                if self.tunnel_name is not None:
                                                    return True

                                                if self.tunnel_type is not None:
                                                    return True

                                                if self.tunnel_v6_enabled is not None:
                                                    return True

                                                if self.tunnel_v6_required is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhteTunnel']['meta_info']


                                        class MdtGroupAddr(object):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr']['meta_info']


                                        class L2VpnEvpnEsi(object):
                                            """
                                            L2VPN EVPN ESI
                                            
                                            .. attribute:: esi
                                            
                                            	esi
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.esi = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.esi is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.L2VpnEvpnEsi']['meta_info']


                                        class GwAddr(object):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.len = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.len is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.GwAddr']['meta_info']


                                        class BestPathCompWinner(object):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner']['meta_info']


                                        class MvpnNbrAddr(object):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr']['meta_info']


                                        class MvpnNexthopAddr(object):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr']['meta_info']


                                        class L2VpnCircuitStatusValue(object):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                        class MvpnPmsiValue(object):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue']['meta_info']


                                        class ExtendedCommunity(object):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity']['meta_info']


                                        class LocalPeersAdvertisedTo(object):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                        class PePeersAdvertisedTo(object):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo']['meta_info']


                                        class BestPathOrrBitfield(object):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield']['meta_info']


                                        class AddPathOrrBitfield(object):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.accept_own_path is not None:
                                                return True

                                            if self.accept_own_self_originated_p_ath is not None:
                                                return True

                                            if self.add_path_orr_bitfield is not None:
                                                for child_ref in self.add_path_orr_bitfield:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.advertisedto_pe is not None:
                                                return True

                                            if self.aigp_metric is not None:
                                                return True

                                            if self.best_path_comp_stage is not None:
                                                return True

                                            if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                return True

                                            if self.best_path_id is not None:
                                                return True

                                            if self.best_path_id_comp_winner is not None:
                                                return True

                                            if self.best_path_orr_bitfield is not None:
                                                for child_ref in self.best_path_orr_bitfield:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                return True

                                            if self.dampen_penalty is not None:
                                                return True

                                            if self.extended_community is not None:
                                                for child_ref in self.extended_community:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.fspec_invalid_path is not None:
                                                return True

                                            if self.graceful_shutdown is not None:
                                                return True

                                            if self.gw_addr is not None and self.gw_addr._has_data():
                                                return True

                                            if self.halflife_time is not None:
                                                return True

                                            if self.has_esi is not None:
                                                return True

                                            if self.has_gw_addr is not None:
                                                return True

                                            if self.has_local_net_label is not None:
                                                return True

                                            if self.has_mdt_group_addr is not None:
                                                return True

                                            if self.has_mvpn_extcomm is not None:
                                                return True

                                            if self.has_mvpn_nbr_addr is not None:
                                                return True

                                            if self.has_mvpn_nexthop_addr is not None:
                                                return True

                                            if self.has_mvpn_pmsi is not None:
                                                return True

                                            if self.has_rcvd_label is not None:
                                                return True

                                            if self.has_second_label is not None:
                                                return True

                                            if self.ibgp_signaled_validity is not None:
                                                return True

                                            if self.igp_metric is not None:
                                                return True

                                            if self.is_aggregation_suppressed is not None:
                                                return True

                                            if self.is_as_best is not None:
                                                return True

                                            if self.is_best_path is not None:
                                                return True

                                            if self.is_import_dampened is not None:
                                                return True

                                            if self.is_import_suspect is not None:
                                                return True

                                            if self.is_internal_path is not None:
                                                return True

                                            if self.is_partial_best is not None:
                                                return True

                                            if self.is_path_additional_path is not None:
                                                return True

                                            if self.is_path_advertised_local_as_only is not None:
                                                return True

                                            if self.is_path_af_install_eligible is not None:
                                                return True

                                            if self.is_path_backup is not None:
                                                return True

                                            if self.is_path_backup_protect_multipath is not None:
                                                return True

                                            if self.is_path_best_external is not None:
                                                return True

                                            if self.is_path_damped is not None:
                                                return True

                                            if self.is_path_from_confederation_peer is not None:
                                                return True

                                            if self.is_path_from_network_command is not None:
                                                return True

                                            if self.is_path_from_redistribute_command is not None:
                                                return True

                                            if self.is_path_from_route_reflector is not None:
                                                return True

                                            if self.is_path_history_held is not None:
                                                return True

                                            if self.is_path_imp_candidate is not None:
                                                return True

                                            if self.is_path_imported is not None:
                                                return True

                                            if self.is_path_local_aggregate is not None:
                                                return True

                                            if self.is_path_locally_sourced is not None:
                                                return True

                                            if self.is_path_long_lived_stale is not None:
                                                return True

                                            if self.is_path_multipath is not None:
                                                return True

                                            if self.is_path_nexthop_discarded is not None:
                                                return True

                                            if self.is_path_not_advertised is not None:
                                                return True

                                            if self.is_path_not_advertised_to_ebg_ps is not None:
                                                return True

                                            if self.is_path_received_only is not None:
                                                return True

                                            if self.is_path_reoriginated is not None:
                                                return True

                                            if self.is_path_reoriginated_stitching is not None:
                                                return True

                                            if self.is_path_stale is not None:
                                                return True

                                            if self.is_path_synced_with_igp is not None:
                                                return True

                                            if self.is_path_valid is not None:
                                                return True

                                            if self.is_path_vpn_only is not None:
                                                return True

                                            if self.is_permanent_path is not None:
                                                return True

                                            if self.is_received_path_not_modified is not None:
                                                return True

                                            if self.is_spkr_as_best is not None:
                                                return True

                                            if self.l2vpn_circuit_status_value is not None:
                                                for child_ref in self.l2vpn_circuit_status_value:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                return True

                                            if self.l2vpn_size is not None:
                                                return True

                                            if self.labeled_unicast_safi_path is not None:
                                                return True

                                            if self.local_label is not None:
                                                return True

                                            if self.local_nh is not None:
                                                return True

                                            if self.local_path_id is not None:
                                                return True

                                            if self.local_peers_advertised_to is not None:
                                                for child_ref in self.local_peers_advertised_to:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.maximum_suppress_time is not None:
                                                return True

                                            if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                return True

                                            if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                return True

                                            if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                return True

                                            if self.mvpn_path_flags is not None:
                                                return True

                                            if self.mvpn_pmsi_flags is not None:
                                                return True

                                            if self.mvpn_pmsi_label is not None:
                                                return True

                                            if self.mvpn_pmsi_type is not None:
                                                return True

                                            if self.mvpn_pmsi_value is not None:
                                                for child_ref in self.mvpn_pmsi_value:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.mvpn_sfs_path is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            if self.neighbor_router_id is not None:
                                                return True

                                            if self.next_hop is not None and self.next_hop._has_data():
                                                return True

                                            if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                return True

                                            if self.path_flags is not None:
                                                return True

                                            if self.path_flap_count is not None:
                                                return True

                                            if self.path_import_flags is not None:
                                                return True

                                            if self.path_rt_set_id is not None:
                                                return True

                                            if self.path_rt_set_route_count is not None:
                                                return True

                                            if self.path_table_version is not None:
                                                return True

                                            if self.path_weight is not None:
                                                return True

                                            if self.pe_peers_advertised_to is not None:
                                                for child_ref in self.pe_peers_advertised_to:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.rcvd_label is not None:
                                                return True

                                            if self.rcvd_path_id is not None:
                                                return True

                                            if self.reuse_value is not None:
                                                return True

                                            if self.rib_failed is not None:
                                                return True

                                            if self.route_type is not None:
                                                return True

                                            if self.rpki_origin_as_validation_disabled is not None:
                                                return True

                                            if self.rt_set_limit_enabled is not None:
                                                return True

                                            if self.second_label is not None:
                                                return True

                                            if self.seconds_since_first_flap is not None:
                                                return True

                                            if self.show_rpki_origin_as_validity is not None:
                                                return True

                                            if self.sn_rpki_origin_as_validity is not None:
                                                return True

                                            if self.suppress_penalty is not None:
                                                return True

                                            if self.time_to_unsuppress is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation']['meta_info']


                                    class AttributesAfterPolicyIn(object):
                                        """
                                        Attributes after inbound policy applied
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet>`
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes>`
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp>`
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr>`
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\:  bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet()
                                            self.attr_set.parent = self
                                            self.attribute_key_number = None
                                            self.attribute_reuse_id_config = None
                                            self.attribute_reuse_id_current = None
                                            self.attribute_reuse_id_keys = None
                                            self.attribute_reuse_id_max_id = None
                                            self.attribute_reuse_id_node = None
                                            self.attribute_reuse_id_recover_sec = None
                                            self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self.is_application_gateway_present = None
                                            self.is_as_path2_byte = None
                                            self.is_attr_set_present = None
                                            self.is_ribrnh_present = None
                                            self.is_rnh_present = None
                                            self.ribrnh_encap = None
                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self.ribrnh_mac = None
                                            self.ribrnh_table = None
                                            self.ribrnh_vni = None
                                            self.ribrnhip_table = None
                                            self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self.rnh_addr_len = None
                                            self.rnh_len = None
                                            self.rnh_type = None
                                            self.set_aigp_inbound_igp = None
                                            self.set_aigp_inbound_metric = None
                                            self.vpn_distinguisher = None


                                        class CommonAttributes(object):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_encap_present
                                            
                                            	Tunnel Encap attribute present 
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_policy_allocated_binding_sid
                                            
                                            	SR Policy allocated Binding sid by the router
                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                            
                                            .. attribute:: sr_policy_binding_sid
                                            
                                            	SR Policy Binding sid
                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                            
                                            .. attribute:: sr_policy_explicit_path
                                            
                                            	SR Policy Explicit paths
                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                            
                                            .. attribute:: sr_policy_preference
                                            
                                            	SR Policy Preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_tunnel_request_state
                                            
                                            	SR Tunnel Request State
                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                            
                                            .. attribute:: sr_tunnel_state
                                            
                                            	SR Tunnel State
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap_type
                                            
                                            	Tunnel Encap Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.aggregator_address = None
                                                self.aggregator_as = None
                                                self.aigp_metric_value = None
                                                self.as_path = None
                                                self.cluster = YList()
                                                self.cluster.parent = self
                                                self.cluster.name = 'cluster'
                                                self.community = YList()
                                                self.community.parent = self
                                                self.community.name = 'community'
                                                self.connector_type = None
                                                self.connector_value = YList()
                                                self.connector_value.parent = self
                                                self.connector_value.name = 'connector_value'
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.extended_community_flags = None
                                                self.is_aggregator_present = None
                                                self.is_aigp_present = None
                                                self.is_as_path_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_community_present = None
                                                self.is_connector_present = None
                                                self.is_extended_community_present = None
                                                self.is_label_index_present = None
                                                self.is_local_pref_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_metric_present = None
                                                self.is_origin_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_ssa_present = None
                                                self.is_tunnel_encap_present = None
                                                self.l2tpv3_cookie = YList()
                                                self.l2tpv3_cookie.parent = self
                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                self.l2tpv3_session_id = None
                                                self.label_index_attr = YList()
                                                self.label_index_attr.parent = self
                                                self.label_index_attr.name = 'label_index_attr'
                                                self.local_preference = None
                                                self.ls_attr = YList()
                                                self.ls_attr.parent = self
                                                self.ls_attr.name = 'ls_attr'
                                                self.metric = None
                                                self.neighbor_as = None
                                                self.origin = None
                                                self.originator = None
                                                self.pe_distinguisher_label = YList()
                                                self.pe_distinguisher_label.parent = self
                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.pmsi_type = None
                                                self.pmsi_value = YList()
                                                self.pmsi_value.parent = self
                                                self.pmsi_value.name = 'pmsi_value'
                                                self.ppm_pvalue = None
                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                self.sr_policy_allocated_binding_sid.parent = self
                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                self.sr_policy_binding_sid.parent = self
                                                self.sr_policy_explicit_path = YList()
                                                self.sr_policy_explicit_path.parent = self
                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                self.sr_policy_preference = None
                                                self.sr_tunnel_request_state = None
                                                self.sr_tunnel_state = None
                                                self.tunnel_encap_type = None
                                                self.unknown_attribute = YList()
                                                self.unknown_attribute.parent = self
                                                self.unknown_attribute.name = 'unknown_attribute'


                                            class SrPolicyBindingSid(object):
                                                """
                                                SR Policy Binding sid
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                            class SrPolicyAllocatedBindingSid(object):
                                                """
                                                SR Policy allocated Binding sid by the router
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                            class Community(object):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                            class UnknownAttribute(object):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                            class Cluster(object):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                            class L2Tpv3Cookie(object):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                            class ConnectorValue(object):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                            class PmsiValue(object):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                            class LsAttr(object):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                            class LabelIndexAttr(object):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                            class PeDistinguisherLabel(object):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.label = None
                                                    self.pe_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.label is not None:
                                                        return True

                                                    if self.pe_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                            class SrPolicyExplicitPath(object):
                                                """
                                                SR Policy Explicit paths
                                                
                                                .. attribute:: sid
                                                
                                                	Sidlist for explicit path
                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                
                                                .. attribute:: weight
                                                
                                                	Weight of explicit path
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.sid = YList()
                                                    self.sid.parent = self
                                                    self.sid.name = 'sid'
                                                    self.weight = None


                                                class Sid(object):
                                                    """
                                                    Sidlist for explicit path
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IP Address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label sid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Sid Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4 is not None:
                                                            return True

                                                        if self.ipv6 is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.sid is not None:
                                                        for child_ref in self.sid:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.weight is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.aggregator_address is not None:
                                                    return True

                                                if self.aggregator_as is not None:
                                                    return True

                                                if self.aigp_metric_value is not None:
                                                    return True

                                                if self.as_path is not None:
                                                    return True

                                                if self.cluster is not None:
                                                    for child_ref in self.cluster:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.community is not None:
                                                    for child_ref in self.community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.connector_type is not None:
                                                    return True

                                                if self.connector_value is not None:
                                                    for child_ref in self.connector_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community_flags is not None:
                                                    return True

                                                if self.is_aggregator_present is not None:
                                                    return True

                                                if self.is_aigp_present is not None:
                                                    return True

                                                if self.is_as_path_present is not None:
                                                    return True

                                                if self.is_atomic_aggregate_present is not None:
                                                    return True

                                                if self.is_community_present is not None:
                                                    return True

                                                if self.is_connector_present is not None:
                                                    return True

                                                if self.is_extended_community_present is not None:
                                                    return True

                                                if self.is_label_index_present is not None:
                                                    return True

                                                if self.is_local_pref_present is not None:
                                                    return True

                                                if self.is_ls_attribute_present is not None:
                                                    return True

                                                if self.is_metric_present is not None:
                                                    return True

                                                if self.is_origin_present is not None:
                                                    return True

                                                if self.is_pe_distinguisher_label_present is not None:
                                                    return True

                                                if self.is_pmsi_present is not None:
                                                    return True

                                                if self.is_pppmp_present is not None:
                                                    return True

                                                if self.is_ssa_present is not None:
                                                    return True

                                                if self.is_tunnel_encap_present is not None:
                                                    return True

                                                if self.l2tpv3_cookie is not None:
                                                    for child_ref in self.l2tpv3_cookie:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2tpv3_session_id is not None:
                                                    return True

                                                if self.label_index_attr is not None:
                                                    for child_ref in self.label_index_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_preference is not None:
                                                    return True

                                                if self.ls_attr is not None:
                                                    for child_ref in self.ls_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.metric is not None:
                                                    return True

                                                if self.neighbor_as is not None:
                                                    return True

                                                if self.origin is not None:
                                                    return True

                                                if self.originator is not None:
                                                    return True

                                                if self.pe_distinguisher_label is not None:
                                                    for child_ref in self.pe_distinguisher_label:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.pmsi_flags is not None:
                                                    return True

                                                if self.pmsi_label is not None:
                                                    return True

                                                if self.pmsi_type is not None:
                                                    return True

                                                if self.pmsi_value is not None:
                                                    for child_ref in self.pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.ppm_pvalue is not None:
                                                    return True

                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_explicit_path is not None:
                                                    for child_ref in self.sr_policy_explicit_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.sr_policy_preference is not None:
                                                    return True

                                                if self.sr_tunnel_request_state is not None:
                                                    return True

                                                if self.sr_tunnel_state is not None:
                                                    return True

                                                if self.tunnel_encap_type is not None:
                                                    return True

                                                if self.unknown_attribute is not None:
                                                    for child_ref in self.unknown_attribute:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                        class AttrSet(object):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_encap_present
                                            
                                            	Tunnel Encap attribute present 
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_policy_allocated_binding_sid
                                            
                                            	SR Policy allocated Binding sid by the router
                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                            
                                            .. attribute:: sr_policy_binding_sid
                                            
                                            	SR Policy Binding sid
                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                            
                                            .. attribute:: sr_policy_explicit_path
                                            
                                            	SR Policy Explicit paths
                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                            
                                            .. attribute:: sr_policy_preference
                                            
                                            	SR Policy Preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_tunnel_request_state
                                            
                                            	SR Tunnel Request State
                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                            
                                            .. attribute:: sr_tunnel_state
                                            
                                            	SR Tunnel State
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap_type
                                            
                                            	Tunnel Encap Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.aggregator_address = None
                                                self.aggregator_as = None
                                                self.aigp_metric_value = None
                                                self.as_path = None
                                                self.cluster = YList()
                                                self.cluster.parent = self
                                                self.cluster.name = 'cluster'
                                                self.community = YList()
                                                self.community.parent = self
                                                self.community.name = 'community'
                                                self.connector_type = None
                                                self.connector_value = YList()
                                                self.connector_value.parent = self
                                                self.connector_value.name = 'connector_value'
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.extended_community_flags = None
                                                self.is_aggregator_present = None
                                                self.is_aigp_present = None
                                                self.is_as_path_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_community_present = None
                                                self.is_connector_present = None
                                                self.is_extended_community_present = None
                                                self.is_label_index_present = None
                                                self.is_local_pref_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_metric_present = None
                                                self.is_origin_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_ssa_present = None
                                                self.is_tunnel_encap_present = None
                                                self.l2tpv3_cookie = YList()
                                                self.l2tpv3_cookie.parent = self
                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                self.l2tpv3_session_id = None
                                                self.label_index_attr = YList()
                                                self.label_index_attr.parent = self
                                                self.label_index_attr.name = 'label_index_attr'
                                                self.local_preference = None
                                                self.ls_attr = YList()
                                                self.ls_attr.parent = self
                                                self.ls_attr.name = 'ls_attr'
                                                self.metric = None
                                                self.neighbor_as = None
                                                self.origin = None
                                                self.originator = None
                                                self.pe_distinguisher_label = YList()
                                                self.pe_distinguisher_label.parent = self
                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.pmsi_type = None
                                                self.pmsi_value = YList()
                                                self.pmsi_value.parent = self
                                                self.pmsi_value.name = 'pmsi_value'
                                                self.ppm_pvalue = None
                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                self.sr_policy_allocated_binding_sid.parent = self
                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                self.sr_policy_binding_sid.parent = self
                                                self.sr_policy_explicit_path = YList()
                                                self.sr_policy_explicit_path.parent = self
                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                self.sr_policy_preference = None
                                                self.sr_tunnel_request_state = None
                                                self.sr_tunnel_state = None
                                                self.tunnel_encap_type = None
                                                self.unknown_attribute = YList()
                                                self.unknown_attribute.parent = self
                                                self.unknown_attribute.name = 'unknown_attribute'


                                            class SrPolicyBindingSid(object):
                                                """
                                                SR Policy Binding sid
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                            class SrPolicyAllocatedBindingSid(object):
                                                """
                                                SR Policy allocated Binding sid by the router
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                            class Community(object):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                            class UnknownAttribute(object):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                            class Cluster(object):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                            class L2Tpv3Cookie(object):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                            class ConnectorValue(object):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                            class PmsiValue(object):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                            class LsAttr(object):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                            class LabelIndexAttr(object):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                            class PeDistinguisherLabel(object):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.label = None
                                                    self.pe_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.label is not None:
                                                        return True

                                                    if self.pe_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                            class SrPolicyExplicitPath(object):
                                                """
                                                SR Policy Explicit paths
                                                
                                                .. attribute:: sid
                                                
                                                	Sidlist for explicit path
                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                
                                                .. attribute:: weight
                                                
                                                	Weight of explicit path
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.sid = YList()
                                                    self.sid.parent = self
                                                    self.sid.name = 'sid'
                                                    self.weight = None


                                                class Sid(object):
                                                    """
                                                    Sidlist for explicit path
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IP Address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label sid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Sid Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4 is not None:
                                                            return True

                                                        if self.ipv6 is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.sid is not None:
                                                        for child_ref in self.sid:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.weight is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.aggregator_address is not None:
                                                    return True

                                                if self.aggregator_as is not None:
                                                    return True

                                                if self.aigp_metric_value is not None:
                                                    return True

                                                if self.as_path is not None:
                                                    return True

                                                if self.cluster is not None:
                                                    for child_ref in self.cluster:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.community is not None:
                                                    for child_ref in self.community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.connector_type is not None:
                                                    return True

                                                if self.connector_value is not None:
                                                    for child_ref in self.connector_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community_flags is not None:
                                                    return True

                                                if self.is_aggregator_present is not None:
                                                    return True

                                                if self.is_aigp_present is not None:
                                                    return True

                                                if self.is_as_path_present is not None:
                                                    return True

                                                if self.is_atomic_aggregate_present is not None:
                                                    return True

                                                if self.is_community_present is not None:
                                                    return True

                                                if self.is_connector_present is not None:
                                                    return True

                                                if self.is_extended_community_present is not None:
                                                    return True

                                                if self.is_label_index_present is not None:
                                                    return True

                                                if self.is_local_pref_present is not None:
                                                    return True

                                                if self.is_ls_attribute_present is not None:
                                                    return True

                                                if self.is_metric_present is not None:
                                                    return True

                                                if self.is_origin_present is not None:
                                                    return True

                                                if self.is_pe_distinguisher_label_present is not None:
                                                    return True

                                                if self.is_pmsi_present is not None:
                                                    return True

                                                if self.is_pppmp_present is not None:
                                                    return True

                                                if self.is_ssa_present is not None:
                                                    return True

                                                if self.is_tunnel_encap_present is not None:
                                                    return True

                                                if self.l2tpv3_cookie is not None:
                                                    for child_ref in self.l2tpv3_cookie:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2tpv3_session_id is not None:
                                                    return True

                                                if self.label_index_attr is not None:
                                                    for child_ref in self.label_index_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_preference is not None:
                                                    return True

                                                if self.ls_attr is not None:
                                                    for child_ref in self.ls_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.metric is not None:
                                                    return True

                                                if self.neighbor_as is not None:
                                                    return True

                                                if self.origin is not None:
                                                    return True

                                                if self.originator is not None:
                                                    return True

                                                if self.pe_distinguisher_label is not None:
                                                    for child_ref in self.pe_distinguisher_label:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.pmsi_flags is not None:
                                                    return True

                                                if self.pmsi_label is not None:
                                                    return True

                                                if self.pmsi_type is not None:
                                                    return True

                                                if self.pmsi_value is not None:
                                                    for child_ref in self.pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.ppm_pvalue is not None:
                                                    return True

                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_explicit_path is not None:
                                                    for child_ref in self.sr_policy_explicit_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.sr_policy_preference is not None:
                                                    return True

                                                if self.sr_tunnel_request_state is not None:
                                                    return True

                                                if self.sr_tunnel_state is not None:
                                                    return True

                                                if self.tunnel_encap_type is not None:
                                                    return True

                                                if self.unknown_attribute is not None:
                                                    for child_ref in self.unknown_attribute:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                        class RnhAddr(object):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.len = None
                                                self.mac_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.len is not None:
                                                    return True

                                                if self.mac_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                        class RibrnhIp(object):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.attr_set is not None and self.attr_set._has_data():
                                                return True

                                            if self.attribute_key_number is not None:
                                                return True

                                            if self.attribute_reuse_id_config is not None:
                                                return True

                                            if self.attribute_reuse_id_current is not None:
                                                return True

                                            if self.attribute_reuse_id_keys is not None:
                                                return True

                                            if self.attribute_reuse_id_max_id is not None:
                                                return True

                                            if self.attribute_reuse_id_node is not None:
                                                return True

                                            if self.attribute_reuse_id_recover_sec is not None:
                                                return True

                                            if self.common_attributes is not None and self.common_attributes._has_data():
                                                return True

                                            if self.is_application_gateway_present is not None:
                                                return True

                                            if self.is_as_path2_byte is not None:
                                                return True

                                            if self.is_attr_set_present is not None:
                                                return True

                                            if self.is_ribrnh_present is not None:
                                                return True

                                            if self.is_rnh_present is not None:
                                                return True

                                            if self.ribrnh_encap is not None:
                                                return True

                                            if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                return True

                                            if self.ribrnh_mac is not None:
                                                return True

                                            if self.ribrnh_table is not None:
                                                return True

                                            if self.ribrnh_vni is not None:
                                                return True

                                            if self.ribrnhip_table is not None:
                                                return True

                                            if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                return True

                                            if self.rnh_addr_len is not None:
                                                return True

                                            if self.rnh_len is not None:
                                                return True

                                            if self.rnh_type is not None:
                                                return True

                                            if self.set_aigp_inbound_igp is not None:
                                                return True

                                            if self.set_aigp_inbound_metric is not None:
                                                return True

                                            if self.vpn_distinguisher is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                            return True

                                        if self.label_fail is not None:
                                            return True

                                        if self.label_o_or_version is not None:
                                            return True

                                        if self.label_oor is not None:
                                            return True

                                        if self.neighbor_address is not None:
                                            return True

                                        if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                            return True

                                        if self.network is not None:
                                            return True

                                        if self.no_path is not None:
                                            return True

                                        if self.path_id is not None:
                                            return True

                                        if self.path_information is not None and self.path_information._has_data():
                                            return True

                                        if self.prefix_length is not None:
                                            return True

                                        if self.prefix_version is not None:
                                            return True

                                        if self.process_instance_id is not None:
                                            return True

                                        if self.rd is not None:
                                            return True

                                        if self.route_distinguisher is not None:
                                            return True

                                        if self.route_type is not None:
                                            return True

                                        if self.source_rd is not None:
                                            return True

                                        if self.source_route_distinguisher is not None:
                                            return True

                                        if self.source_vrf_name is not None:
                                            return True

                                        if self.srcaf_name is not None:
                                            return True

                                        if self.vrf_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-table'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.path is not None:
                                        for child_ref in self.path:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable']['meta_info']


                            class Epes(object):
                                """
                                The BGP Egress Engineering table
                                
                                .. attribute:: epe
                                
                                	A BGP Egress Engineering table entry
                                	**type**\: list of    :py:class:`Epe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.epe = YList()
                                    self.epe.parent = self
                                    self.epe.name = 'epe'


                                class Epe(object):
                                    """
                                    A BGP Egress Engineering table entry
                                    
                                    .. attribute:: epe_flags
                                    
                                    	EPE object's flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: epe_key
                                    
                                    	Key of EPE object
                                    	**type**\: list of    :py:class:`EpeKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeKey>`
                                    
                                    .. attribute:: epe_key_length
                                    
                                    	Epe Key Length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: epe_key_length_xr
                                    
                                    	EPE key length in bits
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: epe_local_address
                                    
                                    	Local address
                                    	**type**\:   :py:class:`EpeLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress>`
                                    
                                    .. attribute:: epe_local_asn
                                    
                                    	Local AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: epe_local_router_id
                                    
                                    	Local router id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: epe_next_hop
                                    
                                    	Nexthop address
                                    	**type**\:   :py:class:`EpeNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop>`
                                    
                                    .. attribute:: epe_remote_asn
                                    
                                    	Remote AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: epe_remote_router_id
                                    
                                    	Remote router id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: epe_set_key
                                    
                                    	Epe Set Key
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: epe_version
                                    
                                    	EPE object's version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: first_hop
                                    
                                    	List of firsthops of EPE
                                    	**type**\: list of    :py:class:`FirstHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop>`
                                    
                                    .. attribute:: ifhandle
                                    
                                    	List of ifhandle of EPE
                                    	**type**\: list of    :py:class:`Ifhandle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.Ifhandle>`
                                    
                                    .. attribute:: label
                                    
                                    	Label assigned to the RPCnext\-hop set
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nexthop_id
                                    
                                    	List of nexthop ID of EPE
                                    	**type**\: list of    :py:class:`NexthopId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.NexthopId>`
                                    
                                    .. attribute:: ref_count
                                    
                                    	Refcount
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.epe_flags = None
                                        self.epe_key = YList()
                                        self.epe_key.parent = self
                                        self.epe_key.name = 'epe_key'
                                        self.epe_key_length = None
                                        self.epe_key_length_xr = None
                                        self.epe_local_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress()
                                        self.epe_local_address.parent = self
                                        self.epe_local_asn = None
                                        self.epe_local_router_id = None
                                        self.epe_next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop()
                                        self.epe_next_hop.parent = self
                                        self.epe_remote_asn = None
                                        self.epe_remote_router_id = None
                                        self.epe_set_key = None
                                        self.epe_version = None
                                        self.first_hop = YList()
                                        self.first_hop.parent = self
                                        self.first_hop.name = 'first_hop'
                                        self.ifhandle = YList()
                                        self.ifhandle.parent = self
                                        self.ifhandle.name = 'ifhandle'
                                        self.label = None
                                        self.nexthop_id = YList()
                                        self.nexthop_id.parent = self
                                        self.nexthop_id.name = 'nexthop_id'
                                        self.ref_count = None


                                    class EpeLocalAddress(object):
                                        """
                                        Local address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:epe-local-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress']['meta_info']


                                    class EpeNextHop(object):
                                        """
                                        Nexthop address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:epe-next-hop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop']['meta_info']


                                    class EpeKey(object):
                                        """
                                        Key of EPE object
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.entry = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:epe-key'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.entry is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeKey']['meta_info']


                                    class NexthopId(object):
                                        """
                                        List of nexthop ID of EPE
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.entry = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nexthop-id'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.entry is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.NexthopId']['meta_info']


                                    class Ifhandle(object):
                                        """
                                        List of ifhandle of EPE
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.entry = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ifhandle'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.entry is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.Ifhandle']['meta_info']


                                    class FirstHop(object):
                                        """
                                        List of firsthops of EPE
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-hop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:epe'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.epe_flags is not None:
                                            return True

                                        if self.epe_key is not None:
                                            for child_ref in self.epe_key:
                                                if child_ref._has_data():
                                                    return True

                                        if self.epe_key_length is not None:
                                            return True

                                        if self.epe_key_length_xr is not None:
                                            return True

                                        if self.epe_local_address is not None and self.epe_local_address._has_data():
                                            return True

                                        if self.epe_local_asn is not None:
                                            return True

                                        if self.epe_local_router_id is not None:
                                            return True

                                        if self.epe_next_hop is not None and self.epe_next_hop._has_data():
                                            return True

                                        if self.epe_remote_asn is not None:
                                            return True

                                        if self.epe_remote_router_id is not None:
                                            return True

                                        if self.epe_set_key is not None:
                                            return True

                                        if self.epe_version is not None:
                                            return True

                                        if self.first_hop is not None:
                                            for child_ref in self.first_hop:
                                                if child_ref._has_data():
                                                    return True

                                        if self.ifhandle is not None:
                                            for child_ref in self.ifhandle:
                                                if child_ref._has_data():
                                                    return True

                                        if self.label is not None:
                                            return True

                                        if self.nexthop_id is not None:
                                            for child_ref in self.nexthop_id:
                                                if child_ref._has_data():
                                                    return True

                                        if self.ref_count is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:epes'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.epe is not None:
                                        for child_ref in self.epe:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes']['meta_info']


                            class AdvertisedPathCounts(object):
                                """
                                The BGP Advertised paths table (bestpath)
                                
                                .. attribute:: advertised_path_count
                                
                                	The BGP Advertised path table Count (bestpath)
                                	**type**\: list of    :py:class:`AdvertisedPathCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.advertised_path_count = YList()
                                    self.advertised_path_count.parent = self
                                    self.advertised_path_count.name = 'advertised_path_count'


                                class AdvertisedPathCount(object):
                                    """
                                    The BGP Advertised path table Count
                                    (bestpath)
                                    
                                    .. attribute:: neighbor_address  <key>
                                    
                                    	Neighbor address
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: max_prefix_advertisedcount
                                    
                                    	Number of prefixes advertsied to neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.neighbor_address = None
                                        self.max_prefix_advertisedcount = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.neighbor_address is None:
                                            raise YPYModelError('Key property neighbor_address is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertised-path-count[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address = ' + str(self.neighbor_address) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.neighbor_address is not None:
                                            return True

                                        if self.max_prefix_advertisedcount is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertised-path-counts'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.advertised_path_count is not None:
                                        for child_ref in self.advertised_path_count:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathCounts']['meta_info']


                            class PathLabeledTable(object):
                                """
                                The BGP Path Labeled Table
                                
                                .. attribute:: path
                                
                                	A BGP path table entry
                                	**type**\: list of    :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.path = YList()
                                    self.path.parent = self
                                    self.path.name = 'path'


                                class Path(object):
                                    """
                                    A BGP path table entry
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: attributes_after_policy_in
                                    
                                    	Attributes after inbound policy applied
                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn>`
                                    
                                    .. attribute:: label_fail
                                    
                                    	LSD label allocation failed 
                                    	**type**\:  bool
                                    
                                    .. attribute:: label_o_or_version
                                    
                                    	Label Version when OOR happens
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_oor
                                    
                                    	LSD label space is exhausted
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor adddress
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr>`
                                    
                                    .. attribute:: network
                                    
                                    	Network Prefix in Hex format
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: no_path
                                    
                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_id
                                    
                                    	Received Path ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: path_information
                                    
                                    	Path information
                                    	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: prefix_version
                                    
                                    	Version of BGP Prefix Table
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: route_type
                                    
                                    	Route Type
                                    	**type**\:   :py:class:`BgpRouteEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRouteEnum>`
                                    
                                    .. attribute:: source_rd
                                    
                                    	Source Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: source_route_distinguisher
                                    
                                    	Source Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_vrf_name
                                    
                                    	Name of the source VRF
                                    	**type**\:  str
                                    
                                    .. attribute:: srcaf_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn()
                                        self.attributes_after_policy_in.parent = self
                                        self.label_fail = None
                                        self.label_o_or_version = None
                                        self.label_oor = None
                                        self.neighbor_address = None
                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr()
                                        self.neighbor_address_xr.parent = self
                                        self.network = None
                                        self.no_path = None
                                        self.path_id = None
                                        self.path_information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation()
                                        self.path_information.parent = self
                                        self.prefix_length = None
                                        self.prefix_version = None
                                        self.process_instance_id = None
                                        self.rd = None
                                        self.route_distinguisher = None
                                        self.route_type = None
                                        self.source_rd = None
                                        self.source_route_distinguisher = None
                                        self.source_vrf_name = None
                                        self.srcaf_name = None
                                        self.vrf_name = None


                                    class NeighborAddressXr(object):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.NeighborAddressXr']['meta_info']


                                    class PathInformation(object):
                                        """
                                        Path information
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_own_self_originated_p_ath
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\:  bool
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield>`
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner>`
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix>`
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity>`
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\:  bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\:  bool
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr>`
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_esi
                                        
                                        	Path has EVPN ESI
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_rcvd_label
                                        
                                        	Path has received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\:  bool
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebg_ps
                                        
                                        	Not advertised to EBGPs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2VpnCircuitStatusValue>`
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2VpnEvpnEsi>`
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr>`
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue>`
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress>`
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop>`
                                        
                                        .. attribute:: nhte_tunnel
                                        
                                        	NH TE tunnel information
                                        	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhteTunnel>`
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\:  bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.accept_own_path = None
                                            self.accept_own_self_originated_p_ath = None
                                            self.add_path_orr_bitfield = YList()
                                            self.add_path_orr_bitfield.parent = self
                                            self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                            self.advertisedto_pe = None
                                            self.aigp_metric = None
                                            self.best_path_comp_stage = None
                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self.best_path_id = None
                                            self.best_path_id_comp_winner = None
                                            self.best_path_orr_bitfield = YList()
                                            self.best_path_orr_bitfield.parent = self
                                            self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self.dampen_penalty = None
                                            self.extended_community = YList()
                                            self.extended_community.parent = self
                                            self.extended_community.name = 'extended_community'
                                            self.fspec_invalid_path = None
                                            self.graceful_shutdown = None
                                            self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr()
                                            self.gw_addr.parent = self
                                            self.halflife_time = None
                                            self.has_esi = None
                                            self.has_gw_addr = None
                                            self.has_local_net_label = None
                                            self.has_mdt_group_addr = None
                                            self.has_mvpn_extcomm = None
                                            self.has_mvpn_nbr_addr = None
                                            self.has_mvpn_nexthop_addr = None
                                            self.has_mvpn_pmsi = None
                                            self.has_rcvd_label = None
                                            self.has_second_label = None
                                            self.ibgp_signaled_validity = None
                                            self.igp_metric = None
                                            self.is_aggregation_suppressed = None
                                            self.is_as_best = None
                                            self.is_best_path = None
                                            self.is_import_dampened = None
                                            self.is_import_suspect = None
                                            self.is_internal_path = None
                                            self.is_partial_best = None
                                            self.is_path_additional_path = None
                                            self.is_path_advertised_local_as_only = None
                                            self.is_path_af_install_eligible = None
                                            self.is_path_backup = None
                                            self.is_path_backup_protect_multipath = None
                                            self.is_path_best_external = None
                                            self.is_path_damped = None
                                            self.is_path_from_confederation_peer = None
                                            self.is_path_from_network_command = None
                                            self.is_path_from_redistribute_command = None
                                            self.is_path_from_route_reflector = None
                                            self.is_path_history_held = None
                                            self.is_path_imp_candidate = None
                                            self.is_path_imported = None
                                            self.is_path_local_aggregate = None
                                            self.is_path_locally_sourced = None
                                            self.is_path_long_lived_stale = None
                                            self.is_path_multipath = None
                                            self.is_path_nexthop_discarded = None
                                            self.is_path_not_advertised = None
                                            self.is_path_not_advertised_to_ebg_ps = None
                                            self.is_path_received_only = None
                                            self.is_path_reoriginated = None
                                            self.is_path_reoriginated_stitching = None
                                            self.is_path_stale = None
                                            self.is_path_synced_with_igp = None
                                            self.is_path_valid = None
                                            self.is_path_vpn_only = None
                                            self.is_permanent_path = None
                                            self.is_received_path_not_modified = None
                                            self.is_spkr_as_best = None
                                            self.l2vpn_circuit_status_value = YList()
                                            self.l2vpn_circuit_status_value.parent = self
                                            self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                            self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2VpnEvpnEsi()
                                            self.l2vpn_evpn_esi.parent = self
                                            self.l2vpn_size = None
                                            self.labeled_unicast_safi_path = None
                                            self.local_label = None
                                            self.local_nh = None
                                            self.local_path_id = None
                                            self.local_peers_advertised_to = YList()
                                            self.local_peers_advertised_to.parent = self
                                            self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                            self.maximum_suppress_time = None
                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self.mvpn_path_flags = None
                                            self.mvpn_pmsi_flags = None
                                            self.mvpn_pmsi_label = None
                                            self.mvpn_pmsi_type = None
                                            self.mvpn_pmsi_value = YList()
                                            self.mvpn_pmsi_value.parent = self
                                            self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                            self.mvpn_sfs_path = None
                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self.neighbor_router_id = None
                                            self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop()
                                            self.next_hop.parent = self
                                            self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhteTunnel()
                                            self.nhte_tunnel.parent = self
                                            self.path_flags = None
                                            self.path_flap_count = None
                                            self.path_import_flags = None
                                            self.path_rt_set_id = None
                                            self.path_rt_set_route_count = None
                                            self.path_table_version = None
                                            self.path_weight = None
                                            self.pe_peers_advertised_to = YList()
                                            self.pe_peers_advertised_to.parent = self
                                            self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                            self.rcvd_label = None
                                            self.rcvd_path_id = None
                                            self.reuse_value = None
                                            self.rib_failed = None
                                            self.route_type = None
                                            self.rpki_origin_as_validation_disabled = None
                                            self.rt_set_limit_enabled = None
                                            self.second_label = None
                                            self.seconds_since_first_flap = None
                                            self.show_rpki_origin_as_validity = None
                                            self.sn_rpki_origin_as_validity = None
                                            self.suppress_penalty = None
                                            self.time_to_unsuppress = None


                                        class BgpPrefix(object):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self.prefix_length = None


                                            class Prefix(object):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.prefix is not None and self.prefix._has_data():
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix']['meta_info']


                                        class NeighborAddress(object):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress']['meta_info']


                                        class NextHop(object):
                                            """
                                            Next hop
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop']['meta_info']


                                        class NhteTunnel(object):
                                            """
                                            NH TE tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_te_tunnel
                                            
                                            	NH TE Tunnel info is present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last rib update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	tunnel name
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	tunnel type
                                            	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.binding_label = None
                                                self.has_te_tunnel = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.is_tunnel_up = None
                                                self.last_tunnel_update = None
                                                self.tunnel_if_handle = None
                                                self.tunnel_name = None
                                                self.tunnel_type = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_v6_required = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.binding_label is not None:
                                                    return True

                                                if self.has_te_tunnel is not None:
                                                    return True

                                                if self.is_tunnel_info_stale is not None:
                                                    return True

                                                if self.is_tunnel_registered is not None:
                                                    return True

                                                if self.is_tunnel_up is not None:
                                                    return True

                                                if self.last_tunnel_update is not None:
                                                    return True

                                                if self.tunnel_if_handle is not None:
                                                    return True

                                                if self.tunnel_name is not None:
                                                    return True

                                                if self.tunnel_type is not None:
                                                    return True

                                                if self.tunnel_v6_enabled is not None:
                                                    return True

                                                if self.tunnel_v6_required is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhteTunnel']['meta_info']


                                        class MdtGroupAddr(object):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr']['meta_info']


                                        class L2VpnEvpnEsi(object):
                                            """
                                            L2VPN EVPN ESI
                                            
                                            .. attribute:: esi
                                            
                                            	esi
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.esi = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.esi is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2VpnEvpnEsi']['meta_info']


                                        class GwAddr(object):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.len = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.len is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr']['meta_info']


                                        class BestPathCompWinner(object):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner']['meta_info']


                                        class MvpnNbrAddr(object):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr']['meta_info']


                                        class MvpnNexthopAddr(object):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr']['meta_info']


                                        class L2VpnCircuitStatusValue(object):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                        class MvpnPmsiValue(object):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue']['meta_info']


                                        class ExtendedCommunity(object):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity']['meta_info']


                                        class LocalPeersAdvertisedTo(object):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                        class PePeersAdvertisedTo(object):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo']['meta_info']


                                        class BestPathOrrBitfield(object):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield']['meta_info']


                                        class AddPathOrrBitfield(object):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.accept_own_path is not None:
                                                return True

                                            if self.accept_own_self_originated_p_ath is not None:
                                                return True

                                            if self.add_path_orr_bitfield is not None:
                                                for child_ref in self.add_path_orr_bitfield:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.advertisedto_pe is not None:
                                                return True

                                            if self.aigp_metric is not None:
                                                return True

                                            if self.best_path_comp_stage is not None:
                                                return True

                                            if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                return True

                                            if self.best_path_id is not None:
                                                return True

                                            if self.best_path_id_comp_winner is not None:
                                                return True

                                            if self.best_path_orr_bitfield is not None:
                                                for child_ref in self.best_path_orr_bitfield:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                return True

                                            if self.dampen_penalty is not None:
                                                return True

                                            if self.extended_community is not None:
                                                for child_ref in self.extended_community:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.fspec_invalid_path is not None:
                                                return True

                                            if self.graceful_shutdown is not None:
                                                return True

                                            if self.gw_addr is not None and self.gw_addr._has_data():
                                                return True

                                            if self.halflife_time is not None:
                                                return True

                                            if self.has_esi is not None:
                                                return True

                                            if self.has_gw_addr is not None:
                                                return True

                                            if self.has_local_net_label is not None:
                                                return True

                                            if self.has_mdt_group_addr is not None:
                                                return True

                                            if self.has_mvpn_extcomm is not None:
                                                return True

                                            if self.has_mvpn_nbr_addr is not None:
                                                return True

                                            if self.has_mvpn_nexthop_addr is not None:
                                                return True

                                            if self.has_mvpn_pmsi is not None:
                                                return True

                                            if self.has_rcvd_label is not None:
                                                return True

                                            if self.has_second_label is not None:
                                                return True

                                            if self.ibgp_signaled_validity is not None:
                                                return True

                                            if self.igp_metric is not None:
                                                return True

                                            if self.is_aggregation_suppressed is not None:
                                                return True

                                            if self.is_as_best is not None:
                                                return True

                                            if self.is_best_path is not None:
                                                return True

                                            if self.is_import_dampened is not None:
                                                return True

                                            if self.is_import_suspect is not None:
                                                return True

                                            if self.is_internal_path is not None:
                                                return True

                                            if self.is_partial_best is not None:
                                                return True

                                            if self.is_path_additional_path is not None:
                                                return True

                                            if self.is_path_advertised_local_as_only is not None:
                                                return True

                                            if self.is_path_af_install_eligible is not None:
                                                return True

                                            if self.is_path_backup is not None:
                                                return True

                                            if self.is_path_backup_protect_multipath is not None:
                                                return True

                                            if self.is_path_best_external is not None:
                                                return True

                                            if self.is_path_damped is not None:
                                                return True

                                            if self.is_path_from_confederation_peer is not None:
                                                return True

                                            if self.is_path_from_network_command is not None:
                                                return True

                                            if self.is_path_from_redistribute_command is not None:
                                                return True

                                            if self.is_path_from_route_reflector is not None:
                                                return True

                                            if self.is_path_history_held is not None:
                                                return True

                                            if self.is_path_imp_candidate is not None:
                                                return True

                                            if self.is_path_imported is not None:
                                                return True

                                            if self.is_path_local_aggregate is not None:
                                                return True

                                            if self.is_path_locally_sourced is not None:
                                                return True

                                            if self.is_path_long_lived_stale is not None:
                                                return True

                                            if self.is_path_multipath is not None:
                                                return True

                                            if self.is_path_nexthop_discarded is not None:
                                                return True

                                            if self.is_path_not_advertised is not None:
                                                return True

                                            if self.is_path_not_advertised_to_ebg_ps is not None:
                                                return True

                                            if self.is_path_received_only is not None:
                                                return True

                                            if self.is_path_reoriginated is not None:
                                                return True

                                            if self.is_path_reoriginated_stitching is not None:
                                                return True

                                            if self.is_path_stale is not None:
                                                return True

                                            if self.is_path_synced_with_igp is not None:
                                                return True

                                            if self.is_path_valid is not None:
                                                return True

                                            if self.is_path_vpn_only is not None:
                                                return True

                                            if self.is_permanent_path is not None:
                                                return True

                                            if self.is_received_path_not_modified is not None:
                                                return True

                                            if self.is_spkr_as_best is not None:
                                                return True

                                            if self.l2vpn_circuit_status_value is not None:
                                                for child_ref in self.l2vpn_circuit_status_value:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                return True

                                            if self.l2vpn_size is not None:
                                                return True

                                            if self.labeled_unicast_safi_path is not None:
                                                return True

                                            if self.local_label is not None:
                                                return True

                                            if self.local_nh is not None:
                                                return True

                                            if self.local_path_id is not None:
                                                return True

                                            if self.local_peers_advertised_to is not None:
                                                for child_ref in self.local_peers_advertised_to:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.maximum_suppress_time is not None:
                                                return True

                                            if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                return True

                                            if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                return True

                                            if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                return True

                                            if self.mvpn_path_flags is not None:
                                                return True

                                            if self.mvpn_pmsi_flags is not None:
                                                return True

                                            if self.mvpn_pmsi_label is not None:
                                                return True

                                            if self.mvpn_pmsi_type is not None:
                                                return True

                                            if self.mvpn_pmsi_value is not None:
                                                for child_ref in self.mvpn_pmsi_value:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.mvpn_sfs_path is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            if self.neighbor_router_id is not None:
                                                return True

                                            if self.next_hop is not None and self.next_hop._has_data():
                                                return True

                                            if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                return True

                                            if self.path_flags is not None:
                                                return True

                                            if self.path_flap_count is not None:
                                                return True

                                            if self.path_import_flags is not None:
                                                return True

                                            if self.path_rt_set_id is not None:
                                                return True

                                            if self.path_rt_set_route_count is not None:
                                                return True

                                            if self.path_table_version is not None:
                                                return True

                                            if self.path_weight is not None:
                                                return True

                                            if self.pe_peers_advertised_to is not None:
                                                for child_ref in self.pe_peers_advertised_to:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.rcvd_label is not None:
                                                return True

                                            if self.rcvd_path_id is not None:
                                                return True

                                            if self.reuse_value is not None:
                                                return True

                                            if self.rib_failed is not None:
                                                return True

                                            if self.route_type is not None:
                                                return True

                                            if self.rpki_origin_as_validation_disabled is not None:
                                                return True

                                            if self.rt_set_limit_enabled is not None:
                                                return True

                                            if self.second_label is not None:
                                                return True

                                            if self.seconds_since_first_flap is not None:
                                                return True

                                            if self.show_rpki_origin_as_validity is not None:
                                                return True

                                            if self.sn_rpki_origin_as_validity is not None:
                                                return True

                                            if self.suppress_penalty is not None:
                                                return True

                                            if self.time_to_unsuppress is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation']['meta_info']


                                    class AttributesAfterPolicyIn(object):
                                        """
                                        Attributes after inbound policy applied
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet>`
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes>`
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp>`
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr>`
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\:  bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet()
                                            self.attr_set.parent = self
                                            self.attribute_key_number = None
                                            self.attribute_reuse_id_config = None
                                            self.attribute_reuse_id_current = None
                                            self.attribute_reuse_id_keys = None
                                            self.attribute_reuse_id_max_id = None
                                            self.attribute_reuse_id_node = None
                                            self.attribute_reuse_id_recover_sec = None
                                            self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self.is_application_gateway_present = None
                                            self.is_as_path2_byte = None
                                            self.is_attr_set_present = None
                                            self.is_ribrnh_present = None
                                            self.is_rnh_present = None
                                            self.ribrnh_encap = None
                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self.ribrnh_mac = None
                                            self.ribrnh_table = None
                                            self.ribrnh_vni = None
                                            self.ribrnhip_table = None
                                            self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self.rnh_addr_len = None
                                            self.rnh_len = None
                                            self.rnh_type = None
                                            self.set_aigp_inbound_igp = None
                                            self.set_aigp_inbound_metric = None
                                            self.vpn_distinguisher = None


                                        class CommonAttributes(object):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_encap_present
                                            
                                            	Tunnel Encap attribute present 
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_policy_allocated_binding_sid
                                            
                                            	SR Policy allocated Binding sid by the router
                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                            
                                            .. attribute:: sr_policy_binding_sid
                                            
                                            	SR Policy Binding sid
                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                            
                                            .. attribute:: sr_policy_explicit_path
                                            
                                            	SR Policy Explicit paths
                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                            
                                            .. attribute:: sr_policy_preference
                                            
                                            	SR Policy Preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_tunnel_request_state
                                            
                                            	SR Tunnel Request State
                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                            
                                            .. attribute:: sr_tunnel_state
                                            
                                            	SR Tunnel State
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap_type
                                            
                                            	Tunnel Encap Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.aggregator_address = None
                                                self.aggregator_as = None
                                                self.aigp_metric_value = None
                                                self.as_path = None
                                                self.cluster = YList()
                                                self.cluster.parent = self
                                                self.cluster.name = 'cluster'
                                                self.community = YList()
                                                self.community.parent = self
                                                self.community.name = 'community'
                                                self.connector_type = None
                                                self.connector_value = YList()
                                                self.connector_value.parent = self
                                                self.connector_value.name = 'connector_value'
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.extended_community_flags = None
                                                self.is_aggregator_present = None
                                                self.is_aigp_present = None
                                                self.is_as_path_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_community_present = None
                                                self.is_connector_present = None
                                                self.is_extended_community_present = None
                                                self.is_label_index_present = None
                                                self.is_local_pref_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_metric_present = None
                                                self.is_origin_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_ssa_present = None
                                                self.is_tunnel_encap_present = None
                                                self.l2tpv3_cookie = YList()
                                                self.l2tpv3_cookie.parent = self
                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                self.l2tpv3_session_id = None
                                                self.label_index_attr = YList()
                                                self.label_index_attr.parent = self
                                                self.label_index_attr.name = 'label_index_attr'
                                                self.local_preference = None
                                                self.ls_attr = YList()
                                                self.ls_attr.parent = self
                                                self.ls_attr.name = 'ls_attr'
                                                self.metric = None
                                                self.neighbor_as = None
                                                self.origin = None
                                                self.originator = None
                                                self.pe_distinguisher_label = YList()
                                                self.pe_distinguisher_label.parent = self
                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.pmsi_type = None
                                                self.pmsi_value = YList()
                                                self.pmsi_value.parent = self
                                                self.pmsi_value.name = 'pmsi_value'
                                                self.ppm_pvalue = None
                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                self.sr_policy_allocated_binding_sid.parent = self
                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                self.sr_policy_binding_sid.parent = self
                                                self.sr_policy_explicit_path = YList()
                                                self.sr_policy_explicit_path.parent = self
                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                self.sr_policy_preference = None
                                                self.sr_tunnel_request_state = None
                                                self.sr_tunnel_state = None
                                                self.tunnel_encap_type = None
                                                self.unknown_attribute = YList()
                                                self.unknown_attribute.parent = self
                                                self.unknown_attribute.name = 'unknown_attribute'


                                            class SrPolicyBindingSid(object):
                                                """
                                                SR Policy Binding sid
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                            class SrPolicyAllocatedBindingSid(object):
                                                """
                                                SR Policy allocated Binding sid by the router
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                            class Community(object):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                            class UnknownAttribute(object):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                            class Cluster(object):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                            class L2Tpv3Cookie(object):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                            class ConnectorValue(object):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                            class PmsiValue(object):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                            class LsAttr(object):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                            class LabelIndexAttr(object):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                            class PeDistinguisherLabel(object):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.label = None
                                                    self.pe_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.label is not None:
                                                        return True

                                                    if self.pe_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                            class SrPolicyExplicitPath(object):
                                                """
                                                SR Policy Explicit paths
                                                
                                                .. attribute:: sid
                                                
                                                	Sidlist for explicit path
                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                
                                                .. attribute:: weight
                                                
                                                	Weight of explicit path
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.sid = YList()
                                                    self.sid.parent = self
                                                    self.sid.name = 'sid'
                                                    self.weight = None


                                                class Sid(object):
                                                    """
                                                    Sidlist for explicit path
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IP Address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label sid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Sid Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4 is not None:
                                                            return True

                                                        if self.ipv6 is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.sid is not None:
                                                        for child_ref in self.sid:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.weight is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.aggregator_address is not None:
                                                    return True

                                                if self.aggregator_as is not None:
                                                    return True

                                                if self.aigp_metric_value is not None:
                                                    return True

                                                if self.as_path is not None:
                                                    return True

                                                if self.cluster is not None:
                                                    for child_ref in self.cluster:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.community is not None:
                                                    for child_ref in self.community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.connector_type is not None:
                                                    return True

                                                if self.connector_value is not None:
                                                    for child_ref in self.connector_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community_flags is not None:
                                                    return True

                                                if self.is_aggregator_present is not None:
                                                    return True

                                                if self.is_aigp_present is not None:
                                                    return True

                                                if self.is_as_path_present is not None:
                                                    return True

                                                if self.is_atomic_aggregate_present is not None:
                                                    return True

                                                if self.is_community_present is not None:
                                                    return True

                                                if self.is_connector_present is not None:
                                                    return True

                                                if self.is_extended_community_present is not None:
                                                    return True

                                                if self.is_label_index_present is not None:
                                                    return True

                                                if self.is_local_pref_present is not None:
                                                    return True

                                                if self.is_ls_attribute_present is not None:
                                                    return True

                                                if self.is_metric_present is not None:
                                                    return True

                                                if self.is_origin_present is not None:
                                                    return True

                                                if self.is_pe_distinguisher_label_present is not None:
                                                    return True

                                                if self.is_pmsi_present is not None:
                                                    return True

                                                if self.is_pppmp_present is not None:
                                                    return True

                                                if self.is_ssa_present is not None:
                                                    return True

                                                if self.is_tunnel_encap_present is not None:
                                                    return True

                                                if self.l2tpv3_cookie is not None:
                                                    for child_ref in self.l2tpv3_cookie:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2tpv3_session_id is not None:
                                                    return True

                                                if self.label_index_attr is not None:
                                                    for child_ref in self.label_index_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_preference is not None:
                                                    return True

                                                if self.ls_attr is not None:
                                                    for child_ref in self.ls_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.metric is not None:
                                                    return True

                                                if self.neighbor_as is not None:
                                                    return True

                                                if self.origin is not None:
                                                    return True

                                                if self.originator is not None:
                                                    return True

                                                if self.pe_distinguisher_label is not None:
                                                    for child_ref in self.pe_distinguisher_label:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.pmsi_flags is not None:
                                                    return True

                                                if self.pmsi_label is not None:
                                                    return True

                                                if self.pmsi_type is not None:
                                                    return True

                                                if self.pmsi_value is not None:
                                                    for child_ref in self.pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.ppm_pvalue is not None:
                                                    return True

                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_explicit_path is not None:
                                                    for child_ref in self.sr_policy_explicit_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.sr_policy_preference is not None:
                                                    return True

                                                if self.sr_tunnel_request_state is not None:
                                                    return True

                                                if self.sr_tunnel_state is not None:
                                                    return True

                                                if self.tunnel_encap_type is not None:
                                                    return True

                                                if self.unknown_attribute is not None:
                                                    for child_ref in self.unknown_attribute:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                        class AttrSet(object):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_encap_present
                                            
                                            	Tunnel Encap attribute present 
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_policy_allocated_binding_sid
                                            
                                            	SR Policy allocated Binding sid by the router
                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                            
                                            .. attribute:: sr_policy_binding_sid
                                            
                                            	SR Policy Binding sid
                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                            
                                            .. attribute:: sr_policy_explicit_path
                                            
                                            	SR Policy Explicit paths
                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                            
                                            .. attribute:: sr_policy_preference
                                            
                                            	SR Policy Preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_tunnel_request_state
                                            
                                            	SR Tunnel Request State
                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                            
                                            .. attribute:: sr_tunnel_state
                                            
                                            	SR Tunnel State
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap_type
                                            
                                            	Tunnel Encap Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.aggregator_address = None
                                                self.aggregator_as = None
                                                self.aigp_metric_value = None
                                                self.as_path = None
                                                self.cluster = YList()
                                                self.cluster.parent = self
                                                self.cluster.name = 'cluster'
                                                self.community = YList()
                                                self.community.parent = self
                                                self.community.name = 'community'
                                                self.connector_type = None
                                                self.connector_value = YList()
                                                self.connector_value.parent = self
                                                self.connector_value.name = 'connector_value'
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.extended_community_flags = None
                                                self.is_aggregator_present = None
                                                self.is_aigp_present = None
                                                self.is_as_path_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_community_present = None
                                                self.is_connector_present = None
                                                self.is_extended_community_present = None
                                                self.is_label_index_present = None
                                                self.is_local_pref_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_metric_present = None
                                                self.is_origin_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_ssa_present = None
                                                self.is_tunnel_encap_present = None
                                                self.l2tpv3_cookie = YList()
                                                self.l2tpv3_cookie.parent = self
                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                self.l2tpv3_session_id = None
                                                self.label_index_attr = YList()
                                                self.label_index_attr.parent = self
                                                self.label_index_attr.name = 'label_index_attr'
                                                self.local_preference = None
                                                self.ls_attr = YList()
                                                self.ls_attr.parent = self
                                                self.ls_attr.name = 'ls_attr'
                                                self.metric = None
                                                self.neighbor_as = None
                                                self.origin = None
                                                self.originator = None
                                                self.pe_distinguisher_label = YList()
                                                self.pe_distinguisher_label.parent = self
                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.pmsi_type = None
                                                self.pmsi_value = YList()
                                                self.pmsi_value.parent = self
                                                self.pmsi_value.name = 'pmsi_value'
                                                self.ppm_pvalue = None
                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                self.sr_policy_allocated_binding_sid.parent = self
                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                self.sr_policy_binding_sid.parent = self
                                                self.sr_policy_explicit_path = YList()
                                                self.sr_policy_explicit_path.parent = self
                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                self.sr_policy_preference = None
                                                self.sr_tunnel_request_state = None
                                                self.sr_tunnel_state = None
                                                self.tunnel_encap_type = None
                                                self.unknown_attribute = YList()
                                                self.unknown_attribute.parent = self
                                                self.unknown_attribute.name = 'unknown_attribute'


                                            class SrPolicyBindingSid(object):
                                                """
                                                SR Policy Binding sid
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                            class SrPolicyAllocatedBindingSid(object):
                                                """
                                                SR Policy allocated Binding sid by the router
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                            class Community(object):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                            class UnknownAttribute(object):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                            class Cluster(object):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                            class L2Tpv3Cookie(object):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                            class ConnectorValue(object):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                            class PmsiValue(object):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                            class LsAttr(object):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                            class LabelIndexAttr(object):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                            class PeDistinguisherLabel(object):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.label = None
                                                    self.pe_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.label is not None:
                                                        return True

                                                    if self.pe_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                            class SrPolicyExplicitPath(object):
                                                """
                                                SR Policy Explicit paths
                                                
                                                .. attribute:: sid
                                                
                                                	Sidlist for explicit path
                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                
                                                .. attribute:: weight
                                                
                                                	Weight of explicit path
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.sid = YList()
                                                    self.sid.parent = self
                                                    self.sid.name = 'sid'
                                                    self.weight = None


                                                class Sid(object):
                                                    """
                                                    Sidlist for explicit path
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IP Address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label sid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Sid Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4 is not None:
                                                            return True

                                                        if self.ipv6 is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.sid is not None:
                                                        for child_ref in self.sid:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.weight is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.aggregator_address is not None:
                                                    return True

                                                if self.aggregator_as is not None:
                                                    return True

                                                if self.aigp_metric_value is not None:
                                                    return True

                                                if self.as_path is not None:
                                                    return True

                                                if self.cluster is not None:
                                                    for child_ref in self.cluster:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.community is not None:
                                                    for child_ref in self.community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.connector_type is not None:
                                                    return True

                                                if self.connector_value is not None:
                                                    for child_ref in self.connector_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community_flags is not None:
                                                    return True

                                                if self.is_aggregator_present is not None:
                                                    return True

                                                if self.is_aigp_present is not None:
                                                    return True

                                                if self.is_as_path_present is not None:
                                                    return True

                                                if self.is_atomic_aggregate_present is not None:
                                                    return True

                                                if self.is_community_present is not None:
                                                    return True

                                                if self.is_connector_present is not None:
                                                    return True

                                                if self.is_extended_community_present is not None:
                                                    return True

                                                if self.is_label_index_present is not None:
                                                    return True

                                                if self.is_local_pref_present is not None:
                                                    return True

                                                if self.is_ls_attribute_present is not None:
                                                    return True

                                                if self.is_metric_present is not None:
                                                    return True

                                                if self.is_origin_present is not None:
                                                    return True

                                                if self.is_pe_distinguisher_label_present is not None:
                                                    return True

                                                if self.is_pmsi_present is not None:
                                                    return True

                                                if self.is_pppmp_present is not None:
                                                    return True

                                                if self.is_ssa_present is not None:
                                                    return True

                                                if self.is_tunnel_encap_present is not None:
                                                    return True

                                                if self.l2tpv3_cookie is not None:
                                                    for child_ref in self.l2tpv3_cookie:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2tpv3_session_id is not None:
                                                    return True

                                                if self.label_index_attr is not None:
                                                    for child_ref in self.label_index_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_preference is not None:
                                                    return True

                                                if self.ls_attr is not None:
                                                    for child_ref in self.ls_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.metric is not None:
                                                    return True

                                                if self.neighbor_as is not None:
                                                    return True

                                                if self.origin is not None:
                                                    return True

                                                if self.originator is not None:
                                                    return True

                                                if self.pe_distinguisher_label is not None:
                                                    for child_ref in self.pe_distinguisher_label:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.pmsi_flags is not None:
                                                    return True

                                                if self.pmsi_label is not None:
                                                    return True

                                                if self.pmsi_type is not None:
                                                    return True

                                                if self.pmsi_value is not None:
                                                    for child_ref in self.pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.ppm_pvalue is not None:
                                                    return True

                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_explicit_path is not None:
                                                    for child_ref in self.sr_policy_explicit_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.sr_policy_preference is not None:
                                                    return True

                                                if self.sr_tunnel_request_state is not None:
                                                    return True

                                                if self.sr_tunnel_state is not None:
                                                    return True

                                                if self.tunnel_encap_type is not None:
                                                    return True

                                                if self.unknown_attribute is not None:
                                                    for child_ref in self.unknown_attribute:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                        class RnhAddr(object):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.len = None
                                                self.mac_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.len is not None:
                                                    return True

                                                if self.mac_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                        class RibrnhIp(object):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.attr_set is not None and self.attr_set._has_data():
                                                return True

                                            if self.attribute_key_number is not None:
                                                return True

                                            if self.attribute_reuse_id_config is not None:
                                                return True

                                            if self.attribute_reuse_id_current is not None:
                                                return True

                                            if self.attribute_reuse_id_keys is not None:
                                                return True

                                            if self.attribute_reuse_id_max_id is not None:
                                                return True

                                            if self.attribute_reuse_id_node is not None:
                                                return True

                                            if self.attribute_reuse_id_recover_sec is not None:
                                                return True

                                            if self.common_attributes is not None and self.common_attributes._has_data():
                                                return True

                                            if self.is_application_gateway_present is not None:
                                                return True

                                            if self.is_as_path2_byte is not None:
                                                return True

                                            if self.is_attr_set_present is not None:
                                                return True

                                            if self.is_ribrnh_present is not None:
                                                return True

                                            if self.is_rnh_present is not None:
                                                return True

                                            if self.ribrnh_encap is not None:
                                                return True

                                            if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                return True

                                            if self.ribrnh_mac is not None:
                                                return True

                                            if self.ribrnh_table is not None:
                                                return True

                                            if self.ribrnh_vni is not None:
                                                return True

                                            if self.ribrnhip_table is not None:
                                                return True

                                            if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                return True

                                            if self.rnh_addr_len is not None:
                                                return True

                                            if self.rnh_len is not None:
                                                return True

                                            if self.rnh_type is not None:
                                                return True

                                            if self.set_aigp_inbound_igp is not None:
                                                return True

                                            if self.set_aigp_inbound_metric is not None:
                                                return True

                                            if self.vpn_distinguisher is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                            return True

                                        if self.label_fail is not None:
                                            return True

                                        if self.label_o_or_version is not None:
                                            return True

                                        if self.label_oor is not None:
                                            return True

                                        if self.neighbor_address is not None:
                                            return True

                                        if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                            return True

                                        if self.network is not None:
                                            return True

                                        if self.no_path is not None:
                                            return True

                                        if self.path_id is not None:
                                            return True

                                        if self.path_information is not None and self.path_information._has_data():
                                            return True

                                        if self.prefix_length is not None:
                                            return True

                                        if self.prefix_version is not None:
                                            return True

                                        if self.process_instance_id is not None:
                                            return True

                                        if self.rd is not None:
                                            return True

                                        if self.route_distinguisher is not None:
                                            return True

                                        if self.route_type is not None:
                                            return True

                                        if self.source_rd is not None:
                                            return True

                                        if self.source_route_distinguisher is not None:
                                            return True

                                        if self.source_vrf_name is not None:
                                            return True

                                        if self.srcaf_name is not None:
                                            return True

                                        if self.vrf_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-labeled-table'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.path is not None:
                                        for child_ref in self.path:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable']['meta_info']


                            class AdvertisedPaths(object):
                                """
                                The BGP Advertised paths table (add\-paths)
                                
                                .. attribute:: advertised_path
                                
                                	A BGP Advertised paths table entry (add\-paths)
                                	**type**\: list of    :py:class:`AdvertisedPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.advertised_path = YList()
                                    self.advertised_path.parent = self
                                    self.advertised_path.name = 'advertised_path'


                                class AdvertisedPath(object):
                                    """
                                    A BGP Advertised paths table entry
                                    (add\-paths)
                                    
                                    .. attribute:: adv_path_info
                                    
                                    	Net Advertized Paths
                                    	**type**\: list of    :py:class:`AdvPathInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo>`
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor 
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: network
                                    
                                    	Network in hex string bytes format
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: paths
                                    
                                    	paths
                                    	**type**\: list of    :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths>`
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix length
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.adv_path_info = YList()
                                        self.adv_path_info.parent = self
                                        self.adv_path_info.name = 'adv_path_info'
                                        self.neighbor_address = None
                                        self.network = None
                                        self.paths = YList()
                                        self.paths.parent = self
                                        self.paths.name = 'paths'
                                        self.prefix_length = None
                                        self.rd = None


                                    class Paths(object):
                                        """
                                        paths
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\:  bool
                                        
                                        .. attribute:: label_o_or_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation>`
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\:  str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self.label_fail = None
                                            self.label_o_or_version = None
                                            self.label_oor = None
                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self.no_path = None
                                            self.path_information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation()
                                            self.path_information.parent = self
                                            self.prefix_version = None
                                            self.process_instance_id = None
                                            self.route_distinguisher = None
                                            self.source_route_distinguisher = None
                                            self.source_vrf_name = None
                                            self.srcaf_name = None
                                            self.vrf_name = None


                                        class NeighborAddressXr(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.NeighborAddressXr']['meta_info']


                                        class PathInformation(object):
                                            """
                                            Path information
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_esi
                                            
                                            	Path has EVPN ESI
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_rcvd_label
                                            
                                            	Path has received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebg_ps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2VpnEvpnEsi>`
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop>`
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhteTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_p_ath = None
                                                self.add_path_orr_bitfield = YList()
                                                self.add_path_orr_bitfield.parent = self
                                                self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                self.advertisedto_pe = None
                                                self.aigp_metric = None
                                                self.best_path_comp_stage = None
                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self.best_path_id = None
                                                self.best_path_id_comp_winner = None
                                                self.best_path_orr_bitfield = YList()
                                                self.best_path_orr_bitfield.parent = self
                                                self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self.dampen_penalty = None
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.fspec_invalid_path = None
                                                self.graceful_shutdown = None
                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self.halflife_time = None
                                                self.has_esi = None
                                                self.has_gw_addr = None
                                                self.has_local_net_label = None
                                                self.has_mdt_group_addr = None
                                                self.has_mvpn_extcomm = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.has_rcvd_label = None
                                                self.has_second_label = None
                                                self.ibgp_signaled_validity = None
                                                self.igp_metric = None
                                                self.is_aggregation_suppressed = None
                                                self.is_as_best = None
                                                self.is_best_path = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_internal_path = None
                                                self.is_partial_best = None
                                                self.is_path_additional_path = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_af_install_eligible = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_damped = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_history_held = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_imported = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_multipath = None
                                                self.is_path_nexthop_discarded = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebg_ps = None
                                                self.is_path_received_only = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_stale = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_valid = None
                                                self.is_path_vpn_only = None
                                                self.is_permanent_path = None
                                                self.is_received_path_not_modified = None
                                                self.is_spkr_as_best = None
                                                self.l2vpn_circuit_status_value = YList()
                                                self.l2vpn_circuit_status_value.parent = self
                                                self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2VpnEvpnEsi()
                                                self.l2vpn_evpn_esi.parent = self
                                                self.l2vpn_size = None
                                                self.labeled_unicast_safi_path = None
                                                self.local_label = None
                                                self.local_nh = None
                                                self.local_path_id = None
                                                self.local_peers_advertised_to = YList()
                                                self.local_peers_advertised_to.parent = self
                                                self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                self.maximum_suppress_time = None
                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self.mvpn_path_flags = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_value = YList()
                                                self.mvpn_pmsi_value.parent = self
                                                self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                self.mvpn_sfs_path = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.neighbor_router_id = None
                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.path_flags = None
                                                self.path_flap_count = None
                                                self.path_import_flags = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.path_table_version = None
                                                self.path_weight = None
                                                self.pe_peers_advertised_to = YList()
                                                self.pe_peers_advertised_to.parent = self
                                                self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                self.rcvd_label = None
                                                self.rcvd_path_id = None
                                                self.reuse_value = None
                                                self.rib_failed = None
                                                self.route_type = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.rt_set_limit_enabled = None
                                                self.second_label = None
                                                self.seconds_since_first_flap = None
                                                self.show_rpki_origin_as_validity = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.suppress_penalty = None
                                                self.time_to_unsuppress = None


                                            class BgpPrefix(object):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self.prefix_length = None


                                                class Prefix(object):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.prefix is not None and self.prefix._has_data():
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix']['meta_info']


                                            class NeighborAddress(object):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress']['meta_info']


                                            class NextHop(object):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhteTunnel']['meta_info']


                                            class MdtGroupAddr(object):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr']['meta_info']


                                            class L2VpnEvpnEsi(object):
                                                """
                                                L2VPN EVPN ESI
                                                
                                                .. attribute:: esi
                                                
                                                	esi
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.esi = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.esi is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2VpnEvpnEsi']['meta_info']


                                            class GwAddr(object):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr']['meta_info']


                                            class BestPathCompWinner(object):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner']['meta_info']


                                            class MvpnNbrAddr(object):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr']['meta_info']


                                            class MvpnNexthopAddr(object):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr']['meta_info']


                                            class L2VpnCircuitStatusValue(object):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                            class MvpnPmsiValue(object):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity']['meta_info']


                                            class LocalPeersAdvertisedTo(object):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                            class PePeersAdvertisedTo(object):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo']['meta_info']


                                            class BestPathOrrBitfield(object):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield']['meta_info']


                                            class AddPathOrrBitfield(object):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.accept_own_path is not None:
                                                    return True

                                                if self.accept_own_self_originated_p_ath is not None:
                                                    return True

                                                if self.add_path_orr_bitfield is not None:
                                                    for child_ref in self.add_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.advertisedto_pe is not None:
                                                    return True

                                                if self.aigp_metric is not None:
                                                    return True

                                                if self.best_path_comp_stage is not None:
                                                    return True

                                                if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                    return True

                                                if self.best_path_id is not None:
                                                    return True

                                                if self.best_path_id_comp_winner is not None:
                                                    return True

                                                if self.best_path_orr_bitfield is not None:
                                                    for child_ref in self.best_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                    return True

                                                if self.dampen_penalty is not None:
                                                    return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.fspec_invalid_path is not None:
                                                    return True

                                                if self.graceful_shutdown is not None:
                                                    return True

                                                if self.gw_addr is not None and self.gw_addr._has_data():
                                                    return True

                                                if self.halflife_time is not None:
                                                    return True

                                                if self.has_esi is not None:
                                                    return True

                                                if self.has_gw_addr is not None:
                                                    return True

                                                if self.has_local_net_label is not None:
                                                    return True

                                                if self.has_mdt_group_addr is not None:
                                                    return True

                                                if self.has_mvpn_extcomm is not None:
                                                    return True

                                                if self.has_mvpn_nbr_addr is not None:
                                                    return True

                                                if self.has_mvpn_nexthop_addr is not None:
                                                    return True

                                                if self.has_mvpn_pmsi is not None:
                                                    return True

                                                if self.has_rcvd_label is not None:
                                                    return True

                                                if self.has_second_label is not None:
                                                    return True

                                                if self.ibgp_signaled_validity is not None:
                                                    return True

                                                if self.igp_metric is not None:
                                                    return True

                                                if self.is_aggregation_suppressed is not None:
                                                    return True

                                                if self.is_as_best is not None:
                                                    return True

                                                if self.is_best_path is not None:
                                                    return True

                                                if self.is_import_dampened is not None:
                                                    return True

                                                if self.is_import_suspect is not None:
                                                    return True

                                                if self.is_internal_path is not None:
                                                    return True

                                                if self.is_partial_best is not None:
                                                    return True

                                                if self.is_path_additional_path is not None:
                                                    return True

                                                if self.is_path_advertised_local_as_only is not None:
                                                    return True

                                                if self.is_path_af_install_eligible is not None:
                                                    return True

                                                if self.is_path_backup is not None:
                                                    return True

                                                if self.is_path_backup_protect_multipath is not None:
                                                    return True

                                                if self.is_path_best_external is not None:
                                                    return True

                                                if self.is_path_damped is not None:
                                                    return True

                                                if self.is_path_from_confederation_peer is not None:
                                                    return True

                                                if self.is_path_from_network_command is not None:
                                                    return True

                                                if self.is_path_from_redistribute_command is not None:
                                                    return True

                                                if self.is_path_from_route_reflector is not None:
                                                    return True

                                                if self.is_path_history_held is not None:
                                                    return True

                                                if self.is_path_imp_candidate is not None:
                                                    return True

                                                if self.is_path_imported is not None:
                                                    return True

                                                if self.is_path_local_aggregate is not None:
                                                    return True

                                                if self.is_path_locally_sourced is not None:
                                                    return True

                                                if self.is_path_long_lived_stale is not None:
                                                    return True

                                                if self.is_path_multipath is not None:
                                                    return True

                                                if self.is_path_nexthop_discarded is not None:
                                                    return True

                                                if self.is_path_not_advertised is not None:
                                                    return True

                                                if self.is_path_not_advertised_to_ebg_ps is not None:
                                                    return True

                                                if self.is_path_received_only is not None:
                                                    return True

                                                if self.is_path_reoriginated is not None:
                                                    return True

                                                if self.is_path_reoriginated_stitching is not None:
                                                    return True

                                                if self.is_path_stale is not None:
                                                    return True

                                                if self.is_path_synced_with_igp is not None:
                                                    return True

                                                if self.is_path_valid is not None:
                                                    return True

                                                if self.is_path_vpn_only is not None:
                                                    return True

                                                if self.is_permanent_path is not None:
                                                    return True

                                                if self.is_received_path_not_modified is not None:
                                                    return True

                                                if self.is_spkr_as_best is not None:
                                                    return True

                                                if self.l2vpn_circuit_status_value is not None:
                                                    for child_ref in self.l2vpn_circuit_status_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                    return True

                                                if self.l2vpn_size is not None:
                                                    return True

                                                if self.labeled_unicast_safi_path is not None:
                                                    return True

                                                if self.local_label is not None:
                                                    return True

                                                if self.local_nh is not None:
                                                    return True

                                                if self.local_path_id is not None:
                                                    return True

                                                if self.local_peers_advertised_to is not None:
                                                    for child_ref in self.local_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.maximum_suppress_time is not None:
                                                    return True

                                                if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                    return True

                                                if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                    return True

                                                if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                    return True

                                                if self.mvpn_path_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_label is not None:
                                                    return True

                                                if self.mvpn_pmsi_type is not None:
                                                    return True

                                                if self.mvpn_pmsi_value is not None:
                                                    for child_ref in self.mvpn_pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.mvpn_sfs_path is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.neighbor_router_id is not None:
                                                    return True

                                                if self.next_hop is not None and self.next_hop._has_data():
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.path_flags is not None:
                                                    return True

                                                if self.path_flap_count is not None:
                                                    return True

                                                if self.path_import_flags is not None:
                                                    return True

                                                if self.path_rt_set_id is not None:
                                                    return True

                                                if self.path_rt_set_route_count is not None:
                                                    return True

                                                if self.path_table_version is not None:
                                                    return True

                                                if self.path_weight is not None:
                                                    return True

                                                if self.pe_peers_advertised_to is not None:
                                                    for child_ref in self.pe_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.rcvd_label is not None:
                                                    return True

                                                if self.rcvd_path_id is not None:
                                                    return True

                                                if self.reuse_value is not None:
                                                    return True

                                                if self.rib_failed is not None:
                                                    return True

                                                if self.route_type is not None:
                                                    return True

                                                if self.rpki_origin_as_validation_disabled is not None:
                                                    return True

                                                if self.rt_set_limit_enabled is not None:
                                                    return True

                                                if self.second_label is not None:
                                                    return True

                                                if self.seconds_since_first_flap is not None:
                                                    return True

                                                if self.show_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.sn_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.suppress_penalty is not None:
                                                    return True

                                                if self.time_to_unsuppress is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation']['meta_info']


                                        class AttributesAfterPolicyIn(object):
                                            """
                                            Attributes after inbound policy applied
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self.is_application_gateway_present = None
                                                self.is_as_path2_byte = None
                                                self.is_attr_set_present = None
                                                self.is_ribrnh_present = None
                                                self.is_rnh_present = None
                                                self.ribrnh_encap = None
                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self.ribrnh_mac = None
                                                self.ribrnh_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnhip_table = None
                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self.rnh_addr_len = None
                                                self.rnh_len = None
                                                self.rnh_type = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.vpn_distinguisher = None


                                            class CommonAttributes(object):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                            class AttrSet(object):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                            class RnhAddr(object):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None
                                                    self.mac_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    if self.mac_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                            class RibrnhIp(object):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.attr_set is not None and self.attr_set._has_data():
                                                    return True

                                                if self.attribute_key_number is not None:
                                                    return True

                                                if self.attribute_reuse_id_config is not None:
                                                    return True

                                                if self.attribute_reuse_id_current is not None:
                                                    return True

                                                if self.attribute_reuse_id_keys is not None:
                                                    return True

                                                if self.attribute_reuse_id_max_id is not None:
                                                    return True

                                                if self.attribute_reuse_id_node is not None:
                                                    return True

                                                if self.attribute_reuse_id_recover_sec is not None:
                                                    return True

                                                if self.common_attributes is not None and self.common_attributes._has_data():
                                                    return True

                                                if self.is_application_gateway_present is not None:
                                                    return True

                                                if self.is_as_path2_byte is not None:
                                                    return True

                                                if self.is_attr_set_present is not None:
                                                    return True

                                                if self.is_ribrnh_present is not None:
                                                    return True

                                                if self.is_rnh_present is not None:
                                                    return True

                                                if self.ribrnh_encap is not None:
                                                    return True

                                                if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                    return True

                                                if self.ribrnh_mac is not None:
                                                    return True

                                                if self.ribrnh_table is not None:
                                                    return True

                                                if self.ribrnh_vni is not None:
                                                    return True

                                                if self.ribrnhip_table is not None:
                                                    return True

                                                if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                    return True

                                                if self.rnh_addr_len is not None:
                                                    return True

                                                if self.rnh_len is not None:
                                                    return True

                                                if self.rnh_type is not None:
                                                    return True

                                                if self.set_aigp_inbound_igp is not None:
                                                    return True

                                                if self.set_aigp_inbound_metric is not None:
                                                    return True

                                                if self.vpn_distinguisher is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:paths'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                return True

                                            if self.label_fail is not None:
                                                return True

                                            if self.label_o_or_version is not None:
                                                return True

                                            if self.label_oor is not None:
                                                return True

                                            if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                return True

                                            if self.no_path is not None:
                                                return True

                                            if self.path_information is not None and self.path_information._has_data():
                                                return True

                                            if self.prefix_version is not None:
                                                return True

                                            if self.process_instance_id is not None:
                                                return True

                                            if self.route_distinguisher is not None:
                                                return True

                                            if self.source_route_distinguisher is not None:
                                                return True

                                            if self.source_vrf_name is not None:
                                                return True

                                            if self.srcaf_name is not None:
                                                return True

                                            if self.vrf_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths']['meta_info']


                                    class AdvPathInfo(object):
                                        """
                                        Net Advertized Paths
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy
                                        	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: attributes_after_policy_out
                                        
                                        	Attributes after outbound policy
                                        	**type**\:   :py:class:`AttributesAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut>`
                                        
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists All 'sp\_path\_in' fields except 'sp\_path\_in\->bag\_prefix' are invalid.  All 'sp\_path\_out' fields are invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_info_after_policy_in
                                        
                                        	Path information after inbound policy
                                        	**type**\:   :py:class:`PathInfoAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn>`
                                        
                                        .. attribute:: path_info_after_policy_out
                                        
                                        	Path information after outbound policy
                                        	**type**\:   :py:class:`PathInfoAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut>`
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.af_name = None
                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self.attributes_after_policy_out = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut()
                                            self.attributes_after_policy_out.parent = self
                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self.no_path = None
                                            self.path_info_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn()
                                            self.path_info_after_policy_in.parent = self
                                            self.path_info_after_policy_out = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut()
                                            self.path_info_after_policy_out.parent = self
                                            self.route_distinguisher = None
                                            self.source_route_distinguisher = None
                                            self.vrf_name = None


                                        class NeighborAddressXr(object):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr']['meta_info']


                                        class PathInfoAfterPolicyIn(object):
                                            """
                                            Path information after inbound policy
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_esi
                                            
                                            	Path has EVPN ESI
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_rcvd_label
                                            
                                            	Path has received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebg_ps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2VpnEvpnEsi>`
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop>`
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhteTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_p_ath = None
                                                self.add_path_orr_bitfield = YList()
                                                self.add_path_orr_bitfield.parent = self
                                                self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                self.advertisedto_pe = None
                                                self.aigp_metric = None
                                                self.best_path_comp_stage = None
                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self.best_path_id = None
                                                self.best_path_id_comp_winner = None
                                                self.best_path_orr_bitfield = YList()
                                                self.best_path_orr_bitfield.parent = self
                                                self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self.dampen_penalty = None
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.fspec_invalid_path = None
                                                self.graceful_shutdown = None
                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr()
                                                self.gw_addr.parent = self
                                                self.halflife_time = None
                                                self.has_esi = None
                                                self.has_gw_addr = None
                                                self.has_local_net_label = None
                                                self.has_mdt_group_addr = None
                                                self.has_mvpn_extcomm = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.has_rcvd_label = None
                                                self.has_second_label = None
                                                self.ibgp_signaled_validity = None
                                                self.igp_metric = None
                                                self.is_aggregation_suppressed = None
                                                self.is_as_best = None
                                                self.is_best_path = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_internal_path = None
                                                self.is_partial_best = None
                                                self.is_path_additional_path = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_af_install_eligible = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_damped = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_history_held = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_imported = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_multipath = None
                                                self.is_path_nexthop_discarded = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebg_ps = None
                                                self.is_path_received_only = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_stale = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_valid = None
                                                self.is_path_vpn_only = None
                                                self.is_permanent_path = None
                                                self.is_received_path_not_modified = None
                                                self.is_spkr_as_best = None
                                                self.l2vpn_circuit_status_value = YList()
                                                self.l2vpn_circuit_status_value.parent = self
                                                self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2VpnEvpnEsi()
                                                self.l2vpn_evpn_esi.parent = self
                                                self.l2vpn_size = None
                                                self.labeled_unicast_safi_path = None
                                                self.local_label = None
                                                self.local_nh = None
                                                self.local_path_id = None
                                                self.local_peers_advertised_to = YList()
                                                self.local_peers_advertised_to.parent = self
                                                self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                self.maximum_suppress_time = None
                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self.mvpn_path_flags = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_value = YList()
                                                self.mvpn_pmsi_value.parent = self
                                                self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                self.mvpn_sfs_path = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.neighbor_router_id = None
                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop()
                                                self.next_hop.parent = self
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.path_flags = None
                                                self.path_flap_count = None
                                                self.path_import_flags = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.path_table_version = None
                                                self.path_weight = None
                                                self.pe_peers_advertised_to = YList()
                                                self.pe_peers_advertised_to.parent = self
                                                self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                self.rcvd_label = None
                                                self.rcvd_path_id = None
                                                self.reuse_value = None
                                                self.rib_failed = None
                                                self.route_type = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.rt_set_limit_enabled = None
                                                self.second_label = None
                                                self.seconds_since_first_flap = None
                                                self.show_rpki_origin_as_validity = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.suppress_penalty = None
                                                self.time_to_unsuppress = None


                                            class BgpPrefix(object):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self.prefix_length = None


                                                class Prefix(object):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.prefix is not None and self.prefix._has_data():
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix']['meta_info']


                                            class NeighborAddress(object):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress']['meta_info']


                                            class NextHop(object):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhteTunnel']['meta_info']


                                            class MdtGroupAddr(object):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr']['meta_info']


                                            class L2VpnEvpnEsi(object):
                                                """
                                                L2VPN EVPN ESI
                                                
                                                .. attribute:: esi
                                                
                                                	esi
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.esi = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.esi is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2VpnEvpnEsi']['meta_info']


                                            class GwAddr(object):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr']['meta_info']


                                            class BestPathCompWinner(object):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner']['meta_info']


                                            class MvpnNbrAddr(object):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr']['meta_info']


                                            class MvpnNexthopAddr(object):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr']['meta_info']


                                            class L2VpnCircuitStatusValue(object):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2VpnCircuitStatusValue']['meta_info']


                                            class MvpnPmsiValue(object):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity']['meta_info']


                                            class LocalPeersAdvertisedTo(object):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo']['meta_info']


                                            class PePeersAdvertisedTo(object):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo']['meta_info']


                                            class BestPathOrrBitfield(object):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield']['meta_info']


                                            class AddPathOrrBitfield(object):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-info-after-policy-in'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.accept_own_path is not None:
                                                    return True

                                                if self.accept_own_self_originated_p_ath is not None:
                                                    return True

                                                if self.add_path_orr_bitfield is not None:
                                                    for child_ref in self.add_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.advertisedto_pe is not None:
                                                    return True

                                                if self.aigp_metric is not None:
                                                    return True

                                                if self.best_path_comp_stage is not None:
                                                    return True

                                                if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                    return True

                                                if self.best_path_id is not None:
                                                    return True

                                                if self.best_path_id_comp_winner is not None:
                                                    return True

                                                if self.best_path_orr_bitfield is not None:
                                                    for child_ref in self.best_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                    return True

                                                if self.dampen_penalty is not None:
                                                    return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.fspec_invalid_path is not None:
                                                    return True

                                                if self.graceful_shutdown is not None:
                                                    return True

                                                if self.gw_addr is not None and self.gw_addr._has_data():
                                                    return True

                                                if self.halflife_time is not None:
                                                    return True

                                                if self.has_esi is not None:
                                                    return True

                                                if self.has_gw_addr is not None:
                                                    return True

                                                if self.has_local_net_label is not None:
                                                    return True

                                                if self.has_mdt_group_addr is not None:
                                                    return True

                                                if self.has_mvpn_extcomm is not None:
                                                    return True

                                                if self.has_mvpn_nbr_addr is not None:
                                                    return True

                                                if self.has_mvpn_nexthop_addr is not None:
                                                    return True

                                                if self.has_mvpn_pmsi is not None:
                                                    return True

                                                if self.has_rcvd_label is not None:
                                                    return True

                                                if self.has_second_label is not None:
                                                    return True

                                                if self.ibgp_signaled_validity is not None:
                                                    return True

                                                if self.igp_metric is not None:
                                                    return True

                                                if self.is_aggregation_suppressed is not None:
                                                    return True

                                                if self.is_as_best is not None:
                                                    return True

                                                if self.is_best_path is not None:
                                                    return True

                                                if self.is_import_dampened is not None:
                                                    return True

                                                if self.is_import_suspect is not None:
                                                    return True

                                                if self.is_internal_path is not None:
                                                    return True

                                                if self.is_partial_best is not None:
                                                    return True

                                                if self.is_path_additional_path is not None:
                                                    return True

                                                if self.is_path_advertised_local_as_only is not None:
                                                    return True

                                                if self.is_path_af_install_eligible is not None:
                                                    return True

                                                if self.is_path_backup is not None:
                                                    return True

                                                if self.is_path_backup_protect_multipath is not None:
                                                    return True

                                                if self.is_path_best_external is not None:
                                                    return True

                                                if self.is_path_damped is not None:
                                                    return True

                                                if self.is_path_from_confederation_peer is not None:
                                                    return True

                                                if self.is_path_from_network_command is not None:
                                                    return True

                                                if self.is_path_from_redistribute_command is not None:
                                                    return True

                                                if self.is_path_from_route_reflector is not None:
                                                    return True

                                                if self.is_path_history_held is not None:
                                                    return True

                                                if self.is_path_imp_candidate is not None:
                                                    return True

                                                if self.is_path_imported is not None:
                                                    return True

                                                if self.is_path_local_aggregate is not None:
                                                    return True

                                                if self.is_path_locally_sourced is not None:
                                                    return True

                                                if self.is_path_long_lived_stale is not None:
                                                    return True

                                                if self.is_path_multipath is not None:
                                                    return True

                                                if self.is_path_nexthop_discarded is not None:
                                                    return True

                                                if self.is_path_not_advertised is not None:
                                                    return True

                                                if self.is_path_not_advertised_to_ebg_ps is not None:
                                                    return True

                                                if self.is_path_received_only is not None:
                                                    return True

                                                if self.is_path_reoriginated is not None:
                                                    return True

                                                if self.is_path_reoriginated_stitching is not None:
                                                    return True

                                                if self.is_path_stale is not None:
                                                    return True

                                                if self.is_path_synced_with_igp is not None:
                                                    return True

                                                if self.is_path_valid is not None:
                                                    return True

                                                if self.is_path_vpn_only is not None:
                                                    return True

                                                if self.is_permanent_path is not None:
                                                    return True

                                                if self.is_received_path_not_modified is not None:
                                                    return True

                                                if self.is_spkr_as_best is not None:
                                                    return True

                                                if self.l2vpn_circuit_status_value is not None:
                                                    for child_ref in self.l2vpn_circuit_status_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                    return True

                                                if self.l2vpn_size is not None:
                                                    return True

                                                if self.labeled_unicast_safi_path is not None:
                                                    return True

                                                if self.local_label is not None:
                                                    return True

                                                if self.local_nh is not None:
                                                    return True

                                                if self.local_path_id is not None:
                                                    return True

                                                if self.local_peers_advertised_to is not None:
                                                    for child_ref in self.local_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.maximum_suppress_time is not None:
                                                    return True

                                                if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                    return True

                                                if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                    return True

                                                if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                    return True

                                                if self.mvpn_path_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_label is not None:
                                                    return True

                                                if self.mvpn_pmsi_type is not None:
                                                    return True

                                                if self.mvpn_pmsi_value is not None:
                                                    for child_ref in self.mvpn_pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.mvpn_sfs_path is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.neighbor_router_id is not None:
                                                    return True

                                                if self.next_hop is not None and self.next_hop._has_data():
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.path_flags is not None:
                                                    return True

                                                if self.path_flap_count is not None:
                                                    return True

                                                if self.path_import_flags is not None:
                                                    return True

                                                if self.path_rt_set_id is not None:
                                                    return True

                                                if self.path_rt_set_route_count is not None:
                                                    return True

                                                if self.path_table_version is not None:
                                                    return True

                                                if self.path_weight is not None:
                                                    return True

                                                if self.pe_peers_advertised_to is not None:
                                                    for child_ref in self.pe_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.rcvd_label is not None:
                                                    return True

                                                if self.rcvd_path_id is not None:
                                                    return True

                                                if self.reuse_value is not None:
                                                    return True

                                                if self.rib_failed is not None:
                                                    return True

                                                if self.route_type is not None:
                                                    return True

                                                if self.rpki_origin_as_validation_disabled is not None:
                                                    return True

                                                if self.rt_set_limit_enabled is not None:
                                                    return True

                                                if self.second_label is not None:
                                                    return True

                                                if self.seconds_since_first_flap is not None:
                                                    return True

                                                if self.show_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.sn_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.suppress_penalty is not None:
                                                    return True

                                                if self.time_to_unsuppress is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn']['meta_info']


                                        class PathInfoAfterPolicyOut(object):
                                            """
                                            Path information after outbound policy
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\:  bool
                                            
                                            .. attribute:: accept_own_self_originated_p_ath
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\:  bool
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner>`
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix>`
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity>`
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\:  bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\:  bool
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr>`
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_esi
                                            
                                            	Path has EVPN ESI
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_rcvd_label
                                            
                                            	Path has received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\:  bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\:  bool
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebg_ps
                                            
                                            	Not advertised to EBGPs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue>`
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2VpnEvpnEsi>`
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr>`
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue>`
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress>`
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop>`
                                            
                                            .. attribute:: nhte_tunnel
                                            
                                            	NH TE tunnel information
                                            	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhteTunnel>`
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\:  bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\:  bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_p_ath = None
                                                self.add_path_orr_bitfield = YList()
                                                self.add_path_orr_bitfield.parent = self
                                                self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                self.advertisedto_pe = None
                                                self.aigp_metric = None
                                                self.best_path_comp_stage = None
                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self.best_path_id = None
                                                self.best_path_id_comp_winner = None
                                                self.best_path_orr_bitfield = YList()
                                                self.best_path_orr_bitfield.parent = self
                                                self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self.dampen_penalty = None
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.fspec_invalid_path = None
                                                self.graceful_shutdown = None
                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr()
                                                self.gw_addr.parent = self
                                                self.halflife_time = None
                                                self.has_esi = None
                                                self.has_gw_addr = None
                                                self.has_local_net_label = None
                                                self.has_mdt_group_addr = None
                                                self.has_mvpn_extcomm = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.has_rcvd_label = None
                                                self.has_second_label = None
                                                self.ibgp_signaled_validity = None
                                                self.igp_metric = None
                                                self.is_aggregation_suppressed = None
                                                self.is_as_best = None
                                                self.is_best_path = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_internal_path = None
                                                self.is_partial_best = None
                                                self.is_path_additional_path = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_af_install_eligible = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_damped = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_history_held = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_imported = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_multipath = None
                                                self.is_path_nexthop_discarded = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebg_ps = None
                                                self.is_path_received_only = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_stale = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_valid = None
                                                self.is_path_vpn_only = None
                                                self.is_permanent_path = None
                                                self.is_received_path_not_modified = None
                                                self.is_spkr_as_best = None
                                                self.l2vpn_circuit_status_value = YList()
                                                self.l2vpn_circuit_status_value.parent = self
                                                self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2VpnEvpnEsi()
                                                self.l2vpn_evpn_esi.parent = self
                                                self.l2vpn_size = None
                                                self.labeled_unicast_safi_path = None
                                                self.local_label = None
                                                self.local_nh = None
                                                self.local_path_id = None
                                                self.local_peers_advertised_to = YList()
                                                self.local_peers_advertised_to.parent = self
                                                self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                self.maximum_suppress_time = None
                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self.mvpn_path_flags = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_value = YList()
                                                self.mvpn_pmsi_value.parent = self
                                                self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                self.mvpn_sfs_path = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.neighbor_router_id = None
                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop()
                                                self.next_hop.parent = self
                                                self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhteTunnel()
                                                self.nhte_tunnel.parent = self
                                                self.path_flags = None
                                                self.path_flap_count = None
                                                self.path_import_flags = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.path_table_version = None
                                                self.path_weight = None
                                                self.pe_peers_advertised_to = YList()
                                                self.pe_peers_advertised_to.parent = self
                                                self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                self.rcvd_label = None
                                                self.rcvd_path_id = None
                                                self.reuse_value = None
                                                self.rib_failed = None
                                                self.route_type = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.rt_set_limit_enabled = None
                                                self.second_label = None
                                                self.seconds_since_first_flap = None
                                                self.show_rpki_origin_as_validity = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.suppress_penalty = None
                                                self.time_to_unsuppress = None


                                            class BgpPrefix(object):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self.prefix_length = None


                                                class Prefix(object):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.prefix is not None and self.prefix._has_data():
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix']['meta_info']


                                            class NeighborAddress(object):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress']['meta_info']


                                            class NextHop(object):
                                                """
                                                Next hop
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop']['meta_info']


                                            class NhteTunnel(object):
                                                """
                                                NH TE tunnel information
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_te_tunnel
                                                
                                                	NH TE Tunnel info is present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\:  bool
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	tunnel name
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	tunnel type
                                                	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.binding_label = None
                                                    self.has_te_tunnel = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.is_tunnel_up = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_if_handle = None
                                                    self.tunnel_name = None
                                                    self.tunnel_type = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_v6_required = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.binding_label is not None:
                                                        return True

                                                    if self.has_te_tunnel is not None:
                                                        return True

                                                    if self.is_tunnel_info_stale is not None:
                                                        return True

                                                    if self.is_tunnel_registered is not None:
                                                        return True

                                                    if self.is_tunnel_up is not None:
                                                        return True

                                                    if self.last_tunnel_update is not None:
                                                        return True

                                                    if self.tunnel_if_handle is not None:
                                                        return True

                                                    if self.tunnel_name is not None:
                                                        return True

                                                    if self.tunnel_type is not None:
                                                        return True

                                                    if self.tunnel_v6_enabled is not None:
                                                        return True

                                                    if self.tunnel_v6_required is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhteTunnel']['meta_info']


                                            class MdtGroupAddr(object):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr']['meta_info']


                                            class L2VpnEvpnEsi(object):
                                                """
                                                L2VPN EVPN ESI
                                                
                                                .. attribute:: esi
                                                
                                                	esi
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.esi = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.esi is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2VpnEvpnEsi']['meta_info']


                                            class GwAddr(object):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr']['meta_info']


                                            class BestPathCompWinner(object):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner']['meta_info']


                                            class MvpnNbrAddr(object):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr']['meta_info']


                                            class MvpnNexthopAddr(object):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr']['meta_info']


                                            class L2VpnCircuitStatusValue(object):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2VpnCircuitStatusValue']['meta_info']


                                            class MvpnPmsiValue(object):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity']['meta_info']


                                            class LocalPeersAdvertisedTo(object):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo']['meta_info']


                                            class PePeersAdvertisedTo(object):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo']['meta_info']


                                            class BestPathOrrBitfield(object):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield']['meta_info']


                                            class AddPathOrrBitfield(object):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-info-after-policy-out'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.accept_own_path is not None:
                                                    return True

                                                if self.accept_own_self_originated_p_ath is not None:
                                                    return True

                                                if self.add_path_orr_bitfield is not None:
                                                    for child_ref in self.add_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.advertisedto_pe is not None:
                                                    return True

                                                if self.aigp_metric is not None:
                                                    return True

                                                if self.best_path_comp_stage is not None:
                                                    return True

                                                if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                    return True

                                                if self.best_path_id is not None:
                                                    return True

                                                if self.best_path_id_comp_winner is not None:
                                                    return True

                                                if self.best_path_orr_bitfield is not None:
                                                    for child_ref in self.best_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                    return True

                                                if self.dampen_penalty is not None:
                                                    return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.fspec_invalid_path is not None:
                                                    return True

                                                if self.graceful_shutdown is not None:
                                                    return True

                                                if self.gw_addr is not None and self.gw_addr._has_data():
                                                    return True

                                                if self.halflife_time is not None:
                                                    return True

                                                if self.has_esi is not None:
                                                    return True

                                                if self.has_gw_addr is not None:
                                                    return True

                                                if self.has_local_net_label is not None:
                                                    return True

                                                if self.has_mdt_group_addr is not None:
                                                    return True

                                                if self.has_mvpn_extcomm is not None:
                                                    return True

                                                if self.has_mvpn_nbr_addr is not None:
                                                    return True

                                                if self.has_mvpn_nexthop_addr is not None:
                                                    return True

                                                if self.has_mvpn_pmsi is not None:
                                                    return True

                                                if self.has_rcvd_label is not None:
                                                    return True

                                                if self.has_second_label is not None:
                                                    return True

                                                if self.ibgp_signaled_validity is not None:
                                                    return True

                                                if self.igp_metric is not None:
                                                    return True

                                                if self.is_aggregation_suppressed is not None:
                                                    return True

                                                if self.is_as_best is not None:
                                                    return True

                                                if self.is_best_path is not None:
                                                    return True

                                                if self.is_import_dampened is not None:
                                                    return True

                                                if self.is_import_suspect is not None:
                                                    return True

                                                if self.is_internal_path is not None:
                                                    return True

                                                if self.is_partial_best is not None:
                                                    return True

                                                if self.is_path_additional_path is not None:
                                                    return True

                                                if self.is_path_advertised_local_as_only is not None:
                                                    return True

                                                if self.is_path_af_install_eligible is not None:
                                                    return True

                                                if self.is_path_backup is not None:
                                                    return True

                                                if self.is_path_backup_protect_multipath is not None:
                                                    return True

                                                if self.is_path_best_external is not None:
                                                    return True

                                                if self.is_path_damped is not None:
                                                    return True

                                                if self.is_path_from_confederation_peer is not None:
                                                    return True

                                                if self.is_path_from_network_command is not None:
                                                    return True

                                                if self.is_path_from_redistribute_command is not None:
                                                    return True

                                                if self.is_path_from_route_reflector is not None:
                                                    return True

                                                if self.is_path_history_held is not None:
                                                    return True

                                                if self.is_path_imp_candidate is not None:
                                                    return True

                                                if self.is_path_imported is not None:
                                                    return True

                                                if self.is_path_local_aggregate is not None:
                                                    return True

                                                if self.is_path_locally_sourced is not None:
                                                    return True

                                                if self.is_path_long_lived_stale is not None:
                                                    return True

                                                if self.is_path_multipath is not None:
                                                    return True

                                                if self.is_path_nexthop_discarded is not None:
                                                    return True

                                                if self.is_path_not_advertised is not None:
                                                    return True

                                                if self.is_path_not_advertised_to_ebg_ps is not None:
                                                    return True

                                                if self.is_path_received_only is not None:
                                                    return True

                                                if self.is_path_reoriginated is not None:
                                                    return True

                                                if self.is_path_reoriginated_stitching is not None:
                                                    return True

                                                if self.is_path_stale is not None:
                                                    return True

                                                if self.is_path_synced_with_igp is not None:
                                                    return True

                                                if self.is_path_valid is not None:
                                                    return True

                                                if self.is_path_vpn_only is not None:
                                                    return True

                                                if self.is_permanent_path is not None:
                                                    return True

                                                if self.is_received_path_not_modified is not None:
                                                    return True

                                                if self.is_spkr_as_best is not None:
                                                    return True

                                                if self.l2vpn_circuit_status_value is not None:
                                                    for child_ref in self.l2vpn_circuit_status_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                    return True

                                                if self.l2vpn_size is not None:
                                                    return True

                                                if self.labeled_unicast_safi_path is not None:
                                                    return True

                                                if self.local_label is not None:
                                                    return True

                                                if self.local_nh is not None:
                                                    return True

                                                if self.local_path_id is not None:
                                                    return True

                                                if self.local_peers_advertised_to is not None:
                                                    for child_ref in self.local_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.maximum_suppress_time is not None:
                                                    return True

                                                if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                    return True

                                                if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                    return True

                                                if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                    return True

                                                if self.mvpn_path_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_flags is not None:
                                                    return True

                                                if self.mvpn_pmsi_label is not None:
                                                    return True

                                                if self.mvpn_pmsi_type is not None:
                                                    return True

                                                if self.mvpn_pmsi_value is not None:
                                                    for child_ref in self.mvpn_pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.mvpn_sfs_path is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.neighbor_router_id is not None:
                                                    return True

                                                if self.next_hop is not None and self.next_hop._has_data():
                                                    return True

                                                if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                    return True

                                                if self.path_flags is not None:
                                                    return True

                                                if self.path_flap_count is not None:
                                                    return True

                                                if self.path_import_flags is not None:
                                                    return True

                                                if self.path_rt_set_id is not None:
                                                    return True

                                                if self.path_rt_set_route_count is not None:
                                                    return True

                                                if self.path_table_version is not None:
                                                    return True

                                                if self.path_weight is not None:
                                                    return True

                                                if self.pe_peers_advertised_to is not None:
                                                    for child_ref in self.pe_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.rcvd_label is not None:
                                                    return True

                                                if self.rcvd_path_id is not None:
                                                    return True

                                                if self.reuse_value is not None:
                                                    return True

                                                if self.rib_failed is not None:
                                                    return True

                                                if self.route_type is not None:
                                                    return True

                                                if self.rpki_origin_as_validation_disabled is not None:
                                                    return True

                                                if self.rt_set_limit_enabled is not None:
                                                    return True

                                                if self.second_label is not None:
                                                    return True

                                                if self.seconds_since_first_flap is not None:
                                                    return True

                                                if self.show_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.sn_rpki_origin_as_validity is not None:
                                                    return True

                                                if self.suppress_penalty is not None:
                                                    return True

                                                if self.time_to_unsuppress is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut']['meta_info']


                                        class AttributesAfterPolicyIn(object):
                                            """
                                            Attributes after inbound policy
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self.is_application_gateway_present = None
                                                self.is_as_path2_byte = None
                                                self.is_attr_set_present = None
                                                self.is_ribrnh_present = None
                                                self.is_rnh_present = None
                                                self.ribrnh_encap = None
                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self.ribrnh_mac = None
                                                self.ribrnh_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnhip_table = None
                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self.rnh_addr_len = None
                                                self.rnh_len = None
                                                self.rnh_type = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.vpn_distinguisher = None


                                            class CommonAttributes(object):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                            class AttrSet(object):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                            class RnhAddr(object):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None
                                                    self.mac_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    if self.mac_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                            class RibrnhIp(object):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.attr_set is not None and self.attr_set._has_data():
                                                    return True

                                                if self.attribute_key_number is not None:
                                                    return True

                                                if self.attribute_reuse_id_config is not None:
                                                    return True

                                                if self.attribute_reuse_id_current is not None:
                                                    return True

                                                if self.attribute_reuse_id_keys is not None:
                                                    return True

                                                if self.attribute_reuse_id_max_id is not None:
                                                    return True

                                                if self.attribute_reuse_id_node is not None:
                                                    return True

                                                if self.attribute_reuse_id_recover_sec is not None:
                                                    return True

                                                if self.common_attributes is not None and self.common_attributes._has_data():
                                                    return True

                                                if self.is_application_gateway_present is not None:
                                                    return True

                                                if self.is_as_path2_byte is not None:
                                                    return True

                                                if self.is_attr_set_present is not None:
                                                    return True

                                                if self.is_ribrnh_present is not None:
                                                    return True

                                                if self.is_rnh_present is not None:
                                                    return True

                                                if self.ribrnh_encap is not None:
                                                    return True

                                                if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                    return True

                                                if self.ribrnh_mac is not None:
                                                    return True

                                                if self.ribrnh_table is not None:
                                                    return True

                                                if self.ribrnh_vni is not None:
                                                    return True

                                                if self.ribrnhip_table is not None:
                                                    return True

                                                if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                    return True

                                                if self.rnh_addr_len is not None:
                                                    return True

                                                if self.rnh_len is not None:
                                                    return True

                                                if self.rnh_type is not None:
                                                    return True

                                                if self.set_aigp_inbound_igp is not None:
                                                    return True

                                                if self.set_aigp_inbound_metric is not None:
                                                    return True

                                                if self.vpn_distinguisher is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn']['meta_info']


                                        class AttributesAfterPolicyOut(object):
                                            """
                                            Attributes after outbound policy
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet>`
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes>`
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp>`
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr>`
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\:  bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\:  bool
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet()
                                                self.attr_set.parent = self
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self.is_application_gateway_present = None
                                                self.is_as_path2_byte = None
                                                self.is_attr_set_present = None
                                                self.is_ribrnh_present = None
                                                self.is_rnh_present = None
                                                self.ribrnh_encap = None
                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self.ribrnh_mac = None
                                                self.ribrnh_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnhip_table = None
                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self.rnh_addr_len = None
                                                self.rnh_len = None
                                                self.rnh_type = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.vpn_distinguisher = None


                                            class CommonAttributes(object):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes']['meta_info']


                                            class AttrSet(object):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\:  str
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster>`
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community>`
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\:  bool
                                                
                                                .. attribute:: is_tunnel_encap_present
                                                
                                                	Tunnel Encap attribute present 
                                                	**type**\:  bool
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie>`
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_index_attr
                                                
                                                	Label Index attribute
                                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr>`
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr>`
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_policy_allocated_binding_sid
                                                
                                                	SR Policy allocated Binding sid by the router
                                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyAllocatedBindingSid>`
                                                
                                                .. attribute:: sr_policy_binding_sid
                                                
                                                	SR Policy Binding sid
                                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyBindingSid>`
                                                
                                                .. attribute:: sr_policy_explicit_path
                                                
                                                	SR Policy Explicit paths
                                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyExplicitPath>`
                                                
                                                .. attribute:: sr_policy_preference
                                                
                                                	SR Policy Preference
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sr_tunnel_request_state
                                                
                                                	SR Tunnel Request State
                                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                
                                                .. attribute:: sr_tunnel_state
                                                
                                                	SR Tunnel State
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_encap_type
                                                
                                                	Tunnel Encap Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.aggregator_address = None
                                                    self.aggregator_as = None
                                                    self.aigp_metric_value = None
                                                    self.as_path = None
                                                    self.cluster = YList()
                                                    self.cluster.parent = self
                                                    self.cluster.name = 'cluster'
                                                    self.community = YList()
                                                    self.community.parent = self
                                                    self.community.name = 'community'
                                                    self.connector_type = None
                                                    self.connector_value = YList()
                                                    self.connector_value.parent = self
                                                    self.connector_value.name = 'connector_value'
                                                    self.extended_community = YList()
                                                    self.extended_community.parent = self
                                                    self.extended_community.name = 'extended_community'
                                                    self.extended_community_flags = None
                                                    self.is_aggregator_present = None
                                                    self.is_aigp_present = None
                                                    self.is_as_path_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_community_present = None
                                                    self.is_connector_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_label_index_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_metric_present = None
                                                    self.is_origin_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_ssa_present = None
                                                    self.is_tunnel_encap_present = None
                                                    self.l2tpv3_cookie = YList()
                                                    self.l2tpv3_cookie.parent = self
                                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                    self.l2tpv3_session_id = None
                                                    self.label_index_attr = YList()
                                                    self.label_index_attr.parent = self
                                                    self.label_index_attr.name = 'label_index_attr'
                                                    self.local_preference = None
                                                    self.ls_attr = YList()
                                                    self.ls_attr.parent = self
                                                    self.ls_attr.name = 'ls_attr'
                                                    self.metric = None
                                                    self.neighbor_as = None
                                                    self.origin = None
                                                    self.originator = None
                                                    self.pe_distinguisher_label = YList()
                                                    self.pe_distinguisher_label.parent = self
                                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.pmsi_type = None
                                                    self.pmsi_value = YList()
                                                    self.pmsi_value.parent = self
                                                    self.pmsi_value.name = 'pmsi_value'
                                                    self.ppm_pvalue = None
                                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyAllocatedBindingSid()
                                                    self.sr_policy_allocated_binding_sid.parent = self
                                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyBindingSid()
                                                    self.sr_policy_binding_sid.parent = self
                                                    self.sr_policy_explicit_path = YList()
                                                    self.sr_policy_explicit_path.parent = self
                                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                    self.sr_policy_preference = None
                                                    self.sr_tunnel_request_state = None
                                                    self.sr_tunnel_state = None
                                                    self.tunnel_encap_type = None
                                                    self.unknown_attribute = YList()
                                                    self.unknown_attribute.parent = self
                                                    self.unknown_attribute.name = 'unknown_attribute'


                                                class SrPolicyBindingSid(object):
                                                    """
                                                    SR Policy Binding sid
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyBindingSid']['meta_info']


                                                class SrPolicyAllocatedBindingSid(object):
                                                    """
                                                    SR Policy allocated Binding sid by the router
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Type
                                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_address = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                class Community(object):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community']['meta_info']


                                                class ExtendedCommunity(object):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity']['meta_info']


                                                class UnknownAttribute(object):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute']['meta_info']


                                                class Cluster(object):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster']['meta_info']


                                                class L2Tpv3Cookie(object):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2Tpv3Cookie']['meta_info']


                                                class ConnectorValue(object):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue']['meta_info']


                                                class PmsiValue(object):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue']['meta_info']


                                                class LsAttr(object):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr']['meta_info']


                                                class LabelIndexAttr(object):
                                                    """
                                                    Label Index attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.entry = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.entry is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LabelIndexAttr']['meta_info']


                                                class PeDistinguisherLabel(object):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.label = None
                                                        self.pe_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.label is not None:
                                                            return True

                                                        if self.pe_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel']['meta_info']


                                                class SrPolicyExplicitPath(object):
                                                    """
                                                    SR Policy Explicit paths
                                                    
                                                    .. attribute:: sid
                                                    
                                                    	Sidlist for explicit path
                                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyExplicitPath.Sid>`
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight of explicit path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.sid = YList()
                                                        self.sid.parent = self
                                                        self.sid.name = 'sid'
                                                        self.weight = None


                                                    class Sid(object):
                                                        """
                                                        Sidlist for explicit path
                                                        
                                                        .. attribute:: ipv4
                                                        
                                                        	IP Address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6
                                                        
                                                        	IPv6 address sid
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label sid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Sid Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4 = None
                                                            self.ipv6 = None
                                                            self.label = None
                                                            self.type = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4 is not None:
                                                                return True

                                                            if self.ipv6 is not None:
                                                                return True

                                                            if self.label is not None:
                                                                return True

                                                            if self.type is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.sid is not None:
                                                            for child_ref in self.sid:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.weight is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.aggregator_address is not None:
                                                        return True

                                                    if self.aggregator_as is not None:
                                                        return True

                                                    if self.aigp_metric_value is not None:
                                                        return True

                                                    if self.as_path is not None:
                                                        return True

                                                    if self.cluster is not None:
                                                        for child_ref in self.cluster:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.community is not None:
                                                        for child_ref in self.community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.connector_type is not None:
                                                        return True

                                                    if self.connector_value is not None:
                                                        for child_ref in self.connector_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community is not None:
                                                        for child_ref in self.extended_community:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.extended_community_flags is not None:
                                                        return True

                                                    if self.is_aggregator_present is not None:
                                                        return True

                                                    if self.is_aigp_present is not None:
                                                        return True

                                                    if self.is_as_path_present is not None:
                                                        return True

                                                    if self.is_atomic_aggregate_present is not None:
                                                        return True

                                                    if self.is_community_present is not None:
                                                        return True

                                                    if self.is_connector_present is not None:
                                                        return True

                                                    if self.is_extended_community_present is not None:
                                                        return True

                                                    if self.is_label_index_present is not None:
                                                        return True

                                                    if self.is_local_pref_present is not None:
                                                        return True

                                                    if self.is_ls_attribute_present is not None:
                                                        return True

                                                    if self.is_metric_present is not None:
                                                        return True

                                                    if self.is_origin_present is not None:
                                                        return True

                                                    if self.is_pe_distinguisher_label_present is not None:
                                                        return True

                                                    if self.is_pmsi_present is not None:
                                                        return True

                                                    if self.is_pppmp_present is not None:
                                                        return True

                                                    if self.is_ssa_present is not None:
                                                        return True

                                                    if self.is_tunnel_encap_present is not None:
                                                        return True

                                                    if self.l2tpv3_cookie is not None:
                                                        for child_ref in self.l2tpv3_cookie:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.l2tpv3_session_id is not None:
                                                        return True

                                                    if self.label_index_attr is not None:
                                                        for child_ref in self.label_index_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.local_preference is not None:
                                                        return True

                                                    if self.ls_attr is not None:
                                                        for child_ref in self.ls_attr:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.metric is not None:
                                                        return True

                                                    if self.neighbor_as is not None:
                                                        return True

                                                    if self.origin is not None:
                                                        return True

                                                    if self.originator is not None:
                                                        return True

                                                    if self.pe_distinguisher_label is not None:
                                                        for child_ref in self.pe_distinguisher_label:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.pmsi_flags is not None:
                                                        return True

                                                    if self.pmsi_label is not None:
                                                        return True

                                                    if self.pmsi_type is not None:
                                                        return True

                                                    if self.pmsi_value is not None:
                                                        for child_ref in self.pmsi_value:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.ppm_pvalue is not None:
                                                        return True

                                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                        return True

                                                    if self.sr_policy_explicit_path is not None:
                                                        for child_ref in self.sr_policy_explicit_path:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.sr_policy_preference is not None:
                                                        return True

                                                    if self.sr_tunnel_request_state is not None:
                                                        return True

                                                    if self.sr_tunnel_state is not None:
                                                        return True

                                                    if self.tunnel_encap_type is not None:
                                                        return True

                                                    if self.unknown_attribute is not None:
                                                        for child_ref in self.unknown_attribute:
                                                            if child_ref._has_data():
                                                                return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet']['meta_info']


                                            class RnhAddr(object):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.len = None
                                                    self.mac_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.len is not None:
                                                        return True

                                                    if self.mac_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr']['meta_info']


                                            class RibrnhIp(object):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-out'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.attr_set is not None and self.attr_set._has_data():
                                                    return True

                                                if self.attribute_key_number is not None:
                                                    return True

                                                if self.attribute_reuse_id_config is not None:
                                                    return True

                                                if self.attribute_reuse_id_current is not None:
                                                    return True

                                                if self.attribute_reuse_id_keys is not None:
                                                    return True

                                                if self.attribute_reuse_id_max_id is not None:
                                                    return True

                                                if self.attribute_reuse_id_node is not None:
                                                    return True

                                                if self.attribute_reuse_id_recover_sec is not None:
                                                    return True

                                                if self.common_attributes is not None and self.common_attributes._has_data():
                                                    return True

                                                if self.is_application_gateway_present is not None:
                                                    return True

                                                if self.is_as_path2_byte is not None:
                                                    return True

                                                if self.is_attr_set_present is not None:
                                                    return True

                                                if self.is_ribrnh_present is not None:
                                                    return True

                                                if self.is_rnh_present is not None:
                                                    return True

                                                if self.ribrnh_encap is not None:
                                                    return True

                                                if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                    return True

                                                if self.ribrnh_mac is not None:
                                                    return True

                                                if self.ribrnh_table is not None:
                                                    return True

                                                if self.ribrnh_vni is not None:
                                                    return True

                                                if self.ribrnhip_table is not None:
                                                    return True

                                                if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                    return True

                                                if self.rnh_addr_len is not None:
                                                    return True

                                                if self.rnh_len is not None:
                                                    return True

                                                if self.rnh_type is not None:
                                                    return True

                                                if self.set_aigp_inbound_igp is not None:
                                                    return True

                                                if self.set_aigp_inbound_metric is not None:
                                                    return True

                                                if self.vpn_distinguisher is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:adv-path-info'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.af_name is not None:
                                                return True

                                            if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                return True

                                            if self.attributes_after_policy_out is not None and self.attributes_after_policy_out._has_data():
                                                return True

                                            if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                return True

                                            if self.no_path is not None:
                                                return True

                                            if self.path_info_after_policy_in is not None and self.path_info_after_policy_in._has_data():
                                                return True

                                            if self.path_info_after_policy_out is not None and self.path_info_after_policy_out._has_data():
                                                return True

                                            if self.route_distinguisher is not None:
                                                return True

                                            if self.source_route_distinguisher is not None:
                                                return True

                                            if self.vrf_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertised-path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.adv_path_info is not None:
                                            for child_ref in self.adv_path_info:
                                                if child_ref._has_data():
                                                    return True

                                        if self.neighbor_address is not None:
                                            return True

                                        if self.network is not None:
                                            return True

                                        if self.paths is not None:
                                            for child_ref in self.paths:
                                                if child_ref._has_data():
                                                    return True

                                        if self.prefix_length is not None:
                                            return True

                                        if self.rd is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:advertised-paths'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.advertised_path is not None:
                                        for child_ref in self.advertised_path:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths']['meta_info']


                            class NeighborAfTable(object):
                                """
                                The BGP Neighbor AF table
                                
                                .. attribute:: neighbor
                                
                                	A BGP Neighbor table entry
                                	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.neighbor = YList()
                                    self.neighbor.parent = self
                                    self.neighbor.name = 'neighbor'


                                class Neighbor(object):
                                    """
                                    A BGP Neighbor table entry
                                    
                                    .. attribute:: neighbor_address  <key>
                                    
                                    	Neighbor address
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: active_bmp_servers
                                    
                                    	BMP Servers to which the neighbor sends logs
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: actual_last_write_bytes
                                    
                                    	Actual size of last write
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: actual_last_write_reset_bytes
                                    
                                    	Actual size of last write before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: actual_second_last_write_bytes
                                    
                                    	Actual size of second last write
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: actual_second_last_write_reset_bytes
                                    
                                    	Actual size of second last write before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: af_data
                                    
                                    	Address family specific neighbor data
                                    	**type**\: list of    :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData>`
                                    
                                    .. attribute:: attempted_last_write_bytes
                                    
                                    	Attempted size of last write
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: attempted_last_write_reset_bytes
                                    
                                    	Attempted size of last write before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: attempted_second_last_write_bytes
                                    
                                    	Attempted size of second last write
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: attempted_second_last_write_reset_bytes
                                    
                                    	Attempted size of second last write before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_minintervalval
                                    
                                    	BFD Mininterval for this peer
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_multiplierval
                                    
                                    	BFD Multiplier for this peer
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_session_created_state
                                    
                                    	BFD state for this peer
                                    	**type**\:   :py:class:`BgpBfdStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdStateEnum>`
                                    
                                    .. attribute:: bfd_session_enable_mode
                                    
                                    	BFD enable mode for this peer
                                    	**type**\:   :py:class:`BgpBfdEnableModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdEnableModeEnum>`
                                    
                                    .. attribute:: bfd_session_state
                                    
                                    	BFD state for this peer
                                    	**type**\:   :py:class:`BgpBfdStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdStateEnum>`
                                    
                                    .. attribute:: bfd_state_ts
                                    
                                    	Timestamp since when nbr is in this bfd state
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bytes_read
                                    
                                    	Total bytes read
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: bytes_written
                                    
                                    	Total bytes written by write thread
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: configured_hold_time
                                    
                                    	Hold time (in secs) configured for this connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: configured_keepalive
                                    
                                    	Keepalive time (in secs) configured for this connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: configured_min_acc_hold_time
                                    
                                    	Minimum acceptable hold time from neighbor (in secs) configured for this connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: connect_retry_interval
                                    
                                    	Time (in secs) for connect retry timer
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: connection_admin_status
                                    
                                    	Administrative status of connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: connection_down_count
                                    
                                    	Number of times connection was dropped
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: connection_established_time
                                    
                                    	Time (in secs) that the connection has been established
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: connection_local_address
                                    
                                    	Local address for the connection
                                    	**type**\:   :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress>`
                                    
                                    .. attribute:: connection_local_port
                                    
                                    	Local port for the connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: connection_remote_address
                                    
                                    	Remote address for the connection
                                    	**type**\:   :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress>`
                                    
                                    .. attribute:: connection_remote_port
                                    
                                    	Remote port for the connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: connection_state
                                    
                                    	State of connection
                                    	**type**\:   :py:class:`BgpConnStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnStateEnum>`
                                    
                                    .. attribute:: connection_up_count
                                    
                                    	Number of times the connection was established
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: count_last_write
                                    
                                    	Count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: description
                                    
                                    	Description
                                    	**type**\:  str
                                    
                                    .. attribute:: discard_as4_path
                                    
                                    	Discard AS4\_PATH in case there is a discrepancy in merging AS\_PATH and AS4\_PATH,retain ASPATH
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: discard_data_bytes
                                    
                                    	Remaining discard data (bytes) on Standby
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: dmz_link_bandwidth
                                    
                                    	Bandwidth of link to single\-hop eBGP peer
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: dynamic_neighbor
                                    
                                    	Dynamic neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: ebgp_recv_dmz
                                    
                                    	Receive Bandwidth of link to single\-hop eBGP peer
                                    	**type**\:  bool
                                    
                                    .. attribute:: ebgp_send_dmz_mode
                                    
                                    	Ebgp send dmz link bw mode
                                    	**type**\:   :py:class:`BgpEbgpSendDmzEnableModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableModeEnum>`
                                    
                                    .. attribute:: ebgp_time_to_live
                                    
                                    	Maximum number of hops for external BGP neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: egress_peer_engineering_enabled
                                    
                                    	Indicates if Egress Peer Engineering is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: error_notifies_received
                                    
                                    	Number of error notifications received on the connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: error_notifies_sent
                                    
                                    	Number of error notifications sent on the connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fpbsn_offset
                                    
                                    	First standby PDU boundary SeqNo offset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fssn_offset
                                    
                                    	First standby SeqNo offset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: gr_restart_time
                                    
                                    	Neighbor restart time (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: gr_stale_path_time
                                    
                                    	Neighbor stale\-path time (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: graceful_maintenance
                                    
                                    	Graceful Maintenance
                                    	**type**\:   :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance>`
                                    
                                    .. attribute:: graceful_restart_enabled_nbr
                                    
                                    	Neighbor supports graceful\-restart
                                    	**type**\:  bool
                                    
                                    .. attribute:: has_internal_link
                                    
                                    	Internal link to neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: hold_time
                                    
                                    	Hold time (in secs) negotiated for this connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: ignore_connected
                                    
                                    	If true, the VPN client isan IBGP CE peer
                                    	**type**\:  bool
                                    
                                    .. attribute:: internal_vpn_client
                                    
                                    	If true, don't do NHconnected check for nbr
                                    	**type**\:  bool
                                    
                                    .. attribute:: io_armed
                                    
                                    	If true, socket has beenauto\-armed for io control
                                    	**type**\:  bool
                                    
                                    .. attribute:: is4_byte_as_capability_received
                                    
                                    	4\-byte AScapability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is4_byte_as_capability_sent
                                    
                                    	4\-byte AScapability Snt
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_administratively_shut_down
                                    
                                    	Neighbor is administratively shut down
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_capability_negotiation_performed
                                    
                                    	Capability negotiation performed
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_capability_negotiation_suppressed
                                    
                                    	Capability negotiation suppressed
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ebgp_multihop_bgpmpls_forwarding_disabled
                                    
                                    	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ebgp_peer_as_league
                                    
                                    	EBGP peer belongs to AS League
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ebgp_peer_common_admin
                                    
                                    	EBGP peer with common administation
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_external_neighbor_not_directly_connected
                                    
                                    	External neighbor not directly connected
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_gr_aware
                                    
                                    	GR awareness received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_local_address_configured
                                    
                                    	Local address configured for the neighbor connection
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_neighbor_max_prefix_shutdown
                                    
                                    	Neighbor shut down because it exceeded max prfx count
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_out_of_memory_forced_up
                                    
                                    	Neighbor forced up during a low memory condition
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_out_of_memory_shutdown
                                    
                                    	Neighbor shut down during a SEVERE low memory condition
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_passive_close
                                    
                                    	If true, active socket canbe closed if passive openis received for a GRcapable neighbor
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_read_disabled
                                    
                                    	If true, socket read isdisabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_route_refresh_capability_received
                                    
                                    	Route refresh capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_route_refresh_old_capability_received
                                    
                                    	Route refresh old capability received
                                    	**type**\:  bool
                                    
                                    .. attribute:: keep_alive_time
                                    
                                    	Keepalive time (in secs) negotiated for this connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_ackd_seq_no
                                    
                                    	SeqNo of the last Ackd byte
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_k_aerror_reset
                                    
                                    	Duration (in secs) since last time that an error was encountered after KA expiry
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_k_aexpiry_reset
                                    
                                    	Time (in secs) since last KA timer expiry before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_k_anotsent_reset
                                    
                                    	Duration (in secs) since last time that KA was not sent before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_k_astart_reset
                                    
                                    	Time (in secs) since the last KA timer start before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_notify_error_code
                                    
                                    	Code for the last error notification seen on the connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: last_notify_error_subcode
                                    
                                    	Error subcode of the last error notification seen on the connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: last_write_event
                                    
                                    	Time (in secs) since last write thread event
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: local_as
                                    
                                    	Local AS number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_as_dual_as
                                    
                                    	Local AS Dual\-AS option
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_as_dual_as_mode_native
                                    
                                    	Applies only if Local AS Dual\-AS option is enabled. Indicates if Dual\-AS mode is native
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_as_no_prepend
                                    
                                    	Option to not prepend the Local AS to announcements
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_as_replace_as
                                    
                                    	Local AS Replace\-AS option
                                    	**type**\:  bool
                                    
                                    .. attribute:: message_statistics
                                    
                                    	Message statistics
                                    	**type**\:   :py:class:`MessageStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics>`
                                    
                                    .. attribute:: messages_queued_in
                                    
                                    	No. of msgs on receive queue
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: messages_queued_out
                                    
                                    	No. of messages on send queue
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: messages_received
                                    
                                    	Number of messages received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: messages_sent
                                    
                                    	Number of messages sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: min_advertise_interval
                                    
                                    	Minimum advertisement interval, secs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: min_advertise_interval_msecs
                                    
                                    	Minimum advertisement interval, msecs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: min_origination_interval
                                    
                                    	Minimum origination interval (in secs)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: msg_log_in
                                    
                                    	Message in log count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: msg_log_out
                                    
                                    	Message out log count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: multi_protocol_capability_received
                                    
                                    	Multi\-protocol capability has been received
                                    	**type**\:  bool
                                    
                                    .. attribute:: nbr_cluster_id
                                    
                                    	Cluster id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nbr_enforce_first_as
                                    
                                    	Neighbor enforce first AS
                                    	**type**\:  bool
                                    
                                    .. attribute:: nbr_in_cluster
                                    
                                    	Type of cluster\_id\:undefined/number/Ip address
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: negotiated_protocol_version
                                    
                                    	Negotiated protocol version
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: neighbor_interface_handle
                                    
                                    	Interface Handle of Neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_local_as
                                    
                                    	Local AS configured on the neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_enabled
                                    
                                    	Neighbor supports NSR
                                    	**type**\:  bool
                                    
                                    .. attribute:: nsr_state
                                    
                                    	NSR state
                                    	**type**\:   :py:class:`BgpSyncNbrNsrStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrStateEnum>`
                                    
                                    .. attribute:: open_check_error_code
                                    
                                    	Open check error code
                                    	**type**\:   :py:class:`BgpOpenCheckErrEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpOpenCheckErrEnum>`
                                    
                                    .. attribute:: peer_error_code
                                    
                                    	If peer closed, error received from transport
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: peer_reset_reason
                                    
                                    	Reason for last peer close event
                                    	**type**\:   :py:class:`BgpPeerResetReasonIndexEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPeerResetReasonIndexEnum>`
                                    
                                    .. attribute:: performance_statistics
                                    
                                    	Performance statistics
                                    	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics>`
                                    
                                    .. attribute:: previous_connection_state
                                    
                                    	Previous state of connection
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: read_armed
                                    
                                    	If true, socket has beenauto\-armed for read
                                    	**type**\:  bool
                                    
                                    .. attribute:: received_notification_info
                                    
                                    	Information on the last notification received
                                    	**type**\:   :py:class:`ReceivedNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo>`
                                    
                                    .. attribute:: remote_as
                                    
                                    	Remote AS number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_as_number
                                    
                                    	Remote AS number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reset_notification_sent
                                    
                                    	Notification was sent during last reset
                                    	**type**\:  bool
                                    
                                    .. attribute:: reset_reason
                                    
                                    	Reason for last connection reset
                                    	**type**\:   :py:class:`BgpResetReasonIndexEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndexEnum>`
                                    
                                    .. attribute:: router_id
                                    
                                    	Router ID for the neighbor
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rpki_allow_invalid
                                    
                                    	Prefix v. allow invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: rpki_disable
                                    
                                    	Prefix validation disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: rpki_signal_ibgp
                                    
                                    	Prefix v. signal ibgp
                                    	**type**\:  bool
                                    
                                    .. attribute:: rpki_use_validity
                                    
                                    	Prefix v. use validity
                                    	**type**\:  bool
                                    
                                    .. attribute:: second_last_k_aexpiry_reset
                                    
                                    	Time (in secs) since second last KA timer expiry before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: second_last_k_astart_reset
                                    
                                    	Time (in secs) since the second last KA timer start before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: second_last_write_event
                                    
                                    	Time (in secs) since second last write thread event
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: send_notification_info
                                    
                                    	Information on the last notification sent
                                    	**type**\:   :py:class:`SendNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo>`
                                    
                                    .. attribute:: socket_read_bytes
                                    
                                    	Total read bytes value insocket\-lib
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: speaker_id
                                    
                                    	Speaker this neighbor is allocated to
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: standby_rp
                                    
                                    	Standby RP socket inited for Active Open
                                    	**type**\:  bool
                                    
                                    .. attribute:: suppress4_byte_as
                                    
                                    	Suppress 4byteas capability
                                    	**type**\:  bool
                                    
                                    .. attribute:: tcp_init_sync_done_time_spec
                                    
                                    	Time when neighbor entered TCP Init Sync Done
                                    	**type**\:   :py:class:`TcpInitSyncDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec>`
                                    
                                    .. attribute:: tcp_init_sync_phase_two_time_spec
                                    
                                    	Time when neighbor entered TCP Init Sync Phase Two
                                    	**type**\:   :py:class:`TcpInitSyncPhaseTwoTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec>`
                                    
                                    .. attribute:: tcp_init_sync_time_spec
                                    
                                    	Time When neighbor entered TCP Init Sync
                                    	**type**\:   :py:class:`TcpInitSyncTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec>`
                                    
                                    .. attribute:: tcp_session_open_mode
                                    
                                    	The TCP mode to be used to set up BGP session with the neighbor
                                    	**type**\:   :py:class:`BgpTcpModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpModeEnum>`
                                    
                                    .. attribute:: tcpmss
                                    
                                    	Neighbor TCP Maximum Segment                     size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: time_last_cb
                                    
                                    	CB
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: time_last_cb_reset
                                    
                                    	Last CB before reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: time_last_fb
                                    
                                    	FB
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: time_since_connection_last_dropped
                                    
                                    	Time since the connection last went down (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: time_since_last_read
                                    
                                    	Time (in secs) since last read
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: time_since_last_read_reset
                                    
                                    	Time (in secs) since last read before last reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: time_since_last_update
                                    
                                    	Time (in secs) since last update message was received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: time_since_last_write
                                    
                                    	Time (in secs) since last write
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: time_since_last_write_reset
                                    
                                    	Time (in secs) since last write before last reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: time_since_second_last_write
                                    
                                    	Time (in secs) since second  last write
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: time_since_second_last_write_reset
                                    
                                    	Time (in secs) since last write before last reset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: tos_type
                                    
                                    	Precedence or DSCP type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_value
                                    
                                    	Precedence or DSCP value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl_security_enabled
                                    
                                    	TTL Security enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: update_bytes_read
                                    
                                    	Total update bytes read
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: update_messages_in
                                    
                                    	No. of update msgs received
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_messages_out
                                    
                                    	No. of update messages sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    .. attribute:: write_armed
                                    
                                    	If true, socket has beenauto\-armed for write
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.neighbor_address = None
                                        self.active_bmp_servers = None
                                        self.actual_last_write_bytes = None
                                        self.actual_last_write_reset_bytes = None
                                        self.actual_second_last_write_bytes = None
                                        self.actual_second_last_write_reset_bytes = None
                                        self.af_data = YList()
                                        self.af_data.parent = self
                                        self.af_data.name = 'af_data'
                                        self.attempted_last_write_bytes = None
                                        self.attempted_last_write_reset_bytes = None
                                        self.attempted_second_last_write_bytes = None
                                        self.attempted_second_last_write_reset_bytes = None
                                        self.bfd_minintervalval = None
                                        self.bfd_multiplierval = None
                                        self.bfd_session_created_state = None
                                        self.bfd_session_enable_mode = None
                                        self.bfd_session_state = None
                                        self.bfd_state_ts = None
                                        self.bytes_read = None
                                        self.bytes_written = None
                                        self.configured_hold_time = None
                                        self.configured_keepalive = None
                                        self.configured_min_acc_hold_time = None
                                        self.connect_retry_interval = None
                                        self.connection_admin_status = None
                                        self.connection_down_count = None
                                        self.connection_established_time = None
                                        self.connection_local_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress()
                                        self.connection_local_address.parent = self
                                        self.connection_local_port = None
                                        self.connection_remote_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress()
                                        self.connection_remote_address.parent = self
                                        self.connection_remote_port = None
                                        self.connection_state = None
                                        self.connection_up_count = None
                                        self.count_last_write = None
                                        self.description = None
                                        self.discard_as4_path = None
                                        self.discard_data_bytes = None
                                        self.dmz_link_bandwidth = None
                                        self.dynamic_neighbor = None
                                        self.ebgp_recv_dmz = None
                                        self.ebgp_send_dmz_mode = None
                                        self.ebgp_time_to_live = None
                                        self.egress_peer_engineering_enabled = None
                                        self.error_notifies_received = None
                                        self.error_notifies_sent = None
                                        self.fpbsn_offset = None
                                        self.fssn_offset = None
                                        self.gr_restart_time = None
                                        self.gr_stale_path_time = None
                                        self.graceful_maintenance = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance()
                                        self.graceful_maintenance.parent = self
                                        self.graceful_restart_enabled_nbr = None
                                        self.has_internal_link = None
                                        self.hold_time = None
                                        self.ignore_connected = None
                                        self.internal_vpn_client = None
                                        self.io_armed = None
                                        self.is4_byte_as_capability_received = None
                                        self.is4_byte_as_capability_sent = None
                                        self.is_administratively_shut_down = None
                                        self.is_capability_negotiation_performed = None
                                        self.is_capability_negotiation_suppressed = None
                                        self.is_ebgp_multihop_bgpmpls_forwarding_disabled = None
                                        self.is_ebgp_peer_as_league = None
                                        self.is_ebgp_peer_common_admin = None
                                        self.is_external_neighbor_not_directly_connected = None
                                        self.is_gr_aware = None
                                        self.is_local_address_configured = None
                                        self.is_neighbor_max_prefix_shutdown = None
                                        self.is_out_of_memory_forced_up = None
                                        self.is_out_of_memory_shutdown = None
                                        self.is_passive_close = None
                                        self.is_read_disabled = None
                                        self.is_route_refresh_capability_received = None
                                        self.is_route_refresh_old_capability_received = None
                                        self.keep_alive_time = None
                                        self.last_ackd_seq_no = None
                                        self.last_k_aerror_reset = None
                                        self.last_k_aexpiry_reset = None
                                        self.last_k_anotsent_reset = None
                                        self.last_k_astart_reset = None
                                        self.last_notify_error_code = None
                                        self.last_notify_error_subcode = None
                                        self.last_write_event = None
                                        self.local_as = None
                                        self.local_as_dual_as = None
                                        self.local_as_dual_as_mode_native = None
                                        self.local_as_no_prepend = None
                                        self.local_as_replace_as = None
                                        self.message_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics()
                                        self.message_statistics.parent = self
                                        self.messages_queued_in = None
                                        self.messages_queued_out = None
                                        self.messages_received = None
                                        self.messages_sent = None
                                        self.min_advertise_interval = None
                                        self.min_advertise_interval_msecs = None
                                        self.min_origination_interval = None
                                        self.msg_log_in = None
                                        self.msg_log_out = None
                                        self.multi_protocol_capability_received = None
                                        self.nbr_cluster_id = None
                                        self.nbr_enforce_first_as = None
                                        self.nbr_in_cluster = None
                                        self.negotiated_protocol_version = None
                                        self.neighbor_interface_handle = None
                                        self.neighbor_local_as = None
                                        self.nsr_enabled = None
                                        self.nsr_state = None
                                        self.open_check_error_code = None
                                        self.peer_error_code = None
                                        self.peer_reset_reason = None
                                        self.performance_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics()
                                        self.performance_statistics.parent = self
                                        self.previous_connection_state = None
                                        self.read_armed = None
                                        self.received_notification_info = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo()
                                        self.received_notification_info.parent = self
                                        self.remote_as = None
                                        self.remote_as_number = None
                                        self.reset_notification_sent = None
                                        self.reset_reason = None
                                        self.router_id = None
                                        self.rpki_allow_invalid = None
                                        self.rpki_disable = None
                                        self.rpki_signal_ibgp = None
                                        self.rpki_use_validity = None
                                        self.second_last_k_aexpiry_reset = None
                                        self.second_last_k_astart_reset = None
                                        self.second_last_write_event = None
                                        self.send_notification_info = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo()
                                        self.send_notification_info.parent = self
                                        self.socket_read_bytes = None
                                        self.speaker_id = None
                                        self.standby_rp = None
                                        self.suppress4_byte_as = None
                                        self.tcp_init_sync_done_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec()
                                        self.tcp_init_sync_done_time_spec.parent = self
                                        self.tcp_init_sync_phase_two_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec()
                                        self.tcp_init_sync_phase_two_time_spec.parent = self
                                        self.tcp_init_sync_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec()
                                        self.tcp_init_sync_time_spec.parent = self
                                        self.tcp_session_open_mode = None
                                        self.tcpmss = None
                                        self.time_last_cb = None
                                        self.time_last_cb_reset = None
                                        self.time_last_fb = None
                                        self.time_since_connection_last_dropped = None
                                        self.time_since_last_read = None
                                        self.time_since_last_read_reset = None
                                        self.time_since_last_update = None
                                        self.time_since_last_write = None
                                        self.time_since_last_write_reset = None
                                        self.time_since_second_last_write = None
                                        self.time_since_second_last_write_reset = None
                                        self.tos_type = None
                                        self.tos_value = None
                                        self.ttl_security_enabled = None
                                        self.update_bytes_read = None
                                        self.update_messages_in = None
                                        self.update_messages_out = None
                                        self.vrf_name = None
                                        self.write_armed = None


                                    class ConnectionLocalAddress(object):
                                        """
                                        Local address for the connection
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connection-local-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress']['meta_info']


                                    class ConnectionRemoteAddress(object):
                                        """
                                        Remote address for the connection
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connection-remote-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress']['meta_info']


                                    class SendNotificationInfo(object):
                                        """
                                        Information on the last notification sent
                                        
                                        .. attribute:: last_notification_data
                                        
                                        	Message data in last notification
                                        	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData>`
                                        
                                        .. attribute:: notification_error_code
                                        
                                        	Error code in last notification
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: notification_error_subcode
                                        
                                        	Error subcode in last notification
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: time_since_last_notification
                                        
                                        	Time since the last notification was sent or received (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.last_notification_data = YList()
                                            self.last_notification_data.parent = self
                                            self.last_notification_data.name = 'last_notification_data'
                                            self.notification_error_code = None
                                            self.notification_error_subcode = None
                                            self.time_since_last_notification = None


                                        class LastNotificationData(object):
                                            """
                                            Message data in last notification
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-notification-data'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:send-notification-info'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.last_notification_data is not None:
                                                for child_ref in self.last_notification_data:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.notification_error_code is not None:
                                                return True

                                            if self.notification_error_subcode is not None:
                                                return True

                                            if self.time_since_last_notification is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo']['meta_info']


                                    class ReceivedNotificationInfo(object):
                                        """
                                        Information on the last notification received
                                        
                                        .. attribute:: last_notification_data
                                        
                                        	Message data in last notification
                                        	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData>`
                                        
                                        .. attribute:: notification_error_code
                                        
                                        	Error code in last notification
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: notification_error_subcode
                                        
                                        	Error subcode in last notification
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: time_since_last_notification
                                        
                                        	Time since the last notification was sent or received (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.last_notification_data = YList()
                                            self.last_notification_data.parent = self
                                            self.last_notification_data.name = 'last_notification_data'
                                            self.notification_error_code = None
                                            self.notification_error_subcode = None
                                            self.time_since_last_notification = None


                                        class LastNotificationData(object):
                                            """
                                            Message data in last notification
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-notification-data'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:received-notification-info'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.last_notification_data is not None:
                                                for child_ref in self.last_notification_data:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.notification_error_code is not None:
                                                return True

                                            if self.notification_error_subcode is not None:
                                                return True

                                            if self.time_since_last_notification is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo']['meta_info']


                                    class PerformanceStatistics(object):
                                        """
                                        Performance statistics
                                        
                                        .. attribute:: active_collision
                                        
                                        	Number of Closed Active connections for this neighbor due to collision 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: actives
                                        
                                        	Number of retried Active opens for this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: control_to_read_thread_trigger
                                        
                                        	Number of times io\-control thread trigger read thread
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: control_to_write_thread_trigger
                                        
                                        	Number of times io\-control thread trigger write thread
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: data_bytes_read
                                        
                                        	No. of bytes of data read
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: data_bytes_written
                                        
                                        	No. of data bytes written
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: failed_post_actives
                                        
                                        	Number of Active Opens that failed in the Post Active State for this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: high_throttled_read
                                        
                                        	Num of socket reads after nbr crossed high threshold
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: inbound_update_messages
                                        
                                        	Number of inbound update messages processed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: inbound_update_messages_time
                                        
                                        	Time spent processing inbound update messages (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: io_read_time
                                        
                                        	Time spent reading inbound data (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: io_write_time
                                        
                                        	Time spent writing outbound data (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: last_nsr_scoped_sync
                                        
                                        	Last time NSR scoped syncwas done for the neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_sent_seq_no
                                        
                                        	Seq No of the last sent byte
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: low_throttled_read
                                        
                                        	Num socket reads after nbrs crossed low threshold
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_read_size
                                        
                                        	Size of largest socket (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: nbr_fd
                                        
                                        	Primary FD, per nbr
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: nbr_flags
                                        
                                        	Nbr flags, per thread
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: network_status
                                        
                                        	Socket status, TRUE if socket closed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nsr_oper_down_count
                                        
                                        	Number of times NSR scoped sync has been done
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: passive_collision
                                        
                                        	Number of Closed Remote opens for this neighborneighbor due to collision 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: passives
                                        
                                        	Number of retried Passive opens for this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: read_calls_count
                                        
                                        	No. of calls to function to read inbound data
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: read_messages_count
                                        
                                        	Number of BGP messages read
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: read_throttles
                                        
                                        	Number of partial read throttles
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rejected_passives
                                        
                                        	Number of rejected Passive opens for this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reset_flags
                                        
                                        	Reset flags, per thread
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reset_retries
                                        
                                        	Reset Retries, per nbr
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: subgroup_list_time
                                        
                                        	Time spent processing sub\-group message list  (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: sync_flags
                                        
                                        	Sync flags, per nbr
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_since_last_throttled_read
                                        
                                        	Time (in secs) since last read after being throttled
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: write_calls_count
                                        
                                        	No. of calls to function to write outbound data
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: write_queue_calls_count
                                        
                                        	No. of calls to function to process write queue
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: write_queue_messages_count
                                        
                                        	Number of write queue messages processed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: write_queue_time
                                        
                                        	Time spent processing write queue (milliseconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: write_subgroup_calls_count
                                        
                                        	No. of calls to function to process sub\-group message list
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: write_subgroup_messages_count
                                        
                                        	Number of sub\-group msgs processed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.active_collision = None
                                            self.actives = None
                                            self.control_to_read_thread_trigger = None
                                            self.control_to_write_thread_trigger = None
                                            self.data_bytes_read = None
                                            self.data_bytes_written = None
                                            self.failed_post_actives = None
                                            self.high_throttled_read = None
                                            self.inbound_update_messages = None
                                            self.inbound_update_messages_time = None
                                            self.io_read_time = None
                                            self.io_write_time = None
                                            self.last_nsr_scoped_sync = None
                                            self.last_sent_seq_no = None
                                            self.low_throttled_read = None
                                            self.maximum_read_size = None
                                            self.nbr_fd = None
                                            self.nbr_flags = None
                                            self.network_status = None
                                            self.nsr_oper_down_count = None
                                            self.passive_collision = None
                                            self.passives = None
                                            self.read_calls_count = None
                                            self.read_messages_count = None
                                            self.read_throttles = None
                                            self.rejected_passives = None
                                            self.reset_flags = None
                                            self.reset_retries = None
                                            self.subgroup_list_time = None
                                            self.sync_flags = None
                                            self.time_since_last_throttled_read = None
                                            self.write_calls_count = None
                                            self.write_queue_calls_count = None
                                            self.write_queue_messages_count = None
                                            self.write_queue_time = None
                                            self.write_subgroup_calls_count = None
                                            self.write_subgroup_messages_count = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:performance-statistics'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.active_collision is not None:
                                                return True

                                            if self.actives is not None:
                                                return True

                                            if self.control_to_read_thread_trigger is not None:
                                                return True

                                            if self.control_to_write_thread_trigger is not None:
                                                return True

                                            if self.data_bytes_read is not None:
                                                return True

                                            if self.data_bytes_written is not None:
                                                return True

                                            if self.failed_post_actives is not None:
                                                return True

                                            if self.high_throttled_read is not None:
                                                return True

                                            if self.inbound_update_messages is not None:
                                                return True

                                            if self.inbound_update_messages_time is not None:
                                                return True

                                            if self.io_read_time is not None:
                                                return True

                                            if self.io_write_time is not None:
                                                return True

                                            if self.last_nsr_scoped_sync is not None:
                                                return True

                                            if self.last_sent_seq_no is not None:
                                                return True

                                            if self.low_throttled_read is not None:
                                                return True

                                            if self.maximum_read_size is not None:
                                                return True

                                            if self.nbr_fd is not None:
                                                return True

                                            if self.nbr_flags is not None:
                                                return True

                                            if self.network_status is not None:
                                                return True

                                            if self.nsr_oper_down_count is not None:
                                                return True

                                            if self.passive_collision is not None:
                                                return True

                                            if self.passives is not None:
                                                return True

                                            if self.read_calls_count is not None:
                                                return True

                                            if self.read_messages_count is not None:
                                                return True

                                            if self.read_throttles is not None:
                                                return True

                                            if self.rejected_passives is not None:
                                                return True

                                            if self.reset_flags is not None:
                                                return True

                                            if self.reset_retries is not None:
                                                return True

                                            if self.subgroup_list_time is not None:
                                                return True

                                            if self.sync_flags is not None:
                                                return True

                                            if self.time_since_last_throttled_read is not None:
                                                return True

                                            if self.write_calls_count is not None:
                                                return True

                                            if self.write_queue_calls_count is not None:
                                                return True

                                            if self.write_queue_messages_count is not None:
                                                return True

                                            if self.write_queue_time is not None:
                                                return True

                                            if self.write_subgroup_calls_count is not None:
                                                return True

                                            if self.write_subgroup_messages_count is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics']['meta_info']


                                    class MessageStatistics(object):
                                        """
                                        Message statistics
                                        
                                        .. attribute:: keepalive
                                        
                                        	Keepalive
                                        	**type**\:   :py:class:`Keepalive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive>`
                                        
                                        .. attribute:: notification
                                        
                                        	Notification
                                        	**type**\:   :py:class:`Notification <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification>`
                                        
                                        .. attribute:: open
                                        
                                        	Open
                                        	**type**\:   :py:class:`Open <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open>`
                                        
                                        .. attribute:: route_refresh
                                        
                                        	Route refresh
                                        	**type**\:   :py:class:`RouteRefresh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh>`
                                        
                                        .. attribute:: total
                                        
                                        	Total
                                        	**type**\:   :py:class:`Total <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total>`
                                        
                                        .. attribute:: update
                                        
                                        	Update
                                        	**type**\:   :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.keepalive = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive()
                                            self.keepalive.parent = self
                                            self.notification = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification()
                                            self.notification.parent = self
                                            self.open = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open()
                                            self.open.parent = self
                                            self.route_refresh = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh()
                                            self.route_refresh.parent = self
                                            self.total = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total()
                                            self.total.parent = self
                                            self.update = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update()
                                            self.update.parent = self


                                        class Open(object):
                                            """
                                            Open
                                            
                                            .. attribute:: rx
                                            
                                            	Receive
                                            	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx>`
                                            
                                            .. attribute:: tx
                                            
                                            	Transmit
                                            	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.rx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx()
                                                self.rx.parent = self
                                                self.tx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx()
                                                self.tx.parent = self


                                            class Tx(object):
                                                """
                                                Transmit
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.count = None
                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec()
                                                    self.last_time_spec.parent = self


                                                class LastTimeSpec(object):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.count is not None:
                                                        return True

                                                    if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx']['meta_info']


                                            class Rx(object):
                                                """
                                                Receive
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.count = None
                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec()
                                                    self.last_time_spec.parent = self


                                                class LastTimeSpec(object):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.count is not None:
                                                        return True

                                                    if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:open'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.rx is not None and self.rx._has_data():
                                                    return True

                                                if self.tx is not None and self.tx._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open']['meta_info']


                                        class Notification(object):
                                            """
                                            Notification
                                            
                                            .. attribute:: rx
                                            
                                            	Receive
                                            	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx>`
                                            
                                            .. attribute:: tx
                                            
                                            	Transmit
                                            	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.rx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx()
                                                self.rx.parent = self
                                                self.tx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx()
                                                self.tx.parent = self


                                            class Tx(object):
                                                """
                                                Transmit
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.count = None
                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec()
                                                    self.last_time_spec.parent = self


                                                class LastTimeSpec(object):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.count is not None:
                                                        return True

                                                    if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx']['meta_info']


                                            class Rx(object):
                                                """
                                                Receive
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.count = None
                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec()
                                                    self.last_time_spec.parent = self


                                                class LastTimeSpec(object):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.count is not None:
                                                        return True

                                                    if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:notification'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.rx is not None and self.rx._has_data():
                                                    return True

                                                if self.tx is not None and self.tx._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification']['meta_info']


                                        class Update(object):
                                            """
                                            Update
                                            
                                            .. attribute:: rx
                                            
                                            	Receive
                                            	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx>`
                                            
                                            .. attribute:: tx
                                            
                                            	Transmit
                                            	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.rx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx()
                                                self.rx.parent = self
                                                self.tx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx()
                                                self.tx.parent = self


                                            class Tx(object):
                                                """
                                                Transmit
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.count = None
                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec()
                                                    self.last_time_spec.parent = self


                                                class LastTimeSpec(object):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.count is not None:
                                                        return True

                                                    if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx']['meta_info']


                                            class Rx(object):
                                                """
                                                Receive
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.count = None
                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec()
                                                    self.last_time_spec.parent = self


                                                class LastTimeSpec(object):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.count is not None:
                                                        return True

                                                    if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.rx is not None and self.rx._has_data():
                                                    return True

                                                if self.tx is not None and self.tx._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update']['meta_info']


                                        class Keepalive(object):
                                            """
                                            Keepalive
                                            
                                            .. attribute:: rx
                                            
                                            	Receive
                                            	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx>`
                                            
                                            .. attribute:: tx
                                            
                                            	Transmit
                                            	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.rx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx()
                                                self.rx.parent = self
                                                self.tx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx()
                                                self.tx.parent = self


                                            class Tx(object):
                                                """
                                                Transmit
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.count = None
                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec()
                                                    self.last_time_spec.parent = self


                                                class LastTimeSpec(object):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.count is not None:
                                                        return True

                                                    if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx']['meta_info']


                                            class Rx(object):
                                                """
                                                Receive
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.count = None
                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec()
                                                    self.last_time_spec.parent = self


                                                class LastTimeSpec(object):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.count is not None:
                                                        return True

                                                    if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:keepalive'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.rx is not None and self.rx._has_data():
                                                    return True

                                                if self.tx is not None and self.tx._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive']['meta_info']


                                        class RouteRefresh(object):
                                            """
                                            Route refresh
                                            
                                            .. attribute:: rx
                                            
                                            	Receive
                                            	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx>`
                                            
                                            .. attribute:: tx
                                            
                                            	Transmit
                                            	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.rx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx()
                                                self.rx.parent = self
                                                self.tx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx()
                                                self.tx.parent = self


                                            class Tx(object):
                                                """
                                                Transmit
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.count = None
                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec()
                                                    self.last_time_spec.parent = self


                                                class LastTimeSpec(object):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.count is not None:
                                                        return True

                                                    if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx']['meta_info']


                                            class Rx(object):
                                                """
                                                Receive
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.count = None
                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec()
                                                    self.last_time_spec.parent = self


                                                class LastTimeSpec(object):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.count is not None:
                                                        return True

                                                    if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:route-refresh'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.rx is not None and self.rx._has_data():
                                                    return True

                                                if self.tx is not None and self.tx._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh']['meta_info']


                                        class Total(object):
                                            """
                                            Total
                                            
                                            .. attribute:: rx
                                            
                                            	Receive
                                            	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx>`
                                            
                                            .. attribute:: tx
                                            
                                            	Transmit
                                            	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.rx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx()
                                                self.rx.parent = self
                                                self.tx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx()
                                                self.tx.parent = self


                                            class Tx(object):
                                                """
                                                Transmit
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.count = None
                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec()
                                                    self.last_time_spec.parent = self


                                                class LastTimeSpec(object):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.count is not None:
                                                        return True

                                                    if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx']['meta_info']


                                            class Rx(object):
                                                """
                                                Receive
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.count = None
                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec()
                                                    self.last_time_spec.parent = self


                                                class LastTimeSpec(object):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.nanoseconds = None
                                                        self.seconds = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.nanoseconds is not None:
                                                            return True

                                                        if self.seconds is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.count is not None:
                                                        return True

                                                    if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:total'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.rx is not None and self.rx._has_data():
                                                    return True

                                                if self.tx is not None and self.tx._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:message-statistics'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.keepalive is not None and self.keepalive._has_data():
                                                return True

                                            if self.notification is not None and self.notification._has_data():
                                                return True

                                            if self.open is not None and self.open._has_data():
                                                return True

                                            if self.route_refresh is not None and self.route_refresh._has_data():
                                                return True

                                            if self.total is not None and self.total._has_data():
                                                return True

                                            if self.update is not None and self.update._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics']['meta_info']


                                    class TcpInitSyncTimeSpec(object):
                                        """
                                        Time When neighbor entered TCP Init Sync
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tcp-init-sync-time-spec'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec']['meta_info']


                                    class TcpInitSyncPhaseTwoTimeSpec(object):
                                        """
                                        Time when neighbor entered TCP Init Sync Phase
                                        Two
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tcp-init-sync-phase-two-time-spec'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec']['meta_info']


                                    class TcpInitSyncDoneTimeSpec(object):
                                        """
                                        Time when neighbor entered TCP Init Sync Done
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tcp-init-sync-done-time-spec'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec']['meta_info']


                                    class GracefulMaintenance(object):
                                        """
                                        Graceful Maintenance
                                        
                                        .. attribute:: gshut_active
                                        
                                        	Graceful Maintenance activated
                                        	**type**\:  bool
                                        
                                        .. attribute:: gshut_exists
                                        
                                        	Graceful Maintenance enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: gshut_local_active
                                        
                                        	Graceful Maintenance locally activated
                                        	**type**\:  bool
                                        
                                        .. attribute:: gshut_locpref
                                        
                                        	Graceful Maintenance Local Preference
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: gshut_locpref_set
                                        
                                        	Graceful Maintenance Local Preference set
                                        	**type**\:  bool
                                        
                                        .. attribute:: gshut_prepends
                                        
                                        	Graceful Maintenance number of AS prepends
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.gshut_active = None
                                            self.gshut_exists = None
                                            self.gshut_local_active = None
                                            self.gshut_locpref = None
                                            self.gshut_locpref_set = None
                                            self.gshut_prepends = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:graceful-maintenance'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.gshut_active is not None:
                                                return True

                                            if self.gshut_exists is not None:
                                                return True

                                            if self.gshut_local_active is not None:
                                                return True

                                            if self.gshut_locpref is not None:
                                                return True

                                            if self.gshut_locpref_set is not None:
                                                return True

                                            if self.gshut_prepends is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance']['meta_info']


                                    class AfData(object):
                                        """
                                        Address family specific neighbor data
                                        
                                        .. attribute:: accept_own_enabled
                                        
                                        	Accept\-Own enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: acked_version
                                        
                                        	Version mapped from acked seqNo
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: address_family_long_lived_time
                                        
                                        	AF specific Long\-lived\-time config
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertise_afi
                                        
                                        	Encode in Advertise AFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_afi_def_vrf_imp_disable
                                        
                                        	Advertise of default VRF import disable
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_afi_disable
                                        
                                        	Encode in Advertise AFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_afi_eo_r_ready
                                        
                                        	EoR Can be sent for Advertise AFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_afi_reorg
                                        
                                        	Encode in Advertise AFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_afi_vrf_re_imp_disable
                                        
                                        	Advertise of VRF re\-import disable
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_evp_nv4afi_def_vrf_imp_disable
                                        
                                        	Advertise of v4 default VRF import disable
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_evp_nv4afi_vrf_re_imp_disable
                                        
                                        	Advertise of v4 VRF re\-import disable
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_evp_nv6afi_def_vrf_imp_disable
                                        
                                        	Advertise of v6 default VRF import disable
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_evp_nv6afi_vrf_re_imp_disable
                                        
                                        	Advertise of v6 VRF re\-import disable
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_local_labeled_route_unicast
                                        
                                        	Advertise routes with local\-label via Unicast SAFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_rt_type
                                        
                                        	Advertise RT type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: advertise_v4_flags
                                        
                                        	Advertise options for VPNV4
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertise_v6_flags
                                        
                                        	Advertise options for VPNV6
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: afrpki_allow_invalid
                                        
                                        	Prefix v. allow invalid
                                        	**type**\:  bool
                                        
                                        .. attribute:: afrpki_disable
                                        
                                        	Prefix validation disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: afrpki_signal_ibgp
                                        
                                        	Prefix v. signal ibgp
                                        	**type**\:  bool
                                        
                                        .. attribute:: afrpki_use_validity
                                        
                                        	Prefix v. use validity
                                        	**type**\:  bool
                                        
                                        .. attribute:: allow_as_in_count
                                        
                                        	Allowas\-in count config
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: always_use_next_hop_local
                                        
                                        	Local router always used for next\-hop
                                        	**type**\:  bool
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation type
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: eo_r_received_in_read_only
                                        
                                        	An EoR was received while in read\-only mode
                                        	**type**\:  bool
                                        
                                        .. attribute:: extended_community
                                        
                                        	Extended community attribute
                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity>`
                                        
                                        .. attribute:: extended_community_standby
                                        
                                        	Extended community attribute
                                        	**type**\: list of    :py:class:`ExtendedCommunityStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby>`
                                        
                                        .. attribute:: filter_group_index
                                        
                                        	Filter group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: flowspec_redirect_validation_d_isable
                                        
                                        	Flowspec Redirect Validation Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: flowspec_validation_d_isable
                                        
                                        	Flowspec Validation Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: import_reoriginate
                                        
                                        	Import Reoriginate enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: import_reoriginate_stitching
                                        
                                        	Import Reoriginate Stitching enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: import_stitching
                                        
                                        	Import Stitching enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_add_path_receive_capability_advertised
                                        
                                        	Addpath Receive capability advertised
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_add_path_receive_capability_received
                                        
                                        	Addpath Receive capability received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_add_path_send_capability_advertised
                                        
                                        	Addpath Send capability advertised
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_add_path_send_capability_received
                                        
                                        	Addpath Send capability received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_addpath_receive_operational
                                        
                                        	Addpath is operational on receive\-side
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_addpath_send_operational
                                        
                                        	Addpath is operational on send\-side
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertise_permanent_network
                                        
                                        	Advertise Permanent Network
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertised_graceful_restart
                                        
                                        	Graceful Restart Capability advertised
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertised_orf_receive
                                        
                                        	Prefix based ORF receive mode capability advertised
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_advertised_orf_send
                                        
                                        	Prefix based ORF send mode capability advertised
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_aigp_set
                                        
                                        	AIGP set 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_allow_as_in_set
                                        
                                        	Allowas\-in set 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_override_set
                                        
                                        	As override set 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_default_originate_sent
                                        
                                        	Default origination update sent
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ext_nh_encoding_capability_received
                                        
                                        	Extended nexthop encoding capability received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ext_nh_encoding_capability_sent
                                        
                                        	Extended nexhop encoding capability Sent
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_graceful_restart_state_flag
                                        
                                        	Restart state flag enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_legacy_pe_rt
                                        
                                        	Nbr accepts route from legacy PE for RT\-Constraint AF 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_af_capable
                                        
                                        	Address family capability received from neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_ebgp_without_inbound_policy
                                        
                                        	eBGP neighbor with no configured inbound policy
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_ebgp_without_outbound_policy
                                        
                                        	eBGP neighbor with no configured outbound policy
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_neighbor_route_reflector_client
                                        
                                        	Nbr is a route reflector client
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_orf_send_scheduled
                                        
                                        	Scheduled to send prefix based ORF
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_orf_sent
                                        
                                        	Outbound route filter sent to neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_orr_root_address_configured
                                        
                                        	ORR Root address configuredfor the neighbor connection
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_peer_orf_capable
                                        
                                        	Peer has outbound route filter capability
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_prefix_orf_present
                                        
                                        	Outbound route filter prefix ORF present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_graceful_restart_capable
                                        
                                        	Graceful Restart Capability received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_orf_receive_capable
                                        
                                        	Prefix based ORF receive mode capability received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_orf_send_capable
                                        
                                        	Prefix based ORF send mode capability received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rt_present
                                        
                                        	RT attribute list present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rt_present_standby
                                        
                                        	RT attribute list present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_send_mcast_attr
                                        
                                        	Send Mcast Attr
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_soft_reconfiguration_inbound_allowed
                                        
                                        	Inbound soft reconfiguration allowed
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_update_deferred
                                        
                                        	Update deferred until ORF/route refresh received
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_update_leaving
                                        
                                        	Nbr leaving update\-groupto another
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_update_throttled
                                        
                                        	Updates Throttled becausewrite limit is reached
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_use_soft_reconfiguration_always_on
                                        
                                        	Soft reconf overrides route refresh
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_restart_time
                                        
                                        	Local Restart time (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: long_lived_graceful_restart_capability_received
                                        
                                        	Long\-lived graceful\-restart capability received from the neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: long_lived_graceful_restart_stale_time_accept
                                        
                                        	Maximum long\-lived graceful\-restart stale time acceptable from the neighbor (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: long_lived_graceful_restart_stale_time_configured
                                        
                                        	Long\-lived graceful\-restart stale time is configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: long_lived_graceful_restart_stale_time_received
                                        
                                        	Long\-lived graceful\-restart stale time received from the neighbor (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: long_lived_graceful_restart_stale_time_sent
                                        
                                        	Stale time sent in long\-lived graceful\-restart capability (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: max_prefix_discard_extra_paths
                                        
                                        	Discard extra paths when prefix limit reached
                                        	**type**\:  bool
                                        
                                        .. attribute:: max_prefix_exceed_discard_paths
                                        
                                        	Did we discard extra paths when prefix limit reached
                                        	**type**\:  bool
                                        
                                        .. attribute:: max_prefix_limit
                                        
                                        	Max limit for # of prefixes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: max_prefix_restart_time
                                        
                                        	Time interval (in minutes) after which peering session will be reestablished
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: minute
                                        
                                        .. attribute:: max_prefix_threshold_percent
                                        
                                        	Percentage of maximum no. of prefixes at which to generate warning
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: percentage
                                        
                                        .. attribute:: neighbor_af_performance_statistics
                                        
                                        	Neighbor AF statistics
                                        	**type**\:   :py:class:`NeighborAfPerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics>`
                                        
                                        .. attribute:: neighbor_default_originate
                                        
                                        	Neighbor originates default
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_long_lived_graceful_restart_capable
                                        
                                        	Treat neighbor as long\-lived graceful\-restart capable
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_long_lived_graceful_restart_time_remaining
                                        
                                        	Remaining long\-lived graceful\-restart time
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_preserved_forwarding_state
                                        
                                        	Neighbor preserved forwarding state
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_preserved_long_lived_forwarding_state
                                        
                                        	Neighbor preserved long\-lived forwarding state
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_version
                                        
                                        	Neighbor version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: number_of_best_externalpaths
                                        
                                        	No. of best\-external paths from this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: number_of_bestpaths
                                        
                                        	No. of bestpaths from this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: orf_entries_received
                                        
                                        	Number of outbound route filter entries received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: orr_group_index
                                        
                                        	ORR Group Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: orr_group_name
                                        
                                        	ORR Group Name
                                        	**type**\:  str
                                        
                                        .. attribute:: outstanding_version
                                        
                                        	Version mapped from acked seqNo that was synced last
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: outstanding_version_max
                                        
                                        	Version mapped from acked seqNo that was synced last
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_accepted
                                        
                                        	No. of prefixes accepted
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_advertised
                                        
                                        	No. of prefixes advertised
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_be_advertised
                                        
                                        	No BE prefixes advertised
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_denied
                                        
                                        	No. of prefixes denied
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_denied_no_policy
                                        
                                        	No. of prefixes denied because there was no inbound policy
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_denied_non_cumulative
                                        
                                        	No. of prefixes exactly denied (non cumulative)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_denied_orf_policy
                                        
                                        	No. of prefixes denied by prefix based ORF policy
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_denied_policy
                                        
                                        	No. of prefixes denied by inbound policy
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_denied_rt_permit
                                        
                                        	No. of prefixes denied because RT extended community is not imported
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_suppressed
                                        
                                        	No. of prefixes suppressed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_synced
                                        
                                        	Number of prefixes synced to standby
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_withdrawn
                                        
                                        	No. of prefixes withdrawn
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_withdrawn_not_found
                                        
                                        	No. of prefixes withdrawn but not found
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_acked_version
                                        
                                        	Version acked by the peer for refresh updates sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_target_version
                                        
                                        	Target version for refresh update generation
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_version
                                        
                                        	Version till which refresh updates have been generated
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remove_private_as_entire_aspath_from_inbound_updates
                                        
                                        	Private AS numbers removed from updates from this nbr only if the aspath has only private ASes
                                        	**type**\:  bool
                                        
                                        .. attribute:: remove_private_as_entire_aspath_from_updates
                                        
                                        	Private AS numbers removed from updates to thisnbr only if the aspath hasonly private ASes
                                        	**type**\:  bool
                                        
                                        .. attribute:: remove_private_as_from_inbound_updates
                                        
                                        	Private AS numbers removed from updates from this nbr
                                        	**type**\:  bool
                                        
                                        .. attribute:: remove_private_as_from_updates
                                        
                                        	Private AS numbers removed from updates to this nbr
                                        	**type**\:  bool
                                        
                                        .. attribute:: restart_time
                                        
                                        	Restart time advertised (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: rib_purge_timeout_value
                                        
                                        	RIB purge timeout time (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: route_policy_default_originate
                                        
                                        	Default\-originate route policy name
                                        	**type**\:  str
                                        
                                        .. attribute:: route_policy_in
                                        
                                        	Incoming route policy name
                                        	**type**\:  str
                                        
                                        .. attribute:: route_policy_out
                                        
                                        	Outgoing route policy name
                                        	**type**\:  str
                                        
                                        .. attribute:: route_policy_prefix_orf
                                        
                                        	Prefix based ORF for incoming updates
                                        	**type**\:  str
                                        
                                        .. attribute:: route_refreshes_received
                                        
                                        	Number of route refresh requests received
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_refreshes_sent
                                        
                                        	Number of route refresh requests sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: selective_multipath_eligible
                                        
                                        	Selective multipath eligible
                                        	**type**\:  bool
                                        
                                        .. attribute:: sent_community_to_neighbor
                                        
                                        	Community attribute sent to neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: sent_extended_community_to_neighbor
                                        
                                        	Extended community attribute sent to neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: sent_gshut_community_to_neighbor
                                        
                                        	GSHUT Community attribute sent to neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: stale_path_timeout
                                        
                                        	Stale path timeout time (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: synced_acked_version
                                        
                                        	Version mapped from acked seqNo that was synced last
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: use_max_prefix_warning_only
                                        
                                        	Warning only when maximum prefix limit reached
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_update_gen_enabled
                                        
                                        	RT Nbr enabled for updategento another
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_update_gen_trigger_enabled
                                        
                                        	RT Nbr enabled for updategento another
                                        	**type**\:  bool
                                        
                                        .. attribute:: weight
                                        
                                        	Weight for this AF
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.accept_own_enabled = None
                                            self.acked_version = None
                                            self.address_family_long_lived_time = None
                                            self.advertise_afi = None
                                            self.advertise_afi_def_vrf_imp_disable = None
                                            self.advertise_afi_disable = None
                                            self.advertise_afi_eo_r_ready = None
                                            self.advertise_afi_reorg = None
                                            self.advertise_afi_vrf_re_imp_disable = None
                                            self.advertise_evp_nv4afi_def_vrf_imp_disable = None
                                            self.advertise_evp_nv4afi_vrf_re_imp_disable = None
                                            self.advertise_evp_nv6afi_def_vrf_imp_disable = None
                                            self.advertise_evp_nv6afi_vrf_re_imp_disable = None
                                            self.advertise_local_labeled_route_unicast = None
                                            self.advertise_rt_type = None
                                            self.advertise_v4_flags = None
                                            self.advertise_v6_flags = None
                                            self.af_name = None
                                            self.afrpki_allow_invalid = None
                                            self.afrpki_disable = None
                                            self.afrpki_signal_ibgp = None
                                            self.afrpki_use_validity = None
                                            self.allow_as_in_count = None
                                            self.always_use_next_hop_local = None
                                            self.encapsulation_type = None
                                            self.eo_r_received_in_read_only = None
                                            self.extended_community = YList()
                                            self.extended_community.parent = self
                                            self.extended_community.name = 'extended_community'
                                            self.extended_community_standby = YList()
                                            self.extended_community_standby.parent = self
                                            self.extended_community_standby.name = 'extended_community_standby'
                                            self.filter_group_index = None
                                            self.flowspec_redirect_validation_d_isable = None
                                            self.flowspec_validation_d_isable = None
                                            self.import_reoriginate = None
                                            self.import_reoriginate_stitching = None
                                            self.import_stitching = None
                                            self.is_add_path_receive_capability_advertised = None
                                            self.is_add_path_receive_capability_received = None
                                            self.is_add_path_send_capability_advertised = None
                                            self.is_add_path_send_capability_received = None
                                            self.is_addpath_receive_operational = None
                                            self.is_addpath_send_operational = None
                                            self.is_advertise_permanent_network = None
                                            self.is_advertised_graceful_restart = None
                                            self.is_advertised_orf_receive = None
                                            self.is_advertised_orf_send = None
                                            self.is_aigp_set = None
                                            self.is_allow_as_in_set = None
                                            self.is_as_override_set = None
                                            self.is_default_originate_sent = None
                                            self.is_ext_nh_encoding_capability_received = None
                                            self.is_ext_nh_encoding_capability_sent = None
                                            self.is_graceful_restart_state_flag = None
                                            self.is_legacy_pe_rt = None
                                            self.is_neighbor_af_capable = None
                                            self.is_neighbor_ebgp_without_inbound_policy = None
                                            self.is_neighbor_ebgp_without_outbound_policy = None
                                            self.is_neighbor_route_reflector_client = None
                                            self.is_orf_send_scheduled = None
                                            self.is_orf_sent = None
                                            self.is_orr_root_address_configured = None
                                            self.is_peer_orf_capable = None
                                            self.is_prefix_orf_present = None
                                            self.is_received_graceful_restart_capable = None
                                            self.is_received_orf_receive_capable = None
                                            self.is_received_orf_send_capable = None
                                            self.is_rt_present = None
                                            self.is_rt_present_standby = None
                                            self.is_send_mcast_attr = None
                                            self.is_soft_reconfiguration_inbound_allowed = None
                                            self.is_update_deferred = None
                                            self.is_update_leaving = None
                                            self.is_update_throttled = None
                                            self.is_use_soft_reconfiguration_always_on = None
                                            self.local_restart_time = None
                                            self.long_lived_graceful_restart_capability_received = None
                                            self.long_lived_graceful_restart_stale_time_accept = None
                                            self.long_lived_graceful_restart_stale_time_configured = None
                                            self.long_lived_graceful_restart_stale_time_received = None
                                            self.long_lived_graceful_restart_stale_time_sent = None
                                            self.max_prefix_discard_extra_paths = None
                                            self.max_prefix_exceed_discard_paths = None
                                            self.max_prefix_limit = None
                                            self.max_prefix_restart_time = None
                                            self.max_prefix_threshold_percent = None
                                            self.neighbor_af_performance_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics()
                                            self.neighbor_af_performance_statistics.parent = self
                                            self.neighbor_default_originate = None
                                            self.neighbor_long_lived_graceful_restart_capable = None
                                            self.neighbor_long_lived_graceful_restart_time_remaining = None
                                            self.neighbor_preserved_forwarding_state = None
                                            self.neighbor_preserved_long_lived_forwarding_state = None
                                            self.neighbor_version = None
                                            self.number_of_best_externalpaths = None
                                            self.number_of_bestpaths = None
                                            self.orf_entries_received = None
                                            self.orr_group_index = None
                                            self.orr_group_name = None
                                            self.outstanding_version = None
                                            self.outstanding_version_max = None
                                            self.prefixes_accepted = None
                                            self.prefixes_advertised = None
                                            self.prefixes_be_advertised = None
                                            self.prefixes_denied = None
                                            self.prefixes_denied_no_policy = None
                                            self.prefixes_denied_non_cumulative = None
                                            self.prefixes_denied_orf_policy = None
                                            self.prefixes_denied_policy = None
                                            self.prefixes_denied_rt_permit = None
                                            self.prefixes_suppressed = None
                                            self.prefixes_synced = None
                                            self.prefixes_withdrawn = None
                                            self.prefixes_withdrawn_not_found = None
                                            self.refresh_acked_version = None
                                            self.refresh_target_version = None
                                            self.refresh_version = None
                                            self.remove_private_as_entire_aspath_from_inbound_updates = None
                                            self.remove_private_as_entire_aspath_from_updates = None
                                            self.remove_private_as_from_inbound_updates = None
                                            self.remove_private_as_from_updates = None
                                            self.restart_time = None
                                            self.rib_purge_timeout_value = None
                                            self.route_policy_default_originate = None
                                            self.route_policy_in = None
                                            self.route_policy_out = None
                                            self.route_policy_prefix_orf = None
                                            self.route_refreshes_received = None
                                            self.route_refreshes_sent = None
                                            self.selective_multipath_eligible = None
                                            self.sent_community_to_neighbor = None
                                            self.sent_extended_community_to_neighbor = None
                                            self.sent_gshut_community_to_neighbor = None
                                            self.stale_path_timeout = None
                                            self.synced_acked_version = None
                                            self.update_group_number = None
                                            self.use_max_prefix_warning_only = None
                                            self.vpn_update_gen_enabled = None
                                            self.vpn_update_gen_trigger_enabled = None
                                            self.weight = None


                                        class NeighborAfPerformanceStatistics(object):
                                            """
                                            Neighbor AF statistics
                                            
                                            .. attribute:: processed_messages
                                            
                                            	Number of messages processed from the neighbor's write queue
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sent_messages
                                            
                                            	Number of messages sent from the neighbor's write queue
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: split_horizon_update_blocked
                                            
                                            	No. of update messages with split\-horizon flag that were blocked
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: split_horizon_update_transmit
                                            
                                            	No. of update messages with split\-horizon flag that were sent out
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: split_horizon_withdraw_blocked
                                            
                                            	No. of withdraw messages with split\-horizon flag that were blocked
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: split_horizon_withdraw_transmit
                                            
                                            	No. of withdraw messages with split\-horizon flag that were sent out
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sub_group_pending_message_count
                                            
                                            	No. of sub\-group messages waiting to be sent out on this neighbor \-\- DEPRECATED \-\- 
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.processed_messages = None
                                                self.sent_messages = None
                                                self.split_horizon_update_blocked = None
                                                self.split_horizon_update_transmit = None
                                                self.split_horizon_withdraw_blocked = None
                                                self.split_horizon_withdraw_transmit = None
                                                self.sub_group_pending_message_count = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-af-performance-statistics'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.processed_messages is not None:
                                                    return True

                                                if self.sent_messages is not None:
                                                    return True

                                                if self.split_horizon_update_blocked is not None:
                                                    return True

                                                if self.split_horizon_update_transmit is not None:
                                                    return True

                                                if self.split_horizon_withdraw_blocked is not None:
                                                    return True

                                                if self.split_horizon_withdraw_transmit is not None:
                                                    return True

                                                if self.sub_group_pending_message_count is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics']['meta_info']


                                        class ExtendedCommunity(object):
                                            """
                                            Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity']['meta_info']


                                        class ExtendedCommunityStandby(object):
                                            """
                                            Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community-standby'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af-data'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.accept_own_enabled is not None:
                                                return True

                                            if self.acked_version is not None:
                                                return True

                                            if self.address_family_long_lived_time is not None:
                                                return True

                                            if self.advertise_afi is not None:
                                                return True

                                            if self.advertise_afi_def_vrf_imp_disable is not None:
                                                return True

                                            if self.advertise_afi_disable is not None:
                                                return True

                                            if self.advertise_afi_eo_r_ready is not None:
                                                return True

                                            if self.advertise_afi_reorg is not None:
                                                return True

                                            if self.advertise_afi_vrf_re_imp_disable is not None:
                                                return True

                                            if self.advertise_evp_nv4afi_def_vrf_imp_disable is not None:
                                                return True

                                            if self.advertise_evp_nv4afi_vrf_re_imp_disable is not None:
                                                return True

                                            if self.advertise_evp_nv6afi_def_vrf_imp_disable is not None:
                                                return True

                                            if self.advertise_evp_nv6afi_vrf_re_imp_disable is not None:
                                                return True

                                            if self.advertise_local_labeled_route_unicast is not None:
                                                return True

                                            if self.advertise_rt_type is not None:
                                                return True

                                            if self.advertise_v4_flags is not None:
                                                return True

                                            if self.advertise_v6_flags is not None:
                                                return True

                                            if self.af_name is not None:
                                                return True

                                            if self.afrpki_allow_invalid is not None:
                                                return True

                                            if self.afrpki_disable is not None:
                                                return True

                                            if self.afrpki_signal_ibgp is not None:
                                                return True

                                            if self.afrpki_use_validity is not None:
                                                return True

                                            if self.allow_as_in_count is not None:
                                                return True

                                            if self.always_use_next_hop_local is not None:
                                                return True

                                            if self.encapsulation_type is not None:
                                                return True

                                            if self.eo_r_received_in_read_only is not None:
                                                return True

                                            if self.extended_community is not None:
                                                for child_ref in self.extended_community:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.extended_community_standby is not None:
                                                for child_ref in self.extended_community_standby:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.filter_group_index is not None:
                                                return True

                                            if self.flowspec_redirect_validation_d_isable is not None:
                                                return True

                                            if self.flowspec_validation_d_isable is not None:
                                                return True

                                            if self.import_reoriginate is not None:
                                                return True

                                            if self.import_reoriginate_stitching is not None:
                                                return True

                                            if self.import_stitching is not None:
                                                return True

                                            if self.is_add_path_receive_capability_advertised is not None:
                                                return True

                                            if self.is_add_path_receive_capability_received is not None:
                                                return True

                                            if self.is_add_path_send_capability_advertised is not None:
                                                return True

                                            if self.is_add_path_send_capability_received is not None:
                                                return True

                                            if self.is_addpath_receive_operational is not None:
                                                return True

                                            if self.is_addpath_send_operational is not None:
                                                return True

                                            if self.is_advertise_permanent_network is not None:
                                                return True

                                            if self.is_advertised_graceful_restart is not None:
                                                return True

                                            if self.is_advertised_orf_receive is not None:
                                                return True

                                            if self.is_advertised_orf_send is not None:
                                                return True

                                            if self.is_aigp_set is not None:
                                                return True

                                            if self.is_allow_as_in_set is not None:
                                                return True

                                            if self.is_as_override_set is not None:
                                                return True

                                            if self.is_default_originate_sent is not None:
                                                return True

                                            if self.is_ext_nh_encoding_capability_received is not None:
                                                return True

                                            if self.is_ext_nh_encoding_capability_sent is not None:
                                                return True

                                            if self.is_graceful_restart_state_flag is not None:
                                                return True

                                            if self.is_legacy_pe_rt is not None:
                                                return True

                                            if self.is_neighbor_af_capable is not None:
                                                return True

                                            if self.is_neighbor_ebgp_without_inbound_policy is not None:
                                                return True

                                            if self.is_neighbor_ebgp_without_outbound_policy is not None:
                                                return True

                                            if self.is_neighbor_route_reflector_client is not None:
                                                return True

                                            if self.is_orf_send_scheduled is not None:
                                                return True

                                            if self.is_orf_sent is not None:
                                                return True

                                            if self.is_orr_root_address_configured is not None:
                                                return True

                                            if self.is_peer_orf_capable is not None:
                                                return True

                                            if self.is_prefix_orf_present is not None:
                                                return True

                                            if self.is_received_graceful_restart_capable is not None:
                                                return True

                                            if self.is_received_orf_receive_capable is not None:
                                                return True

                                            if self.is_received_orf_send_capable is not None:
                                                return True

                                            if self.is_rt_present is not None:
                                                return True

                                            if self.is_rt_present_standby is not None:
                                                return True

                                            if self.is_send_mcast_attr is not None:
                                                return True

                                            if self.is_soft_reconfiguration_inbound_allowed is not None:
                                                return True

                                            if self.is_update_deferred is not None:
                                                return True

                                            if self.is_update_leaving is not None:
                                                return True

                                            if self.is_update_throttled is not None:
                                                return True

                                            if self.is_use_soft_reconfiguration_always_on is not None:
                                                return True

                                            if self.local_restart_time is not None:
                                                return True

                                            if self.long_lived_graceful_restart_capability_received is not None:
                                                return True

                                            if self.long_lived_graceful_restart_stale_time_accept is not None:
                                                return True

                                            if self.long_lived_graceful_restart_stale_time_configured is not None:
                                                return True

                                            if self.long_lived_graceful_restart_stale_time_received is not None:
                                                return True

                                            if self.long_lived_graceful_restart_stale_time_sent is not None:
                                                return True

                                            if self.max_prefix_discard_extra_paths is not None:
                                                return True

                                            if self.max_prefix_exceed_discard_paths is not None:
                                                return True

                                            if self.max_prefix_limit is not None:
                                                return True

                                            if self.max_prefix_restart_time is not None:
                                                return True

                                            if self.max_prefix_threshold_percent is not None:
                                                return True

                                            if self.neighbor_af_performance_statistics is not None and self.neighbor_af_performance_statistics._has_data():
                                                return True

                                            if self.neighbor_default_originate is not None:
                                                return True

                                            if self.neighbor_long_lived_graceful_restart_capable is not None:
                                                return True

                                            if self.neighbor_long_lived_graceful_restart_time_remaining is not None:
                                                return True

                                            if self.neighbor_preserved_forwarding_state is not None:
                                                return True

                                            if self.neighbor_preserved_long_lived_forwarding_state is not None:
                                                return True

                                            if self.neighbor_version is not None:
                                                return True

                                            if self.number_of_best_externalpaths is not None:
                                                return True

                                            if self.number_of_bestpaths is not None:
                                                return True

                                            if self.orf_entries_received is not None:
                                                return True

                                            if self.orr_group_index is not None:
                                                return True

                                            if self.orr_group_name is not None:
                                                return True

                                            if self.outstanding_version is not None:
                                                return True

                                            if self.outstanding_version_max is not None:
                                                return True

                                            if self.prefixes_accepted is not None:
                                                return True

                                            if self.prefixes_advertised is not None:
                                                return True

                                            if self.prefixes_be_advertised is not None:
                                                return True

                                            if self.prefixes_denied is not None:
                                                return True

                                            if self.prefixes_denied_no_policy is not None:
                                                return True

                                            if self.prefixes_denied_non_cumulative is not None:
                                                return True

                                            if self.prefixes_denied_orf_policy is not None:
                                                return True

                                            if self.prefixes_denied_policy is not None:
                                                return True

                                            if self.prefixes_denied_rt_permit is not None:
                                                return True

                                            if self.prefixes_suppressed is not None:
                                                return True

                                            if self.prefixes_synced is not None:
                                                return True

                                            if self.prefixes_withdrawn is not None:
                                                return True

                                            if self.prefixes_withdrawn_not_found is not None:
                                                return True

                                            if self.refresh_acked_version is not None:
                                                return True

                                            if self.refresh_target_version is not None:
                                                return True

                                            if self.refresh_version is not None:
                                                return True

                                            if self.remove_private_as_entire_aspath_from_inbound_updates is not None:
                                                return True

                                            if self.remove_private_as_entire_aspath_from_updates is not None:
                                                return True

                                            if self.remove_private_as_from_inbound_updates is not None:
                                                return True

                                            if self.remove_private_as_from_updates is not None:
                                                return True

                                            if self.restart_time is not None:
                                                return True

                                            if self.rib_purge_timeout_value is not None:
                                                return True

                                            if self.route_policy_default_originate is not None:
                                                return True

                                            if self.route_policy_in is not None:
                                                return True

                                            if self.route_policy_out is not None:
                                                return True

                                            if self.route_policy_prefix_orf is not None:
                                                return True

                                            if self.route_refreshes_received is not None:
                                                return True

                                            if self.route_refreshes_sent is not None:
                                                return True

                                            if self.selective_multipath_eligible is not None:
                                                return True

                                            if self.sent_community_to_neighbor is not None:
                                                return True

                                            if self.sent_extended_community_to_neighbor is not None:
                                                return True

                                            if self.sent_gshut_community_to_neighbor is not None:
                                                return True

                                            if self.stale_path_timeout is not None:
                                                return True

                                            if self.synced_acked_version is not None:
                                                return True

                                            if self.update_group_number is not None:
                                                return True

                                            if self.use_max_prefix_warning_only is not None:
                                                return True

                                            if self.vpn_update_gen_enabled is not None:
                                                return True

                                            if self.vpn_update_gen_trigger_enabled is not None:
                                                return True

                                            if self.weight is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.neighbor_address is None:
                                            raise YPYModelError('Key property neighbor_address is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address = ' + str(self.neighbor_address) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.neighbor_address is not None:
                                            return True

                                        if self.active_bmp_servers is not None:
                                            return True

                                        if self.actual_last_write_bytes is not None:
                                            return True

                                        if self.actual_last_write_reset_bytes is not None:
                                            return True

                                        if self.actual_second_last_write_bytes is not None:
                                            return True

                                        if self.actual_second_last_write_reset_bytes is not None:
                                            return True

                                        if self.af_data is not None:
                                            for child_ref in self.af_data:
                                                if child_ref._has_data():
                                                    return True

                                        if self.attempted_last_write_bytes is not None:
                                            return True

                                        if self.attempted_last_write_reset_bytes is not None:
                                            return True

                                        if self.attempted_second_last_write_bytes is not None:
                                            return True

                                        if self.attempted_second_last_write_reset_bytes is not None:
                                            return True

                                        if self.bfd_minintervalval is not None:
                                            return True

                                        if self.bfd_multiplierval is not None:
                                            return True

                                        if self.bfd_session_created_state is not None:
                                            return True

                                        if self.bfd_session_enable_mode is not None:
                                            return True

                                        if self.bfd_session_state is not None:
                                            return True

                                        if self.bfd_state_ts is not None:
                                            return True

                                        if self.bytes_read is not None:
                                            return True

                                        if self.bytes_written is not None:
                                            return True

                                        if self.configured_hold_time is not None:
                                            return True

                                        if self.configured_keepalive is not None:
                                            return True

                                        if self.configured_min_acc_hold_time is not None:
                                            return True

                                        if self.connect_retry_interval is not None:
                                            return True

                                        if self.connection_admin_status is not None:
                                            return True

                                        if self.connection_down_count is not None:
                                            return True

                                        if self.connection_established_time is not None:
                                            return True

                                        if self.connection_local_address is not None and self.connection_local_address._has_data():
                                            return True

                                        if self.connection_local_port is not None:
                                            return True

                                        if self.connection_remote_address is not None and self.connection_remote_address._has_data():
                                            return True

                                        if self.connection_remote_port is not None:
                                            return True

                                        if self.connection_state is not None:
                                            return True

                                        if self.connection_up_count is not None:
                                            return True

                                        if self.count_last_write is not None:
                                            return True

                                        if self.description is not None:
                                            return True

                                        if self.discard_as4_path is not None:
                                            return True

                                        if self.discard_data_bytes is not None:
                                            return True

                                        if self.dmz_link_bandwidth is not None:
                                            return True

                                        if self.dynamic_neighbor is not None:
                                            return True

                                        if self.ebgp_recv_dmz is not None:
                                            return True

                                        if self.ebgp_send_dmz_mode is not None:
                                            return True

                                        if self.ebgp_time_to_live is not None:
                                            return True

                                        if self.egress_peer_engineering_enabled is not None:
                                            return True

                                        if self.error_notifies_received is not None:
                                            return True

                                        if self.error_notifies_sent is not None:
                                            return True

                                        if self.fpbsn_offset is not None:
                                            return True

                                        if self.fssn_offset is not None:
                                            return True

                                        if self.gr_restart_time is not None:
                                            return True

                                        if self.gr_stale_path_time is not None:
                                            return True

                                        if self.graceful_maintenance is not None and self.graceful_maintenance._has_data():
                                            return True

                                        if self.graceful_restart_enabled_nbr is not None:
                                            return True

                                        if self.has_internal_link is not None:
                                            return True

                                        if self.hold_time is not None:
                                            return True

                                        if self.ignore_connected is not None:
                                            return True

                                        if self.internal_vpn_client is not None:
                                            return True

                                        if self.io_armed is not None:
                                            return True

                                        if self.is4_byte_as_capability_received is not None:
                                            return True

                                        if self.is4_byte_as_capability_sent is not None:
                                            return True

                                        if self.is_administratively_shut_down is not None:
                                            return True

                                        if self.is_capability_negotiation_performed is not None:
                                            return True

                                        if self.is_capability_negotiation_suppressed is not None:
                                            return True

                                        if self.is_ebgp_multihop_bgpmpls_forwarding_disabled is not None:
                                            return True

                                        if self.is_ebgp_peer_as_league is not None:
                                            return True

                                        if self.is_ebgp_peer_common_admin is not None:
                                            return True

                                        if self.is_external_neighbor_not_directly_connected is not None:
                                            return True

                                        if self.is_gr_aware is not None:
                                            return True

                                        if self.is_local_address_configured is not None:
                                            return True

                                        if self.is_neighbor_max_prefix_shutdown is not None:
                                            return True

                                        if self.is_out_of_memory_forced_up is not None:
                                            return True

                                        if self.is_out_of_memory_shutdown is not None:
                                            return True

                                        if self.is_passive_close is not None:
                                            return True

                                        if self.is_read_disabled is not None:
                                            return True

                                        if self.is_route_refresh_capability_received is not None:
                                            return True

                                        if self.is_route_refresh_old_capability_received is not None:
                                            return True

                                        if self.keep_alive_time is not None:
                                            return True

                                        if self.last_ackd_seq_no is not None:
                                            return True

                                        if self.last_k_aerror_reset is not None:
                                            return True

                                        if self.last_k_aexpiry_reset is not None:
                                            return True

                                        if self.last_k_anotsent_reset is not None:
                                            return True

                                        if self.last_k_astart_reset is not None:
                                            return True

                                        if self.last_notify_error_code is not None:
                                            return True

                                        if self.last_notify_error_subcode is not None:
                                            return True

                                        if self.last_write_event is not None:
                                            return True

                                        if self.local_as is not None:
                                            return True

                                        if self.local_as_dual_as is not None:
                                            return True

                                        if self.local_as_dual_as_mode_native is not None:
                                            return True

                                        if self.local_as_no_prepend is not None:
                                            return True

                                        if self.local_as_replace_as is not None:
                                            return True

                                        if self.message_statistics is not None and self.message_statistics._has_data():
                                            return True

                                        if self.messages_queued_in is not None:
                                            return True

                                        if self.messages_queued_out is not None:
                                            return True

                                        if self.messages_received is not None:
                                            return True

                                        if self.messages_sent is not None:
                                            return True

                                        if self.min_advertise_interval is not None:
                                            return True

                                        if self.min_advertise_interval_msecs is not None:
                                            return True

                                        if self.min_origination_interval is not None:
                                            return True

                                        if self.msg_log_in is not None:
                                            return True

                                        if self.msg_log_out is not None:
                                            return True

                                        if self.multi_protocol_capability_received is not None:
                                            return True

                                        if self.nbr_cluster_id is not None:
                                            return True

                                        if self.nbr_enforce_first_as is not None:
                                            return True

                                        if self.nbr_in_cluster is not None:
                                            return True

                                        if self.negotiated_protocol_version is not None:
                                            return True

                                        if self.neighbor_interface_handle is not None:
                                            return True

                                        if self.neighbor_local_as is not None:
                                            return True

                                        if self.nsr_enabled is not None:
                                            return True

                                        if self.nsr_state is not None:
                                            return True

                                        if self.open_check_error_code is not None:
                                            return True

                                        if self.peer_error_code is not None:
                                            return True

                                        if self.peer_reset_reason is not None:
                                            return True

                                        if self.performance_statistics is not None and self.performance_statistics._has_data():
                                            return True

                                        if self.previous_connection_state is not None:
                                            return True

                                        if self.read_armed is not None:
                                            return True

                                        if self.received_notification_info is not None and self.received_notification_info._has_data():
                                            return True

                                        if self.remote_as is not None:
                                            return True

                                        if self.remote_as_number is not None:
                                            return True

                                        if self.reset_notification_sent is not None:
                                            return True

                                        if self.reset_reason is not None:
                                            return True

                                        if self.router_id is not None:
                                            return True

                                        if self.rpki_allow_invalid is not None:
                                            return True

                                        if self.rpki_disable is not None:
                                            return True

                                        if self.rpki_signal_ibgp is not None:
                                            return True

                                        if self.rpki_use_validity is not None:
                                            return True

                                        if self.second_last_k_aexpiry_reset is not None:
                                            return True

                                        if self.second_last_k_astart_reset is not None:
                                            return True

                                        if self.second_last_write_event is not None:
                                            return True

                                        if self.send_notification_info is not None and self.send_notification_info._has_data():
                                            return True

                                        if self.socket_read_bytes is not None:
                                            return True

                                        if self.speaker_id is not None:
                                            return True

                                        if self.standby_rp is not None:
                                            return True

                                        if self.suppress4_byte_as is not None:
                                            return True

                                        if self.tcp_init_sync_done_time_spec is not None and self.tcp_init_sync_done_time_spec._has_data():
                                            return True

                                        if self.tcp_init_sync_phase_two_time_spec is not None and self.tcp_init_sync_phase_two_time_spec._has_data():
                                            return True

                                        if self.tcp_init_sync_time_spec is not None and self.tcp_init_sync_time_spec._has_data():
                                            return True

                                        if self.tcp_session_open_mode is not None:
                                            return True

                                        if self.tcpmss is not None:
                                            return True

                                        if self.time_last_cb is not None:
                                            return True

                                        if self.time_last_cb_reset is not None:
                                            return True

                                        if self.time_last_fb is not None:
                                            return True

                                        if self.time_since_connection_last_dropped is not None:
                                            return True

                                        if self.time_since_last_read is not None:
                                            return True

                                        if self.time_since_last_read_reset is not None:
                                            return True

                                        if self.time_since_last_update is not None:
                                            return True

                                        if self.time_since_last_write is not None:
                                            return True

                                        if self.time_since_last_write_reset is not None:
                                            return True

                                        if self.time_since_second_last_write is not None:
                                            return True

                                        if self.time_since_second_last_write_reset is not None:
                                            return True

                                        if self.tos_type is not None:
                                            return True

                                        if self.tos_value is not None:
                                            return True

                                        if self.ttl_security_enabled is not None:
                                            return True

                                        if self.update_bytes_read is not None:
                                            return True

                                        if self.update_messages_in is not None:
                                            return True

                                        if self.update_messages_out is not None:
                                            return True

                                        if self.vrf_name is not None:
                                            return True

                                        if self.write_armed is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-af-table'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.neighbor is not None:
                                        for child_ref in self.neighbor:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable']['meta_info']


                            class NetworkAllRds(object):
                                """
                                The BGP Network Lookup Table
                                
                                .. attribute:: network_all_rd
                                
                                	The BGP Network Lookup table
                                	**type**\: list of    :py:class:`NetworkAllRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.network_all_rd = YList()
                                    self.network_all_rd.parent = self
                                    self.network_all_rd.name = 'network_all_rd'


                                class NetworkAllRd(object):
                                    """
                                    The BGP Network Lookup table
                                    
                                    .. attribute:: network_addr  <key>
                                    
                                    	Network in prefix/length format (address part)
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: network_prefix  <key>
                                    
                                    	Network in prefix/length format (prefix part)
                                    	**type**\:  int
                                    
                                    	**range:** 0..128
                                    
                                    .. attribute:: network_rds
                                    
                                    	The BGP Network Lookup table
                                    	**type**\:   :py:class:`NetworkRds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.network_addr = None
                                        self.network_prefix = None
                                        self.network_rds = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds()
                                        self.network_rds.parent = self


                                    class NetworkRds(object):
                                        """
                                        The BGP Network Lookup table
                                        
                                        .. attribute:: network_rd
                                        
                                        	A BGP Network table entry
                                        	**type**\: list of    :py:class:`NetworkRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.network_rd = YList()
                                            self.network_rd.parent = self
                                            self.network_rd.name = 'network_rd'


                                        class NetworkRd(object):
                                            """
                                            A BGP Network table entry
                                            
                                            .. attribute:: rd  <key>
                                            
                                            	Route Distinguisher value
                                            	**type**\:  str
                                            
                                            .. attribute:: active_path_element
                                            
                                            	Path element list received from Active inst
                                            	**type**\: list of    :py:class:`ActivePathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement>`
                                            
                                            .. attribute:: active_process_instance_path
                                            
                                            	Active's paths for this net 
                                            	**type**\: list of    :py:class:`ActiveProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath>`
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield>`
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\:  bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield>`
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix>`
                                            
                                            .. attribute:: bit
                                            
                                            	Bit
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: flags
                                            
                                            	Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: gateway_array
                                            
                                            	Gateway array ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_inconsistent_paths
                                            
                                            	Net has inconsistent paths
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_lbl_retained
                                            
                                            	Net has label retained
                                            	**type**\:  bool
                                            
                                            .. attribute:: has_local_label
                                            
                                            	Net has local label
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_net_aggregation_suppressed
                                            
                                            	Net suppressed due to aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_net_ldp_signaled
                                            
                                            	L2VPN Net LDP signaled  aggregation
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_permanent_network
                                            
                                            	Permanent Network
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_path_element
                                            
                                            	Local path element list
                                            	**type**\: list of    :py:class:`LocalPathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement>`
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: local_process_instance_path
                                            
                                            	Local (to process instance) paths for this net 
                                            	**type**\: list of    :py:class:`LocalProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath>`
                                            
                                            .. attribute:: net_backup_available
                                            
                                            	Net has backup path
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_backup_label_rewrite_available
                                            
                                            	Net has label rewrite for backup path
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_eibgp_multipath
                                            
                                            	Net has EIBGP multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_extended_flags
                                            
                                            	Net extended flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: net_flags
                                            
                                            	Flags associated with                            net
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: net_local_label
                                            
                                            	Local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: net_local_label_rewrite
                                            
                                            	Net label has rewrite
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_local_label_srgb
                                            
                                            	Net label allocated fromSegment routing global block
                                            	**type**\:  bool
                                            
                                            .. attribute:: net_multipath
                                            
                                            	Net has multipaths
                                            	**type**\:  bool
                                            
                                            .. attribute:: num_of_path
                                            
                                            	Number of path for this net
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: process_instance_id
                                            
                                            	Process instance ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: resilient_nexthop_set
                                            
                                            	Resilient nexthop set ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_failed
                                            
                                            	RIB install failed
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: table_brib_version
                                            
                                            	Table version # for updates
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: table_version
                                            
                                            	Table version # for net
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: version
                                            
                                            	Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: version_age
                                            
                                            	Version age
                                            	**type**\:   :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionAge>`
                                            
                                            .. attribute:: version_timestamp
                                            
                                            	Version timestamp
                                            	**type**\:   :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionTimestamp>`
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.rd = None
                                                self.active_path_element = YList()
                                                self.active_path_element.parent = self
                                                self.active_path_element.name = 'active_path_element'
                                                self.active_process_instance_path = YList()
                                                self.active_process_instance_path.parent = self
                                                self.active_process_instance_path.name = 'active_process_instance_path'
                                                self.add_path_orr_bitfield = YList()
                                                self.add_path_orr_bitfield.parent = self
                                                self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                self.advertisedto_pe = None
                                                self.af_name = None
                                                self.best_path_orr_bitfield = YList()
                                                self.best_path_orr_bitfield.parent = self
                                                self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self.bit = None
                                                self.flags = None
                                                self.gateway_array = None
                                                self.has_inconsistent_paths = None
                                                self.has_lbl_retained = None
                                                self.has_local_label = None
                                                self.is_net_aggregation_suppressed = None
                                                self.is_net_ldp_signaled = None
                                                self.is_permanent_network = None
                                                self.local_path_element = YList()
                                                self.local_path_element.parent = self
                                                self.local_path_element.name = 'local_path_element'
                                                self.local_peers_advertised_to = YList()
                                                self.local_peers_advertised_to.parent = self
                                                self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                self.local_process_instance_path = YList()
                                                self.local_process_instance_path.parent = self
                                                self.local_process_instance_path.name = 'local_process_instance_path'
                                                self.net_backup_available = None
                                                self.net_backup_label_rewrite_available = None
                                                self.net_eibgp_multipath = None
                                                self.net_extended_flags = None
                                                self.net_flags = None
                                                self.net_local_label = None
                                                self.net_local_label_rewrite = None
                                                self.net_local_label_srgb = None
                                                self.net_multipath = None
                                                self.num_of_path = None
                                                self.pe_peers_advertised_to = YList()
                                                self.pe_peers_advertised_to.parent = self
                                                self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                self.process_instance_id = None
                                                self.resilient_nexthop_set = None
                                                self.rib_failed = None
                                                self.route_distinguisher = None
                                                self.table_brib_version = None
                                                self.table_version = None
                                                self.version = None
                                                self.version_age = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionAge()
                                                self.version_age.parent = self
                                                self.version_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionTimestamp()
                                                self.version_timestamp.parent = self
                                                self.vrf_name = None


                                            class BgpPrefix(object):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self.prefix_length = None


                                                class Prefix(object):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.prefix is not None and self.prefix._has_data():
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BgpPrefix']['meta_info']


                                            class VersionTimestamp(object):
                                                """
                                                Version timestamp
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-timestamp'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionTimestamp']['meta_info']


                                            class VersionAge(object):
                                                """
                                                Version age
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.nanoseconds = None
                                                    self.seconds = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:version-age'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.nanoseconds is not None:
                                                        return True

                                                    if self.seconds is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.VersionAge']['meta_info']


                                            class LocalPeersAdvertisedTo(object):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPeersAdvertisedTo']['meta_info']


                                            class PePeersAdvertisedTo(object):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.PePeersAdvertisedTo']['meta_info']


                                            class BestPathOrrBitfield(object):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.BestPathOrrBitfield']['meta_info']


                                            class AddPathOrrBitfield(object):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_neighbor = None
                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self.update_group_number = None


                                                class NeighborAddress(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_neighbor is not None:
                                                        return True

                                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                        return True

                                                    if self.update_group_number is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.AddPathOrrBitfield']['meta_info']


                                            class LocalProcessInstancePath(object):
                                                """
                                                Local (to process instance) paths for this net 
                                                
                                                .. attribute:: af_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: attributes_after_policy_in
                                                
                                                	Attributes after inbound policy applied
                                                	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn>`
                                                
                                                .. attribute:: label_fail
                                                
                                                	LSD label allocation failed 
                                                	**type**\:  bool
                                                
                                                .. attribute:: label_o_or_version
                                                
                                                	Label Version when OOR happens
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_oor
                                                
                                                	LSD label space is exhausted
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address_xr
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr>`
                                                
                                                .. attribute:: no_path
                                                
                                                	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                                	**type**\:  bool
                                                
                                                .. attribute:: path_information
                                                
                                                	Path information
                                                	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation>`
                                                
                                                .. attribute:: prefix_version
                                                
                                                	Version of BGP Prefix Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: process_instance_id
                                                
                                                	Process instance ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: source_route_distinguisher
                                                
                                                	Source Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: source_vrf_name
                                                
                                                	Name of the source VRF
                                                	**type**\:  str
                                                
                                                .. attribute:: srcaf_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: vrf_name
                                                
                                                	Name of the VRF
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.af_name = None
                                                    self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn()
                                                    self.attributes_after_policy_in.parent = self
                                                    self.label_fail = None
                                                    self.label_o_or_version = None
                                                    self.label_oor = None
                                                    self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr()
                                                    self.neighbor_address_xr.parent = self
                                                    self.no_path = None
                                                    self.path_information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation()
                                                    self.path_information.parent = self
                                                    self.prefix_version = None
                                                    self.process_instance_id = None
                                                    self.route_distinguisher = None
                                                    self.source_route_distinguisher = None
                                                    self.source_vrf_name = None
                                                    self.srcaf_name = None
                                                    self.vrf_name = None


                                                class NeighborAddressXr(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.NeighborAddressXr']['meta_info']


                                                class PathInformation(object):
                                                    """
                                                    Path information
                                                    
                                                    .. attribute:: accept_own_path
                                                    
                                                    	Accept Own
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: accept_own_self_originated_p_ath
                                                    
                                                    	Accept\-Own self\-originated
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: add_path_orr_bitfield
                                                    
                                                    	ORR Add path Bitfields
                                                    	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                    
                                                    .. attribute:: advertisedto_pe
                                                    
                                                    	Net could be advertised                          to PE peers
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: aigp_metric
                                                    
                                                    	Total AIGP metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: best_path_comp_stage
                                                    
                                                    	Stage where the path lost to the best path or group best
                                                    	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                                    
                                                    .. attribute:: best_path_comp_winner
                                                    
                                                    	Neighbor address of the path which won best path comparison
                                                    	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                    
                                                    .. attribute:: best_path_id
                                                    
                                                    	Best path ID; DEPRECATED BYLocalPathId
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: best_path_id_comp_winner
                                                    
                                                    	Path ID of the path which won best path comparison
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: best_path_orr_bitfield
                                                    
                                                    	ORR Best path Bitfields
                                                    	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                    
                                                    .. attribute:: bgp_prefix
                                                    
                                                    	BGP prefix
                                                    	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix>`
                                                    
                                                    .. attribute:: dampen_penalty
                                                    
                                                    	Dampening penalty
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Mvpn Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                    
                                                    .. attribute:: fspec_invalid_path
                                                    
                                                    	Is Fspec invalid path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: graceful_shutdown
                                                    
                                                    	Marked for graceful shutdown
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: gw_addr
                                                    
                                                    	Path GW Address
                                                    	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.GwAddr>`
                                                    
                                                    .. attribute:: halflife_time
                                                    
                                                    	Half\-life time for the penalty
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_esi
                                                    
                                                    	Path has EVPN ESI
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_gw_addr
                                                    
                                                    	Path has GW Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_local_net_label
                                                    
                                                    	Path has local label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mdt_group_addr
                                                    
                                                    	Path has MDT Group Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_extcomm
                                                    
                                                    	Path has MVPN EXTCOMM feedback
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_nbr_addr
                                                    
                                                    	Path has Mvpn nbr Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_nexthop_addr
                                                    
                                                    	Path has MVPN nexthop Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_pmsi
                                                    
                                                    	Path has MVPN PMSI feedback
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_rcvd_label
                                                    
                                                    	Path has received label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_second_label
                                                    
                                                    	Path has second received label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ibgp_signaled_validity
                                                    
                                                    	IBGP signalled validation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: igp_metric
                                                    
                                                    	IGP metric to the gateway
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_aggregation_suppressed
                                                    
                                                    	Path suppressed due to aggregation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_best
                                                    
                                                    	Best available path within AS
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_best_path
                                                    
                                                    	Best available path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_import_dampened
                                                    
                                                    	net import dampened
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_import_suspect
                                                    
                                                    	net import suspect
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_internal_path
                                                    
                                                    	Received over an internal link
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_best
                                                    
                                                    	Partial best path within distributed speaker
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_additional_path
                                                    
                                                    	Path is an additional\-path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_advertised_local_as_only
                                                    
                                                    	Not advertised outside local AS
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_af_install_eligible
                                                    
                                                    	Path can be installed in AF RIB
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_backup
                                                    
                                                    	Path is a backup path 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_backup_protect_multipath
                                                    
                                                    	Path is a backup path to protect multipaths
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_best_external
                                                    
                                                    	Path is a best external path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_damped
                                                    
                                                    	Path suppressed due to dampening
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_confederation_peer
                                                    
                                                    	Path received from confederation peer
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_network_command
                                                    
                                                    	Path sourced by network command
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_redistribute_command
                                                    
                                                    	Path sourced by redistribute command
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_route_reflector
                                                    
                                                    	Path received from route reflector
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_history_held
                                                    
                                                    	Path entry held to remember history
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_imp_candidate
                                                    
                                                    	Path is a candidate for multipath import
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_imported
                                                    
                                                    	Path is imported
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_local_aggregate
                                                    
                                                    	Path is a locally created aggregate
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_locally_sourced
                                                    
                                                    	Path sourced locally
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_long_lived_stale
                                                    
                                                    	Long lived stale routes learnt before neighbor restarts
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_multipath
                                                    
                                                    	Path is one of multipath best routes
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_nexthop_discarded
                                                    
                                                    	Path is redirected to Null0
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_not_advertised
                                                    
                                                    	Not advertised to any peer
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_not_advertised_to_ebg_ps
                                                    
                                                    	Not advertised to EBGPs
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_received_only
                                                    
                                                    	Path is received only
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_reoriginated
                                                    
                                                    	Path is reoriginated
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_reoriginated_stitching
                                                    
                                                    	Path is reoriginated with stitching RTs
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_stale
                                                    
                                                    	Stale routes learnt before neighbor restarts
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_synced_with_igp
                                                    
                                                    	Path synchronized with IGP
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_valid
                                                    
                                                    	Path attributes are usable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_vpn_only
                                                    
                                                    	Path is not in the vrf
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_permanent_path
                                                    
                                                    	Path is of type Permanent path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_received_path_not_modified
                                                    
                                                    	Received path used without modification
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_spkr_as_best
                                                    
                                                    	Best available path within AS in speaker
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2vpn_circuit_status_value
                                                    
                                                    	L2VPN Circuit Status Value
                                                    	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                    
                                                    .. attribute:: l2vpn_evpn_esi
                                                    
                                                    	L2VPN EVPN ESI
                                                    	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi>`
                                                    
                                                    .. attribute:: l2vpn_size
                                                    
                                                    	Path block size
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: labeled_unicast_safi_path
                                                    
                                                    	Path was learnt by labeled\-unicast SAFI
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: local_label
                                                    
                                                    	Path local label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_nh
                                                    
                                                    	Path has local nexthop
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: local_path_id
                                                    
                                                    	Local path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_peers_advertised_to
                                                    
                                                    	Local peers that this prefix has been advertised to
                                                    	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                    
                                                    .. attribute:: maximum_suppress_time
                                                    
                                                    	Maximum duration to suppress a stable route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mdt_group_addr
                                                    
                                                    	IPv4 MDT Group Address for the path
                                                    	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                    
                                                    .. attribute:: mvpn_nbr_addr
                                                    
                                                    	Mvpn nbr Address for the path
                                                    	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                    
                                                    .. attribute:: mvpn_nexthop_addr
                                                    
                                                    	Mvpn nexthop Address for the path
                                                    	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                    
                                                    .. attribute:: mvpn_path_flags
                                                    
                                                    	Mvpn path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: mvpn_pmsi_flags
                                                    
                                                    	Mvpn PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: mvpn_pmsi_label
                                                    
                                                    	Mvpn PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mvpn_pmsi_type
                                                    
                                                    	Mvpn PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: mvpn_pmsi_value
                                                    
                                                    	Mvpn PMSI Value
                                                    	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                    
                                                    .. attribute:: mvpn_sfs_path
                                                    
                                                    	Is MVPN single forwarder PE path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress>`
                                                    
                                                    .. attribute:: neighbor_router_id
                                                    
                                                    	Router ID of the neighbor for the path
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: next_hop
                                                    
                                                    	Next hop
                                                    	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop>`
                                                    
                                                    .. attribute:: nhte_tunnel
                                                    
                                                    	NH TE tunnel information
                                                    	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhteTunnel>`
                                                    
                                                    .. attribute:: path_flags
                                                    
                                                    	Flags associated with path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: path_flap_count
                                                    
                                                    	Number of times this route has flapped
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_import_flags
                                                    
                                                    	Path import flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_rt_set_id
                                                    
                                                    	RT\-set id of the path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_rt_set_route_count
                                                    
                                                    	Count in RT\-set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_table_version
                                                    
                                                    	Table version # for pelem
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_weight
                                                    
                                                    	Weight for the path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pe_peers_advertised_to
                                                    
                                                    	PE peers that this prefix has been advertised to
                                                    	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                    
                                                    .. attribute:: rcvd_label
                                                    
                                                    	Path received label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rcvd_path_id
                                                    
                                                    	Received path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: reuse_value
                                                    
                                                    	Value to start reusing a route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rib_failed
                                                    
                                                    	Is net failed installed                          in RIB
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: route_type
                                                    
                                                    	Route Type of path
                                                    	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                                    
                                                    .. attribute:: rpki_origin_as_validation_disabled
                                                    
                                                    	RPKI originAS V. Disabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rt_set_limit_enabled
                                                    
                                                    	Path subject to RT\-set net limit
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_label
                                                    
                                                    	Path second received label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: seconds_since_first_flap
                                                    
                                                    	Seconds since route first flapped
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: show_rpki_origin_as_validity
                                                    
                                                    	Display validity state ?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: sn_rpki_origin_as_validity
                                                    
                                                    	RPKI origin validation state
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: suppress_penalty
                                                    
                                                    	Value to start suppressing a route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: time_to_unsuppress
                                                    
                                                    	Seconds until route is unsuppressed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.accept_own_path = None
                                                        self.accept_own_self_originated_p_ath = None
                                                        self.add_path_orr_bitfield = YList()
                                                        self.add_path_orr_bitfield.parent = self
                                                        self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                        self.advertisedto_pe = None
                                                        self.aigp_metric = None
                                                        self.best_path_comp_stage = None
                                                        self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner()
                                                        self.best_path_comp_winner.parent = self
                                                        self.best_path_id = None
                                                        self.best_path_id_comp_winner = None
                                                        self.best_path_orr_bitfield = YList()
                                                        self.best_path_orr_bitfield.parent = self
                                                        self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                        self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix()
                                                        self.bgp_prefix.parent = self
                                                        self.dampen_penalty = None
                                                        self.extended_community = YList()
                                                        self.extended_community.parent = self
                                                        self.extended_community.name = 'extended_community'
                                                        self.fspec_invalid_path = None
                                                        self.graceful_shutdown = None
                                                        self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.GwAddr()
                                                        self.gw_addr.parent = self
                                                        self.halflife_time = None
                                                        self.has_esi = None
                                                        self.has_gw_addr = None
                                                        self.has_local_net_label = None
                                                        self.has_mdt_group_addr = None
                                                        self.has_mvpn_extcomm = None
                                                        self.has_mvpn_nbr_addr = None
                                                        self.has_mvpn_nexthop_addr = None
                                                        self.has_mvpn_pmsi = None
                                                        self.has_rcvd_label = None
                                                        self.has_second_label = None
                                                        self.ibgp_signaled_validity = None
                                                        self.igp_metric = None
                                                        self.is_aggregation_suppressed = None
                                                        self.is_as_best = None
                                                        self.is_best_path = None
                                                        self.is_import_dampened = None
                                                        self.is_import_suspect = None
                                                        self.is_internal_path = None
                                                        self.is_partial_best = None
                                                        self.is_path_additional_path = None
                                                        self.is_path_advertised_local_as_only = None
                                                        self.is_path_af_install_eligible = None
                                                        self.is_path_backup = None
                                                        self.is_path_backup_protect_multipath = None
                                                        self.is_path_best_external = None
                                                        self.is_path_damped = None
                                                        self.is_path_from_confederation_peer = None
                                                        self.is_path_from_network_command = None
                                                        self.is_path_from_redistribute_command = None
                                                        self.is_path_from_route_reflector = None
                                                        self.is_path_history_held = None
                                                        self.is_path_imp_candidate = None
                                                        self.is_path_imported = None
                                                        self.is_path_local_aggregate = None
                                                        self.is_path_locally_sourced = None
                                                        self.is_path_long_lived_stale = None
                                                        self.is_path_multipath = None
                                                        self.is_path_nexthop_discarded = None
                                                        self.is_path_not_advertised = None
                                                        self.is_path_not_advertised_to_ebg_ps = None
                                                        self.is_path_received_only = None
                                                        self.is_path_reoriginated = None
                                                        self.is_path_reoriginated_stitching = None
                                                        self.is_path_stale = None
                                                        self.is_path_synced_with_igp = None
                                                        self.is_path_valid = None
                                                        self.is_path_vpn_only = None
                                                        self.is_permanent_path = None
                                                        self.is_received_path_not_modified = None
                                                        self.is_spkr_as_best = None
                                                        self.l2vpn_circuit_status_value = YList()
                                                        self.l2vpn_circuit_status_value.parent = self
                                                        self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                        self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi()
                                                        self.l2vpn_evpn_esi.parent = self
                                                        self.l2vpn_size = None
                                                        self.labeled_unicast_safi_path = None
                                                        self.local_label = None
                                                        self.local_nh = None
                                                        self.local_path_id = None
                                                        self.local_peers_advertised_to = YList()
                                                        self.local_peers_advertised_to.parent = self
                                                        self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                        self.maximum_suppress_time = None
                                                        self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr()
                                                        self.mdt_group_addr.parent = self
                                                        self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                        self.mvpn_nbr_addr.parent = self
                                                        self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                        self.mvpn_nexthop_addr.parent = self
                                                        self.mvpn_path_flags = None
                                                        self.mvpn_pmsi_flags = None
                                                        self.mvpn_pmsi_label = None
                                                        self.mvpn_pmsi_type = None
                                                        self.mvpn_pmsi_value = YList()
                                                        self.mvpn_pmsi_value.parent = self
                                                        self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                        self.mvpn_sfs_path = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.neighbor_router_id = None
                                                        self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop()
                                                        self.next_hop.parent = self
                                                        self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhteTunnel()
                                                        self.nhte_tunnel.parent = self
                                                        self.path_flags = None
                                                        self.path_flap_count = None
                                                        self.path_import_flags = None
                                                        self.path_rt_set_id = None
                                                        self.path_rt_set_route_count = None
                                                        self.path_table_version = None
                                                        self.path_weight = None
                                                        self.pe_peers_advertised_to = YList()
                                                        self.pe_peers_advertised_to.parent = self
                                                        self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                        self.rcvd_label = None
                                                        self.rcvd_path_id = None
                                                        self.reuse_value = None
                                                        self.rib_failed = None
                                                        self.route_type = None
                                                        self.rpki_origin_as_validation_disabled = None
                                                        self.rt_set_limit_enabled = None
                                                        self.second_label = None
                                                        self.seconds_since_first_flap = None
                                                        self.show_rpki_origin_as_validity = None
                                                        self.sn_rpki_origin_as_validity = None
                                                        self.suppress_penalty = None
                                                        self.time_to_unsuppress = None


                                                    class BgpPrefix(object):
                                                        """
                                                        BGP prefix
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Prefix
                                                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                            self.prefix.parent = self
                                                            self.prefix_length = None


                                                        class Prefix(object):
                                                            """
                                                            Prefix
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.prefix is not None and self.prefix._has_data():
                                                                return True

                                                            if self.prefix_length is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BgpPrefix']['meta_info']


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NeighborAddress']['meta_info']


                                                    class NextHop(object):
                                                        """
                                                        Next hop
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NextHop']['meta_info']


                                                    class NhteTunnel(object):
                                                        """
                                                        NH TE tunnel information
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	Binding label for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_te_tunnel
                                                        
                                                        	NH TE Tunnel info is present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_info_stale
                                                        
                                                        	Tunnel is stale
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_registered
                                                        
                                                        	Tunnel registered flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_up
                                                        
                                                        	Tunnel Up flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: last_tunnel_update
                                                        
                                                        	Time since the last rib update happened
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_if_handle
                                                        
                                                        	Interface handle for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_name
                                                        
                                                        	tunnel name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        .. attribute:: tunnel_type
                                                        
                                                        	tunnel type
                                                        	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                        
                                                        .. attribute:: tunnel_v6_enabled
                                                        
                                                        	IPv6 enabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_v6_required
                                                        
                                                        	Tunnel need IPv6
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.binding_label = None
                                                            self.has_te_tunnel = None
                                                            self.is_tunnel_info_stale = None
                                                            self.is_tunnel_registered = None
                                                            self.is_tunnel_up = None
                                                            self.last_tunnel_update = None
                                                            self.tunnel_if_handle = None
                                                            self.tunnel_name = None
                                                            self.tunnel_type = None
                                                            self.tunnel_v6_enabled = None
                                                            self.tunnel_v6_required = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.binding_label is not None:
                                                                return True

                                                            if self.has_te_tunnel is not None:
                                                                return True

                                                            if self.is_tunnel_info_stale is not None:
                                                                return True

                                                            if self.is_tunnel_registered is not None:
                                                                return True

                                                            if self.is_tunnel_up is not None:
                                                                return True

                                                            if self.last_tunnel_update is not None:
                                                                return True

                                                            if self.tunnel_if_handle is not None:
                                                                return True

                                                            if self.tunnel_name is not None:
                                                                return True

                                                            if self.tunnel_type is not None:
                                                                return True

                                                            if self.tunnel_v6_enabled is not None:
                                                                return True

                                                            if self.tunnel_v6_required is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.NhteTunnel']['meta_info']


                                                    class MdtGroupAddr(object):
                                                        """
                                                        IPv4 MDT Group Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MdtGroupAddr']['meta_info']


                                                    class L2VpnEvpnEsi(object):
                                                        """
                                                        L2VPN EVPN ESI
                                                        
                                                        .. attribute:: esi
                                                        
                                                        	esi
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.esi = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.esi is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.L2VpnEvpnEsi']['meta_info']


                                                    class GwAddr(object):
                                                        """
                                                        Path GW Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_address = None
                                                            self.ipv6_address = None
                                                            self.len = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.len is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.GwAddr']['meta_info']


                                                    class BestPathCompWinner(object):
                                                        """
                                                        Neighbor address of the path which won best path
                                                        comparison
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathCompWinner']['meta_info']


                                                    class MvpnNbrAddr(object):
                                                        """
                                                        Mvpn nbr Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNbrAddr']['meta_info']


                                                    class MvpnNexthopAddr(object):
                                                        """
                                                        Mvpn nexthop Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr']['meta_info']


                                                    class L2VpnCircuitStatusValue(object):
                                                        """
                                                        L2VPN Circuit Status Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                                    class MvpnPmsiValue(object):
                                                        """
                                                        Mvpn PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.MvpnPmsiValue']['meta_info']


                                                    class ExtendedCommunity(object):
                                                        """
                                                        Mvpn Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.ExtendedCommunity']['meta_info']


                                                    class LocalPeersAdvertisedTo(object):
                                                        """
                                                        Local peers that this prefix has been advertised
                                                        to
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.is_neighbor = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.update_group_number = None


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.is_neighbor is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.update_group_number is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                                    class PePeersAdvertisedTo(object):
                                                        """
                                                        PE peers that this prefix has been advertised to
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.is_neighbor = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.update_group_number = None


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.is_neighbor is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.update_group_number is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo']['meta_info']


                                                    class BestPathOrrBitfield(object):
                                                        """
                                                        ORR Best path Bitfields
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.is_neighbor = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.update_group_number = None


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.is_neighbor is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.update_group_number is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield']['meta_info']


                                                    class AddPathOrrBitfield(object):
                                                        """
                                                        ORR Add path Bitfields
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.is_neighbor = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.update_group_number = None


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.is_neighbor is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.update_group_number is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.accept_own_path is not None:
                                                            return True

                                                        if self.accept_own_self_originated_p_ath is not None:
                                                            return True

                                                        if self.add_path_orr_bitfield is not None:
                                                            for child_ref in self.add_path_orr_bitfield:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.advertisedto_pe is not None:
                                                            return True

                                                        if self.aigp_metric is not None:
                                                            return True

                                                        if self.best_path_comp_stage is not None:
                                                            return True

                                                        if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                            return True

                                                        if self.best_path_id is not None:
                                                            return True

                                                        if self.best_path_id_comp_winner is not None:
                                                            return True

                                                        if self.best_path_orr_bitfield is not None:
                                                            for child_ref in self.best_path_orr_bitfield:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                            return True

                                                        if self.dampen_penalty is not None:
                                                            return True

                                                        if self.extended_community is not None:
                                                            for child_ref in self.extended_community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.fspec_invalid_path is not None:
                                                            return True

                                                        if self.graceful_shutdown is not None:
                                                            return True

                                                        if self.gw_addr is not None and self.gw_addr._has_data():
                                                            return True

                                                        if self.halflife_time is not None:
                                                            return True

                                                        if self.has_esi is not None:
                                                            return True

                                                        if self.has_gw_addr is not None:
                                                            return True

                                                        if self.has_local_net_label is not None:
                                                            return True

                                                        if self.has_mdt_group_addr is not None:
                                                            return True

                                                        if self.has_mvpn_extcomm is not None:
                                                            return True

                                                        if self.has_mvpn_nbr_addr is not None:
                                                            return True

                                                        if self.has_mvpn_nexthop_addr is not None:
                                                            return True

                                                        if self.has_mvpn_pmsi is not None:
                                                            return True

                                                        if self.has_rcvd_label is not None:
                                                            return True

                                                        if self.has_second_label is not None:
                                                            return True

                                                        if self.ibgp_signaled_validity is not None:
                                                            return True

                                                        if self.igp_metric is not None:
                                                            return True

                                                        if self.is_aggregation_suppressed is not None:
                                                            return True

                                                        if self.is_as_best is not None:
                                                            return True

                                                        if self.is_best_path is not None:
                                                            return True

                                                        if self.is_import_dampened is not None:
                                                            return True

                                                        if self.is_import_suspect is not None:
                                                            return True

                                                        if self.is_internal_path is not None:
                                                            return True

                                                        if self.is_partial_best is not None:
                                                            return True

                                                        if self.is_path_additional_path is not None:
                                                            return True

                                                        if self.is_path_advertised_local_as_only is not None:
                                                            return True

                                                        if self.is_path_af_install_eligible is not None:
                                                            return True

                                                        if self.is_path_backup is not None:
                                                            return True

                                                        if self.is_path_backup_protect_multipath is not None:
                                                            return True

                                                        if self.is_path_best_external is not None:
                                                            return True

                                                        if self.is_path_damped is not None:
                                                            return True

                                                        if self.is_path_from_confederation_peer is not None:
                                                            return True

                                                        if self.is_path_from_network_command is not None:
                                                            return True

                                                        if self.is_path_from_redistribute_command is not None:
                                                            return True

                                                        if self.is_path_from_route_reflector is not None:
                                                            return True

                                                        if self.is_path_history_held is not None:
                                                            return True

                                                        if self.is_path_imp_candidate is not None:
                                                            return True

                                                        if self.is_path_imported is not None:
                                                            return True

                                                        if self.is_path_local_aggregate is not None:
                                                            return True

                                                        if self.is_path_locally_sourced is not None:
                                                            return True

                                                        if self.is_path_long_lived_stale is not None:
                                                            return True

                                                        if self.is_path_multipath is not None:
                                                            return True

                                                        if self.is_path_nexthop_discarded is not None:
                                                            return True

                                                        if self.is_path_not_advertised is not None:
                                                            return True

                                                        if self.is_path_not_advertised_to_ebg_ps is not None:
                                                            return True

                                                        if self.is_path_received_only is not None:
                                                            return True

                                                        if self.is_path_reoriginated is not None:
                                                            return True

                                                        if self.is_path_reoriginated_stitching is not None:
                                                            return True

                                                        if self.is_path_stale is not None:
                                                            return True

                                                        if self.is_path_synced_with_igp is not None:
                                                            return True

                                                        if self.is_path_valid is not None:
                                                            return True

                                                        if self.is_path_vpn_only is not None:
                                                            return True

                                                        if self.is_permanent_path is not None:
                                                            return True

                                                        if self.is_received_path_not_modified is not None:
                                                            return True

                                                        if self.is_spkr_as_best is not None:
                                                            return True

                                                        if self.l2vpn_circuit_status_value is not None:
                                                            for child_ref in self.l2vpn_circuit_status_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                            return True

                                                        if self.l2vpn_size is not None:
                                                            return True

                                                        if self.labeled_unicast_safi_path is not None:
                                                            return True

                                                        if self.local_label is not None:
                                                            return True

                                                        if self.local_nh is not None:
                                                            return True

                                                        if self.local_path_id is not None:
                                                            return True

                                                        if self.local_peers_advertised_to is not None:
                                                            for child_ref in self.local_peers_advertised_to:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.maximum_suppress_time is not None:
                                                            return True

                                                        if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                            return True

                                                        if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                            return True

                                                        if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                            return True

                                                        if self.mvpn_path_flags is not None:
                                                            return True

                                                        if self.mvpn_pmsi_flags is not None:
                                                            return True

                                                        if self.mvpn_pmsi_label is not None:
                                                            return True

                                                        if self.mvpn_pmsi_type is not None:
                                                            return True

                                                        if self.mvpn_pmsi_value is not None:
                                                            for child_ref in self.mvpn_pmsi_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.mvpn_sfs_path is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.neighbor_router_id is not None:
                                                            return True

                                                        if self.next_hop is not None and self.next_hop._has_data():
                                                            return True

                                                        if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                            return True

                                                        if self.path_flags is not None:
                                                            return True

                                                        if self.path_flap_count is not None:
                                                            return True

                                                        if self.path_import_flags is not None:
                                                            return True

                                                        if self.path_rt_set_id is not None:
                                                            return True

                                                        if self.path_rt_set_route_count is not None:
                                                            return True

                                                        if self.path_table_version is not None:
                                                            return True

                                                        if self.path_weight is not None:
                                                            return True

                                                        if self.pe_peers_advertised_to is not None:
                                                            for child_ref in self.pe_peers_advertised_to:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.rcvd_label is not None:
                                                            return True

                                                        if self.rcvd_path_id is not None:
                                                            return True

                                                        if self.reuse_value is not None:
                                                            return True

                                                        if self.rib_failed is not None:
                                                            return True

                                                        if self.route_type is not None:
                                                            return True

                                                        if self.rpki_origin_as_validation_disabled is not None:
                                                            return True

                                                        if self.rt_set_limit_enabled is not None:
                                                            return True

                                                        if self.second_label is not None:
                                                            return True

                                                        if self.seconds_since_first_flap is not None:
                                                            return True

                                                        if self.show_rpki_origin_as_validity is not None:
                                                            return True

                                                        if self.sn_rpki_origin_as_validity is not None:
                                                            return True

                                                        if self.suppress_penalty is not None:
                                                            return True

                                                        if self.time_to_unsuppress is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.PathInformation']['meta_info']


                                                class AttributesAfterPolicyIn(object):
                                                    """
                                                    Attributes after inbound policy applied
                                                    
                                                    .. attribute:: attr_set
                                                    
                                                    	ATTR\_SET attribute
                                                    	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                    
                                                    .. attribute:: attribute_key_number
                                                    
                                                    	Attribute key number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_config
                                                    
                                                    	Attribute reuse ID Configured
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: attribute_reuse_id_current
                                                    
                                                    	Attribute reuse ID current ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_keys
                                                    
                                                    	Attribute reuse ID allocated keys
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_max_id
                                                    
                                                    	Attribute reuse ID maximum ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_node
                                                    
                                                    	Attribute reuse ID nodes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_recover_sec
                                                    
                                                    	Attribute reuse ID timer in seconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: common_attributes
                                                    
                                                    	Common attributes
                                                    	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                    
                                                    .. attribute:: is_application_gateway_present
                                                    
                                                    	Application gateway present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path2_byte
                                                    
                                                    	AS path encoded as 2\-byte
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_attr_set_present
                                                    
                                                    	BGP ATTR\_SET attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ribrnh_present
                                                    
                                                    	RIB RNH Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_rnh_present
                                                    
                                                    	RNH Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ribrnh_encap
                                                    
                                                    	RIB RNH Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ribrnh_ip
                                                    
                                                    	RIB RNH IP Address
                                                    	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                    
                                                    .. attribute:: ribrnh_mac
                                                    
                                                    	RIB RNH MAC Address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    .. attribute:: ribrnh_table
                                                    
                                                    	RIB RNH Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ribrnh_vni
                                                    
                                                    	RIB RNH Vni
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ribrnhip_table
                                                    
                                                    	RIB RNH IP Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rnh_addr
                                                    
                                                    	RNH Address
                                                    	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                    
                                                    .. attribute:: rnh_addr_len
                                                    
                                                    	RNH Address Length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rnh_len
                                                    
                                                    	RNH Length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: rnh_type
                                                    
                                                    	RNH Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: set_aigp_inbound_igp
                                                    
                                                    	AIGP set by policy inbound IGP 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: set_aigp_inbound_metric
                                                    
                                                    	AIGP set by policy inbound metric
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: vpn_distinguisher
                                                    
                                                    	VPN Distinguisher
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                        self.attr_set.parent = self
                                                        self.attribute_key_number = None
                                                        self.attribute_reuse_id_config = None
                                                        self.attribute_reuse_id_current = None
                                                        self.attribute_reuse_id_keys = None
                                                        self.attribute_reuse_id_max_id = None
                                                        self.attribute_reuse_id_node = None
                                                        self.attribute_reuse_id_recover_sec = None
                                                        self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                        self.common_attributes.parent = self
                                                        self.is_application_gateway_present = None
                                                        self.is_as_path2_byte = None
                                                        self.is_attr_set_present = None
                                                        self.is_ribrnh_present = None
                                                        self.is_rnh_present = None
                                                        self.ribrnh_encap = None
                                                        self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                        self.ribrnh_ip.parent = self
                                                        self.ribrnh_mac = None
                                                        self.ribrnh_table = None
                                                        self.ribrnh_vni = None
                                                        self.ribrnhip_table = None
                                                        self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                        self.rnh_addr.parent = self
                                                        self.rnh_addr_len = None
                                                        self.rnh_len = None
                                                        self.rnh_type = None
                                                        self.set_aigp_inbound_igp = None
                                                        self.set_aigp_inbound_metric = None
                                                        self.vpn_distinguisher = None


                                                    class CommonAttributes(object):
                                                        """
                                                        Common attributes
                                                        
                                                        .. attribute:: aggregator_address
                                                        
                                                        	Address where aggregation was performed
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: aggregator_as
                                                        
                                                        	AS where aggregation was last performed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: aigp_metric_value
                                                        
                                                        	AIGP metric value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: as_path
                                                        
                                                        	AS path attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: cluster
                                                        
                                                        	Cluster list attribute
                                                        	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                        
                                                        .. attribute:: community
                                                        
                                                        	Community attribute
                                                        	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                        
                                                        .. attribute:: connector_type
                                                        
                                                        	Connector Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: connector_value
                                                        
                                                        	Connector Value
                                                        	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                        
                                                        .. attribute:: extended_community_flags
                                                        
                                                        	Extended community Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: is_aggregator_present
                                                        
                                                        	Aggregator attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_aigp_present
                                                        
                                                        	AIGP Present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path_present
                                                        
                                                        	AS path attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_atomic_aggregate_present
                                                        
                                                        	Atomic aggregate attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_community_present
                                                        
                                                        	Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_connector_present
                                                        
                                                        	Connector present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_extended_community_present
                                                        
                                                        	Extended community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_label_index_present
                                                        
                                                        	Label Index attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_local_pref_present
                                                        
                                                        	Local Preference attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ls_attribute_present
                                                        
                                                        	BGP LS attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_metric_present
                                                        
                                                        	Metric attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_origin_present
                                                        
                                                        	Origin attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pe_distinguisher_label_present
                                                        
                                                        	PE distinguisher label  attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pmsi_present
                                                        
                                                        	PMSI Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pppmp_present
                                                        
                                                        	PPMP Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ssa_present
                                                        
                                                        	SSA attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_encap_present
                                                        
                                                        	Tunnel Encap attribute present 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2tpv3_cookie
                                                        
                                                        	L2TPv3 Cookie
                                                        	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                        
                                                        .. attribute:: l2tpv3_session_id
                                                        
                                                        	L2TPv3 session id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: label_index_attr
                                                        
                                                        	Label Index attribute
                                                        	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                        
                                                        .. attribute:: local_preference
                                                        
                                                        	Local preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ls_attr
                                                        
                                                        	BGP LS attribute
                                                        	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: neighbor_as
                                                        
                                                        	Neighbor AS number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: origin
                                                        
                                                        	Origin
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: originator
                                                        
                                                        	Originator attribute
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: pe_distinguisher_label
                                                        
                                                        	PE distinguisher label attribute
                                                        	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                        
                                                        .. attribute:: pmsi_flags
                                                        
                                                        	PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pmsi_label
                                                        
                                                        	PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pmsi_type
                                                        
                                                        	PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pmsi_value
                                                        
                                                        	PMSI Value
                                                        	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                        
                                                        .. attribute:: ppm_pvalue
                                                        
                                                        	PPMP Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: sr_policy_allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                        
                                                        .. attribute:: sr_policy_binding_sid
                                                        
                                                        	SR Policy Binding sid
                                                        	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                        
                                                        .. attribute:: sr_policy_explicit_path
                                                        
                                                        	SR Policy Explicit paths
                                                        	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                        
                                                        .. attribute:: sr_policy_preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: sr_tunnel_request_state
                                                        
                                                        	SR Tunnel Request State
                                                        	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                        
                                                        .. attribute:: sr_tunnel_state
                                                        
                                                        	SR Tunnel State
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encap Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: unknown_attribute
                                                        
                                                        	Unknown attributes
                                                        	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.aggregator_address = None
                                                            self.aggregator_as = None
                                                            self.aigp_metric_value = None
                                                            self.as_path = None
                                                            self.cluster = YList()
                                                            self.cluster.parent = self
                                                            self.cluster.name = 'cluster'
                                                            self.community = YList()
                                                            self.community.parent = self
                                                            self.community.name = 'community'
                                                            self.connector_type = None
                                                            self.connector_value = YList()
                                                            self.connector_value.parent = self
                                                            self.connector_value.name = 'connector_value'
                                                            self.extended_community = YList()
                                                            self.extended_community.parent = self
                                                            self.extended_community.name = 'extended_community'
                                                            self.extended_community_flags = None
                                                            self.is_aggregator_present = None
                                                            self.is_aigp_present = None
                                                            self.is_as_path_present = None
                                                            self.is_atomic_aggregate_present = None
                                                            self.is_community_present = None
                                                            self.is_connector_present = None
                                                            self.is_extended_community_present = None
                                                            self.is_label_index_present = None
                                                            self.is_local_pref_present = None
                                                            self.is_ls_attribute_present = None
                                                            self.is_metric_present = None
                                                            self.is_origin_present = None
                                                            self.is_pe_distinguisher_label_present = None
                                                            self.is_pmsi_present = None
                                                            self.is_pppmp_present = None
                                                            self.is_ssa_present = None
                                                            self.is_tunnel_encap_present = None
                                                            self.l2tpv3_cookie = YList()
                                                            self.l2tpv3_cookie.parent = self
                                                            self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                            self.l2tpv3_session_id = None
                                                            self.label_index_attr = YList()
                                                            self.label_index_attr.parent = self
                                                            self.label_index_attr.name = 'label_index_attr'
                                                            self.local_preference = None
                                                            self.ls_attr = YList()
                                                            self.ls_attr.parent = self
                                                            self.ls_attr.name = 'ls_attr'
                                                            self.metric = None
                                                            self.neighbor_as = None
                                                            self.origin = None
                                                            self.originator = None
                                                            self.pe_distinguisher_label = YList()
                                                            self.pe_distinguisher_label.parent = self
                                                            self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                            self.pmsi_flags = None
                                                            self.pmsi_label = None
                                                            self.pmsi_type = None
                                                            self.pmsi_value = YList()
                                                            self.pmsi_value.parent = self
                                                            self.pmsi_value.name = 'pmsi_value'
                                                            self.ppm_pvalue = None
                                                            self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                            self.sr_policy_allocated_binding_sid.parent = self
                                                            self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                            self.sr_policy_binding_sid.parent = self
                                                            self.sr_policy_explicit_path = YList()
                                                            self.sr_policy_explicit_path.parent = self
                                                            self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                            self.sr_policy_preference = None
                                                            self.sr_tunnel_request_state = None
                                                            self.sr_tunnel_state = None
                                                            self.tunnel_encap_type = None
                                                            self.unknown_attribute = YList()
                                                            self.unknown_attribute.parent = self
                                                            self.unknown_attribute.name = 'unknown_attribute'


                                                        class SrPolicyBindingSid(object):
                                                            """
                                                            SR Policy Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_address = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                        class SrPolicyAllocatedBindingSid(object):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_address = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                        class Community(object):
                                                            """
                                                            Community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                        class ExtendedCommunity(object):
                                                            """
                                                            Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                        class UnknownAttribute(object):
                                                            """
                                                            Unknown attributes
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                        class Cluster(object):
                                                            """
                                                            Cluster list attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                        class L2Tpv3Cookie(object):
                                                            """
                                                            L2TPv3 Cookie
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                        class ConnectorValue(object):
                                                            """
                                                            Connector Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                        class PmsiValue(object):
                                                            """
                                                            PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                        class LsAttr(object):
                                                            """
                                                            BGP LS attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                        class LabelIndexAttr(object):
                                                            """
                                                            Label Index attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                        class PeDistinguisherLabel(object):
                                                            """
                                                            PE distinguisher label attribute
                                                            
                                                            .. attribute:: label
                                                            
                                                            	Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pe_address
                                                            
                                                            	 PE address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.label = None
                                                                self.pe_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.label is not None:
                                                                    return True

                                                                if self.pe_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                        class SrPolicyExplicitPath(object):
                                                            """
                                                            SR Policy Explicit paths
                                                            
                                                            .. attribute:: sid
                                                            
                                                            	Sidlist for explicit path
                                                            	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of explicit path
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.sid = YList()
                                                                self.sid.parent = self
                                                                self.sid.name = 'sid'
                                                                self.weight = None


                                                            class Sid(object):
                                                                """
                                                                Sidlist for explicit path
                                                                
                                                                .. attribute:: ipv4
                                                                
                                                                	IP Address sid
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6
                                                                
                                                                	IPv6 address sid
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label sid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Sid Type
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4 = None
                                                                    self.ipv6 = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4 is not None:
                                                                        return True

                                                                    if self.ipv6 is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.sid is not None:
                                                                    for child_ref in self.sid:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.weight is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.aggregator_address is not None:
                                                                return True

                                                            if self.aggregator_as is not None:
                                                                return True

                                                            if self.aigp_metric_value is not None:
                                                                return True

                                                            if self.as_path is not None:
                                                                return True

                                                            if self.cluster is not None:
                                                                for child_ref in self.cluster:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.community is not None:
                                                                for child_ref in self.community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.connector_type is not None:
                                                                return True

                                                            if self.connector_value is not None:
                                                                for child_ref in self.connector_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.extended_community is not None:
                                                                for child_ref in self.extended_community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.extended_community_flags is not None:
                                                                return True

                                                            if self.is_aggregator_present is not None:
                                                                return True

                                                            if self.is_aigp_present is not None:
                                                                return True

                                                            if self.is_as_path_present is not None:
                                                                return True

                                                            if self.is_atomic_aggregate_present is not None:
                                                                return True

                                                            if self.is_community_present is not None:
                                                                return True

                                                            if self.is_connector_present is not None:
                                                                return True

                                                            if self.is_extended_community_present is not None:
                                                                return True

                                                            if self.is_label_index_present is not None:
                                                                return True

                                                            if self.is_local_pref_present is not None:
                                                                return True

                                                            if self.is_ls_attribute_present is not None:
                                                                return True

                                                            if self.is_metric_present is not None:
                                                                return True

                                                            if self.is_origin_present is not None:
                                                                return True

                                                            if self.is_pe_distinguisher_label_present is not None:
                                                                return True

                                                            if self.is_pmsi_present is not None:
                                                                return True

                                                            if self.is_pppmp_present is not None:
                                                                return True

                                                            if self.is_ssa_present is not None:
                                                                return True

                                                            if self.is_tunnel_encap_present is not None:
                                                                return True

                                                            if self.l2tpv3_cookie is not None:
                                                                for child_ref in self.l2tpv3_cookie:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.l2tpv3_session_id is not None:
                                                                return True

                                                            if self.label_index_attr is not None:
                                                                for child_ref in self.label_index_attr:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.local_preference is not None:
                                                                return True

                                                            if self.ls_attr is not None:
                                                                for child_ref in self.ls_attr:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.neighbor_as is not None:
                                                                return True

                                                            if self.origin is not None:
                                                                return True

                                                            if self.originator is not None:
                                                                return True

                                                            if self.pe_distinguisher_label is not None:
                                                                for child_ref in self.pe_distinguisher_label:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.pmsi_flags is not None:
                                                                return True

                                                            if self.pmsi_label is not None:
                                                                return True

                                                            if self.pmsi_type is not None:
                                                                return True

                                                            if self.pmsi_value is not None:
                                                                for child_ref in self.pmsi_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.ppm_pvalue is not None:
                                                                return True

                                                            if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                                return True

                                                            if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                                return True

                                                            if self.sr_policy_explicit_path is not None:
                                                                for child_ref in self.sr_policy_explicit_path:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.sr_policy_preference is not None:
                                                                return True

                                                            if self.sr_tunnel_request_state is not None:
                                                                return True

                                                            if self.sr_tunnel_state is not None:
                                                                return True

                                                            if self.tunnel_encap_type is not None:
                                                                return True

                                                            if self.unknown_attribute is not None:
                                                                for child_ref in self.unknown_attribute:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                                    class AttrSet(object):
                                                        """
                                                        ATTR\_SET attribute
                                                        
                                                        .. attribute:: aggregator_address
                                                        
                                                        	Address where aggregation was performed
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: aggregator_as
                                                        
                                                        	AS where aggregation was last performed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: aigp_metric_value
                                                        
                                                        	AIGP metric value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: as_path
                                                        
                                                        	AS path attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: cluster
                                                        
                                                        	Cluster list attribute
                                                        	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                        
                                                        .. attribute:: community
                                                        
                                                        	Community attribute
                                                        	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                        
                                                        .. attribute:: connector_type
                                                        
                                                        	Connector Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: connector_value
                                                        
                                                        	Connector Value
                                                        	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                        
                                                        .. attribute:: extended_community_flags
                                                        
                                                        	Extended community Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: is_aggregator_present
                                                        
                                                        	Aggregator attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_aigp_present
                                                        
                                                        	AIGP Present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path_present
                                                        
                                                        	AS path attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_atomic_aggregate_present
                                                        
                                                        	Atomic aggregate attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_community_present
                                                        
                                                        	Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_connector_present
                                                        
                                                        	Connector present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_extended_community_present
                                                        
                                                        	Extended community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_label_index_present
                                                        
                                                        	Label Index attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_local_pref_present
                                                        
                                                        	Local Preference attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ls_attribute_present
                                                        
                                                        	BGP LS attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_metric_present
                                                        
                                                        	Metric attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_origin_present
                                                        
                                                        	Origin attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pe_distinguisher_label_present
                                                        
                                                        	PE distinguisher label  attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pmsi_present
                                                        
                                                        	PMSI Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pppmp_present
                                                        
                                                        	PPMP Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ssa_present
                                                        
                                                        	SSA attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_encap_present
                                                        
                                                        	Tunnel Encap attribute present 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2tpv3_cookie
                                                        
                                                        	L2TPv3 Cookie
                                                        	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                        
                                                        .. attribute:: l2tpv3_session_id
                                                        
                                                        	L2TPv3 session id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: label_index_attr
                                                        
                                                        	Label Index attribute
                                                        	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                        
                                                        .. attribute:: local_preference
                                                        
                                                        	Local preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ls_attr
                                                        
                                                        	BGP LS attribute
                                                        	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: neighbor_as
                                                        
                                                        	Neighbor AS number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: origin
                                                        
                                                        	Origin
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: originator
                                                        
                                                        	Originator attribute
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: pe_distinguisher_label
                                                        
                                                        	PE distinguisher label attribute
                                                        	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                        
                                                        .. attribute:: pmsi_flags
                                                        
                                                        	PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pmsi_label
                                                        
                                                        	PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pmsi_type
                                                        
                                                        	PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pmsi_value
                                                        
                                                        	PMSI Value
                                                        	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                        
                                                        .. attribute:: ppm_pvalue
                                                        
                                                        	PPMP Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: sr_policy_allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                        
                                                        .. attribute:: sr_policy_binding_sid
                                                        
                                                        	SR Policy Binding sid
                                                        	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                        
                                                        .. attribute:: sr_policy_explicit_path
                                                        
                                                        	SR Policy Explicit paths
                                                        	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                        
                                                        .. attribute:: sr_policy_preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: sr_tunnel_request_state
                                                        
                                                        	SR Tunnel Request State
                                                        	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                        
                                                        .. attribute:: sr_tunnel_state
                                                        
                                                        	SR Tunnel State
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encap Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: unknown_attribute
                                                        
                                                        	Unknown attributes
                                                        	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.aggregator_address = None
                                                            self.aggregator_as = None
                                                            self.aigp_metric_value = None
                                                            self.as_path = None
                                                            self.cluster = YList()
                                                            self.cluster.parent = self
                                                            self.cluster.name = 'cluster'
                                                            self.community = YList()
                                                            self.community.parent = self
                                                            self.community.name = 'community'
                                                            self.connector_type = None
                                                            self.connector_value = YList()
                                                            self.connector_value.parent = self
                                                            self.connector_value.name = 'connector_value'
                                                            self.extended_community = YList()
                                                            self.extended_community.parent = self
                                                            self.extended_community.name = 'extended_community'
                                                            self.extended_community_flags = None
                                                            self.is_aggregator_present = None
                                                            self.is_aigp_present = None
                                                            self.is_as_path_present = None
                                                            self.is_atomic_aggregate_present = None
                                                            self.is_community_present = None
                                                            self.is_connector_present = None
                                                            self.is_extended_community_present = None
                                                            self.is_label_index_present = None
                                                            self.is_local_pref_present = None
                                                            self.is_ls_attribute_present = None
                                                            self.is_metric_present = None
                                                            self.is_origin_present = None
                                                            self.is_pe_distinguisher_label_present = None
                                                            self.is_pmsi_present = None
                                                            self.is_pppmp_present = None
                                                            self.is_ssa_present = None
                                                            self.is_tunnel_encap_present = None
                                                            self.l2tpv3_cookie = YList()
                                                            self.l2tpv3_cookie.parent = self
                                                            self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                            self.l2tpv3_session_id = None
                                                            self.label_index_attr = YList()
                                                            self.label_index_attr.parent = self
                                                            self.label_index_attr.name = 'label_index_attr'
                                                            self.local_preference = None
                                                            self.ls_attr = YList()
                                                            self.ls_attr.parent = self
                                                            self.ls_attr.name = 'ls_attr'
                                                            self.metric = None
                                                            self.neighbor_as = None
                                                            self.origin = None
                                                            self.originator = None
                                                            self.pe_distinguisher_label = YList()
                                                            self.pe_distinguisher_label.parent = self
                                                            self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                            self.pmsi_flags = None
                                                            self.pmsi_label = None
                                                            self.pmsi_type = None
                                                            self.pmsi_value = YList()
                                                            self.pmsi_value.parent = self
                                                            self.pmsi_value.name = 'pmsi_value'
                                                            self.ppm_pvalue = None
                                                            self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                            self.sr_policy_allocated_binding_sid.parent = self
                                                            self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                            self.sr_policy_binding_sid.parent = self
                                                            self.sr_policy_explicit_path = YList()
                                                            self.sr_policy_explicit_path.parent = self
                                                            self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                            self.sr_policy_preference = None
                                                            self.sr_tunnel_request_state = None
                                                            self.sr_tunnel_state = None
                                                            self.tunnel_encap_type = None
                                                            self.unknown_attribute = YList()
                                                            self.unknown_attribute.parent = self
                                                            self.unknown_attribute.name = 'unknown_attribute'


                                                        class SrPolicyBindingSid(object):
                                                            """
                                                            SR Policy Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_address = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                        class SrPolicyAllocatedBindingSid(object):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_address = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                        class Community(object):
                                                            """
                                                            Community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                        class ExtendedCommunity(object):
                                                            """
                                                            Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                        class UnknownAttribute(object):
                                                            """
                                                            Unknown attributes
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                        class Cluster(object):
                                                            """
                                                            Cluster list attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                        class L2Tpv3Cookie(object):
                                                            """
                                                            L2TPv3 Cookie
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                        class ConnectorValue(object):
                                                            """
                                                            Connector Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                        class PmsiValue(object):
                                                            """
                                                            PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                        class LsAttr(object):
                                                            """
                                                            BGP LS attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                        class LabelIndexAttr(object):
                                                            """
                                                            Label Index attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                        class PeDistinguisherLabel(object):
                                                            """
                                                            PE distinguisher label attribute
                                                            
                                                            .. attribute:: label
                                                            
                                                            	Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pe_address
                                                            
                                                            	 PE address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.label = None
                                                                self.pe_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.label is not None:
                                                                    return True

                                                                if self.pe_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                        class SrPolicyExplicitPath(object):
                                                            """
                                                            SR Policy Explicit paths
                                                            
                                                            .. attribute:: sid
                                                            
                                                            	Sidlist for explicit path
                                                            	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of explicit path
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.sid = YList()
                                                                self.sid.parent = self
                                                                self.sid.name = 'sid'
                                                                self.weight = None


                                                            class Sid(object):
                                                                """
                                                                Sidlist for explicit path
                                                                
                                                                .. attribute:: ipv4
                                                                
                                                                	IP Address sid
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6
                                                                
                                                                	IPv6 address sid
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label sid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Sid Type
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4 = None
                                                                    self.ipv6 = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4 is not None:
                                                                        return True

                                                                    if self.ipv6 is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.sid is not None:
                                                                    for child_ref in self.sid:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.weight is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.aggregator_address is not None:
                                                                return True

                                                            if self.aggregator_as is not None:
                                                                return True

                                                            if self.aigp_metric_value is not None:
                                                                return True

                                                            if self.as_path is not None:
                                                                return True

                                                            if self.cluster is not None:
                                                                for child_ref in self.cluster:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.community is not None:
                                                                for child_ref in self.community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.connector_type is not None:
                                                                return True

                                                            if self.connector_value is not None:
                                                                for child_ref in self.connector_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.extended_community is not None:
                                                                for child_ref in self.extended_community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.extended_community_flags is not None:
                                                                return True

                                                            if self.is_aggregator_present is not None:
                                                                return True

                                                            if self.is_aigp_present is not None:
                                                                return True

                                                            if self.is_as_path_present is not None:
                                                                return True

                                                            if self.is_atomic_aggregate_present is not None:
                                                                return True

                                                            if self.is_community_present is not None:
                                                                return True

                                                            if self.is_connector_present is not None:
                                                                return True

                                                            if self.is_extended_community_present is not None:
                                                                return True

                                                            if self.is_label_index_present is not None:
                                                                return True

                                                            if self.is_local_pref_present is not None:
                                                                return True

                                                            if self.is_ls_attribute_present is not None:
                                                                return True

                                                            if self.is_metric_present is not None:
                                                                return True

                                                            if self.is_origin_present is not None:
                                                                return True

                                                            if self.is_pe_distinguisher_label_present is not None:
                                                                return True

                                                            if self.is_pmsi_present is not None:
                                                                return True

                                                            if self.is_pppmp_present is not None:
                                                                return True

                                                            if self.is_ssa_present is not None:
                                                                return True

                                                            if self.is_tunnel_encap_present is not None:
                                                                return True

                                                            if self.l2tpv3_cookie is not None:
                                                                for child_ref in self.l2tpv3_cookie:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.l2tpv3_session_id is not None:
                                                                return True

                                                            if self.label_index_attr is not None:
                                                                for child_ref in self.label_index_attr:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.local_preference is not None:
                                                                return True

                                                            if self.ls_attr is not None:
                                                                for child_ref in self.ls_attr:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.neighbor_as is not None:
                                                                return True

                                                            if self.origin is not None:
                                                                return True

                                                            if self.originator is not None:
                                                                return True

                                                            if self.pe_distinguisher_label is not None:
                                                                for child_ref in self.pe_distinguisher_label:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.pmsi_flags is not None:
                                                                return True

                                                            if self.pmsi_label is not None:
                                                                return True

                                                            if self.pmsi_type is not None:
                                                                return True

                                                            if self.pmsi_value is not None:
                                                                for child_ref in self.pmsi_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.ppm_pvalue is not None:
                                                                return True

                                                            if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                                return True

                                                            if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                                return True

                                                            if self.sr_policy_explicit_path is not None:
                                                                for child_ref in self.sr_policy_explicit_path:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.sr_policy_preference is not None:
                                                                return True

                                                            if self.sr_tunnel_request_state is not None:
                                                                return True

                                                            if self.sr_tunnel_state is not None:
                                                                return True

                                                            if self.tunnel_encap_type is not None:
                                                                return True

                                                            if self.unknown_attribute is not None:
                                                                for child_ref in self.unknown_attribute:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                                    class RnhAddr(object):
                                                        """
                                                        RNH Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                        
                                                        .. attribute:: mac_address
                                                        
                                                        	MAC Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_address = None
                                                            self.ipv6_address = None
                                                            self.len = None
                                                            self.mac_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.len is not None:
                                                                return True

                                                            if self.mac_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                                    class RibrnhIp(object):
                                                        """
                                                        RIB RNH IP Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.attr_set is not None and self.attr_set._has_data():
                                                            return True

                                                        if self.attribute_key_number is not None:
                                                            return True

                                                        if self.attribute_reuse_id_config is not None:
                                                            return True

                                                        if self.attribute_reuse_id_current is not None:
                                                            return True

                                                        if self.attribute_reuse_id_keys is not None:
                                                            return True

                                                        if self.attribute_reuse_id_max_id is not None:
                                                            return True

                                                        if self.attribute_reuse_id_node is not None:
                                                            return True

                                                        if self.attribute_reuse_id_recover_sec is not None:
                                                            return True

                                                        if self.common_attributes is not None and self.common_attributes._has_data():
                                                            return True

                                                        if self.is_application_gateway_present is not None:
                                                            return True

                                                        if self.is_as_path2_byte is not None:
                                                            return True

                                                        if self.is_attr_set_present is not None:
                                                            return True

                                                        if self.is_ribrnh_present is not None:
                                                            return True

                                                        if self.is_rnh_present is not None:
                                                            return True

                                                        if self.ribrnh_encap is not None:
                                                            return True

                                                        if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                            return True

                                                        if self.ribrnh_mac is not None:
                                                            return True

                                                        if self.ribrnh_table is not None:
                                                            return True

                                                        if self.ribrnh_vni is not None:
                                                            return True

                                                        if self.ribrnhip_table is not None:
                                                            return True

                                                        if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                            return True

                                                        if self.rnh_addr_len is not None:
                                                            return True

                                                        if self.rnh_len is not None:
                                                            return True

                                                        if self.rnh_type is not None:
                                                            return True

                                                        if self.set_aigp_inbound_igp is not None:
                                                            return True

                                                        if self.set_aigp_inbound_metric is not None:
                                                            return True

                                                        if self.vpn_distinguisher is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath.AttributesAfterPolicyIn']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-process-instance-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.af_name is not None:
                                                        return True

                                                    if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                        return True

                                                    if self.label_fail is not None:
                                                        return True

                                                    if self.label_o_or_version is not None:
                                                        return True

                                                    if self.label_oor is not None:
                                                        return True

                                                    if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                        return True

                                                    if self.no_path is not None:
                                                        return True

                                                    if self.path_information is not None and self.path_information._has_data():
                                                        return True

                                                    if self.prefix_version is not None:
                                                        return True

                                                    if self.process_instance_id is not None:
                                                        return True

                                                    if self.route_distinguisher is not None:
                                                        return True

                                                    if self.source_route_distinguisher is not None:
                                                        return True

                                                    if self.source_vrf_name is not None:
                                                        return True

                                                    if self.srcaf_name is not None:
                                                        return True

                                                    if self.vrf_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalProcessInstancePath']['meta_info']


                                            class ActiveProcessInstancePath(object):
                                                """
                                                Active's paths for this net 
                                                
                                                .. attribute:: af_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: attributes_after_policy_in
                                                
                                                	Attributes after inbound policy applied
                                                	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn>`
                                                
                                                .. attribute:: label_fail
                                                
                                                	LSD label allocation failed 
                                                	**type**\:  bool
                                                
                                                .. attribute:: label_o_or_version
                                                
                                                	Label Version when OOR happens
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: label_oor
                                                
                                                	LSD label space is exhausted
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_address_xr
                                                
                                                	Neighbor Address
                                                	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr>`
                                                
                                                .. attribute:: no_path
                                                
                                                	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                                	**type**\:  bool
                                                
                                                .. attribute:: path_information
                                                
                                                	Path information
                                                	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation>`
                                                
                                                .. attribute:: prefix_version
                                                
                                                	Version of BGP Prefix Table
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: process_instance_id
                                                
                                                	Process instance ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: source_route_distinguisher
                                                
                                                	Source Route Distinguisher
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: source_vrf_name
                                                
                                                	Name of the source VRF
                                                	**type**\:  str
                                                
                                                .. attribute:: srcaf_name
                                                
                                                	Address family identifier
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: vrf_name
                                                
                                                	Name of the VRF
                                                	**type**\:  str
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.af_name = None
                                                    self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn()
                                                    self.attributes_after_policy_in.parent = self
                                                    self.label_fail = None
                                                    self.label_o_or_version = None
                                                    self.label_oor = None
                                                    self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr()
                                                    self.neighbor_address_xr.parent = self
                                                    self.no_path = None
                                                    self.path_information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation()
                                                    self.path_information.parent = self
                                                    self.prefix_version = None
                                                    self.process_instance_id = None
                                                    self.route_distinguisher = None
                                                    self.source_route_distinguisher = None
                                                    self.source_vrf_name = None
                                                    self.srcaf_name = None
                                                    self.vrf_name = None


                                                class NeighborAddressXr(object):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.NeighborAddressXr']['meta_info']


                                                class PathInformation(object):
                                                    """
                                                    Path information
                                                    
                                                    .. attribute:: accept_own_path
                                                    
                                                    	Accept Own
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: accept_own_self_originated_p_ath
                                                    
                                                    	Accept\-Own self\-originated
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: add_path_orr_bitfield
                                                    
                                                    	ORR Add path Bitfields
                                                    	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                    
                                                    .. attribute:: advertisedto_pe
                                                    
                                                    	Net could be advertised                          to PE peers
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: aigp_metric
                                                    
                                                    	Total AIGP metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: best_path_comp_stage
                                                    
                                                    	Stage where the path lost to the best path or group best
                                                    	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                                    
                                                    .. attribute:: best_path_comp_winner
                                                    
                                                    	Neighbor address of the path which won best path comparison
                                                    	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                    
                                                    .. attribute:: best_path_id
                                                    
                                                    	Best path ID; DEPRECATED BYLocalPathId
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: best_path_id_comp_winner
                                                    
                                                    	Path ID of the path which won best path comparison
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: best_path_orr_bitfield
                                                    
                                                    	ORR Best path Bitfields
                                                    	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                    
                                                    .. attribute:: bgp_prefix
                                                    
                                                    	BGP prefix
                                                    	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix>`
                                                    
                                                    .. attribute:: dampen_penalty
                                                    
                                                    	Dampening penalty
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Mvpn Extended community attribute
                                                    	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                    
                                                    .. attribute:: fspec_invalid_path
                                                    
                                                    	Is Fspec invalid path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: graceful_shutdown
                                                    
                                                    	Marked for graceful shutdown
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: gw_addr
                                                    
                                                    	Path GW Address
                                                    	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.GwAddr>`
                                                    
                                                    .. attribute:: halflife_time
                                                    
                                                    	Half\-life time for the penalty
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_esi
                                                    
                                                    	Path has EVPN ESI
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_gw_addr
                                                    
                                                    	Path has GW Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_local_net_label
                                                    
                                                    	Path has local label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mdt_group_addr
                                                    
                                                    	Path has MDT Group Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_extcomm
                                                    
                                                    	Path has MVPN EXTCOMM feedback
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_nbr_addr
                                                    
                                                    	Path has Mvpn nbr Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_nexthop_addr
                                                    
                                                    	Path has MVPN nexthop Address
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_mvpn_pmsi
                                                    
                                                    	Path has MVPN PMSI feedback
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_rcvd_label
                                                    
                                                    	Path has received label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: has_second_label
                                                    
                                                    	Path has second received label
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ibgp_signaled_validity
                                                    
                                                    	IBGP signalled validation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: igp_metric
                                                    
                                                    	IGP metric to the gateway
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_aggregation_suppressed
                                                    
                                                    	Path suppressed due to aggregation
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_best
                                                    
                                                    	Best available path within AS
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_best_path
                                                    
                                                    	Best available path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_import_dampened
                                                    
                                                    	net import dampened
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_import_suspect
                                                    
                                                    	net import suspect
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_internal_path
                                                    
                                                    	Received over an internal link
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_partial_best
                                                    
                                                    	Partial best path within distributed speaker
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_additional_path
                                                    
                                                    	Path is an additional\-path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_advertised_local_as_only
                                                    
                                                    	Not advertised outside local AS
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_af_install_eligible
                                                    
                                                    	Path can be installed in AF RIB
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_backup
                                                    
                                                    	Path is a backup path 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_backup_protect_multipath
                                                    
                                                    	Path is a backup path to protect multipaths
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_best_external
                                                    
                                                    	Path is a best external path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_damped
                                                    
                                                    	Path suppressed due to dampening
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_confederation_peer
                                                    
                                                    	Path received from confederation peer
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_network_command
                                                    
                                                    	Path sourced by network command
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_redistribute_command
                                                    
                                                    	Path sourced by redistribute command
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_from_route_reflector
                                                    
                                                    	Path received from route reflector
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_history_held
                                                    
                                                    	Path entry held to remember history
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_imp_candidate
                                                    
                                                    	Path is a candidate for multipath import
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_imported
                                                    
                                                    	Path is imported
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_local_aggregate
                                                    
                                                    	Path is a locally created aggregate
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_locally_sourced
                                                    
                                                    	Path sourced locally
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_long_lived_stale
                                                    
                                                    	Long lived stale routes learnt before neighbor restarts
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_multipath
                                                    
                                                    	Path is one of multipath best routes
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_nexthop_discarded
                                                    
                                                    	Path is redirected to Null0
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_not_advertised
                                                    
                                                    	Not advertised to any peer
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_not_advertised_to_ebg_ps
                                                    
                                                    	Not advertised to EBGPs
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_received_only
                                                    
                                                    	Path is received only
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_reoriginated
                                                    
                                                    	Path is reoriginated
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_reoriginated_stitching
                                                    
                                                    	Path is reoriginated with stitching RTs
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_stale
                                                    
                                                    	Stale routes learnt before neighbor restarts
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_synced_with_igp
                                                    
                                                    	Path synchronized with IGP
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_valid
                                                    
                                                    	Path attributes are usable
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_path_vpn_only
                                                    
                                                    	Path is not in the vrf
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_permanent_path
                                                    
                                                    	Path is of type Permanent path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_received_path_not_modified
                                                    
                                                    	Received path used without modification
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_spkr_as_best
                                                    
                                                    	Best available path within AS in speaker
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: l2vpn_circuit_status_value
                                                    
                                                    	L2VPN Circuit Status Value
                                                    	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue>`
                                                    
                                                    .. attribute:: l2vpn_evpn_esi
                                                    
                                                    	L2VPN EVPN ESI
                                                    	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi>`
                                                    
                                                    .. attribute:: l2vpn_size
                                                    
                                                    	Path block size
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: labeled_unicast_safi_path
                                                    
                                                    	Path was learnt by labeled\-unicast SAFI
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: local_label
                                                    
                                                    	Path local label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_nh
                                                    
                                                    	Path has local nexthop
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: local_path_id
                                                    
                                                    	Local path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_peers_advertised_to
                                                    
                                                    	Local peers that this prefix has been advertised to
                                                    	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                    
                                                    .. attribute:: maximum_suppress_time
                                                    
                                                    	Maximum duration to suppress a stable route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mdt_group_addr
                                                    
                                                    	IPv4 MDT Group Address for the path
                                                    	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                    
                                                    .. attribute:: mvpn_nbr_addr
                                                    
                                                    	Mvpn nbr Address for the path
                                                    	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                    
                                                    .. attribute:: mvpn_nexthop_addr
                                                    
                                                    	Mvpn nexthop Address for the path
                                                    	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                    
                                                    .. attribute:: mvpn_path_flags
                                                    
                                                    	Mvpn path flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: mvpn_pmsi_flags
                                                    
                                                    	Mvpn PMSI Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: mvpn_pmsi_label
                                                    
                                                    	Mvpn PMSI label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mvpn_pmsi_type
                                                    
                                                    	Mvpn PMSI Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: mvpn_pmsi_value
                                                    
                                                    	Mvpn PMSI Value
                                                    	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                    
                                                    .. attribute:: mvpn_sfs_path
                                                    
                                                    	Is MVPN single forwarder PE path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor address
                                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress>`
                                                    
                                                    .. attribute:: neighbor_router_id
                                                    
                                                    	Router ID of the neighbor for the path
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: next_hop
                                                    
                                                    	Next hop
                                                    	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop>`
                                                    
                                                    .. attribute:: nhte_tunnel
                                                    
                                                    	NH TE tunnel information
                                                    	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhteTunnel>`
                                                    
                                                    .. attribute:: path_flags
                                                    
                                                    	Flags associated with path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: path_flap_count
                                                    
                                                    	Number of times this route has flapped
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_import_flags
                                                    
                                                    	Path import flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_rt_set_id
                                                    
                                                    	RT\-set id of the path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_rt_set_route_count
                                                    
                                                    	Count in RT\-set
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_table_version
                                                    
                                                    	Table version # for pelem
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: path_weight
                                                    
                                                    	Weight for the path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pe_peers_advertised_to
                                                    
                                                    	PE peers that this prefix has been advertised to
                                                    	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                    
                                                    .. attribute:: rcvd_label
                                                    
                                                    	Path received label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rcvd_path_id
                                                    
                                                    	Received path ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: reuse_value
                                                    
                                                    	Value to start reusing a route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rib_failed
                                                    
                                                    	Is net failed installed                          in RIB
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: route_type
                                                    
                                                    	Route Type of path
                                                    	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                                    
                                                    .. attribute:: rpki_origin_as_validation_disabled
                                                    
                                                    	RPKI originAS V. Disabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rt_set_limit_enabled
                                                    
                                                    	Path subject to RT\-set net limit
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: second_label
                                                    
                                                    	Path second received label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: seconds_since_first_flap
                                                    
                                                    	Seconds since route first flapped
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: show_rpki_origin_as_validity
                                                    
                                                    	Display validity state ?
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: sn_rpki_origin_as_validity
                                                    
                                                    	RPKI origin validation state
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: suppress_penalty
                                                    
                                                    	Value to start suppressing a route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: time_to_unsuppress
                                                    
                                                    	Seconds until route is unsuppressed
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.accept_own_path = None
                                                        self.accept_own_self_originated_p_ath = None
                                                        self.add_path_orr_bitfield = YList()
                                                        self.add_path_orr_bitfield.parent = self
                                                        self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                                        self.advertisedto_pe = None
                                                        self.aigp_metric = None
                                                        self.best_path_comp_stage = None
                                                        self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner()
                                                        self.best_path_comp_winner.parent = self
                                                        self.best_path_id = None
                                                        self.best_path_id_comp_winner = None
                                                        self.best_path_orr_bitfield = YList()
                                                        self.best_path_orr_bitfield.parent = self
                                                        self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                                        self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix()
                                                        self.bgp_prefix.parent = self
                                                        self.dampen_penalty = None
                                                        self.extended_community = YList()
                                                        self.extended_community.parent = self
                                                        self.extended_community.name = 'extended_community'
                                                        self.fspec_invalid_path = None
                                                        self.graceful_shutdown = None
                                                        self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.GwAddr()
                                                        self.gw_addr.parent = self
                                                        self.halflife_time = None
                                                        self.has_esi = None
                                                        self.has_gw_addr = None
                                                        self.has_local_net_label = None
                                                        self.has_mdt_group_addr = None
                                                        self.has_mvpn_extcomm = None
                                                        self.has_mvpn_nbr_addr = None
                                                        self.has_mvpn_nexthop_addr = None
                                                        self.has_mvpn_pmsi = None
                                                        self.has_rcvd_label = None
                                                        self.has_second_label = None
                                                        self.ibgp_signaled_validity = None
                                                        self.igp_metric = None
                                                        self.is_aggregation_suppressed = None
                                                        self.is_as_best = None
                                                        self.is_best_path = None
                                                        self.is_import_dampened = None
                                                        self.is_import_suspect = None
                                                        self.is_internal_path = None
                                                        self.is_partial_best = None
                                                        self.is_path_additional_path = None
                                                        self.is_path_advertised_local_as_only = None
                                                        self.is_path_af_install_eligible = None
                                                        self.is_path_backup = None
                                                        self.is_path_backup_protect_multipath = None
                                                        self.is_path_best_external = None
                                                        self.is_path_damped = None
                                                        self.is_path_from_confederation_peer = None
                                                        self.is_path_from_network_command = None
                                                        self.is_path_from_redistribute_command = None
                                                        self.is_path_from_route_reflector = None
                                                        self.is_path_history_held = None
                                                        self.is_path_imp_candidate = None
                                                        self.is_path_imported = None
                                                        self.is_path_local_aggregate = None
                                                        self.is_path_locally_sourced = None
                                                        self.is_path_long_lived_stale = None
                                                        self.is_path_multipath = None
                                                        self.is_path_nexthop_discarded = None
                                                        self.is_path_not_advertised = None
                                                        self.is_path_not_advertised_to_ebg_ps = None
                                                        self.is_path_received_only = None
                                                        self.is_path_reoriginated = None
                                                        self.is_path_reoriginated_stitching = None
                                                        self.is_path_stale = None
                                                        self.is_path_synced_with_igp = None
                                                        self.is_path_valid = None
                                                        self.is_path_vpn_only = None
                                                        self.is_permanent_path = None
                                                        self.is_received_path_not_modified = None
                                                        self.is_spkr_as_best = None
                                                        self.l2vpn_circuit_status_value = YList()
                                                        self.l2vpn_circuit_status_value.parent = self
                                                        self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                                        self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi()
                                                        self.l2vpn_evpn_esi.parent = self
                                                        self.l2vpn_size = None
                                                        self.labeled_unicast_safi_path = None
                                                        self.local_label = None
                                                        self.local_nh = None
                                                        self.local_path_id = None
                                                        self.local_peers_advertised_to = YList()
                                                        self.local_peers_advertised_to.parent = self
                                                        self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                                        self.maximum_suppress_time = None
                                                        self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr()
                                                        self.mdt_group_addr.parent = self
                                                        self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                        self.mvpn_nbr_addr.parent = self
                                                        self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                        self.mvpn_nexthop_addr.parent = self
                                                        self.mvpn_path_flags = None
                                                        self.mvpn_pmsi_flags = None
                                                        self.mvpn_pmsi_label = None
                                                        self.mvpn_pmsi_type = None
                                                        self.mvpn_pmsi_value = YList()
                                                        self.mvpn_pmsi_value.parent = self
                                                        self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                                        self.mvpn_sfs_path = None
                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self.neighbor_router_id = None
                                                        self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop()
                                                        self.next_hop.parent = self
                                                        self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhteTunnel()
                                                        self.nhte_tunnel.parent = self
                                                        self.path_flags = None
                                                        self.path_flap_count = None
                                                        self.path_import_flags = None
                                                        self.path_rt_set_id = None
                                                        self.path_rt_set_route_count = None
                                                        self.path_table_version = None
                                                        self.path_weight = None
                                                        self.pe_peers_advertised_to = YList()
                                                        self.pe_peers_advertised_to.parent = self
                                                        self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                                        self.rcvd_label = None
                                                        self.rcvd_path_id = None
                                                        self.reuse_value = None
                                                        self.rib_failed = None
                                                        self.route_type = None
                                                        self.rpki_origin_as_validation_disabled = None
                                                        self.rt_set_limit_enabled = None
                                                        self.second_label = None
                                                        self.seconds_since_first_flap = None
                                                        self.show_rpki_origin_as_validity = None
                                                        self.sn_rpki_origin_as_validity = None
                                                        self.suppress_penalty = None
                                                        self.time_to_unsuppress = None


                                                    class BgpPrefix(object):
                                                        """
                                                        BGP prefix
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Prefix
                                                        	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                            self.prefix.parent = self
                                                            self.prefix_length = None


                                                        class Prefix(object):
                                                            """
                                                            Prefix
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.prefix is not None and self.prefix._has_data():
                                                                return True

                                                            if self.prefix_length is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BgpPrefix']['meta_info']


                                                    class NeighborAddress(object):
                                                        """
                                                        Neighbor address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NeighborAddress']['meta_info']


                                                    class NextHop(object):
                                                        """
                                                        Next hop
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NextHop']['meta_info']


                                                    class NhteTunnel(object):
                                                        """
                                                        NH TE tunnel information
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	Binding label for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_te_tunnel
                                                        
                                                        	NH TE Tunnel info is present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_info_stale
                                                        
                                                        	Tunnel is stale
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_registered
                                                        
                                                        	Tunnel registered flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_up
                                                        
                                                        	Tunnel Up flag
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: last_tunnel_update
                                                        
                                                        	Time since the last rib update happened
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_if_handle
                                                        
                                                        	Interface handle for the tunnel
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_name
                                                        
                                                        	tunnel name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        .. attribute:: tunnel_type
                                                        
                                                        	tunnel type
                                                        	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                        
                                                        .. attribute:: tunnel_v6_enabled
                                                        
                                                        	IPv6 enabled
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_v6_required
                                                        
                                                        	Tunnel need IPv6
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.binding_label = None
                                                            self.has_te_tunnel = None
                                                            self.is_tunnel_info_stale = None
                                                            self.is_tunnel_registered = None
                                                            self.is_tunnel_up = None
                                                            self.last_tunnel_update = None
                                                            self.tunnel_if_handle = None
                                                            self.tunnel_name = None
                                                            self.tunnel_type = None
                                                            self.tunnel_v6_enabled = None
                                                            self.tunnel_v6_required = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.binding_label is not None:
                                                                return True

                                                            if self.has_te_tunnel is not None:
                                                                return True

                                                            if self.is_tunnel_info_stale is not None:
                                                                return True

                                                            if self.is_tunnel_registered is not None:
                                                                return True

                                                            if self.is_tunnel_up is not None:
                                                                return True

                                                            if self.last_tunnel_update is not None:
                                                                return True

                                                            if self.tunnel_if_handle is not None:
                                                                return True

                                                            if self.tunnel_name is not None:
                                                                return True

                                                            if self.tunnel_type is not None:
                                                                return True

                                                            if self.tunnel_v6_enabled is not None:
                                                                return True

                                                            if self.tunnel_v6_required is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.NhteTunnel']['meta_info']


                                                    class MdtGroupAddr(object):
                                                        """
                                                        IPv4 MDT Group Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MdtGroupAddr']['meta_info']


                                                    class L2VpnEvpnEsi(object):
                                                        """
                                                        L2VPN EVPN ESI
                                                        
                                                        .. attribute:: esi
                                                        
                                                        	esi
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.esi = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.esi is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.L2VpnEvpnEsi']['meta_info']


                                                    class GwAddr(object):
                                                        """
                                                        Path GW Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_address = None
                                                            self.ipv6_address = None
                                                            self.len = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.len is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.GwAddr']['meta_info']


                                                    class BestPathCompWinner(object):
                                                        """
                                                        Neighbor address of the path which won best path
                                                        comparison
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathCompWinner']['meta_info']


                                                    class MvpnNbrAddr(object):
                                                        """
                                                        Mvpn nbr Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr']['meta_info']


                                                    class MvpnNexthopAddr(object):
                                                        """
                                                        Mvpn nexthop Address for the path
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr']['meta_info']


                                                    class L2VpnCircuitStatusValue(object):
                                                        """
                                                        L2VPN Circuit Status Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                                    class MvpnPmsiValue(object):
                                                        """
                                                        Mvpn PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue']['meta_info']


                                                    class ExtendedCommunity(object):
                                                        """
                                                        Mvpn Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.entry = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.entry is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.ExtendedCommunity']['meta_info']


                                                    class LocalPeersAdvertisedTo(object):
                                                        """
                                                        Local peers that this prefix has been advertised
                                                        to
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.is_neighbor = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.update_group_number = None


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.is_neighbor is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.update_group_number is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                                    class PePeersAdvertisedTo(object):
                                                        """
                                                        PE peers that this prefix has been advertised to
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.is_neighbor = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.update_group_number = None


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.is_neighbor is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.update_group_number is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo']['meta_info']


                                                    class BestPathOrrBitfield(object):
                                                        """
                                                        ORR Best path Bitfields
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.is_neighbor = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.update_group_number = None


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.is_neighbor is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.update_group_number is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield']['meta_info']


                                                    class AddPathOrrBitfield(object):
                                                        """
                                                        ORR Add path Bitfields
                                                        
                                                        .. attribute:: is_neighbor
                                                        
                                                        	Entry is a neighbor (not an update group)
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: neighbor_address
                                                        
                                                        	Neighbor Address
                                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                        
                                                        .. attribute:: update_group_number
                                                        
                                                        	Update group index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.is_neighbor = None
                                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                            self.neighbor_address.parent = self
                                                            self.update_group_number = None


                                                        class NeighborAddress(object):
                                                            """
                                                            Neighbor Address
                                                            
                                                            .. attribute:: afi
                                                            
                                                            	AFI
                                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_flowspec_address
                                                            
                                                            	IPV4 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4_label_address
                                                            
                                                            	IPv4 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_mcast_address
                                                            
                                                            	IPv4 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4_tunnel_address
                                                            
                                                            	IPv4 Tunnel
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mdt_address
                                                            
                                                            	IPv4 MDT Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                            
                                                            .. attribute:: ipv4mvpn_address
                                                            
                                                            	MVPN4 addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                                            
                                                            .. attribute:: ipv4sr_policy_address
                                                            
                                                            	IPV4 Policy Addr
                                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv4vpn_address
                                                            
                                                            	IPv4 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv4vpn_flowspec_address
                                                            
                                                            	IPV4 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv4vpna_mcastddress
                                                            
                                                            	IPv4 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPV6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_flowspec_address
                                                            
                                                            	IPV6 Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6_label_address
                                                            
                                                            	IPv6 Label Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_mcast_address
                                                            
                                                            	IPV6 Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6mvpn_address
                                                            
                                                            	MVPN addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                                            
                                                            .. attribute:: ipv6sr_policy_address
                                                            
                                                            	IPV6 Policy Addr
                                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                            
                                                            .. attribute:: ipv6vpn_address
                                                            
                                                            	IPv6 VPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6vpn_flowspec_address
                                                            
                                                            	IPV6 VPN Flowspec Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                                            
                                                            .. attribute:: ipv6vpn_mcast_address
                                                            
                                                            	IPv6 VPN Mcast Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: l2vpn_evpn_address
                                                            
                                                            	L2VPN EVPN Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                                            
                                                            .. attribute:: l2vpn_mspw_address
                                                            
                                                            	L2VPN MSPW Addr
                                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                            
                                                            .. attribute:: l2vpnvpls_address
                                                            
                                                            	L2VPN VPLS Addr
                                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                            
                                                            .. attribute:: ls_ls_address
                                                            
                                                            	LINKSTATE LINKSTATE Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]+
                                                            
                                                            .. attribute:: rt_constraint_address
                                                            
                                                            	RT Constrt Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.afi = None
                                                                self.ipv4_address = None
                                                                self.ipv4_flowspec_address = None
                                                                self.ipv4_label_address = None
                                                                self.ipv4_mcast_address = None
                                                                self.ipv4_tunnel_address = None
                                                                self.ipv4mdt_address = None
                                                                self.ipv4mvpn_address = None
                                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                                self.ipv4sr_policy_address.parent = self
                                                                self.ipv4vpn_address = None
                                                                self.ipv4vpn_flowspec_address = None
                                                                self.ipv4vpna_mcastddress = None
                                                                self.ipv6_address = None
                                                                self.ipv6_flowspec_address = None
                                                                self.ipv6_label_address = None
                                                                self.ipv6_mcast_address = None
                                                                self.ipv6mvpn_address = None
                                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                                self.ipv6sr_policy_address.parent = self
                                                                self.ipv6vpn_address = None
                                                                self.ipv6vpn_flowspec_address = None
                                                                self.ipv6vpn_mcast_address = None
                                                                self.l2vpn_evpn_address = None
                                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                                self.l2vpn_mspw_address.parent = self
                                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                                self.l2vpnvpls_address.parent = self
                                                                self.ls_ls_address = None
                                                                self.rt_constraint_address = None


                                                            class L2VpnvplsAddress(object):
                                                                """
                                                                L2VPN VPLS Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                            class L2VpnMspwAddress(object):
                                                                """
                                                                L2VPN MSPW Addr
                                                                
                                                                .. attribute:: l2vpn_address
                                                                
                                                                	l2vpn address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.l2vpn_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.l2vpn_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                            class Ipv4SrPolicyAddress(object):
                                                                """
                                                                IPV4 Policy Addr
                                                                
                                                                .. attribute:: ipv4_srpolicy_address
                                                                
                                                                	ipv4 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                            class Ipv6SrPolicyAddress(object):
                                                                """
                                                                IPV6 Policy Addr
                                                                
                                                                .. attribute:: ipv6_srpolicy_address
                                                                
                                                                	ipv6 srpolicy address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv6_srpolicy_address = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv6_srpolicy_address is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.afi is not None:
                                                                    return True

                                                                if self.ipv4_address is not None:
                                                                    return True

                                                                if self.ipv4_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4_label_address is not None:
                                                                    return True

                                                                if self.ipv4_mcast_address is not None:
                                                                    return True

                                                                if self.ipv4_tunnel_address is not None:
                                                                    return True

                                                                if self.ipv4mdt_address is not None:
                                                                    return True

                                                                if self.ipv4mvpn_address is not None:
                                                                    return True

                                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv4vpn_address is not None:
                                                                    return True

                                                                if self.ipv4vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv4vpna_mcastddress is not None:
                                                                    return True

                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.ipv6_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6_label_address is not None:
                                                                    return True

                                                                if self.ipv6_mcast_address is not None:
                                                                    return True

                                                                if self.ipv6mvpn_address is not None:
                                                                    return True

                                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                    return True

                                                                if self.ipv6vpn_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_flowspec_address is not None:
                                                                    return True

                                                                if self.ipv6vpn_mcast_address is not None:
                                                                    return True

                                                                if self.l2vpn_evpn_address is not None:
                                                                    return True

                                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                    return True

                                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                    return True

                                                                if self.ls_ls_address is not None:
                                                                    return True

                                                                if self.rt_constraint_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.is_neighbor is not None:
                                                                return True

                                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                                return True

                                                            if self.update_group_number is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.accept_own_path is not None:
                                                            return True

                                                        if self.accept_own_self_originated_p_ath is not None:
                                                            return True

                                                        if self.add_path_orr_bitfield is not None:
                                                            for child_ref in self.add_path_orr_bitfield:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.advertisedto_pe is not None:
                                                            return True

                                                        if self.aigp_metric is not None:
                                                            return True

                                                        if self.best_path_comp_stage is not None:
                                                            return True

                                                        if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                            return True

                                                        if self.best_path_id is not None:
                                                            return True

                                                        if self.best_path_id_comp_winner is not None:
                                                            return True

                                                        if self.best_path_orr_bitfield is not None:
                                                            for child_ref in self.best_path_orr_bitfield:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                            return True

                                                        if self.dampen_penalty is not None:
                                                            return True

                                                        if self.extended_community is not None:
                                                            for child_ref in self.extended_community:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.fspec_invalid_path is not None:
                                                            return True

                                                        if self.graceful_shutdown is not None:
                                                            return True

                                                        if self.gw_addr is not None and self.gw_addr._has_data():
                                                            return True

                                                        if self.halflife_time is not None:
                                                            return True

                                                        if self.has_esi is not None:
                                                            return True

                                                        if self.has_gw_addr is not None:
                                                            return True

                                                        if self.has_local_net_label is not None:
                                                            return True

                                                        if self.has_mdt_group_addr is not None:
                                                            return True

                                                        if self.has_mvpn_extcomm is not None:
                                                            return True

                                                        if self.has_mvpn_nbr_addr is not None:
                                                            return True

                                                        if self.has_mvpn_nexthop_addr is not None:
                                                            return True

                                                        if self.has_mvpn_pmsi is not None:
                                                            return True

                                                        if self.has_rcvd_label is not None:
                                                            return True

                                                        if self.has_second_label is not None:
                                                            return True

                                                        if self.ibgp_signaled_validity is not None:
                                                            return True

                                                        if self.igp_metric is not None:
                                                            return True

                                                        if self.is_aggregation_suppressed is not None:
                                                            return True

                                                        if self.is_as_best is not None:
                                                            return True

                                                        if self.is_best_path is not None:
                                                            return True

                                                        if self.is_import_dampened is not None:
                                                            return True

                                                        if self.is_import_suspect is not None:
                                                            return True

                                                        if self.is_internal_path is not None:
                                                            return True

                                                        if self.is_partial_best is not None:
                                                            return True

                                                        if self.is_path_additional_path is not None:
                                                            return True

                                                        if self.is_path_advertised_local_as_only is not None:
                                                            return True

                                                        if self.is_path_af_install_eligible is not None:
                                                            return True

                                                        if self.is_path_backup is not None:
                                                            return True

                                                        if self.is_path_backup_protect_multipath is not None:
                                                            return True

                                                        if self.is_path_best_external is not None:
                                                            return True

                                                        if self.is_path_damped is not None:
                                                            return True

                                                        if self.is_path_from_confederation_peer is not None:
                                                            return True

                                                        if self.is_path_from_network_command is not None:
                                                            return True

                                                        if self.is_path_from_redistribute_command is not None:
                                                            return True

                                                        if self.is_path_from_route_reflector is not None:
                                                            return True

                                                        if self.is_path_history_held is not None:
                                                            return True

                                                        if self.is_path_imp_candidate is not None:
                                                            return True

                                                        if self.is_path_imported is not None:
                                                            return True

                                                        if self.is_path_local_aggregate is not None:
                                                            return True

                                                        if self.is_path_locally_sourced is not None:
                                                            return True

                                                        if self.is_path_long_lived_stale is not None:
                                                            return True

                                                        if self.is_path_multipath is not None:
                                                            return True

                                                        if self.is_path_nexthop_discarded is not None:
                                                            return True

                                                        if self.is_path_not_advertised is not None:
                                                            return True

                                                        if self.is_path_not_advertised_to_ebg_ps is not None:
                                                            return True

                                                        if self.is_path_received_only is not None:
                                                            return True

                                                        if self.is_path_reoriginated is not None:
                                                            return True

                                                        if self.is_path_reoriginated_stitching is not None:
                                                            return True

                                                        if self.is_path_stale is not None:
                                                            return True

                                                        if self.is_path_synced_with_igp is not None:
                                                            return True

                                                        if self.is_path_valid is not None:
                                                            return True

                                                        if self.is_path_vpn_only is not None:
                                                            return True

                                                        if self.is_permanent_path is not None:
                                                            return True

                                                        if self.is_received_path_not_modified is not None:
                                                            return True

                                                        if self.is_spkr_as_best is not None:
                                                            return True

                                                        if self.l2vpn_circuit_status_value is not None:
                                                            for child_ref in self.l2vpn_circuit_status_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                            return True

                                                        if self.l2vpn_size is not None:
                                                            return True

                                                        if self.labeled_unicast_safi_path is not None:
                                                            return True

                                                        if self.local_label is not None:
                                                            return True

                                                        if self.local_nh is not None:
                                                            return True

                                                        if self.local_path_id is not None:
                                                            return True

                                                        if self.local_peers_advertised_to is not None:
                                                            for child_ref in self.local_peers_advertised_to:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.maximum_suppress_time is not None:
                                                            return True

                                                        if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                            return True

                                                        if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                            return True

                                                        if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                            return True

                                                        if self.mvpn_path_flags is not None:
                                                            return True

                                                        if self.mvpn_pmsi_flags is not None:
                                                            return True

                                                        if self.mvpn_pmsi_label is not None:
                                                            return True

                                                        if self.mvpn_pmsi_type is not None:
                                                            return True

                                                        if self.mvpn_pmsi_value is not None:
                                                            for child_ref in self.mvpn_pmsi_value:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.mvpn_sfs_path is not None:
                                                            return True

                                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                            return True

                                                        if self.neighbor_router_id is not None:
                                                            return True

                                                        if self.next_hop is not None and self.next_hop._has_data():
                                                            return True

                                                        if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                            return True

                                                        if self.path_flags is not None:
                                                            return True

                                                        if self.path_flap_count is not None:
                                                            return True

                                                        if self.path_import_flags is not None:
                                                            return True

                                                        if self.path_rt_set_id is not None:
                                                            return True

                                                        if self.path_rt_set_route_count is not None:
                                                            return True

                                                        if self.path_table_version is not None:
                                                            return True

                                                        if self.path_weight is not None:
                                                            return True

                                                        if self.pe_peers_advertised_to is not None:
                                                            for child_ref in self.pe_peers_advertised_to:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.rcvd_label is not None:
                                                            return True

                                                        if self.rcvd_path_id is not None:
                                                            return True

                                                        if self.reuse_value is not None:
                                                            return True

                                                        if self.rib_failed is not None:
                                                            return True

                                                        if self.route_type is not None:
                                                            return True

                                                        if self.rpki_origin_as_validation_disabled is not None:
                                                            return True

                                                        if self.rt_set_limit_enabled is not None:
                                                            return True

                                                        if self.second_label is not None:
                                                            return True

                                                        if self.seconds_since_first_flap is not None:
                                                            return True

                                                        if self.show_rpki_origin_as_validity is not None:
                                                            return True

                                                        if self.sn_rpki_origin_as_validity is not None:
                                                            return True

                                                        if self.suppress_penalty is not None:
                                                            return True

                                                        if self.time_to_unsuppress is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.PathInformation']['meta_info']


                                                class AttributesAfterPolicyIn(object):
                                                    """
                                                    Attributes after inbound policy applied
                                                    
                                                    .. attribute:: attr_set
                                                    
                                                    	ATTR\_SET attribute
                                                    	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                    
                                                    .. attribute:: attribute_key_number
                                                    
                                                    	Attribute key number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_config
                                                    
                                                    	Attribute reuse ID Configured
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: attribute_reuse_id_current
                                                    
                                                    	Attribute reuse ID current ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_keys
                                                    
                                                    	Attribute reuse ID allocated keys
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_max_id
                                                    
                                                    	Attribute reuse ID maximum ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_node
                                                    
                                                    	Attribute reuse ID nodes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: attribute_reuse_id_recover_sec
                                                    
                                                    	Attribute reuse ID timer in seconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: common_attributes
                                                    
                                                    	Common attributes
                                                    	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                    
                                                    .. attribute:: is_application_gateway_present
                                                    
                                                    	Application gateway present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_as_path2_byte
                                                    
                                                    	AS path encoded as 2\-byte
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_attr_set_present
                                                    
                                                    	BGP ATTR\_SET attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_ribrnh_present
                                                    
                                                    	RIB RNH Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_rnh_present
                                                    
                                                    	RNH Attribute  present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ribrnh_encap
                                                    
                                                    	RIB RNH Encapsulation Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ribrnh_ip
                                                    
                                                    	RIB RNH IP Address
                                                    	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                    
                                                    .. attribute:: ribrnh_mac
                                                    
                                                    	RIB RNH MAC Address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    .. attribute:: ribrnh_table
                                                    
                                                    	RIB RNH Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ribrnh_vni
                                                    
                                                    	RIB RNH Vni
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ribrnhip_table
                                                    
                                                    	RIB RNH IP Table
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rnh_addr
                                                    
                                                    	RNH Address
                                                    	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                    
                                                    .. attribute:: rnh_addr_len
                                                    
                                                    	RNH Address Length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rnh_len
                                                    
                                                    	RNH Length
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: rnh_type
                                                    
                                                    	RNH Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: set_aigp_inbound_igp
                                                    
                                                    	AIGP set by policy inbound IGP 
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: set_aigp_inbound_metric
                                                    
                                                    	AIGP set by policy inbound metric
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: vpn_distinguisher
                                                    
                                                    	VPN Distinguisher
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                        self.attr_set.parent = self
                                                        self.attribute_key_number = None
                                                        self.attribute_reuse_id_config = None
                                                        self.attribute_reuse_id_current = None
                                                        self.attribute_reuse_id_keys = None
                                                        self.attribute_reuse_id_max_id = None
                                                        self.attribute_reuse_id_node = None
                                                        self.attribute_reuse_id_recover_sec = None
                                                        self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                        self.common_attributes.parent = self
                                                        self.is_application_gateway_present = None
                                                        self.is_as_path2_byte = None
                                                        self.is_attr_set_present = None
                                                        self.is_ribrnh_present = None
                                                        self.is_rnh_present = None
                                                        self.ribrnh_encap = None
                                                        self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                        self.ribrnh_ip.parent = self
                                                        self.ribrnh_mac = None
                                                        self.ribrnh_table = None
                                                        self.ribrnh_vni = None
                                                        self.ribrnhip_table = None
                                                        self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                        self.rnh_addr.parent = self
                                                        self.rnh_addr_len = None
                                                        self.rnh_len = None
                                                        self.rnh_type = None
                                                        self.set_aigp_inbound_igp = None
                                                        self.set_aigp_inbound_metric = None
                                                        self.vpn_distinguisher = None


                                                    class CommonAttributes(object):
                                                        """
                                                        Common attributes
                                                        
                                                        .. attribute:: aggregator_address
                                                        
                                                        	Address where aggregation was performed
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: aggregator_as
                                                        
                                                        	AS where aggregation was last performed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: aigp_metric_value
                                                        
                                                        	AIGP metric value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: as_path
                                                        
                                                        	AS path attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: cluster
                                                        
                                                        	Cluster list attribute
                                                        	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                        
                                                        .. attribute:: community
                                                        
                                                        	Community attribute
                                                        	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                        
                                                        .. attribute:: connector_type
                                                        
                                                        	Connector Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: connector_value
                                                        
                                                        	Connector Value
                                                        	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                        
                                                        .. attribute:: extended_community_flags
                                                        
                                                        	Extended community Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: is_aggregator_present
                                                        
                                                        	Aggregator attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_aigp_present
                                                        
                                                        	AIGP Present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path_present
                                                        
                                                        	AS path attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_atomic_aggregate_present
                                                        
                                                        	Atomic aggregate attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_community_present
                                                        
                                                        	Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_connector_present
                                                        
                                                        	Connector present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_extended_community_present
                                                        
                                                        	Extended community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_label_index_present
                                                        
                                                        	Label Index attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_local_pref_present
                                                        
                                                        	Local Preference attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ls_attribute_present
                                                        
                                                        	BGP LS attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_metric_present
                                                        
                                                        	Metric attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_origin_present
                                                        
                                                        	Origin attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pe_distinguisher_label_present
                                                        
                                                        	PE distinguisher label  attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pmsi_present
                                                        
                                                        	PMSI Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pppmp_present
                                                        
                                                        	PPMP Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ssa_present
                                                        
                                                        	SSA attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_encap_present
                                                        
                                                        	Tunnel Encap attribute present 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2tpv3_cookie
                                                        
                                                        	L2TPv3 Cookie
                                                        	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                                        
                                                        .. attribute:: l2tpv3_session_id
                                                        
                                                        	L2TPv3 session id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: label_index_attr
                                                        
                                                        	Label Index attribute
                                                        	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                                        
                                                        .. attribute:: local_preference
                                                        
                                                        	Local preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ls_attr
                                                        
                                                        	BGP LS attribute
                                                        	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: neighbor_as
                                                        
                                                        	Neighbor AS number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: origin
                                                        
                                                        	Origin
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: originator
                                                        
                                                        	Originator attribute
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: pe_distinguisher_label
                                                        
                                                        	PE distinguisher label attribute
                                                        	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                        
                                                        .. attribute:: pmsi_flags
                                                        
                                                        	PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pmsi_label
                                                        
                                                        	PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pmsi_type
                                                        
                                                        	PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pmsi_value
                                                        
                                                        	PMSI Value
                                                        	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                        
                                                        .. attribute:: ppm_pvalue
                                                        
                                                        	PPMP Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: sr_policy_allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                                        
                                                        .. attribute:: sr_policy_binding_sid
                                                        
                                                        	SR Policy Binding sid
                                                        	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                                        
                                                        .. attribute:: sr_policy_explicit_path
                                                        
                                                        	SR Policy Explicit paths
                                                        	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                                        
                                                        .. attribute:: sr_policy_preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: sr_tunnel_request_state
                                                        
                                                        	SR Tunnel Request State
                                                        	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                        
                                                        .. attribute:: sr_tunnel_state
                                                        
                                                        	SR Tunnel State
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encap Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: unknown_attribute
                                                        
                                                        	Unknown attributes
                                                        	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.aggregator_address = None
                                                            self.aggregator_as = None
                                                            self.aigp_metric_value = None
                                                            self.as_path = None
                                                            self.cluster = YList()
                                                            self.cluster.parent = self
                                                            self.cluster.name = 'cluster'
                                                            self.community = YList()
                                                            self.community.parent = self
                                                            self.community.name = 'community'
                                                            self.connector_type = None
                                                            self.connector_value = YList()
                                                            self.connector_value.parent = self
                                                            self.connector_value.name = 'connector_value'
                                                            self.extended_community = YList()
                                                            self.extended_community.parent = self
                                                            self.extended_community.name = 'extended_community'
                                                            self.extended_community_flags = None
                                                            self.is_aggregator_present = None
                                                            self.is_aigp_present = None
                                                            self.is_as_path_present = None
                                                            self.is_atomic_aggregate_present = None
                                                            self.is_community_present = None
                                                            self.is_connector_present = None
                                                            self.is_extended_community_present = None
                                                            self.is_label_index_present = None
                                                            self.is_local_pref_present = None
                                                            self.is_ls_attribute_present = None
                                                            self.is_metric_present = None
                                                            self.is_origin_present = None
                                                            self.is_pe_distinguisher_label_present = None
                                                            self.is_pmsi_present = None
                                                            self.is_pppmp_present = None
                                                            self.is_ssa_present = None
                                                            self.is_tunnel_encap_present = None
                                                            self.l2tpv3_cookie = YList()
                                                            self.l2tpv3_cookie.parent = self
                                                            self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                            self.l2tpv3_session_id = None
                                                            self.label_index_attr = YList()
                                                            self.label_index_attr.parent = self
                                                            self.label_index_attr.name = 'label_index_attr'
                                                            self.local_preference = None
                                                            self.ls_attr = YList()
                                                            self.ls_attr.parent = self
                                                            self.ls_attr.name = 'ls_attr'
                                                            self.metric = None
                                                            self.neighbor_as = None
                                                            self.origin = None
                                                            self.originator = None
                                                            self.pe_distinguisher_label = YList()
                                                            self.pe_distinguisher_label.parent = self
                                                            self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                            self.pmsi_flags = None
                                                            self.pmsi_label = None
                                                            self.pmsi_type = None
                                                            self.pmsi_value = YList()
                                                            self.pmsi_value.parent = self
                                                            self.pmsi_value.name = 'pmsi_value'
                                                            self.ppm_pvalue = None
                                                            self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                            self.sr_policy_allocated_binding_sid.parent = self
                                                            self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                            self.sr_policy_binding_sid.parent = self
                                                            self.sr_policy_explicit_path = YList()
                                                            self.sr_policy_explicit_path.parent = self
                                                            self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                            self.sr_policy_preference = None
                                                            self.sr_tunnel_request_state = None
                                                            self.sr_tunnel_state = None
                                                            self.tunnel_encap_type = None
                                                            self.unknown_attribute = YList()
                                                            self.unknown_attribute.parent = self
                                                            self.unknown_attribute.name = 'unknown_attribute'


                                                        class SrPolicyBindingSid(object):
                                                            """
                                                            SR Policy Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_address = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                                        class SrPolicyAllocatedBindingSid(object):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_address = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                                        class Community(object):
                                                            """
                                                            Community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                                        class ExtendedCommunity(object):
                                                            """
                                                            Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                                        class UnknownAttribute(object):
                                                            """
                                                            Unknown attributes
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                                        class Cluster(object):
                                                            """
                                                            Cluster list attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                                        class L2Tpv3Cookie(object):
                                                            """
                                                            L2TPv3 Cookie
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                                        class ConnectorValue(object):
                                                            """
                                                            Connector Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                                        class PmsiValue(object):
                                                            """
                                                            PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                                        class LsAttr(object):
                                                            """
                                                            BGP LS attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                                        class LabelIndexAttr(object):
                                                            """
                                                            Label Index attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                                        class PeDistinguisherLabel(object):
                                                            """
                                                            PE distinguisher label attribute
                                                            
                                                            .. attribute:: label
                                                            
                                                            	Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pe_address
                                                            
                                                            	 PE address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.label = None
                                                                self.pe_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.label is not None:
                                                                    return True

                                                                if self.pe_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                                        class SrPolicyExplicitPath(object):
                                                            """
                                                            SR Policy Explicit paths
                                                            
                                                            .. attribute:: sid
                                                            
                                                            	Sidlist for explicit path
                                                            	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of explicit path
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.sid = YList()
                                                                self.sid.parent = self
                                                                self.sid.name = 'sid'
                                                                self.weight = None


                                                            class Sid(object):
                                                                """
                                                                Sidlist for explicit path
                                                                
                                                                .. attribute:: ipv4
                                                                
                                                                	IP Address sid
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6
                                                                
                                                                	IPv6 address sid
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label sid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Sid Type
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4 = None
                                                                    self.ipv6 = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4 is not None:
                                                                        return True

                                                                    if self.ipv6 is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.sid is not None:
                                                                    for child_ref in self.sid:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.weight is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.aggregator_address is not None:
                                                                return True

                                                            if self.aggregator_as is not None:
                                                                return True

                                                            if self.aigp_metric_value is not None:
                                                                return True

                                                            if self.as_path is not None:
                                                                return True

                                                            if self.cluster is not None:
                                                                for child_ref in self.cluster:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.community is not None:
                                                                for child_ref in self.community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.connector_type is not None:
                                                                return True

                                                            if self.connector_value is not None:
                                                                for child_ref in self.connector_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.extended_community is not None:
                                                                for child_ref in self.extended_community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.extended_community_flags is not None:
                                                                return True

                                                            if self.is_aggregator_present is not None:
                                                                return True

                                                            if self.is_aigp_present is not None:
                                                                return True

                                                            if self.is_as_path_present is not None:
                                                                return True

                                                            if self.is_atomic_aggregate_present is not None:
                                                                return True

                                                            if self.is_community_present is not None:
                                                                return True

                                                            if self.is_connector_present is not None:
                                                                return True

                                                            if self.is_extended_community_present is not None:
                                                                return True

                                                            if self.is_label_index_present is not None:
                                                                return True

                                                            if self.is_local_pref_present is not None:
                                                                return True

                                                            if self.is_ls_attribute_present is not None:
                                                                return True

                                                            if self.is_metric_present is not None:
                                                                return True

                                                            if self.is_origin_present is not None:
                                                                return True

                                                            if self.is_pe_distinguisher_label_present is not None:
                                                                return True

                                                            if self.is_pmsi_present is not None:
                                                                return True

                                                            if self.is_pppmp_present is not None:
                                                                return True

                                                            if self.is_ssa_present is not None:
                                                                return True

                                                            if self.is_tunnel_encap_present is not None:
                                                                return True

                                                            if self.l2tpv3_cookie is not None:
                                                                for child_ref in self.l2tpv3_cookie:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.l2tpv3_session_id is not None:
                                                                return True

                                                            if self.label_index_attr is not None:
                                                                for child_ref in self.label_index_attr:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.local_preference is not None:
                                                                return True

                                                            if self.ls_attr is not None:
                                                                for child_ref in self.ls_attr:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.neighbor_as is not None:
                                                                return True

                                                            if self.origin is not None:
                                                                return True

                                                            if self.originator is not None:
                                                                return True

                                                            if self.pe_distinguisher_label is not None:
                                                                for child_ref in self.pe_distinguisher_label:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.pmsi_flags is not None:
                                                                return True

                                                            if self.pmsi_label is not None:
                                                                return True

                                                            if self.pmsi_type is not None:
                                                                return True

                                                            if self.pmsi_value is not None:
                                                                for child_ref in self.pmsi_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.ppm_pvalue is not None:
                                                                return True

                                                            if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                                return True

                                                            if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                                return True

                                                            if self.sr_policy_explicit_path is not None:
                                                                for child_ref in self.sr_policy_explicit_path:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.sr_policy_preference is not None:
                                                                return True

                                                            if self.sr_tunnel_request_state is not None:
                                                                return True

                                                            if self.sr_tunnel_state is not None:
                                                                return True

                                                            if self.tunnel_encap_type is not None:
                                                                return True

                                                            if self.unknown_attribute is not None:
                                                                for child_ref in self.unknown_attribute:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                                    class AttrSet(object):
                                                        """
                                                        ATTR\_SET attribute
                                                        
                                                        .. attribute:: aggregator_address
                                                        
                                                        	Address where aggregation was performed
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: aggregator_as
                                                        
                                                        	AS where aggregation was last performed
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: aigp_metric_value
                                                        
                                                        	AIGP metric value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: as_path
                                                        
                                                        	AS path attribute
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: cluster
                                                        
                                                        	Cluster list attribute
                                                        	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                        
                                                        .. attribute:: community
                                                        
                                                        	Community attribute
                                                        	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                        
                                                        .. attribute:: connector_type
                                                        
                                                        	Connector Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: connector_value
                                                        
                                                        	Connector Value
                                                        	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                        
                                                        .. attribute:: extended_community
                                                        
                                                        	Extended community attribute
                                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                        
                                                        .. attribute:: extended_community_flags
                                                        
                                                        	Extended community Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: is_aggregator_present
                                                        
                                                        	Aggregator attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_aigp_present
                                                        
                                                        	AIGP Present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_as_path_present
                                                        
                                                        	AS path attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_atomic_aggregate_present
                                                        
                                                        	Atomic aggregate attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_community_present
                                                        
                                                        	Community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_connector_present
                                                        
                                                        	Connector present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_extended_community_present
                                                        
                                                        	Extended community attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_label_index_present
                                                        
                                                        	Label Index attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_local_pref_present
                                                        
                                                        	Local Preference attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ls_attribute_present
                                                        
                                                        	BGP LS attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_metric_present
                                                        
                                                        	Metric attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_origin_present
                                                        
                                                        	Origin attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pe_distinguisher_label_present
                                                        
                                                        	PE distinguisher label  attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pmsi_present
                                                        
                                                        	PMSI Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_pppmp_present
                                                        
                                                        	PPMP Attribute  present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_ssa_present
                                                        
                                                        	SSA attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: is_tunnel_encap_present
                                                        
                                                        	Tunnel Encap attribute present 
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: l2tpv3_cookie
                                                        
                                                        	L2TPv3 Cookie
                                                        	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                                        
                                                        .. attribute:: l2tpv3_session_id
                                                        
                                                        	L2TPv3 session id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: label_index_attr
                                                        
                                                        	Label Index attribute
                                                        	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                                        
                                                        .. attribute:: local_preference
                                                        
                                                        	Local preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ls_attr
                                                        
                                                        	BGP LS attribute
                                                        	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: neighbor_as
                                                        
                                                        	Neighbor AS number
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: origin
                                                        
                                                        	Origin
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: originator
                                                        
                                                        	Originator attribute
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: pe_distinguisher_label
                                                        
                                                        	PE distinguisher label attribute
                                                        	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                        
                                                        .. attribute:: pmsi_flags
                                                        
                                                        	PMSI Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pmsi_label
                                                        
                                                        	PMSI label
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pmsi_type
                                                        
                                                        	PMSI Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: pmsi_value
                                                        
                                                        	PMSI Value
                                                        	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                        
                                                        .. attribute:: ppm_pvalue
                                                        
                                                        	PPMP Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: sr_policy_allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                                        
                                                        .. attribute:: sr_policy_binding_sid
                                                        
                                                        	SR Policy Binding sid
                                                        	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                                        
                                                        .. attribute:: sr_policy_explicit_path
                                                        
                                                        	SR Policy Explicit paths
                                                        	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                                        
                                                        .. attribute:: sr_policy_preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: sr_tunnel_request_state
                                                        
                                                        	SR Tunnel Request State
                                                        	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                                        
                                                        .. attribute:: sr_tunnel_state
                                                        
                                                        	SR Tunnel State
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encap Type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: unknown_attribute
                                                        
                                                        	Unknown attributes
                                                        	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.aggregator_address = None
                                                            self.aggregator_as = None
                                                            self.aigp_metric_value = None
                                                            self.as_path = None
                                                            self.cluster = YList()
                                                            self.cluster.parent = self
                                                            self.cluster.name = 'cluster'
                                                            self.community = YList()
                                                            self.community.parent = self
                                                            self.community.name = 'community'
                                                            self.connector_type = None
                                                            self.connector_value = YList()
                                                            self.connector_value.parent = self
                                                            self.connector_value.name = 'connector_value'
                                                            self.extended_community = YList()
                                                            self.extended_community.parent = self
                                                            self.extended_community.name = 'extended_community'
                                                            self.extended_community_flags = None
                                                            self.is_aggregator_present = None
                                                            self.is_aigp_present = None
                                                            self.is_as_path_present = None
                                                            self.is_atomic_aggregate_present = None
                                                            self.is_community_present = None
                                                            self.is_connector_present = None
                                                            self.is_extended_community_present = None
                                                            self.is_label_index_present = None
                                                            self.is_local_pref_present = None
                                                            self.is_ls_attribute_present = None
                                                            self.is_metric_present = None
                                                            self.is_origin_present = None
                                                            self.is_pe_distinguisher_label_present = None
                                                            self.is_pmsi_present = None
                                                            self.is_pppmp_present = None
                                                            self.is_ssa_present = None
                                                            self.is_tunnel_encap_present = None
                                                            self.l2tpv3_cookie = YList()
                                                            self.l2tpv3_cookie.parent = self
                                                            self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                            self.l2tpv3_session_id = None
                                                            self.label_index_attr = YList()
                                                            self.label_index_attr.parent = self
                                                            self.label_index_attr.name = 'label_index_attr'
                                                            self.local_preference = None
                                                            self.ls_attr = YList()
                                                            self.ls_attr.parent = self
                                                            self.ls_attr.name = 'ls_attr'
                                                            self.metric = None
                                                            self.neighbor_as = None
                                                            self.origin = None
                                                            self.originator = None
                                                            self.pe_distinguisher_label = YList()
                                                            self.pe_distinguisher_label.parent = self
                                                            self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                            self.pmsi_flags = None
                                                            self.pmsi_label = None
                                                            self.pmsi_type = None
                                                            self.pmsi_value = YList()
                                                            self.pmsi_value.parent = self
                                                            self.pmsi_value.name = 'pmsi_value'
                                                            self.ppm_pvalue = None
                                                            self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                            self.sr_policy_allocated_binding_sid.parent = self
                                                            self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                            self.sr_policy_binding_sid.parent = self
                                                            self.sr_policy_explicit_path = YList()
                                                            self.sr_policy_explicit_path.parent = self
                                                            self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                            self.sr_policy_preference = None
                                                            self.sr_tunnel_request_state = None
                                                            self.sr_tunnel_state = None
                                                            self.tunnel_encap_type = None
                                                            self.unknown_attribute = YList()
                                                            self.unknown_attribute.parent = self
                                                            self.unknown_attribute.name = 'unknown_attribute'


                                                        class SrPolicyBindingSid(object):
                                                            """
                                                            SR Policy Binding sid
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_address = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                                        class SrPolicyAllocatedBindingSid(object):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_address = None
                                                                self.label = None
                                                                self.type = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_address is not None:
                                                                    return True

                                                                if self.label is not None:
                                                                    return True

                                                                if self.type is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                                        class Community(object):
                                                            """
                                                            Community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                                        class ExtendedCommunity(object):
                                                            """
                                                            Extended community attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                                        class UnknownAttribute(object):
                                                            """
                                                            Unknown attributes
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                                        class Cluster(object):
                                                            """
                                                            Cluster list attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                                        class L2Tpv3Cookie(object):
                                                            """
                                                            L2TPv3 Cookie
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                                        class ConnectorValue(object):
                                                            """
                                                            Connector Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                                        class PmsiValue(object):
                                                            """
                                                            PMSI Value
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                                        class LsAttr(object):
                                                            """
                                                            BGP LS attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                                        class LabelIndexAttr(object):
                                                            """
                                                            Label Index attribute
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.entry = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.entry is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                                        class PeDistinguisherLabel(object):
                                                            """
                                                            PE distinguisher label attribute
                                                            
                                                            .. attribute:: label
                                                            
                                                            	Label
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: pe_address
                                                            
                                                            	 PE address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.label = None
                                                                self.pe_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.label is not None:
                                                                    return True

                                                                if self.pe_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                                        class SrPolicyExplicitPath(object):
                                                            """
                                                            SR Policy Explicit paths
                                                            
                                                            .. attribute:: sid
                                                            
                                                            	Sidlist for explicit path
                                                            	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of explicit path
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.sid = YList()
                                                                self.sid.parent = self
                                                                self.sid.name = 'sid'
                                                                self.weight = None


                                                            class Sid(object):
                                                                """
                                                                Sidlist for explicit path
                                                                
                                                                .. attribute:: ipv4
                                                                
                                                                	IP Address sid
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6
                                                                
                                                                	IPv6 address sid
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label sid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Sid Type
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2015-08-27'

                                                                def __init__(self):
                                                                    self.parent = None
                                                                    self.ipv4 = None
                                                                    self.ipv6 = None
                                                                    self.label = None
                                                                    self.type = None

                                                                @property
                                                                def _common_path(self):
                                                                    if self.parent is None:
                                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                                def is_config(self):
                                                                    ''' Returns True if this instance represents config data else returns False '''
                                                                    return False

                                                                def _has_data(self):
                                                                    if not self.is_config():
                                                                        return False
                                                                    if self.ipv4 is not None:
                                                                        return True

                                                                    if self.ipv6 is not None:
                                                                        return True

                                                                    if self.label is not None:
                                                                        return True

                                                                    if self.type is not None:
                                                                        return True

                                                                    return False

                                                                @staticmethod
                                                                def _meta_info():
                                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.sid is not None:
                                                                    for child_ref in self.sid:
                                                                        if child_ref._has_data():
                                                                            return True

                                                                if self.weight is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.aggregator_address is not None:
                                                                return True

                                                            if self.aggregator_as is not None:
                                                                return True

                                                            if self.aigp_metric_value is not None:
                                                                return True

                                                            if self.as_path is not None:
                                                                return True

                                                            if self.cluster is not None:
                                                                for child_ref in self.cluster:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.community is not None:
                                                                for child_ref in self.community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.connector_type is not None:
                                                                return True

                                                            if self.connector_value is not None:
                                                                for child_ref in self.connector_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.extended_community is not None:
                                                                for child_ref in self.extended_community:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.extended_community_flags is not None:
                                                                return True

                                                            if self.is_aggregator_present is not None:
                                                                return True

                                                            if self.is_aigp_present is not None:
                                                                return True

                                                            if self.is_as_path_present is not None:
                                                                return True

                                                            if self.is_atomic_aggregate_present is not None:
                                                                return True

                                                            if self.is_community_present is not None:
                                                                return True

                                                            if self.is_connector_present is not None:
                                                                return True

                                                            if self.is_extended_community_present is not None:
                                                                return True

                                                            if self.is_label_index_present is not None:
                                                                return True

                                                            if self.is_local_pref_present is not None:
                                                                return True

                                                            if self.is_ls_attribute_present is not None:
                                                                return True

                                                            if self.is_metric_present is not None:
                                                                return True

                                                            if self.is_origin_present is not None:
                                                                return True

                                                            if self.is_pe_distinguisher_label_present is not None:
                                                                return True

                                                            if self.is_pmsi_present is not None:
                                                                return True

                                                            if self.is_pppmp_present is not None:
                                                                return True

                                                            if self.is_ssa_present is not None:
                                                                return True

                                                            if self.is_tunnel_encap_present is not None:
                                                                return True

                                                            if self.l2tpv3_cookie is not None:
                                                                for child_ref in self.l2tpv3_cookie:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.l2tpv3_session_id is not None:
                                                                return True

                                                            if self.label_index_attr is not None:
                                                                for child_ref in self.label_index_attr:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.local_preference is not None:
                                                                return True

                                                            if self.ls_attr is not None:
                                                                for child_ref in self.ls_attr:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.metric is not None:
                                                                return True

                                                            if self.neighbor_as is not None:
                                                                return True

                                                            if self.origin is not None:
                                                                return True

                                                            if self.originator is not None:
                                                                return True

                                                            if self.pe_distinguisher_label is not None:
                                                                for child_ref in self.pe_distinguisher_label:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.pmsi_flags is not None:
                                                                return True

                                                            if self.pmsi_label is not None:
                                                                return True

                                                            if self.pmsi_type is not None:
                                                                return True

                                                            if self.pmsi_value is not None:
                                                                for child_ref in self.pmsi_value:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.ppm_pvalue is not None:
                                                                return True

                                                            if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                                return True

                                                            if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                                return True

                                                            if self.sr_policy_explicit_path is not None:
                                                                for child_ref in self.sr_policy_explicit_path:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            if self.sr_policy_preference is not None:
                                                                return True

                                                            if self.sr_tunnel_request_state is not None:
                                                                return True

                                                            if self.sr_tunnel_state is not None:
                                                                return True

                                                            if self.tunnel_encap_type is not None:
                                                                return True

                                                            if self.unknown_attribute is not None:
                                                                for child_ref in self.unknown_attribute:
                                                                    if child_ref._has_data():
                                                                        return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                                    class RnhAddr(object):
                                                        """
                                                        RNH Address
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: len
                                                        
                                                        	len
                                                        	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                                        
                                                        .. attribute:: mac_address
                                                        
                                                        	MAC Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_address = None
                                                            self.ipv6_address = None
                                                            self.len = None
                                                            self.mac_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.len is not None:
                                                                return True

                                                            if self.mac_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                                    class RibrnhIp(object):
                                                        """
                                                        RIB RNH IP Address
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: ipv4sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv6sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                                        
                                                        .. attribute:: l2vpnvpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4mdt_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                            self.ipv4sr_policy_address.parent = self
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                            self.ipv6sr_policy_address.parent = self
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_flowspec_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                            self.l2vpnvpls_address.parent = self
                                                            self.ls_ls_address = None
                                                            self.rt_constraint_address = None


                                                        class L2VpnvplsAddress(object):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                                        class L2VpnMspwAddress(object):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.l2vpn_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.l2vpn_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                                        class Ipv4SrPolicyAddress(object):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv4_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv4_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                                        class Ipv6SrPolicyAddress(object):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2015-08-27'

                                                            def __init__(self):
                                                                self.parent = None
                                                                self.ipv6_srpolicy_address = None

                                                            @property
                                                            def _common_path(self):
                                                                if self.parent is None:
                                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                            def is_config(self):
                                                                ''' Returns True if this instance represents config data else returns False '''
                                                                return False

                                                            def _has_data(self):
                                                                if not self.is_config():
                                                                    return False
                                                                if self.ipv6_srpolicy_address is not None:
                                                                    return True

                                                                return False

                                                            @staticmethod
                                                            def _meta_info():
                                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.afi is not None:
                                                                return True

                                                            if self.ipv4_address is not None:
                                                                return True

                                                            if self.ipv4_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4_label_address is not None:
                                                                return True

                                                            if self.ipv4_mcast_address is not None:
                                                                return True

                                                            if self.ipv4_tunnel_address is not None:
                                                                return True

                                                            if self.ipv4mdt_address is not None:
                                                                return True

                                                            if self.ipv4mvpn_address is not None:
                                                                return True

                                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv4vpn_address is not None:
                                                                return True

                                                            if self.ipv4vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv4vpna_mcastddress is not None:
                                                                return True

                                                            if self.ipv6_address is not None:
                                                                return True

                                                            if self.ipv6_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6_label_address is not None:
                                                                return True

                                                            if self.ipv6_mcast_address is not None:
                                                                return True

                                                            if self.ipv6mvpn_address is not None:
                                                                return True

                                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                                return True

                                                            if self.ipv6vpn_address is not None:
                                                                return True

                                                            if self.ipv6vpn_flowspec_address is not None:
                                                                return True

                                                            if self.ipv6vpn_mcast_address is not None:
                                                                return True

                                                            if self.l2vpn_evpn_address is not None:
                                                                return True

                                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                                return True

                                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                                return True

                                                            if self.ls_ls_address is not None:
                                                                return True

                                                            if self.rt_constraint_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.attr_set is not None and self.attr_set._has_data():
                                                            return True

                                                        if self.attribute_key_number is not None:
                                                            return True

                                                        if self.attribute_reuse_id_config is not None:
                                                            return True

                                                        if self.attribute_reuse_id_current is not None:
                                                            return True

                                                        if self.attribute_reuse_id_keys is not None:
                                                            return True

                                                        if self.attribute_reuse_id_max_id is not None:
                                                            return True

                                                        if self.attribute_reuse_id_node is not None:
                                                            return True

                                                        if self.attribute_reuse_id_recover_sec is not None:
                                                            return True

                                                        if self.common_attributes is not None and self.common_attributes._has_data():
                                                            return True

                                                        if self.is_application_gateway_present is not None:
                                                            return True

                                                        if self.is_as_path2_byte is not None:
                                                            return True

                                                        if self.is_attr_set_present is not None:
                                                            return True

                                                        if self.is_ribrnh_present is not None:
                                                            return True

                                                        if self.is_rnh_present is not None:
                                                            return True

                                                        if self.ribrnh_encap is not None:
                                                            return True

                                                        if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                            return True

                                                        if self.ribrnh_mac is not None:
                                                            return True

                                                        if self.ribrnh_table is not None:
                                                            return True

                                                        if self.ribrnh_vni is not None:
                                                            return True

                                                        if self.ribrnhip_table is not None:
                                                            return True

                                                        if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                            return True

                                                        if self.rnh_addr_len is not None:
                                                            return True

                                                        if self.rnh_len is not None:
                                                            return True

                                                        if self.rnh_type is not None:
                                                            return True

                                                        if self.set_aigp_inbound_igp is not None:
                                                            return True

                                                        if self.set_aigp_inbound_metric is not None:
                                                            return True

                                                        if self.vpn_distinguisher is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath.AttributesAfterPolicyIn']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-process-instance-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.af_name is not None:
                                                        return True

                                                    if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                                        return True

                                                    if self.label_fail is not None:
                                                        return True

                                                    if self.label_o_or_version is not None:
                                                        return True

                                                    if self.label_oor is not None:
                                                        return True

                                                    if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                                        return True

                                                    if self.no_path is not None:
                                                        return True

                                                    if self.path_information is not None and self.path_information._has_data():
                                                        return True

                                                    if self.prefix_version is not None:
                                                        return True

                                                    if self.process_instance_id is not None:
                                                        return True

                                                    if self.route_distinguisher is not None:
                                                        return True

                                                    if self.source_route_distinguisher is not None:
                                                        return True

                                                    if self.source_vrf_name is not None:
                                                        return True

                                                    if self.srcaf_name is not None:
                                                        return True

                                                    if self.vrf_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActiveProcessInstancePath']['meta_info']


                                            class LocalPathElement(object):
                                                """
                                                Local path element list
                                                
                                                .. attribute:: is_perm_path_pelem
                                                
                                                	Pelem for permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: nhte_tunnel
                                                
                                                	NH TE tunnel information
                                                	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.NhteTunnel>`
                                                
                                                .. attribute:: pelem_flags
                                                
                                                	Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_gw_metric
                                                
                                                	Gateway metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_no_addpath_table_attr_version
                                                
                                                	No\-addpath Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_no_bestpath_table_attr_version
                                                
                                                	No\-bestpath Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_flags
                                                
                                                	Path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pelem_path_id
                                                
                                                	Local Path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_neighbor_addr
                                                
                                                	Path neighbor address
                                                	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr>`
                                                
                                                .. attribute:: pelem_path_nexthop
                                                
                                                	Path nexthop address
                                                	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop>`
                                                
                                                .. attribute:: pelem_path_peer_path_id
                                                
                                                	Path peer path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_table_attr_version
                                                
                                                	Path Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_table_attr_version
                                                
                                                	Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_version
                                                
                                                	Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_perm_path_pelem = None
                                                    self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.NhteTunnel()
                                                    self.nhte_tunnel.parent = self
                                                    self.pelem_flags = None
                                                    self.pelem_gw_metric = None
                                                    self.pelem_no_addpath_table_attr_version = None
                                                    self.pelem_no_bestpath_table_attr_version = None
                                                    self.pelem_path_flags = None
                                                    self.pelem_path_id = None
                                                    self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr()
                                                    self.pelem_path_neighbor_addr.parent = self
                                                    self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop()
                                                    self.pelem_path_nexthop.parent = self
                                                    self.pelem_path_peer_path_id = None
                                                    self.pelem_path_table_attr_version = None
                                                    self.pelem_table_attr_version = None
                                                    self.pelem_version = None


                                                class PelemPathNexthop(object):
                                                    """
                                                    Path nexthop address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-nexthop'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNexthop']['meta_info']


                                                class NhteTunnel(object):
                                                    """
                                                    NH TE tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_te_tunnel
                                                    
                                                    	NH TE Tunnel info is present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last rib update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	tunnel name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	tunnel type
                                                    	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.binding_label = None
                                                        self.has_te_tunnel = None
                                                        self.is_tunnel_info_stale = None
                                                        self.is_tunnel_registered = None
                                                        self.is_tunnel_up = None
                                                        self.last_tunnel_update = None
                                                        self.tunnel_if_handle = None
                                                        self.tunnel_name = None
                                                        self.tunnel_type = None
                                                        self.tunnel_v6_enabled = None
                                                        self.tunnel_v6_required = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.binding_label is not None:
                                                            return True

                                                        if self.has_te_tunnel is not None:
                                                            return True

                                                        if self.is_tunnel_info_stale is not None:
                                                            return True

                                                        if self.is_tunnel_registered is not None:
                                                            return True

                                                        if self.is_tunnel_up is not None:
                                                            return True

                                                        if self.last_tunnel_update is not None:
                                                            return True

                                                        if self.tunnel_if_handle is not None:
                                                            return True

                                                        if self.tunnel_name is not None:
                                                            return True

                                                        if self.tunnel_type is not None:
                                                            return True

                                                        if self.tunnel_v6_enabled is not None:
                                                            return True

                                                        if self.tunnel_v6_required is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.NhteTunnel']['meta_info']


                                                class PelemPathNeighborAddr(object):
                                                    """
                                                    Path neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-neighbor-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement.PelemPathNeighborAddr']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-path-element'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_perm_path_pelem is not None:
                                                        return True

                                                    if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                        return True

                                                    if self.pelem_flags is not None:
                                                        return True

                                                    if self.pelem_gw_metric is not None:
                                                        return True

                                                    if self.pelem_no_addpath_table_attr_version is not None:
                                                        return True

                                                    if self.pelem_no_bestpath_table_attr_version is not None:
                                                        return True

                                                    if self.pelem_path_flags is not None:
                                                        return True

                                                    if self.pelem_path_id is not None:
                                                        return True

                                                    if self.pelem_path_neighbor_addr is not None and self.pelem_path_neighbor_addr._has_data():
                                                        return True

                                                    if self.pelem_path_nexthop is not None and self.pelem_path_nexthop._has_data():
                                                        return True

                                                    if self.pelem_path_peer_path_id is not None:
                                                        return True

                                                    if self.pelem_path_table_attr_version is not None:
                                                        return True

                                                    if self.pelem_table_attr_version is not None:
                                                        return True

                                                    if self.pelem_version is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.LocalPathElement']['meta_info']


                                            class ActivePathElement(object):
                                                """
                                                Path element list received from Active inst
                                                
                                                .. attribute:: is_perm_path_pelem
                                                
                                                	Pelem for permanent path
                                                	**type**\:  bool
                                                
                                                .. attribute:: nhte_tunnel
                                                
                                                	NH TE tunnel information
                                                	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.NhteTunnel>`
                                                
                                                .. attribute:: pelem_flags
                                                
                                                	Flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_gw_metric
                                                
                                                	Gateway metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_no_addpath_table_attr_version
                                                
                                                	No\-addpath Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_no_bestpath_table_attr_version
                                                
                                                	No\-bestpath Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_flags
                                                
                                                	Path flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pelem_path_id
                                                
                                                	Local Path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_neighbor_addr
                                                
                                                	Path neighbor address
                                                	**type**\:   :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr>`
                                                
                                                .. attribute:: pelem_path_nexthop
                                                
                                                	Path nexthop address
                                                	**type**\:   :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop>`
                                                
                                                .. attribute:: pelem_path_peer_path_id
                                                
                                                	Path peer path ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_path_table_attr_version
                                                
                                                	Path Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_table_attr_version
                                                
                                                	Table Attr version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pelem_version
                                                
                                                	Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.is_perm_path_pelem = None
                                                    self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.NhteTunnel()
                                                    self.nhte_tunnel.parent = self
                                                    self.pelem_flags = None
                                                    self.pelem_gw_metric = None
                                                    self.pelem_no_addpath_table_attr_version = None
                                                    self.pelem_no_bestpath_table_attr_version = None
                                                    self.pelem_path_flags = None
                                                    self.pelem_path_id = None
                                                    self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr()
                                                    self.pelem_path_neighbor_addr.parent = self
                                                    self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop()
                                                    self.pelem_path_nexthop.parent = self
                                                    self.pelem_path_peer_path_id = None
                                                    self.pelem_path_table_attr_version = None
                                                    self.pelem_table_attr_version = None
                                                    self.pelem_version = None


                                                class PelemPathNexthop(object):
                                                    """
                                                    Path nexthop address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-nexthop'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNexthop']['meta_info']


                                                class NhteTunnel(object):
                                                    """
                                                    NH TE tunnel information
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_te_tunnel
                                                    
                                                    	NH TE Tunnel info is present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last rib update happened
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	tunnel name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	tunnel type
                                                    	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.binding_label = None
                                                        self.has_te_tunnel = None
                                                        self.is_tunnel_info_stale = None
                                                        self.is_tunnel_registered = None
                                                        self.is_tunnel_up = None
                                                        self.last_tunnel_update = None
                                                        self.tunnel_if_handle = None
                                                        self.tunnel_name = None
                                                        self.tunnel_type = None
                                                        self.tunnel_v6_enabled = None
                                                        self.tunnel_v6_required = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.binding_label is not None:
                                                            return True

                                                        if self.has_te_tunnel is not None:
                                                            return True

                                                        if self.is_tunnel_info_stale is not None:
                                                            return True

                                                        if self.is_tunnel_registered is not None:
                                                            return True

                                                        if self.is_tunnel_up is not None:
                                                            return True

                                                        if self.last_tunnel_update is not None:
                                                            return True

                                                        if self.tunnel_if_handle is not None:
                                                            return True

                                                        if self.tunnel_name is not None:
                                                            return True

                                                        if self.tunnel_type is not None:
                                                            return True

                                                        if self.tunnel_v6_enabled is not None:
                                                            return True

                                                        if self.tunnel_v6_required is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.NhteTunnel']['meta_info']


                                                class PelemPathNeighborAddr(object):
                                                    """
                                                    Path neighbor address
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pelem-path-neighbor-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement.PelemPathNeighborAddr']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-path-element'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.is_perm_path_pelem is not None:
                                                        return True

                                                    if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                        return True

                                                    if self.pelem_flags is not None:
                                                        return True

                                                    if self.pelem_gw_metric is not None:
                                                        return True

                                                    if self.pelem_no_addpath_table_attr_version is not None:
                                                        return True

                                                    if self.pelem_no_bestpath_table_attr_version is not None:
                                                        return True

                                                    if self.pelem_path_flags is not None:
                                                        return True

                                                    if self.pelem_path_id is not None:
                                                        return True

                                                    if self.pelem_path_neighbor_addr is not None and self.pelem_path_neighbor_addr._has_data():
                                                        return True

                                                    if self.pelem_path_nexthop is not None and self.pelem_path_nexthop._has_data():
                                                        return True

                                                    if self.pelem_path_peer_path_id is not None:
                                                        return True

                                                    if self.pelem_path_table_attr_version is not None:
                                                        return True

                                                    if self.pelem_table_attr_version is not None:
                                                        return True

                                                    if self.pelem_version is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd.ActivePathElement']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                                if self.rd is None:
                                                    raise YPYModelError('Key property rd is None')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-rd[Cisco-IOS-XR-ipv4-bgp-oper:rd = ' + str(self.rd) + ']'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.rd is not None:
                                                    return True

                                                if self.active_path_element is not None:
                                                    for child_ref in self.active_path_element:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.active_process_instance_path is not None:
                                                    for child_ref in self.active_process_instance_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.add_path_orr_bitfield is not None:
                                                    for child_ref in self.add_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.advertisedto_pe is not None:
                                                    return True

                                                if self.af_name is not None:
                                                    return True

                                                if self.best_path_orr_bitfield is not None:
                                                    for child_ref in self.best_path_orr_bitfield:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                    return True

                                                if self.bit is not None:
                                                    return True

                                                if self.flags is not None:
                                                    return True

                                                if self.gateway_array is not None:
                                                    return True

                                                if self.has_inconsistent_paths is not None:
                                                    return True

                                                if self.has_lbl_retained is not None:
                                                    return True

                                                if self.has_local_label is not None:
                                                    return True

                                                if self.is_net_aggregation_suppressed is not None:
                                                    return True

                                                if self.is_net_ldp_signaled is not None:
                                                    return True

                                                if self.is_permanent_network is not None:
                                                    return True

                                                if self.local_path_element is not None:
                                                    for child_ref in self.local_path_element:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_peers_advertised_to is not None:
                                                    for child_ref in self.local_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_process_instance_path is not None:
                                                    for child_ref in self.local_process_instance_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.net_backup_available is not None:
                                                    return True

                                                if self.net_backup_label_rewrite_available is not None:
                                                    return True

                                                if self.net_eibgp_multipath is not None:
                                                    return True

                                                if self.net_extended_flags is not None:
                                                    return True

                                                if self.net_flags is not None:
                                                    return True

                                                if self.net_local_label is not None:
                                                    return True

                                                if self.net_local_label_rewrite is not None:
                                                    return True

                                                if self.net_local_label_srgb is not None:
                                                    return True

                                                if self.net_multipath is not None:
                                                    return True

                                                if self.num_of_path is not None:
                                                    return True

                                                if self.pe_peers_advertised_to is not None:
                                                    for child_ref in self.pe_peers_advertised_to:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.process_instance_id is not None:
                                                    return True

                                                if self.resilient_nexthop_set is not None:
                                                    return True

                                                if self.rib_failed is not None:
                                                    return True

                                                if self.route_distinguisher is not None:
                                                    return True

                                                if self.table_brib_version is not None:
                                                    return True

                                                if self.table_version is not None:
                                                    return True

                                                if self.version is not None:
                                                    return True

                                                if self.version_age is not None and self.version_age._has_data():
                                                    return True

                                                if self.version_timestamp is not None and self.version_timestamp._has_data():
                                                    return True

                                                if self.vrf_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds.NetworkRd']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-rds'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.network_rd is not None:
                                                for child_ref in self.network_rd:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd.NetworkRds']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.network_addr is None:
                                            raise YPYModelError('Key property network_addr is None')
                                        if self.network_prefix is None:
                                            raise YPYModelError('Key property network_prefix is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-all-rd[Cisco-IOS-XR-ipv4-bgp-oper:network-addr = ' + str(self.network_addr) + '][Cisco-IOS-XR-ipv4-bgp-oper:network-prefix = ' + str(self.network_prefix) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.network_addr is not None:
                                            return True

                                        if self.network_prefix is not None:
                                            return True

                                        if self.network_rds is not None and self.network_rds._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds.NetworkAllRd']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:network-all-rds'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.network_all_rd is not None:
                                        for child_ref in self.network_all_rd:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NetworkAllRds']['meta_info']


                            class UpdateGenerationNeighbors(object):
                                """
                                Update generation for all neighbors
                                
                                .. attribute:: update_generation_neighbor
                                
                                	Update generation for neighbor
                                	**type**\: list of    :py:class:`UpdateGenerationNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.update_generation_neighbor = YList()
                                    self.update_generation_neighbor.parent = self
                                    self.update_generation_neighbor.name = 'update_generation_neighbor'


                                class UpdateGenerationNeighbor(object):
                                    """
                                    Update generation for neighbor
                                    
                                    .. attribute:: ack_version
                                    
                                    	Ack version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: current_update_group_af_name
                                    
                                    	Current Update\-group address\-family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: default_originate_internal_context
                                    
                                    	Default\-origination context
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: default_originate_state
                                    
                                    	Default\-origination state
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: filter_group_index
                                    
                                    	Filter\-group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: first_default_originate_timestamp
                                    
                                    	First default\-origination time
                                    	**type**\:   :py:class:`FirstDefaultOriginateTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp>`
                                    
                                    .. attribute:: first_update_queued_timestamp
                                    
                                    	First update queued time
                                    	**type**\:   :py:class:`FirstUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp>`
                                    
                                    .. attribute:: first_update_write_timestamp
                                    
                                    	First update write time
                                    	**type**\:   :py:class:`FirstUpdateWriteTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp>`
                                    
                                    .. attribute:: inbound_refresh_count
                                    
                                    	Refresh Inbound count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_eor_outstanding
                                    
                                    	Number of EORs outstanding
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_update_group_timer_running
                                    
                                    	Is update\-group timer running
                                    	**type**\:  bool
                                    
                                    .. attribute:: last_default_originate_age
                                    
                                    	Time since last default\-origination event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_default_originate_timestamp
                                    
                                    	Last default\-origination time
                                    	**type**\:   :py:class:`LastDefaultOriginateTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp>`
                                    
                                    .. attribute:: last_filter_group_add_timestamp
                                    
                                    	Last added time
                                    	**type**\:   :py:class:`LastFilterGroupAddTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp>`
                                    
                                    .. attribute:: last_filter_group_remove_timestamp
                                    
                                    	Last removed time
                                    	**type**\:   :py:class:`LastFilterGroupRemoveTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp>`
                                    
                                    .. attribute:: last_refresh_update_queued_age
                                    
                                    	Time since last refresh update queued event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_refresh_update_queued_timestamp
                                    
                                    	Last refresh update queued time
                                    	**type**\:   :py:class:`LastRefreshUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp>`
                                    
                                    .. attribute:: last_refresh_update_write_age
                                    
                                    	Time since last refresh update write event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_refresh_update_write_timestamp
                                    
                                    	Last refresh update write time
                                    	**type**\:   :py:class:`LastRefreshUpdateWriteTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp>`
                                    
                                    .. attribute:: last_sub_group_add_timestamp
                                    
                                    	Last added time
                                    	**type**\:   :py:class:`LastSubGroupAddTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp>`
                                    
                                    .. attribute:: last_sub_group_remove_timestamp
                                    
                                    	Last removed time
                                    	**type**\:   :py:class:`LastSubGroupRemoveTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp>`
                                    
                                    .. attribute:: last_update_group_af_name
                                    
                                    	Last Update\-group address\-family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: last_update_group_expiry_timestamp
                                    
                                    	Last update\-group timer expiry
                                    	**type**\:   :py:class:`LastUpdateGroupExpiryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp>`
                                    
                                    .. attribute:: last_update_group_start_timestamp
                                    
                                    	Last update\-group timer start
                                    	**type**\:   :py:class:`LastUpdateGroupStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp>`
                                    
                                    .. attribute:: last_update_queued_age
                                    
                                    	Time since last update queued event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_queued_timestamp
                                    
                                    	Last update queued time
                                    	**type**\:   :py:class:`LastUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp>`
                                    
                                    .. attribute:: last_update_write_age
                                    
                                    	Time since last update write event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_write_timestamp
                                    
                                    	Last update write time
                                    	**type**\:   :py:class:`LastUpdateWriteTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp>`
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: next_resume_version
                                    
                                    	Resume version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: outbound_refresh_count
                                    
                                    	Refresh Outbound count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: outstanding_version_count
                                    
                                    	Outstanding version count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pending_target_version
                                    
                                    	Pending target version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_id
                                    
                                    	ProcessID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_ack_version
                                    
                                    	Refresh Ack version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_filter_group_index
                                    
                                    	Refresh Filter\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_next_resume_version
                                    
                                    	Refresh resume version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_pending_target_version
                                    
                                    	Pending refresh target version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_requested_target_version
                                    
                                    	Requested refresh target version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_id
                                    
                                    	Refresh sub\-group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_index
                                    
                                    	Refresh Sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_update_out_queue_messages
                                    
                                    	Refresh OutQueue messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_update_out_queue_size
                                    
                                    	Refresh OutQueue size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_id
                                    
                                    	Sub\-group ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sub_group_index
                                    
                                    	Sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sub_group_index_xr
                                    
                                    	Sub\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: synced_ack_version
                                    
                                    	Synced ack version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_filter_group_index
                                    
                                    	Filter\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_filter_group_messages
                                    
                                    	Filter\-group messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_group_af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: update_group_index
                                    
                                    	Update\-group index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: update_group_index_xr
                                    
                                    	Update\-group index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_main_table_version
                                    
                                    	Main table version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\:   :py:class:`UpdateNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress>`
                                    
                                    .. attribute:: update_out_queue_messages
                                    
                                    	OutQueue messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_size
                                    
                                    	OutQueue size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_refresh_target_version
                                    
                                    	Refresh target version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_refresh_version
                                    
                                    	Refresh version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_statistics
                                    
                                    	Update statistics
                                    	**type**\:   :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics>`
                                    
                                    .. attribute:: update_vrf_name
                                    
                                    	VRF Name
                                    	**type**\:  str
                                    
                                    .. attribute:: update_vrf_table_rib_version
                                    
                                    	VRF Table RIB version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version
                                    
                                    	Version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ack_version = None
                                        self.current_update_group_af_name = None
                                        self.default_originate_internal_context = None
                                        self.default_originate_state = None
                                        self.filter_group_index = None
                                        self.first_default_originate_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp()
                                        self.first_default_originate_timestamp.parent = self
                                        self.first_update_queued_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp()
                                        self.first_update_queued_timestamp.parent = self
                                        self.first_update_write_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp()
                                        self.first_update_write_timestamp.parent = self
                                        self.inbound_refresh_count = None
                                        self.is_eor_outstanding = None
                                        self.is_update_group_timer_running = None
                                        self.last_default_originate_age = None
                                        self.last_default_originate_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp()
                                        self.last_default_originate_timestamp.parent = self
                                        self.last_filter_group_add_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp()
                                        self.last_filter_group_add_timestamp.parent = self
                                        self.last_filter_group_remove_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp()
                                        self.last_filter_group_remove_timestamp.parent = self
                                        self.last_refresh_update_queued_age = None
                                        self.last_refresh_update_queued_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp()
                                        self.last_refresh_update_queued_timestamp.parent = self
                                        self.last_refresh_update_write_age = None
                                        self.last_refresh_update_write_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp()
                                        self.last_refresh_update_write_timestamp.parent = self
                                        self.last_sub_group_add_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp()
                                        self.last_sub_group_add_timestamp.parent = self
                                        self.last_sub_group_remove_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp()
                                        self.last_sub_group_remove_timestamp.parent = self
                                        self.last_update_group_af_name = None
                                        self.last_update_group_expiry_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp()
                                        self.last_update_group_expiry_timestamp.parent = self
                                        self.last_update_group_start_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp()
                                        self.last_update_group_start_timestamp.parent = self
                                        self.last_update_queued_age = None
                                        self.last_update_queued_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp()
                                        self.last_update_queued_timestamp.parent = self
                                        self.last_update_write_age = None
                                        self.last_update_write_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp()
                                        self.last_update_write_timestamp.parent = self
                                        self.neighbor_address = None
                                        self.next_resume_version = None
                                        self.outbound_refresh_count = None
                                        self.outstanding_version_count = None
                                        self.pending_target_version = None
                                        self.process_id = None
                                        self.refresh_ack_version = None
                                        self.refresh_filter_group_index = None
                                        self.refresh_next_resume_version = None
                                        self.refresh_pending_target_version = None
                                        self.refresh_requested_target_version = None
                                        self.refresh_sub_group_id = None
                                        self.refresh_sub_group_index = None
                                        self.refresh_update_out_queue_messages = None
                                        self.refresh_update_out_queue_size = None
                                        self.sub_group_id = None
                                        self.sub_group_index = None
                                        self.sub_group_index_xr = None
                                        self.synced_ack_version = None
                                        self.update_filter_group_index = None
                                        self.update_filter_group_messages = None
                                        self.update_group_af_name = None
                                        self.update_group_index = None
                                        self.update_group_index_xr = None
                                        self.update_main_table_version = None
                                        self.update_neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress()
                                        self.update_neighbor_address.parent = self
                                        self.update_out_queue_messages = None
                                        self.update_out_queue_size = None
                                        self.update_refresh_target_version = None
                                        self.update_refresh_version = None
                                        self.update_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics()
                                        self.update_statistics.parent = self
                                        self.update_vrf_name = None
                                        self.update_vrf_table_rib_version = None
                                        self.version = None


                                    class UpdateNeighborAddress(object):
                                        """
                                        Neighbor address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-neighbor-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress']['meta_info']


                                    class LastSubGroupAddTimestamp(object):
                                        """
                                        Last added time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-sub-group-add-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp']['meta_info']


                                    class LastSubGroupRemoveTimestamp(object):
                                        """
                                        Last removed time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-sub-group-remove-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp']['meta_info']


                                    class LastFilterGroupAddTimestamp(object):
                                        """
                                        Last added time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-filter-group-add-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp']['meta_info']


                                    class LastFilterGroupRemoveTimestamp(object):
                                        """
                                        Last removed time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-filter-group-remove-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp']['meta_info']


                                    class FirstDefaultOriginateTimestamp(object):
                                        """
                                        First default\-origination time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-default-originate-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp']['meta_info']


                                    class LastDefaultOriginateTimestamp(object):
                                        """
                                        Last default\-origination time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-default-originate-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp']['meta_info']


                                    class LastUpdateGroupStartTimestamp(object):
                                        """
                                        Last update\-group timer start
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-group-start-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp']['meta_info']


                                    class LastUpdateGroupExpiryTimestamp(object):
                                        """
                                        Last update\-group timer expiry
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-group-expiry-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp']['meta_info']


                                    class FirstUpdateQueuedTimestamp(object):
                                        """
                                        First update queued time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-update-queued-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp']['meta_info']


                                    class LastUpdateQueuedTimestamp(object):
                                        """
                                        Last update queued time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-queued-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp']['meta_info']


                                    class LastRefreshUpdateQueuedTimestamp(object):
                                        """
                                        Last refresh update queued time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-refresh-update-queued-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp']['meta_info']


                                    class FirstUpdateWriteTimestamp(object):
                                        """
                                        First update write time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-update-write-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp']['meta_info']


                                    class LastUpdateWriteTimestamp(object):
                                        """
                                        Last update write time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-write-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp']['meta_info']


                                    class LastRefreshUpdateWriteTimestamp(object):
                                        """
                                        Last refresh update write time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-refresh-update-write-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp']['meta_info']


                                    class UpdateStatistics(object):
                                        """
                                        Update statistics
                                        
                                        .. attribute:: last_update_cleard_age
                                        
                                        	Time since last Clear event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_cleared_timestamp
                                        
                                        	Last Cleared time
                                        	**type**\:   :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp>`
                                        
                                        .. attribute:: last_update_discard_age
                                        
                                        	Time since last Discard event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_discard_timestamp
                                        
                                        	Last Discarded time
                                        	**type**\:   :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                        
                                        .. attribute:: last_update_memory_allocation_fail_age
                                        
                                        	Time since last memory allocation failure event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_memory_allocation_fail_timestamp
                                        
                                        	Memory allocation failure time
                                        	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                        
                                        .. attribute:: last_update_recovery_age
                                        
                                        	Time since last Recovery event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_recovery_timestamp
                                        
                                        	Last Recovery time
                                        	**type**\:   :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                        
                                        .. attribute:: last_update_throttle_age
                                        
                                        	Time since last Throttle event (in seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_throttle_timestamp
                                        
                                        	Last Throttled time
                                        	**type**\:   :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                        
                                        .. attribute:: update_memory_allocation_fail_count
                                        
                                        	Memory allocation failure count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cleared
                                        
                                        	OutQueue Cleared Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cumulative
                                        
                                        	OutQueue Cumulative Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_discarded
                                        
                                        	OutQueue Discarded Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_high
                                        
                                        	OutQueue High Messages
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size_cleared
                                        
                                        	OutQueue Cleared Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_cumulative
                                        
                                        	OutQueue Cumulative Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_discarded
                                        
                                        	OutQueue Discarded Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_high
                                        
                                        	OutQueue Hi Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_recovery_count
                                        
                                        	Recovery Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_throttle_count
                                        
                                        	Throttle Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.last_update_cleard_age = None
                                            self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp()
                                            self.last_update_cleared_timestamp.parent = self
                                            self.last_update_discard_age = None
                                            self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp()
                                            self.last_update_discard_timestamp.parent = self
                                            self.last_update_memory_allocation_fail_age = None
                                            self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                            self.last_update_memory_allocation_fail_timestamp.parent = self
                                            self.last_update_recovery_age = None
                                            self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                            self.last_update_recovery_timestamp.parent = self
                                            self.last_update_throttle_age = None
                                            self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp()
                                            self.last_update_throttle_timestamp.parent = self
                                            self.update_memory_allocation_fail_count = None
                                            self.update_out_queue_messages_cleared = None
                                            self.update_out_queue_messages_cumulative = None
                                            self.update_out_queue_messages_discarded = None
                                            self.update_out_queue_messages_high = None
                                            self.update_out_queue_size_cleared = None
                                            self.update_out_queue_size_cumulative = None
                                            self.update_out_queue_size_discarded = None
                                            self.update_out_queue_size_high = None
                                            self.update_recovery_count = None
                                            self.update_throttle_count = None


                                        class LastUpdateDiscardTimestamp(object):
                                            """
                                            Last Discarded time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-discard-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp']['meta_info']


                                        class LastUpdateClearedTimestamp(object):
                                            """
                                            Last Cleared time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-cleared-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp']['meta_info']


                                        class LastUpdateThrottleTimestamp(object):
                                            """
                                            Last Throttled time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-throttle-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp']['meta_info']


                                        class LastUpdateRecoveryTimestamp(object):
                                            """
                                            Last Recovery time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-recovery-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp']['meta_info']


                                        class LastUpdateMemoryAllocationFailTimestamp(object):
                                            """
                                            Memory allocation failure time
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-memory-allocation-fail-timestamp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-statistics'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.last_update_cleard_age is not None:
                                                return True

                                            if self.last_update_cleared_timestamp is not None and self.last_update_cleared_timestamp._has_data():
                                                return True

                                            if self.last_update_discard_age is not None:
                                                return True

                                            if self.last_update_discard_timestamp is not None and self.last_update_discard_timestamp._has_data():
                                                return True

                                            if self.last_update_memory_allocation_fail_age is not None:
                                                return True

                                            if self.last_update_memory_allocation_fail_timestamp is not None and self.last_update_memory_allocation_fail_timestamp._has_data():
                                                return True

                                            if self.last_update_recovery_age is not None:
                                                return True

                                            if self.last_update_recovery_timestamp is not None and self.last_update_recovery_timestamp._has_data():
                                                return True

                                            if self.last_update_throttle_age is not None:
                                                return True

                                            if self.last_update_throttle_timestamp is not None and self.last_update_throttle_timestamp._has_data():
                                                return True

                                            if self.update_memory_allocation_fail_count is not None:
                                                return True

                                            if self.update_out_queue_messages_cleared is not None:
                                                return True

                                            if self.update_out_queue_messages_cumulative is not None:
                                                return True

                                            if self.update_out_queue_messages_discarded is not None:
                                                return True

                                            if self.update_out_queue_messages_high is not None:
                                                return True

                                            if self.update_out_queue_size_cleared is not None:
                                                return True

                                            if self.update_out_queue_size_cumulative is not None:
                                                return True

                                            if self.update_out_queue_size_discarded is not None:
                                                return True

                                            if self.update_out_queue_size_high is not None:
                                                return True

                                            if self.update_recovery_count is not None:
                                                return True

                                            if self.update_throttle_count is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-neighbor'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ack_version is not None:
                                            return True

                                        if self.current_update_group_af_name is not None:
                                            return True

                                        if self.default_originate_internal_context is not None:
                                            return True

                                        if self.default_originate_state is not None:
                                            return True

                                        if self.filter_group_index is not None:
                                            return True

                                        if self.first_default_originate_timestamp is not None and self.first_default_originate_timestamp._has_data():
                                            return True

                                        if self.first_update_queued_timestamp is not None and self.first_update_queued_timestamp._has_data():
                                            return True

                                        if self.first_update_write_timestamp is not None and self.first_update_write_timestamp._has_data():
                                            return True

                                        if self.inbound_refresh_count is not None:
                                            return True

                                        if self.is_eor_outstanding is not None:
                                            return True

                                        if self.is_update_group_timer_running is not None:
                                            return True

                                        if self.last_default_originate_age is not None:
                                            return True

                                        if self.last_default_originate_timestamp is not None and self.last_default_originate_timestamp._has_data():
                                            return True

                                        if self.last_filter_group_add_timestamp is not None and self.last_filter_group_add_timestamp._has_data():
                                            return True

                                        if self.last_filter_group_remove_timestamp is not None and self.last_filter_group_remove_timestamp._has_data():
                                            return True

                                        if self.last_refresh_update_queued_age is not None:
                                            return True

                                        if self.last_refresh_update_queued_timestamp is not None and self.last_refresh_update_queued_timestamp._has_data():
                                            return True

                                        if self.last_refresh_update_write_age is not None:
                                            return True

                                        if self.last_refresh_update_write_timestamp is not None and self.last_refresh_update_write_timestamp._has_data():
                                            return True

                                        if self.last_sub_group_add_timestamp is not None and self.last_sub_group_add_timestamp._has_data():
                                            return True

                                        if self.last_sub_group_remove_timestamp is not None and self.last_sub_group_remove_timestamp._has_data():
                                            return True

                                        if self.last_update_group_af_name is not None:
                                            return True

                                        if self.last_update_group_expiry_timestamp is not None and self.last_update_group_expiry_timestamp._has_data():
                                            return True

                                        if self.last_update_group_start_timestamp is not None and self.last_update_group_start_timestamp._has_data():
                                            return True

                                        if self.last_update_queued_age is not None:
                                            return True

                                        if self.last_update_queued_timestamp is not None and self.last_update_queued_timestamp._has_data():
                                            return True

                                        if self.last_update_write_age is not None:
                                            return True

                                        if self.last_update_write_timestamp is not None and self.last_update_write_timestamp._has_data():
                                            return True

                                        if self.neighbor_address is not None:
                                            return True

                                        if self.next_resume_version is not None:
                                            return True

                                        if self.outbound_refresh_count is not None:
                                            return True

                                        if self.outstanding_version_count is not None:
                                            return True

                                        if self.pending_target_version is not None:
                                            return True

                                        if self.process_id is not None:
                                            return True

                                        if self.refresh_ack_version is not None:
                                            return True

                                        if self.refresh_filter_group_index is not None:
                                            return True

                                        if self.refresh_next_resume_version is not None:
                                            return True

                                        if self.refresh_pending_target_version is not None:
                                            return True

                                        if self.refresh_requested_target_version is not None:
                                            return True

                                        if self.refresh_sub_group_id is not None:
                                            return True

                                        if self.refresh_sub_group_index is not None:
                                            return True

                                        if self.refresh_update_out_queue_messages is not None:
                                            return True

                                        if self.refresh_update_out_queue_size is not None:
                                            return True

                                        if self.sub_group_id is not None:
                                            return True

                                        if self.sub_group_index is not None:
                                            return True

                                        if self.sub_group_index_xr is not None:
                                            return True

                                        if self.synced_ack_version is not None:
                                            return True

                                        if self.update_filter_group_index is not None:
                                            return True

                                        if self.update_filter_group_messages is not None:
                                            return True

                                        if self.update_group_af_name is not None:
                                            return True

                                        if self.update_group_index is not None:
                                            return True

                                        if self.update_group_index_xr is not None:
                                            return True

                                        if self.update_main_table_version is not None:
                                            return True

                                        if self.update_neighbor_address is not None and self.update_neighbor_address._has_data():
                                            return True

                                        if self.update_out_queue_messages is not None:
                                            return True

                                        if self.update_out_queue_size is not None:
                                            return True

                                        if self.update_refresh_target_version is not None:
                                            return True

                                        if self.update_refresh_version is not None:
                                            return True

                                        if self.update_statistics is not None and self.update_statistics._has_data():
                                            return True

                                        if self.update_vrf_name is not None:
                                            return True

                                        if self.update_vrf_table_rib_version is not None:
                                            return True

                                        if self.version is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-neighbors'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.update_generation_neighbor is not None:
                                        for child_ref in self.update_generation_neighbor:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors']['meta_info']


                            class UpdateGenerationAddressFamily(object):
                                """
                                Update generation for address\-family
                                
                                .. attribute:: configured_update_limit_af
                                
                                	Configured AF update limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: configured_update_limit_sub_group_ibgp
                                
                                	Configured IBGP sub\-group update limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: configured_update_limit_subgrp_ebgp
                                
                                	Configured EBGP sub\-group update limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: current_update_limit_af
                                
                                	Current AF update limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: current_update_limit_sub_group_ibgp
                                
                                	Current IBGP sub\-group update limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: current_update_limit_subgrp_ebgp
                                
                                	Current EBGP sub\-group update limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: filter_group_count
                                
                                	Filter\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_count
                                
                                	Neighbor count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: refresh_sub_group_count
                                
                                	Refresh sub\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: refresh_sub_group_throttled_count
                                
                                	Throttled refresh sub\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sub_group_throttled_count
                                
                                	Throttled sub\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: table_neighbor_count
                                
                                	VRF Table neighbor count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: table_refresh_sub_group_count
                                
                                	VRF Table refresh sub\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: table_refresh_sub_group_throttled_count
                                
                                	VRF Table throttled refresh sub\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: table_sub_group_throttled_count
                                
                                	VRF Table throttled sub\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: table_update_group_count
                                
                                	VRF Table update\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_group_af_name
                                
                                	Address family identifier
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: update_main_table_version
                                
                                	Main table version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_min_neighbor_version
                                
                                	Minimum Neighbor version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_out_queue_messages
                                
                                	OutQueue messsages
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_out_queue_size
                                
                                	OutQueue size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_rib_version
                                
                                	RIB version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_statistics
                                
                                	Upate statistics
                                	**type**\:   :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics>`
                                
                                .. attribute:: update_sub_group_count
                                
                                	Sub\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_table_filter_group_count
                                
                                	VRF Table filter\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_table_sub_group_count
                                
                                	VRF Table sub\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_table_vrf_name
                                
                                	VRF Name
                                	**type**\:  str
                                
                                .. attribute:: update_throttled
                                
                                	Is Update throttled
                                	**type**\:  bool
                                
                                .. attribute:: update_update_group_count
                                
                                	Update\-group count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_vrf_rd_version
                                
                                	RD Version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_vrf_table_rib_version
                                
                                	VRF Table RIB version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_vrfaf_name
                                
                                	Address family identifier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.configured_update_limit_af = None
                                    self.configured_update_limit_sub_group_ibgp = None
                                    self.configured_update_limit_subgrp_ebgp = None
                                    self.current_update_limit_af = None
                                    self.current_update_limit_sub_group_ibgp = None
                                    self.current_update_limit_subgrp_ebgp = None
                                    self.filter_group_count = None
                                    self.neighbor_count = None
                                    self.refresh_sub_group_count = None
                                    self.refresh_sub_group_throttled_count = None
                                    self.sub_group_throttled_count = None
                                    self.table_neighbor_count = None
                                    self.table_refresh_sub_group_count = None
                                    self.table_refresh_sub_group_throttled_count = None
                                    self.table_sub_group_throttled_count = None
                                    self.table_update_group_count = None
                                    self.update_group_af_name = None
                                    self.update_main_table_version = None
                                    self.update_min_neighbor_version = None
                                    self.update_out_queue_messages = None
                                    self.update_out_queue_size = None
                                    self.update_rib_version = None
                                    self.update_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics()
                                    self.update_statistics.parent = self
                                    self.update_sub_group_count = None
                                    self.update_table_filter_group_count = None
                                    self.update_table_sub_group_count = None
                                    self.update_table_vrf_name = None
                                    self.update_throttled = None
                                    self.update_update_group_count = None
                                    self.update_vrf_rd_version = None
                                    self.update_vrf_table_rib_version = None
                                    self.update_vrfaf_name = None


                                class UpdateStatistics(object):
                                    """
                                    Upate statistics
                                    
                                    .. attribute:: last_update_cleard_age
                                    
                                    	Time since last Clear event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_cleared_timestamp
                                    
                                    	Last Cleared time
                                    	**type**\:   :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp>`
                                    
                                    .. attribute:: last_update_discard_age
                                    
                                    	Time since last Discard event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_discard_timestamp
                                    
                                    	Last Discarded time
                                    	**type**\:   :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                    
                                    .. attribute:: last_update_memory_allocation_fail_age
                                    
                                    	Time since last memory allocation failure event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_memory_allocation_fail_timestamp
                                    
                                    	Memory allocation failure time
                                    	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                    
                                    .. attribute:: last_update_recovery_age
                                    
                                    	Time since last Recovery event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_recovery_timestamp
                                    
                                    	Last Recovery time
                                    	**type**\:   :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                    
                                    .. attribute:: last_update_throttle_age
                                    
                                    	Time since last Throttle event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_throttle_timestamp
                                    
                                    	Last Throttled time
                                    	**type**\:   :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                    
                                    .. attribute:: update_memory_allocation_fail_count
                                    
                                    	Memory allocation failure count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages_cleared
                                    
                                    	OutQueue Cleared Messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages_cumulative
                                    
                                    	OutQueue Cumulative Messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages_discarded
                                    
                                    	OutQueue Discarded Messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages_high
                                    
                                    	OutQueue High Messages
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_size_cleared
                                    
                                    	OutQueue Cleared Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: update_out_queue_size_cumulative
                                    
                                    	OutQueue Cumulative Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: update_out_queue_size_discarded
                                    
                                    	OutQueue Discarded Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: update_out_queue_size_high
                                    
                                    	OutQueue Hi Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_recovery_count
                                    
                                    	Recovery Count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_throttle_count
                                    
                                    	Throttle Count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.last_update_cleard_age = None
                                        self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp()
                                        self.last_update_cleared_timestamp.parent = self
                                        self.last_update_discard_age = None
                                        self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp()
                                        self.last_update_discard_timestamp.parent = self
                                        self.last_update_memory_allocation_fail_age = None
                                        self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                        self.last_update_memory_allocation_fail_timestamp.parent = self
                                        self.last_update_recovery_age = None
                                        self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                        self.last_update_recovery_timestamp.parent = self
                                        self.last_update_throttle_age = None
                                        self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp()
                                        self.last_update_throttle_timestamp.parent = self
                                        self.update_memory_allocation_fail_count = None
                                        self.update_out_queue_messages_cleared = None
                                        self.update_out_queue_messages_cumulative = None
                                        self.update_out_queue_messages_discarded = None
                                        self.update_out_queue_messages_high = None
                                        self.update_out_queue_size_cleared = None
                                        self.update_out_queue_size_cumulative = None
                                        self.update_out_queue_size_discarded = None
                                        self.update_out_queue_size_high = None
                                        self.update_recovery_count = None
                                        self.update_throttle_count = None


                                    class LastUpdateDiscardTimestamp(object):
                                        """
                                        Last Discarded time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-discard-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp']['meta_info']


                                    class LastUpdateClearedTimestamp(object):
                                        """
                                        Last Cleared time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-cleared-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp']['meta_info']


                                    class LastUpdateThrottleTimestamp(object):
                                        """
                                        Last Throttled time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-throttle-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp']['meta_info']


                                    class LastUpdateRecoveryTimestamp(object):
                                        """
                                        Last Recovery time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-recovery-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp']['meta_info']


                                    class LastUpdateMemoryAllocationFailTimestamp(object):
                                        """
                                        Memory allocation failure time
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-memory-allocation-fail-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-statistics'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.last_update_cleard_age is not None:
                                            return True

                                        if self.last_update_cleared_timestamp is not None and self.last_update_cleared_timestamp._has_data():
                                            return True

                                        if self.last_update_discard_age is not None:
                                            return True

                                        if self.last_update_discard_timestamp is not None and self.last_update_discard_timestamp._has_data():
                                            return True

                                        if self.last_update_memory_allocation_fail_age is not None:
                                            return True

                                        if self.last_update_memory_allocation_fail_timestamp is not None and self.last_update_memory_allocation_fail_timestamp._has_data():
                                            return True

                                        if self.last_update_recovery_age is not None:
                                            return True

                                        if self.last_update_recovery_timestamp is not None and self.last_update_recovery_timestamp._has_data():
                                            return True

                                        if self.last_update_throttle_age is not None:
                                            return True

                                        if self.last_update_throttle_timestamp is not None and self.last_update_throttle_timestamp._has_data():
                                            return True

                                        if self.update_memory_allocation_fail_count is not None:
                                            return True

                                        if self.update_out_queue_messages_cleared is not None:
                                            return True

                                        if self.update_out_queue_messages_cumulative is not None:
                                            return True

                                        if self.update_out_queue_messages_discarded is not None:
                                            return True

                                        if self.update_out_queue_messages_high is not None:
                                            return True

                                        if self.update_out_queue_size_cleared is not None:
                                            return True

                                        if self.update_out_queue_size_cumulative is not None:
                                            return True

                                        if self.update_out_queue_size_discarded is not None:
                                            return True

                                        if self.update_out_queue_size_high is not None:
                                            return True

                                        if self.update_recovery_count is not None:
                                            return True

                                        if self.update_throttle_count is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-generation-address-family'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.configured_update_limit_af is not None:
                                        return True

                                    if self.configured_update_limit_sub_group_ibgp is not None:
                                        return True

                                    if self.configured_update_limit_subgrp_ebgp is not None:
                                        return True

                                    if self.current_update_limit_af is not None:
                                        return True

                                    if self.current_update_limit_sub_group_ibgp is not None:
                                        return True

                                    if self.current_update_limit_subgrp_ebgp is not None:
                                        return True

                                    if self.filter_group_count is not None:
                                        return True

                                    if self.neighbor_count is not None:
                                        return True

                                    if self.refresh_sub_group_count is not None:
                                        return True

                                    if self.refresh_sub_group_throttled_count is not None:
                                        return True

                                    if self.sub_group_throttled_count is not None:
                                        return True

                                    if self.table_neighbor_count is not None:
                                        return True

                                    if self.table_refresh_sub_group_count is not None:
                                        return True

                                    if self.table_refresh_sub_group_throttled_count is not None:
                                        return True

                                    if self.table_sub_group_throttled_count is not None:
                                        return True

                                    if self.table_update_group_count is not None:
                                        return True

                                    if self.update_group_af_name is not None:
                                        return True

                                    if self.update_main_table_version is not None:
                                        return True

                                    if self.update_min_neighbor_version is not None:
                                        return True

                                    if self.update_out_queue_messages is not None:
                                        return True

                                    if self.update_out_queue_size is not None:
                                        return True

                                    if self.update_rib_version is not None:
                                        return True

                                    if self.update_statistics is not None and self.update_statistics._has_data():
                                        return True

                                    if self.update_sub_group_count is not None:
                                        return True

                                    if self.update_table_filter_group_count is not None:
                                        return True

                                    if self.update_table_sub_group_count is not None:
                                        return True

                                    if self.update_table_vrf_name is not None:
                                        return True

                                    if self.update_throttled is not None:
                                        return True

                                    if self.update_update_group_count is not None:
                                        return True

                                    if self.update_vrf_rd_version is not None:
                                        return True

                                    if self.update_vrf_table_rib_version is not None:
                                        return True

                                    if self.update_vrfaf_name is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily']['meta_info']


                            class Dampenings(object):
                                """
                                The BGP Dampening table
                                
                                .. attribute:: dampening
                                
                                	A BGP Dampening table entry
                                	**type**\: list of    :py:class:`Dampening <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.dampening = YList()
                                    self.dampening.parent = self
                                    self.dampening.name = 'dampening'


                                class Dampening(object):
                                    """
                                    A BGP Dampening table entry
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: attributes_after_policy_in
                                    
                                    	Attributes after inbound policy applied
                                    	**type**\:   :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn>`
                                    
                                    .. attribute:: label_fail
                                    
                                    	LSD label allocation failed 
                                    	**type**\:  bool
                                    
                                    .. attribute:: label_o_or_version
                                    
                                    	Label Version when OOR happens
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_oor
                                    
                                    	LSD label space is exhausted
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr>`
                                    
                                    .. attribute:: network
                                    
                                    	Network in prefix/length format
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    
                                    ----
                                    .. attribute:: no_path
                                    
                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_id
                                    
                                    	Received Path ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: path_information
                                    
                                    	Path information
                                    	**type**\:   :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation>`
                                    
                                    .. attribute:: prefix_version
                                    
                                    	Version of BGP Prefix Table
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: reuse
                                    
                                    	Reuse array index
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_rd
                                    
                                    	Source Route Distinguisher value
                                    	**type**\:  str
                                    
                                    .. attribute:: source_route_distinguisher
                                    
                                    	Source Route Distinguisher
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_vrf_name
                                    
                                    	Name of the source VRF
                                    	**type**\:  str
                                    
                                    .. attribute:: srcaf_name
                                    
                                    	Address family identifier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: version
                                    
                                    	Version number
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.af_name = None
                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn()
                                        self.attributes_after_policy_in.parent = self
                                        self.label_fail = None
                                        self.label_o_or_version = None
                                        self.label_oor = None
                                        self.neighbor_address = None
                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr()
                                        self.neighbor_address_xr.parent = self
                                        self.network = None
                                        self.no_path = None
                                        self.path_id = None
                                        self.path_information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation()
                                        self.path_information.parent = self
                                        self.prefix_version = None
                                        self.process_instance_id = None
                                        self.rd = None
                                        self.reuse = None
                                        self.route_distinguisher = None
                                        self.source_rd = None
                                        self.source_route_distinguisher = None
                                        self.source_vrf_name = None
                                        self.srcaf_name = None
                                        self.version = None
                                        self.vrf_name = None


                                    class NeighborAddressXr(object):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.NeighborAddressXr']['meta_info']


                                    class PathInformation(object):
                                        """
                                        Path information
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_own_self_originated_p_ath
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\:  bool
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of    :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield>`
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\:  bool
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:   :py:class:`BgpBpStageEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStageEnum>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:   :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner>`
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of    :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield>`
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix>`
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity>`
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\:  bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\:  bool
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:   :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr>`
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_esi
                                        
                                        	Path has EVPN ESI
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_rcvd_label
                                        
                                        	Path has received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\:  bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\:  bool
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebg_ps
                                        
                                        	Not advertised to EBGPs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\:  bool
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of    :py:class:`L2VpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.L2VpnCircuitStatusValue>`
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\:   :py:class:`L2VpnEvpnEsi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.L2VpnEvpnEsi>`
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:   :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:   :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:   :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr>`
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of    :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue>`
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress>`
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop>`
                                        
                                        .. attribute:: nhte_tunnel
                                        
                                        	NH TE tunnel information
                                        	**type**\:   :py:class:`NhteTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhteTunnel>`
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of    :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:   :py:class:`BgpRoute1Enum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1Enum>`
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\:  bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\:  bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.accept_own_path = None
                                            self.accept_own_self_originated_p_ath = None
                                            self.add_path_orr_bitfield = YList()
                                            self.add_path_orr_bitfield.parent = self
                                            self.add_path_orr_bitfield.name = 'add_path_orr_bitfield'
                                            self.advertisedto_pe = None
                                            self.aigp_metric = None
                                            self.best_path_comp_stage = None
                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self.best_path_id = None
                                            self.best_path_id_comp_winner = None
                                            self.best_path_orr_bitfield = YList()
                                            self.best_path_orr_bitfield.parent = self
                                            self.best_path_orr_bitfield.name = 'best_path_orr_bitfield'
                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self.dampen_penalty = None
                                            self.extended_community = YList()
                                            self.extended_community.parent = self
                                            self.extended_community.name = 'extended_community'
                                            self.fspec_invalid_path = None
                                            self.graceful_shutdown = None
                                            self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr()
                                            self.gw_addr.parent = self
                                            self.halflife_time = None
                                            self.has_esi = None
                                            self.has_gw_addr = None
                                            self.has_local_net_label = None
                                            self.has_mdt_group_addr = None
                                            self.has_mvpn_extcomm = None
                                            self.has_mvpn_nbr_addr = None
                                            self.has_mvpn_nexthop_addr = None
                                            self.has_mvpn_pmsi = None
                                            self.has_rcvd_label = None
                                            self.has_second_label = None
                                            self.ibgp_signaled_validity = None
                                            self.igp_metric = None
                                            self.is_aggregation_suppressed = None
                                            self.is_as_best = None
                                            self.is_best_path = None
                                            self.is_import_dampened = None
                                            self.is_import_suspect = None
                                            self.is_internal_path = None
                                            self.is_partial_best = None
                                            self.is_path_additional_path = None
                                            self.is_path_advertised_local_as_only = None
                                            self.is_path_af_install_eligible = None
                                            self.is_path_backup = None
                                            self.is_path_backup_protect_multipath = None
                                            self.is_path_best_external = None
                                            self.is_path_damped = None
                                            self.is_path_from_confederation_peer = None
                                            self.is_path_from_network_command = None
                                            self.is_path_from_redistribute_command = None
                                            self.is_path_from_route_reflector = None
                                            self.is_path_history_held = None
                                            self.is_path_imp_candidate = None
                                            self.is_path_imported = None
                                            self.is_path_local_aggregate = None
                                            self.is_path_locally_sourced = None
                                            self.is_path_long_lived_stale = None
                                            self.is_path_multipath = None
                                            self.is_path_nexthop_discarded = None
                                            self.is_path_not_advertised = None
                                            self.is_path_not_advertised_to_ebg_ps = None
                                            self.is_path_received_only = None
                                            self.is_path_reoriginated = None
                                            self.is_path_reoriginated_stitching = None
                                            self.is_path_stale = None
                                            self.is_path_synced_with_igp = None
                                            self.is_path_valid = None
                                            self.is_path_vpn_only = None
                                            self.is_permanent_path = None
                                            self.is_received_path_not_modified = None
                                            self.is_spkr_as_best = None
                                            self.l2vpn_circuit_status_value = YList()
                                            self.l2vpn_circuit_status_value.parent = self
                                            self.l2vpn_circuit_status_value.name = 'l2vpn_circuit_status_value'
                                            self.l2vpn_evpn_esi = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.L2VpnEvpnEsi()
                                            self.l2vpn_evpn_esi.parent = self
                                            self.l2vpn_size = None
                                            self.labeled_unicast_safi_path = None
                                            self.local_label = None
                                            self.local_nh = None
                                            self.local_path_id = None
                                            self.local_peers_advertised_to = YList()
                                            self.local_peers_advertised_to.parent = self
                                            self.local_peers_advertised_to.name = 'local_peers_advertised_to'
                                            self.maximum_suppress_time = None
                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self.mvpn_path_flags = None
                                            self.mvpn_pmsi_flags = None
                                            self.mvpn_pmsi_label = None
                                            self.mvpn_pmsi_type = None
                                            self.mvpn_pmsi_value = YList()
                                            self.mvpn_pmsi_value.parent = self
                                            self.mvpn_pmsi_value.name = 'mvpn_pmsi_value'
                                            self.mvpn_sfs_path = None
                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self.neighbor_router_id = None
                                            self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop()
                                            self.next_hop.parent = self
                                            self.nhte_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhteTunnel()
                                            self.nhte_tunnel.parent = self
                                            self.path_flags = None
                                            self.path_flap_count = None
                                            self.path_import_flags = None
                                            self.path_rt_set_id = None
                                            self.path_rt_set_route_count = None
                                            self.path_table_version = None
                                            self.path_weight = None
                                            self.pe_peers_advertised_to = YList()
                                            self.pe_peers_advertised_to.parent = self
                                            self.pe_peers_advertised_to.name = 'pe_peers_advertised_to'
                                            self.rcvd_label = None
                                            self.rcvd_path_id = None
                                            self.reuse_value = None
                                            self.rib_failed = None
                                            self.route_type = None
                                            self.rpki_origin_as_validation_disabled = None
                                            self.rt_set_limit_enabled = None
                                            self.second_label = None
                                            self.seconds_since_first_flap = None
                                            self.show_rpki_origin_as_validity = None
                                            self.sn_rpki_origin_as_validity = None
                                            self.suppress_penalty = None
                                            self.time_to_unsuppress = None


                                        class BgpPrefix(object):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self.prefix_length = None


                                            class Prefix(object):
                                                """
                                                Prefix
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.prefix is not None and self.prefix._has_data():
                                                    return True

                                                if self.prefix_length is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix']['meta_info']


                                        class NeighborAddress(object):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress']['meta_info']


                                        class NextHop(object):
                                            """
                                            Next hop
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop']['meta_info']


                                        class NhteTunnel(object):
                                            """
                                            NH TE tunnel information
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_te_tunnel
                                            
                                            	NH TE Tunnel info is present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\:  bool
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last rib update happened
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	tunnel name
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	tunnel type
                                            	**type**\:   :py:class:`BgpteTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpteTunnelEnum>`
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.binding_label = None
                                                self.has_te_tunnel = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.is_tunnel_up = None
                                                self.last_tunnel_update = None
                                                self.tunnel_if_handle = None
                                                self.tunnel_name = None
                                                self.tunnel_type = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_v6_required = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nhte-tunnel'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.binding_label is not None:
                                                    return True

                                                if self.has_te_tunnel is not None:
                                                    return True

                                                if self.is_tunnel_info_stale is not None:
                                                    return True

                                                if self.is_tunnel_registered is not None:
                                                    return True

                                                if self.is_tunnel_up is not None:
                                                    return True

                                                if self.last_tunnel_update is not None:
                                                    return True

                                                if self.tunnel_if_handle is not None:
                                                    return True

                                                if self.tunnel_name is not None:
                                                    return True

                                                if self.tunnel_type is not None:
                                                    return True

                                                if self.tunnel_v6_enabled is not None:
                                                    return True

                                                if self.tunnel_v6_required is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhteTunnel']['meta_info']


                                        class MdtGroupAddr(object):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mdt-group-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr']['meta_info']


                                        class L2VpnEvpnEsi(object):
                                            """
                                            L2VPN EVPN ESI
                                            
                                            .. attribute:: esi
                                            
                                            	esi
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.esi = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-evpn-esi'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.esi is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.L2VpnEvpnEsi']['meta_info']


                                        class GwAddr(object):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpGwAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpGwAddrLenEnum>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.len = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:gw-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.len is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr']['meta_info']


                                        class BestPathCompWinner(object):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-comp-winner'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner']['meta_info']


                                        class MvpnNbrAddr(object):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nbr-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr']['meta_info']


                                        class MvpnNexthopAddr(object):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-nexthop-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr']['meta_info']


                                        class L2VpnCircuitStatusValue(object):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-circuit-status-value'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.L2VpnCircuitStatusValue']['meta_info']


                                        class MvpnPmsiValue(object):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:mvpn-pmsi-value'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue']['meta_info']


                                        class ExtendedCommunity(object):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity']['meta_info']


                                        class LocalPeersAdvertisedTo(object):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:local-peers-advertised-to'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo']['meta_info']


                                        class PePeersAdvertisedTo(object):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-peers-advertised-to'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo']['meta_info']


                                        class BestPathOrrBitfield(object):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:best-path-orr-bitfield'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield']['meta_info']


                                        class AddPathOrrBitfield(object):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_neighbor = None
                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self.update_group_number = None


                                            class NeighborAddress(object):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\:  str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: ipv4sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv6sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress>`
                                                
                                                .. attribute:: l2vpnvpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress>`
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4mdt_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4sr_policy_address.parent = self
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6sr_policy_address.parent = self
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_flowspec_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress()
                                                    self.l2vpnvpls_address.parent = self
                                                    self.ls_ls_address = None
                                                    self.rt_constraint_address = None


                                                class L2VpnvplsAddress(object):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                                class L2VpnMspwAddress(object):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.l2vpn_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.l2vpn_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                                class Ipv4SrPolicyAddress(object):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                                class Ipv6SrPolicyAddress(object):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv6_srpolicy_address = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv6_srpolicy_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.afi is not None:
                                                        return True

                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.ipv4_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4_label_address is not None:
                                                        return True

                                                    if self.ipv4_mcast_address is not None:
                                                        return True

                                                    if self.ipv4_tunnel_address is not None:
                                                        return True

                                                    if self.ipv4mdt_address is not None:
                                                        return True

                                                    if self.ipv4mvpn_address is not None:
                                                        return True

                                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv4vpn_address is not None:
                                                        return True

                                                    if self.ipv4vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv4vpna_mcastddress is not None:
                                                        return True

                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.ipv6_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6_label_address is not None:
                                                        return True

                                                    if self.ipv6_mcast_address is not None:
                                                        return True

                                                    if self.ipv6mvpn_address is not None:
                                                        return True

                                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                        return True

                                                    if self.ipv6vpn_address is not None:
                                                        return True

                                                    if self.ipv6vpn_flowspec_address is not None:
                                                        return True

                                                    if self.ipv6vpn_mcast_address is not None:
                                                        return True

                                                    if self.l2vpn_evpn_address is not None:
                                                        return True

                                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                        return True

                                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                        return True

                                                    if self.ls_ls_address is not None:
                                                        return True

                                                    if self.rt_constraint_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:add-path-orr-bitfield'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_neighbor is not None:
                                                    return True

                                                if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                    return True

                                                if self.update_group_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:path-information'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.accept_own_path is not None:
                                                return True

                                            if self.accept_own_self_originated_p_ath is not None:
                                                return True

                                            if self.add_path_orr_bitfield is not None:
                                                for child_ref in self.add_path_orr_bitfield:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.advertisedto_pe is not None:
                                                return True

                                            if self.aigp_metric is not None:
                                                return True

                                            if self.best_path_comp_stage is not None:
                                                return True

                                            if self.best_path_comp_winner is not None and self.best_path_comp_winner._has_data():
                                                return True

                                            if self.best_path_id is not None:
                                                return True

                                            if self.best_path_id_comp_winner is not None:
                                                return True

                                            if self.best_path_orr_bitfield is not None:
                                                for child_ref in self.best_path_orr_bitfield:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                return True

                                            if self.dampen_penalty is not None:
                                                return True

                                            if self.extended_community is not None:
                                                for child_ref in self.extended_community:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.fspec_invalid_path is not None:
                                                return True

                                            if self.graceful_shutdown is not None:
                                                return True

                                            if self.gw_addr is not None and self.gw_addr._has_data():
                                                return True

                                            if self.halflife_time is not None:
                                                return True

                                            if self.has_esi is not None:
                                                return True

                                            if self.has_gw_addr is not None:
                                                return True

                                            if self.has_local_net_label is not None:
                                                return True

                                            if self.has_mdt_group_addr is not None:
                                                return True

                                            if self.has_mvpn_extcomm is not None:
                                                return True

                                            if self.has_mvpn_nbr_addr is not None:
                                                return True

                                            if self.has_mvpn_nexthop_addr is not None:
                                                return True

                                            if self.has_mvpn_pmsi is not None:
                                                return True

                                            if self.has_rcvd_label is not None:
                                                return True

                                            if self.has_second_label is not None:
                                                return True

                                            if self.ibgp_signaled_validity is not None:
                                                return True

                                            if self.igp_metric is not None:
                                                return True

                                            if self.is_aggregation_suppressed is not None:
                                                return True

                                            if self.is_as_best is not None:
                                                return True

                                            if self.is_best_path is not None:
                                                return True

                                            if self.is_import_dampened is not None:
                                                return True

                                            if self.is_import_suspect is not None:
                                                return True

                                            if self.is_internal_path is not None:
                                                return True

                                            if self.is_partial_best is not None:
                                                return True

                                            if self.is_path_additional_path is not None:
                                                return True

                                            if self.is_path_advertised_local_as_only is not None:
                                                return True

                                            if self.is_path_af_install_eligible is not None:
                                                return True

                                            if self.is_path_backup is not None:
                                                return True

                                            if self.is_path_backup_protect_multipath is not None:
                                                return True

                                            if self.is_path_best_external is not None:
                                                return True

                                            if self.is_path_damped is not None:
                                                return True

                                            if self.is_path_from_confederation_peer is not None:
                                                return True

                                            if self.is_path_from_network_command is not None:
                                                return True

                                            if self.is_path_from_redistribute_command is not None:
                                                return True

                                            if self.is_path_from_route_reflector is not None:
                                                return True

                                            if self.is_path_history_held is not None:
                                                return True

                                            if self.is_path_imp_candidate is not None:
                                                return True

                                            if self.is_path_imported is not None:
                                                return True

                                            if self.is_path_local_aggregate is not None:
                                                return True

                                            if self.is_path_locally_sourced is not None:
                                                return True

                                            if self.is_path_long_lived_stale is not None:
                                                return True

                                            if self.is_path_multipath is not None:
                                                return True

                                            if self.is_path_nexthop_discarded is not None:
                                                return True

                                            if self.is_path_not_advertised is not None:
                                                return True

                                            if self.is_path_not_advertised_to_ebg_ps is not None:
                                                return True

                                            if self.is_path_received_only is not None:
                                                return True

                                            if self.is_path_reoriginated is not None:
                                                return True

                                            if self.is_path_reoriginated_stitching is not None:
                                                return True

                                            if self.is_path_stale is not None:
                                                return True

                                            if self.is_path_synced_with_igp is not None:
                                                return True

                                            if self.is_path_valid is not None:
                                                return True

                                            if self.is_path_vpn_only is not None:
                                                return True

                                            if self.is_permanent_path is not None:
                                                return True

                                            if self.is_received_path_not_modified is not None:
                                                return True

                                            if self.is_spkr_as_best is not None:
                                                return True

                                            if self.l2vpn_circuit_status_value is not None:
                                                for child_ref in self.l2vpn_circuit_status_value:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.l2vpn_evpn_esi is not None and self.l2vpn_evpn_esi._has_data():
                                                return True

                                            if self.l2vpn_size is not None:
                                                return True

                                            if self.labeled_unicast_safi_path is not None:
                                                return True

                                            if self.local_label is not None:
                                                return True

                                            if self.local_nh is not None:
                                                return True

                                            if self.local_path_id is not None:
                                                return True

                                            if self.local_peers_advertised_to is not None:
                                                for child_ref in self.local_peers_advertised_to:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.maximum_suppress_time is not None:
                                                return True

                                            if self.mdt_group_addr is not None and self.mdt_group_addr._has_data():
                                                return True

                                            if self.mvpn_nbr_addr is not None and self.mvpn_nbr_addr._has_data():
                                                return True

                                            if self.mvpn_nexthop_addr is not None and self.mvpn_nexthop_addr._has_data():
                                                return True

                                            if self.mvpn_path_flags is not None:
                                                return True

                                            if self.mvpn_pmsi_flags is not None:
                                                return True

                                            if self.mvpn_pmsi_label is not None:
                                                return True

                                            if self.mvpn_pmsi_type is not None:
                                                return True

                                            if self.mvpn_pmsi_value is not None:
                                                for child_ref in self.mvpn_pmsi_value:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.mvpn_sfs_path is not None:
                                                return True

                                            if self.neighbor_address is not None and self.neighbor_address._has_data():
                                                return True

                                            if self.neighbor_router_id is not None:
                                                return True

                                            if self.next_hop is not None and self.next_hop._has_data():
                                                return True

                                            if self.nhte_tunnel is not None and self.nhte_tunnel._has_data():
                                                return True

                                            if self.path_flags is not None:
                                                return True

                                            if self.path_flap_count is not None:
                                                return True

                                            if self.path_import_flags is not None:
                                                return True

                                            if self.path_rt_set_id is not None:
                                                return True

                                            if self.path_rt_set_route_count is not None:
                                                return True

                                            if self.path_table_version is not None:
                                                return True

                                            if self.path_weight is not None:
                                                return True

                                            if self.pe_peers_advertised_to is not None:
                                                for child_ref in self.pe_peers_advertised_to:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.rcvd_label is not None:
                                                return True

                                            if self.rcvd_path_id is not None:
                                                return True

                                            if self.reuse_value is not None:
                                                return True

                                            if self.rib_failed is not None:
                                                return True

                                            if self.route_type is not None:
                                                return True

                                            if self.rpki_origin_as_validation_disabled is not None:
                                                return True

                                            if self.rt_set_limit_enabled is not None:
                                                return True

                                            if self.second_label is not None:
                                                return True

                                            if self.seconds_since_first_flap is not None:
                                                return True

                                            if self.show_rpki_origin_as_validity is not None:
                                                return True

                                            if self.sn_rpki_origin_as_validity is not None:
                                                return True

                                            if self.suppress_penalty is not None:
                                                return True

                                            if self.time_to_unsuppress is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation']['meta_info']


                                    class AttributesAfterPolicyIn(object):
                                        """
                                        Attributes after inbound policy applied
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet>`
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes>`
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp>`
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr>`
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\:  bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet()
                                            self.attr_set.parent = self
                                            self.attribute_key_number = None
                                            self.attribute_reuse_id_config = None
                                            self.attribute_reuse_id_current = None
                                            self.attribute_reuse_id_keys = None
                                            self.attribute_reuse_id_max_id = None
                                            self.attribute_reuse_id_node = None
                                            self.attribute_reuse_id_recover_sec = None
                                            self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self.is_application_gateway_present = None
                                            self.is_as_path2_byte = None
                                            self.is_attr_set_present = None
                                            self.is_ribrnh_present = None
                                            self.is_rnh_present = None
                                            self.ribrnh_encap = None
                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self.ribrnh_mac = None
                                            self.ribrnh_table = None
                                            self.ribrnh_vni = None
                                            self.ribrnhip_table = None
                                            self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self.rnh_addr_len = None
                                            self.rnh_len = None
                                            self.rnh_type = None
                                            self.set_aigp_inbound_igp = None
                                            self.set_aigp_inbound_metric = None
                                            self.vpn_distinguisher = None


                                        class CommonAttributes(object):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_encap_present
                                            
                                            	Tunnel Encap attribute present 
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_policy_allocated_binding_sid
                                            
                                            	SR Policy allocated Binding sid by the router
                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                            
                                            .. attribute:: sr_policy_binding_sid
                                            
                                            	SR Policy Binding sid
                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid>`
                                            
                                            .. attribute:: sr_policy_explicit_path
                                            
                                            	SR Policy Explicit paths
                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath>`
                                            
                                            .. attribute:: sr_policy_preference
                                            
                                            	SR Policy Preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_tunnel_request_state
                                            
                                            	SR Tunnel Request State
                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                            
                                            .. attribute:: sr_tunnel_state
                                            
                                            	SR Tunnel State
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap_type
                                            
                                            	Tunnel Encap Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.aggregator_address = None
                                                self.aggregator_as = None
                                                self.aigp_metric_value = None
                                                self.as_path = None
                                                self.cluster = YList()
                                                self.cluster.parent = self
                                                self.cluster.name = 'cluster'
                                                self.community = YList()
                                                self.community.parent = self
                                                self.community.name = 'community'
                                                self.connector_type = None
                                                self.connector_value = YList()
                                                self.connector_value.parent = self
                                                self.connector_value.name = 'connector_value'
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.extended_community_flags = None
                                                self.is_aggregator_present = None
                                                self.is_aigp_present = None
                                                self.is_as_path_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_community_present = None
                                                self.is_connector_present = None
                                                self.is_extended_community_present = None
                                                self.is_label_index_present = None
                                                self.is_local_pref_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_metric_present = None
                                                self.is_origin_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_ssa_present = None
                                                self.is_tunnel_encap_present = None
                                                self.l2tpv3_cookie = YList()
                                                self.l2tpv3_cookie.parent = self
                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                self.l2tpv3_session_id = None
                                                self.label_index_attr = YList()
                                                self.label_index_attr.parent = self
                                                self.label_index_attr.name = 'label_index_attr'
                                                self.local_preference = None
                                                self.ls_attr = YList()
                                                self.ls_attr.parent = self
                                                self.ls_attr.name = 'ls_attr'
                                                self.metric = None
                                                self.neighbor_as = None
                                                self.origin = None
                                                self.originator = None
                                                self.pe_distinguisher_label = YList()
                                                self.pe_distinguisher_label.parent = self
                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.pmsi_type = None
                                                self.pmsi_value = YList()
                                                self.pmsi_value.parent = self
                                                self.pmsi_value.name = 'pmsi_value'
                                                self.ppm_pvalue = None
                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                self.sr_policy_allocated_binding_sid.parent = self
                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid()
                                                self.sr_policy_binding_sid.parent = self
                                                self.sr_policy_explicit_path = YList()
                                                self.sr_policy_explicit_path.parent = self
                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                self.sr_policy_preference = None
                                                self.sr_tunnel_request_state = None
                                                self.sr_tunnel_state = None
                                                self.tunnel_encap_type = None
                                                self.unknown_attribute = YList()
                                                self.unknown_attribute.parent = self
                                                self.unknown_attribute.name = 'unknown_attribute'


                                            class SrPolicyBindingSid(object):
                                                """
                                                SR Policy Binding sid
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                            class SrPolicyAllocatedBindingSid(object):
                                                """
                                                SR Policy allocated Binding sid by the router
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                            class Community(object):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity']['meta_info']


                                            class UnknownAttribute(object):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute']['meta_info']


                                            class Cluster(object):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster']['meta_info']


                                            class L2Tpv3Cookie(object):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                            class ConnectorValue(object):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue']['meta_info']


                                            class PmsiValue(object):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue']['meta_info']


                                            class LsAttr(object):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr']['meta_info']


                                            class LabelIndexAttr(object):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LabelIndexAttr']['meta_info']


                                            class PeDistinguisherLabel(object):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.label = None
                                                    self.pe_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.label is not None:
                                                        return True

                                                    if self.pe_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                            class SrPolicyExplicitPath(object):
                                                """
                                                SR Policy Explicit paths
                                                
                                                .. attribute:: sid
                                                
                                                	Sidlist for explicit path
                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                
                                                .. attribute:: weight
                                                
                                                	Weight of explicit path
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.sid = YList()
                                                    self.sid.parent = self
                                                    self.sid.name = 'sid'
                                                    self.weight = None


                                                class Sid(object):
                                                    """
                                                    Sidlist for explicit path
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IP Address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label sid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Sid Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4 is not None:
                                                            return True

                                                        if self.ipv6 is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.sid is not None:
                                                        for child_ref in self.sid:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.weight is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.aggregator_address is not None:
                                                    return True

                                                if self.aggregator_as is not None:
                                                    return True

                                                if self.aigp_metric_value is not None:
                                                    return True

                                                if self.as_path is not None:
                                                    return True

                                                if self.cluster is not None:
                                                    for child_ref in self.cluster:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.community is not None:
                                                    for child_ref in self.community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.connector_type is not None:
                                                    return True

                                                if self.connector_value is not None:
                                                    for child_ref in self.connector_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community_flags is not None:
                                                    return True

                                                if self.is_aggregator_present is not None:
                                                    return True

                                                if self.is_aigp_present is not None:
                                                    return True

                                                if self.is_as_path_present is not None:
                                                    return True

                                                if self.is_atomic_aggregate_present is not None:
                                                    return True

                                                if self.is_community_present is not None:
                                                    return True

                                                if self.is_connector_present is not None:
                                                    return True

                                                if self.is_extended_community_present is not None:
                                                    return True

                                                if self.is_label_index_present is not None:
                                                    return True

                                                if self.is_local_pref_present is not None:
                                                    return True

                                                if self.is_ls_attribute_present is not None:
                                                    return True

                                                if self.is_metric_present is not None:
                                                    return True

                                                if self.is_origin_present is not None:
                                                    return True

                                                if self.is_pe_distinguisher_label_present is not None:
                                                    return True

                                                if self.is_pmsi_present is not None:
                                                    return True

                                                if self.is_pppmp_present is not None:
                                                    return True

                                                if self.is_ssa_present is not None:
                                                    return True

                                                if self.is_tunnel_encap_present is not None:
                                                    return True

                                                if self.l2tpv3_cookie is not None:
                                                    for child_ref in self.l2tpv3_cookie:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2tpv3_session_id is not None:
                                                    return True

                                                if self.label_index_attr is not None:
                                                    for child_ref in self.label_index_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_preference is not None:
                                                    return True

                                                if self.ls_attr is not None:
                                                    for child_ref in self.ls_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.metric is not None:
                                                    return True

                                                if self.neighbor_as is not None:
                                                    return True

                                                if self.origin is not None:
                                                    return True

                                                if self.originator is not None:
                                                    return True

                                                if self.pe_distinguisher_label is not None:
                                                    for child_ref in self.pe_distinguisher_label:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.pmsi_flags is not None:
                                                    return True

                                                if self.pmsi_label is not None:
                                                    return True

                                                if self.pmsi_type is not None:
                                                    return True

                                                if self.pmsi_value is not None:
                                                    for child_ref in self.pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.ppm_pvalue is not None:
                                                    return True

                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_explicit_path is not None:
                                                    for child_ref in self.sr_policy_explicit_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.sr_policy_preference is not None:
                                                    return True

                                                if self.sr_tunnel_request_state is not None:
                                                    return True

                                                if self.sr_tunnel_state is not None:
                                                    return True

                                                if self.tunnel_encap_type is not None:
                                                    return True

                                                if self.unknown_attribute is not None:
                                                    for child_ref in self.unknown_attribute:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes']['meta_info']


                                        class AttrSet(object):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_encap_present
                                            
                                            	Tunnel Encap attribute present 
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_policy_allocated_binding_sid
                                            
                                            	SR Policy allocated Binding sid by the router
                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid>`
                                            
                                            .. attribute:: sr_policy_binding_sid
                                            
                                            	SR Policy Binding sid
                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid>`
                                            
                                            .. attribute:: sr_policy_explicit_path
                                            
                                            	SR Policy Explicit paths
                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath>`
                                            
                                            .. attribute:: sr_policy_preference
                                            
                                            	SR Policy Preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_tunnel_request_state
                                            
                                            	SR Tunnel Request State
                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                            
                                            .. attribute:: sr_tunnel_state
                                            
                                            	SR Tunnel State
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap_type
                                            
                                            	Tunnel Encap Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.aggregator_address = None
                                                self.aggregator_as = None
                                                self.aigp_metric_value = None
                                                self.as_path = None
                                                self.cluster = YList()
                                                self.cluster.parent = self
                                                self.cluster.name = 'cluster'
                                                self.community = YList()
                                                self.community.parent = self
                                                self.community.name = 'community'
                                                self.connector_type = None
                                                self.connector_value = YList()
                                                self.connector_value.parent = self
                                                self.connector_value.name = 'connector_value'
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.extended_community_flags = None
                                                self.is_aggregator_present = None
                                                self.is_aigp_present = None
                                                self.is_as_path_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_community_present = None
                                                self.is_connector_present = None
                                                self.is_extended_community_present = None
                                                self.is_label_index_present = None
                                                self.is_local_pref_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_metric_present = None
                                                self.is_origin_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_ssa_present = None
                                                self.is_tunnel_encap_present = None
                                                self.l2tpv3_cookie = YList()
                                                self.l2tpv3_cookie.parent = self
                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                self.l2tpv3_session_id = None
                                                self.label_index_attr = YList()
                                                self.label_index_attr.parent = self
                                                self.label_index_attr.name = 'label_index_attr'
                                                self.local_preference = None
                                                self.ls_attr = YList()
                                                self.ls_attr.parent = self
                                                self.ls_attr.name = 'ls_attr'
                                                self.metric = None
                                                self.neighbor_as = None
                                                self.origin = None
                                                self.originator = None
                                                self.pe_distinguisher_label = YList()
                                                self.pe_distinguisher_label.parent = self
                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.pmsi_type = None
                                                self.pmsi_value = YList()
                                                self.pmsi_value.parent = self
                                                self.pmsi_value.name = 'pmsi_value'
                                                self.ppm_pvalue = None
                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid()
                                                self.sr_policy_allocated_binding_sid.parent = self
                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid()
                                                self.sr_policy_binding_sid.parent = self
                                                self.sr_policy_explicit_path = YList()
                                                self.sr_policy_explicit_path.parent = self
                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                self.sr_policy_preference = None
                                                self.sr_tunnel_request_state = None
                                                self.sr_tunnel_state = None
                                                self.tunnel_encap_type = None
                                                self.unknown_attribute = YList()
                                                self.unknown_attribute.parent = self
                                                self.unknown_attribute.name = 'unknown_attribute'


                                            class SrPolicyBindingSid(object):
                                                """
                                                SR Policy Binding sid
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyBindingSid']['meta_info']


                                            class SrPolicyAllocatedBindingSid(object):
                                                """
                                                SR Policy allocated Binding sid by the router
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                            class Community(object):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity']['meta_info']


                                            class UnknownAttribute(object):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute']['meta_info']


                                            class Cluster(object):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster']['meta_info']


                                            class L2Tpv3Cookie(object):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2Tpv3Cookie']['meta_info']


                                            class ConnectorValue(object):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue']['meta_info']


                                            class PmsiValue(object):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue']['meta_info']


                                            class LsAttr(object):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr']['meta_info']


                                            class LabelIndexAttr(object):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LabelIndexAttr']['meta_info']


                                            class PeDistinguisherLabel(object):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.label = None
                                                    self.pe_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.label is not None:
                                                        return True

                                                    if self.pe_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel']['meta_info']


                                            class SrPolicyExplicitPath(object):
                                                """
                                                SR Policy Explicit paths
                                                
                                                .. attribute:: sid
                                                
                                                	Sidlist for explicit path
                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid>`
                                                
                                                .. attribute:: weight
                                                
                                                	Weight of explicit path
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.sid = YList()
                                                    self.sid.parent = self
                                                    self.sid.name = 'sid'
                                                    self.weight = None


                                                class Sid(object):
                                                    """
                                                    Sidlist for explicit path
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IP Address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label sid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Sid Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4 is not None:
                                                            return True

                                                        if self.ipv6 is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.sid is not None:
                                                        for child_ref in self.sid:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.weight is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.SrPolicyExplicitPath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.aggregator_address is not None:
                                                    return True

                                                if self.aggregator_as is not None:
                                                    return True

                                                if self.aigp_metric_value is not None:
                                                    return True

                                                if self.as_path is not None:
                                                    return True

                                                if self.cluster is not None:
                                                    for child_ref in self.cluster:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.community is not None:
                                                    for child_ref in self.community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.connector_type is not None:
                                                    return True

                                                if self.connector_value is not None:
                                                    for child_ref in self.connector_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community_flags is not None:
                                                    return True

                                                if self.is_aggregator_present is not None:
                                                    return True

                                                if self.is_aigp_present is not None:
                                                    return True

                                                if self.is_as_path_present is not None:
                                                    return True

                                                if self.is_atomic_aggregate_present is not None:
                                                    return True

                                                if self.is_community_present is not None:
                                                    return True

                                                if self.is_connector_present is not None:
                                                    return True

                                                if self.is_extended_community_present is not None:
                                                    return True

                                                if self.is_label_index_present is not None:
                                                    return True

                                                if self.is_local_pref_present is not None:
                                                    return True

                                                if self.is_ls_attribute_present is not None:
                                                    return True

                                                if self.is_metric_present is not None:
                                                    return True

                                                if self.is_origin_present is not None:
                                                    return True

                                                if self.is_pe_distinguisher_label_present is not None:
                                                    return True

                                                if self.is_pmsi_present is not None:
                                                    return True

                                                if self.is_pppmp_present is not None:
                                                    return True

                                                if self.is_ssa_present is not None:
                                                    return True

                                                if self.is_tunnel_encap_present is not None:
                                                    return True

                                                if self.l2tpv3_cookie is not None:
                                                    for child_ref in self.l2tpv3_cookie:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2tpv3_session_id is not None:
                                                    return True

                                                if self.label_index_attr is not None:
                                                    for child_ref in self.label_index_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_preference is not None:
                                                    return True

                                                if self.ls_attr is not None:
                                                    for child_ref in self.ls_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.metric is not None:
                                                    return True

                                                if self.neighbor_as is not None:
                                                    return True

                                                if self.origin is not None:
                                                    return True

                                                if self.originator is not None:
                                                    return True

                                                if self.pe_distinguisher_label is not None:
                                                    for child_ref in self.pe_distinguisher_label:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.pmsi_flags is not None:
                                                    return True

                                                if self.pmsi_label is not None:
                                                    return True

                                                if self.pmsi_type is not None:
                                                    return True

                                                if self.pmsi_value is not None:
                                                    for child_ref in self.pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.ppm_pvalue is not None:
                                                    return True

                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_explicit_path is not None:
                                                    for child_ref in self.sr_policy_explicit_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.sr_policy_preference is not None:
                                                    return True

                                                if self.sr_tunnel_request_state is not None:
                                                    return True

                                                if self.sr_tunnel_state is not None:
                                                    return True

                                                if self.tunnel_encap_type is not None:
                                                    return True

                                                if self.unknown_attribute is not None:
                                                    for child_ref in self.unknown_attribute:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet']['meta_info']


                                        class RnhAddr(object):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.len = None
                                                self.mac_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.len is not None:
                                                    return True

                                                if self.mac_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr']['meta_info']


                                        class RibrnhIp(object):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes-after-policy-in'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.attr_set is not None and self.attr_set._has_data():
                                                return True

                                            if self.attribute_key_number is not None:
                                                return True

                                            if self.attribute_reuse_id_config is not None:
                                                return True

                                            if self.attribute_reuse_id_current is not None:
                                                return True

                                            if self.attribute_reuse_id_keys is not None:
                                                return True

                                            if self.attribute_reuse_id_max_id is not None:
                                                return True

                                            if self.attribute_reuse_id_node is not None:
                                                return True

                                            if self.attribute_reuse_id_recover_sec is not None:
                                                return True

                                            if self.common_attributes is not None and self.common_attributes._has_data():
                                                return True

                                            if self.is_application_gateway_present is not None:
                                                return True

                                            if self.is_as_path2_byte is not None:
                                                return True

                                            if self.is_attr_set_present is not None:
                                                return True

                                            if self.is_ribrnh_present is not None:
                                                return True

                                            if self.is_rnh_present is not None:
                                                return True

                                            if self.ribrnh_encap is not None:
                                                return True

                                            if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                return True

                                            if self.ribrnh_mac is not None:
                                                return True

                                            if self.ribrnh_table is not None:
                                                return True

                                            if self.ribrnh_vni is not None:
                                                return True

                                            if self.ribrnhip_table is not None:
                                                return True

                                            if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                return True

                                            if self.rnh_addr_len is not None:
                                                return True

                                            if self.rnh_len is not None:
                                                return True

                                            if self.rnh_type is not None:
                                                return True

                                            if self.set_aigp_inbound_igp is not None:
                                                return True

                                            if self.set_aigp_inbound_metric is not None:
                                                return True

                                            if self.vpn_distinguisher is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:dampening'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.af_name is not None:
                                            return True

                                        if self.attributes_after_policy_in is not None and self.attributes_after_policy_in._has_data():
                                            return True

                                        if self.label_fail is not None:
                                            return True

                                        if self.label_o_or_version is not None:
                                            return True

                                        if self.label_oor is not None:
                                            return True

                                        if self.neighbor_address is not None:
                                            return True

                                        if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                            return True

                                        if self.network is not None:
                                            return True

                                        if self.no_path is not None:
                                            return True

                                        if self.path_id is not None:
                                            return True

                                        if self.path_information is not None and self.path_information._has_data():
                                            return True

                                        if self.prefix_version is not None:
                                            return True

                                        if self.process_instance_id is not None:
                                            return True

                                        if self.rd is not None:
                                            return True

                                        if self.reuse is not None:
                                            return True

                                        if self.route_distinguisher is not None:
                                            return True

                                        if self.source_rd is not None:
                                            return True

                                        if self.source_route_distinguisher is not None:
                                            return True

                                        if self.source_vrf_name is not None:
                                            return True

                                        if self.srcaf_name is not None:
                                            return True

                                        if self.version is not None:
                                            return True

                                        if self.vrf_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:dampenings'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dampening is not None:
                                        for child_ref in self.dampening:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings']['meta_info']


                            class PrefixFilters(object):
                                """
                                The BGP Prefix Filter table
                                
                                .. attribute:: prefix_filter
                                
                                	A BGP prefix filter table entry
                                	**type**\: list of    :py:class:`PrefixFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.prefix_filter = YList()
                                    self.prefix_filter.parent = self
                                    self.prefix_filter.name = 'prefix_filter'


                                class PrefixFilter(object):
                                    """
                                    A BGP prefix filter table entry
                                    
                                    .. attribute:: neighbor_address  <key>
                                    
                                    	Neighbor address
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: af_name
                                    
                                    	Address family identfier
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr>`
                                    
                                    .. attribute:: prefix_list_info
                                    
                                    	Prefix list
                                    	**type**\:   :py:class:`PrefixListInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.neighbor_address = None
                                        self.af_name = None
                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr()
                                        self.neighbor_address_xr.parent = self
                                        self.prefix_list_info = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo()
                                        self.prefix_list_info.parent = self


                                    class NeighborAddressXr(object):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address-xr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr']['meta_info']


                                    class PrefixListInfo(object):
                                        """
                                        Prefix list
                                        
                                        .. attribute:: bgp_pfxlst
                                        
                                        	bgp pfxlst
                                        	**type**\: list of    :py:class:`BgpPfxlst <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.bgp_pfxlst = YList()
                                            self.bgp_pfxlst.parent = self
                                            self.bgp_pfxlst.name = 'bgp_pfxlst'


                                        class BgpPfxlst(object):
                                            """
                                            bgp pfxlst
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:   :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix>`
                                            
                                            .. attribute:: is_prefix_grant
                                            
                                            	TRUE = permit, FALSE = deny
                                            	**type**\:  bool
                                            
                                            .. attribute:: max_prefix_length
                                            
                                            	Maximum prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: min_prefix_length
                                            
                                            	Minimum prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self.is_prefix_grant = None
                                                self.max_prefix_length = None
                                                self.min_prefix_length = None
                                                self.sequence_number = None


                                            class BgpPrefix(object):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:   :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self.prefix_length = None


                                                class Prefix(object):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: ipv4sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv6sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnMspwAddress>`
                                                    
                                                    .. attribute:: l2vpnvpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnvplsAddress>`
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4mdt_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4sr_policy_address.parent = self
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6sr_policy_address.parent = self
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_flowspec_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnvplsAddress()
                                                        self.l2vpnvpls_address.parent = self
                                                        self.ls_ls_address = None
                                                        self.rt_constraint_address = None


                                                    class L2VpnvplsAddress(object):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnvplsAddress']['meta_info']


                                                    class L2VpnMspwAddress(object):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.l2vpn_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.l2vpn_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2VpnMspwAddress']['meta_info']


                                                    class Ipv4SrPolicyAddress(object):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv4_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv4_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress']['meta_info']


                                                    class Ipv6SrPolicyAddress(object):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2015-08-27'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.ipv6_srpolicy_address = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.ipv6_srpolicy_address is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.afi is not None:
                                                            return True

                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.ipv4_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4_label_address is not None:
                                                            return True

                                                        if self.ipv4_mcast_address is not None:
                                                            return True

                                                        if self.ipv4_tunnel_address is not None:
                                                            return True

                                                        if self.ipv4mdt_address is not None:
                                                            return True

                                                        if self.ipv4mvpn_address is not None:
                                                            return True

                                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv4vpn_address is not None:
                                                            return True

                                                        if self.ipv4vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv4vpna_mcastddress is not None:
                                                            return True

                                                        if self.ipv6_address is not None:
                                                            return True

                                                        if self.ipv6_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6_label_address is not None:
                                                            return True

                                                        if self.ipv6_mcast_address is not None:
                                                            return True

                                                        if self.ipv6mvpn_address is not None:
                                                            return True

                                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                            return True

                                                        if self.ipv6vpn_address is not None:
                                                            return True

                                                        if self.ipv6vpn_flowspec_address is not None:
                                                            return True

                                                        if self.ipv6vpn_mcast_address is not None:
                                                            return True

                                                        if self.l2vpn_evpn_address is not None:
                                                            return True

                                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                            return True

                                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                            return True

                                                        if self.ls_ls_address is not None:
                                                            return True

                                                        if self.rt_constraint_address is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-prefix'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.prefix is not None and self.prefix._has_data():
                                                        return True

                                                    if self.prefix_length is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bgp-pfxlst'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bgp_prefix is not None and self.bgp_prefix._has_data():
                                                    return True

                                                if self.is_prefix_grant is not None:
                                                    return True

                                                if self.max_prefix_length is not None:
                                                    return True

                                                if self.min_prefix_length is not None:
                                                    return True

                                                if self.sequence_number is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix-list-info'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bgp_pfxlst is not None:
                                                for child_ref in self.bgp_pfxlst:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.neighbor_address is None:
                                            raise YPYModelError('Key property neighbor_address is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix-filter[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address = ' + str(self.neighbor_address) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.neighbor_address is not None:
                                            return True

                                        if self.af_name is not None:
                                            return True

                                        if self.neighbor_address_xr is not None and self.neighbor_address_xr._has_data():
                                            return True

                                        if self.prefix_list_info is not None and self.prefix_list_info._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:prefix-filters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.prefix_filter is not None:
                                        for child_ref in self.prefix_filter:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters']['meta_info']


                            class Attributes(object):
                                """
                                The BGP Attribute table
                                
                                .. attribute:: attribute
                                
                                	A BGP Attribute table entry
                                	**type**\: list of    :py:class:`Attribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.attribute = YList()
                                    self.attribute.parent = self
                                    self.attribute.name = 'attribute'


                                class Attribute(object):
                                    """
                                    A BGP Attribute table entry
                                    
                                    .. attribute:: attribute_cache_bucket
                                    
                                    	Attribute cache bucket
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: attribute_cache_id
                                    
                                    	Attribute cache ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: attribute_iid
                                    
                                    	Attribute IID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: attribute_info
                                    
                                    	Attributes
                                    	**type**\:   :py:class:`AttributeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo>`
                                    
                                    .. attribute:: attribute_instance_id
                                    
                                    	Attribute Instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: attribute_structure_hash_value
                                    
                                    	Hash value for attribute structure
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: attribute_structure_id
                                    
                                    	ID of attribute structure
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: reference_count
                                    
                                    	Number of paths which use this attribute structure
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.attribute_cache_bucket = None
                                        self.attribute_cache_id = None
                                        self.attribute_iid = None
                                        self.attribute_info = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo()
                                        self.attribute_info.parent = self
                                        self.attribute_instance_id = None
                                        self.attribute_structure_hash_value = None
                                        self.attribute_structure_id = None
                                        self.process_instance_id = None
                                        self.reference_count = None


                                    class AttributeInfo(object):
                                        """
                                        Attributes
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet>`
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes>`
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\:  bool
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp>`
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr>`
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\:  bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\:  bool
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet()
                                            self.attr_set.parent = self
                                            self.attribute_key_number = None
                                            self.attribute_reuse_id_config = None
                                            self.attribute_reuse_id_current = None
                                            self.attribute_reuse_id_keys = None
                                            self.attribute_reuse_id_max_id = None
                                            self.attribute_reuse_id_node = None
                                            self.attribute_reuse_id_recover_sec = None
                                            self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self.is_application_gateway_present = None
                                            self.is_as_path2_byte = None
                                            self.is_attr_set_present = None
                                            self.is_ribrnh_present = None
                                            self.is_rnh_present = None
                                            self.ribrnh_encap = None
                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self.ribrnh_mac = None
                                            self.ribrnh_table = None
                                            self.ribrnh_vni = None
                                            self.ribrnhip_table = None
                                            self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self.rnh_addr_len = None
                                            self.rnh_len = None
                                            self.rnh_type = None
                                            self.set_aigp_inbound_igp = None
                                            self.set_aigp_inbound_metric = None
                                            self.vpn_distinguisher = None


                                        class CommonAttributes(object):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_encap_present
                                            
                                            	Tunnel Encap attribute present 
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LabelIndexAttr>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_policy_allocated_binding_sid
                                            
                                            	SR Policy allocated Binding sid by the router
                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                            
                                            .. attribute:: sr_policy_binding_sid
                                            
                                            	SR Policy Binding sid
                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyBindingSid>`
                                            
                                            .. attribute:: sr_policy_explicit_path
                                            
                                            	SR Policy Explicit paths
                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyExplicitPath>`
                                            
                                            .. attribute:: sr_policy_preference
                                            
                                            	SR Policy Preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_tunnel_request_state
                                            
                                            	SR Tunnel Request State
                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                            
                                            .. attribute:: sr_tunnel_state
                                            
                                            	SR Tunnel State
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap_type
                                            
                                            	Tunnel Encap Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.aggregator_address = None
                                                self.aggregator_as = None
                                                self.aigp_metric_value = None
                                                self.as_path = None
                                                self.cluster = YList()
                                                self.cluster.parent = self
                                                self.cluster.name = 'cluster'
                                                self.community = YList()
                                                self.community.parent = self
                                                self.community.name = 'community'
                                                self.connector_type = None
                                                self.connector_value = YList()
                                                self.connector_value.parent = self
                                                self.connector_value.name = 'connector_value'
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.extended_community_flags = None
                                                self.is_aggregator_present = None
                                                self.is_aigp_present = None
                                                self.is_as_path_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_community_present = None
                                                self.is_connector_present = None
                                                self.is_extended_community_present = None
                                                self.is_label_index_present = None
                                                self.is_local_pref_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_metric_present = None
                                                self.is_origin_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_ssa_present = None
                                                self.is_tunnel_encap_present = None
                                                self.l2tpv3_cookie = YList()
                                                self.l2tpv3_cookie.parent = self
                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                self.l2tpv3_session_id = None
                                                self.label_index_attr = YList()
                                                self.label_index_attr.parent = self
                                                self.label_index_attr.name = 'label_index_attr'
                                                self.local_preference = None
                                                self.ls_attr = YList()
                                                self.ls_attr.parent = self
                                                self.ls_attr.name = 'ls_attr'
                                                self.metric = None
                                                self.neighbor_as = None
                                                self.origin = None
                                                self.originator = None
                                                self.pe_distinguisher_label = YList()
                                                self.pe_distinguisher_label.parent = self
                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.pmsi_type = None
                                                self.pmsi_value = YList()
                                                self.pmsi_value.parent = self
                                                self.pmsi_value.name = 'pmsi_value'
                                                self.ppm_pvalue = None
                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyAllocatedBindingSid()
                                                self.sr_policy_allocated_binding_sid.parent = self
                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyBindingSid()
                                                self.sr_policy_binding_sid.parent = self
                                                self.sr_policy_explicit_path = YList()
                                                self.sr_policy_explicit_path.parent = self
                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                self.sr_policy_preference = None
                                                self.sr_tunnel_request_state = None
                                                self.sr_tunnel_state = None
                                                self.tunnel_encap_type = None
                                                self.unknown_attribute = YList()
                                                self.unknown_attribute.parent = self
                                                self.unknown_attribute.name = 'unknown_attribute'


                                            class SrPolicyBindingSid(object):
                                                """
                                                SR Policy Binding sid
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                            class SrPolicyAllocatedBindingSid(object):
                                                """
                                                SR Policy allocated Binding sid by the router
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                            class Community(object):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity']['meta_info']


                                            class UnknownAttribute(object):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute']['meta_info']


                                            class Cluster(object):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster']['meta_info']


                                            class L2Tpv3Cookie(object):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                            class ConnectorValue(object):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue']['meta_info']


                                            class PmsiValue(object):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue']['meta_info']


                                            class LsAttr(object):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr']['meta_info']


                                            class LabelIndexAttr(object):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LabelIndexAttr']['meta_info']


                                            class PeDistinguisherLabel(object):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.label = None
                                                    self.pe_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.label is not None:
                                                        return True

                                                    if self.pe_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                            class SrPolicyExplicitPath(object):
                                                """
                                                SR Policy Explicit paths
                                                
                                                .. attribute:: sid
                                                
                                                	Sidlist for explicit path
                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                                
                                                .. attribute:: weight
                                                
                                                	Weight of explicit path
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.sid = YList()
                                                    self.sid.parent = self
                                                    self.sid.name = 'sid'
                                                    self.weight = None


                                                class Sid(object):
                                                    """
                                                    Sidlist for explicit path
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IP Address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label sid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Sid Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4 is not None:
                                                            return True

                                                        if self.ipv6 is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.sid is not None:
                                                        for child_ref in self.sid:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.weight is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.aggregator_address is not None:
                                                    return True

                                                if self.aggregator_as is not None:
                                                    return True

                                                if self.aigp_metric_value is not None:
                                                    return True

                                                if self.as_path is not None:
                                                    return True

                                                if self.cluster is not None:
                                                    for child_ref in self.cluster:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.community is not None:
                                                    for child_ref in self.community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.connector_type is not None:
                                                    return True

                                                if self.connector_value is not None:
                                                    for child_ref in self.connector_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community_flags is not None:
                                                    return True

                                                if self.is_aggregator_present is not None:
                                                    return True

                                                if self.is_aigp_present is not None:
                                                    return True

                                                if self.is_as_path_present is not None:
                                                    return True

                                                if self.is_atomic_aggregate_present is not None:
                                                    return True

                                                if self.is_community_present is not None:
                                                    return True

                                                if self.is_connector_present is not None:
                                                    return True

                                                if self.is_extended_community_present is not None:
                                                    return True

                                                if self.is_label_index_present is not None:
                                                    return True

                                                if self.is_local_pref_present is not None:
                                                    return True

                                                if self.is_ls_attribute_present is not None:
                                                    return True

                                                if self.is_metric_present is not None:
                                                    return True

                                                if self.is_origin_present is not None:
                                                    return True

                                                if self.is_pe_distinguisher_label_present is not None:
                                                    return True

                                                if self.is_pmsi_present is not None:
                                                    return True

                                                if self.is_pppmp_present is not None:
                                                    return True

                                                if self.is_ssa_present is not None:
                                                    return True

                                                if self.is_tunnel_encap_present is not None:
                                                    return True

                                                if self.l2tpv3_cookie is not None:
                                                    for child_ref in self.l2tpv3_cookie:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2tpv3_session_id is not None:
                                                    return True

                                                if self.label_index_attr is not None:
                                                    for child_ref in self.label_index_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_preference is not None:
                                                    return True

                                                if self.ls_attr is not None:
                                                    for child_ref in self.ls_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.metric is not None:
                                                    return True

                                                if self.neighbor_as is not None:
                                                    return True

                                                if self.origin is not None:
                                                    return True

                                                if self.originator is not None:
                                                    return True

                                                if self.pe_distinguisher_label is not None:
                                                    for child_ref in self.pe_distinguisher_label:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.pmsi_flags is not None:
                                                    return True

                                                if self.pmsi_label is not None:
                                                    return True

                                                if self.pmsi_type is not None:
                                                    return True

                                                if self.pmsi_value is not None:
                                                    for child_ref in self.pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.ppm_pvalue is not None:
                                                    return True

                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_explicit_path is not None:
                                                    for child_ref in self.sr_policy_explicit_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.sr_policy_preference is not None:
                                                    return True

                                                if self.sr_tunnel_request_state is not None:
                                                    return True

                                                if self.sr_tunnel_state is not None:
                                                    return True

                                                if self.tunnel_encap_type is not None:
                                                    return True

                                                if self.unknown_attribute is not None:
                                                    for child_ref in self.unknown_attribute:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes']['meta_info']


                                        class AttrSet(object):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\:  str
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster>`
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community>`
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tunnel_encap_present
                                            
                                            	Tunnel Encap attribute present 
                                            	**type**\:  bool
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2Tpv3Cookie>`
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_index_attr
                                            
                                            	Label Index attribute
                                            	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LabelIndexAttr>`
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr>`
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_policy_allocated_binding_sid
                                            
                                            	SR Policy allocated Binding sid by the router
                                            	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyAllocatedBindingSid>`
                                            
                                            .. attribute:: sr_policy_binding_sid
                                            
                                            	SR Policy Binding sid
                                            	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyBindingSid>`
                                            
                                            .. attribute:: sr_policy_explicit_path
                                            
                                            	SR Policy Explicit paths
                                            	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyExplicitPath>`
                                            
                                            .. attribute:: sr_policy_preference
                                            
                                            	SR Policy Preference
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sr_tunnel_request_state
                                            
                                            	SR Tunnel Request State
                                            	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                            
                                            .. attribute:: sr_tunnel_state
                                            
                                            	SR Tunnel State
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_encap_type
                                            
                                            	Tunnel Encap Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.aggregator_address = None
                                                self.aggregator_as = None
                                                self.aigp_metric_value = None
                                                self.as_path = None
                                                self.cluster = YList()
                                                self.cluster.parent = self
                                                self.cluster.name = 'cluster'
                                                self.community = YList()
                                                self.community.parent = self
                                                self.community.name = 'community'
                                                self.connector_type = None
                                                self.connector_value = YList()
                                                self.connector_value.parent = self
                                                self.connector_value.name = 'connector_value'
                                                self.extended_community = YList()
                                                self.extended_community.parent = self
                                                self.extended_community.name = 'extended_community'
                                                self.extended_community_flags = None
                                                self.is_aggregator_present = None
                                                self.is_aigp_present = None
                                                self.is_as_path_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_community_present = None
                                                self.is_connector_present = None
                                                self.is_extended_community_present = None
                                                self.is_label_index_present = None
                                                self.is_local_pref_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_metric_present = None
                                                self.is_origin_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_ssa_present = None
                                                self.is_tunnel_encap_present = None
                                                self.l2tpv3_cookie = YList()
                                                self.l2tpv3_cookie.parent = self
                                                self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                                self.l2tpv3_session_id = None
                                                self.label_index_attr = YList()
                                                self.label_index_attr.parent = self
                                                self.label_index_attr.name = 'label_index_attr'
                                                self.local_preference = None
                                                self.ls_attr = YList()
                                                self.ls_attr.parent = self
                                                self.ls_attr.name = 'ls_attr'
                                                self.metric = None
                                                self.neighbor_as = None
                                                self.origin = None
                                                self.originator = None
                                                self.pe_distinguisher_label = YList()
                                                self.pe_distinguisher_label.parent = self
                                                self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.pmsi_type = None
                                                self.pmsi_value = YList()
                                                self.pmsi_value.parent = self
                                                self.pmsi_value.name = 'pmsi_value'
                                                self.ppm_pvalue = None
                                                self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyAllocatedBindingSid()
                                                self.sr_policy_allocated_binding_sid.parent = self
                                                self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyBindingSid()
                                                self.sr_policy_binding_sid.parent = self
                                                self.sr_policy_explicit_path = YList()
                                                self.sr_policy_explicit_path.parent = self
                                                self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                                self.sr_policy_preference = None
                                                self.sr_tunnel_request_state = None
                                                self.sr_tunnel_state = None
                                                self.tunnel_encap_type = None
                                                self.unknown_attribute = YList()
                                                self.unknown_attribute.parent = self
                                                self.unknown_attribute.name = 'unknown_attribute'


                                            class SrPolicyBindingSid(object):
                                                """
                                                SR Policy Binding sid
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyBindingSid']['meta_info']


                                            class SrPolicyAllocatedBindingSid(object):
                                                """
                                                SR Policy allocated Binding sid by the router
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_address = None
                                                    self.label = None
                                                    self.type = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_address is not None:
                                                        return True

                                                    if self.label is not None:
                                                        return True

                                                    if self.type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                            class Community(object):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community']['meta_info']


                                            class ExtendedCommunity(object):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity']['meta_info']


                                            class UnknownAttribute(object):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute']['meta_info']


                                            class Cluster(object):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster']['meta_info']


                                            class L2Tpv3Cookie(object):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2Tpv3Cookie']['meta_info']


                                            class ConnectorValue(object):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue']['meta_info']


                                            class PmsiValue(object):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue']['meta_info']


                                            class LsAttr(object):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr']['meta_info']


                                            class LabelIndexAttr(object):
                                                """
                                                Label Index attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LabelIndexAttr']['meta_info']


                                            class PeDistinguisherLabel(object):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.label = None
                                                    self.pe_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.label is not None:
                                                        return True

                                                    if self.pe_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel']['meta_info']


                                            class SrPolicyExplicitPath(object):
                                                """
                                                SR Policy Explicit paths
                                                
                                                .. attribute:: sid
                                                
                                                	Sidlist for explicit path
                                                	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyExplicitPath.Sid>`
                                                
                                                .. attribute:: weight
                                                
                                                	Weight of explicit path
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.sid = YList()
                                                    self.sid.parent = self
                                                    self.sid.name = 'sid'
                                                    self.weight = None


                                                class Sid(object):
                                                    """
                                                    Sidlist for explicit path
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IP Address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPv6 address sid
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	MPLS Label sid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Sid Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2015-08-27'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self.label = None
                                                        self.type = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4 is not None:
                                                            return True

                                                        if self.ipv6 is not None:
                                                            return True

                                                        if self.label is not None:
                                                            return True

                                                        if self.type is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.sid is not None:
                                                        for child_ref in self.sid:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.weight is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyExplicitPath']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.aggregator_address is not None:
                                                    return True

                                                if self.aggregator_as is not None:
                                                    return True

                                                if self.aigp_metric_value is not None:
                                                    return True

                                                if self.as_path is not None:
                                                    return True

                                                if self.cluster is not None:
                                                    for child_ref in self.cluster:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.community is not None:
                                                    for child_ref in self.community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.connector_type is not None:
                                                    return True

                                                if self.connector_value is not None:
                                                    for child_ref in self.connector_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community is not None:
                                                    for child_ref in self.extended_community:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.extended_community_flags is not None:
                                                    return True

                                                if self.is_aggregator_present is not None:
                                                    return True

                                                if self.is_aigp_present is not None:
                                                    return True

                                                if self.is_as_path_present is not None:
                                                    return True

                                                if self.is_atomic_aggregate_present is not None:
                                                    return True

                                                if self.is_community_present is not None:
                                                    return True

                                                if self.is_connector_present is not None:
                                                    return True

                                                if self.is_extended_community_present is not None:
                                                    return True

                                                if self.is_label_index_present is not None:
                                                    return True

                                                if self.is_local_pref_present is not None:
                                                    return True

                                                if self.is_ls_attribute_present is not None:
                                                    return True

                                                if self.is_metric_present is not None:
                                                    return True

                                                if self.is_origin_present is not None:
                                                    return True

                                                if self.is_pe_distinguisher_label_present is not None:
                                                    return True

                                                if self.is_pmsi_present is not None:
                                                    return True

                                                if self.is_pppmp_present is not None:
                                                    return True

                                                if self.is_ssa_present is not None:
                                                    return True

                                                if self.is_tunnel_encap_present is not None:
                                                    return True

                                                if self.l2tpv3_cookie is not None:
                                                    for child_ref in self.l2tpv3_cookie:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.l2tpv3_session_id is not None:
                                                    return True

                                                if self.label_index_attr is not None:
                                                    for child_ref in self.label_index_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.local_preference is not None:
                                                    return True

                                                if self.ls_attr is not None:
                                                    for child_ref in self.ls_attr:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.metric is not None:
                                                    return True

                                                if self.neighbor_as is not None:
                                                    return True

                                                if self.origin is not None:
                                                    return True

                                                if self.originator is not None:
                                                    return True

                                                if self.pe_distinguisher_label is not None:
                                                    for child_ref in self.pe_distinguisher_label:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.pmsi_flags is not None:
                                                    return True

                                                if self.pmsi_label is not None:
                                                    return True

                                                if self.pmsi_type is not None:
                                                    return True

                                                if self.pmsi_value is not None:
                                                    for child_ref in self.pmsi_value:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.ppm_pvalue is not None:
                                                    return True

                                                if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                                    return True

                                                if self.sr_policy_explicit_path is not None:
                                                    for child_ref in self.sr_policy_explicit_path:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.sr_policy_preference is not None:
                                                    return True

                                                if self.sr_tunnel_request_state is not None:
                                                    return True

                                                if self.sr_tunnel_state is not None:
                                                    return True

                                                if self.tunnel_encap_type is not None:
                                                    return True

                                                if self.unknown_attribute is not None:
                                                    for child_ref in self.unknown_attribute:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet']['meta_info']


                                        class RnhAddr(object):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.len = None
                                                self.mac_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.len is not None:
                                                    return True

                                                if self.mac_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr']['meta_info']


                                        class RibrnhIp(object):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attribute-info'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.attr_set is not None and self.attr_set._has_data():
                                                return True

                                            if self.attribute_key_number is not None:
                                                return True

                                            if self.attribute_reuse_id_config is not None:
                                                return True

                                            if self.attribute_reuse_id_current is not None:
                                                return True

                                            if self.attribute_reuse_id_keys is not None:
                                                return True

                                            if self.attribute_reuse_id_max_id is not None:
                                                return True

                                            if self.attribute_reuse_id_node is not None:
                                                return True

                                            if self.attribute_reuse_id_recover_sec is not None:
                                                return True

                                            if self.common_attributes is not None and self.common_attributes._has_data():
                                                return True

                                            if self.is_application_gateway_present is not None:
                                                return True

                                            if self.is_as_path2_byte is not None:
                                                return True

                                            if self.is_attr_set_present is not None:
                                                return True

                                            if self.is_ribrnh_present is not None:
                                                return True

                                            if self.is_rnh_present is not None:
                                                return True

                                            if self.ribrnh_encap is not None:
                                                return True

                                            if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                                return True

                                            if self.ribrnh_mac is not None:
                                                return True

                                            if self.ribrnh_table is not None:
                                                return True

                                            if self.ribrnh_vni is not None:
                                                return True

                                            if self.ribrnhip_table is not None:
                                                return True

                                            if self.rnh_addr is not None and self.rnh_addr._has_data():
                                                return True

                                            if self.rnh_addr_len is not None:
                                                return True

                                            if self.rnh_len is not None:
                                                return True

                                            if self.rnh_type is not None:
                                                return True

                                            if self.set_aigp_inbound_igp is not None:
                                                return True

                                            if self.set_aigp_inbound_metric is not None:
                                                return True

                                            if self.vpn_distinguisher is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attribute'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.attribute_cache_bucket is not None:
                                            return True

                                        if self.attribute_cache_id is not None:
                                            return True

                                        if self.attribute_iid is not None:
                                            return True

                                        if self.attribute_info is not None and self.attribute_info._has_data():
                                            return True

                                        if self.attribute_instance_id is not None:
                                            return True

                                        if self.attribute_structure_hash_value is not None:
                                            return True

                                        if self.attribute_structure_id is not None:
                                            return True

                                        if self.process_instance_id is not None:
                                            return True

                                        if self.reference_count is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.attribute is not None:
                                        for child_ref in self.attribute:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.af_name is None:
                                    raise YPYModelError('Key property af_name is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af[Cisco-IOS-XR-ipv4-bgp-oper:af-name = ' + str(self.af_name) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.af_name is not None:
                                    return True

                                if self.advertised_path_counts is not None and self.advertised_path_counts._has_data():
                                    return True

                                if self.advertised_path_xr is not None and self.advertised_path_xr._has_data():
                                    return True

                                if self.advertised_paths is not None and self.advertised_paths._has_data():
                                    return True

                                if self.af_process_info is not None and self.af_process_info._has_data():
                                    return True

                                if self.attributes is not None and self.attributes._has_data():
                                    return True

                                if self.bmp_paths is not None and self.bmp_paths._has_data():
                                    return True

                                if self.convergence is not None and self.convergence._has_data():
                                    return True

                                if self.dampenings is not None and self.dampenings._has_data():
                                    return True

                                if self.epes is not None and self.epes._has_data():
                                    return True

                                if self.global_af_process_info is not None and self.global_af_process_info._has_data():
                                    return True

                                if self.neighbor_af_table is not None and self.neighbor_af_table._has_data():
                                    return True

                                if self.network_all_rds is not None and self.network_all_rds._has_data():
                                    return True

                                if self.network_lookup_all_rds is not None and self.network_lookup_all_rds._has_data():
                                    return True

                                if self.network_prefixes is not None and self.network_prefixes._has_data():
                                    return True

                                if self.networks is not None and self.networks._has_data():
                                    return True

                                if self.next_hop_address_families is not None and self.next_hop_address_families._has_data():
                                    return True

                                if self.path_labeled_table is not None and self.path_labeled_table._has_data():
                                    return True

                                if self.path_table is not None and self.path_table._has_data():
                                    return True

                                if self.path_used_table is not None and self.path_used_table._has_data():
                                    return True

                                if self.policies is not None and self.policies._has_data():
                                    return True

                                if self.prefix_filters is not None and self.prefix_filters._has_data():
                                    return True

                                if self.rpc_sets is not None and self.rpc_sets._has_data():
                                    return True

                                if self.rt_set_counters is not None and self.rt_set_counters._has_data():
                                    return True

                                if self.sourced_networks is not None and self.sourced_networks._has_data():
                                    return True

                                if self.update_generation_address_family is not None and self.update_generation_address_family._has_data():
                                    return True

                                if self.update_generation_filter_groups is not None and self.update_generation_filter_groups._has_data():
                                    return True

                                if self.update_generation_neighbors is not None and self.update_generation_neighbors._has_data():
                                    return True

                                if self.update_generation_sub_groups is not None and self.update_generation_sub_groups._has_data():
                                    return True

                                if self.update_generation_update_groups is not None and self.update_generation_update_groups._has_data():
                                    return True

                                if self.update_groups is not None and self.update_groups._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:afs'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af is not None:
                                for child_ref in self.af:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs']['meta_info']


                    class Information(object):
                        """
                        Meta data for VRF
                        
                        .. attribute:: route_distinguisher
                        
                        	Route Distinguisher
                        	**type**\:  str
                        
                        	**pattern:** [a\-fA\-F0\-9]{16}
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.route_distinguisher = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.route_distinguisher is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Information']['meta_info']


                    class UpdateInboundFilterVrf(object):
                        """
                        Update inbound filtering information for the VRF
                        
                        .. attribute:: last_update_filtered_age
                        
                        	Time since last filtered messages received event (in seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: last_update_filtered_timestamp
                        
                        	Last Filtered messages received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                        	**type**\:   :py:class:`LastUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp>`
                        
                        .. attribute:: update_filtered_message_count
                        
                        	Filtered messages count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_filtered_neighbor_count
                        
                        	Count of neighbors that received filtered messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_vrf_name
                        
                        	VRF Name
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.last_update_filtered_age = None
                            self.last_update_filtered_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp()
                            self.last_update_filtered_timestamp.parent = self
                            self.update_filtered_message_count = None
                            self.update_filtered_neighbor_count = None
                            self.update_vrf_name = None


                        class LastUpdateFilteredTimestamp(object):
                            """
                            Last Filtered messages received time\: time
                            elapsed since 00\:00\:00 UTC, January 1, 1970
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.nanoseconds = None
                                self.seconds = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-filtered-timestamp'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.nanoseconds is not None:
                                    return True

                                if self.seconds is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-inbound-filter-vrf'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.last_update_filtered_age is not None:
                                return True

                            if self.last_update_filtered_timestamp is not None and self.last_update_filtered_timestamp._has_data():
                                return True

                            if self.update_filtered_message_count is not None:
                                return True

                            if self.update_filtered_neighbor_count is not None:
                                return True

                            if self.update_vrf_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterVrf']['meta_info']


                    class Postits(object):
                        """
                        The BGP Neighbor table
                        
                        .. attribute:: postit
                        
                        	A BGP Postit table entry
                        	**type**\: list of    :py:class:`Postit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.postit = YList()
                            self.postit.parent = self
                            self.postit.name = 'postit'


                        class Postit(object):
                            """
                            A BGP Postit table entry
                            
                            .. attribute:: neighbor_address  <key>
                            
                            	Neighbor address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: connect_state
                            
                            	State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_af
                            
                            	Neighbor Afi
                            	**type**\: list of    :py:class:`NeighborAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborAf>`
                            
                            .. attribute:: neighbors_address
                            
                            	Neighbor Addr
                            	**type**\:   :py:class:`NeighborsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress>`
                            
                            .. attribute:: nsr_state
                            
                            	NSR state
                            	**type**\:   :py:class:`BgpSyncNbrNsrStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrStateEnum>`
                            
                            .. attribute:: postit_info
                            
                            	Postit Info
                            	**type**\: list of    :py:class:`PostitInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.PostitInfo>`
                            
                            .. attribute:: start_time
                            
                            	StartTime
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vrf_name
                            
                            	VRF Name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.neighbor_address = None
                                self.connect_state = None
                                self.neighbor_af = YList()
                                self.neighbor_af.parent = self
                                self.neighbor_af.name = 'neighbor_af'
                                self.neighbors_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress()
                                self.neighbors_address.parent = self
                                self.nsr_state = None
                                self.postit_info = YList()
                                self.postit_info.parent = self
                                self.postit_info.name = 'postit_info'
                                self.start_time = None
                                self.vrf_name = None


                            class NeighborsAddress(object):
                                """
                                Neighbor Addr
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpnvpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.L2VpnvplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4mdt_address = None
                                    self.ipv4mvpn_address = None
                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress()
                                    self.ipv4sr_policy_address.parent = self
                                    self.ipv4vpn_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress()
                                    self.ipv6sr_policy_address.parent = self
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_flowspec_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.l2vpn_evpn_address = None
                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.L2VpnvplsAddress()
                                    self.l2vpnvpls_address.parent = self
                                    self.ls_ls_address = None
                                    self.rt_constraint_address = None


                                class L2VpnvplsAddress(object):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.L2VpnvplsAddress']['meta_info']


                                class L2VpnMspwAddress(object):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.L2VpnMspwAddress']['meta_info']


                                class Ipv4SrPolicyAddress(object):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress']['meta_info']


                                class Ipv6SrPolicyAddress(object):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv6_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv6_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbors-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.afi is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv4_flowspec_address is not None:
                                        return True

                                    if self.ipv4_label_address is not None:
                                        return True

                                    if self.ipv4_mcast_address is not None:
                                        return True

                                    if self.ipv4_tunnel_address is not None:
                                        return True

                                    if self.ipv4mdt_address is not None:
                                        return True

                                    if self.ipv4mvpn_address is not None:
                                        return True

                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                        return True

                                    if self.ipv4vpn_address is not None:
                                        return True

                                    if self.ipv4vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv4vpna_mcastddress is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    if self.ipv6_flowspec_address is not None:
                                        return True

                                    if self.ipv6_label_address is not None:
                                        return True

                                    if self.ipv6_mcast_address is not None:
                                        return True

                                    if self.ipv6mvpn_address is not None:
                                        return True

                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                        return True

                                    if self.ipv6vpn_address is not None:
                                        return True

                                    if self.ipv6vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv6vpn_mcast_address is not None:
                                        return True

                                    if self.l2vpn_evpn_address is not None:
                                        return True

                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                        return True

                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                        return True

                                    if self.ls_ls_address is not None:
                                        return True

                                    if self.rt_constraint_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress']['meta_info']


                            class NeighborAf(object):
                                """
                                Neighbor Afi
                                
                                .. attribute:: entry
                                
                                	Array entry
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.entry = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-af'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.entry is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborAf']['meta_info']


                            class PostitInfo(object):
                                """
                                Postit Info
                                
                                .. attribute:: peer_id
                                
                                	Peer ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: postit_af_name
                                
                                	Postit Afi
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: postit_direction
                                
                                	Postit Direction
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: postit_flags
                                
                                	Postit Flags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: postit_id
                                
                                	Postit ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: postit_notification
                                
                                	Postit notification
                                	**type**\:   :py:class:`PostitNotification <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification>`
                                
                                .. attribute:: postit_policy
                                
                                	Policy
                                	**type**\:  str
                                
                                .. attribute:: postit_reset
                                
                                	Reset
                                	**type**\:   :py:class:`BgpResetReasonIndexEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndexEnum>`
                                
                                .. attribute:: postit_subtype
                                
                                	Postit Subtype
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: postit_ts
                                
                                	Postit TS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: postit_type
                                
                                	Postit Type
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.peer_id = None
                                    self.postit_af_name = None
                                    self.postit_direction = None
                                    self.postit_flags = None
                                    self.postit_id = None
                                    self.postit_notification = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification()
                                    self.postit_notification.parent = self
                                    self.postit_policy = None
                                    self.postit_reset = None
                                    self.postit_subtype = None
                                    self.postit_ts = None
                                    self.postit_type = None


                                class PostitNotification(object):
                                    """
                                    Postit notification
                                    
                                    .. attribute:: last_notification_data
                                    
                                    	Message data in last notification
                                    	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData>`
                                    
                                    .. attribute:: notification_error_code
                                    
                                    	Error code in last notification
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: notification_error_subcode
                                    
                                    	Error subcode in last notification
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: time_since_last_notification
                                    
                                    	Time since the last notification was sent or received (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.last_notification_data = YList()
                                        self.last_notification_data.parent = self
                                        self.last_notification_data.name = 'last_notification_data'
                                        self.notification_error_code = None
                                        self.notification_error_subcode = None
                                        self.time_since_last_notification = None


                                    class LastNotificationData(object):
                                        """
                                        Message data in last notification
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.entry = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-notification-data'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.entry is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:postit-notification'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.last_notification_data is not None:
                                            for child_ref in self.last_notification_data:
                                                if child_ref._has_data():
                                                    return True

                                        if self.notification_error_code is not None:
                                            return True

                                        if self.notification_error_subcode is not None:
                                            return True

                                        if self.time_since_last_notification is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:postit-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.peer_id is not None:
                                        return True

                                    if self.postit_af_name is not None:
                                        return True

                                    if self.postit_direction is not None:
                                        return True

                                    if self.postit_flags is not None:
                                        return True

                                    if self.postit_id is not None:
                                        return True

                                    if self.postit_notification is not None and self.postit_notification._has_data():
                                        return True

                                    if self.postit_policy is not None:
                                        return True

                                    if self.postit_reset is not None:
                                        return True

                                    if self.postit_subtype is not None:
                                        return True

                                    if self.postit_ts is not None:
                                        return True

                                    if self.postit_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.PostitInfo']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.neighbor_address is None:
                                    raise YPYModelError('Key property neighbor_address is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:postit[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address = ' + str(self.neighbor_address) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.neighbor_address is not None:
                                    return True

                                if self.connect_state is not None:
                                    return True

                                if self.neighbor_af is not None:
                                    for child_ref in self.neighbor_af:
                                        if child_ref._has_data():
                                            return True

                                if self.neighbors_address is not None and self.neighbors_address._has_data():
                                    return True

                                if self.nsr_state is not None:
                                    return True

                                if self.postit_info is not None:
                                    for child_ref in self.postit_info:
                                        if child_ref._has_data():
                                            return True

                                if self.start_time is not None:
                                    return True

                                if self.vrf_name is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:postits'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.postit is not None:
                                for child_ref in self.postit:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits']['meta_info']


                    class GlobalProcessInfo(object):
                        """
                        The Global Process information table
                        
                        .. attribute:: global_
                        
                        	Global information
                        	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Global_>`
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Vrf>`
                        
                        .. attribute:: vrf_name
                        
                        	Name of the VRF
                        	**type**\:  str
                        
                        .. attribute:: vrfid
                        
                        	VRF ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.global_ = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Global_()
                            self.global_.parent = self
                            self.vrf = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Vrf()
                            self.vrf.parent = self
                            self.vrf_name = None
                            self.vrfid = None


                        class Global_(object):
                            """
                            Global information
                            
                            .. attribute:: asn_format
                            
                            	BGP AS Number Format
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bmp_current_buffer_size
                            
                            	Current value for BMP buffer 
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bmp_default_buffer_size
                            
                            	Default value for BMP buffer limit when a value is not configured
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bmp_maximum_buffer_size
                            
                            	Maximum limit user can configure for max\-buffer\-size command under bmp\-server
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: cluster_id
                            
                            	Cluster ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: cluster_id_entry
                            
                            	All configured Cluster IDs
                            	**type**\: list of    :py:class:`ClusterIdEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Global_.ClusterIdEntry>`
                            
                            .. attribute:: confederation_id
                            
                            	Confederation ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: configured_cluster_id
                            
                            	Configured cluster ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: generic_scan_period
                            
                            	Period (in seconds) of generic scanner runs
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: graceful_maint_all_nbrs
                            
                            	Graceful Maintenance also for neighbors without GM configuration
                            	**type**\:  bool
                            
                            .. attribute:: graceful_maint_retain_routes
                            
                            	Retaining routes in RIB when BGP process stops while in Graceful Maintenance
                            	**type**\:  bool
                            
                            .. attribute:: graceful_maintenance
                            
                            	Graceful Maintenance
                            	**type**\:  bool
                            
                            .. attribute:: in_standalone_mode
                            
                            	Standalone or Distributed mode
                            	**type**\:  bool
                            
                            .. attribute:: instance_name
                            
                            	Name of BGP instance
                            	**type**\:  str
                            
                            .. attribute:: is_cluster_id_specified_as_ip
                            
                            	Cluster ID specified as an IP address
                            	**type**\:  bool
                            
                            .. attribute:: local_as
                            
                            	Local autonomous system number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: process_rlimit
                            
                            	Platform RLIMIT max for the process
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: restart_count
                            
                            	No of times BGP has started
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: srgb_end
                            
                            	In use Segment\-routing Global Block end value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: srgb_end_configured
                            
                            	Configured segment\-routing Global Block end value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: srgb_start
                            
                            	In use segment\-routing Global Block start value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: srgb_start_configured
                            
                            	Configured segment\-routing Global Block start value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_delay
                            
                            	Update delay timeout time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.asn_format = None
                                self.bmp_current_buffer_size = None
                                self.bmp_default_buffer_size = None
                                self.bmp_maximum_buffer_size = None
                                self.cluster_id = None
                                self.cluster_id_entry = YList()
                                self.cluster_id_entry.parent = self
                                self.cluster_id_entry.name = 'cluster_id_entry'
                                self.confederation_id = None
                                self.configured_cluster_id = None
                                self.generic_scan_period = None
                                self.graceful_maint_all_nbrs = None
                                self.graceful_maint_retain_routes = None
                                self.graceful_maintenance = None
                                self.in_standalone_mode = None
                                self.instance_name = None
                                self.is_cluster_id_specified_as_ip = None
                                self.local_as = None
                                self.process_rlimit = None
                                self.restart_count = None
                                self.srgb_end = None
                                self.srgb_end_configured = None
                                self.srgb_start = None
                                self.srgb_start_configured = None
                                self.update_delay = None


                            class ClusterIdEntry(object):
                                """
                                All configured Cluster IDs
                                
                                .. attribute:: cluster_id_type
                                
                                	Cluster ID type\: number or IPv4 address
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: cluster_id_val
                                
                                	Cluster ID 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.cluster_id_type = None
                                    self.cluster_id_val = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster-id-entry'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.cluster_id_type is not None:
                                        return True

                                    if self.cluster_id_val is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Global_.ClusterIdEntry']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:global'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.asn_format is not None:
                                    return True

                                if self.bmp_current_buffer_size is not None:
                                    return True

                                if self.bmp_default_buffer_size is not None:
                                    return True

                                if self.bmp_maximum_buffer_size is not None:
                                    return True

                                if self.cluster_id is not None:
                                    return True

                                if self.cluster_id_entry is not None:
                                    for child_ref in self.cluster_id_entry:
                                        if child_ref._has_data():
                                            return True

                                if self.confederation_id is not None:
                                    return True

                                if self.configured_cluster_id is not None:
                                    return True

                                if self.generic_scan_period is not None:
                                    return True

                                if self.graceful_maint_all_nbrs is not None:
                                    return True

                                if self.graceful_maint_retain_routes is not None:
                                    return True

                                if self.graceful_maintenance is not None:
                                    return True

                                if self.in_standalone_mode is not None:
                                    return True

                                if self.instance_name is not None:
                                    return True

                                if self.is_cluster_id_specified_as_ip is not None:
                                    return True

                                if self.local_as is not None:
                                    return True

                                if self.process_rlimit is not None:
                                    return True

                                if self.restart_count is not None:
                                    return True

                                if self.srgb_end is not None:
                                    return True

                                if self.srgb_end_configured is not None:
                                    return True

                                if self.srgb_start is not None:
                                    return True

                                if self.srgb_start_configured is not None:
                                    return True

                                if self.update_delay is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Global_']['meta_info']


                        class Vrf(object):
                            """
                            VRF information
                            
                            .. attribute:: configured_router_id
                            
                            	Configured router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: default_local_preference
                            
                            	Default local preference
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: default_metric
                            
                            	Default metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: hold_time
                            
                            	Default hold timer (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: is_bestpath_aigp_ignore_enabled
                            
                            	Bestpath\: Ignore AIGP unless both paths have AIGP attribute
                            	**type**\:  bool
                            
                            .. attribute:: is_bestpath_always_compare_med_enabled
                            
                            	Bestpath\: Always compare MED
                            	**type**\:  bool
                            
                            .. attribute:: is_bestpath_as_path_mpath_relax_enabled
                            
                            	Bestpath\: Relax AS path for mpath
                            	**type**\:  bool
                            
                            .. attribute:: is_bestpath_compare_med_from_confed_peer_enabled
                            
                            	Bestpath\: Compare MED from confed peer
                            	**type**\:  bool
                            
                            .. attribute:: is_bestpath_compare_router_id_for_ebgp_peers_enabled
                            
                            	Bestpath\: Compare routerID for eBGP peers
                            	**type**\:  bool
                            
                            .. attribute:: is_bestpath_ignore_as_path_enabled
                            
                            	Bestpath\: Ignore AS path
                            	**type**\:  bool
                            
                            .. attribute:: is_bestpath_missing_med_is_worst_enabled
                            
                            	Bestpath\: Treat missing MED as worst
                            	**type**\:  bool
                            
                            .. attribute:: is_default_metric_configured
                            
                            	Default metric configured
                            	**type**\:  bool
                            
                            .. attribute:: is_default_originate_configured
                            
                            	Default route originate configured
                            	**type**\:  bool
                            
                            .. attribute:: is_enforce_first_as_enabled
                            
                            	Enforce first AS
                            	**type**\:  bool
                            
                            .. attribute:: is_fast_external_fallover_enabled
                            
                            	Fast external fallover enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_graceful_restart
                            
                            	Graceful restart enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_multipath_as_path_ignore_onwards_enabled
                            
                            	Multipath\: Ignore everything AS path onwards for mpath
                            	**type**\:  bool
                            
                            .. attribute:: is_neighbor_logging
                            
                            	Neighbor logging enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_nsr
                            
                            	Non\-stop routing enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_redistribute_ibgp_to_ig_ps_enabled
                            
                            	Redistribute iBGP into IGPs enabled
                            	**type**\:  bool
                            
                            .. attribute:: keep_alive_time
                            
                            	Default keepalive timer (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: min_acceptable_hold_time
                            
                            	Default min acceptable hold time from neighbor(seconds)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: restart_time
                            
                            	Restart time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: rib_purge_timeout
                            
                            	RIB purge timeout time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: route_distinguisher
                            
                            	Route Distinguisher
                            	**type**\:  str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: router_id
                            
                            	Router ID for the VRF
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: stale_path_time
                            
                            	Stale path timeout time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: vrf_is_active
                            
                            	VRF state
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.configured_router_id = None
                                self.default_local_preference = None
                                self.default_metric = None
                                self.hold_time = None
                                self.is_bestpath_aigp_ignore_enabled = None
                                self.is_bestpath_always_compare_med_enabled = None
                                self.is_bestpath_as_path_mpath_relax_enabled = None
                                self.is_bestpath_compare_med_from_confed_peer_enabled = None
                                self.is_bestpath_compare_router_id_for_ebgp_peers_enabled = None
                                self.is_bestpath_ignore_as_path_enabled = None
                                self.is_bestpath_missing_med_is_worst_enabled = None
                                self.is_default_metric_configured = None
                                self.is_default_originate_configured = None
                                self.is_enforce_first_as_enabled = None
                                self.is_fast_external_fallover_enabled = None
                                self.is_graceful_restart = None
                                self.is_multipath_as_path_ignore_onwards_enabled = None
                                self.is_neighbor_logging = None
                                self.is_nsr = None
                                self.is_redistribute_ibgp_to_ig_ps_enabled = None
                                self.keep_alive_time = None
                                self.min_acceptable_hold_time = None
                                self.restart_time = None
                                self.rib_purge_timeout = None
                                self.route_distinguisher = None
                                self.router_id = None
                                self.stale_path_time = None
                                self.vrf_is_active = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:vrf'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.configured_router_id is not None:
                                    return True

                                if self.default_local_preference is not None:
                                    return True

                                if self.default_metric is not None:
                                    return True

                                if self.hold_time is not None:
                                    return True

                                if self.is_bestpath_aigp_ignore_enabled is not None:
                                    return True

                                if self.is_bestpath_always_compare_med_enabled is not None:
                                    return True

                                if self.is_bestpath_as_path_mpath_relax_enabled is not None:
                                    return True

                                if self.is_bestpath_compare_med_from_confed_peer_enabled is not None:
                                    return True

                                if self.is_bestpath_compare_router_id_for_ebgp_peers_enabled is not None:
                                    return True

                                if self.is_bestpath_ignore_as_path_enabled is not None:
                                    return True

                                if self.is_bestpath_missing_med_is_worst_enabled is not None:
                                    return True

                                if self.is_default_metric_configured is not None:
                                    return True

                                if self.is_default_originate_configured is not None:
                                    return True

                                if self.is_enforce_first_as_enabled is not None:
                                    return True

                                if self.is_fast_external_fallover_enabled is not None:
                                    return True

                                if self.is_graceful_restart is not None:
                                    return True

                                if self.is_multipath_as_path_ignore_onwards_enabled is not None:
                                    return True

                                if self.is_neighbor_logging is not None:
                                    return True

                                if self.is_nsr is not None:
                                    return True

                                if self.is_redistribute_ibgp_to_ig_ps_enabled is not None:
                                    return True

                                if self.keep_alive_time is not None:
                                    return True

                                if self.min_acceptable_hold_time is not None:
                                    return True

                                if self.restart_time is not None:
                                    return True

                                if self.rib_purge_timeout is not None:
                                    return True

                                if self.route_distinguisher is not None:
                                    return True

                                if self.router_id is not None:
                                    return True

                                if self.stale_path_time is not None:
                                    return True

                                if self.vrf_is_active is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Vrf']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:global-process-info'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.global_ is not None and self.global_._has_data():
                                return True

                            if self.vrf is not None and self.vrf._has_data():
                                return True

                            if self.vrf_name is not None:
                                return True

                            if self.vrfid is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo']['meta_info']


                    class UpdateInboundErrorNeighbors(object):
                        """
                        Update inbound error information for all
                        neighbors
                        
                        .. attribute:: update_inbound_error_neighbor
                        
                        	Update inbound error information for neighbor
                        	**type**\: list of    :py:class:`UpdateInboundErrorNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.update_inbound_error_neighbor = YList()
                            self.update_inbound_error_neighbor.parent = self
                            self.update_inbound_error_neighbor.name = 'update_inbound_error_neighbor'


                        class UpdateInboundErrorNeighbor(object):
                            """
                            Update inbound error information for neighbor
                            
                            .. attribute:: neighbor_address  <key>
                            
                            	Neighbor address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: establishment_action_count
                            
                            	Number of occurence of each action type since  session establishment
                            	**type**\: list of    :py:class:`EstablishmentActionCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount>`
                            
                            .. attribute:: establishment_total_update_message_count
                            
                            	Total update messages count since session establishment
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: first_update_error_handling_reset_timestamp
                            
                            	First error\-handling reset time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`FirstUpdateErrorHandlingResetTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp>`
                            
                            .. attribute:: first_update_malformed_timestamp
                            
                            	First malformed message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`FirstUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp>`
                            
                            .. attribute:: first_update_memory_allocation_fail_timestamp
                            
                            	First memory allocation failure time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`FirstUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp>`
                            
                            .. attribute:: last_error_handling_reset_age
                            
                            	Time since last error\-handling reset event (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_error_handling_reset_timestamp
                            
                            	Last error\-handling reset time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`LastErrorHandlingResetTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp>`
                            
                            .. attribute:: last_update_malformed_age
                            
                            	Time since last malformed message received event (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_update_malformed_timestamp
                            
                            	Last malformed message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`LastUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp>`
                            
                            .. attribute:: last_update_memory_allocation_fail_age
                            
                            	Time since last memory allocation failure event (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_update_memory_allocation_fail_timestamp
                            
                            	Last memory allocation failure time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp>`
                            
                            .. attribute:: total_update_message_count
                            
                            	Total update messages count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_attribute_discard_count
                            
                            	Discarded attribute count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_error_handling_avoid_reset
                            
                            	Configure error\-handling to avoid resets
                            	**type**\:  bool
                            
                            .. attribute:: update_error_handling_reset_count
                            
                            	Error\-handling reset count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_error_message
                            
                            	List of malformed messages
                            	**type**\: list of    :py:class:`UpdateErrorMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage>`
                            
                            .. attribute:: update_error_message_list_count
                            
                            	Malformed messages list count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_malformed_message_count
                            
                            	Malformed messages count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_memory_allocation_fail_count
                            
                            	Memory allocation failure count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_neighbor_address
                            
                            	Neighbor address
                            	**type**\:   :py:class:`UpdateNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress>`
                            
                            .. attribute:: update_vrf_name
                            
                            	VRF Name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.neighbor_address = None
                                self.establishment_action_count = YList()
                                self.establishment_action_count.parent = self
                                self.establishment_action_count.name = 'establishment_action_count'
                                self.establishment_total_update_message_count = None
                                self.first_update_error_handling_reset_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp()
                                self.first_update_error_handling_reset_timestamp.parent = self
                                self.first_update_malformed_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp()
                                self.first_update_malformed_timestamp.parent = self
                                self.first_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp()
                                self.first_update_memory_allocation_fail_timestamp.parent = self
                                self.last_error_handling_reset_age = None
                                self.last_error_handling_reset_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp()
                                self.last_error_handling_reset_timestamp.parent = self
                                self.last_update_malformed_age = None
                                self.last_update_malformed_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp()
                                self.last_update_malformed_timestamp.parent = self
                                self.last_update_memory_allocation_fail_age = None
                                self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp()
                                self.last_update_memory_allocation_fail_timestamp.parent = self
                                self.total_update_message_count = None
                                self.update_attribute_discard_count = None
                                self.update_error_handling_avoid_reset = None
                                self.update_error_handling_reset_count = None
                                self.update_error_message = YList()
                                self.update_error_message.parent = self
                                self.update_error_message.name = 'update_error_message'
                                self.update_error_message_list_count = None
                                self.update_malformed_message_count = None
                                self.update_memory_allocation_fail_count = None
                                self.update_neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress()
                                self.update_neighbor_address.parent = self
                                self.update_vrf_name = None


                            class UpdateNeighborAddress(object):
                                """
                                Neighbor address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpnvpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnvplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4mdt_address = None
                                    self.ipv4mvpn_address = None
                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress()
                                    self.ipv4sr_policy_address.parent = self
                                    self.ipv4vpn_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress()
                                    self.ipv6sr_policy_address.parent = self
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_flowspec_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.l2vpn_evpn_address = None
                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnvplsAddress()
                                    self.l2vpnvpls_address.parent = self
                                    self.ls_ls_address = None
                                    self.rt_constraint_address = None


                                class L2VpnvplsAddress(object):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnvplsAddress']['meta_info']


                                class L2VpnMspwAddress(object):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2VpnMspwAddress']['meta_info']


                                class Ipv4SrPolicyAddress(object):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                class Ipv6SrPolicyAddress(object):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv6_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv6_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-neighbor-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.afi is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv4_flowspec_address is not None:
                                        return True

                                    if self.ipv4_label_address is not None:
                                        return True

                                    if self.ipv4_mcast_address is not None:
                                        return True

                                    if self.ipv4_tunnel_address is not None:
                                        return True

                                    if self.ipv4mdt_address is not None:
                                        return True

                                    if self.ipv4mvpn_address is not None:
                                        return True

                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                        return True

                                    if self.ipv4vpn_address is not None:
                                        return True

                                    if self.ipv4vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv4vpna_mcastddress is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    if self.ipv6_flowspec_address is not None:
                                        return True

                                    if self.ipv6_label_address is not None:
                                        return True

                                    if self.ipv6_mcast_address is not None:
                                        return True

                                    if self.ipv6mvpn_address is not None:
                                        return True

                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                        return True

                                    if self.ipv6vpn_address is not None:
                                        return True

                                    if self.ipv6vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv6vpn_mcast_address is not None:
                                        return True

                                    if self.l2vpn_evpn_address is not None:
                                        return True

                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                        return True

                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                        return True

                                    if self.ls_ls_address is not None:
                                        return True

                                    if self.rt_constraint_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress']['meta_info']


                            class FirstUpdateMalformedTimestamp(object):
                                """
                                First malformed message received time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.nanoseconds = None
                                    self.seconds = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-update-malformed-timestamp'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.nanoseconds is not None:
                                        return True

                                    if self.seconds is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp']['meta_info']


                            class LastUpdateMalformedTimestamp(object):
                                """
                                Last malformed message received time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.nanoseconds = None
                                    self.seconds = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-malformed-timestamp'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.nanoseconds is not None:
                                        return True

                                    if self.seconds is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp']['meta_info']


                            class FirstUpdateMemoryAllocationFailTimestamp(object):
                                """
                                First memory allocation failure time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.nanoseconds = None
                                    self.seconds = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-update-memory-allocation-fail-timestamp'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.nanoseconds is not None:
                                        return True

                                    if self.seconds is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp']['meta_info']


                            class LastUpdateMemoryAllocationFailTimestamp(object):
                                """
                                Last memory allocation failure time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.nanoseconds = None
                                    self.seconds = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-memory-allocation-fail-timestamp'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.nanoseconds is not None:
                                        return True

                                    if self.seconds is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp']['meta_info']


                            class FirstUpdateErrorHandlingResetTimestamp(object):
                                """
                                First error\-handling reset time\: time elapsed
                                since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.nanoseconds = None
                                    self.seconds = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-update-error-handling-reset-timestamp'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.nanoseconds is not None:
                                        return True

                                    if self.seconds is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp']['meta_info']


                            class LastErrorHandlingResetTimestamp(object):
                                """
                                Last error\-handling reset time\: time elapsed
                                since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.nanoseconds = None
                                    self.seconds = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-error-handling-reset-timestamp'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.nanoseconds is not None:
                                        return True

                                    if self.seconds is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp']['meta_info']


                            class EstablishmentActionCount(object):
                                """
                                Number of occurence of each action type since
                                
                                session establishment
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.entry = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:establishment-action-count'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.entry is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount']['meta_info']


                            class UpdateErrorMessage(object):
                                """
                                List of malformed messages
                                
                                .. attribute:: update_attribute_discard_count
                                
                                	Discarded attribute count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_error_element
                                
                                	Error element list
                                	**type**\: list of    :py:class:`UpdateErrorElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement>`
                                
                                .. attribute:: update_error_final_action
                                
                                	Error final action
                                	**type**\:   :py:class:`BgpBagUpdErrActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdErrActionEnum>`
                                
                                .. attribute:: update_error_nlri_address_family
                                
                                	NLRI address\-family
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: update_error_nlri_string
                                
                                	List of NLRIs in string format
                                	**type**\:  str
                                
                                .. attribute:: update_error_nlri_string_truncated
                                
                                	Indicates whether NLRI string was truncated due to lack of space
                                	**type**\:  bool
                                
                                .. attribute:: update_message_data
                                
                                	Raw Message data in binary format
                                	**type**\: list of    :py:class:`UpdateMessageData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData>`
                                
                                .. attribute:: update_message_reset_data
                                
                                	Reset data
                                	**type**\:   :py:class:`UpdateMessageResetData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData>`
                                
                                .. attribute:: update_message_timestamp
                                
                                	Message timestamp\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`UpdateMessageTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.update_attribute_discard_count = None
                                    self.update_error_element = YList()
                                    self.update_error_element.parent = self
                                    self.update_error_element.name = 'update_error_element'
                                    self.update_error_final_action = None
                                    self.update_error_nlri_address_family = None
                                    self.update_error_nlri_string = None
                                    self.update_error_nlri_string_truncated = None
                                    self.update_message_data = YList()
                                    self.update_message_data.parent = self
                                    self.update_message_data.name = 'update_message_data'
                                    self.update_message_reset_data = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData()
                                    self.update_message_reset_data.parent = self
                                    self.update_message_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp()
                                    self.update_message_timestamp.parent = self


                                class UpdateMessageTimestamp(object):
                                    """
                                    Message timestamp\: time elapsed since 00\:00\:00
                                    UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-message-timestamp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp']['meta_info']


                                class UpdateMessageResetData(object):
                                    """
                                    Reset data
                                    
                                    .. attribute:: update_error_reset_notification_code
                                    
                                    	Notification code
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_error_reset_notification_data
                                    
                                    	Notification data
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: update_error_reset_notification_data_length
                                    
                                    	Notification data length
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: update_error_reset_notification_sub_code
                                    
                                    	Notification sub code
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: update_error_reset_reason
                                    
                                    	Reset Reason
                                    	**type**\:   :py:class:`BgpResetReasonIndexEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndexEnum>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.update_error_reset_notification_code = None
                                        self.update_error_reset_notification_data = None
                                        self.update_error_reset_notification_data_length = None
                                        self.update_error_reset_notification_sub_code = None
                                        self.update_error_reset_reason = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-message-reset-data'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.update_error_reset_notification_code is not None:
                                            return True

                                        if self.update_error_reset_notification_data is not None:
                                            return True

                                        if self.update_error_reset_notification_data_length is not None:
                                            return True

                                        if self.update_error_reset_notification_sub_code is not None:
                                            return True

                                        if self.update_error_reset_reason is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData']['meta_info']


                                class UpdateMessageData(object):
                                    """
                                    Raw Message data in binary format
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-message-data'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData']['meta_info']


                                class UpdateErrorElement(object):
                                    """
                                    Error element list
                                    
                                    .. attribute:: update_attribute_code
                                    
                                    	Attribute code [RFC4271\: BGP4]
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_attribute_flags
                                    
                                    	Attribute Flags [RFC4271\: BGP4]
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_attribute_length
                                    
                                    	Attribute Length [RFC4271\: BGP4]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: update_error_action
                                    
                                    	Error action
                                    	**type**\:   :py:class:`BgpBagUpdErrActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdErrActionEnum>`
                                    
                                    .. attribute:: update_error_data
                                    
                                    	Error data
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: update_error_data_length
                                    
                                    	Error data length
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.update_attribute_code = None
                                        self.update_attribute_flags = None
                                        self.update_attribute_length = None
                                        self.update_error_action = None
                                        self.update_error_data = None
                                        self.update_error_data_length = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-error-element'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.update_attribute_code is not None:
                                            return True

                                        if self.update_attribute_flags is not None:
                                            return True

                                        if self.update_attribute_length is not None:
                                            return True

                                        if self.update_error_action is not None:
                                            return True

                                        if self.update_error_data is not None:
                                            return True

                                        if self.update_error_data_length is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-error-message'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.update_attribute_discard_count is not None:
                                        return True

                                    if self.update_error_element is not None:
                                        for child_ref in self.update_error_element:
                                            if child_ref._has_data():
                                                return True

                                    if self.update_error_final_action is not None:
                                        return True

                                    if self.update_error_nlri_address_family is not None:
                                        return True

                                    if self.update_error_nlri_string is not None:
                                        return True

                                    if self.update_error_nlri_string_truncated is not None:
                                        return True

                                    if self.update_message_data is not None:
                                        for child_ref in self.update_message_data:
                                            if child_ref._has_data():
                                                return True

                                    if self.update_message_reset_data is not None and self.update_message_reset_data._has_data():
                                        return True

                                    if self.update_message_timestamp is not None and self.update_message_timestamp._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.neighbor_address is None:
                                    raise YPYModelError('Key property neighbor_address is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-inbound-error-neighbor[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address = ' + str(self.neighbor_address) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.neighbor_address is not None:
                                    return True

                                if self.establishment_action_count is not None:
                                    for child_ref in self.establishment_action_count:
                                        if child_ref._has_data():
                                            return True

                                if self.establishment_total_update_message_count is not None:
                                    return True

                                if self.first_update_error_handling_reset_timestamp is not None and self.first_update_error_handling_reset_timestamp._has_data():
                                    return True

                                if self.first_update_malformed_timestamp is not None and self.first_update_malformed_timestamp._has_data():
                                    return True

                                if self.first_update_memory_allocation_fail_timestamp is not None and self.first_update_memory_allocation_fail_timestamp._has_data():
                                    return True

                                if self.last_error_handling_reset_age is not None:
                                    return True

                                if self.last_error_handling_reset_timestamp is not None and self.last_error_handling_reset_timestamp._has_data():
                                    return True

                                if self.last_update_malformed_age is not None:
                                    return True

                                if self.last_update_malformed_timestamp is not None and self.last_update_malformed_timestamp._has_data():
                                    return True

                                if self.last_update_memory_allocation_fail_age is not None:
                                    return True

                                if self.last_update_memory_allocation_fail_timestamp is not None and self.last_update_memory_allocation_fail_timestamp._has_data():
                                    return True

                                if self.total_update_message_count is not None:
                                    return True

                                if self.update_attribute_discard_count is not None:
                                    return True

                                if self.update_error_handling_avoid_reset is not None:
                                    return True

                                if self.update_error_handling_reset_count is not None:
                                    return True

                                if self.update_error_message is not None:
                                    for child_ref in self.update_error_message:
                                        if child_ref._has_data():
                                            return True

                                if self.update_error_message_list_count is not None:
                                    return True

                                if self.update_malformed_message_count is not None:
                                    return True

                                if self.update_memory_allocation_fail_count is not None:
                                    return True

                                if self.update_neighbor_address is not None and self.update_neighbor_address._has_data():
                                    return True

                                if self.update_vrf_name is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-inbound-error-neighbors'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.update_inbound_error_neighbor is not None:
                                for child_ref in self.update_inbound_error_neighbor:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors']['meta_info']


                    class UpdateInboundFilterNeighbors(object):
                        """
                        Update inbound filtering information for all
                        neighbors
                        
                        .. attribute:: update_inbound_filter_neighbor
                        
                        	Update inbound filtering information for neighbor
                        	**type**\: list of    :py:class:`UpdateInboundFilterNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.update_inbound_filter_neighbor = YList()
                            self.update_inbound_filter_neighbor.parent = self
                            self.update_inbound_filter_neighbor.name = 'update_inbound_filter_neighbor'


                        class UpdateInboundFilterNeighbor(object):
                            """
                            Update inbound filtering information for
                            neighbor
                            
                            .. attribute:: neighbor_address  <key>
                            
                            	Neighbor address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: configured_update_filter_message_buffer_count
                            
                            	Configured Filtered message buffer count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: establishment_total_filter_update_message_count
                            
                            	Total update messages count since session establishment
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: establishment_update_filtered_message_count
                            
                            	Filtered messages count since session establishment
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: first_update_filtered_timestamp
                            
                            	First filtered message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`FirstUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp>`
                            
                            .. attribute:: last_update_filtered_age
                            
                            	Time since last filtered message received event (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_update_filtered_timestamp
                            
                            	Last filtered message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:   :py:class:`LastUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp>`
                            
                            .. attribute:: message_update_attribute_filtering_enabled
                            
                            	Attribute filtering is enabled for the current message being parsed
                            	**type**\:  bool
                            
                            .. attribute:: operational_update_attribute_filtering_enabled
                            
                            	Attribute filtering is enabled
                            	**type**\:  bool
                            
                            .. attribute:: operational_update_filter_message_buffer_count
                            
                            	Operational Filtered messages buffer count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total_filter_update_message_count
                            
                            	Total update messages count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_attribute_filter_attributes
                            
                            	List of attributes that can be filtered
                            	**type**\: list of    :py:class:`UpdateAttributeFilterAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes>`
                            
                            .. attribute:: update_attribute_filter_group_name
                            
                            	Update attribute\-filter group name
                            	**type**\:  str
                            
                            .. attribute:: update_filter_logging_enabled
                            
                            	Logging is enabled
                            	**type**\:  bool
                            
                            .. attribute:: update_filter_message
                            
                            	List of filtered messages
                            	**type**\: list of    :py:class:`UpdateFilterMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage>`
                            
                            .. attribute:: update_filter_message_buffer_circular
                            
                            	Indicates if the message buffers are circular
                            	**type**\:  bool
                            
                            .. attribute:: update_filter_message_list_count
                            
                            	Filtered messages list count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_filtered_message_count
                            
                            	Filtered messages count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_neighbor_address
                            
                            	Neighbor address
                            	**type**\:   :py:class:`UpdateNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress>`
                            
                            .. attribute:: update_vrf_name
                            
                            	VRF Name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.neighbor_address = None
                                self.configured_update_filter_message_buffer_count = None
                                self.establishment_total_filter_update_message_count = None
                                self.establishment_update_filtered_message_count = None
                                self.first_update_filtered_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp()
                                self.first_update_filtered_timestamp.parent = self
                                self.last_update_filtered_age = None
                                self.last_update_filtered_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp()
                                self.last_update_filtered_timestamp.parent = self
                                self.message_update_attribute_filtering_enabled = None
                                self.operational_update_attribute_filtering_enabled = None
                                self.operational_update_filter_message_buffer_count = None
                                self.total_filter_update_message_count = None
                                self.update_attribute_filter_attributes = YList()
                                self.update_attribute_filter_attributes.parent = self
                                self.update_attribute_filter_attributes.name = 'update_attribute_filter_attributes'
                                self.update_attribute_filter_group_name = None
                                self.update_filter_logging_enabled = None
                                self.update_filter_message = YList()
                                self.update_filter_message.parent = self
                                self.update_filter_message.name = 'update_filter_message'
                                self.update_filter_message_buffer_circular = None
                                self.update_filter_message_list_count = None
                                self.update_filtered_message_count = None
                                self.update_neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress()
                                self.update_neighbor_address.parent = self
                                self.update_vrf_name = None


                            class UpdateNeighborAddress(object):
                                """
                                Neighbor address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpnvpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnvplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4mdt_address = None
                                    self.ipv4mvpn_address = None
                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress()
                                    self.ipv4sr_policy_address.parent = self
                                    self.ipv4vpn_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress()
                                    self.ipv6sr_policy_address.parent = self
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_flowspec_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.l2vpn_evpn_address = None
                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnvplsAddress()
                                    self.l2vpnvpls_address.parent = self
                                    self.ls_ls_address = None
                                    self.rt_constraint_address = None


                                class L2VpnvplsAddress(object):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnvplsAddress']['meta_info']


                                class L2VpnMspwAddress(object):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2VpnMspwAddress']['meta_info']


                                class Ipv4SrPolicyAddress(object):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                class Ipv6SrPolicyAddress(object):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv6_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv6_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-neighbor-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.afi is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv4_flowspec_address is not None:
                                        return True

                                    if self.ipv4_label_address is not None:
                                        return True

                                    if self.ipv4_mcast_address is not None:
                                        return True

                                    if self.ipv4_tunnel_address is not None:
                                        return True

                                    if self.ipv4mdt_address is not None:
                                        return True

                                    if self.ipv4mvpn_address is not None:
                                        return True

                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                        return True

                                    if self.ipv4vpn_address is not None:
                                        return True

                                    if self.ipv4vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv4vpna_mcastddress is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    if self.ipv6_flowspec_address is not None:
                                        return True

                                    if self.ipv6_label_address is not None:
                                        return True

                                    if self.ipv6_mcast_address is not None:
                                        return True

                                    if self.ipv6mvpn_address is not None:
                                        return True

                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                        return True

                                    if self.ipv6vpn_address is not None:
                                        return True

                                    if self.ipv6vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv6vpn_mcast_address is not None:
                                        return True

                                    if self.l2vpn_evpn_address is not None:
                                        return True

                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                        return True

                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                        return True

                                    if self.ls_ls_address is not None:
                                        return True

                                    if self.rt_constraint_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress']['meta_info']


                            class FirstUpdateFilteredTimestamp(object):
                                """
                                First filtered message received time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.nanoseconds = None
                                    self.seconds = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-update-filtered-timestamp'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.nanoseconds is not None:
                                        return True

                                    if self.seconds is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp']['meta_info']


                            class LastUpdateFilteredTimestamp(object):
                                """
                                Last filtered message received time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.nanoseconds = None
                                    self.seconds = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-filtered-timestamp'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.nanoseconds is not None:
                                        return True

                                    if self.seconds is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp']['meta_info']


                            class UpdateAttributeFilterAttributes(object):
                                """
                                List of attributes that can be filtered
                                
                                .. attribute:: establishment_update_filter_match_count
                                
                                	Filter match counter since last session establishment
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_update_filter_match_age
                                
                                	Time since this attribute was last filtered (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_update_filter_match_timestamp
                                
                                	Last attribute filtered time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`LastUpdateFilterMatchTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp>`
                                
                                .. attribute:: update_filter_action
                                
                                	Filtering action
                                	**type**\:   :py:class:`BgpBagUpdFilterActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterActionEnum>`
                                
                                .. attribute:: update_filter_match_count
                                
                                	Filter match counter
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_internal_attribute_code
                                
                                	Internal attribute code [RFC4271\: BGP4]
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.establishment_update_filter_match_count = None
                                    self.last_update_filter_match_age = None
                                    self.last_update_filter_match_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp()
                                    self.last_update_filter_match_timestamp.parent = self
                                    self.update_filter_action = None
                                    self.update_filter_match_count = None
                                    self.update_internal_attribute_code = None


                                class LastUpdateFilterMatchTimestamp(object):
                                    """
                                    Last attribute filtered time\: time elapsed since
                                    00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-filter-match-timestamp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-attribute-filter-attributes'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.establishment_update_filter_match_count is not None:
                                        return True

                                    if self.last_update_filter_match_age is not None:
                                        return True

                                    if self.last_update_filter_match_timestamp is not None and self.last_update_filter_match_timestamp._has_data():
                                        return True

                                    if self.update_filter_action is not None:
                                        return True

                                    if self.update_filter_match_count is not None:
                                        return True

                                    if self.update_internal_attribute_code is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes']['meta_info']


                            class UpdateFilterMessage(object):
                                """
                                List of filtered messages
                                
                                .. attribute:: update_filter_element
                                
                                	Filtering element list
                                	**type**\: list of    :py:class:`UpdateFilterElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement>`
                                
                                .. attribute:: update_filter_final_action
                                
                                	Filtering final action
                                	**type**\:   :py:class:`BgpBagUpdFilterActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterActionEnum>`
                                
                                .. attribute:: update_filter_message_data
                                
                                	Raw Message data in binary format
                                	**type**\: list of    :py:class:`UpdateFilterMessageData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData>`
                                
                                .. attribute:: update_filter_message_timestamp
                                
                                	Message timestamp\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`UpdateFilterMessageTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp>`
                                
                                .. attribute:: update_filter_nlri_address_family
                                
                                	NLRI address\-family
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: update_filter_nlri_string
                                
                                	List of NLRIs in string format
                                	**type**\:  str
                                
                                .. attribute:: update_filter_nlri_string_truncated
                                
                                	Indicates whether NLRI string was truncated due to lack of space
                                	**type**\:  bool
                                
                                .. attribute:: update_filtered_attribute_count
                                
                                	Filtered attributes count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.update_filter_element = YList()
                                    self.update_filter_element.parent = self
                                    self.update_filter_element.name = 'update_filter_element'
                                    self.update_filter_final_action = None
                                    self.update_filter_message_data = YList()
                                    self.update_filter_message_data.parent = self
                                    self.update_filter_message_data.name = 'update_filter_message_data'
                                    self.update_filter_message_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp()
                                    self.update_filter_message_timestamp.parent = self
                                    self.update_filter_nlri_address_family = None
                                    self.update_filter_nlri_string = None
                                    self.update_filter_nlri_string_truncated = None
                                    self.update_filtered_attribute_count = None


                                class UpdateFilterMessageTimestamp(object):
                                    """
                                    Message timestamp\: time elapsed since 00\:00\:00
                                    UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-filter-message-timestamp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp']['meta_info']


                                class UpdateFilterMessageData(object):
                                    """
                                    Raw Message data in binary format
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-filter-message-data'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData']['meta_info']


                                class UpdateFilterElement(object):
                                    """
                                    Filtering element list
                                    
                                    .. attribute:: update_attribute_code
                                    
                                    	Attribute code [RFC4271\: BGP4]
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_attribute_flags
                                    
                                    	Attribute Flags [RFC4271\: BGP4]
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_filter_action
                                    
                                    	Filtering action
                                    	**type**\:   :py:class:`BgpBagUpdFilterActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterActionEnum>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.update_attribute_code = None
                                        self.update_attribute_flags = None
                                        self.update_filter_action = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-filter-element'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.update_attribute_code is not None:
                                            return True

                                        if self.update_attribute_flags is not None:
                                            return True

                                        if self.update_filter_action is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-filter-message'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.update_filter_element is not None:
                                        for child_ref in self.update_filter_element:
                                            if child_ref._has_data():
                                                return True

                                    if self.update_filter_final_action is not None:
                                        return True

                                    if self.update_filter_message_data is not None:
                                        for child_ref in self.update_filter_message_data:
                                            if child_ref._has_data():
                                                return True

                                    if self.update_filter_message_timestamp is not None and self.update_filter_message_timestamp._has_data():
                                        return True

                                    if self.update_filter_nlri_address_family is not None:
                                        return True

                                    if self.update_filter_nlri_string is not None:
                                        return True

                                    if self.update_filter_nlri_string_truncated is not None:
                                        return True

                                    if self.update_filtered_attribute_count is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.neighbor_address is None:
                                    raise YPYModelError('Key property neighbor_address is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-inbound-filter-neighbor[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address = ' + str(self.neighbor_address) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.neighbor_address is not None:
                                    return True

                                if self.configured_update_filter_message_buffer_count is not None:
                                    return True

                                if self.establishment_total_filter_update_message_count is not None:
                                    return True

                                if self.establishment_update_filtered_message_count is not None:
                                    return True

                                if self.first_update_filtered_timestamp is not None and self.first_update_filtered_timestamp._has_data():
                                    return True

                                if self.last_update_filtered_age is not None:
                                    return True

                                if self.last_update_filtered_timestamp is not None and self.last_update_filtered_timestamp._has_data():
                                    return True

                                if self.message_update_attribute_filtering_enabled is not None:
                                    return True

                                if self.operational_update_attribute_filtering_enabled is not None:
                                    return True

                                if self.operational_update_filter_message_buffer_count is not None:
                                    return True

                                if self.total_filter_update_message_count is not None:
                                    return True

                                if self.update_attribute_filter_attributes is not None:
                                    for child_ref in self.update_attribute_filter_attributes:
                                        if child_ref._has_data():
                                            return True

                                if self.update_attribute_filter_group_name is not None:
                                    return True

                                if self.update_filter_logging_enabled is not None:
                                    return True

                                if self.update_filter_message is not None:
                                    for child_ref in self.update_filter_message:
                                        if child_ref._has_data():
                                            return True

                                if self.update_filter_message_buffer_circular is not None:
                                    return True

                                if self.update_filter_message_list_count is not None:
                                    return True

                                if self.update_filtered_message_count is not None:
                                    return True

                                if self.update_neighbor_address is not None and self.update_neighbor_address._has_data():
                                    return True

                                if self.update_vrf_name is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-inbound-filter-neighbors'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.update_inbound_filter_neighbor is not None:
                                for child_ref in self.update_inbound_filter_neighbor:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors']['meta_info']


                    class Bmp(object):
                        """
                        BMP related Operational Data
                        
                        .. attribute:: server_neighbors
                        
                        	Table of Neighbors for a BMP Server
                        	**type**\:   :py:class:`ServerNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors>`
                        
                        .. attribute:: server_summaries
                        
                        	Table of BMP Servers
                        	**type**\:   :py:class:`ServerSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.server_neighbors = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors()
                            self.server_neighbors.parent = self
                            self.server_summaries = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries()
                            self.server_summaries.parent = self


                        class ServerSummaries(object):
                            """
                            Table of BMP Servers
                            
                            .. attribute:: server_summary
                            
                            	Summary Information about BMP server
                            	**type**\: list of    :py:class:`ServerSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.server_summary = YList()
                                self.server_summary.parent = self
                                self.server_summary.name = 'server_summary'


                            class ServerSummary(object):
                                """
                                Summary Information about BMP server
                                
                                .. attribute:: server_id  <key>
                                
                                	BMP Server ID
                                	**type**\:  int
                                
                                	**range:** 1..8
                                
                                .. attribute:: bmp_bytes_written_tcp
                                
                                	Total bytes sent to TCP
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: bmp_init_msg_count
                                
                                	Number of Initiation Msgs sent by this BMP Server
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_messages_wdraw_discarded
                                
                                	Total bmpQ wdraw msgs discarded because of peer down
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_peer_msg_drop_count
                                
                                	Total number of messages dropped
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_peer_msg_pending_count
                                
                                	Total number of bmpQ msgs pending
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_peer_msg_pending_count_hwts
                                
                                	Total bmpQ msgs pending max time
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmp_peer_msg_pending_count_max
                                
                                	Total bmpQ msgs pending max
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_per_peer_msg_count
                                
                                	Total number of per peer messages sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_per_peer_msg_route_mon_count
                                
                                	Total number of per peer route mon messages sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_pfx_wdraw_discarded
                                
                                	Total bmpQ wdraw pfxes discarded because of peer down
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_send_version
                                
                                	Table Version that this BMP server has caught  upto
                                	**type**\: list of    :py:class:`BmpSendVersion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpSendVersion>`
                                
                                .. attribute:: bmp_server_host_name
                                
                                	BMP Server Hostname
                                	**type**\:  str
                                
                                .. attribute:: bmp_server_id
                                
                                	BMP Server ID
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: bmp_server_is_flapping
                                
                                	Connection to the BMP server Flapping
                                	**type**\:  bool
                                
                                .. attribute:: bmp_server_last_discon_time
                                
                                	Timespec of Last Disconnect event received from BMP server
                                	**type**\:   :py:class:`BmpServerLastDisconTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime>`
                                
                                .. attribute:: bmp_server_nbr_count
                                
                                	Neighbor count for the BMP Server
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_server_port
                                
                                	BMP Server Port Number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_server_state
                                
                                	Connection state of the BMP server
                                	**type**\:   :py:class:`BgpBmpStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBmpStateEnum>`
                                
                                .. attribute:: bmp_server_state_age
                                
                                	Age of current state of BMP Server
                                	**type**\:   :py:class:`BmpServerStateAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge>`
                                
                                .. attribute:: bmp_server_state_time_spec
                                
                                	Timespec of current state of BMP Server
                                	**type**\:   :py:class:`BmpServerStateTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec>`
                                
                                .. attribute:: bmp_status_report_count
                                
                                	Number of Status ReportMessages sent by this BMP Server
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_termination_msg_count
                                
                                	Number of Termination Messages sent by this BMP Server
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_update_mode
                                
                                	Update sending mode configured for this BMP server
                                	**type**\:   :py:class:`BgpBmpUpdModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBmpUpdModeEnum>`
                                
                                .. attribute:: bmp_vrf_id
                                
                                	VRF ID for the vrf name configured
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_vrf_name
                                
                                	VRF Name configured
                                	**type**\:  str
                                
                                .. attribute:: bmpq_last_all_write_pulse_sent_time
                                
                                	Last BMPQ write pulse Sent for all BMP servers 
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmpq_last_write_pulse_cb_time
                                
                                	Last BMPQ write pulse callback time
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmpq_last_write_pulse_sent_time
                                
                                	Last BMPQ write pulse Sent time
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmpr_mon_upd_messages
                                
                                	Total bmpQ update msgs 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmpr_mon_update_gen_time
                                
                                	Time spent in update generation(milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: bmpr_mon_wdraw_messages
                                
                                	Total bmpQ withdraw msgs 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_update_count
                                
                                	Number of path update sent 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_update_drop
                                
                                	Number of path update drop 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_withdraw_count
                                
                                	Number of path wdraw sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_withdraw_drop
                                
                                	Number of path wdraw drop 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tcp_keep_alive_interval
                                
                                	TCP Keep alive interval configured
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tcp_last_write_cb_time
                                
                                	Last TCP Write CB time
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: tcp_last_write_result
                                
                                	Last TCP Socket write status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tcp_last_write_time
                                
                                	Last TCP Write time
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: tcp_maximum_segment_size
                                
                                	TCP Maximum Segments size configured
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tcp_write_cb_pending
                                
                                	Are we waiting for TCP write callback ?
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tcp_write_time
                                
                                	Time spent processing sending msg to TCP(milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: tos_type
                                
                                	Precedence (0) or DSCP (1) type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_value
                                
                                	Precedence or DSCP value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: update_source_address
                                
                                	Address of Interface configured as Update Source
                                	**type**\:   :py:class:`UpdateSourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress>`
                                
                                .. attribute:: update_source_interface_name
                                
                                	Interface configured as Update Source
                                	**type**\:  str
                                
                                .. attribute:: update_source_vrf_id
                                
                                	VRF ID of interface configured as Update Source
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.server_id = None
                                    self.bmp_bytes_written_tcp = None
                                    self.bmp_init_msg_count = None
                                    self.bmp_messages_wdraw_discarded = None
                                    self.bmp_peer_msg_drop_count = None
                                    self.bmp_peer_msg_pending_count = None
                                    self.bmp_peer_msg_pending_count_hwts = None
                                    self.bmp_peer_msg_pending_count_max = None
                                    self.bmp_per_peer_msg_count = None
                                    self.bmp_per_peer_msg_route_mon_count = None
                                    self.bmp_pfx_wdraw_discarded = None
                                    self.bmp_send_version = YList()
                                    self.bmp_send_version.parent = self
                                    self.bmp_send_version.name = 'bmp_send_version'
                                    self.bmp_server_host_name = None
                                    self.bmp_server_id = None
                                    self.bmp_server_is_flapping = None
                                    self.bmp_server_last_discon_time = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime()
                                    self.bmp_server_last_discon_time.parent = self
                                    self.bmp_server_nbr_count = None
                                    self.bmp_server_port = None
                                    self.bmp_server_state = None
                                    self.bmp_server_state_age = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge()
                                    self.bmp_server_state_age.parent = self
                                    self.bmp_server_state_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec()
                                    self.bmp_server_state_time_spec.parent = self
                                    self.bmp_status_report_count = None
                                    self.bmp_termination_msg_count = None
                                    self.bmp_update_mode = None
                                    self.bmp_vrf_id = None
                                    self.bmp_vrf_name = None
                                    self.bmpq_last_all_write_pulse_sent_time = None
                                    self.bmpq_last_write_pulse_cb_time = None
                                    self.bmpq_last_write_pulse_sent_time = None
                                    self.bmpr_mon_upd_messages = None
                                    self.bmpr_mon_update_gen_time = None
                                    self.bmpr_mon_wdraw_messages = None
                                    self.path_update_count = None
                                    self.path_update_drop = None
                                    self.path_withdraw_count = None
                                    self.path_withdraw_drop = None
                                    self.tcp_keep_alive_interval = None
                                    self.tcp_last_write_cb_time = None
                                    self.tcp_last_write_result = None
                                    self.tcp_last_write_time = None
                                    self.tcp_maximum_segment_size = None
                                    self.tcp_write_cb_pending = None
                                    self.tcp_write_time = None
                                    self.tos_type = None
                                    self.tos_value = None
                                    self.update_source_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress()
                                    self.update_source_address.parent = self
                                    self.update_source_interface_name = None
                                    self.update_source_vrf_id = None


                                class BmpServerStateAge(object):
                                    """
                                    Age of current state of BMP Server
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-server-state-age'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge']['meta_info']


                                class BmpServerStateTimeSpec(object):
                                    """
                                    Timespec of current state of BMP Server
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-server-state-time-spec'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec']['meta_info']


                                class BmpServerLastDisconTime(object):
                                    """
                                    Timespec of Last Disconnect event received from
                                    BMP server
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-server-last-discon-time'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime']['meta_info']


                                class UpdateSourceAddress(object):
                                    """
                                    Address of Interface configured as Update Source
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpnvpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnvplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4mdt_address = None
                                        self.ipv4mvpn_address = None
                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress()
                                        self.ipv4sr_policy_address.parent = self
                                        self.ipv4vpn_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress()
                                        self.ipv6sr_policy_address.parent = self
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_flowspec_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.l2vpn_evpn_address = None
                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnvplsAddress()
                                        self.l2vpnvpls_address.parent = self
                                        self.ls_ls_address = None
                                        self.rt_constraint_address = None


                                    class L2VpnvplsAddress(object):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnvplsAddress']['meta_info']


                                    class L2VpnMspwAddress(object):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2VpnMspwAddress']['meta_info']


                                    class Ipv4SrPolicyAddress(object):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress']['meta_info']


                                    class Ipv6SrPolicyAddress(object):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv6_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv6_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-source-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.afi is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv4_flowspec_address is not None:
                                            return True

                                        if self.ipv4_label_address is not None:
                                            return True

                                        if self.ipv4_mcast_address is not None:
                                            return True

                                        if self.ipv4_tunnel_address is not None:
                                            return True

                                        if self.ipv4mdt_address is not None:
                                            return True

                                        if self.ipv4mvpn_address is not None:
                                            return True

                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                            return True

                                        if self.ipv4vpn_address is not None:
                                            return True

                                        if self.ipv4vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv4vpna_mcastddress is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        if self.ipv6_flowspec_address is not None:
                                            return True

                                        if self.ipv6_label_address is not None:
                                            return True

                                        if self.ipv6_mcast_address is not None:
                                            return True

                                        if self.ipv6mvpn_address is not None:
                                            return True

                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                            return True

                                        if self.ipv6vpn_address is not None:
                                            return True

                                        if self.ipv6vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv6vpn_mcast_address is not None:
                                            return True

                                        if self.l2vpn_evpn_address is not None:
                                            return True

                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                            return True

                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                            return True

                                        if self.ls_ls_address is not None:
                                            return True

                                        if self.rt_constraint_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress']['meta_info']


                                class BmpSendVersion(object):
                                    """
                                    Table Version that this BMP server has caught
                                    
                                    upto
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-send-version'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpSendVersion']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.server_id is None:
                                        raise YPYModelError('Key property server_id is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:server-summary[Cisco-IOS-XR-ipv4-bgp-oper:server-id = ' + str(self.server_id) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.server_id is not None:
                                        return True

                                    if self.bmp_bytes_written_tcp is not None:
                                        return True

                                    if self.bmp_init_msg_count is not None:
                                        return True

                                    if self.bmp_messages_wdraw_discarded is not None:
                                        return True

                                    if self.bmp_peer_msg_drop_count is not None:
                                        return True

                                    if self.bmp_peer_msg_pending_count is not None:
                                        return True

                                    if self.bmp_peer_msg_pending_count_hwts is not None:
                                        return True

                                    if self.bmp_peer_msg_pending_count_max is not None:
                                        return True

                                    if self.bmp_per_peer_msg_count is not None:
                                        return True

                                    if self.bmp_per_peer_msg_route_mon_count is not None:
                                        return True

                                    if self.bmp_pfx_wdraw_discarded is not None:
                                        return True

                                    if self.bmp_send_version is not None:
                                        for child_ref in self.bmp_send_version:
                                            if child_ref._has_data():
                                                return True

                                    if self.bmp_server_host_name is not None:
                                        return True

                                    if self.bmp_server_id is not None:
                                        return True

                                    if self.bmp_server_is_flapping is not None:
                                        return True

                                    if self.bmp_server_last_discon_time is not None and self.bmp_server_last_discon_time._has_data():
                                        return True

                                    if self.bmp_server_nbr_count is not None:
                                        return True

                                    if self.bmp_server_port is not None:
                                        return True

                                    if self.bmp_server_state is not None:
                                        return True

                                    if self.bmp_server_state_age is not None and self.bmp_server_state_age._has_data():
                                        return True

                                    if self.bmp_server_state_time_spec is not None and self.bmp_server_state_time_spec._has_data():
                                        return True

                                    if self.bmp_status_report_count is not None:
                                        return True

                                    if self.bmp_termination_msg_count is not None:
                                        return True

                                    if self.bmp_update_mode is not None:
                                        return True

                                    if self.bmp_vrf_id is not None:
                                        return True

                                    if self.bmp_vrf_name is not None:
                                        return True

                                    if self.bmpq_last_all_write_pulse_sent_time is not None:
                                        return True

                                    if self.bmpq_last_write_pulse_cb_time is not None:
                                        return True

                                    if self.bmpq_last_write_pulse_sent_time is not None:
                                        return True

                                    if self.bmpr_mon_upd_messages is not None:
                                        return True

                                    if self.bmpr_mon_update_gen_time is not None:
                                        return True

                                    if self.bmpr_mon_wdraw_messages is not None:
                                        return True

                                    if self.path_update_count is not None:
                                        return True

                                    if self.path_update_drop is not None:
                                        return True

                                    if self.path_withdraw_count is not None:
                                        return True

                                    if self.path_withdraw_drop is not None:
                                        return True

                                    if self.tcp_keep_alive_interval is not None:
                                        return True

                                    if self.tcp_last_write_cb_time is not None:
                                        return True

                                    if self.tcp_last_write_result is not None:
                                        return True

                                    if self.tcp_last_write_time is not None:
                                        return True

                                    if self.tcp_maximum_segment_size is not None:
                                        return True

                                    if self.tcp_write_cb_pending is not None:
                                        return True

                                    if self.tcp_write_time is not None:
                                        return True

                                    if self.tos_type is not None:
                                        return True

                                    if self.tos_value is not None:
                                        return True

                                    if self.update_source_address is not None and self.update_source_address._has_data():
                                        return True

                                    if self.update_source_interface_name is not None:
                                        return True

                                    if self.update_source_vrf_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:server-summaries'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.server_summary is not None:
                                    for child_ref in self.server_summary:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries']['meta_info']


                        class ServerNeighbors(object):
                            """
                            Table of Neighbors for a BMP Server
                            
                            .. attribute:: server_neighbor
                            
                            	BMP Server under which neighbor info are needed
                            	**type**\: list of    :py:class:`ServerNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.server_neighbor = YList()
                                self.server_neighbor.parent = self
                                self.server_neighbor.name = 'server_neighbor'


                            class ServerNeighbor(object):
                                """
                                BMP Server under which neighbor info are
                                needed
                                
                                .. attribute:: server_id  <key>
                                
                                	BMP Server ID
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: monitored_neighbors
                                
                                	List of Neighbors under which BMP Server is confgiured
                                	**type**\:   :py:class:`MonitoredNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.server_id = None
                                    self.monitored_neighbors = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors()
                                    self.monitored_neighbors.parent = self


                                class MonitoredNeighbors(object):
                                    """
                                    List of Neighbors under which BMP Server is
                                    confgiured
                                    
                                    .. attribute:: monitored_neighbor
                                    
                                    	Information about a neighbor monitored by BMP server
                                    	**type**\: list of    :py:class:`MonitoredNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.monitored_neighbor = YList()
                                        self.monitored_neighbor.parent = self
                                        self.monitored_neighbor.name = 'monitored_neighbor'


                                    class MonitoredNeighbor(object):
                                        """
                                        Information about a neighbor monitored by
                                        BMP server
                                        
                                        .. attribute:: neighbor_address  <key>
                                        
                                        	Neighbor address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: bmp_neighbor_address
                                        
                                        	Address of Nbr that logs to BMP server
                                        	**type**\:   :py:class:`BmpNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress>`
                                        
                                        .. attribute:: bmp_neighbor_msg_dropped
                                        
                                        	Number of messages dropped sent from this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_msg_pending
                                        
                                        	Number of messages pending to be sent to BMP Server from this Neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_path_update_drop
                                        
                                        	Number of path update drop 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_path_update_sent
                                        
                                        	Number of Path UpdateMessages sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_path_withdraw_drop
                                        
                                        	Number of path wdraw drop 
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_path_withdraw_sent
                                        
                                        	Number of Path WithdrawMessages sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_peer_down_sent
                                        
                                        	Number of Peer DOWN Messages sent from this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_peer_up_sent
                                        
                                        	Number of Peer UP Messages sent from this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_route_monitor_sent
                                        
                                        	Number of Route Monitor Messages sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_upd_msg_sent
                                        
                                        	Number of update message sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_wdraw_msg_sent
                                        
                                        	Number of withdraw message sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.neighbor_address = None
                                            self.bmp_neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress()
                                            self.bmp_neighbor_address.parent = self
                                            self.bmp_neighbor_msg_dropped = None
                                            self.bmp_neighbor_msg_pending = None
                                            self.bmp_neighbor_path_update_drop = None
                                            self.bmp_neighbor_path_update_sent = None
                                            self.bmp_neighbor_path_withdraw_drop = None
                                            self.bmp_neighbor_path_withdraw_sent = None
                                            self.bmp_neighbor_peer_down_sent = None
                                            self.bmp_neighbor_peer_up_sent = None
                                            self.bmp_neighbor_route_monitor_sent = None
                                            self.bmp_neighbor_upd_msg_sent = None
                                            self.bmp_neighbor_wdraw_msg_sent = None


                                        class BmpNeighborAddress(object):
                                            """
                                            Address of Nbr that logs to BMP server
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\:  str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: ipv4sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv6sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnMspwAddress>`
                                            
                                            .. attribute:: l2vpnvpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnvplsAddress>`
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4mdt_address = None
                                                self.ipv4mvpn_address = None
                                                self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4sr_policy_address.parent = self
                                                self.ipv4vpn_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6sr_policy_address.parent = self
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_flowspec_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.l2vpn_evpn_address = None
                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnvplsAddress()
                                                self.l2vpnvpls_address.parent = self
                                                self.ls_ls_address = None
                                                self.rt_constraint_address = None


                                            class L2VpnvplsAddress(object):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnvplsAddress']['meta_info']


                                            class L2VpnMspwAddress(object):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.l2vpn_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.l2vpn_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2VpnMspwAddress']['meta_info']


                                            class Ipv4SrPolicyAddress(object):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                            class Ipv6SrPolicyAddress(object):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv6_srpolicy_address = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv6_srpolicy_address is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-neighbor-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.afi is not None:
                                                    return True

                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.ipv4_flowspec_address is not None:
                                                    return True

                                                if self.ipv4_label_address is not None:
                                                    return True

                                                if self.ipv4_mcast_address is not None:
                                                    return True

                                                if self.ipv4_tunnel_address is not None:
                                                    return True

                                                if self.ipv4mdt_address is not None:
                                                    return True

                                                if self.ipv4mvpn_address is not None:
                                                    return True

                                                if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                    return True

                                                if self.ipv4vpn_address is not None:
                                                    return True

                                                if self.ipv4vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv4vpna_mcastddress is not None:
                                                    return True

                                                if self.ipv6_address is not None:
                                                    return True

                                                if self.ipv6_flowspec_address is not None:
                                                    return True

                                                if self.ipv6_label_address is not None:
                                                    return True

                                                if self.ipv6_mcast_address is not None:
                                                    return True

                                                if self.ipv6mvpn_address is not None:
                                                    return True

                                                if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                    return True

                                                if self.ipv6vpn_address is not None:
                                                    return True

                                                if self.ipv6vpn_flowspec_address is not None:
                                                    return True

                                                if self.ipv6vpn_mcast_address is not None:
                                                    return True

                                                if self.l2vpn_evpn_address is not None:
                                                    return True

                                                if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                    return True

                                                if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                    return True

                                                if self.ls_ls_address is not None:
                                                    return True

                                                if self.rt_constraint_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')
                                            if self.neighbor_address is None:
                                                raise YPYModelError('Key property neighbor_address is None')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:monitored-neighbor[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address = ' + str(self.neighbor_address) + ']'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.neighbor_address is not None:
                                                return True

                                            if self.bmp_neighbor_address is not None and self.bmp_neighbor_address._has_data():
                                                return True

                                            if self.bmp_neighbor_msg_dropped is not None:
                                                return True

                                            if self.bmp_neighbor_msg_pending is not None:
                                                return True

                                            if self.bmp_neighbor_path_update_drop is not None:
                                                return True

                                            if self.bmp_neighbor_path_update_sent is not None:
                                                return True

                                            if self.bmp_neighbor_path_withdraw_drop is not None:
                                                return True

                                            if self.bmp_neighbor_path_withdraw_sent is not None:
                                                return True

                                            if self.bmp_neighbor_peer_down_sent is not None:
                                                return True

                                            if self.bmp_neighbor_peer_up_sent is not None:
                                                return True

                                            if self.bmp_neighbor_route_monitor_sent is not None:
                                                return True

                                            if self.bmp_neighbor_upd_msg_sent is not None:
                                                return True

                                            if self.bmp_neighbor_wdraw_msg_sent is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:monitored-neighbors'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.monitored_neighbor is not None:
                                            for child_ref in self.monitored_neighbor:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.server_id is None:
                                        raise YPYModelError('Key property server_id is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:server-neighbor[Cisco-IOS-XR-ipv4-bgp-oper:server-id = ' + str(self.server_id) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.server_id is not None:
                                        return True

                                    if self.monitored_neighbors is not None and self.monitored_neighbors._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:server-neighbors'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.server_neighbor is not None:
                                    for child_ref in self.server_neighbor:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.server_neighbors is not None and self.server_neighbors._has_data():
                                return True

                            if self.server_summaries is not None and self.server_summaries._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp']['meta_info']


                    class ProcessInfo(object):
                        """
                        A Process instance table entry
                        
                        .. attribute:: global_
                        
                        	Global information
                        	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_>`
                        
                        .. attribute:: performance_statistics
                        
                        	Performance statistics
                        	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics>`
                        
                        .. attribute:: process_instance
                        
                        	ID for the BGP process instance
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Vrf>`
                        
                        .. attribute:: vrf_name
                        
                        	Name of the VRF
                        	**type**\:  str
                        
                        .. attribute:: vrf_totals
                        
                        	per VRF counts aggregated across all VRFs
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.global_ = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_()
                            self.global_.parent = self
                            self.performance_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics()
                            self.performance_statistics.parent = self
                            self.process_instance = None
                            self.vrf = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Vrf()
                            self.vrf.parent = self
                            self.vrf_name = None
                            self.vrf_totals = None


                        class Global_(object):
                            """
                            Global information
                            
                            .. attribute:: as_path_entries_memory
                            
                            	Memory (in bytes) used by AS\-path entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: as_path_entry_count
                            
                            	Number of AS\-path entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attr_set_entry_count
                            
                            	Number of ATTRSET entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attr_set_memory
                            
                            	Memory (in bytes) used by ATTRSET entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: bmp_pool_alloc_count
                            
                            	bmp pool alloc count
                            	**type**\: list of    :py:class:`BmpPoolAllocCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.BmpPoolAllocCount>`
                            
                            .. attribute:: bmp_pool_free_count
                            
                            	bmp pool free count
                            	**type**\: list of    :py:class:`BmpPoolFreeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.BmpPoolFreeCount>`
                            
                            .. attribute:: bmp_pool_size
                            
                            	bmp pool size
                            	**type**\: list of    :py:class:`BmpPoolSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.BmpPoolSize>`
                            
                            .. attribute:: community_entry_count
                            
                            	Number of community entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: community_memory
                            
                            	Memory (in bytes) used by community entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: established_neighbors_count_total
                            
                            	Total umber of established neighbors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: extended_community_entry_count
                            
                            	Number of extended community entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: extended_community_memory
                            
                            	Memory (in bytes) used by extended community entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: lindex_entry_count
                            
                            	Number of LINDEX entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lindex_memory
                            
                            	Memory (in bytes) used by LINDEX entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: local_as
                            
                            	Local autonomous system number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsattr_entry_count
                            
                            	Number of LASATTR entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsattr_memory
                            
                            	Memory (in bytes) used by LSATTR entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: msg_log_pool_alloc_count
                            
                            	msg log pool alloc count
                            	**type**\: list of    :py:class:`MsgLogPoolAllocCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.MsgLogPoolAllocCount>`
                            
                            .. attribute:: msg_log_pool_free_count
                            
                            	msg log pool free count
                            	**type**\: list of    :py:class:`MsgLogPoolFreeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.MsgLogPoolFreeCount>`
                            
                            .. attribute:: msg_log_pool_size
                            
                            	msg log pool size
                            	**type**\: list of    :py:class:`MsgLogPoolSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.MsgLogPoolSize>`
                            
                            .. attribute:: neighbors_count_total
                            
                            	Total number of neighbors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nexthop_count
                            
                            	Number of nexthop attribute info entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nexthop_memory
                            
                            	Memory (in bytes) used by nexthop attribute info entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: path_attribute_memory
                            
                            	Memory (bytes) used by path attribute entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: path_attributes_entry_count
                            
                            	No. of path attribute entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pe_distinguisher_label_entry_count
                            
                            	Number of PE distinguisher label entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pe_distinguisher_label_memory
                            
                            	Memory (in bytes) used by PE distinguisher labels entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: pool_alloc_count
                            
                            	pool alloc count
                            	**type**\: list of    :py:class:`PoolAllocCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.PoolAllocCount>`
                            
                            .. attribute:: pool_free_count
                            
                            	pool free count
                            	**type**\: list of    :py:class:`PoolFreeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.PoolFreeCount>`
                            
                            .. attribute:: pool_size
                            
                            	pool size
                            	**type**\: list of    :py:class:`PoolSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.PoolSize>`
                            
                            .. attribute:: ppmp_entry_count
                            
                            	Number of PPMP entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ppmp_memory
                            
                            	Memory (in bytes) used by PPMP entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: process_instance_node
                            
                            	Node the process instance is on
                            	**type**\:  str
                            
                            .. attribute:: pta_entry_count
                            
                            	Number of PTA entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pta_memory
                            
                            	Memory (in bytes) used by PTA entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: restart_count
                            
                            	No. of times BGP has started
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ribrnh_entry_count
                            
                            	Number of RIBRNH entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ribrnh_memory
                            
                            	Memory (in bytes) used by RIBRNH entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: route_reflector_memory
                            
                            	Memory (in bytes) used by route reflector info entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: route_reflectors
                            
                            	Number of route reflector info entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sn_num_non_dflt_vrf_nbrs
                            
                            	sn num non dflt vrf nbrs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sn_num_non_dflt_vrf_nbrs_estab
                            
                            	sn num non dflt vrf nbrs estab
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total_vrf_count
                            
                            	total vrf count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tunnel_encap_entry_count
                            
                            	Number of Tunnel encap entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tunnel_encap_memory
                            
                            	Memory (in bytes) used by tunnel encap entries
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.as_path_entries_memory = None
                                self.as_path_entry_count = None
                                self.attr_set_entry_count = None
                                self.attr_set_memory = None
                                self.bmp_pool_alloc_count = YList()
                                self.bmp_pool_alloc_count.parent = self
                                self.bmp_pool_alloc_count.name = 'bmp_pool_alloc_count'
                                self.bmp_pool_free_count = YList()
                                self.bmp_pool_free_count.parent = self
                                self.bmp_pool_free_count.name = 'bmp_pool_free_count'
                                self.bmp_pool_size = YList()
                                self.bmp_pool_size.parent = self
                                self.bmp_pool_size.name = 'bmp_pool_size'
                                self.community_entry_count = None
                                self.community_memory = None
                                self.established_neighbors_count_total = None
                                self.extended_community_entry_count = None
                                self.extended_community_memory = None
                                self.lindex_entry_count = None
                                self.lindex_memory = None
                                self.local_as = None
                                self.lsattr_entry_count = None
                                self.lsattr_memory = None
                                self.msg_log_pool_alloc_count = YList()
                                self.msg_log_pool_alloc_count.parent = self
                                self.msg_log_pool_alloc_count.name = 'msg_log_pool_alloc_count'
                                self.msg_log_pool_free_count = YList()
                                self.msg_log_pool_free_count.parent = self
                                self.msg_log_pool_free_count.name = 'msg_log_pool_free_count'
                                self.msg_log_pool_size = YList()
                                self.msg_log_pool_size.parent = self
                                self.msg_log_pool_size.name = 'msg_log_pool_size'
                                self.neighbors_count_total = None
                                self.nexthop_count = None
                                self.nexthop_memory = None
                                self.path_attribute_memory = None
                                self.path_attributes_entry_count = None
                                self.pe_distinguisher_label_entry_count = None
                                self.pe_distinguisher_label_memory = None
                                self.pool_alloc_count = YList()
                                self.pool_alloc_count.parent = self
                                self.pool_alloc_count.name = 'pool_alloc_count'
                                self.pool_free_count = YList()
                                self.pool_free_count.parent = self
                                self.pool_free_count.name = 'pool_free_count'
                                self.pool_size = YList()
                                self.pool_size.parent = self
                                self.pool_size.name = 'pool_size'
                                self.ppmp_entry_count = None
                                self.ppmp_memory = None
                                self.process_instance_node = None
                                self.pta_entry_count = None
                                self.pta_memory = None
                                self.restart_count = None
                                self.ribrnh_entry_count = None
                                self.ribrnh_memory = None
                                self.route_reflector_memory = None
                                self.route_reflectors = None
                                self.sn_num_non_dflt_vrf_nbrs = None
                                self.sn_num_non_dflt_vrf_nbrs_estab = None
                                self.total_vrf_count = None
                                self.tunnel_encap_entry_count = None
                                self.tunnel_encap_memory = None


                            class PoolSize(object):
                                """
                                pool size
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.entry = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pool-size'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.entry is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.PoolSize']['meta_info']


                            class PoolAllocCount(object):
                                """
                                pool alloc count
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.entry = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pool-alloc-count'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.entry is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.PoolAllocCount']['meta_info']


                            class PoolFreeCount(object):
                                """
                                pool free count
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.entry = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pool-free-count'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.entry is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.PoolFreeCount']['meta_info']


                            class MsgLogPoolSize(object):
                                """
                                msg log pool size
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.entry = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:msg-log-pool-size'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.entry is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.MsgLogPoolSize']['meta_info']


                            class MsgLogPoolAllocCount(object):
                                """
                                msg log pool alloc count
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.entry = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:msg-log-pool-alloc-count'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.entry is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.MsgLogPoolAllocCount']['meta_info']


                            class MsgLogPoolFreeCount(object):
                                """
                                msg log pool free count
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.entry = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:msg-log-pool-free-count'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.entry is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.MsgLogPoolFreeCount']['meta_info']


                            class BmpPoolSize(object):
                                """
                                bmp pool size
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.entry = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-pool-size'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.entry is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.BmpPoolSize']['meta_info']


                            class BmpPoolAllocCount(object):
                                """
                                bmp pool alloc count
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.entry = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-pool-alloc-count'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.entry is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.BmpPoolAllocCount']['meta_info']


                            class BmpPoolFreeCount(object):
                                """
                                bmp pool free count
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.entry = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:bmp-pool-free-count'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.entry is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_.BmpPoolFreeCount']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:global'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.as_path_entries_memory is not None:
                                    return True

                                if self.as_path_entry_count is not None:
                                    return True

                                if self.attr_set_entry_count is not None:
                                    return True

                                if self.attr_set_memory is not None:
                                    return True

                                if self.bmp_pool_alloc_count is not None:
                                    for child_ref in self.bmp_pool_alloc_count:
                                        if child_ref._has_data():
                                            return True

                                if self.bmp_pool_free_count is not None:
                                    for child_ref in self.bmp_pool_free_count:
                                        if child_ref._has_data():
                                            return True

                                if self.bmp_pool_size is not None:
                                    for child_ref in self.bmp_pool_size:
                                        if child_ref._has_data():
                                            return True

                                if self.community_entry_count is not None:
                                    return True

                                if self.community_memory is not None:
                                    return True

                                if self.established_neighbors_count_total is not None:
                                    return True

                                if self.extended_community_entry_count is not None:
                                    return True

                                if self.extended_community_memory is not None:
                                    return True

                                if self.lindex_entry_count is not None:
                                    return True

                                if self.lindex_memory is not None:
                                    return True

                                if self.local_as is not None:
                                    return True

                                if self.lsattr_entry_count is not None:
                                    return True

                                if self.lsattr_memory is not None:
                                    return True

                                if self.msg_log_pool_alloc_count is not None:
                                    for child_ref in self.msg_log_pool_alloc_count:
                                        if child_ref._has_data():
                                            return True

                                if self.msg_log_pool_free_count is not None:
                                    for child_ref in self.msg_log_pool_free_count:
                                        if child_ref._has_data():
                                            return True

                                if self.msg_log_pool_size is not None:
                                    for child_ref in self.msg_log_pool_size:
                                        if child_ref._has_data():
                                            return True

                                if self.neighbors_count_total is not None:
                                    return True

                                if self.nexthop_count is not None:
                                    return True

                                if self.nexthop_memory is not None:
                                    return True

                                if self.path_attribute_memory is not None:
                                    return True

                                if self.path_attributes_entry_count is not None:
                                    return True

                                if self.pe_distinguisher_label_entry_count is not None:
                                    return True

                                if self.pe_distinguisher_label_memory is not None:
                                    return True

                                if self.pool_alloc_count is not None:
                                    for child_ref in self.pool_alloc_count:
                                        if child_ref._has_data():
                                            return True

                                if self.pool_free_count is not None:
                                    for child_ref in self.pool_free_count:
                                        if child_ref._has_data():
                                            return True

                                if self.pool_size is not None:
                                    for child_ref in self.pool_size:
                                        if child_ref._has_data():
                                            return True

                                if self.ppmp_entry_count is not None:
                                    return True

                                if self.ppmp_memory is not None:
                                    return True

                                if self.process_instance_node is not None:
                                    return True

                                if self.pta_entry_count is not None:
                                    return True

                                if self.pta_memory is not None:
                                    return True

                                if self.restart_count is not None:
                                    return True

                                if self.ribrnh_entry_count is not None:
                                    return True

                                if self.ribrnh_memory is not None:
                                    return True

                                if self.route_reflector_memory is not None:
                                    return True

                                if self.route_reflectors is not None:
                                    return True

                                if self.sn_num_non_dflt_vrf_nbrs is not None:
                                    return True

                                if self.sn_num_non_dflt_vrf_nbrs_estab is not None:
                                    return True

                                if self.total_vrf_count is not None:
                                    return True

                                if self.tunnel_encap_entry_count is not None:
                                    return True

                                if self.tunnel_encap_memory is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global_']['meta_info']


                        class Vrf(object):
                            """
                            VRF information
                            
                            .. attribute:: established_neighbors_count
                            
                            	Number of established neighbors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbors_count
                            
                            	Number of neighbors
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: network_count
                            
                            	Number of networks
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: notifications_received
                            
                            	No. of notifications received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: notifications_sent
                            
                            	No. of notifications sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: path_count
                            
                            	Number of paths
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_messages_received
                            
                            	Number of update messages received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_messages_sent
                            
                            	No. of update messages sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.established_neighbors_count = None
                                self.neighbors_count = None
                                self.network_count = None
                                self.notifications_received = None
                                self.notifications_sent = None
                                self.path_count = None
                                self.update_messages_received = None
                                self.update_messages_sent = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:vrf'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.established_neighbors_count is not None:
                                    return True

                                if self.neighbors_count is not None:
                                    return True

                                if self.network_count is not None:
                                    return True

                                if self.notifications_received is not None:
                                    return True

                                if self.notifications_sent is not None:
                                    return True

                                if self.path_count is not None:
                                    return True

                                if self.update_messages_received is not None:
                                    return True

                                if self.update_messages_sent is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Vrf']['meta_info']


                        class PerformanceStatistics(object):
                            """
                            Performance statistics
                            
                            .. attribute:: global_
                            
                            	Global information
                            	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_>`
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:   :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Vrf>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.global_ = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_()
                                self.global_.parent = self
                                self.vrf = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Vrf()
                                self.vrf.parent = self


                            class Global_(object):
                                """
                                Global information
                                
                                .. attribute:: active_nsr_mode_enter_time
                                
                                	Time that each mode was entered (seconds since  Jan 1 1970)
                                	**type**\: list of    :py:class:`ActiveNsrModeEnterTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrModeEnterTime>`
                                
                                .. attribute:: active_nsr_state
                                
                                	Current Active BGP nsrstate
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: active_nsrfo_time
                                
                                	Time that each thread isdone with its  go\-activeprocessing (seconds since Jan 1 1970)
                                	**type**\: list of    :py:class:`ActiveNsrfoTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrfoTime>`
                                
                                .. attribute:: active_nsrtcp_phase_two_enter_time
                                
                                	Time that NSR TCP Init Sync Phase Two entered on active (seconds since Jan 1 1970)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: bgp_te_infra_tunnel_type
                                
                                	BGP TE infra tunnel type
                                	**type**\:   :py:class:`BgpTeInfraTunnelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTeInfraTunnelEnum>`
                                
                                .. attribute:: brib_api_input_bytes
                                
                                	bRIB API input bytes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: brib_api_input_messages
                                
                                	bRIB API input messages
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_input_prefixes_received
                                
                                	bRIB API input advertised prefixes received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_input_processing_time
                                
                                	Time spent processing input from bRIB API (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: brib_api_input_withdrawn_prefixes
                                
                                	bRIB API input withdrawn prefixes received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_output_bytes_generated
                                
                                	bRIB API output bytes generated
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: brib_api_output_bytes_sent
                                
                                	bRIB API output bytes sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: brib_api_output_calls
                                
                                	bRIB API calls to generate output
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_output_generation_time
                                
                                	Time spent generating output for bRIB API (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: brib_api_output_messages_sent
                                
                                	bRIB API output messages sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_output_prefixes_advertised
                                
                                	bRIB API output prefixes advertised
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_output_prefixes_withdrawn
                                
                                	bRIB API output prefixes withdrawn
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_output_sending_time
                                
                                	Time spent sending output to bRIB API (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: configuration_items_processed
                                
                                	Number of config items processed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: configuration_processing_time
                                
                                	Time spent processing config (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: current_clock_time
                                
                                	Current time
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ds_npl
                                
                                	NSR related DS and NPL information
                                	**type**\:   :py:class:`DsNpl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl>`
                                
                                .. attribute:: edm_processing_time
                                
                                	Time spent processing EDM requests (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: edm_requests_count
                                
                                	Number of EDM requests processed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: in_event_attach_calls
                                
                                	event\_file\_attach  calls for input
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: in_out_event_attach_calls
                                
                                	event\_file\_attach calls for input
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: initial_sync_sessions_added
                                
                                	If true, BGP has at least one established session when NSR initial synchronization is started
                                	**type**\:  bool
                                
                                .. attribute:: instance_node_role
                                
                                	Node role \- active/passive
                                	**type**\:  bool
                                
                                .. attribute:: io_handler_tm
                                
                                	Timestamp when IO timer handler got called
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: io_timer_id
                                
                                	IO master timer ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: io_tree_timer_expiry
                                
                                	Time as per tree\->mtexptime
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: io_tree_timer_left
                                
                                	Time left before the QNX timer would expire
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ipv4rib_server
                                
                                	IPv4 RIB server global info
                                	**type**\:   :py:class:`Ipv4RibServer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer>`
                                
                                .. attribute:: ipv6rib_server
                                
                                	IPv6 RIB server global info
                                	**type**\:   :py:class:`Ipv6RibServer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer>`
                                
                                .. attribute:: issu_milestone
                                
                                	ISSU Milestones
                                	**type**\: list of    :py:class:`IssuMilestone <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.IssuMilestone>`
                                
                                .. attribute:: issu_milestone_packed
                                
                                	Flag to indicate ISSU Milestones packed
                                	**type**\:  bool
                                
                                .. attribute:: lsd_connection
                                
                                	MPLS LSD server connection info
                                	**type**\:   :py:class:`LsdConnection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection>`
                                
                                .. attribute:: nsr_last_reset_reason
                                
                                	Reason for last nsr state  machine reset
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: out_event_attach_calls
                                
                                	event\_file\_attach  calls for output
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: postit_count_info
                                
                                	List of neighbors and their postit counts
                                	**type**\: list of    :py:class:`PostitCountInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo>`
                                
                                .. attribute:: proc_scoped_sync_state
                                
                                	BGP scoped sync state
                                	**type**\:   :py:class:`BgpScopedSyncStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpScopedSyncStateEnum>`
                                
                                .. attribute:: qad_ac_ks_failure
                                
                                	Ack failure on QAD 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_ac_ks_received
                                
                                	Acks received on QAD 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_init_drops
                                
                                	Packets dropped on standby during initialization
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_messages_received
                                
                                	Messages received on QAD 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_messages_sent
                                
                                	Messages sent on QAD 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_processed
                                
                                	Messages processed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_recv_drops
                                
                                	Received packet dropped due to null peer 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_resumes
                                
                                	QAD send resume 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_send_drops
                                
                                	Send packets dropped due to null peer 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_send_failure
                                
                                	Send failure on QAD 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_suspends
                                
                                	QAD send suspend
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_timeout_received
                                
                                	Timeouts received on QAD 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_timeout_recvd
                                
                                	Number of packet send timeouts 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qadack_sent
                                
                                	Acks sent on QAD 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qadoos_drops
                                
                                	Packets dropped due to  out of sequence packetreceived
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: redcon_nsr_ready
                                
                                	NSR state conveyed to Redcon  by bgp \- nsr ready/unready
                                	**type**\:  bool
                                
                                .. attribute:: redcon_state_time
                                
                                	Time when nsr state wasconveyed to Redcon last
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sec_active_nsr_state
                                
                                	Current Sec Active BGP nsrstate
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sec_active_nsrtcp_phase_two_enter_time
                                
                                	Time that NSR TCP Init Sync Phase Two entered on active (seconds since Jan 1 1970)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: standby_nsr_mode_enter_time
                                
                                	Time that each mode was entered (seconds since  Jan 1 1970)
                                	**type**\: list of    :py:class:`StandbyNsrModeEnterTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.StandbyNsrModeEnterTime>`
                                
                                .. attribute:: te_connection
                                
                                	MPLS TE server connection info
                                	**type**\:   :py:class:`TeConnection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection>`
                                
                                .. attribute:: tep2p_auto_tunnel_enabled
                                
                                	TE support for P2P auto tunnel
                                	**type**\:  bool
                                
                                .. attribute:: total_neighbors_with_pending_postits
                                
                                	Total nbrs with pending postits
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_outstanding_postits
                                
                                	Total outstanding postits across all neighbors
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: updgen_handler_tm
                                
                                	Timestamp when updgen timer handler got called
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: updgen_timer_id
                                
                                	Updgen master timer ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: updgen_tree_timer_expiry
                                
                                	Time as per tree\->mtexptime
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: updgen_tree_timer_left
                                
                                	Time left before the QNX timer would expire
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.active_nsr_mode_enter_time = YList()
                                    self.active_nsr_mode_enter_time.parent = self
                                    self.active_nsr_mode_enter_time.name = 'active_nsr_mode_enter_time'
                                    self.active_nsr_state = None
                                    self.active_nsrfo_time = YList()
                                    self.active_nsrfo_time.parent = self
                                    self.active_nsrfo_time.name = 'active_nsrfo_time'
                                    self.active_nsrtcp_phase_two_enter_time = None
                                    self.bgp_te_infra_tunnel_type = None
                                    self.brib_api_input_bytes = None
                                    self.brib_api_input_messages = None
                                    self.brib_api_input_prefixes_received = None
                                    self.brib_api_input_processing_time = None
                                    self.brib_api_input_withdrawn_prefixes = None
                                    self.brib_api_output_bytes_generated = None
                                    self.brib_api_output_bytes_sent = None
                                    self.brib_api_output_calls = None
                                    self.brib_api_output_generation_time = None
                                    self.brib_api_output_messages_sent = None
                                    self.brib_api_output_prefixes_advertised = None
                                    self.brib_api_output_prefixes_withdrawn = None
                                    self.brib_api_output_sending_time = None
                                    self.configuration_items_processed = None
                                    self.configuration_processing_time = None
                                    self.current_clock_time = None
                                    self.ds_npl = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl()
                                    self.ds_npl.parent = self
                                    self.edm_processing_time = None
                                    self.edm_requests_count = None
                                    self.in_event_attach_calls = None
                                    self.in_out_event_attach_calls = None
                                    self.initial_sync_sessions_added = None
                                    self.instance_node_role = None
                                    self.io_handler_tm = None
                                    self.io_timer_id = None
                                    self.io_tree_timer_expiry = None
                                    self.io_tree_timer_left = None
                                    self.ipv4rib_server = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer()
                                    self.ipv4rib_server.parent = self
                                    self.ipv6rib_server = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer()
                                    self.ipv6rib_server.parent = self
                                    self.issu_milestone = YList()
                                    self.issu_milestone.parent = self
                                    self.issu_milestone.name = 'issu_milestone'
                                    self.issu_milestone_packed = None
                                    self.lsd_connection = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection()
                                    self.lsd_connection.parent = self
                                    self.nsr_last_reset_reason = None
                                    self.out_event_attach_calls = None
                                    self.postit_count_info = YList()
                                    self.postit_count_info.parent = self
                                    self.postit_count_info.name = 'postit_count_info'
                                    self.proc_scoped_sync_state = None
                                    self.qad_ac_ks_failure = None
                                    self.qad_ac_ks_received = None
                                    self.qad_init_drops = None
                                    self.qad_messages_received = None
                                    self.qad_messages_sent = None
                                    self.qad_processed = None
                                    self.qad_recv_drops = None
                                    self.qad_resumes = None
                                    self.qad_send_drops = None
                                    self.qad_send_failure = None
                                    self.qad_suspends = None
                                    self.qad_timeout_received = None
                                    self.qad_timeout_recvd = None
                                    self.qadack_sent = None
                                    self.qadoos_drops = None
                                    self.redcon_nsr_ready = None
                                    self.redcon_state_time = None
                                    self.sec_active_nsr_state = None
                                    self.sec_active_nsrtcp_phase_two_enter_time = None
                                    self.standby_nsr_mode_enter_time = YList()
                                    self.standby_nsr_mode_enter_time.parent = self
                                    self.standby_nsr_mode_enter_time.name = 'standby_nsr_mode_enter_time'
                                    self.te_connection = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection()
                                    self.te_connection.parent = self
                                    self.tep2p_auto_tunnel_enabled = None
                                    self.total_neighbors_with_pending_postits = None
                                    self.total_outstanding_postits = None
                                    self.updgen_handler_tm = None
                                    self.updgen_timer_id = None
                                    self.updgen_tree_timer_expiry = None
                                    self.updgen_tree_timer_left = None


                                class Ipv4RibServer(object):
                                    """
                                    IPv4 RIB server global info
                                    
                                    .. attribute:: first_rib_connection_down_timestamp
                                    
                                    	First RIB connection Down event timestamp
                                    	**type**\:   :py:class:`FirstRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionDownTimestamp>`
                                    
                                    .. attribute:: first_rib_connection_up_timestamp
                                    
                                    	First RIB connection Up event timestamp
                                    	**type**\:   :py:class:`FirstRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionUpTimestamp>`
                                    
                                    .. attribute:: is_rib_connection_up
                                    
                                    	Is RIB Connection Up?
                                    	**type**\:  bool
                                    
                                    .. attribute:: last_rib_connection_down_age
                                    
                                    	Time since last RIB connection Down event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_rib_connection_down_timestamp
                                    
                                    	Last RIB connection Down event timestamp
                                    	**type**\:   :py:class:`LastRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionDownTimestamp>`
                                    
                                    .. attribute:: last_rib_connection_up_age
                                    
                                    	Time since last RIB connection Up event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_rib_connection_up_timestamp
                                    
                                    	Last RIB connection Up event timestamp
                                    	**type**\:   :py:class:`LastRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionUpTimestamp>`
                                    
                                    .. attribute:: rib_connection_down_count
                                    
                                    	Number of RIB connection Down events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_connection_up_count
                                    
                                    	Number of RIB connection Up events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.first_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionDownTimestamp()
                                        self.first_rib_connection_down_timestamp.parent = self
                                        self.first_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionUpTimestamp()
                                        self.first_rib_connection_up_timestamp.parent = self
                                        self.is_rib_connection_up = None
                                        self.last_rib_connection_down_age = None
                                        self.last_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionDownTimestamp()
                                        self.last_rib_connection_down_timestamp.parent = self
                                        self.last_rib_connection_up_age = None
                                        self.last_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionUpTimestamp()
                                        self.last_rib_connection_up_timestamp.parent = self
                                        self.rib_connection_down_count = None
                                        self.rib_connection_up_count = None


                                    class FirstRibConnectionUpTimestamp(object):
                                        """
                                        First RIB connection Up event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-rib-connection-up-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionUpTimestamp']['meta_info']


                                    class LastRibConnectionUpTimestamp(object):
                                        """
                                        Last RIB connection Up event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-rib-connection-up-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionUpTimestamp']['meta_info']


                                    class FirstRibConnectionDownTimestamp(object):
                                        """
                                        First RIB connection Down event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-rib-connection-down-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.FirstRibConnectionDownTimestamp']['meta_info']


                                    class LastRibConnectionDownTimestamp(object):
                                        """
                                        Last RIB connection Down event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-rib-connection-down-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer.LastRibConnectionDownTimestamp']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4rib-server'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.first_rib_connection_down_timestamp is not None and self.first_rib_connection_down_timestamp._has_data():
                                            return True

                                        if self.first_rib_connection_up_timestamp is not None and self.first_rib_connection_up_timestamp._has_data():
                                            return True

                                        if self.is_rib_connection_up is not None:
                                            return True

                                        if self.last_rib_connection_down_age is not None:
                                            return True

                                        if self.last_rib_connection_down_timestamp is not None and self.last_rib_connection_down_timestamp._has_data():
                                            return True

                                        if self.last_rib_connection_up_age is not None:
                                            return True

                                        if self.last_rib_connection_up_timestamp is not None and self.last_rib_connection_up_timestamp._has_data():
                                            return True

                                        if self.rib_connection_down_count is not None:
                                            return True

                                        if self.rib_connection_up_count is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv4RibServer']['meta_info']


                                class Ipv6RibServer(object):
                                    """
                                    IPv6 RIB server global info
                                    
                                    .. attribute:: first_rib_connection_down_timestamp
                                    
                                    	First RIB connection Down event timestamp
                                    	**type**\:   :py:class:`FirstRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionDownTimestamp>`
                                    
                                    .. attribute:: first_rib_connection_up_timestamp
                                    
                                    	First RIB connection Up event timestamp
                                    	**type**\:   :py:class:`FirstRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionUpTimestamp>`
                                    
                                    .. attribute:: is_rib_connection_up
                                    
                                    	Is RIB Connection Up?
                                    	**type**\:  bool
                                    
                                    .. attribute:: last_rib_connection_down_age
                                    
                                    	Time since last RIB connection Down event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_rib_connection_down_timestamp
                                    
                                    	Last RIB connection Down event timestamp
                                    	**type**\:   :py:class:`LastRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionDownTimestamp>`
                                    
                                    .. attribute:: last_rib_connection_up_age
                                    
                                    	Time since last RIB connection Up event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_rib_connection_up_timestamp
                                    
                                    	Last RIB connection Up event timestamp
                                    	**type**\:   :py:class:`LastRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionUpTimestamp>`
                                    
                                    .. attribute:: rib_connection_down_count
                                    
                                    	Number of RIB connection Down events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_connection_up_count
                                    
                                    	Number of RIB connection Up events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.first_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionDownTimestamp()
                                        self.first_rib_connection_down_timestamp.parent = self
                                        self.first_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionUpTimestamp()
                                        self.first_rib_connection_up_timestamp.parent = self
                                        self.is_rib_connection_up = None
                                        self.last_rib_connection_down_age = None
                                        self.last_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionDownTimestamp()
                                        self.last_rib_connection_down_timestamp.parent = self
                                        self.last_rib_connection_up_age = None
                                        self.last_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionUpTimestamp()
                                        self.last_rib_connection_up_timestamp.parent = self
                                        self.rib_connection_down_count = None
                                        self.rib_connection_up_count = None


                                    class FirstRibConnectionUpTimestamp(object):
                                        """
                                        First RIB connection Up event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-rib-connection-up-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionUpTimestamp']['meta_info']


                                    class LastRibConnectionUpTimestamp(object):
                                        """
                                        Last RIB connection Up event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-rib-connection-up-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionUpTimestamp']['meta_info']


                                    class FirstRibConnectionDownTimestamp(object):
                                        """
                                        First RIB connection Down event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-rib-connection-down-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.FirstRibConnectionDownTimestamp']['meta_info']


                                    class LastRibConnectionDownTimestamp(object):
                                        """
                                        Last RIB connection Down event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-rib-connection-down-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer.LastRibConnectionDownTimestamp']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6rib-server'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.first_rib_connection_down_timestamp is not None and self.first_rib_connection_down_timestamp._has_data():
                                            return True

                                        if self.first_rib_connection_up_timestamp is not None and self.first_rib_connection_up_timestamp._has_data():
                                            return True

                                        if self.is_rib_connection_up is not None:
                                            return True

                                        if self.last_rib_connection_down_age is not None:
                                            return True

                                        if self.last_rib_connection_down_timestamp is not None and self.last_rib_connection_down_timestamp._has_data():
                                            return True

                                        if self.last_rib_connection_up_age is not None:
                                            return True

                                        if self.last_rib_connection_up_timestamp is not None and self.last_rib_connection_up_timestamp._has_data():
                                            return True

                                        if self.rib_connection_down_count is not None:
                                            return True

                                        if self.rib_connection_up_count is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.Ipv6RibServer']['meta_info']


                                class TeConnection(object):
                                    """
                                    MPLS TE server connection info
                                    
                                    .. attribute:: connection_down_count
                                    
                                    	Number of connection down events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: connection_up_count
                                    
                                    	Number of connection Up events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: first_connection_down_timestamp
                                    
                                    	First connection Down event timestamp
                                    	**type**\:   :py:class:`FirstConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionDownTimestamp>`
                                    
                                    .. attribute:: first_connection_up_timestamp
                                    
                                    	First connection Up event timestamp
                                    	**type**\:   :py:class:`FirstConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionUpTimestamp>`
                                    
                                    .. attribute:: is_connection_up
                                    
                                    	Is Connection Up?
                                    	**type**\:  bool
                                    
                                    .. attribute:: last_connection_down_age
                                    
                                    	Time since last connection Down event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_connection_down_timestamp
                                    
                                    	Last connection Down event timestamp
                                    	**type**\:   :py:class:`LastConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionDownTimestamp>`
                                    
                                    .. attribute:: last_connection_up_age
                                    
                                    	Time since last connection Up event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_connection_up_timestamp
                                    
                                    	Last connection Up event timestamp
                                    	**type**\:   :py:class:`LastConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionUpTimestamp>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.connection_down_count = None
                                        self.connection_up_count = None
                                        self.first_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionDownTimestamp()
                                        self.first_connection_down_timestamp.parent = self
                                        self.first_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionUpTimestamp()
                                        self.first_connection_up_timestamp.parent = self
                                        self.is_connection_up = None
                                        self.last_connection_down_age = None
                                        self.last_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionDownTimestamp()
                                        self.last_connection_down_timestamp.parent = self
                                        self.last_connection_up_age = None
                                        self.last_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionUpTimestamp()
                                        self.last_connection_up_timestamp.parent = self


                                    class FirstConnectionUpTimestamp(object):
                                        """
                                        First connection Up event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-connection-up-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionUpTimestamp']['meta_info']


                                    class LastConnectionUpTimestamp(object):
                                        """
                                        Last connection Up event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-connection-up-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionUpTimestamp']['meta_info']


                                    class FirstConnectionDownTimestamp(object):
                                        """
                                        First connection Down event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-connection-down-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.FirstConnectionDownTimestamp']['meta_info']


                                    class LastConnectionDownTimestamp(object):
                                        """
                                        Last connection Down event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-connection-down-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection.LastConnectionDownTimestamp']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:te-connection'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.connection_down_count is not None:
                                            return True

                                        if self.connection_up_count is not None:
                                            return True

                                        if self.first_connection_down_timestamp is not None and self.first_connection_down_timestamp._has_data():
                                            return True

                                        if self.first_connection_up_timestamp is not None and self.first_connection_up_timestamp._has_data():
                                            return True

                                        if self.is_connection_up is not None:
                                            return True

                                        if self.last_connection_down_age is not None:
                                            return True

                                        if self.last_connection_down_timestamp is not None and self.last_connection_down_timestamp._has_data():
                                            return True

                                        if self.last_connection_up_age is not None:
                                            return True

                                        if self.last_connection_up_timestamp is not None and self.last_connection_up_timestamp._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.TeConnection']['meta_info']


                                class LsdConnection(object):
                                    """
                                    MPLS LSD server connection info
                                    
                                    .. attribute:: connection_down_count
                                    
                                    	Number of connection down events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: connection_up_count
                                    
                                    	Number of connection Up events
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: first_connection_down_timestamp
                                    
                                    	First connection Down event timestamp
                                    	**type**\:   :py:class:`FirstConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionDownTimestamp>`
                                    
                                    .. attribute:: first_connection_up_timestamp
                                    
                                    	First connection Up event timestamp
                                    	**type**\:   :py:class:`FirstConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionUpTimestamp>`
                                    
                                    .. attribute:: is_connection_up
                                    
                                    	Is Connection Up?
                                    	**type**\:  bool
                                    
                                    .. attribute:: last_connection_down_age
                                    
                                    	Time since last connection Down event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_connection_down_timestamp
                                    
                                    	Last connection Down event timestamp
                                    	**type**\:   :py:class:`LastConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionDownTimestamp>`
                                    
                                    .. attribute:: last_connection_up_age
                                    
                                    	Time since last connection Up event (in seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_connection_up_timestamp
                                    
                                    	Last connection Up event timestamp
                                    	**type**\:   :py:class:`LastConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionUpTimestamp>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.connection_down_count = None
                                        self.connection_up_count = None
                                        self.first_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionDownTimestamp()
                                        self.first_connection_down_timestamp.parent = self
                                        self.first_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionUpTimestamp()
                                        self.first_connection_up_timestamp.parent = self
                                        self.is_connection_up = None
                                        self.last_connection_down_age = None
                                        self.last_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionDownTimestamp()
                                        self.last_connection_down_timestamp.parent = self
                                        self.last_connection_up_age = None
                                        self.last_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionUpTimestamp()
                                        self.last_connection_up_timestamp.parent = self


                                    class FirstConnectionUpTimestamp(object):
                                        """
                                        First connection Up event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-connection-up-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionUpTimestamp']['meta_info']


                                    class LastConnectionUpTimestamp(object):
                                        """
                                        Last connection Up event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-connection-up-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionUpTimestamp']['meta_info']


                                    class FirstConnectionDownTimestamp(object):
                                        """
                                        First connection Down event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:first-connection-down-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.FirstConnectionDownTimestamp']['meta_info']


                                    class LastConnectionDownTimestamp(object):
                                        """
                                        Last connection Down event timestamp
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.nanoseconds = None
                                            self.seconds = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-connection-down-timestamp'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.nanoseconds is not None:
                                                return True

                                            if self.seconds is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection.LastConnectionDownTimestamp']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:lsd-connection'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.connection_down_count is not None:
                                            return True

                                        if self.connection_up_count is not None:
                                            return True

                                        if self.first_connection_down_timestamp is not None and self.first_connection_down_timestamp._has_data():
                                            return True

                                        if self.first_connection_up_timestamp is not None and self.first_connection_up_timestamp._has_data():
                                            return True

                                        if self.is_connection_up is not None:
                                            return True

                                        if self.last_connection_down_age is not None:
                                            return True

                                        if self.last_connection_down_timestamp is not None and self.last_connection_down_timestamp._has_data():
                                            return True

                                        if self.last_connection_up_age is not None:
                                            return True

                                        if self.last_connection_up_timestamp is not None and self.last_connection_up_timestamp._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.LsdConnection']['meta_info']


                                class DsNpl(object):
                                    """
                                    NSR related DS and NPL information
                                    
                                    .. attribute:: dir_service_conn_state
                                    
                                    	Current Directory Service connectionstate
                                    	**type**\:   :py:class:`BgpDsConnStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpDsConnStateEnum>`
                                    
                                    .. attribute:: dsissu_status_flag
                                    
                                    	DS ISSU status flag
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: issu_mgr_conn_state
                                    
                                    	Current ISSU Mgr connection state
                                    	**type**\:   :py:class:`BgpIsmConnStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpIsmConnStateEnum>`
                                    
                                    .. attribute:: issu_phase
                                    
                                    	Current ISSU Phase
                                    	**type**\:  str
                                    
                                    .. attribute:: issu_type_ng
                                    
                                    	ISSU type is Next Gen
                                    	**type**\:  bool
                                    
                                    .. attribute:: issuha_option
                                    
                                    	Current ISSU HA option
                                    	**type**\:  str
                                    
                                    .. attribute:: local_ds_handle
                                    
                                    	Local Directory Service handle
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: npl_endpoint
                                    
                                    	NPL endpoint information
                                    	**type**\: list of    :py:class:`NplEndpoint <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint>`
                                    
                                    .. attribute:: npl_priority_statistic
                                    
                                    	NPL priority statistics
                                    	**type**\: list of    :py:class:`NplPriorityStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic>`
                                    
                                    .. attribute:: service_name
                                    
                                    	Local DS service name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.dir_service_conn_state = None
                                        self.dsissu_status_flag = None
                                        self.issu_mgr_conn_state = None
                                        self.issu_phase = None
                                        self.issu_type_ng = None
                                        self.issuha_option = None
                                        self.local_ds_handle = None
                                        self.npl_endpoint = YList()
                                        self.npl_endpoint.parent = self
                                        self.npl_endpoint.name = 'npl_endpoint'
                                        self.npl_priority_statistic = YList()
                                        self.npl_priority_statistic.parent = self
                                        self.npl_priority_statistic.name = 'npl_priority_statistic'
                                        self.service_name = None


                                    class NplPriorityStatistic(object):
                                        """
                                        NPL priority statistics
                                        
                                        .. attribute:: num_recv
                                        
                                        	Total recvd
                                        	**type**\: list of    :py:class:`NumRecv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecv>`
                                        
                                        .. attribute:: num_recv_drop
                                        
                                        	Recv Errors/drops
                                        	**type**\: list of    :py:class:`NumRecvDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop>`
                                        
                                        .. attribute:: num_sent
                                        
                                        	Total sent
                                        	**type**\: list of    :py:class:`NumSent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSent>`
                                        
                                        .. attribute:: num_sent_drop
                                        
                                        	Sent Error/drops
                                        	**type**\: list of    :py:class:`NumSentDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.num_recv = YList()
                                            self.num_recv.parent = self
                                            self.num_recv.name = 'num_recv'
                                            self.num_recv_drop = YList()
                                            self.num_recv_drop.parent = self
                                            self.num_recv_drop.name = 'num_recv_drop'
                                            self.num_sent = YList()
                                            self.num_sent.parent = self
                                            self.num_sent.name = 'num_sent'
                                            self.num_sent_drop = YList()
                                            self.num_sent_drop.parent = self
                                            self.num_sent_drop.name = 'num_sent_drop'


                                        class NumSent(object):
                                            """
                                            Total sent
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:num-sent'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSent']['meta_info']


                                        class NumRecv(object):
                                            """
                                            Total recvd
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:num-recv'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecv']['meta_info']


                                        class NumSentDrop(object):
                                            """
                                            Sent Error/drops
                                            
                                            .. attribute:: nsr_pl_send_drop_array
                                            
                                            	nsr pl send drop array
                                            	**type**\: list of    :py:class:`NsrPlSendDropArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nsr_pl_send_drop_array = YList()
                                                self.nsr_pl_send_drop_array.parent = self
                                                self.nsr_pl_send_drop_array.name = 'nsr_pl_send_drop_array'


                                            class NsrPlSendDropArray(object):
                                                """
                                                nsr pl send drop array
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nsr-pl-send-drop-array'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:num-sent-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nsr_pl_send_drop_array is not None:
                                                    for child_ref in self.nsr_pl_send_drop_array:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumSentDrop']['meta_info']


                                        class NumRecvDrop(object):
                                            """
                                            Recv Errors/drops
                                            
                                            .. attribute:: nsr_pl_recv_drop_array
                                            
                                            	nsr pl recv drop array
                                            	**type**\: list of    :py:class:`NsrPlRecvDropArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nsr_pl_recv_drop_array = YList()
                                                self.nsr_pl_recv_drop_array.parent = self
                                                self.nsr_pl_recv_drop_array.name = 'nsr_pl_recv_drop_array'


                                            class NsrPlRecvDropArray(object):
                                                """
                                                nsr pl recv drop array
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2015-08-27'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.entry = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:nsr-pl-recv-drop-array'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.entry is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:num-recv-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nsr_pl_recv_drop_array is not None:
                                                    for child_ref in self.nsr_pl_recv_drop_array:
                                                        if child_ref._has_data():
                                                            return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic.NumRecvDrop']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:npl-priority-statistic'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.num_recv is not None:
                                                for child_ref in self.num_recv:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.num_recv_drop is not None:
                                                for child_ref in self.num_recv_drop:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.num_sent is not None:
                                                for child_ref in self.num_sent:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.num_sent_drop is not None:
                                                for child_ref in self.num_sent_drop:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplPriorityStatistic']['meta_info']


                                    class NplEndpoint(object):
                                        """
                                        NPL endpoint information
                                        
                                        .. attribute:: endpoint
                                        
                                        	NCD endpoint bytestream
                                        	**type**\: list of    :py:class:`Endpoint <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint.Endpoint>`
                                        
                                        .. attribute:: endpoint_active_flag
                                        
                                        	Endpoint active flag
                                        	**type**\:  bool
                                        
                                        .. attribute:: endpoint_handle
                                        
                                        	NCD endpoint handle
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: endpoint_issu_role
                                        
                                        	Endpoint's ISSU Role. Values are 'Primary', 'Secondary' and 'Tertiary'
                                        	**type**\:  str
                                        
                                        .. attribute:: endpoint_name
                                        
                                        	Endpoint name
                                        	**type**\:  str
                                        
                                        .. attribute:: endpoint_stale_flag
                                        
                                        	Endpoint stale flag
                                        	**type**\:  bool
                                        
                                        .. attribute:: expected_sequence_num
                                        
                                        	Expected sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: msg_size
                                        
                                        	Message size for this entity
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: node_id
                                        
                                        	Node ID
                                        	**type**\:  str
                                        
                                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                                        
                                        .. attribute:: sync_group_name
                                        
                                        	Syncgroup associated with this endpoint
                                        	**type**\:  str
                                        
                                        .. attribute:: wheel_id
                                        
                                        	Wheel ID for this endpoint
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.endpoint = YList()
                                            self.endpoint.parent = self
                                            self.endpoint.name = 'endpoint'
                                            self.endpoint_active_flag = None
                                            self.endpoint_handle = None
                                            self.endpoint_issu_role = None
                                            self.endpoint_name = None
                                            self.endpoint_stale_flag = None
                                            self.expected_sequence_num = None
                                            self.msg_size = None
                                            self.node_id = None
                                            self.sync_group_name = None
                                            self.wheel_id = None


                                        class Endpoint(object):
                                            """
                                            NCD endpoint bytestream
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.entry = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:endpoint'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.entry is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint.Endpoint']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:npl-endpoint'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.endpoint is not None:
                                                for child_ref in self.endpoint:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.endpoint_active_flag is not None:
                                                return True

                                            if self.endpoint_handle is not None:
                                                return True

                                            if self.endpoint_issu_role is not None:
                                                return True

                                            if self.endpoint_name is not None:
                                                return True

                                            if self.endpoint_stale_flag is not None:
                                                return True

                                            if self.expected_sequence_num is not None:
                                                return True

                                            if self.msg_size is not None:
                                                return True

                                            if self.node_id is not None:
                                                return True

                                            if self.sync_group_name is not None:
                                                return True

                                            if self.wheel_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl.NplEndpoint']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ds-npl'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dir_service_conn_state is not None:
                                            return True

                                        if self.dsissu_status_flag is not None:
                                            return True

                                        if self.issu_mgr_conn_state is not None:
                                            return True

                                        if self.issu_phase is not None:
                                            return True

                                        if self.issu_type_ng is not None:
                                            return True

                                        if self.issuha_option is not None:
                                            return True

                                        if self.local_ds_handle is not None:
                                            return True

                                        if self.npl_endpoint is not None:
                                            for child_ref in self.npl_endpoint:
                                                if child_ref._has_data():
                                                    return True

                                        if self.npl_priority_statistic is not None:
                                            for child_ref in self.npl_priority_statistic:
                                                if child_ref._has_data():
                                                    return True

                                        if self.service_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.DsNpl']['meta_info']


                                class ActiveNsrModeEnterTime(object):
                                    """
                                    Time that each mode was entered (seconds since
                                    
                                    Jan 1 1970)
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-nsr-mode-enter-time'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrModeEnterTime']['meta_info']


                                class StandbyNsrModeEnterTime(object):
                                    """
                                    Time that each mode was entered (seconds since
                                    
                                    Jan 1 1970)
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:standby-nsr-mode-enter-time'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.StandbyNsrModeEnterTime']['meta_info']


                                class ActiveNsrfoTime(object):
                                    """
                                    Time that each thread isdone with its
                                    
                                    go\-activeprocessing (seconds since Jan 1 1970)
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:active-nsrfo-time'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.ActiveNsrfoTime']['meta_info']


                                class PostitCountInfo(object):
                                    """
                                    List of neighbors and their postit counts
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor Address
                                    	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress>`
                                    
                                    .. attribute:: postit_count
                                    
                                    	Count of the number of postits for this nbr
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress()
                                        self.neighbor_address.parent = self
                                        self.postit_count = None
                                        self.vrf_name = None


                                    class NeighborAddress(object):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\:  str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: ipv4sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv6sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnMspwAddress>`
                                        
                                        .. attribute:: l2vpnvpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnvplsAddress>`
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4mdt_address = None
                                            self.ipv4mvpn_address = None
                                            self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress()
                                            self.ipv4sr_policy_address.parent = self
                                            self.ipv4vpn_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress()
                                            self.ipv6sr_policy_address.parent = self
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_flowspec_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.l2vpn_evpn_address = None
                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnvplsAddress()
                                            self.l2vpnvpls_address.parent = self
                                            self.ls_ls_address = None
                                            self.rt_constraint_address = None


                                        class L2VpnvplsAddress(object):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                        class L2VpnMspwAddress(object):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.l2vpn_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.l2vpn_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                        class Ipv4SrPolicyAddress(object):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                        class Ipv6SrPolicyAddress(object):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv6_srpolicy_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv6_srpolicy_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.afi is not None:
                                                return True

                                            if self.ipv4_address is not None:
                                                return True

                                            if self.ipv4_flowspec_address is not None:
                                                return True

                                            if self.ipv4_label_address is not None:
                                                return True

                                            if self.ipv4_mcast_address is not None:
                                                return True

                                            if self.ipv4_tunnel_address is not None:
                                                return True

                                            if self.ipv4mdt_address is not None:
                                                return True

                                            if self.ipv4mvpn_address is not None:
                                                return True

                                            if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                                return True

                                            if self.ipv4vpn_address is not None:
                                                return True

                                            if self.ipv4vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv4vpna_mcastddress is not None:
                                                return True

                                            if self.ipv6_address is not None:
                                                return True

                                            if self.ipv6_flowspec_address is not None:
                                                return True

                                            if self.ipv6_label_address is not None:
                                                return True

                                            if self.ipv6_mcast_address is not None:
                                                return True

                                            if self.ipv6mvpn_address is not None:
                                                return True

                                            if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                                return True

                                            if self.ipv6vpn_address is not None:
                                                return True

                                            if self.ipv6vpn_flowspec_address is not None:
                                                return True

                                            if self.ipv6vpn_mcast_address is not None:
                                                return True

                                            if self.l2vpn_evpn_address is not None:
                                                return True

                                            if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                                return True

                                            if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                                return True

                                            if self.ls_ls_address is not None:
                                                return True

                                            if self.rt_constraint_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo.NeighborAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:postit-count-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.neighbor_address is not None and self.neighbor_address._has_data():
                                            return True

                                        if self.postit_count is not None:
                                            return True

                                        if self.vrf_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.PostitCountInfo']['meta_info']


                                class IssuMilestone(object):
                                    """
                                    ISSU Milestones
                                    
                                    .. attribute:: milestone_met_timestamp
                                    
                                    	Milestone met timestamp
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: milestone_name
                                    
                                    	Milestone name
                                    	**type**\:  str
                                    
                                    	**length:** 0..64
                                    
                                    .. attribute:: milestone_start_timestamp
                                    
                                    	Milestone start timestamp
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.milestone_met_timestamp = None
                                        self.milestone_name = None
                                        self.milestone_start_timestamp = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:issu-milestone'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.milestone_met_timestamp is not None:
                                            return True

                                        if self.milestone_name is not None:
                                            return True

                                        if self.milestone_start_timestamp is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_.IssuMilestone']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:global'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.active_nsr_mode_enter_time is not None:
                                        for child_ref in self.active_nsr_mode_enter_time:
                                            if child_ref._has_data():
                                                return True

                                    if self.active_nsr_state is not None:
                                        return True

                                    if self.active_nsrfo_time is not None:
                                        for child_ref in self.active_nsrfo_time:
                                            if child_ref._has_data():
                                                return True

                                    if self.active_nsrtcp_phase_two_enter_time is not None:
                                        return True

                                    if self.bgp_te_infra_tunnel_type is not None:
                                        return True

                                    if self.brib_api_input_bytes is not None:
                                        return True

                                    if self.brib_api_input_messages is not None:
                                        return True

                                    if self.brib_api_input_prefixes_received is not None:
                                        return True

                                    if self.brib_api_input_processing_time is not None:
                                        return True

                                    if self.brib_api_input_withdrawn_prefixes is not None:
                                        return True

                                    if self.brib_api_output_bytes_generated is not None:
                                        return True

                                    if self.brib_api_output_bytes_sent is not None:
                                        return True

                                    if self.brib_api_output_calls is not None:
                                        return True

                                    if self.brib_api_output_generation_time is not None:
                                        return True

                                    if self.brib_api_output_messages_sent is not None:
                                        return True

                                    if self.brib_api_output_prefixes_advertised is not None:
                                        return True

                                    if self.brib_api_output_prefixes_withdrawn is not None:
                                        return True

                                    if self.brib_api_output_sending_time is not None:
                                        return True

                                    if self.configuration_items_processed is not None:
                                        return True

                                    if self.configuration_processing_time is not None:
                                        return True

                                    if self.current_clock_time is not None:
                                        return True

                                    if self.ds_npl is not None and self.ds_npl._has_data():
                                        return True

                                    if self.edm_processing_time is not None:
                                        return True

                                    if self.edm_requests_count is not None:
                                        return True

                                    if self.in_event_attach_calls is not None:
                                        return True

                                    if self.in_out_event_attach_calls is not None:
                                        return True

                                    if self.initial_sync_sessions_added is not None:
                                        return True

                                    if self.instance_node_role is not None:
                                        return True

                                    if self.io_handler_tm is not None:
                                        return True

                                    if self.io_timer_id is not None:
                                        return True

                                    if self.io_tree_timer_expiry is not None:
                                        return True

                                    if self.io_tree_timer_left is not None:
                                        return True

                                    if self.ipv4rib_server is not None and self.ipv4rib_server._has_data():
                                        return True

                                    if self.ipv6rib_server is not None and self.ipv6rib_server._has_data():
                                        return True

                                    if self.issu_milestone is not None:
                                        for child_ref in self.issu_milestone:
                                            if child_ref._has_data():
                                                return True

                                    if self.issu_milestone_packed is not None:
                                        return True

                                    if self.lsd_connection is not None and self.lsd_connection._has_data():
                                        return True

                                    if self.nsr_last_reset_reason is not None:
                                        return True

                                    if self.out_event_attach_calls is not None:
                                        return True

                                    if self.postit_count_info is not None:
                                        for child_ref in self.postit_count_info:
                                            if child_ref._has_data():
                                                return True

                                    if self.proc_scoped_sync_state is not None:
                                        return True

                                    if self.qad_ac_ks_failure is not None:
                                        return True

                                    if self.qad_ac_ks_received is not None:
                                        return True

                                    if self.qad_init_drops is not None:
                                        return True

                                    if self.qad_messages_received is not None:
                                        return True

                                    if self.qad_messages_sent is not None:
                                        return True

                                    if self.qad_processed is not None:
                                        return True

                                    if self.qad_recv_drops is not None:
                                        return True

                                    if self.qad_resumes is not None:
                                        return True

                                    if self.qad_send_drops is not None:
                                        return True

                                    if self.qad_send_failure is not None:
                                        return True

                                    if self.qad_suspends is not None:
                                        return True

                                    if self.qad_timeout_received is not None:
                                        return True

                                    if self.qad_timeout_recvd is not None:
                                        return True

                                    if self.qadack_sent is not None:
                                        return True

                                    if self.qadoos_drops is not None:
                                        return True

                                    if self.redcon_nsr_ready is not None:
                                        return True

                                    if self.redcon_state_time is not None:
                                        return True

                                    if self.sec_active_nsr_state is not None:
                                        return True

                                    if self.sec_active_nsrtcp_phase_two_enter_time is not None:
                                        return True

                                    if self.standby_nsr_mode_enter_time is not None:
                                        for child_ref in self.standby_nsr_mode_enter_time:
                                            if child_ref._has_data():
                                                return True

                                    if self.te_connection is not None and self.te_connection._has_data():
                                        return True

                                    if self.tep2p_auto_tunnel_enabled is not None:
                                        return True

                                    if self.total_neighbors_with_pending_postits is not None:
                                        return True

                                    if self.total_outstanding_postits is not None:
                                        return True

                                    if self.updgen_handler_tm is not None:
                                        return True

                                    if self.updgen_timer_id is not None:
                                        return True

                                    if self.updgen_tree_timer_expiry is not None:
                                        return True

                                    if self.updgen_tree_timer_left is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global_']['meta_info']


                            class Vrf(object):
                                """
                                VRF information
                                
                                .. attribute:: data_bytes_read
                                
                                	No. of bytes of data read
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: data_bytes_written
                                
                                	Number of bytes of data written
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: high_throttled_read_count
                                
                                	Number of socket reads for nbrs above high threshold
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: inbound_update_messages
                                
                                	Number of inbound update messages processed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: inbound_update_messages_time
                                
                                	Time spent processing imbound update messages (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: io_read_time
                                
                                	Time spent reading inbound data (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: io_write_time
                                
                                	Time spent writing outbound data (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low_throttled_read_count
                                
                                	Number of socket reads for nbrs above low threshold
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lpts_calls
                                
                                	Number of times LPTS socket opt set up
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lpts_set_up_time
                                
                                	Time spent setting up LPTS socket opt (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: read_calls_count
                                
                                	No. of calls to function to read inbound data
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: read_messages_count
                                
                                	Number of BGP messages read
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: read_throttles_count
                                
                                	Number of partial read throttles
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: subgroup_list_time
                                
                                	Time spent processing sub\-group message list (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: write_calls_count
                                
                                	No. of calls to function to write outbound data
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_queue_calls_count
                                
                                	No. of Calls to function to process write queue
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_queue_messages_count
                                
                                	Number of write queue messages processed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_queue_time
                                
                                	Time spent processing write queue (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_subgroup_calls_count
                                
                                	No. of calls to to funvction to process sub\-group message list
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_subgroup_messages_count
                                
                                	Number of sub\-group messages processed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.data_bytes_read = None
                                    self.data_bytes_written = None
                                    self.high_throttled_read_count = None
                                    self.inbound_update_messages = None
                                    self.inbound_update_messages_time = None
                                    self.io_read_time = None
                                    self.io_write_time = None
                                    self.low_throttled_read_count = None
                                    self.lpts_calls = None
                                    self.lpts_set_up_time = None
                                    self.read_calls_count = None
                                    self.read_messages_count = None
                                    self.read_throttles_count = None
                                    self.subgroup_list_time = None
                                    self.write_calls_count = None
                                    self.write_queue_calls_count = None
                                    self.write_queue_messages_count = None
                                    self.write_queue_time = None
                                    self.write_subgroup_calls_count = None
                                    self.write_subgroup_messages_count = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:vrf'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.data_bytes_read is not None:
                                        return True

                                    if self.data_bytes_written is not None:
                                        return True

                                    if self.high_throttled_read_count is not None:
                                        return True

                                    if self.inbound_update_messages is not None:
                                        return True

                                    if self.inbound_update_messages_time is not None:
                                        return True

                                    if self.io_read_time is not None:
                                        return True

                                    if self.io_write_time is not None:
                                        return True

                                    if self.low_throttled_read_count is not None:
                                        return True

                                    if self.lpts_calls is not None:
                                        return True

                                    if self.lpts_set_up_time is not None:
                                        return True

                                    if self.read_calls_count is not None:
                                        return True

                                    if self.read_messages_count is not None:
                                        return True

                                    if self.read_throttles_count is not None:
                                        return True

                                    if self.subgroup_list_time is not None:
                                        return True

                                    if self.write_calls_count is not None:
                                        return True

                                    if self.write_queue_calls_count is not None:
                                        return True

                                    if self.write_queue_messages_count is not None:
                                        return True

                                    if self.write_queue_time is not None:
                                        return True

                                    if self.write_subgroup_calls_count is not None:
                                        return True

                                    if self.write_subgroup_messages_count is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Vrf']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:performance-statistics'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.global_ is not None and self.global_._has_data():
                                    return True

                                if self.vrf is not None and self.vrf._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:process-info'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.global_ is not None and self.global_._has_data():
                                return True

                            if self.performance_statistics is not None and self.performance_statistics._has_data():
                                return True

                            if self.process_instance is not None:
                                return True

                            if self.vrf is not None and self.vrf._has_data():
                                return True

                            if self.vrf_name is not None:
                                return True

                            if self.vrf_totals is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo']['meta_info']


                    class Sessions(object):
                        """
                        The BGP session table
                        
                        .. attribute:: session
                        
                        	A BGP session table entry
                        	**type**\: list of    :py:class:`Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.session = YList()
                            self.session.parent = self
                            self.session.name = 'session'


                        class Session(object):
                            """
                            A BGP session table entry
                            
                            .. attribute:: neighbor_address  <key>
                            
                            	Neighbor address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: connection_local_address
                            
                            	Local address for the connection
                            	**type**\:   :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress>`
                            
                            .. attribute:: connection_remote_address
                            
                            	Remote address for the connection
                            	**type**\:   :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress>`
                            
                            .. attribute:: connection_state
                            
                            	State of connection
                            	**type**\:   :py:class:`BgpConnStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnStateEnum>`
                            
                            .. attribute:: description
                            
                            	Description
                            	**type**\:  str
                            
                            .. attribute:: is_local_address_configured
                            
                            	Local address configured for the neighbor connection
                            	**type**\:  bool
                            
                            .. attribute:: local_as
                            
                            	Local AS number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: messages_queued_in
                            
                            	No. of msgs on receive queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: messages_queued_out
                            
                            	No. of messages on send queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_enabled
                            
                            	Neighbor supports NSR
                            	**type**\:  bool
                            
                            .. attribute:: nsr_state
                            
                            	NSR state
                            	**type**\:   :py:class:`BgpSyncNbrNsrStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrStateEnum>`
                            
                            .. attribute:: postit_pending
                            
                            	Nbr has postits pending
                            	**type**\:  bool
                            
                            .. attribute:: remote_as
                            
                            	Remote AS number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: speaker_id
                            
                            	Speaker this neighbor is allocated to
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: vrf_name
                            
                            	Name of the VRF
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.neighbor_address = None
                                self.connection_local_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress()
                                self.connection_local_address.parent = self
                                self.connection_remote_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress()
                                self.connection_remote_address.parent = self
                                self.connection_state = None
                                self.description = None
                                self.is_local_address_configured = None
                                self.local_as = None
                                self.messages_queued_in = None
                                self.messages_queued_out = None
                                self.nsr_enabled = None
                                self.nsr_state = None
                                self.postit_pending = None
                                self.remote_as = None
                                self.speaker_id = None
                                self.vrf_name = None


                            class ConnectionLocalAddress(object):
                                """
                                Local address for the connection
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpnvpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2VpnvplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4mdt_address = None
                                    self.ipv4mvpn_address = None
                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                    self.ipv4sr_policy_address.parent = self
                                    self.ipv4vpn_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                    self.ipv6sr_policy_address.parent = self
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_flowspec_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.l2vpn_evpn_address = None
                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2VpnvplsAddress()
                                    self.l2vpnvpls_address.parent = self
                                    self.ls_ls_address = None
                                    self.rt_constraint_address = None


                                class L2VpnvplsAddress(object):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2VpnvplsAddress']['meta_info']


                                class L2VpnMspwAddress(object):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2VpnMspwAddress']['meta_info']


                                class Ipv4SrPolicyAddress(object):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress']['meta_info']


                                class Ipv6SrPolicyAddress(object):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv6_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv6_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connection-local-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.afi is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv4_flowspec_address is not None:
                                        return True

                                    if self.ipv4_label_address is not None:
                                        return True

                                    if self.ipv4_mcast_address is not None:
                                        return True

                                    if self.ipv4_tunnel_address is not None:
                                        return True

                                    if self.ipv4mdt_address is not None:
                                        return True

                                    if self.ipv4mvpn_address is not None:
                                        return True

                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                        return True

                                    if self.ipv4vpn_address is not None:
                                        return True

                                    if self.ipv4vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv4vpna_mcastddress is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    if self.ipv6_flowspec_address is not None:
                                        return True

                                    if self.ipv6_label_address is not None:
                                        return True

                                    if self.ipv6_mcast_address is not None:
                                        return True

                                    if self.ipv6mvpn_address is not None:
                                        return True

                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                        return True

                                    if self.ipv6vpn_address is not None:
                                        return True

                                    if self.ipv6vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv6vpn_mcast_address is not None:
                                        return True

                                    if self.l2vpn_evpn_address is not None:
                                        return True

                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                        return True

                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                        return True

                                    if self.ls_ls_address is not None:
                                        return True

                                    if self.rt_constraint_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress']['meta_info']


                            class ConnectionRemoteAddress(object):
                                """
                                Remote address for the connection
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpnvpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2VpnvplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4mdt_address = None
                                    self.ipv4mvpn_address = None
                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                    self.ipv4sr_policy_address.parent = self
                                    self.ipv4vpn_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                    self.ipv6sr_policy_address.parent = self
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_flowspec_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.l2vpn_evpn_address = None
                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2VpnvplsAddress()
                                    self.l2vpnvpls_address.parent = self
                                    self.ls_ls_address = None
                                    self.rt_constraint_address = None


                                class L2VpnvplsAddress(object):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2VpnvplsAddress']['meta_info']


                                class L2VpnMspwAddress(object):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2VpnMspwAddress']['meta_info']


                                class Ipv4SrPolicyAddress(object):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress']['meta_info']


                                class Ipv6SrPolicyAddress(object):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv6_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv6_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connection-remote-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.afi is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv4_flowspec_address is not None:
                                        return True

                                    if self.ipv4_label_address is not None:
                                        return True

                                    if self.ipv4_mcast_address is not None:
                                        return True

                                    if self.ipv4_tunnel_address is not None:
                                        return True

                                    if self.ipv4mdt_address is not None:
                                        return True

                                    if self.ipv4mvpn_address is not None:
                                        return True

                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                        return True

                                    if self.ipv4vpn_address is not None:
                                        return True

                                    if self.ipv4vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv4vpna_mcastddress is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    if self.ipv6_flowspec_address is not None:
                                        return True

                                    if self.ipv6_label_address is not None:
                                        return True

                                    if self.ipv6_mcast_address is not None:
                                        return True

                                    if self.ipv6mvpn_address is not None:
                                        return True

                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                        return True

                                    if self.ipv6vpn_address is not None:
                                        return True

                                    if self.ipv6vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv6vpn_mcast_address is not None:
                                        return True

                                    if self.l2vpn_evpn_address is not None:
                                        return True

                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                        return True

                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                        return True

                                    if self.ls_ls_address is not None:
                                        return True

                                    if self.rt_constraint_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.neighbor_address is None:
                                    raise YPYModelError('Key property neighbor_address is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:session[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address = ' + str(self.neighbor_address) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.neighbor_address is not None:
                                    return True

                                if self.connection_local_address is not None and self.connection_local_address._has_data():
                                    return True

                                if self.connection_remote_address is not None and self.connection_remote_address._has_data():
                                    return True

                                if self.connection_state is not None:
                                    return True

                                if self.description is not None:
                                    return True

                                if self.is_local_address_configured is not None:
                                    return True

                                if self.local_as is not None:
                                    return True

                                if self.messages_queued_in is not None:
                                    return True

                                if self.messages_queued_out is not None:
                                    return True

                                if self.nsr_enabled is not None:
                                    return True

                                if self.nsr_state is not None:
                                    return True

                                if self.postit_pending is not None:
                                    return True

                                if self.remote_as is not None:
                                    return True

                                if self.speaker_id is not None:
                                    return True

                                if self.vrf_name is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sessions'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.session is not None:
                                for child_ref in self.session:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions']['meta_info']


                    class Neighbors(object):
                        """
                        The BGP Neighbor table
                        
                        .. attribute:: neighbor
                        
                        	A BGP Neighbor table entry
                        	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.neighbor = YList()
                            self.neighbor.parent = self
                            self.neighbor.name = 'neighbor'


                        class Neighbor(object):
                            """
                            A BGP Neighbor table entry
                            
                            .. attribute:: neighbor_address  <key>
                            
                            	Neighbor address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: active_bmp_servers
                            
                            	BMP Servers to which the neighbor sends logs
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: actual_last_write_bytes
                            
                            	Actual size of last write
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: actual_last_write_reset_bytes
                            
                            	Actual size of last write before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: actual_second_last_write_bytes
                            
                            	Actual size of second last write
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: actual_second_last_write_reset_bytes
                            
                            	Actual size of second last write before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: af_data
                            
                            	Address family specific neighbor data
                            	**type**\: list of    :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData>`
                            
                            .. attribute:: attempted_last_write_bytes
                            
                            	Attempted size of last write
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attempted_last_write_reset_bytes
                            
                            	Attempted size of last write before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attempted_second_last_write_bytes
                            
                            	Attempted size of second last write
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attempted_second_last_write_reset_bytes
                            
                            	Attempted size of second last write before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_minintervalval
                            
                            	BFD Mininterval for this peer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_multiplierval
                            
                            	BFD Multiplier for this peer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_session_created_state
                            
                            	BFD state for this peer
                            	**type**\:   :py:class:`BgpBfdStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdStateEnum>`
                            
                            .. attribute:: bfd_session_enable_mode
                            
                            	BFD enable mode for this peer
                            	**type**\:   :py:class:`BgpBfdEnableModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdEnableModeEnum>`
                            
                            .. attribute:: bfd_session_state
                            
                            	BFD state for this peer
                            	**type**\:   :py:class:`BgpBfdStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdStateEnum>`
                            
                            .. attribute:: bfd_state_ts
                            
                            	Timestamp since when nbr is in this bfd state
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bytes_read
                            
                            	Total bytes read
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: bytes_written
                            
                            	Total bytes written by write thread
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: configured_hold_time
                            
                            	Hold time (in secs) configured for this connection
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: configured_keepalive
                            
                            	Keepalive time (in secs) configured for this connection
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: configured_min_acc_hold_time
                            
                            	Minimum acceptable hold time from neighbor (in secs) configured for this connection
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: connect_retry_interval
                            
                            	Time (in secs) for connect retry timer
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: connection_admin_status
                            
                            	Administrative status of connection
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: connection_down_count
                            
                            	Number of times connection was dropped
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: connection_established_time
                            
                            	Time (in secs) that the connection has been established
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: connection_local_address
                            
                            	Local address for the connection
                            	**type**\:   :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress>`
                            
                            .. attribute:: connection_local_port
                            
                            	Local port for the connection
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: connection_remote_address
                            
                            	Remote address for the connection
                            	**type**\:   :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress>`
                            
                            .. attribute:: connection_remote_port
                            
                            	Remote port for the connection
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: connection_state
                            
                            	State of connection
                            	**type**\:   :py:class:`BgpConnStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnStateEnum>`
                            
                            .. attribute:: connection_up_count
                            
                            	Number of times the connection was established
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: count_last_write
                            
                            	Count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: description
                            
                            	Description
                            	**type**\:  str
                            
                            .. attribute:: discard_as4_path
                            
                            	Discard AS4\_PATH in case there is a discrepancy in merging AS\_PATH and AS4\_PATH,retain ASPATH
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: discard_data_bytes
                            
                            	Remaining discard data (bytes) on Standby
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: dmz_link_bandwidth
                            
                            	Bandwidth of link to single\-hop eBGP peer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: dynamic_neighbor
                            
                            	Dynamic neighbor
                            	**type**\:  bool
                            
                            .. attribute:: ebgp_recv_dmz
                            
                            	Receive Bandwidth of link to single\-hop eBGP peer
                            	**type**\:  bool
                            
                            .. attribute:: ebgp_send_dmz_mode
                            
                            	Ebgp send dmz link bw mode
                            	**type**\:   :py:class:`BgpEbgpSendDmzEnableModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableModeEnum>`
                            
                            .. attribute:: ebgp_time_to_live
                            
                            	Maximum number of hops for external BGP neighbor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: egress_peer_engineering_enabled
                            
                            	Indicates if Egress Peer Engineering is enabled
                            	**type**\:  bool
                            
                            .. attribute:: error_notifies_received
                            
                            	Number of error notifications received on the connection
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: error_notifies_sent
                            
                            	Number of error notifications sent on the connection
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fpbsn_offset
                            
                            	First standby PDU boundary SeqNo offset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fssn_offset
                            
                            	First standby SeqNo offset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: gr_restart_time
                            
                            	Neighbor restart time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: gr_stale_path_time
                            
                            	Neighbor stale\-path time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: graceful_maintenance
                            
                            	Graceful Maintenance
                            	**type**\:   :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.GracefulMaintenance>`
                            
                            .. attribute:: graceful_restart_enabled_nbr
                            
                            	Neighbor supports graceful\-restart
                            	**type**\:  bool
                            
                            .. attribute:: has_internal_link
                            
                            	Internal link to neighbor
                            	**type**\:  bool
                            
                            .. attribute:: hold_time
                            
                            	Hold time (in secs) negotiated for this connection
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: ignore_connected
                            
                            	If true, the VPN client isan IBGP CE peer
                            	**type**\:  bool
                            
                            .. attribute:: internal_vpn_client
                            
                            	If true, don't do NHconnected check for nbr
                            	**type**\:  bool
                            
                            .. attribute:: io_armed
                            
                            	If true, socket has beenauto\-armed for io control
                            	**type**\:  bool
                            
                            .. attribute:: is4_byte_as_capability_received
                            
                            	4\-byte AScapability received
                            	**type**\:  bool
                            
                            .. attribute:: is4_byte_as_capability_sent
                            
                            	4\-byte AScapability Snt
                            	**type**\:  bool
                            
                            .. attribute:: is_administratively_shut_down
                            
                            	Neighbor is administratively shut down
                            	**type**\:  bool
                            
                            .. attribute:: is_capability_negotiation_performed
                            
                            	Capability negotiation performed
                            	**type**\:  bool
                            
                            .. attribute:: is_capability_negotiation_suppressed
                            
                            	Capability negotiation suppressed
                            	**type**\:  bool
                            
                            .. attribute:: is_ebgp_multihop_bgpmpls_forwarding_disabled
                            
                            	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_ebgp_peer_as_league
                            
                            	EBGP peer belongs to AS League
                            	**type**\:  bool
                            
                            .. attribute:: is_ebgp_peer_common_admin
                            
                            	EBGP peer with common administation
                            	**type**\:  bool
                            
                            .. attribute:: is_external_neighbor_not_directly_connected
                            
                            	External neighbor not directly connected
                            	**type**\:  bool
                            
                            .. attribute:: is_gr_aware
                            
                            	GR awareness received
                            	**type**\:  bool
                            
                            .. attribute:: is_local_address_configured
                            
                            	Local address configured for the neighbor connection
                            	**type**\:  bool
                            
                            .. attribute:: is_neighbor_max_prefix_shutdown
                            
                            	Neighbor shut down because it exceeded max prfx count
                            	**type**\:  bool
                            
                            .. attribute:: is_out_of_memory_forced_up
                            
                            	Neighbor forced up during a low memory condition
                            	**type**\:  bool
                            
                            .. attribute:: is_out_of_memory_shutdown
                            
                            	Neighbor shut down during a SEVERE low memory condition
                            	**type**\:  bool
                            
                            .. attribute:: is_passive_close
                            
                            	If true, active socket canbe closed if passive openis received for a GRcapable neighbor
                            	**type**\:  bool
                            
                            .. attribute:: is_read_disabled
                            
                            	If true, socket read isdisabled
                            	**type**\:  bool
                            
                            .. attribute:: is_route_refresh_capability_received
                            
                            	Route refresh capability received
                            	**type**\:  bool
                            
                            .. attribute:: is_route_refresh_old_capability_received
                            
                            	Route refresh old capability received
                            	**type**\:  bool
                            
                            .. attribute:: keep_alive_time
                            
                            	Keepalive time (in secs) negotiated for this connection
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: last_ackd_seq_no
                            
                            	SeqNo of the last Ackd byte
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_k_aerror_reset
                            
                            	Duration (in secs) since last time that an error was encountered after KA expiry
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_k_aexpiry_reset
                            
                            	Time (in secs) since last KA timer expiry before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_k_anotsent_reset
                            
                            	Duration (in secs) since last time that KA was not sent before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_k_astart_reset
                            
                            	Time (in secs) since the last KA timer start before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_notify_error_code
                            
                            	Code for the last error notification seen on the connection
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: last_notify_error_subcode
                            
                            	Error subcode of the last error notification seen on the connection
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: last_write_event
                            
                            	Time (in secs) since last write thread event
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: local_as
                            
                            	Local AS number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_as_dual_as
                            
                            	Local AS Dual\-AS option
                            	**type**\:  bool
                            
                            .. attribute:: local_as_dual_as_mode_native
                            
                            	Applies only if Local AS Dual\-AS option is enabled. Indicates if Dual\-AS mode is native
                            	**type**\:  bool
                            
                            .. attribute:: local_as_no_prepend
                            
                            	Option to not prepend the Local AS to announcements
                            	**type**\:  bool
                            
                            .. attribute:: local_as_replace_as
                            
                            	Local AS Replace\-AS option
                            	**type**\:  bool
                            
                            .. attribute:: message_statistics
                            
                            	Message statistics
                            	**type**\:   :py:class:`MessageStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics>`
                            
                            .. attribute:: messages_queued_in
                            
                            	No. of msgs on receive queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: messages_queued_out
                            
                            	No. of messages on send queue
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: messages_received
                            
                            	Number of messages received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: messages_sent
                            
                            	Number of messages sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: min_advertise_interval
                            
                            	Minimum advertisement interval, secs part
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: min_advertise_interval_msecs
                            
                            	Minimum advertisement interval, msecs part
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: millisecond
                            
                            .. attribute:: min_origination_interval
                            
                            	Minimum origination interval (in secs)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: msg_log_in
                            
                            	Message in log count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msg_log_out
                            
                            	Message out log count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: multi_protocol_capability_received
                            
                            	Multi\-protocol capability has been received
                            	**type**\:  bool
                            
                            .. attribute:: nbr_cluster_id
                            
                            	Cluster id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nbr_enforce_first_as
                            
                            	Neighbor enforce first AS
                            	**type**\:  bool
                            
                            .. attribute:: nbr_in_cluster
                            
                            	Type of cluster\_id\:undefined/number/Ip address
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: negotiated_protocol_version
                            
                            	Negotiated protocol version
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: neighbor_interface_handle
                            
                            	Interface Handle of Neighbor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_local_as
                            
                            	Local AS configured on the neighbor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_enabled
                            
                            	Neighbor supports NSR
                            	**type**\:  bool
                            
                            .. attribute:: nsr_state
                            
                            	NSR state
                            	**type**\:   :py:class:`BgpSyncNbrNsrStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrStateEnum>`
                            
                            .. attribute:: open_check_error_code
                            
                            	Open check error code
                            	**type**\:   :py:class:`BgpOpenCheckErrEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpOpenCheckErrEnum>`
                            
                            .. attribute:: peer_error_code
                            
                            	If peer closed, error received from transport
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: peer_reset_reason
                            
                            	Reason for last peer close event
                            	**type**\:   :py:class:`BgpPeerResetReasonIndexEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPeerResetReasonIndexEnum>`
                            
                            .. attribute:: performance_statistics
                            
                            	Performance statistics
                            	**type**\:   :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.PerformanceStatistics>`
                            
                            .. attribute:: previous_connection_state
                            
                            	Previous state of connection
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: read_armed
                            
                            	If true, socket has beenauto\-armed for read
                            	**type**\:  bool
                            
                            .. attribute:: received_notification_info
                            
                            	Information on the last notification received
                            	**type**\:   :py:class:`ReceivedNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo>`
                            
                            .. attribute:: remote_as
                            
                            	Remote AS number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_as_number
                            
                            	Remote AS number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reset_notification_sent
                            
                            	Notification was sent during last reset
                            	**type**\:  bool
                            
                            .. attribute:: reset_reason
                            
                            	Reason for last connection reset
                            	**type**\:   :py:class:`BgpResetReasonIndexEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndexEnum>`
                            
                            .. attribute:: router_id
                            
                            	Router ID for the neighbor
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: rpki_allow_invalid
                            
                            	Prefix v. allow invalid
                            	**type**\:  bool
                            
                            .. attribute:: rpki_disable
                            
                            	Prefix validation disabled
                            	**type**\:  bool
                            
                            .. attribute:: rpki_signal_ibgp
                            
                            	Prefix v. signal ibgp
                            	**type**\:  bool
                            
                            .. attribute:: rpki_use_validity
                            
                            	Prefix v. use validity
                            	**type**\:  bool
                            
                            .. attribute:: second_last_k_aexpiry_reset
                            
                            	Time (in secs) since second last KA timer expiry before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: second_last_k_astart_reset
                            
                            	Time (in secs) since the second last KA timer start before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: second_last_write_event
                            
                            	Time (in secs) since second last write thread event
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: send_notification_info
                            
                            	Information on the last notification sent
                            	**type**\:   :py:class:`SendNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo>`
                            
                            .. attribute:: socket_read_bytes
                            
                            	Total read bytes value insocket\-lib
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: speaker_id
                            
                            	Speaker this neighbor is allocated to
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: standby_rp
                            
                            	Standby RP socket inited for Active Open
                            	**type**\:  bool
                            
                            .. attribute:: suppress4_byte_as
                            
                            	Suppress 4byteas capability
                            	**type**\:  bool
                            
                            .. attribute:: tcp_init_sync_done_time_spec
                            
                            	Time when neighbor entered TCP Init Sync Done
                            	**type**\:   :py:class:`TcpInitSyncDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec>`
                            
                            .. attribute:: tcp_init_sync_phase_two_time_spec
                            
                            	Time when neighbor entered TCP Init Sync Phase Two
                            	**type**\:   :py:class:`TcpInitSyncPhaseTwoTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec>`
                            
                            .. attribute:: tcp_init_sync_time_spec
                            
                            	Time When neighbor entered TCP Init Sync
                            	**type**\:   :py:class:`TcpInitSyncTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncTimeSpec>`
                            
                            .. attribute:: tcp_session_open_mode
                            
                            	The TCP mode to be used to set up BGP session with the neighbor
                            	**type**\:   :py:class:`BgpTcpModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpModeEnum>`
                            
                            .. attribute:: tcpmss
                            
                            	Neighbor TCP Maximum Segment                     size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_last_cb
                            
                            	CB
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: time_last_cb_reset
                            
                            	Last CB before reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_last_fb
                            
                            	FB
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: time_since_connection_last_dropped
                            
                            	Time since the connection last went down (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: time_since_last_read
                            
                            	Time (in secs) since last read
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: time_since_last_read_reset
                            
                            	Time (in secs) since last read before last reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: time_since_last_update
                            
                            	Time (in secs) since last update message was received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: time_since_last_write
                            
                            	Time (in secs) since last write
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: time_since_last_write_reset
                            
                            	Time (in secs) since last write before last reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: time_since_second_last_write
                            
                            	Time (in secs) since second  last write
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: time_since_second_last_write_reset
                            
                            	Time (in secs) since last write before last reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: tos_type
                            
                            	Precedence or DSCP type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tos_value
                            
                            	Precedence or DSCP value
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ttl_security_enabled
                            
                            	TTL Security enabled
                            	**type**\:  bool
                            
                            .. attribute:: update_bytes_read
                            
                            	Total update bytes read
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: update_messages_in
                            
                            	No. of update msgs received
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_messages_out
                            
                            	No. of update messages sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vrf_name
                            
                            	Name of the VRF
                            	**type**\:  str
                            
                            .. attribute:: write_armed
                            
                            	If true, socket has beenauto\-armed for write
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.neighbor_address = None
                                self.active_bmp_servers = None
                                self.actual_last_write_bytes = None
                                self.actual_last_write_reset_bytes = None
                                self.actual_second_last_write_bytes = None
                                self.actual_second_last_write_reset_bytes = None
                                self.af_data = YList()
                                self.af_data.parent = self
                                self.af_data.name = 'af_data'
                                self.attempted_last_write_bytes = None
                                self.attempted_last_write_reset_bytes = None
                                self.attempted_second_last_write_bytes = None
                                self.attempted_second_last_write_reset_bytes = None
                                self.bfd_minintervalval = None
                                self.bfd_multiplierval = None
                                self.bfd_session_created_state = None
                                self.bfd_session_enable_mode = None
                                self.bfd_session_state = None
                                self.bfd_state_ts = None
                                self.bytes_read = None
                                self.bytes_written = None
                                self.configured_hold_time = None
                                self.configured_keepalive = None
                                self.configured_min_acc_hold_time = None
                                self.connect_retry_interval = None
                                self.connection_admin_status = None
                                self.connection_down_count = None
                                self.connection_established_time = None
                                self.connection_local_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress()
                                self.connection_local_address.parent = self
                                self.connection_local_port = None
                                self.connection_remote_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress()
                                self.connection_remote_address.parent = self
                                self.connection_remote_port = None
                                self.connection_state = None
                                self.connection_up_count = None
                                self.count_last_write = None
                                self.description = None
                                self.discard_as4_path = None
                                self.discard_data_bytes = None
                                self.dmz_link_bandwidth = None
                                self.dynamic_neighbor = None
                                self.ebgp_recv_dmz = None
                                self.ebgp_send_dmz_mode = None
                                self.ebgp_time_to_live = None
                                self.egress_peer_engineering_enabled = None
                                self.error_notifies_received = None
                                self.error_notifies_sent = None
                                self.fpbsn_offset = None
                                self.fssn_offset = None
                                self.gr_restart_time = None
                                self.gr_stale_path_time = None
                                self.graceful_maintenance = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.GracefulMaintenance()
                                self.graceful_maintenance.parent = self
                                self.graceful_restart_enabled_nbr = None
                                self.has_internal_link = None
                                self.hold_time = None
                                self.ignore_connected = None
                                self.internal_vpn_client = None
                                self.io_armed = None
                                self.is4_byte_as_capability_received = None
                                self.is4_byte_as_capability_sent = None
                                self.is_administratively_shut_down = None
                                self.is_capability_negotiation_performed = None
                                self.is_capability_negotiation_suppressed = None
                                self.is_ebgp_multihop_bgpmpls_forwarding_disabled = None
                                self.is_ebgp_peer_as_league = None
                                self.is_ebgp_peer_common_admin = None
                                self.is_external_neighbor_not_directly_connected = None
                                self.is_gr_aware = None
                                self.is_local_address_configured = None
                                self.is_neighbor_max_prefix_shutdown = None
                                self.is_out_of_memory_forced_up = None
                                self.is_out_of_memory_shutdown = None
                                self.is_passive_close = None
                                self.is_read_disabled = None
                                self.is_route_refresh_capability_received = None
                                self.is_route_refresh_old_capability_received = None
                                self.keep_alive_time = None
                                self.last_ackd_seq_no = None
                                self.last_k_aerror_reset = None
                                self.last_k_aexpiry_reset = None
                                self.last_k_anotsent_reset = None
                                self.last_k_astart_reset = None
                                self.last_notify_error_code = None
                                self.last_notify_error_subcode = None
                                self.last_write_event = None
                                self.local_as = None
                                self.local_as_dual_as = None
                                self.local_as_dual_as_mode_native = None
                                self.local_as_no_prepend = None
                                self.local_as_replace_as = None
                                self.message_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics()
                                self.message_statistics.parent = self
                                self.messages_queued_in = None
                                self.messages_queued_out = None
                                self.messages_received = None
                                self.messages_sent = None
                                self.min_advertise_interval = None
                                self.min_advertise_interval_msecs = None
                                self.min_origination_interval = None
                                self.msg_log_in = None
                                self.msg_log_out = None
                                self.multi_protocol_capability_received = None
                                self.nbr_cluster_id = None
                                self.nbr_enforce_first_as = None
                                self.nbr_in_cluster = None
                                self.negotiated_protocol_version = None
                                self.neighbor_interface_handle = None
                                self.neighbor_local_as = None
                                self.nsr_enabled = None
                                self.nsr_state = None
                                self.open_check_error_code = None
                                self.peer_error_code = None
                                self.peer_reset_reason = None
                                self.performance_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.PerformanceStatistics()
                                self.performance_statistics.parent = self
                                self.previous_connection_state = None
                                self.read_armed = None
                                self.received_notification_info = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo()
                                self.received_notification_info.parent = self
                                self.remote_as = None
                                self.remote_as_number = None
                                self.reset_notification_sent = None
                                self.reset_reason = None
                                self.router_id = None
                                self.rpki_allow_invalid = None
                                self.rpki_disable = None
                                self.rpki_signal_ibgp = None
                                self.rpki_use_validity = None
                                self.second_last_k_aexpiry_reset = None
                                self.second_last_k_astart_reset = None
                                self.second_last_write_event = None
                                self.send_notification_info = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo()
                                self.send_notification_info.parent = self
                                self.socket_read_bytes = None
                                self.speaker_id = None
                                self.standby_rp = None
                                self.suppress4_byte_as = None
                                self.tcp_init_sync_done_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec()
                                self.tcp_init_sync_done_time_spec.parent = self
                                self.tcp_init_sync_phase_two_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec()
                                self.tcp_init_sync_phase_two_time_spec.parent = self
                                self.tcp_init_sync_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncTimeSpec()
                                self.tcp_init_sync_time_spec.parent = self
                                self.tcp_session_open_mode = None
                                self.tcpmss = None
                                self.time_last_cb = None
                                self.time_last_cb_reset = None
                                self.time_last_fb = None
                                self.time_since_connection_last_dropped = None
                                self.time_since_last_read = None
                                self.time_since_last_read_reset = None
                                self.time_since_last_update = None
                                self.time_since_last_write = None
                                self.time_since_last_write_reset = None
                                self.time_since_second_last_write = None
                                self.time_since_second_last_write_reset = None
                                self.tos_type = None
                                self.tos_value = None
                                self.ttl_security_enabled = None
                                self.update_bytes_read = None
                                self.update_messages_in = None
                                self.update_messages_out = None
                                self.vrf_name = None
                                self.write_armed = None


                            class ConnectionLocalAddress(object):
                                """
                                Local address for the connection
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpnvpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnvplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4mdt_address = None
                                    self.ipv4mvpn_address = None
                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                    self.ipv4sr_policy_address.parent = self
                                    self.ipv4vpn_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                    self.ipv6sr_policy_address.parent = self
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_flowspec_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.l2vpn_evpn_address = None
                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnvplsAddress()
                                    self.l2vpnvpls_address.parent = self
                                    self.ls_ls_address = None
                                    self.rt_constraint_address = None


                                class L2VpnvplsAddress(object):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnvplsAddress']['meta_info']


                                class L2VpnMspwAddress(object):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2VpnMspwAddress']['meta_info']


                                class Ipv4SrPolicyAddress(object):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress']['meta_info']


                                class Ipv6SrPolicyAddress(object):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv6_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv6_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connection-local-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.afi is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv4_flowspec_address is not None:
                                        return True

                                    if self.ipv4_label_address is not None:
                                        return True

                                    if self.ipv4_mcast_address is not None:
                                        return True

                                    if self.ipv4_tunnel_address is not None:
                                        return True

                                    if self.ipv4mdt_address is not None:
                                        return True

                                    if self.ipv4mvpn_address is not None:
                                        return True

                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                        return True

                                    if self.ipv4vpn_address is not None:
                                        return True

                                    if self.ipv4vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv4vpna_mcastddress is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    if self.ipv6_flowspec_address is not None:
                                        return True

                                    if self.ipv6_label_address is not None:
                                        return True

                                    if self.ipv6_mcast_address is not None:
                                        return True

                                    if self.ipv6mvpn_address is not None:
                                        return True

                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                        return True

                                    if self.ipv6vpn_address is not None:
                                        return True

                                    if self.ipv6vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv6vpn_mcast_address is not None:
                                        return True

                                    if self.l2vpn_evpn_address is not None:
                                        return True

                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                        return True

                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                        return True

                                    if self.ls_ls_address is not None:
                                        return True

                                    if self.rt_constraint_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress']['meta_info']


                            class ConnectionRemoteAddress(object):
                                """
                                Remote address for the connection
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpnvpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnvplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4mdt_address = None
                                    self.ipv4mvpn_address = None
                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                    self.ipv4sr_policy_address.parent = self
                                    self.ipv4vpn_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                    self.ipv6sr_policy_address.parent = self
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_flowspec_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.l2vpn_evpn_address = None
                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnvplsAddress()
                                    self.l2vpnvpls_address.parent = self
                                    self.ls_ls_address = None
                                    self.rt_constraint_address = None


                                class L2VpnvplsAddress(object):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnvplsAddress']['meta_info']


                                class L2VpnMspwAddress(object):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2VpnMspwAddress']['meta_info']


                                class Ipv4SrPolicyAddress(object):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress']['meta_info']


                                class Ipv6SrPolicyAddress(object):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv6_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv6_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connection-remote-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.afi is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv4_flowspec_address is not None:
                                        return True

                                    if self.ipv4_label_address is not None:
                                        return True

                                    if self.ipv4_mcast_address is not None:
                                        return True

                                    if self.ipv4_tunnel_address is not None:
                                        return True

                                    if self.ipv4mdt_address is not None:
                                        return True

                                    if self.ipv4mvpn_address is not None:
                                        return True

                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                        return True

                                    if self.ipv4vpn_address is not None:
                                        return True

                                    if self.ipv4vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv4vpna_mcastddress is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    if self.ipv6_flowspec_address is not None:
                                        return True

                                    if self.ipv6_label_address is not None:
                                        return True

                                    if self.ipv6_mcast_address is not None:
                                        return True

                                    if self.ipv6mvpn_address is not None:
                                        return True

                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                        return True

                                    if self.ipv6vpn_address is not None:
                                        return True

                                    if self.ipv6vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv6vpn_mcast_address is not None:
                                        return True

                                    if self.l2vpn_evpn_address is not None:
                                        return True

                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                        return True

                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                        return True

                                    if self.ls_ls_address is not None:
                                        return True

                                    if self.rt_constraint_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress']['meta_info']


                            class SendNotificationInfo(object):
                                """
                                Information on the last notification sent
                                
                                .. attribute:: last_notification_data
                                
                                	Message data in last notification
                                	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData>`
                                
                                .. attribute:: notification_error_code
                                
                                	Error code in last notification
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: notification_error_subcode
                                
                                	Error subcode in last notification
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: time_since_last_notification
                                
                                	Time since the last notification was sent or received (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.last_notification_data = YList()
                                    self.last_notification_data.parent = self
                                    self.last_notification_data.name = 'last_notification_data'
                                    self.notification_error_code = None
                                    self.notification_error_subcode = None
                                    self.time_since_last_notification = None


                                class LastNotificationData(object):
                                    """
                                    Message data in last notification
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-notification-data'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:send-notification-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.last_notification_data is not None:
                                        for child_ref in self.last_notification_data:
                                            if child_ref._has_data():
                                                return True

                                    if self.notification_error_code is not None:
                                        return True

                                    if self.notification_error_subcode is not None:
                                        return True

                                    if self.time_since_last_notification is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo']['meta_info']


                            class ReceivedNotificationInfo(object):
                                """
                                Information on the last notification received
                                
                                .. attribute:: last_notification_data
                                
                                	Message data in last notification
                                	**type**\: list of    :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData>`
                                
                                .. attribute:: notification_error_code
                                
                                	Error code in last notification
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: notification_error_subcode
                                
                                	Error subcode in last notification
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: time_since_last_notification
                                
                                	Time since the last notification was sent or received (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.last_notification_data = YList()
                                    self.last_notification_data.parent = self
                                    self.last_notification_data.name = 'last_notification_data'
                                    self.notification_error_code = None
                                    self.notification_error_subcode = None
                                    self.time_since_last_notification = None


                                class LastNotificationData(object):
                                    """
                                    Message data in last notification
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-notification-data'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:received-notification-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.last_notification_data is not None:
                                        for child_ref in self.last_notification_data:
                                            if child_ref._has_data():
                                                return True

                                    if self.notification_error_code is not None:
                                        return True

                                    if self.notification_error_subcode is not None:
                                        return True

                                    if self.time_since_last_notification is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo']['meta_info']


                            class PerformanceStatistics(object):
                                """
                                Performance statistics
                                
                                .. attribute:: active_collision
                                
                                	Number of Closed Active connections for this neighbor due to collision 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: actives
                                
                                	Number of retried Active opens for this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: control_to_read_thread_trigger
                                
                                	Number of times io\-control thread trigger read thread
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: control_to_write_thread_trigger
                                
                                	Number of times io\-control thread trigger write thread
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: data_bytes_read
                                
                                	No. of bytes of data read
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: data_bytes_written
                                
                                	No. of data bytes written
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: failed_post_actives
                                
                                	Number of Active Opens that failed in the Post Active State for this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: high_throttled_read
                                
                                	Num of socket reads after nbr crossed high threshold
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: inbound_update_messages
                                
                                	Number of inbound update messages processed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: inbound_update_messages_time
                                
                                	Time spent processing inbound update messages (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: io_read_time
                                
                                	Time spent reading inbound data (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: io_write_time
                                
                                	Time spent writing outbound data (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: last_nsr_scoped_sync
                                
                                	Last time NSR scoped syncwas done for the neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_sent_seq_no
                                
                                	Seq No of the last sent byte
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low_throttled_read
                                
                                	Num socket reads after nbrs crossed low threshold
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_read_size
                                
                                	Size of largest socket (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: nbr_fd
                                
                                	Primary FD, per nbr
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: nbr_flags
                                
                                	Nbr flags, per thread
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: network_status
                                
                                	Socket status, TRUE if socket closed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_oper_down_count
                                
                                	Number of times NSR scoped sync has been done
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: passive_collision
                                
                                	Number of Closed Remote opens for this neighborneighbor due to collision 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: passives
                                
                                	Number of retried Passive opens for this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: read_calls_count
                                
                                	No. of calls to function to read inbound data
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: read_messages_count
                                
                                	Number of BGP messages read
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: read_throttles
                                
                                	Number of partial read throttles
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rejected_passives
                                
                                	Number of rejected Passive opens for this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reset_flags
                                
                                	Reset flags, per thread
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reset_retries
                                
                                	Reset Retries, per nbr
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: subgroup_list_time
                                
                                	Time spent processing sub\-group message list  (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: sync_flags
                                
                                	Sync flags, per nbr
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_since_last_throttled_read
                                
                                	Time (in secs) since last read after being throttled
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: write_calls_count
                                
                                	No. of calls to function to write outbound data
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_queue_calls_count
                                
                                	No. of calls to function to process write queue
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_queue_messages_count
                                
                                	Number of write queue messages processed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_queue_time
                                
                                	Time spent processing write queue (milliseconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: write_subgroup_calls_count
                                
                                	No. of calls to function to process sub\-group message list
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_subgroup_messages_count
                                
                                	Number of sub\-group msgs processed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.active_collision = None
                                    self.actives = None
                                    self.control_to_read_thread_trigger = None
                                    self.control_to_write_thread_trigger = None
                                    self.data_bytes_read = None
                                    self.data_bytes_written = None
                                    self.failed_post_actives = None
                                    self.high_throttled_read = None
                                    self.inbound_update_messages = None
                                    self.inbound_update_messages_time = None
                                    self.io_read_time = None
                                    self.io_write_time = None
                                    self.last_nsr_scoped_sync = None
                                    self.last_sent_seq_no = None
                                    self.low_throttled_read = None
                                    self.maximum_read_size = None
                                    self.nbr_fd = None
                                    self.nbr_flags = None
                                    self.network_status = None
                                    self.nsr_oper_down_count = None
                                    self.passive_collision = None
                                    self.passives = None
                                    self.read_calls_count = None
                                    self.read_messages_count = None
                                    self.read_throttles = None
                                    self.rejected_passives = None
                                    self.reset_flags = None
                                    self.reset_retries = None
                                    self.subgroup_list_time = None
                                    self.sync_flags = None
                                    self.time_since_last_throttled_read = None
                                    self.write_calls_count = None
                                    self.write_queue_calls_count = None
                                    self.write_queue_messages_count = None
                                    self.write_queue_time = None
                                    self.write_subgroup_calls_count = None
                                    self.write_subgroup_messages_count = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:performance-statistics'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.active_collision is not None:
                                        return True

                                    if self.actives is not None:
                                        return True

                                    if self.control_to_read_thread_trigger is not None:
                                        return True

                                    if self.control_to_write_thread_trigger is not None:
                                        return True

                                    if self.data_bytes_read is not None:
                                        return True

                                    if self.data_bytes_written is not None:
                                        return True

                                    if self.failed_post_actives is not None:
                                        return True

                                    if self.high_throttled_read is not None:
                                        return True

                                    if self.inbound_update_messages is not None:
                                        return True

                                    if self.inbound_update_messages_time is not None:
                                        return True

                                    if self.io_read_time is not None:
                                        return True

                                    if self.io_write_time is not None:
                                        return True

                                    if self.last_nsr_scoped_sync is not None:
                                        return True

                                    if self.last_sent_seq_no is not None:
                                        return True

                                    if self.low_throttled_read is not None:
                                        return True

                                    if self.maximum_read_size is not None:
                                        return True

                                    if self.nbr_fd is not None:
                                        return True

                                    if self.nbr_flags is not None:
                                        return True

                                    if self.network_status is not None:
                                        return True

                                    if self.nsr_oper_down_count is not None:
                                        return True

                                    if self.passive_collision is not None:
                                        return True

                                    if self.passives is not None:
                                        return True

                                    if self.read_calls_count is not None:
                                        return True

                                    if self.read_messages_count is not None:
                                        return True

                                    if self.read_throttles is not None:
                                        return True

                                    if self.rejected_passives is not None:
                                        return True

                                    if self.reset_flags is not None:
                                        return True

                                    if self.reset_retries is not None:
                                        return True

                                    if self.subgroup_list_time is not None:
                                        return True

                                    if self.sync_flags is not None:
                                        return True

                                    if self.time_since_last_throttled_read is not None:
                                        return True

                                    if self.write_calls_count is not None:
                                        return True

                                    if self.write_queue_calls_count is not None:
                                        return True

                                    if self.write_queue_messages_count is not None:
                                        return True

                                    if self.write_queue_time is not None:
                                        return True

                                    if self.write_subgroup_calls_count is not None:
                                        return True

                                    if self.write_subgroup_messages_count is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.PerformanceStatistics']['meta_info']


                            class MessageStatistics(object):
                                """
                                Message statistics
                                
                                .. attribute:: keepalive
                                
                                	Keepalive
                                	**type**\:   :py:class:`Keepalive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive>`
                                
                                .. attribute:: notification
                                
                                	Notification
                                	**type**\:   :py:class:`Notification <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification>`
                                
                                .. attribute:: open
                                
                                	Open
                                	**type**\:   :py:class:`Open <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open>`
                                
                                .. attribute:: route_refresh
                                
                                	Route refresh
                                	**type**\:   :py:class:`RouteRefresh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh>`
                                
                                .. attribute:: total
                                
                                	Total
                                	**type**\:   :py:class:`Total <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total>`
                                
                                .. attribute:: update
                                
                                	Update
                                	**type**\:   :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.keepalive = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive()
                                    self.keepalive.parent = self
                                    self.notification = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification()
                                    self.notification.parent = self
                                    self.open = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open()
                                    self.open.parent = self
                                    self.route_refresh = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh()
                                    self.route_refresh.parent = self
                                    self.total = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total()
                                    self.total.parent = self
                                    self.update = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update()
                                    self.update.parent = self


                                class Open(object):
                                    """
                                    Open
                                    
                                    .. attribute:: rx
                                    
                                    	Receive
                                    	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx>`
                                    
                                    .. attribute:: tx
                                    
                                    	Transmit
                                    	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.rx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx()
                                        self.rx.parent = self
                                        self.tx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx()
                                        self.tx.parent = self


                                    class Tx(object):
                                        """
                                        Transmit
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.count = None
                                            self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec()
                                            self.last_time_spec.parent = self


                                        class LastTimeSpec(object):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.count is not None:
                                                return True

                                            if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx']['meta_info']


                                    class Rx(object):
                                        """
                                        Receive
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.count = None
                                            self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec()
                                            self.last_time_spec.parent = self


                                        class LastTimeSpec(object):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.count is not None:
                                                return True

                                            if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:open'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.rx is not None and self.rx._has_data():
                                            return True

                                        if self.tx is not None and self.tx._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open']['meta_info']


                                class Notification(object):
                                    """
                                    Notification
                                    
                                    .. attribute:: rx
                                    
                                    	Receive
                                    	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx>`
                                    
                                    .. attribute:: tx
                                    
                                    	Transmit
                                    	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.rx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx()
                                        self.rx.parent = self
                                        self.tx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx()
                                        self.tx.parent = self


                                    class Tx(object):
                                        """
                                        Transmit
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.count = None
                                            self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec()
                                            self.last_time_spec.parent = self


                                        class LastTimeSpec(object):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.count is not None:
                                                return True

                                            if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx']['meta_info']


                                    class Rx(object):
                                        """
                                        Receive
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.count = None
                                            self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec()
                                            self.last_time_spec.parent = self


                                        class LastTimeSpec(object):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.count is not None:
                                                return True

                                            if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:notification'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.rx is not None and self.rx._has_data():
                                            return True

                                        if self.tx is not None and self.tx._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification']['meta_info']


                                class Update(object):
                                    """
                                    Update
                                    
                                    .. attribute:: rx
                                    
                                    	Receive
                                    	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx>`
                                    
                                    .. attribute:: tx
                                    
                                    	Transmit
                                    	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.rx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx()
                                        self.rx.parent = self
                                        self.tx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx()
                                        self.tx.parent = self


                                    class Tx(object):
                                        """
                                        Transmit
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.count = None
                                            self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec()
                                            self.last_time_spec.parent = self


                                        class LastTimeSpec(object):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.count is not None:
                                                return True

                                            if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx']['meta_info']


                                    class Rx(object):
                                        """
                                        Receive
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.count = None
                                            self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec()
                                            self.last_time_spec.parent = self


                                        class LastTimeSpec(object):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.count is not None:
                                                return True

                                            if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.rx is not None and self.rx._has_data():
                                            return True

                                        if self.tx is not None and self.tx._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update']['meta_info']


                                class Keepalive(object):
                                    """
                                    Keepalive
                                    
                                    .. attribute:: rx
                                    
                                    	Receive
                                    	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx>`
                                    
                                    .. attribute:: tx
                                    
                                    	Transmit
                                    	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.rx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx()
                                        self.rx.parent = self
                                        self.tx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx()
                                        self.tx.parent = self


                                    class Tx(object):
                                        """
                                        Transmit
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.count = None
                                            self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec()
                                            self.last_time_spec.parent = self


                                        class LastTimeSpec(object):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.count is not None:
                                                return True

                                            if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx']['meta_info']


                                    class Rx(object):
                                        """
                                        Receive
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.count = None
                                            self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec()
                                            self.last_time_spec.parent = self


                                        class LastTimeSpec(object):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.count is not None:
                                                return True

                                            if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:keepalive'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.rx is not None and self.rx._has_data():
                                            return True

                                        if self.tx is not None and self.tx._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive']['meta_info']


                                class RouteRefresh(object):
                                    """
                                    Route refresh
                                    
                                    .. attribute:: rx
                                    
                                    	Receive
                                    	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx>`
                                    
                                    .. attribute:: tx
                                    
                                    	Transmit
                                    	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.rx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx()
                                        self.rx.parent = self
                                        self.tx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx()
                                        self.tx.parent = self


                                    class Tx(object):
                                        """
                                        Transmit
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.count = None
                                            self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec()
                                            self.last_time_spec.parent = self


                                        class LastTimeSpec(object):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.count is not None:
                                                return True

                                            if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx']['meta_info']


                                    class Rx(object):
                                        """
                                        Receive
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.count = None
                                            self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec()
                                            self.last_time_spec.parent = self


                                        class LastTimeSpec(object):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.count is not None:
                                                return True

                                            if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:route-refresh'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.rx is not None and self.rx._has_data():
                                            return True

                                        if self.tx is not None and self.tx._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh']['meta_info']


                                class Total(object):
                                    """
                                    Total
                                    
                                    .. attribute:: rx
                                    
                                    	Receive
                                    	**type**\:   :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx>`
                                    
                                    .. attribute:: tx
                                    
                                    	Transmit
                                    	**type**\:   :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.rx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx()
                                        self.rx.parent = self
                                        self.tx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx()
                                        self.tx.parent = self


                                    class Tx(object):
                                        """
                                        Transmit
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.count = None
                                            self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec()
                                            self.last_time_spec.parent = self


                                        class LastTimeSpec(object):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tx'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.count is not None:
                                                return True

                                            if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx']['meta_info']


                                    class Rx(object):
                                        """
                                        Receive
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:   :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.count = None
                                            self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec()
                                            self.last_time_spec.parent = self


                                        class LastTimeSpec(object):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2015-08-27'

                                            def __init__(self):
                                                self.parent = None
                                                self.nanoseconds = None
                                                self.seconds = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-time-spec'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.nanoseconds is not None:
                                                    return True

                                                if self.seconds is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rx'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.count is not None:
                                                return True

                                            if self.last_time_spec is not None and self.last_time_spec._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:total'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.rx is not None and self.rx._has_data():
                                            return True

                                        if self.tx is not None and self.tx._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:message-statistics'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.keepalive is not None and self.keepalive._has_data():
                                        return True

                                    if self.notification is not None and self.notification._has_data():
                                        return True

                                    if self.open is not None and self.open._has_data():
                                        return True

                                    if self.route_refresh is not None and self.route_refresh._has_data():
                                        return True

                                    if self.total is not None and self.total._has_data():
                                        return True

                                    if self.update is not None and self.update._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics']['meta_info']


                            class TcpInitSyncTimeSpec(object):
                                """
                                Time When neighbor entered TCP Init Sync
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.nanoseconds = None
                                    self.seconds = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tcp-init-sync-time-spec'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.nanoseconds is not None:
                                        return True

                                    if self.seconds is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncTimeSpec']['meta_info']


                            class TcpInitSyncPhaseTwoTimeSpec(object):
                                """
                                Time when neighbor entered TCP Init Sync Phase
                                Two
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.nanoseconds = None
                                    self.seconds = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tcp-init-sync-phase-two-time-spec'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.nanoseconds is not None:
                                        return True

                                    if self.seconds is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec']['meta_info']


                            class TcpInitSyncDoneTimeSpec(object):
                                """
                                Time when neighbor entered TCP Init Sync Done
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.nanoseconds = None
                                    self.seconds = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:tcp-init-sync-done-time-spec'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.nanoseconds is not None:
                                        return True

                                    if self.seconds is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec']['meta_info']


                            class GracefulMaintenance(object):
                                """
                                Graceful Maintenance
                                
                                .. attribute:: gshut_active
                                
                                	Graceful Maintenance activated
                                	**type**\:  bool
                                
                                .. attribute:: gshut_exists
                                
                                	Graceful Maintenance enabled
                                	**type**\:  bool
                                
                                .. attribute:: gshut_local_active
                                
                                	Graceful Maintenance locally activated
                                	**type**\:  bool
                                
                                .. attribute:: gshut_locpref
                                
                                	Graceful Maintenance Local Preference
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: gshut_locpref_set
                                
                                	Graceful Maintenance Local Preference set
                                	**type**\:  bool
                                
                                .. attribute:: gshut_prepends
                                
                                	Graceful Maintenance number of AS prepends
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.gshut_active = None
                                    self.gshut_exists = None
                                    self.gshut_local_active = None
                                    self.gshut_locpref = None
                                    self.gshut_locpref_set = None
                                    self.gshut_prepends = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:graceful-maintenance'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.gshut_active is not None:
                                        return True

                                    if self.gshut_exists is not None:
                                        return True

                                    if self.gshut_local_active is not None:
                                        return True

                                    if self.gshut_locpref is not None:
                                        return True

                                    if self.gshut_locpref_set is not None:
                                        return True

                                    if self.gshut_prepends is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.GracefulMaintenance']['meta_info']


                            class AfData(object):
                                """
                                Address family specific neighbor data
                                
                                .. attribute:: accept_own_enabled
                                
                                	Accept\-Own enabled
                                	**type**\:  bool
                                
                                .. attribute:: acked_version
                                
                                	Version mapped from acked seqNo
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: address_family_long_lived_time
                                
                                	AF specific Long\-lived\-time config
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: advertise_afi
                                
                                	Encode in Advertise AFI
                                	**type**\:  bool
                                
                                .. attribute:: advertise_afi_def_vrf_imp_disable
                                
                                	Advertise of default VRF import disable
                                	**type**\:  bool
                                
                                .. attribute:: advertise_afi_disable
                                
                                	Encode in Advertise AFI
                                	**type**\:  bool
                                
                                .. attribute:: advertise_afi_eo_r_ready
                                
                                	EoR Can be sent for Advertise AFI
                                	**type**\:  bool
                                
                                .. attribute:: advertise_afi_reorg
                                
                                	Encode in Advertise AFI
                                	**type**\:  bool
                                
                                .. attribute:: advertise_afi_vrf_re_imp_disable
                                
                                	Advertise of VRF re\-import disable
                                	**type**\:  bool
                                
                                .. attribute:: advertise_evp_nv4afi_def_vrf_imp_disable
                                
                                	Advertise of v4 default VRF import disable
                                	**type**\:  bool
                                
                                .. attribute:: advertise_evp_nv4afi_vrf_re_imp_disable
                                
                                	Advertise of v4 VRF re\-import disable
                                	**type**\:  bool
                                
                                .. attribute:: advertise_evp_nv6afi_def_vrf_imp_disable
                                
                                	Advertise of v6 default VRF import disable
                                	**type**\:  bool
                                
                                .. attribute:: advertise_evp_nv6afi_vrf_re_imp_disable
                                
                                	Advertise of v6 VRF re\-import disable
                                	**type**\:  bool
                                
                                .. attribute:: advertise_local_labeled_route_unicast
                                
                                	Advertise routes with local\-label via Unicast SAFI
                                	**type**\:  bool
                                
                                .. attribute:: advertise_rt_type
                                
                                	Advertise RT type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: advertise_v4_flags
                                
                                	Advertise options for VPNV4
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: advertise_v6_flags
                                
                                	Advertise options for VPNV6
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: af_name
                                
                                	Address family identifier
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: afrpki_allow_invalid
                                
                                	Prefix v. allow invalid
                                	**type**\:  bool
                                
                                .. attribute:: afrpki_disable
                                
                                	Prefix validation disabled
                                	**type**\:  bool
                                
                                .. attribute:: afrpki_signal_ibgp
                                
                                	Prefix v. signal ibgp
                                	**type**\:  bool
                                
                                .. attribute:: afrpki_use_validity
                                
                                	Prefix v. use validity
                                	**type**\:  bool
                                
                                .. attribute:: allow_as_in_count
                                
                                	Allowas\-in count config
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: always_use_next_hop_local
                                
                                	Local router always used for next\-hop
                                	**type**\:  bool
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation type
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: eo_r_received_in_read_only
                                
                                	An EoR was received while in read\-only mode
                                	**type**\:  bool
                                
                                .. attribute:: extended_community
                                
                                	Extended community attribute
                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunity>`
                                
                                .. attribute:: extended_community_standby
                                
                                	Extended community attribute
                                	**type**\: list of    :py:class:`ExtendedCommunityStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby>`
                                
                                .. attribute:: filter_group_index
                                
                                	Filter group index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: flowspec_redirect_validation_d_isable
                                
                                	Flowspec Redirect Validation Disabled
                                	**type**\:  bool
                                
                                .. attribute:: flowspec_validation_d_isable
                                
                                	Flowspec Validation Disabled
                                	**type**\:  bool
                                
                                .. attribute:: import_reoriginate
                                
                                	Import Reoriginate enabled
                                	**type**\:  bool
                                
                                .. attribute:: import_reoriginate_stitching
                                
                                	Import Reoriginate Stitching enabled
                                	**type**\:  bool
                                
                                .. attribute:: import_stitching
                                
                                	Import Stitching enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_add_path_receive_capability_advertised
                                
                                	Addpath Receive capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_add_path_receive_capability_received
                                
                                	Addpath Receive capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_add_path_send_capability_advertised
                                
                                	Addpath Send capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_add_path_send_capability_received
                                
                                	Addpath Send capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_addpath_receive_operational
                                
                                	Addpath is operational on receive\-side
                                	**type**\:  bool
                                
                                .. attribute:: is_addpath_send_operational
                                
                                	Addpath is operational on send\-side
                                	**type**\:  bool
                                
                                .. attribute:: is_advertise_permanent_network
                                
                                	Advertise Permanent Network
                                	**type**\:  bool
                                
                                .. attribute:: is_advertised_graceful_restart
                                
                                	Graceful Restart Capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_advertised_orf_receive
                                
                                	Prefix based ORF receive mode capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_advertised_orf_send
                                
                                	Prefix based ORF send mode capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_aigp_set
                                
                                	AIGP set 
                                	**type**\:  bool
                                
                                .. attribute:: is_allow_as_in_set
                                
                                	Allowas\-in set 
                                	**type**\:  bool
                                
                                .. attribute:: is_as_override_set
                                
                                	As override set 
                                	**type**\:  bool
                                
                                .. attribute:: is_default_originate_sent
                                
                                	Default origination update sent
                                	**type**\:  bool
                                
                                .. attribute:: is_ext_nh_encoding_capability_received
                                
                                	Extended nexthop encoding capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_ext_nh_encoding_capability_sent
                                
                                	Extended nexhop encoding capability Sent
                                	**type**\:  bool
                                
                                .. attribute:: is_graceful_restart_state_flag
                                
                                	Restart state flag enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_legacy_pe_rt
                                
                                	Nbr accepts route from legacy PE for RT\-Constraint AF 
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_af_capable
                                
                                	Address family capability received from neighbor
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_ebgp_without_inbound_policy
                                
                                	eBGP neighbor with no configured inbound policy
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_ebgp_without_outbound_policy
                                
                                	eBGP neighbor with no configured outbound policy
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_route_reflector_client
                                
                                	Nbr is a route reflector client
                                	**type**\:  bool
                                
                                .. attribute:: is_orf_send_scheduled
                                
                                	Scheduled to send prefix based ORF
                                	**type**\:  bool
                                
                                .. attribute:: is_orf_sent
                                
                                	Outbound route filter sent to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: is_orr_root_address_configured
                                
                                	ORR Root address configuredfor the neighbor connection
                                	**type**\:  bool
                                
                                .. attribute:: is_peer_orf_capable
                                
                                	Peer has outbound route filter capability
                                	**type**\:  bool
                                
                                .. attribute:: is_prefix_orf_present
                                
                                	Outbound route filter prefix ORF present
                                	**type**\:  bool
                                
                                .. attribute:: is_received_graceful_restart_capable
                                
                                	Graceful Restart Capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_received_orf_receive_capable
                                
                                	Prefix based ORF receive mode capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_received_orf_send_capable
                                
                                	Prefix based ORF send mode capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_rt_present
                                
                                	RT attribute list present
                                	**type**\:  bool
                                
                                .. attribute:: is_rt_present_standby
                                
                                	RT attribute list present
                                	**type**\:  bool
                                
                                .. attribute:: is_send_mcast_attr
                                
                                	Send Mcast Attr
                                	**type**\:  bool
                                
                                .. attribute:: is_soft_reconfiguration_inbound_allowed
                                
                                	Inbound soft reconfiguration allowed
                                	**type**\:  bool
                                
                                .. attribute:: is_update_deferred
                                
                                	Update deferred until ORF/route refresh received
                                	**type**\:  bool
                                
                                .. attribute:: is_update_leaving
                                
                                	Nbr leaving update\-groupto another
                                	**type**\:  bool
                                
                                .. attribute:: is_update_throttled
                                
                                	Updates Throttled becausewrite limit is reached
                                	**type**\:  bool
                                
                                .. attribute:: is_use_soft_reconfiguration_always_on
                                
                                	Soft reconf overrides route refresh
                                	**type**\:  bool
                                
                                .. attribute:: local_restart_time
                                
                                	Local Restart time (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: long_lived_graceful_restart_capability_received
                                
                                	Long\-lived graceful\-restart capability received from the neighbor
                                	**type**\:  bool
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_accept
                                
                                	Maximum long\-lived graceful\-restart stale time acceptable from the neighbor (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_configured
                                
                                	Long\-lived graceful\-restart stale time is configured
                                	**type**\:  bool
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_received
                                
                                	Long\-lived graceful\-restart stale time received from the neighbor (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_sent
                                
                                	Stale time sent in long\-lived graceful\-restart capability (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: max_prefix_discard_extra_paths
                                
                                	Discard extra paths when prefix limit reached
                                	**type**\:  bool
                                
                                .. attribute:: max_prefix_exceed_discard_paths
                                
                                	Did we discard extra paths when prefix limit reached
                                	**type**\:  bool
                                
                                .. attribute:: max_prefix_limit
                                
                                	Max limit for # of prefixes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max_prefix_restart_time
                                
                                	Time interval (in minutes) after which peering session will be reestablished
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: minute
                                
                                .. attribute:: max_prefix_threshold_percent
                                
                                	Percentage of maximum no. of prefixes at which to generate warning
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: percentage
                                
                                .. attribute:: neighbor_af_performance_statistics
                                
                                	Neighbor AF statistics
                                	**type**\:   :py:class:`NeighborAfPerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics>`
                                
                                .. attribute:: neighbor_default_originate
                                
                                	Neighbor originates default
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_long_lived_graceful_restart_capable
                                
                                	Treat neighbor as long\-lived graceful\-restart capable
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_long_lived_graceful_restart_time_remaining
                                
                                	Remaining long\-lived graceful\-restart time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_preserved_forwarding_state
                                
                                	Neighbor preserved forwarding state
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_preserved_long_lived_forwarding_state
                                
                                	Neighbor preserved long\-lived forwarding state
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_version
                                
                                	Neighbor version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: number_of_best_externalpaths
                                
                                	No. of best\-external paths from this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: number_of_bestpaths
                                
                                	No. of bestpaths from this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: orf_entries_received
                                
                                	Number of outbound route filter entries received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: orr_group_index
                                
                                	ORR Group Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: orr_group_name
                                
                                	ORR Group Name
                                	**type**\:  str
                                
                                .. attribute:: outstanding_version
                                
                                	Version mapped from acked seqNo that was synced last
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: outstanding_version_max
                                
                                	Version mapped from acked seqNo that was synced last
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_accepted
                                
                                	No. of prefixes accepted
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_advertised
                                
                                	No. of prefixes advertised
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_be_advertised
                                
                                	No BE prefixes advertised
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_denied
                                
                                	No. of prefixes denied
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_denied_no_policy
                                
                                	No. of prefixes denied because there was no inbound policy
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_denied_non_cumulative
                                
                                	No. of prefixes exactly denied (non cumulative)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_denied_orf_policy
                                
                                	No. of prefixes denied by prefix based ORF policy
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_denied_policy
                                
                                	No. of prefixes denied by inbound policy
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_denied_rt_permit
                                
                                	No. of prefixes denied because RT extended community is not imported
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_suppressed
                                
                                	No. of prefixes suppressed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_synced
                                
                                	Number of prefixes synced to standby
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_withdrawn
                                
                                	No. of prefixes withdrawn
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_withdrawn_not_found
                                
                                	No. of prefixes withdrawn but not found
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: refresh_acked_version
                                
                                	Version acked by the peer for refresh updates sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: refresh_target_version
                                
                                	Target version for refresh update generation
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: refresh_version
                                
                                	Version till which refresh updates have been generated
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remove_private_as_entire_aspath_from_inbound_updates
                                
                                	Private AS numbers removed from updates from this nbr only if the aspath has only private ASes
                                	**type**\:  bool
                                
                                .. attribute:: remove_private_as_entire_aspath_from_updates
                                
                                	Private AS numbers removed from updates to thisnbr only if the aspath hasonly private ASes
                                	**type**\:  bool
                                
                                .. attribute:: remove_private_as_from_inbound_updates
                                
                                	Private AS numbers removed from updates from this nbr
                                	**type**\:  bool
                                
                                .. attribute:: remove_private_as_from_updates
                                
                                	Private AS numbers removed from updates to this nbr
                                	**type**\:  bool
                                
                                .. attribute:: restart_time
                                
                                	Restart time advertised (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: rib_purge_timeout_value
                                
                                	RIB purge timeout time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: route_policy_default_originate
                                
                                	Default\-originate route policy name
                                	**type**\:  str
                                
                                .. attribute:: route_policy_in
                                
                                	Incoming route policy name
                                	**type**\:  str
                                
                                .. attribute:: route_policy_out
                                
                                	Outgoing route policy name
                                	**type**\:  str
                                
                                .. attribute:: route_policy_prefix_orf
                                
                                	Prefix based ORF for incoming updates
                                	**type**\:  str
                                
                                .. attribute:: route_refreshes_received
                                
                                	Number of route refresh requests received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_refreshes_sent
                                
                                	Number of route refresh requests sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: selective_multipath_eligible
                                
                                	Selective multipath eligible
                                	**type**\:  bool
                                
                                .. attribute:: sent_community_to_neighbor
                                
                                	Community attribute sent to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: sent_extended_community_to_neighbor
                                
                                	Extended community attribute sent to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: sent_gshut_community_to_neighbor
                                
                                	GSHUT Community attribute sent to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: stale_path_timeout
                                
                                	Stale path timeout time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: synced_acked_version
                                
                                	Version mapped from acked seqNo that was synced last
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_group_number
                                
                                	Update group index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: use_max_prefix_warning_only
                                
                                	Warning only when maximum prefix limit reached
                                	**type**\:  bool
                                
                                .. attribute:: vpn_update_gen_enabled
                                
                                	RT Nbr enabled for updategento another
                                	**type**\:  bool
                                
                                .. attribute:: vpn_update_gen_trigger_enabled
                                
                                	RT Nbr enabled for updategento another
                                	**type**\:  bool
                                
                                .. attribute:: weight
                                
                                	Weight for this AF
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.accept_own_enabled = None
                                    self.acked_version = None
                                    self.address_family_long_lived_time = None
                                    self.advertise_afi = None
                                    self.advertise_afi_def_vrf_imp_disable = None
                                    self.advertise_afi_disable = None
                                    self.advertise_afi_eo_r_ready = None
                                    self.advertise_afi_reorg = None
                                    self.advertise_afi_vrf_re_imp_disable = None
                                    self.advertise_evp_nv4afi_def_vrf_imp_disable = None
                                    self.advertise_evp_nv4afi_vrf_re_imp_disable = None
                                    self.advertise_evp_nv6afi_def_vrf_imp_disable = None
                                    self.advertise_evp_nv6afi_vrf_re_imp_disable = None
                                    self.advertise_local_labeled_route_unicast = None
                                    self.advertise_rt_type = None
                                    self.advertise_v4_flags = None
                                    self.advertise_v6_flags = None
                                    self.af_name = None
                                    self.afrpki_allow_invalid = None
                                    self.afrpki_disable = None
                                    self.afrpki_signal_ibgp = None
                                    self.afrpki_use_validity = None
                                    self.allow_as_in_count = None
                                    self.always_use_next_hop_local = None
                                    self.encapsulation_type = None
                                    self.eo_r_received_in_read_only = None
                                    self.extended_community = YList()
                                    self.extended_community.parent = self
                                    self.extended_community.name = 'extended_community'
                                    self.extended_community_standby = YList()
                                    self.extended_community_standby.parent = self
                                    self.extended_community_standby.name = 'extended_community_standby'
                                    self.filter_group_index = None
                                    self.flowspec_redirect_validation_d_isable = None
                                    self.flowspec_validation_d_isable = None
                                    self.import_reoriginate = None
                                    self.import_reoriginate_stitching = None
                                    self.import_stitching = None
                                    self.is_add_path_receive_capability_advertised = None
                                    self.is_add_path_receive_capability_received = None
                                    self.is_add_path_send_capability_advertised = None
                                    self.is_add_path_send_capability_received = None
                                    self.is_addpath_receive_operational = None
                                    self.is_addpath_send_operational = None
                                    self.is_advertise_permanent_network = None
                                    self.is_advertised_graceful_restart = None
                                    self.is_advertised_orf_receive = None
                                    self.is_advertised_orf_send = None
                                    self.is_aigp_set = None
                                    self.is_allow_as_in_set = None
                                    self.is_as_override_set = None
                                    self.is_default_originate_sent = None
                                    self.is_ext_nh_encoding_capability_received = None
                                    self.is_ext_nh_encoding_capability_sent = None
                                    self.is_graceful_restart_state_flag = None
                                    self.is_legacy_pe_rt = None
                                    self.is_neighbor_af_capable = None
                                    self.is_neighbor_ebgp_without_inbound_policy = None
                                    self.is_neighbor_ebgp_without_outbound_policy = None
                                    self.is_neighbor_route_reflector_client = None
                                    self.is_orf_send_scheduled = None
                                    self.is_orf_sent = None
                                    self.is_orr_root_address_configured = None
                                    self.is_peer_orf_capable = None
                                    self.is_prefix_orf_present = None
                                    self.is_received_graceful_restart_capable = None
                                    self.is_received_orf_receive_capable = None
                                    self.is_received_orf_send_capable = None
                                    self.is_rt_present = None
                                    self.is_rt_present_standby = None
                                    self.is_send_mcast_attr = None
                                    self.is_soft_reconfiguration_inbound_allowed = None
                                    self.is_update_deferred = None
                                    self.is_update_leaving = None
                                    self.is_update_throttled = None
                                    self.is_use_soft_reconfiguration_always_on = None
                                    self.local_restart_time = None
                                    self.long_lived_graceful_restart_capability_received = None
                                    self.long_lived_graceful_restart_stale_time_accept = None
                                    self.long_lived_graceful_restart_stale_time_configured = None
                                    self.long_lived_graceful_restart_stale_time_received = None
                                    self.long_lived_graceful_restart_stale_time_sent = None
                                    self.max_prefix_discard_extra_paths = None
                                    self.max_prefix_exceed_discard_paths = None
                                    self.max_prefix_limit = None
                                    self.max_prefix_restart_time = None
                                    self.max_prefix_threshold_percent = None
                                    self.neighbor_af_performance_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics()
                                    self.neighbor_af_performance_statistics.parent = self
                                    self.neighbor_default_originate = None
                                    self.neighbor_long_lived_graceful_restart_capable = None
                                    self.neighbor_long_lived_graceful_restart_time_remaining = None
                                    self.neighbor_preserved_forwarding_state = None
                                    self.neighbor_preserved_long_lived_forwarding_state = None
                                    self.neighbor_version = None
                                    self.number_of_best_externalpaths = None
                                    self.number_of_bestpaths = None
                                    self.orf_entries_received = None
                                    self.orr_group_index = None
                                    self.orr_group_name = None
                                    self.outstanding_version = None
                                    self.outstanding_version_max = None
                                    self.prefixes_accepted = None
                                    self.prefixes_advertised = None
                                    self.prefixes_be_advertised = None
                                    self.prefixes_denied = None
                                    self.prefixes_denied_no_policy = None
                                    self.prefixes_denied_non_cumulative = None
                                    self.prefixes_denied_orf_policy = None
                                    self.prefixes_denied_policy = None
                                    self.prefixes_denied_rt_permit = None
                                    self.prefixes_suppressed = None
                                    self.prefixes_synced = None
                                    self.prefixes_withdrawn = None
                                    self.prefixes_withdrawn_not_found = None
                                    self.refresh_acked_version = None
                                    self.refresh_target_version = None
                                    self.refresh_version = None
                                    self.remove_private_as_entire_aspath_from_inbound_updates = None
                                    self.remove_private_as_entire_aspath_from_updates = None
                                    self.remove_private_as_from_inbound_updates = None
                                    self.remove_private_as_from_updates = None
                                    self.restart_time = None
                                    self.rib_purge_timeout_value = None
                                    self.route_policy_default_originate = None
                                    self.route_policy_in = None
                                    self.route_policy_out = None
                                    self.route_policy_prefix_orf = None
                                    self.route_refreshes_received = None
                                    self.route_refreshes_sent = None
                                    self.selective_multipath_eligible = None
                                    self.sent_community_to_neighbor = None
                                    self.sent_extended_community_to_neighbor = None
                                    self.sent_gshut_community_to_neighbor = None
                                    self.stale_path_timeout = None
                                    self.synced_acked_version = None
                                    self.update_group_number = None
                                    self.use_max_prefix_warning_only = None
                                    self.vpn_update_gen_enabled = None
                                    self.vpn_update_gen_trigger_enabled = None
                                    self.weight = None


                                class NeighborAfPerformanceStatistics(object):
                                    """
                                    Neighbor AF statistics
                                    
                                    .. attribute:: processed_messages
                                    
                                    	Number of messages processed from the neighbor's write queue
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sent_messages
                                    
                                    	Number of messages sent from the neighbor's write queue
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: split_horizon_update_blocked
                                    
                                    	No. of update messages with split\-horizon flag that were blocked
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: split_horizon_update_transmit
                                    
                                    	No. of update messages with split\-horizon flag that were sent out
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: split_horizon_withdraw_blocked
                                    
                                    	No. of withdraw messages with split\-horizon flag that were blocked
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: split_horizon_withdraw_transmit
                                    
                                    	No. of withdraw messages with split\-horizon flag that were sent out
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_pending_message_count
                                    
                                    	No. of sub\-group messages waiting to be sent out on this neighbor \-\- DEPRECATED \-\- 
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.processed_messages = None
                                        self.sent_messages = None
                                        self.split_horizon_update_blocked = None
                                        self.split_horizon_update_transmit = None
                                        self.split_horizon_withdraw_blocked = None
                                        self.split_horizon_withdraw_transmit = None
                                        self.sub_group_pending_message_count = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-af-performance-statistics'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.processed_messages is not None:
                                            return True

                                        if self.sent_messages is not None:
                                            return True

                                        if self.split_horizon_update_blocked is not None:
                                            return True

                                        if self.split_horizon_update_transmit is not None:
                                            return True

                                        if self.split_horizon_withdraw_blocked is not None:
                                            return True

                                        if self.split_horizon_withdraw_transmit is not None:
                                            return True

                                        if self.sub_group_pending_message_count is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics']['meta_info']


                                class ExtendedCommunity(object):
                                    """
                                    Extended community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunity']['meta_info']


                                class ExtendedCommunityStandby(object):
                                    """
                                    Extended community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community-standby'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af-data'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.accept_own_enabled is not None:
                                        return True

                                    if self.acked_version is not None:
                                        return True

                                    if self.address_family_long_lived_time is not None:
                                        return True

                                    if self.advertise_afi is not None:
                                        return True

                                    if self.advertise_afi_def_vrf_imp_disable is not None:
                                        return True

                                    if self.advertise_afi_disable is not None:
                                        return True

                                    if self.advertise_afi_eo_r_ready is not None:
                                        return True

                                    if self.advertise_afi_reorg is not None:
                                        return True

                                    if self.advertise_afi_vrf_re_imp_disable is not None:
                                        return True

                                    if self.advertise_evp_nv4afi_def_vrf_imp_disable is not None:
                                        return True

                                    if self.advertise_evp_nv4afi_vrf_re_imp_disable is not None:
                                        return True

                                    if self.advertise_evp_nv6afi_def_vrf_imp_disable is not None:
                                        return True

                                    if self.advertise_evp_nv6afi_vrf_re_imp_disable is not None:
                                        return True

                                    if self.advertise_local_labeled_route_unicast is not None:
                                        return True

                                    if self.advertise_rt_type is not None:
                                        return True

                                    if self.advertise_v4_flags is not None:
                                        return True

                                    if self.advertise_v6_flags is not None:
                                        return True

                                    if self.af_name is not None:
                                        return True

                                    if self.afrpki_allow_invalid is not None:
                                        return True

                                    if self.afrpki_disable is not None:
                                        return True

                                    if self.afrpki_signal_ibgp is not None:
                                        return True

                                    if self.afrpki_use_validity is not None:
                                        return True

                                    if self.allow_as_in_count is not None:
                                        return True

                                    if self.always_use_next_hop_local is not None:
                                        return True

                                    if self.encapsulation_type is not None:
                                        return True

                                    if self.eo_r_received_in_read_only is not None:
                                        return True

                                    if self.extended_community is not None:
                                        for child_ref in self.extended_community:
                                            if child_ref._has_data():
                                                return True

                                    if self.extended_community_standby is not None:
                                        for child_ref in self.extended_community_standby:
                                            if child_ref._has_data():
                                                return True

                                    if self.filter_group_index is not None:
                                        return True

                                    if self.flowspec_redirect_validation_d_isable is not None:
                                        return True

                                    if self.flowspec_validation_d_isable is not None:
                                        return True

                                    if self.import_reoriginate is not None:
                                        return True

                                    if self.import_reoriginate_stitching is not None:
                                        return True

                                    if self.import_stitching is not None:
                                        return True

                                    if self.is_add_path_receive_capability_advertised is not None:
                                        return True

                                    if self.is_add_path_receive_capability_received is not None:
                                        return True

                                    if self.is_add_path_send_capability_advertised is not None:
                                        return True

                                    if self.is_add_path_send_capability_received is not None:
                                        return True

                                    if self.is_addpath_receive_operational is not None:
                                        return True

                                    if self.is_addpath_send_operational is not None:
                                        return True

                                    if self.is_advertise_permanent_network is not None:
                                        return True

                                    if self.is_advertised_graceful_restart is not None:
                                        return True

                                    if self.is_advertised_orf_receive is not None:
                                        return True

                                    if self.is_advertised_orf_send is not None:
                                        return True

                                    if self.is_aigp_set is not None:
                                        return True

                                    if self.is_allow_as_in_set is not None:
                                        return True

                                    if self.is_as_override_set is not None:
                                        return True

                                    if self.is_default_originate_sent is not None:
                                        return True

                                    if self.is_ext_nh_encoding_capability_received is not None:
                                        return True

                                    if self.is_ext_nh_encoding_capability_sent is not None:
                                        return True

                                    if self.is_graceful_restart_state_flag is not None:
                                        return True

                                    if self.is_legacy_pe_rt is not None:
                                        return True

                                    if self.is_neighbor_af_capable is not None:
                                        return True

                                    if self.is_neighbor_ebgp_without_inbound_policy is not None:
                                        return True

                                    if self.is_neighbor_ebgp_without_outbound_policy is not None:
                                        return True

                                    if self.is_neighbor_route_reflector_client is not None:
                                        return True

                                    if self.is_orf_send_scheduled is not None:
                                        return True

                                    if self.is_orf_sent is not None:
                                        return True

                                    if self.is_orr_root_address_configured is not None:
                                        return True

                                    if self.is_peer_orf_capable is not None:
                                        return True

                                    if self.is_prefix_orf_present is not None:
                                        return True

                                    if self.is_received_graceful_restart_capable is not None:
                                        return True

                                    if self.is_received_orf_receive_capable is not None:
                                        return True

                                    if self.is_received_orf_send_capable is not None:
                                        return True

                                    if self.is_rt_present is not None:
                                        return True

                                    if self.is_rt_present_standby is not None:
                                        return True

                                    if self.is_send_mcast_attr is not None:
                                        return True

                                    if self.is_soft_reconfiguration_inbound_allowed is not None:
                                        return True

                                    if self.is_update_deferred is not None:
                                        return True

                                    if self.is_update_leaving is not None:
                                        return True

                                    if self.is_update_throttled is not None:
                                        return True

                                    if self.is_use_soft_reconfiguration_always_on is not None:
                                        return True

                                    if self.local_restart_time is not None:
                                        return True

                                    if self.long_lived_graceful_restart_capability_received is not None:
                                        return True

                                    if self.long_lived_graceful_restart_stale_time_accept is not None:
                                        return True

                                    if self.long_lived_graceful_restart_stale_time_configured is not None:
                                        return True

                                    if self.long_lived_graceful_restart_stale_time_received is not None:
                                        return True

                                    if self.long_lived_graceful_restart_stale_time_sent is not None:
                                        return True

                                    if self.max_prefix_discard_extra_paths is not None:
                                        return True

                                    if self.max_prefix_exceed_discard_paths is not None:
                                        return True

                                    if self.max_prefix_limit is not None:
                                        return True

                                    if self.max_prefix_restart_time is not None:
                                        return True

                                    if self.max_prefix_threshold_percent is not None:
                                        return True

                                    if self.neighbor_af_performance_statistics is not None and self.neighbor_af_performance_statistics._has_data():
                                        return True

                                    if self.neighbor_default_originate is not None:
                                        return True

                                    if self.neighbor_long_lived_graceful_restart_capable is not None:
                                        return True

                                    if self.neighbor_long_lived_graceful_restart_time_remaining is not None:
                                        return True

                                    if self.neighbor_preserved_forwarding_state is not None:
                                        return True

                                    if self.neighbor_preserved_long_lived_forwarding_state is not None:
                                        return True

                                    if self.neighbor_version is not None:
                                        return True

                                    if self.number_of_best_externalpaths is not None:
                                        return True

                                    if self.number_of_bestpaths is not None:
                                        return True

                                    if self.orf_entries_received is not None:
                                        return True

                                    if self.orr_group_index is not None:
                                        return True

                                    if self.orr_group_name is not None:
                                        return True

                                    if self.outstanding_version is not None:
                                        return True

                                    if self.outstanding_version_max is not None:
                                        return True

                                    if self.prefixes_accepted is not None:
                                        return True

                                    if self.prefixes_advertised is not None:
                                        return True

                                    if self.prefixes_be_advertised is not None:
                                        return True

                                    if self.prefixes_denied is not None:
                                        return True

                                    if self.prefixes_denied_no_policy is not None:
                                        return True

                                    if self.prefixes_denied_non_cumulative is not None:
                                        return True

                                    if self.prefixes_denied_orf_policy is not None:
                                        return True

                                    if self.prefixes_denied_policy is not None:
                                        return True

                                    if self.prefixes_denied_rt_permit is not None:
                                        return True

                                    if self.prefixes_suppressed is not None:
                                        return True

                                    if self.prefixes_synced is not None:
                                        return True

                                    if self.prefixes_withdrawn is not None:
                                        return True

                                    if self.prefixes_withdrawn_not_found is not None:
                                        return True

                                    if self.refresh_acked_version is not None:
                                        return True

                                    if self.refresh_target_version is not None:
                                        return True

                                    if self.refresh_version is not None:
                                        return True

                                    if self.remove_private_as_entire_aspath_from_inbound_updates is not None:
                                        return True

                                    if self.remove_private_as_entire_aspath_from_updates is not None:
                                        return True

                                    if self.remove_private_as_from_inbound_updates is not None:
                                        return True

                                    if self.remove_private_as_from_updates is not None:
                                        return True

                                    if self.restart_time is not None:
                                        return True

                                    if self.rib_purge_timeout_value is not None:
                                        return True

                                    if self.route_policy_default_originate is not None:
                                        return True

                                    if self.route_policy_in is not None:
                                        return True

                                    if self.route_policy_out is not None:
                                        return True

                                    if self.route_policy_prefix_orf is not None:
                                        return True

                                    if self.route_refreshes_received is not None:
                                        return True

                                    if self.route_refreshes_sent is not None:
                                        return True

                                    if self.selective_multipath_eligible is not None:
                                        return True

                                    if self.sent_community_to_neighbor is not None:
                                        return True

                                    if self.sent_extended_community_to_neighbor is not None:
                                        return True

                                    if self.sent_gshut_community_to_neighbor is not None:
                                        return True

                                    if self.stale_path_timeout is not None:
                                        return True

                                    if self.synced_acked_version is not None:
                                        return True

                                    if self.update_group_number is not None:
                                        return True

                                    if self.use_max_prefix_warning_only is not None:
                                        return True

                                    if self.vpn_update_gen_enabled is not None:
                                        return True

                                    if self.vpn_update_gen_trigger_enabled is not None:
                                        return True

                                    if self.weight is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.neighbor_address is None:
                                    raise YPYModelError('Key property neighbor_address is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address = ' + str(self.neighbor_address) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.neighbor_address is not None:
                                    return True

                                if self.active_bmp_servers is not None:
                                    return True

                                if self.actual_last_write_bytes is not None:
                                    return True

                                if self.actual_last_write_reset_bytes is not None:
                                    return True

                                if self.actual_second_last_write_bytes is not None:
                                    return True

                                if self.actual_second_last_write_reset_bytes is not None:
                                    return True

                                if self.af_data is not None:
                                    for child_ref in self.af_data:
                                        if child_ref._has_data():
                                            return True

                                if self.attempted_last_write_bytes is not None:
                                    return True

                                if self.attempted_last_write_reset_bytes is not None:
                                    return True

                                if self.attempted_second_last_write_bytes is not None:
                                    return True

                                if self.attempted_second_last_write_reset_bytes is not None:
                                    return True

                                if self.bfd_minintervalval is not None:
                                    return True

                                if self.bfd_multiplierval is not None:
                                    return True

                                if self.bfd_session_created_state is not None:
                                    return True

                                if self.bfd_session_enable_mode is not None:
                                    return True

                                if self.bfd_session_state is not None:
                                    return True

                                if self.bfd_state_ts is not None:
                                    return True

                                if self.bytes_read is not None:
                                    return True

                                if self.bytes_written is not None:
                                    return True

                                if self.configured_hold_time is not None:
                                    return True

                                if self.configured_keepalive is not None:
                                    return True

                                if self.configured_min_acc_hold_time is not None:
                                    return True

                                if self.connect_retry_interval is not None:
                                    return True

                                if self.connection_admin_status is not None:
                                    return True

                                if self.connection_down_count is not None:
                                    return True

                                if self.connection_established_time is not None:
                                    return True

                                if self.connection_local_address is not None and self.connection_local_address._has_data():
                                    return True

                                if self.connection_local_port is not None:
                                    return True

                                if self.connection_remote_address is not None and self.connection_remote_address._has_data():
                                    return True

                                if self.connection_remote_port is not None:
                                    return True

                                if self.connection_state is not None:
                                    return True

                                if self.connection_up_count is not None:
                                    return True

                                if self.count_last_write is not None:
                                    return True

                                if self.description is not None:
                                    return True

                                if self.discard_as4_path is not None:
                                    return True

                                if self.discard_data_bytes is not None:
                                    return True

                                if self.dmz_link_bandwidth is not None:
                                    return True

                                if self.dynamic_neighbor is not None:
                                    return True

                                if self.ebgp_recv_dmz is not None:
                                    return True

                                if self.ebgp_send_dmz_mode is not None:
                                    return True

                                if self.ebgp_time_to_live is not None:
                                    return True

                                if self.egress_peer_engineering_enabled is not None:
                                    return True

                                if self.error_notifies_received is not None:
                                    return True

                                if self.error_notifies_sent is not None:
                                    return True

                                if self.fpbsn_offset is not None:
                                    return True

                                if self.fssn_offset is not None:
                                    return True

                                if self.gr_restart_time is not None:
                                    return True

                                if self.gr_stale_path_time is not None:
                                    return True

                                if self.graceful_maintenance is not None and self.graceful_maintenance._has_data():
                                    return True

                                if self.graceful_restart_enabled_nbr is not None:
                                    return True

                                if self.has_internal_link is not None:
                                    return True

                                if self.hold_time is not None:
                                    return True

                                if self.ignore_connected is not None:
                                    return True

                                if self.internal_vpn_client is not None:
                                    return True

                                if self.io_armed is not None:
                                    return True

                                if self.is4_byte_as_capability_received is not None:
                                    return True

                                if self.is4_byte_as_capability_sent is not None:
                                    return True

                                if self.is_administratively_shut_down is not None:
                                    return True

                                if self.is_capability_negotiation_performed is not None:
                                    return True

                                if self.is_capability_negotiation_suppressed is not None:
                                    return True

                                if self.is_ebgp_multihop_bgpmpls_forwarding_disabled is not None:
                                    return True

                                if self.is_ebgp_peer_as_league is not None:
                                    return True

                                if self.is_ebgp_peer_common_admin is not None:
                                    return True

                                if self.is_external_neighbor_not_directly_connected is not None:
                                    return True

                                if self.is_gr_aware is not None:
                                    return True

                                if self.is_local_address_configured is not None:
                                    return True

                                if self.is_neighbor_max_prefix_shutdown is not None:
                                    return True

                                if self.is_out_of_memory_forced_up is not None:
                                    return True

                                if self.is_out_of_memory_shutdown is not None:
                                    return True

                                if self.is_passive_close is not None:
                                    return True

                                if self.is_read_disabled is not None:
                                    return True

                                if self.is_route_refresh_capability_received is not None:
                                    return True

                                if self.is_route_refresh_old_capability_received is not None:
                                    return True

                                if self.keep_alive_time is not None:
                                    return True

                                if self.last_ackd_seq_no is not None:
                                    return True

                                if self.last_k_aerror_reset is not None:
                                    return True

                                if self.last_k_aexpiry_reset is not None:
                                    return True

                                if self.last_k_anotsent_reset is not None:
                                    return True

                                if self.last_k_astart_reset is not None:
                                    return True

                                if self.last_notify_error_code is not None:
                                    return True

                                if self.last_notify_error_subcode is not None:
                                    return True

                                if self.last_write_event is not None:
                                    return True

                                if self.local_as is not None:
                                    return True

                                if self.local_as_dual_as is not None:
                                    return True

                                if self.local_as_dual_as_mode_native is not None:
                                    return True

                                if self.local_as_no_prepend is not None:
                                    return True

                                if self.local_as_replace_as is not None:
                                    return True

                                if self.message_statistics is not None and self.message_statistics._has_data():
                                    return True

                                if self.messages_queued_in is not None:
                                    return True

                                if self.messages_queued_out is not None:
                                    return True

                                if self.messages_received is not None:
                                    return True

                                if self.messages_sent is not None:
                                    return True

                                if self.min_advertise_interval is not None:
                                    return True

                                if self.min_advertise_interval_msecs is not None:
                                    return True

                                if self.min_origination_interval is not None:
                                    return True

                                if self.msg_log_in is not None:
                                    return True

                                if self.msg_log_out is not None:
                                    return True

                                if self.multi_protocol_capability_received is not None:
                                    return True

                                if self.nbr_cluster_id is not None:
                                    return True

                                if self.nbr_enforce_first_as is not None:
                                    return True

                                if self.nbr_in_cluster is not None:
                                    return True

                                if self.negotiated_protocol_version is not None:
                                    return True

                                if self.neighbor_interface_handle is not None:
                                    return True

                                if self.neighbor_local_as is not None:
                                    return True

                                if self.nsr_enabled is not None:
                                    return True

                                if self.nsr_state is not None:
                                    return True

                                if self.open_check_error_code is not None:
                                    return True

                                if self.peer_error_code is not None:
                                    return True

                                if self.peer_reset_reason is not None:
                                    return True

                                if self.performance_statistics is not None and self.performance_statistics._has_data():
                                    return True

                                if self.previous_connection_state is not None:
                                    return True

                                if self.read_armed is not None:
                                    return True

                                if self.received_notification_info is not None and self.received_notification_info._has_data():
                                    return True

                                if self.remote_as is not None:
                                    return True

                                if self.remote_as_number is not None:
                                    return True

                                if self.reset_notification_sent is not None:
                                    return True

                                if self.reset_reason is not None:
                                    return True

                                if self.router_id is not None:
                                    return True

                                if self.rpki_allow_invalid is not None:
                                    return True

                                if self.rpki_disable is not None:
                                    return True

                                if self.rpki_signal_ibgp is not None:
                                    return True

                                if self.rpki_use_validity is not None:
                                    return True

                                if self.second_last_k_aexpiry_reset is not None:
                                    return True

                                if self.second_last_k_astart_reset is not None:
                                    return True

                                if self.second_last_write_event is not None:
                                    return True

                                if self.send_notification_info is not None and self.send_notification_info._has_data():
                                    return True

                                if self.socket_read_bytes is not None:
                                    return True

                                if self.speaker_id is not None:
                                    return True

                                if self.standby_rp is not None:
                                    return True

                                if self.suppress4_byte_as is not None:
                                    return True

                                if self.tcp_init_sync_done_time_spec is not None and self.tcp_init_sync_done_time_spec._has_data():
                                    return True

                                if self.tcp_init_sync_phase_two_time_spec is not None and self.tcp_init_sync_phase_two_time_spec._has_data():
                                    return True

                                if self.tcp_init_sync_time_spec is not None and self.tcp_init_sync_time_spec._has_data():
                                    return True

                                if self.tcp_session_open_mode is not None:
                                    return True

                                if self.tcpmss is not None:
                                    return True

                                if self.time_last_cb is not None:
                                    return True

                                if self.time_last_cb_reset is not None:
                                    return True

                                if self.time_last_fb is not None:
                                    return True

                                if self.time_since_connection_last_dropped is not None:
                                    return True

                                if self.time_since_last_read is not None:
                                    return True

                                if self.time_since_last_read_reset is not None:
                                    return True

                                if self.time_since_last_update is not None:
                                    return True

                                if self.time_since_last_write is not None:
                                    return True

                                if self.time_since_last_write_reset is not None:
                                    return True

                                if self.time_since_second_last_write is not None:
                                    return True

                                if self.time_since_second_last_write_reset is not None:
                                    return True

                                if self.tos_type is not None:
                                    return True

                                if self.tos_value is not None:
                                    return True

                                if self.ttl_security_enabled is not None:
                                    return True

                                if self.update_bytes_read is not None:
                                    return True

                                if self.update_messages_in is not None:
                                    return True

                                if self.update_messages_out is not None:
                                    return True

                                if self.vrf_name is not None:
                                    return True

                                if self.write_armed is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbors'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.neighbor is not None:
                                for child_ref in self.neighbor:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors']['meta_info']


                    class NextHopVrf(object):
                        """
                        A BGP Next\-hop VRF table entry
                        
                        .. attribute:: last_notification_processing_time
                        
                        	Processing time for the last notification
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_notificationication_time
                        
                        	Time since the last notification was received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_notification_bestpath_changes
                        
                        	Number of bestpath changes caused by notification which resulted in maximum processing
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_notification_bestpath_deletes
                        
                        	Number of bestpath deletes caused by notification which resulted in maximum processing
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_proc_notification_time
                        
                        	How long since the maximum processing time notifcation was received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: maximum_processing_time
                        
                        	Maximum time spent procesing a single batch notification
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_processing_time
                        
                        	Total time spent in processing
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.last_notification_processing_time = None
                            self.last_notificationication_time = None
                            self.max_notification_bestpath_changes = None
                            self.max_notification_bestpath_deletes = None
                            self.max_proc_notification_time = None
                            self.maximum_processing_time = None
                            self.total_processing_time = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:next-hop-vrf'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.last_notification_processing_time is not None:
                                return True

                            if self.last_notificationication_time is not None:
                                return True

                            if self.max_notification_bestpath_changes is not None:
                                return True

                            if self.max_notification_bestpath_deletes is not None:
                                return True

                            if self.max_proc_notification_time is not None:
                                return True

                            if self.maximum_processing_time is not None:
                                return True

                            if self.total_processing_time is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NextHopVrf']['meta_info']


                    class NeighborRanges(object):
                        """
                        The BGP Dynamic Neighbor Range table
                        
                        .. attribute:: neighbor_range
                        
                        	A BGP Neighbor Range table entry
                        	**type**\: list of    :py:class:`NeighborRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.neighbor_range = YList()
                            self.neighbor_range.parent = self
                            self.neighbor_range.name = 'neighbor_range'


                        class NeighborRange(object):
                            """
                            A BGP Neighbor Range table entry
                            
                            .. attribute:: neighbor_range_address  <key>
                            
                            	Neighbor Range prefix
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            
                            ----
                            .. attribute:: active_bmp_servers
                            
                            	BMP Servers to which the neighbor sends logs
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: addpath_receive_disable
                            
                            	Addpath Receive Disabled
                            	**type**\:  bool
                            
                            .. attribute:: addpath_receive_enable
                            
                            	Addpath Receive enable
                            	**type**\:  bool
                            
                            .. attribute:: addpath_send_disable
                            
                            	Addpath Send Disabled
                            	**type**\:  bool
                            
                            .. attribute:: addpath_send_enable
                            
                            	Addpath Send enabled
                            	**type**\:  bool
                            
                            .. attribute:: af_data
                            
                            	Address family specific neighbor data
                            	**type**\: list of    :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.AfData>`
                            
                            .. attribute:: attrf_group_name
                            
                            	Attrf Group Name
                            	**type**\:  str
                            
                            .. attribute:: bfd_minintervalval
                            
                            	BFD Mininterval for this peer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_multiplierval
                            
                            	BFD Multiplier for this peer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_session_enable_mode
                            
                            	BFD enable mode for this peer
                            	**type**\:   :py:class:`BgpBfdEnableModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdEnableModeEnum>`
                            
                            .. attribute:: cfg_local_address
                            
                            	Configured local address
                            	**type**\:   :py:class:`CfgLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress>`
                            
                            .. attribute:: configured_hold_time
                            
                            	Hold time (in secs) configured for this connection
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: configured_keepalive
                            
                            	Keepalive time (in secs) configured for this connection
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: configured_min_acc_hold_time
                            
                            	Minimum acceptable hold time from neighbor (in secs) configured for this connection
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: connection_local_address
                            
                            	Local address for the connection
                            	**type**\:   :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress>`
                            
                            .. attribute:: connection_remote_address
                            
                            	Remote address for the connection
                            	**type**\:   :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress>`
                            
                            .. attribute:: current_peers
                            
                            	Current Dynamic nbrs in range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: description
                            
                            	Description
                            	**type**\:  str
                            
                            .. attribute:: discard_as4_path
                            
                            	Discard AS4\_PATH in case there is a discrepancy in merging AS\_PATH and AS4\_PATH,retain ASPATH
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: dmz_link_bandwidth
                            
                            	Bandwidth of link to single\-hop eBGP peer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ebgp_recv_dmz
                            
                            	Receive Bandwidth of link to single\-hop eBGP peer
                            	**type**\:  bool
                            
                            .. attribute:: ebgp_send_dmz_mode
                            
                            	Ebgp send dmz link bw mode
                            	**type**\:   :py:class:`BgpEbgpSendDmzEnableModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableModeEnum>`
                            
                            .. attribute:: ebgp_time_to_live
                            
                            	Maximum number of hops for external BGP neighbor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: egress_peer_engineering_enabled
                            
                            	Indicates if Egress Peer Engineering is enabled
                            	**type**\:  bool
                            
                            .. attribute:: gr_restart_time
                            
                            	Neighbor restart time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: gr_stale_path_time
                            
                            	Neighbor stale\-path time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: graceful_maintenance
                            
                            	Graceful Maintenance
                            	**type**\:   :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.GracefulMaintenance>`
                            
                            .. attribute:: graceful_restart_enabled_nbr
                            
                            	Neighbor supports graceful\-restart
                            	**type**\:  bool
                            
                            .. attribute:: has_internal_link
                            
                            	Internal link to neighbor
                            	**type**\:  bool
                            
                            .. attribute:: idle_watch_time
                            
                            	Dynamic Neighbor idle\-watch time (in seconds)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: ignore_connected
                            
                            	If true, the VPN client isan IBGP CE peer
                            	**type**\:  bool
                            
                            .. attribute:: instance
                            
                            	Dynamic Neighbor Instance List
                            	**type**\: list of    :py:class:`Instance_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_>`
                            
                            .. attribute:: internal_vpn_client
                            
                            	If true, don't do NHconnected check for nbr
                            	**type**\:  bool
                            
                            .. attribute:: is_administratively_shut_down
                            
                            	Neighbor is administratively shut down
                            	**type**\:  bool
                            
                            .. attribute:: is_capability_negotiation_performed
                            
                            	Capability negotiation performed
                            	**type**\:  bool
                            
                            .. attribute:: is_ebgp_multihop_bgpmpls_forwarding_disabled
                            
                            	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_local_address_configured
                            
                            	Local address configured for the neighbor connection
                            	**type**\:  bool
                            
                            .. attribute:: is_neighbor_max_prefix_shutdown
                            
                            	Neighbor shut down because it exceeded max prfx count
                            	**type**\:  bool
                            
                            .. attribute:: is_out_of_memory_forced_up
                            
                            	Neighbor forced up during a low memory condition
                            	**type**\:  bool
                            
                            .. attribute:: is_passive_close
                            
                            	If true, active socket canbe closed if passive openis received for a GRcapable neighbor
                            	**type**\:  bool
                            
                            .. attribute:: islocal_address_cfg
                            
                            	Local address configured
                            	**type**\:  bool
                            
                            .. attribute:: local_as
                            
                            	Local AS number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_as_dual_as
                            
                            	Local AS Dual\-AS option
                            	**type**\:  bool
                            
                            .. attribute:: local_as_dual_as_mode_native
                            
                            	Applies only if Local AS Dual\-AS option is enabled. Indicates if Dual\-AS mode is native
                            	**type**\:  bool
                            
                            .. attribute:: local_as_no_prepend
                            
                            	Option to not prepend the Local AS to announcements
                            	**type**\:  bool
                            
                            .. attribute:: local_as_replace_as
                            
                            	Local AS Replace\-AS option
                            	**type**\:  bool
                            
                            .. attribute:: max_peers
                            
                            	Max Dynamic nbrs in range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: min_advertise_interval
                            
                            	Minimum advertisement interval, secs part
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: min_advertise_interval_msecs
                            
                            	Minimum advertisement interval, msecs part
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: millisecond
                            
                            .. attribute:: min_origination_interval
                            
                            	Minimum origination interval (in secs)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: msg_buf_count
                            
                            	Message Buf Count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msg_bug_circular
                            
                            	Message Buf Circular
                            	**type**\:  bool
                            
                            .. attribute:: msg_log_in
                            
                            	Message in log count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msg_log_out
                            
                            	Message out log count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nbr_cluster_id
                            
                            	Cluster id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nbr_enforce_first_as
                            
                            	Neighbor enforce first AS
                            	**type**\:  bool
                            
                            .. attribute:: nbr_in_cluster
                            
                            	Type of cluster\_id\:undefined/number/Ip address
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: nbr_rcv_size
                            
                            	Nbr Receive Size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nbr_send_size
                            
                            	Nbr Send Size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_local_as
                            
                            	Local AS configured on the neighbor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_range_prefix_length
                            
                            	Neighbor Range Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: nsr_enabled
                            
                            	Neighbor supports NSR
                            	**type**\:  bool
                            
                            .. attribute:: oper_attrf_enable
                            
                            	Oper attrf Enable
                            	**type**\:  bool
                            
                            .. attribute:: range_inst_error
                            
                            	Error during instance creation
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: range_max_drop
                            
                            	open drop due to max peers
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: range_open_accepted
                            
                            	open accepted
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: range_open_match
                            
                            	Passive open matching range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_as
                            
                            	Remote AS number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_as_list_name
                            
                            	Remote AS List Name
                            	**type**\:  str
                            
                            .. attribute:: remote_as_number
                            
                            	Remote AS number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rpki_allow_invalid
                            
                            	Prefix v. allow invalid
                            	**type**\:  bool
                            
                            .. attribute:: rpki_disable
                            
                            	Prefix validation disabled
                            	**type**\:  bool
                            
                            .. attribute:: rpki_signal_ibgp
                            
                            	Prefix v. signal ibgp
                            	**type**\:  bool
                            
                            .. attribute:: rpki_use_validity
                            
                            	Prefix v. use validity
                            	**type**\:  bool
                            
                            .. attribute:: speaker_id
                            
                            	Speaker this neighbor is allocated to
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: standby_rp
                            
                            	Standby RP socket inited for Active Open
                            	**type**\:  bool
                            
                            .. attribute:: suppress4_byte_as
                            
                            	Suppress 4byteas capability
                            	**type**\:  bool
                            
                            .. attribute:: syslog_enable
                            
                            	syslog enable
                            	**type**\:  bool
                            
                            .. attribute:: tcp_session_open_mode
                            
                            	The TCP mode to be used to set up BGP session with the neighbor
                            	**type**\:   :py:class:`BgpTcpModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpModeEnum>`
                            
                            .. attribute:: tcpmss
                            
                            	Neighbor TCP Maximum Segment                     size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tos_type
                            
                            	Precedence or DSCP type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tos_value
                            
                            	Precedence or DSCP value
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ttl_security_enabled
                            
                            	TTL Security enabled
                            	**type**\:  bool
                            
                            .. attribute:: upd_errh_noreset
                            
                            	Update errh noreset
                            	**type**\:  bool
                            
                            .. attribute:: update_source
                            
                            	Update Source
                            	**type**\:  str
                            
                            .. attribute:: vrf_name
                            
                            	Name of the VRF
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.neighbor_range_address = None
                                self.active_bmp_servers = None
                                self.addpath_receive_disable = None
                                self.addpath_receive_enable = None
                                self.addpath_send_disable = None
                                self.addpath_send_enable = None
                                self.af_data = YList()
                                self.af_data.parent = self
                                self.af_data.name = 'af_data'
                                self.attrf_group_name = None
                                self.bfd_minintervalval = None
                                self.bfd_multiplierval = None
                                self.bfd_session_enable_mode = None
                                self.cfg_local_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress()
                                self.cfg_local_address.parent = self
                                self.configured_hold_time = None
                                self.configured_keepalive = None
                                self.configured_min_acc_hold_time = None
                                self.connection_local_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress()
                                self.connection_local_address.parent = self
                                self.connection_remote_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress()
                                self.connection_remote_address.parent = self
                                self.current_peers = None
                                self.description = None
                                self.discard_as4_path = None
                                self.dmz_link_bandwidth = None
                                self.ebgp_recv_dmz = None
                                self.ebgp_send_dmz_mode = None
                                self.ebgp_time_to_live = None
                                self.egress_peer_engineering_enabled = None
                                self.gr_restart_time = None
                                self.gr_stale_path_time = None
                                self.graceful_maintenance = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.GracefulMaintenance()
                                self.graceful_maintenance.parent = self
                                self.graceful_restart_enabled_nbr = None
                                self.has_internal_link = None
                                self.idle_watch_time = None
                                self.ignore_connected = None
                                self.instance = YList()
                                self.instance.parent = self
                                self.instance.name = 'instance'
                                self.internal_vpn_client = None
                                self.is_administratively_shut_down = None
                                self.is_capability_negotiation_performed = None
                                self.is_ebgp_multihop_bgpmpls_forwarding_disabled = None
                                self.is_local_address_configured = None
                                self.is_neighbor_max_prefix_shutdown = None
                                self.is_out_of_memory_forced_up = None
                                self.is_passive_close = None
                                self.islocal_address_cfg = None
                                self.local_as = None
                                self.local_as_dual_as = None
                                self.local_as_dual_as_mode_native = None
                                self.local_as_no_prepend = None
                                self.local_as_replace_as = None
                                self.max_peers = None
                                self.min_advertise_interval = None
                                self.min_advertise_interval_msecs = None
                                self.min_origination_interval = None
                                self.msg_buf_count = None
                                self.msg_bug_circular = None
                                self.msg_log_in = None
                                self.msg_log_out = None
                                self.nbr_cluster_id = None
                                self.nbr_enforce_first_as = None
                                self.nbr_in_cluster = None
                                self.nbr_rcv_size = None
                                self.nbr_send_size = None
                                self.neighbor_local_as = None
                                self.neighbor_range_prefix_length = None
                                self.nsr_enabled = None
                                self.oper_attrf_enable = None
                                self.range_inst_error = None
                                self.range_max_drop = None
                                self.range_open_accepted = None
                                self.range_open_match = None
                                self.remote_as = None
                                self.remote_as_list_name = None
                                self.remote_as_number = None
                                self.rpki_allow_invalid = None
                                self.rpki_disable = None
                                self.rpki_signal_ibgp = None
                                self.rpki_use_validity = None
                                self.speaker_id = None
                                self.standby_rp = None
                                self.suppress4_byte_as = None
                                self.syslog_enable = None
                                self.tcp_session_open_mode = None
                                self.tcpmss = None
                                self.tos_type = None
                                self.tos_value = None
                                self.ttl_security_enabled = None
                                self.upd_errh_noreset = None
                                self.update_source = None
                                self.vrf_name = None


                            class ConnectionLocalAddress(object):
                                """
                                Local address for the connection
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpnvpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnvplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4mdt_address = None
                                    self.ipv4mvpn_address = None
                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                    self.ipv4sr_policy_address.parent = self
                                    self.ipv4vpn_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                    self.ipv6sr_policy_address.parent = self
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_flowspec_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.l2vpn_evpn_address = None
                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnvplsAddress()
                                    self.l2vpnvpls_address.parent = self
                                    self.ls_ls_address = None
                                    self.rt_constraint_address = None


                                class L2VpnvplsAddress(object):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnvplsAddress']['meta_info']


                                class L2VpnMspwAddress(object):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2VpnMspwAddress']['meta_info']


                                class Ipv4SrPolicyAddress(object):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress']['meta_info']


                                class Ipv6SrPolicyAddress(object):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv6_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv6_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connection-local-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.afi is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv4_flowspec_address is not None:
                                        return True

                                    if self.ipv4_label_address is not None:
                                        return True

                                    if self.ipv4_mcast_address is not None:
                                        return True

                                    if self.ipv4_tunnel_address is not None:
                                        return True

                                    if self.ipv4mdt_address is not None:
                                        return True

                                    if self.ipv4mvpn_address is not None:
                                        return True

                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                        return True

                                    if self.ipv4vpn_address is not None:
                                        return True

                                    if self.ipv4vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv4vpna_mcastddress is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    if self.ipv6_flowspec_address is not None:
                                        return True

                                    if self.ipv6_label_address is not None:
                                        return True

                                    if self.ipv6_mcast_address is not None:
                                        return True

                                    if self.ipv6mvpn_address is not None:
                                        return True

                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                        return True

                                    if self.ipv6vpn_address is not None:
                                        return True

                                    if self.ipv6vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv6vpn_mcast_address is not None:
                                        return True

                                    if self.l2vpn_evpn_address is not None:
                                        return True

                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                        return True

                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                        return True

                                    if self.ls_ls_address is not None:
                                        return True

                                    if self.rt_constraint_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress']['meta_info']


                            class ConnectionRemoteAddress(object):
                                """
                                Remote address for the connection
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpnvpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnvplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4mdt_address = None
                                    self.ipv4mvpn_address = None
                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                    self.ipv4sr_policy_address.parent = self
                                    self.ipv4vpn_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                    self.ipv6sr_policy_address.parent = self
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_flowspec_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.l2vpn_evpn_address = None
                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnvplsAddress()
                                    self.l2vpnvpls_address.parent = self
                                    self.ls_ls_address = None
                                    self.rt_constraint_address = None


                                class L2VpnvplsAddress(object):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnvplsAddress']['meta_info']


                                class L2VpnMspwAddress(object):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2VpnMspwAddress']['meta_info']


                                class Ipv4SrPolicyAddress(object):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress']['meta_info']


                                class Ipv6SrPolicyAddress(object):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv6_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv6_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connection-remote-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.afi is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv4_flowspec_address is not None:
                                        return True

                                    if self.ipv4_label_address is not None:
                                        return True

                                    if self.ipv4_mcast_address is not None:
                                        return True

                                    if self.ipv4_tunnel_address is not None:
                                        return True

                                    if self.ipv4mdt_address is not None:
                                        return True

                                    if self.ipv4mvpn_address is not None:
                                        return True

                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                        return True

                                    if self.ipv4vpn_address is not None:
                                        return True

                                    if self.ipv4vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv4vpna_mcastddress is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    if self.ipv6_flowspec_address is not None:
                                        return True

                                    if self.ipv6_label_address is not None:
                                        return True

                                    if self.ipv6_mcast_address is not None:
                                        return True

                                    if self.ipv6mvpn_address is not None:
                                        return True

                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                        return True

                                    if self.ipv6vpn_address is not None:
                                        return True

                                    if self.ipv6vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv6vpn_mcast_address is not None:
                                        return True

                                    if self.l2vpn_evpn_address is not None:
                                        return True

                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                        return True

                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                        return True

                                    if self.ls_ls_address is not None:
                                        return True

                                    if self.rt_constraint_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress']['meta_info']


                            class GracefulMaintenance(object):
                                """
                                Graceful Maintenance
                                
                                .. attribute:: gshut_active
                                
                                	Graceful Maintenance activated
                                	**type**\:  bool
                                
                                .. attribute:: gshut_exists
                                
                                	Graceful Maintenance enabled
                                	**type**\:  bool
                                
                                .. attribute:: gshut_local_active
                                
                                	Graceful Maintenance locally activated
                                	**type**\:  bool
                                
                                .. attribute:: gshut_locpref
                                
                                	Graceful Maintenance Local Preference
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: gshut_locpref_set
                                
                                	Graceful Maintenance Local Preference set
                                	**type**\:  bool
                                
                                .. attribute:: gshut_prepends
                                
                                	Graceful Maintenance number of AS prepends
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.gshut_active = None
                                    self.gshut_exists = None
                                    self.gshut_local_active = None
                                    self.gshut_locpref = None
                                    self.gshut_locpref_set = None
                                    self.gshut_prepends = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:graceful-maintenance'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.gshut_active is not None:
                                        return True

                                    if self.gshut_exists is not None:
                                        return True

                                    if self.gshut_local_active is not None:
                                        return True

                                    if self.gshut_locpref is not None:
                                        return True

                                    if self.gshut_locpref_set is not None:
                                        return True

                                    if self.gshut_prepends is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.GracefulMaintenance']['meta_info']


                            class CfgLocalAddress(object):
                                """
                                Configured local address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpnvpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnvplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4mdt_address = None
                                    self.ipv4mvpn_address = None
                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress()
                                    self.ipv4sr_policy_address.parent = self
                                    self.ipv4vpn_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress()
                                    self.ipv6sr_policy_address.parent = self
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_flowspec_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.l2vpn_evpn_address = None
                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnvplsAddress()
                                    self.l2vpnvpls_address.parent = self
                                    self.ls_ls_address = None
                                    self.rt_constraint_address = None


                                class L2VpnvplsAddress(object):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnvplsAddress']['meta_info']


                                class L2VpnMspwAddress(object):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2VpnMspwAddress']['meta_info']


                                class Ipv4SrPolicyAddress(object):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress']['meta_info']


                                class Ipv6SrPolicyAddress(object):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv6_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv6_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cfg-local-address'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.afi is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv4_flowspec_address is not None:
                                        return True

                                    if self.ipv4_label_address is not None:
                                        return True

                                    if self.ipv4_mcast_address is not None:
                                        return True

                                    if self.ipv4_tunnel_address is not None:
                                        return True

                                    if self.ipv4mdt_address is not None:
                                        return True

                                    if self.ipv4mvpn_address is not None:
                                        return True

                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                        return True

                                    if self.ipv4vpn_address is not None:
                                        return True

                                    if self.ipv4vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv4vpna_mcastddress is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    if self.ipv6_flowspec_address is not None:
                                        return True

                                    if self.ipv6_label_address is not None:
                                        return True

                                    if self.ipv6_mcast_address is not None:
                                        return True

                                    if self.ipv6mvpn_address is not None:
                                        return True

                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                        return True

                                    if self.ipv6vpn_address is not None:
                                        return True

                                    if self.ipv6vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv6vpn_mcast_address is not None:
                                        return True

                                    if self.l2vpn_evpn_address is not None:
                                        return True

                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                        return True

                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                        return True

                                    if self.ls_ls_address is not None:
                                        return True

                                    if self.rt_constraint_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress']['meta_info']


                            class AfData(object):
                                """
                                Address family specific neighbor data
                                
                                .. attribute:: accept_own_enabled
                                
                                	Accept\-Own enabled
                                	**type**\:  bool
                                
                                .. attribute:: address_family_long_lived_time
                                
                                	AF specific Long\-lived\-time config
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: advertise_afi
                                
                                	Encode in Advertise AFI
                                	**type**\:  bool
                                
                                .. attribute:: advertise_afi_disable
                                
                                	Encode in Advertise AFI
                                	**type**\:  bool
                                
                                .. attribute:: advertise_afi_local
                                
                                	Encode in Advertise AFI
                                	**type**\:  bool
                                
                                .. attribute:: advertise_afi_reorg
                                
                                	Encode in Advertise AFI
                                	**type**\:  bool
                                
                                .. attribute:: advertise_v4_flags
                                
                                	Advertise options for VPNV4
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: advertise_v6_flags
                                
                                	Advertise options for VPNV6
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: af_name
                                
                                	Address family identifier
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: afrpki_allow_invalid
                                
                                	Prefix v. allow invalid
                                	**type**\:  bool
                                
                                .. attribute:: afrpki_disable
                                
                                	Prefix validation disabled
                                	**type**\:  bool
                                
                                .. attribute:: afrpki_signal_ibgp
                                
                                	Prefix v. signal ibgp
                                	**type**\:  bool
                                
                                .. attribute:: afrpki_use_validity
                                
                                	Prefix v. use validity
                                	**type**\:  bool
                                
                                .. attribute:: allow_as_in_count
                                
                                	Allowas\-in count config
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: always_use_next_hop_local
                                
                                	Local router always used for next\-hop
                                	**type**\:  bool
                                
                                .. attribute:: extended_community
                                
                                	Extended community attribute
                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity>`
                                
                                .. attribute:: extended_community_standby
                                
                                	Extended community attribute
                                	**type**\: list of    :py:class:`ExtendedCommunityStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby>`
                                
                                .. attribute:: flowspec_redirect_validation_d_isable
                                
                                	Flowspec Redirect Validation Disabled
                                	**type**\:  bool
                                
                                .. attribute:: flowspec_validation_d_isable
                                
                                	Flowspec Validation Disabled
                                	**type**\:  bool
                                
                                .. attribute:: import_reoriginate
                                
                                	Import Reoriginate enabled
                                	**type**\:  bool
                                
                                .. attribute:: import_reoriginate_stitching
                                
                                	Import Reoriginate Stitching enabled
                                	**type**\:  bool
                                
                                .. attribute:: import_stitching
                                
                                	Import Stitching enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_add_path_receive_capability_advertised
                                
                                	Addpath Receive capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_add_path_receive_capability_received
                                
                                	Addpath Receive capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_add_path_send_capability_advertised
                                
                                	Addpath Send capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_add_path_send_capability_received
                                
                                	Addpath Send capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_addpath_receive_operational
                                
                                	Addpath is operational on receive\-side
                                	**type**\:  bool
                                
                                .. attribute:: is_addpath_send_operational
                                
                                	Addpath is operational on send\-side
                                	**type**\:  bool
                                
                                .. attribute:: is_advertise_permanent_network
                                
                                	Advertise Permanent Network
                                	**type**\:  bool
                                
                                .. attribute:: is_advertised_graceful_restart
                                
                                	Graceful Restart Capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_advertised_orf_receive
                                
                                	Prefix based ORF receive mode capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_advertised_orf_send
                                
                                	Prefix based ORF send mode capability advertised
                                	**type**\:  bool
                                
                                .. attribute:: is_aigp_set
                                
                                	AIGP set 
                                	**type**\:  bool
                                
                                .. attribute:: is_allow_as_in_set
                                
                                	Allowas\-in set 
                                	**type**\:  bool
                                
                                .. attribute:: is_as_override_set
                                
                                	As override set 
                                	**type**\:  bool
                                
                                .. attribute:: is_graceful_restart_state_flag
                                
                                	Restart state flag enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_legacy_pe_rt
                                
                                	Nbr accepts route from legacy PE for RT\-Constraint AF 
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_af_capable
                                
                                	Address family capability received from neighbor
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_ebgp_without_inbound_policy
                                
                                	eBGP neighbor with no configured inbound policy
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_ebgp_without_outbound_policy
                                
                                	eBGP neighbor with no configured outbound policy
                                	**type**\:  bool
                                
                                .. attribute:: is_neighbor_route_reflector_client
                                
                                	Nbr is a route reflector client
                                	**type**\:  bool
                                
                                .. attribute:: is_orf_send_scheduled
                                
                                	Scheduled to send prefix based ORF
                                	**type**\:  bool
                                
                                .. attribute:: is_orf_sent
                                
                                	Outbound route filter sent to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: is_orr_root_address_configured
                                
                                	ORR Root address configuredfor the neighbor connection
                                	**type**\:  bool
                                
                                .. attribute:: is_peer_orf_capable
                                
                                	Peer has outbound route filter capability
                                	**type**\:  bool
                                
                                .. attribute:: is_prefix_orf_present
                                
                                	Outbound route filter prefix ORF present
                                	**type**\:  bool
                                
                                .. attribute:: is_received_graceful_restart_capable
                                
                                	Graceful Restart Capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_received_orf_receive_capable
                                
                                	Prefix based ORF receive mode capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_received_orf_send_capable
                                
                                	Prefix based ORF send mode capability received
                                	**type**\:  bool
                                
                                .. attribute:: is_rt_present
                                
                                	RT attribute list present
                                	**type**\:  bool
                                
                                .. attribute:: is_rt_present_standby
                                
                                	RT attribute list present
                                	**type**\:  bool
                                
                                .. attribute:: is_send_mcast_attr
                                
                                	Send Mcast Attr
                                	**type**\:  bool
                                
                                .. attribute:: is_soft_reconfiguration_inbound_allowed
                                
                                	Inbound soft reconfiguration allowed
                                	**type**\:  bool
                                
                                .. attribute:: is_update_deferred
                                
                                	Update deferred until ORF/route refresh received
                                	**type**\:  bool
                                
                                .. attribute:: is_use_soft_reconfiguration_always_on
                                
                                	Soft reconf overrides route refresh
                                	**type**\:  bool
                                
                                .. attribute:: local_restart_time
                                
                                	Local Restart time (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: long_lived_graceful_restart_capability_received
                                
                                	Long\-lived graceful\-restart capability received from the neighbor
                                	**type**\:  bool
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_accept
                                
                                	Maximum long\-lived graceful\-restart stale time acceptable from the neighbor (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_configured
                                
                                	Long\-lived graceful\-restart stale time is configured
                                	**type**\:  bool
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_received
                                
                                	Long\-lived graceful\-restart stale time received from the neighbor (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_sent
                                
                                	Stale time sent in long\-lived graceful\-restart capability (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: max_prefix_discard_extra_paths
                                
                                	Discard extra paths when prefix limit reached
                                	**type**\:  bool
                                
                                .. attribute:: max_prefix_exceed_discard_paths
                                
                                	Did we discard extra paths when prefix limit reached
                                	**type**\:  bool
                                
                                .. attribute:: max_prefix_limit
                                
                                	Max limit for # of prefixes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max_prefix_restart_time
                                
                                	Time interval (in minutes) after which peering session will be reestablished
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: minute
                                
                                .. attribute:: max_prefix_threshold_percent
                                
                                	Percentage of maximum no. of prefixes at which to generate warning
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: percentage
                                
                                .. attribute:: neighbor_default_originate
                                
                                	Neighbor originates default
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_long_lived_graceful_restart_capable
                                
                                	Treat neighbor as long\-lived graceful\-restart capable
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_long_lived_graceful_restart_time_remaining
                                
                                	Remaining long\-lived graceful\-restart time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_preserved_forwarding_state
                                
                                	Neighbor preserved forwarding state
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_preserved_long_lived_forwarding_state
                                
                                	Neighbor preserved long\-lived forwarding state
                                	**type**\:  bool
                                
                                .. attribute:: next_hop_unchanged
                                
                                	router does not change next\-hop
                                	**type**\:  bool
                                
                                .. attribute:: orf_entries_received
                                
                                	Number of outbound route filter entries received
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: orr_group_index
                                
                                	ORR Group Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: orr_group_name
                                
                                	ORR Group Name
                                	**type**\:  str
                                
                                .. attribute:: remove_private_as_entire_aspath_from_inbound_updates
                                
                                	Private AS numbers removed from updates from this nbr only if the aspath has only private ASes
                                	**type**\:  bool
                                
                                .. attribute:: remove_private_as_entire_aspath_from_updates
                                
                                	Private AS numbers removed from updates to thisnbr only if the aspath hasonly private ASes
                                	**type**\:  bool
                                
                                .. attribute:: remove_private_as_from_inbound_updates
                                
                                	Private AS numbers removed from updates from this nbr
                                	**type**\:  bool
                                
                                .. attribute:: remove_private_as_from_updates
                                
                                	Private AS numbers removed from updates to this nbr
                                	**type**\:  bool
                                
                                .. attribute:: restart_time
                                
                                	Restart time advertised (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: rib_purge_timeout_value
                                
                                	RIB purge timeout time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: route_policy_default_originate
                                
                                	Default\-originate route policy name
                                	**type**\:  str
                                
                                .. attribute:: route_policy_in
                                
                                	Incoming route policy name
                                	**type**\:  str
                                
                                .. attribute:: route_policy_out
                                
                                	Outgoing route policy name
                                	**type**\:  str
                                
                                .. attribute:: route_policy_prefix_orf
                                
                                	Prefix based ORF for incoming updates
                                	**type**\:  str
                                
                                .. attribute:: selective_multipath_eligible
                                
                                	Selective multipath eligible
                                	**type**\:  bool
                                
                                .. attribute:: sent_community_to_neighbor
                                
                                	Community attribute sent to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: sent_extended_community_to_neighbor
                                
                                	Extended community attribute sent to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: sent_gshut_community_to_neighbor
                                
                                	GSHUT Community attribute sent to neighbor
                                	**type**\:  bool
                                
                                .. attribute:: stale_path_timeout
                                
                                	Stale path timeout time (in seconds)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: use_max_prefix_warning_only
                                
                                	Warning only when maximum prefix limit reached
                                	**type**\:  bool
                                
                                .. attribute:: vpn_update_gen_enabled
                                
                                	RT Nbr enabled for updategento another
                                	**type**\:  bool
                                
                                .. attribute:: vpn_update_gen_trigger_enabled
                                
                                	RT Nbr enabled for updategento another
                                	**type**\:  bool
                                
                                .. attribute:: weight
                                
                                	Weight for this AF
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.accept_own_enabled = None
                                    self.address_family_long_lived_time = None
                                    self.advertise_afi = None
                                    self.advertise_afi_disable = None
                                    self.advertise_afi_local = None
                                    self.advertise_afi_reorg = None
                                    self.advertise_v4_flags = None
                                    self.advertise_v6_flags = None
                                    self.af_name = None
                                    self.afrpki_allow_invalid = None
                                    self.afrpki_disable = None
                                    self.afrpki_signal_ibgp = None
                                    self.afrpki_use_validity = None
                                    self.allow_as_in_count = None
                                    self.always_use_next_hop_local = None
                                    self.extended_community = YList()
                                    self.extended_community.parent = self
                                    self.extended_community.name = 'extended_community'
                                    self.extended_community_standby = YList()
                                    self.extended_community_standby.parent = self
                                    self.extended_community_standby.name = 'extended_community_standby'
                                    self.flowspec_redirect_validation_d_isable = None
                                    self.flowspec_validation_d_isable = None
                                    self.import_reoriginate = None
                                    self.import_reoriginate_stitching = None
                                    self.import_stitching = None
                                    self.is_add_path_receive_capability_advertised = None
                                    self.is_add_path_receive_capability_received = None
                                    self.is_add_path_send_capability_advertised = None
                                    self.is_add_path_send_capability_received = None
                                    self.is_addpath_receive_operational = None
                                    self.is_addpath_send_operational = None
                                    self.is_advertise_permanent_network = None
                                    self.is_advertised_graceful_restart = None
                                    self.is_advertised_orf_receive = None
                                    self.is_advertised_orf_send = None
                                    self.is_aigp_set = None
                                    self.is_allow_as_in_set = None
                                    self.is_as_override_set = None
                                    self.is_graceful_restart_state_flag = None
                                    self.is_legacy_pe_rt = None
                                    self.is_neighbor_af_capable = None
                                    self.is_neighbor_ebgp_without_inbound_policy = None
                                    self.is_neighbor_ebgp_without_outbound_policy = None
                                    self.is_neighbor_route_reflector_client = None
                                    self.is_orf_send_scheduled = None
                                    self.is_orf_sent = None
                                    self.is_orr_root_address_configured = None
                                    self.is_peer_orf_capable = None
                                    self.is_prefix_orf_present = None
                                    self.is_received_graceful_restart_capable = None
                                    self.is_received_orf_receive_capable = None
                                    self.is_received_orf_send_capable = None
                                    self.is_rt_present = None
                                    self.is_rt_present_standby = None
                                    self.is_send_mcast_attr = None
                                    self.is_soft_reconfiguration_inbound_allowed = None
                                    self.is_update_deferred = None
                                    self.is_use_soft_reconfiguration_always_on = None
                                    self.local_restart_time = None
                                    self.long_lived_graceful_restart_capability_received = None
                                    self.long_lived_graceful_restart_stale_time_accept = None
                                    self.long_lived_graceful_restart_stale_time_configured = None
                                    self.long_lived_graceful_restart_stale_time_received = None
                                    self.long_lived_graceful_restart_stale_time_sent = None
                                    self.max_prefix_discard_extra_paths = None
                                    self.max_prefix_exceed_discard_paths = None
                                    self.max_prefix_limit = None
                                    self.max_prefix_restart_time = None
                                    self.max_prefix_threshold_percent = None
                                    self.neighbor_default_originate = None
                                    self.neighbor_long_lived_graceful_restart_capable = None
                                    self.neighbor_long_lived_graceful_restart_time_remaining = None
                                    self.neighbor_preserved_forwarding_state = None
                                    self.neighbor_preserved_long_lived_forwarding_state = None
                                    self.next_hop_unchanged = None
                                    self.orf_entries_received = None
                                    self.orr_group_index = None
                                    self.orr_group_name = None
                                    self.remove_private_as_entire_aspath_from_inbound_updates = None
                                    self.remove_private_as_entire_aspath_from_updates = None
                                    self.remove_private_as_from_inbound_updates = None
                                    self.remove_private_as_from_updates = None
                                    self.restart_time = None
                                    self.rib_purge_timeout_value = None
                                    self.route_policy_default_originate = None
                                    self.route_policy_in = None
                                    self.route_policy_out = None
                                    self.route_policy_prefix_orf = None
                                    self.selective_multipath_eligible = None
                                    self.sent_community_to_neighbor = None
                                    self.sent_extended_community_to_neighbor = None
                                    self.sent_gshut_community_to_neighbor = None
                                    self.stale_path_timeout = None
                                    self.use_max_prefix_warning_only = None
                                    self.vpn_update_gen_enabled = None
                                    self.vpn_update_gen_trigger_enabled = None
                                    self.weight = None


                                class ExtendedCommunity(object):
                                    """
                                    Extended community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity']['meta_info']


                                class ExtendedCommunityStandby(object):
                                    """
                                    Extended community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community-standby'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:af-data'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.accept_own_enabled is not None:
                                        return True

                                    if self.address_family_long_lived_time is not None:
                                        return True

                                    if self.advertise_afi is not None:
                                        return True

                                    if self.advertise_afi_disable is not None:
                                        return True

                                    if self.advertise_afi_local is not None:
                                        return True

                                    if self.advertise_afi_reorg is not None:
                                        return True

                                    if self.advertise_v4_flags is not None:
                                        return True

                                    if self.advertise_v6_flags is not None:
                                        return True

                                    if self.af_name is not None:
                                        return True

                                    if self.afrpki_allow_invalid is not None:
                                        return True

                                    if self.afrpki_disable is not None:
                                        return True

                                    if self.afrpki_signal_ibgp is not None:
                                        return True

                                    if self.afrpki_use_validity is not None:
                                        return True

                                    if self.allow_as_in_count is not None:
                                        return True

                                    if self.always_use_next_hop_local is not None:
                                        return True

                                    if self.extended_community is not None:
                                        for child_ref in self.extended_community:
                                            if child_ref._has_data():
                                                return True

                                    if self.extended_community_standby is not None:
                                        for child_ref in self.extended_community_standby:
                                            if child_ref._has_data():
                                                return True

                                    if self.flowspec_redirect_validation_d_isable is not None:
                                        return True

                                    if self.flowspec_validation_d_isable is not None:
                                        return True

                                    if self.import_reoriginate is not None:
                                        return True

                                    if self.import_reoriginate_stitching is not None:
                                        return True

                                    if self.import_stitching is not None:
                                        return True

                                    if self.is_add_path_receive_capability_advertised is not None:
                                        return True

                                    if self.is_add_path_receive_capability_received is not None:
                                        return True

                                    if self.is_add_path_send_capability_advertised is not None:
                                        return True

                                    if self.is_add_path_send_capability_received is not None:
                                        return True

                                    if self.is_addpath_receive_operational is not None:
                                        return True

                                    if self.is_addpath_send_operational is not None:
                                        return True

                                    if self.is_advertise_permanent_network is not None:
                                        return True

                                    if self.is_advertised_graceful_restart is not None:
                                        return True

                                    if self.is_advertised_orf_receive is not None:
                                        return True

                                    if self.is_advertised_orf_send is not None:
                                        return True

                                    if self.is_aigp_set is not None:
                                        return True

                                    if self.is_allow_as_in_set is not None:
                                        return True

                                    if self.is_as_override_set is not None:
                                        return True

                                    if self.is_graceful_restart_state_flag is not None:
                                        return True

                                    if self.is_legacy_pe_rt is not None:
                                        return True

                                    if self.is_neighbor_af_capable is not None:
                                        return True

                                    if self.is_neighbor_ebgp_without_inbound_policy is not None:
                                        return True

                                    if self.is_neighbor_ebgp_without_outbound_policy is not None:
                                        return True

                                    if self.is_neighbor_route_reflector_client is not None:
                                        return True

                                    if self.is_orf_send_scheduled is not None:
                                        return True

                                    if self.is_orf_sent is not None:
                                        return True

                                    if self.is_orr_root_address_configured is not None:
                                        return True

                                    if self.is_peer_orf_capable is not None:
                                        return True

                                    if self.is_prefix_orf_present is not None:
                                        return True

                                    if self.is_received_graceful_restart_capable is not None:
                                        return True

                                    if self.is_received_orf_receive_capable is not None:
                                        return True

                                    if self.is_received_orf_send_capable is not None:
                                        return True

                                    if self.is_rt_present is not None:
                                        return True

                                    if self.is_rt_present_standby is not None:
                                        return True

                                    if self.is_send_mcast_attr is not None:
                                        return True

                                    if self.is_soft_reconfiguration_inbound_allowed is not None:
                                        return True

                                    if self.is_update_deferred is not None:
                                        return True

                                    if self.is_use_soft_reconfiguration_always_on is not None:
                                        return True

                                    if self.local_restart_time is not None:
                                        return True

                                    if self.long_lived_graceful_restart_capability_received is not None:
                                        return True

                                    if self.long_lived_graceful_restart_stale_time_accept is not None:
                                        return True

                                    if self.long_lived_graceful_restart_stale_time_configured is not None:
                                        return True

                                    if self.long_lived_graceful_restart_stale_time_received is not None:
                                        return True

                                    if self.long_lived_graceful_restart_stale_time_sent is not None:
                                        return True

                                    if self.max_prefix_discard_extra_paths is not None:
                                        return True

                                    if self.max_prefix_exceed_discard_paths is not None:
                                        return True

                                    if self.max_prefix_limit is not None:
                                        return True

                                    if self.max_prefix_restart_time is not None:
                                        return True

                                    if self.max_prefix_threshold_percent is not None:
                                        return True

                                    if self.neighbor_default_originate is not None:
                                        return True

                                    if self.neighbor_long_lived_graceful_restart_capable is not None:
                                        return True

                                    if self.neighbor_long_lived_graceful_restart_time_remaining is not None:
                                        return True

                                    if self.neighbor_preserved_forwarding_state is not None:
                                        return True

                                    if self.neighbor_preserved_long_lived_forwarding_state is not None:
                                        return True

                                    if self.next_hop_unchanged is not None:
                                        return True

                                    if self.orf_entries_received is not None:
                                        return True

                                    if self.orr_group_index is not None:
                                        return True

                                    if self.orr_group_name is not None:
                                        return True

                                    if self.remove_private_as_entire_aspath_from_inbound_updates is not None:
                                        return True

                                    if self.remove_private_as_entire_aspath_from_updates is not None:
                                        return True

                                    if self.remove_private_as_from_inbound_updates is not None:
                                        return True

                                    if self.remove_private_as_from_updates is not None:
                                        return True

                                    if self.restart_time is not None:
                                        return True

                                    if self.rib_purge_timeout_value is not None:
                                        return True

                                    if self.route_policy_default_originate is not None:
                                        return True

                                    if self.route_policy_in is not None:
                                        return True

                                    if self.route_policy_out is not None:
                                        return True

                                    if self.route_policy_prefix_orf is not None:
                                        return True

                                    if self.selective_multipath_eligible is not None:
                                        return True

                                    if self.sent_community_to_neighbor is not None:
                                        return True

                                    if self.sent_extended_community_to_neighbor is not None:
                                        return True

                                    if self.sent_gshut_community_to_neighbor is not None:
                                        return True

                                    if self.stale_path_timeout is not None:
                                        return True

                                    if self.use_max_prefix_warning_only is not None:
                                        return True

                                    if self.vpn_update_gen_enabled is not None:
                                        return True

                                    if self.vpn_update_gen_trigger_enabled is not None:
                                        return True

                                    if self.weight is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.AfData']['meta_info']


                            class Instance_(object):
                                """
                                Dynamic Neighbor Instance List
                                
                                .. attribute:: connection_state
                                
                                	State of connection
                                	**type**\:   :py:class:`BgpConnStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnStateEnum>`
                                
                                .. attribute:: idle_watch_timer_remaining_value
                                
                                	Idle watch timer remaining time
                                	**type**\:   :py:class:`IdleWatchTimerRemainingValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.IdleWatchTimerRemainingValue>`
                                
                                .. attribute:: is_idle_watch_timer_running
                                
                                	Is idle watch timer running
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_address
                                
                                	Dynamic Neighbor address
                                	**type**\:   :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress>`
                                
                                .. attribute:: neighbor_age
                                
                                	Neighbor age
                                	**type**\:   :py:class:`NeighborAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAge>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.connection_state = None
                                    self.idle_watch_timer_remaining_value = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.IdleWatchTimerRemainingValue()
                                    self.idle_watch_timer_remaining_value.parent = self
                                    self.is_idle_watch_timer_running = None
                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress()
                                    self.neighbor_address.parent = self
                                    self.neighbor_age = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAge()
                                    self.neighbor_age.parent = self


                                class NeighborAddress(object):
                                    """
                                    Dynamic Neighbor address
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\:  str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: ipv4sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv6sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2VpnMspwAddress>`
                                    
                                    .. attribute:: l2vpnvpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2VpnvplsAddress>`
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4mdt_address = None
                                        self.ipv4mvpn_address = None
                                        self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv4SrPolicyAddress()
                                        self.ipv4sr_policy_address.parent = self
                                        self.ipv4vpn_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv6SrPolicyAddress()
                                        self.ipv6sr_policy_address.parent = self
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_flowspec_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.l2vpn_evpn_address = None
                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2VpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2VpnvplsAddress()
                                        self.l2vpnvpls_address.parent = self
                                        self.ls_ls_address = None
                                        self.rt_constraint_address = None


                                    class L2VpnvplsAddress(object):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2VpnvplsAddress']['meta_info']


                                    class L2VpnMspwAddress(object):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.l2vpn_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.l2vpn_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2VpnMspwAddress']['meta_info']


                                    class Ipv4SrPolicyAddress(object):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv4SrPolicyAddress']['meta_info']


                                    class Ipv6SrPolicyAddress(object):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv6_srpolicy_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv6_srpolicy_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv6SrPolicyAddress']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.afi is not None:
                                            return True

                                        if self.ipv4_address is not None:
                                            return True

                                        if self.ipv4_flowspec_address is not None:
                                            return True

                                        if self.ipv4_label_address is not None:
                                            return True

                                        if self.ipv4_mcast_address is not None:
                                            return True

                                        if self.ipv4_tunnel_address is not None:
                                            return True

                                        if self.ipv4mdt_address is not None:
                                            return True

                                        if self.ipv4mvpn_address is not None:
                                            return True

                                        if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                            return True

                                        if self.ipv4vpn_address is not None:
                                            return True

                                        if self.ipv4vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv4vpna_mcastddress is not None:
                                            return True

                                        if self.ipv6_address is not None:
                                            return True

                                        if self.ipv6_flowspec_address is not None:
                                            return True

                                        if self.ipv6_label_address is not None:
                                            return True

                                        if self.ipv6_mcast_address is not None:
                                            return True

                                        if self.ipv6mvpn_address is not None:
                                            return True

                                        if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                            return True

                                        if self.ipv6vpn_address is not None:
                                            return True

                                        if self.ipv6vpn_flowspec_address is not None:
                                            return True

                                        if self.ipv6vpn_mcast_address is not None:
                                            return True

                                        if self.l2vpn_evpn_address is not None:
                                            return True

                                        if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                            return True

                                        if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                            return True

                                        if self.ls_ls_address is not None:
                                            return True

                                        if self.rt_constraint_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress']['meta_info']


                                class NeighborAge(object):
                                    """
                                    Neighbor age
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-age'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAge']['meta_info']


                                class IdleWatchTimerRemainingValue(object):
                                    """
                                    Idle watch timer remaining time
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:idle-watch-timer-remaining-value'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.IdleWatchTimerRemainingValue']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:instance'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.connection_state is not None:
                                        return True

                                    if self.idle_watch_timer_remaining_value is not None and self.idle_watch_timer_remaining_value._has_data():
                                        return True

                                    if self.is_idle_watch_timer_running is not None:
                                        return True

                                    if self.neighbor_address is not None and self.neighbor_address._has_data():
                                        return True

                                    if self.neighbor_age is not None and self.neighbor_age._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.neighbor_range_address is None:
                                    raise YPYModelError('Key property neighbor_range_address is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-range[Cisco-IOS-XR-ipv4-bgp-oper:neighbor-range-address = ' + str(self.neighbor_range_address) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.neighbor_range_address is not None:
                                    return True

                                if self.active_bmp_servers is not None:
                                    return True

                                if self.addpath_receive_disable is not None:
                                    return True

                                if self.addpath_receive_enable is not None:
                                    return True

                                if self.addpath_send_disable is not None:
                                    return True

                                if self.addpath_send_enable is not None:
                                    return True

                                if self.af_data is not None:
                                    for child_ref in self.af_data:
                                        if child_ref._has_data():
                                            return True

                                if self.attrf_group_name is not None:
                                    return True

                                if self.bfd_minintervalval is not None:
                                    return True

                                if self.bfd_multiplierval is not None:
                                    return True

                                if self.bfd_session_enable_mode is not None:
                                    return True

                                if self.cfg_local_address is not None and self.cfg_local_address._has_data():
                                    return True

                                if self.configured_hold_time is not None:
                                    return True

                                if self.configured_keepalive is not None:
                                    return True

                                if self.configured_min_acc_hold_time is not None:
                                    return True

                                if self.connection_local_address is not None and self.connection_local_address._has_data():
                                    return True

                                if self.connection_remote_address is not None and self.connection_remote_address._has_data():
                                    return True

                                if self.current_peers is not None:
                                    return True

                                if self.description is not None:
                                    return True

                                if self.discard_as4_path is not None:
                                    return True

                                if self.dmz_link_bandwidth is not None:
                                    return True

                                if self.ebgp_recv_dmz is not None:
                                    return True

                                if self.ebgp_send_dmz_mode is not None:
                                    return True

                                if self.ebgp_time_to_live is not None:
                                    return True

                                if self.egress_peer_engineering_enabled is not None:
                                    return True

                                if self.gr_restart_time is not None:
                                    return True

                                if self.gr_stale_path_time is not None:
                                    return True

                                if self.graceful_maintenance is not None and self.graceful_maintenance._has_data():
                                    return True

                                if self.graceful_restart_enabled_nbr is not None:
                                    return True

                                if self.has_internal_link is not None:
                                    return True

                                if self.idle_watch_time is not None:
                                    return True

                                if self.ignore_connected is not None:
                                    return True

                                if self.instance is not None:
                                    for child_ref in self.instance:
                                        if child_ref._has_data():
                                            return True

                                if self.internal_vpn_client is not None:
                                    return True

                                if self.is_administratively_shut_down is not None:
                                    return True

                                if self.is_capability_negotiation_performed is not None:
                                    return True

                                if self.is_ebgp_multihop_bgpmpls_forwarding_disabled is not None:
                                    return True

                                if self.is_local_address_configured is not None:
                                    return True

                                if self.is_neighbor_max_prefix_shutdown is not None:
                                    return True

                                if self.is_out_of_memory_forced_up is not None:
                                    return True

                                if self.is_passive_close is not None:
                                    return True

                                if self.islocal_address_cfg is not None:
                                    return True

                                if self.local_as is not None:
                                    return True

                                if self.local_as_dual_as is not None:
                                    return True

                                if self.local_as_dual_as_mode_native is not None:
                                    return True

                                if self.local_as_no_prepend is not None:
                                    return True

                                if self.local_as_replace_as is not None:
                                    return True

                                if self.max_peers is not None:
                                    return True

                                if self.min_advertise_interval is not None:
                                    return True

                                if self.min_advertise_interval_msecs is not None:
                                    return True

                                if self.min_origination_interval is not None:
                                    return True

                                if self.msg_buf_count is not None:
                                    return True

                                if self.msg_bug_circular is not None:
                                    return True

                                if self.msg_log_in is not None:
                                    return True

                                if self.msg_log_out is not None:
                                    return True

                                if self.nbr_cluster_id is not None:
                                    return True

                                if self.nbr_enforce_first_as is not None:
                                    return True

                                if self.nbr_in_cluster is not None:
                                    return True

                                if self.nbr_rcv_size is not None:
                                    return True

                                if self.nbr_send_size is not None:
                                    return True

                                if self.neighbor_local_as is not None:
                                    return True

                                if self.neighbor_range_prefix_length is not None:
                                    return True

                                if self.nsr_enabled is not None:
                                    return True

                                if self.oper_attrf_enable is not None:
                                    return True

                                if self.range_inst_error is not None:
                                    return True

                                if self.range_max_drop is not None:
                                    return True

                                if self.range_open_accepted is not None:
                                    return True

                                if self.range_open_match is not None:
                                    return True

                                if self.remote_as is not None:
                                    return True

                                if self.remote_as_list_name is not None:
                                    return True

                                if self.remote_as_number is not None:
                                    return True

                                if self.rpki_allow_invalid is not None:
                                    return True

                                if self.rpki_disable is not None:
                                    return True

                                if self.rpki_signal_ibgp is not None:
                                    return True

                                if self.rpki_use_validity is not None:
                                    return True

                                if self.speaker_id is not None:
                                    return True

                                if self.standby_rp is not None:
                                    return True

                                if self.suppress4_byte_as is not None:
                                    return True

                                if self.syslog_enable is not None:
                                    return True

                                if self.tcp_session_open_mode is not None:
                                    return True

                                if self.tcpmss is not None:
                                    return True

                                if self.tos_type is not None:
                                    return True

                                if self.tos_value is not None:
                                    return True

                                if self.ttl_security_enabled is not None:
                                    return True

                                if self.upd_errh_noreset is not None:
                                    return True

                                if self.update_source is not None:
                                    return True

                                if self.vrf_name is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-ranges'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.neighbor_range is not None:
                                for child_ref in self.neighbor_range:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges']['meta_info']


                    class MessageLogs(object):
                        """
                        The BGP Neighbor Message table
                        
                        .. attribute:: message_log
                        
                        	A BGP Message log entry
                        	**type**\: list of    :py:class:`MessageLog <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.message_log = YList()
                            self.message_log.parent = self
                            self.message_log.name = 'message_log'


                        class MessageLog(object):
                            """
                            A BGP Message log entry
                            
                            .. attribute:: direction
                            
                            	Direction
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: neighbor_address
                            
                            	Neighbor address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: neighbor_message
                            
                            	Array of Neighbor Messages in one direction
                            	**type**\: list of    :py:class:`NeighborMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog.NeighborMessage>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.direction = None
                                self.neighbor_address = None
                                self.neighbor_message = YList()
                                self.neighbor_message.parent = self
                                self.neighbor_message.name = 'neighbor_message'


                            class NeighborMessage(object):
                                """
                                Array of Neighbor Messages in one direction
                                
                                .. attribute:: logged_message_data
                                
                                	Raw Message data in binary format
                                	**type**\: list of    :py:class:`LoggedMessageData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData>`
                                
                                .. attribute:: message_data_length
                                
                                	Message data length
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: message_timestamp
                                
                                	message received time\: time elapsed since 00\:00 \:00 UTC, January 1, 1970
                                	**type**\:   :py:class:`MessageTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp>`
                                
                                .. attribute:: message_type_received
                                
                                	Type of messages Received
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: total_logged_message_count
                                
                                	Total logged messages count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.logged_message_data = YList()
                                    self.logged_message_data.parent = self
                                    self.logged_message_data.name = 'logged_message_data'
                                    self.message_data_length = None
                                    self.message_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp()
                                    self.message_timestamp.parent = self
                                    self.message_type_received = None
                                    self.total_logged_message_count = None


                                class MessageTimestamp(object):
                                    """
                                    message received time\: time elapsed since 00\:00
                                    \:00 UTC, January 1, 1970
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.nanoseconds = None
                                        self.seconds = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:message-timestamp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.nanoseconds is not None:
                                            return True

                                        if self.seconds is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp']['meta_info']


                                class LoggedMessageData(object):
                                    """
                                    Raw Message data in binary format
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:logged-message-data'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:neighbor-message'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.logged_message_data is not None:
                                        for child_ref in self.logged_message_data:
                                            if child_ref._has_data():
                                                return True

                                    if self.message_data_length is not None:
                                        return True

                                    if self.message_timestamp is not None and self.message_timestamp._has_data():
                                        return True

                                    if self.message_type_received is not None:
                                        return True

                                    if self.total_logged_message_count is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog.NeighborMessage']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:message-log'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.direction is not None:
                                    return True

                                if self.neighbor_address is not None:
                                    return True

                                if self.neighbor_message is not None:
                                    for child_ref in self.neighbor_message:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:message-logs'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.message_log is not None:
                                for child_ref in self.message_log:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:default-vrf'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.afs is not None and self.afs._has_data():
                            return True

                        if self.bmp is not None and self.bmp._has_data():
                            return True

                        if self.global_process_info is not None and self.global_process_info._has_data():
                            return True

                        if self.information is not None and self.information._has_data():
                            return True

                        if self.message_logs is not None and self.message_logs._has_data():
                            return True

                        if self.neighbor_ranges is not None and self.neighbor_ranges._has_data():
                            return True

                        if self.neighbors is not None and self.neighbors._has_data():
                            return True

                        if self.next_hop_vrf is not None and self.next_hop_vrf._has_data():
                            return True

                        if self.postits is not None and self.postits._has_data():
                            return True

                        if self.process_info is not None and self.process_info._has_data():
                            return True

                        if self.sessions is not None and self.sessions._has_data():
                            return True

                        if self.update_inbound_error_neighbors is not None and self.update_inbound_error_neighbors._has_data():
                            return True

                        if self.update_inbound_error_vrf is not None and self.update_inbound_error_vrf._has_data():
                            return True

                        if self.update_inbound_filter_neighbors is not None and self.update_inbound_filter_neighbors._has_data():
                            return True

                        if self.update_inbound_filter_vrf is not None and self.update_inbound_filter_vrf._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.DefaultVrf']['meta_info']


                class UpdateInboundFilterProcess(object):
                    """
                    Update inbound filtering information for the
                    process
                    
                    .. attribute:: last_update_filtered_age
                    
                    	Time since last filtered messages received event (in seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: last_update_filtered_timestamp
                    
                    	Last filtered messages received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                    	**type**\:   :py:class:`LastUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.UpdateInboundFilterProcess.LastUpdateFilteredTimestamp>`
                    
                    .. attribute:: update_filtered_message_count
                    
                    	Filtered messages count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update_filtered_neighbor_count
                    
                    	Count of neighbors that received filtered messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2015-08-27'

                    def __init__(self):
                        self.parent = None
                        self.last_update_filtered_age = None
                        self.last_update_filtered_timestamp = Bgp.Instances.Instance.InstanceStandby.UpdateInboundFilterProcess.LastUpdateFilteredTimestamp()
                        self.last_update_filtered_timestamp.parent = self
                        self.update_filtered_message_count = None
                        self.update_filtered_neighbor_count = None


                    class LastUpdateFilteredTimestamp(object):
                        """
                        Last filtered messages received time\: time
                        elapsed since 00\:00\:00 UTC, January 1, 1970
                        
                        .. attribute:: nanoseconds
                        
                        	Nanoseconds part of time value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: seconds
                        
                        	Seconds part of time value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.nanoseconds = None
                            self.seconds = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-filtered-timestamp'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.nanoseconds is not None:
                                return True

                            if self.seconds is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.UpdateInboundFilterProcess.LastUpdateFilteredTimestamp']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-inbound-filter-process'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.last_update_filtered_age is not None:
                            return True

                        if self.last_update_filtered_timestamp is not None and self.last_update_filtered_timestamp._has_data():
                            return True

                        if self.update_filtered_message_count is not None:
                            return True

                        if self.update_filtered_neighbor_count is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.UpdateInboundFilterProcess']['meta_info']


                class Attributes(object):
                    """
                    The BGP Attribute table
                    
                    .. attribute:: attribute
                    
                    	A BGP Attribute table entry
                    	**type**\: list of    :py:class:`Attribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2015-08-27'

                    def __init__(self):
                        self.parent = None
                        self.attribute = YList()
                        self.attribute.parent = self
                        self.attribute.name = 'attribute'


                    class Attribute(object):
                        """
                        A BGP Attribute table entry
                        
                        .. attribute:: attribute_cache_bucket
                        
                        	Attribute cache bucket
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: attribute_cache_id
                        
                        	Attribute cache ID
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: attribute_iid
                        
                        	Attribute IID
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: attribute_info
                        
                        	Attributes
                        	**type**\:   :py:class:`AttributeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo>`
                        
                        .. attribute:: attribute_instance_id
                        
                        	Attribute Instance ID
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: attribute_structure_hash_value
                        
                        	Hash value for attribute structure
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: attribute_structure_id
                        
                        	ID of attribute structure
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: process_instance_id
                        
                        	Process instance ID
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: reference_count
                        
                        	Number of paths which use this attribute structure
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.attribute_cache_bucket = None
                            self.attribute_cache_id = None
                            self.attribute_iid = None
                            self.attribute_info = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo()
                            self.attribute_info.parent = self
                            self.attribute_instance_id = None
                            self.attribute_structure_hash_value = None
                            self.attribute_structure_id = None
                            self.process_instance_id = None
                            self.reference_count = None


                        class AttributeInfo(object):
                            """
                            Attributes
                            
                            .. attribute:: attr_set
                            
                            	ATTR\_SET attribute
                            	**type**\:   :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet>`
                            
                            .. attribute:: attribute_key_number
                            
                            	Attribute key number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_reuse_id_config
                            
                            	Attribute reuse ID Configured
                            	**type**\:  bool
                            
                            .. attribute:: attribute_reuse_id_current
                            
                            	Attribute reuse ID current ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_reuse_id_keys
                            
                            	Attribute reuse ID allocated keys
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_reuse_id_max_id
                            
                            	Attribute reuse ID maximum ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_reuse_id_node
                            
                            	Attribute reuse ID nodes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_reuse_id_recover_sec
                            
                            	Attribute reuse ID timer in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: common_attributes
                            
                            	Common attributes
                            	**type**\:   :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes>`
                            
                            .. attribute:: is_application_gateway_present
                            
                            	Application gateway present
                            	**type**\:  bool
                            
                            .. attribute:: is_as_path2_byte
                            
                            	AS path encoded as 2\-byte
                            	**type**\:  bool
                            
                            .. attribute:: is_attr_set_present
                            
                            	BGP ATTR\_SET attribute present
                            	**type**\:  bool
                            
                            .. attribute:: is_ribrnh_present
                            
                            	RIB RNH Attribute  present
                            	**type**\:  bool
                            
                            .. attribute:: is_rnh_present
                            
                            	RNH Attribute  present
                            	**type**\:  bool
                            
                            .. attribute:: ribrnh_encap
                            
                            	RIB RNH Encapsulation Type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ribrnh_ip
                            
                            	RIB RNH IP Address
                            	**type**\:   :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp>`
                            
                            .. attribute:: ribrnh_mac
                            
                            	RIB RNH MAC Address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: ribrnh_table
                            
                            	RIB RNH Table
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ribrnh_vni
                            
                            	RIB RNH Vni
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ribrnhip_table
                            
                            	RIB RNH IP Table
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rnh_addr
                            
                            	RNH Address
                            	**type**\:   :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RnhAddr>`
                            
                            .. attribute:: rnh_addr_len
                            
                            	RNH Address Length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rnh_len
                            
                            	RNH Length
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: rnh_type
                            
                            	RNH Type
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: set_aigp_inbound_igp
                            
                            	AIGP set by policy inbound IGP 
                            	**type**\:  bool
                            
                            .. attribute:: set_aigp_inbound_metric
                            
                            	AIGP set by policy inbound metric
                            	**type**\:  bool
                            
                            .. attribute:: vpn_distinguisher
                            
                            	VPN Distinguisher
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet()
                                self.attr_set.parent = self
                                self.attribute_key_number = None
                                self.attribute_reuse_id_config = None
                                self.attribute_reuse_id_current = None
                                self.attribute_reuse_id_keys = None
                                self.attribute_reuse_id_max_id = None
                                self.attribute_reuse_id_node = None
                                self.attribute_reuse_id_recover_sec = None
                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes()
                                self.common_attributes.parent = self
                                self.is_application_gateway_present = None
                                self.is_as_path2_byte = None
                                self.is_attr_set_present = None
                                self.is_ribrnh_present = None
                                self.is_rnh_present = None
                                self.ribrnh_encap = None
                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp()
                                self.ribrnh_ip.parent = self
                                self.ribrnh_mac = None
                                self.ribrnh_table = None
                                self.ribrnh_vni = None
                                self.ribrnhip_table = None
                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RnhAddr()
                                self.rnh_addr.parent = self
                                self.rnh_addr_len = None
                                self.rnh_len = None
                                self.rnh_type = None
                                self.set_aigp_inbound_igp = None
                                self.set_aigp_inbound_metric = None
                                self.vpn_distinguisher = None


                            class CommonAttributes(object):
                                """
                                Common attributes
                                
                                .. attribute:: aggregator_address
                                
                                	Address where aggregation was performed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: aggregator_as
                                
                                	AS where aggregation was last performed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: aigp_metric_value
                                
                                	AIGP metric value
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: as_path
                                
                                	AS path attribute
                                	**type**\:  str
                                
                                .. attribute:: cluster
                                
                                	Cluster list attribute
                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster>`
                                
                                .. attribute:: community
                                
                                	Community attribute
                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.Community>`
                                
                                .. attribute:: connector_type
                                
                                	Connector Type
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: connector_value
                                
                                	Connector Value
                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue>`
                                
                                .. attribute:: extended_community
                                
                                	Extended community attribute
                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity>`
                                
                                .. attribute:: extended_community_flags
                                
                                	Extended community Flags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: is_aggregator_present
                                
                                	Aggregator attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_aigp_present
                                
                                	AIGP Present
                                	**type**\:  bool
                                
                                .. attribute:: is_as_path_present
                                
                                	AS path attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_atomic_aggregate_present
                                
                                	Atomic aggregate attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_community_present
                                
                                	Community attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_connector_present
                                
                                	Connector present
                                	**type**\:  bool
                                
                                .. attribute:: is_extended_community_present
                                
                                	Extended community attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_label_index_present
                                
                                	Label Index attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_local_pref_present
                                
                                	Local Preference attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_ls_attribute_present
                                
                                	BGP LS attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_metric_present
                                
                                	Metric attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_origin_present
                                
                                	Origin attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_pe_distinguisher_label_present
                                
                                	PE distinguisher label  attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_pmsi_present
                                
                                	PMSI Attribute  present
                                	**type**\:  bool
                                
                                .. attribute:: is_pppmp_present
                                
                                	PPMP Attribute  present
                                	**type**\:  bool
                                
                                .. attribute:: is_ssa_present
                                
                                	SSA attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_tunnel_encap_present
                                
                                	Tunnel Encap attribute present 
                                	**type**\:  bool
                                
                                .. attribute:: l2tpv3_cookie
                                
                                	L2TPv3 Cookie
                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.L2Tpv3Cookie>`
                                
                                .. attribute:: l2tpv3_session_id
                                
                                	L2TPv3 session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_index_attr
                                
                                	Label Index attribute
                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.LabelIndexAttr>`
                                
                                .. attribute:: local_preference
                                
                                	Local preference
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ls_attr
                                
                                	BGP LS attribute
                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr>`
                                
                                .. attribute:: metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_as
                                
                                	Neighbor AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: origin
                                
                                	Origin
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: originator
                                
                                	Originator attribute
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pe_distinguisher_label
                                
                                	PE distinguisher label attribute
                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel>`
                                
                                .. attribute:: pmsi_flags
                                
                                	PMSI Value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: pmsi_label
                                
                                	PMSI label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pmsi_type
                                
                                	PMSI Type
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: pmsi_value
                                
                                	PMSI Value
                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue>`
                                
                                .. attribute:: ppm_pvalue
                                
                                	PPMP Value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sr_policy_allocated_binding_sid
                                
                                	SR Policy allocated Binding sid by the router
                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyAllocatedBindingSid>`
                                
                                .. attribute:: sr_policy_binding_sid
                                
                                	SR Policy Binding sid
                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyBindingSid>`
                                
                                .. attribute:: sr_policy_explicit_path
                                
                                	SR Policy Explicit paths
                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyExplicitPath>`
                                
                                .. attribute:: sr_policy_preference
                                
                                	SR Policy Preference
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sr_tunnel_request_state
                                
                                	SR Tunnel Request State
                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                
                                .. attribute:: sr_tunnel_state
                                
                                	SR Tunnel State
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tunnel_encap_type
                                
                                	Tunnel Encap Type
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: unknown_attribute
                                
                                	Unknown attributes
                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.aggregator_address = None
                                    self.aggregator_as = None
                                    self.aigp_metric_value = None
                                    self.as_path = None
                                    self.cluster = YList()
                                    self.cluster.parent = self
                                    self.cluster.name = 'cluster'
                                    self.community = YList()
                                    self.community.parent = self
                                    self.community.name = 'community'
                                    self.connector_type = None
                                    self.connector_value = YList()
                                    self.connector_value.parent = self
                                    self.connector_value.name = 'connector_value'
                                    self.extended_community = YList()
                                    self.extended_community.parent = self
                                    self.extended_community.name = 'extended_community'
                                    self.extended_community_flags = None
                                    self.is_aggregator_present = None
                                    self.is_aigp_present = None
                                    self.is_as_path_present = None
                                    self.is_atomic_aggregate_present = None
                                    self.is_community_present = None
                                    self.is_connector_present = None
                                    self.is_extended_community_present = None
                                    self.is_label_index_present = None
                                    self.is_local_pref_present = None
                                    self.is_ls_attribute_present = None
                                    self.is_metric_present = None
                                    self.is_origin_present = None
                                    self.is_pe_distinguisher_label_present = None
                                    self.is_pmsi_present = None
                                    self.is_pppmp_present = None
                                    self.is_ssa_present = None
                                    self.is_tunnel_encap_present = None
                                    self.l2tpv3_cookie = YList()
                                    self.l2tpv3_cookie.parent = self
                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                    self.l2tpv3_session_id = None
                                    self.label_index_attr = YList()
                                    self.label_index_attr.parent = self
                                    self.label_index_attr.name = 'label_index_attr'
                                    self.local_preference = None
                                    self.ls_attr = YList()
                                    self.ls_attr.parent = self
                                    self.ls_attr.name = 'ls_attr'
                                    self.metric = None
                                    self.neighbor_as = None
                                    self.origin = None
                                    self.originator = None
                                    self.pe_distinguisher_label = YList()
                                    self.pe_distinguisher_label.parent = self
                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                    self.pmsi_flags = None
                                    self.pmsi_label = None
                                    self.pmsi_type = None
                                    self.pmsi_value = YList()
                                    self.pmsi_value.parent = self
                                    self.pmsi_value.name = 'pmsi_value'
                                    self.ppm_pvalue = None
                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyAllocatedBindingSid()
                                    self.sr_policy_allocated_binding_sid.parent = self
                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyBindingSid()
                                    self.sr_policy_binding_sid.parent = self
                                    self.sr_policy_explicit_path = YList()
                                    self.sr_policy_explicit_path.parent = self
                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                    self.sr_policy_preference = None
                                    self.sr_tunnel_request_state = None
                                    self.sr_tunnel_state = None
                                    self.tunnel_encap_type = None
                                    self.unknown_attribute = YList()
                                    self.unknown_attribute.parent = self
                                    self.unknown_attribute.name = 'unknown_attribute'


                                class SrPolicyBindingSid(object):
                                    """
                                    SR Policy Binding sid
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPv6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: label
                                    
                                    	MPLS Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv6_address = None
                                        self.label = None
                                        self.type = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv6_address is not None:
                                            return True

                                        if self.label is not None:
                                            return True

                                        if self.type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyBindingSid']['meta_info']


                                class SrPolicyAllocatedBindingSid(object):
                                    """
                                    SR Policy allocated Binding sid by the router
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPv6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: label
                                    
                                    	MPLS Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv6_address = None
                                        self.label = None
                                        self.type = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv6_address is not None:
                                            return True

                                        if self.label is not None:
                                            return True

                                        if self.type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyAllocatedBindingSid']['meta_info']


                                class Community(object):
                                    """
                                    Community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.Community']['meta_info']


                                class ExtendedCommunity(object):
                                    """
                                    Extended community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity']['meta_info']


                                class UnknownAttribute(object):
                                    """
                                    Unknown attributes
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute']['meta_info']


                                class Cluster(object):
                                    """
                                    Cluster list attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster']['meta_info']


                                class L2Tpv3Cookie(object):
                                    """
                                    L2TPv3 Cookie
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.L2Tpv3Cookie']['meta_info']


                                class ConnectorValue(object):
                                    """
                                    Connector Value
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue']['meta_info']


                                class PmsiValue(object):
                                    """
                                    PMSI Value
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue']['meta_info']


                                class LsAttr(object):
                                    """
                                    BGP LS attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr']['meta_info']


                                class LabelIndexAttr(object):
                                    """
                                    Label Index attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.LabelIndexAttr']['meta_info']


                                class PeDistinguisherLabel(object):
                                    """
                                    PE distinguisher label attribute
                                    
                                    .. attribute:: label
                                    
                                    	Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pe_address
                                    
                                    	 PE address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.label = None
                                        self.pe_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.label is not None:
                                            return True

                                        if self.pe_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel']['meta_info']


                                class SrPolicyExplicitPath(object):
                                    """
                                    SR Policy Explicit paths
                                    
                                    .. attribute:: sid
                                    
                                    	Sidlist for explicit path
                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyExplicitPath.Sid>`
                                    
                                    .. attribute:: weight
                                    
                                    	Weight of explicit path
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.sid = YList()
                                        self.sid.parent = self
                                        self.sid.name = 'sid'
                                        self.weight = None


                                    class Sid(object):
                                        """
                                        Sidlist for explicit path
                                        
                                        .. attribute:: ipv4
                                        
                                        	IP Address sid
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address sid
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: label
                                        
                                        	MPLS Label sid
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: type
                                        
                                        	Sid Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self.label = None
                                            self.type = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4 is not None:
                                                return True

                                            if self.ipv6 is not None:
                                                return True

                                            if self.label is not None:
                                                return True

                                            if self.type is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyExplicitPath.Sid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.sid is not None:
                                            for child_ref in self.sid:
                                                if child_ref._has_data():
                                                    return True

                                        if self.weight is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.SrPolicyExplicitPath']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:common-attributes'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.aggregator_address is not None:
                                        return True

                                    if self.aggregator_as is not None:
                                        return True

                                    if self.aigp_metric_value is not None:
                                        return True

                                    if self.as_path is not None:
                                        return True

                                    if self.cluster is not None:
                                        for child_ref in self.cluster:
                                            if child_ref._has_data():
                                                return True

                                    if self.community is not None:
                                        for child_ref in self.community:
                                            if child_ref._has_data():
                                                return True

                                    if self.connector_type is not None:
                                        return True

                                    if self.connector_value is not None:
                                        for child_ref in self.connector_value:
                                            if child_ref._has_data():
                                                return True

                                    if self.extended_community is not None:
                                        for child_ref in self.extended_community:
                                            if child_ref._has_data():
                                                return True

                                    if self.extended_community_flags is not None:
                                        return True

                                    if self.is_aggregator_present is not None:
                                        return True

                                    if self.is_aigp_present is not None:
                                        return True

                                    if self.is_as_path_present is not None:
                                        return True

                                    if self.is_atomic_aggregate_present is not None:
                                        return True

                                    if self.is_community_present is not None:
                                        return True

                                    if self.is_connector_present is not None:
                                        return True

                                    if self.is_extended_community_present is not None:
                                        return True

                                    if self.is_label_index_present is not None:
                                        return True

                                    if self.is_local_pref_present is not None:
                                        return True

                                    if self.is_ls_attribute_present is not None:
                                        return True

                                    if self.is_metric_present is not None:
                                        return True

                                    if self.is_origin_present is not None:
                                        return True

                                    if self.is_pe_distinguisher_label_present is not None:
                                        return True

                                    if self.is_pmsi_present is not None:
                                        return True

                                    if self.is_pppmp_present is not None:
                                        return True

                                    if self.is_ssa_present is not None:
                                        return True

                                    if self.is_tunnel_encap_present is not None:
                                        return True

                                    if self.l2tpv3_cookie is not None:
                                        for child_ref in self.l2tpv3_cookie:
                                            if child_ref._has_data():
                                                return True

                                    if self.l2tpv3_session_id is not None:
                                        return True

                                    if self.label_index_attr is not None:
                                        for child_ref in self.label_index_attr:
                                            if child_ref._has_data():
                                                return True

                                    if self.local_preference is not None:
                                        return True

                                    if self.ls_attr is not None:
                                        for child_ref in self.ls_attr:
                                            if child_ref._has_data():
                                                return True

                                    if self.metric is not None:
                                        return True

                                    if self.neighbor_as is not None:
                                        return True

                                    if self.origin is not None:
                                        return True

                                    if self.originator is not None:
                                        return True

                                    if self.pe_distinguisher_label is not None:
                                        for child_ref in self.pe_distinguisher_label:
                                            if child_ref._has_data():
                                                return True

                                    if self.pmsi_flags is not None:
                                        return True

                                    if self.pmsi_label is not None:
                                        return True

                                    if self.pmsi_type is not None:
                                        return True

                                    if self.pmsi_value is not None:
                                        for child_ref in self.pmsi_value:
                                            if child_ref._has_data():
                                                return True

                                    if self.ppm_pvalue is not None:
                                        return True

                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                        return True

                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                        return True

                                    if self.sr_policy_explicit_path is not None:
                                        for child_ref in self.sr_policy_explicit_path:
                                            if child_ref._has_data():
                                                return True

                                    if self.sr_policy_preference is not None:
                                        return True

                                    if self.sr_tunnel_request_state is not None:
                                        return True

                                    if self.sr_tunnel_state is not None:
                                        return True

                                    if self.tunnel_encap_type is not None:
                                        return True

                                    if self.unknown_attribute is not None:
                                        for child_ref in self.unknown_attribute:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes']['meta_info']


                            class AttrSet(object):
                                """
                                ATTR\_SET attribute
                                
                                .. attribute:: aggregator_address
                                
                                	Address where aggregation was performed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: aggregator_as
                                
                                	AS where aggregation was last performed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: aigp_metric_value
                                
                                	AIGP metric value
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: as_path
                                
                                	AS path attribute
                                	**type**\:  str
                                
                                .. attribute:: cluster
                                
                                	Cluster list attribute
                                	**type**\: list of    :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.Cluster>`
                                
                                .. attribute:: community
                                
                                	Community attribute
                                	**type**\: list of    :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.Community>`
                                
                                .. attribute:: connector_type
                                
                                	Connector Type
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: connector_value
                                
                                	Connector Value
                                	**type**\: list of    :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue>`
                                
                                .. attribute:: extended_community
                                
                                	Extended community attribute
                                	**type**\: list of    :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity>`
                                
                                .. attribute:: extended_community_flags
                                
                                	Extended community Flags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: is_aggregator_present
                                
                                	Aggregator attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_aigp_present
                                
                                	AIGP Present
                                	**type**\:  bool
                                
                                .. attribute:: is_as_path_present
                                
                                	AS path attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_atomic_aggregate_present
                                
                                	Atomic aggregate attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_community_present
                                
                                	Community attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_connector_present
                                
                                	Connector present
                                	**type**\:  bool
                                
                                .. attribute:: is_extended_community_present
                                
                                	Extended community attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_label_index_present
                                
                                	Label Index attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_local_pref_present
                                
                                	Local Preference attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_ls_attribute_present
                                
                                	BGP LS attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_metric_present
                                
                                	Metric attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_origin_present
                                
                                	Origin attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_pe_distinguisher_label_present
                                
                                	PE distinguisher label  attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_pmsi_present
                                
                                	PMSI Attribute  present
                                	**type**\:  bool
                                
                                .. attribute:: is_pppmp_present
                                
                                	PPMP Attribute  present
                                	**type**\:  bool
                                
                                .. attribute:: is_ssa_present
                                
                                	SSA attribute present
                                	**type**\:  bool
                                
                                .. attribute:: is_tunnel_encap_present
                                
                                	Tunnel Encap attribute present 
                                	**type**\:  bool
                                
                                .. attribute:: l2tpv3_cookie
                                
                                	L2TPv3 Cookie
                                	**type**\: list of    :py:class:`L2Tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.L2Tpv3Cookie>`
                                
                                .. attribute:: l2tpv3_session_id
                                
                                	L2TPv3 session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_index_attr
                                
                                	Label Index attribute
                                	**type**\: list of    :py:class:`LabelIndexAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.LabelIndexAttr>`
                                
                                .. attribute:: local_preference
                                
                                	Local preference
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ls_attr
                                
                                	BGP LS attribute
                                	**type**\: list of    :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr>`
                                
                                .. attribute:: metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_as
                                
                                	Neighbor AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: origin
                                
                                	Origin
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: originator
                                
                                	Originator attribute
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pe_distinguisher_label
                                
                                	PE distinguisher label attribute
                                	**type**\: list of    :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel>`
                                
                                .. attribute:: pmsi_flags
                                
                                	PMSI Value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: pmsi_label
                                
                                	PMSI label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pmsi_type
                                
                                	PMSI Type
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: pmsi_value
                                
                                	PMSI Value
                                	**type**\: list of    :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue>`
                                
                                .. attribute:: ppm_pvalue
                                
                                	PPMP Value
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sr_policy_allocated_binding_sid
                                
                                	SR Policy allocated Binding sid by the router
                                	**type**\:   :py:class:`SrPolicyAllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyAllocatedBindingSid>`
                                
                                .. attribute:: sr_policy_binding_sid
                                
                                	SR Policy Binding sid
                                	**type**\:   :py:class:`SrPolicyBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyBindingSid>`
                                
                                .. attribute:: sr_policy_explicit_path
                                
                                	SR Policy Explicit paths
                                	**type**\: list of    :py:class:`SrPolicyExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyExplicitPath>`
                                
                                .. attribute:: sr_policy_preference
                                
                                	SR Policy Preference
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sr_tunnel_request_state
                                
                                	SR Tunnel Request State
                                	**type**\:   :py:class:`BgpSrpolicyTunReqStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyTunReqStateEnum>`
                                
                                .. attribute:: sr_tunnel_state
                                
                                	SR Tunnel State
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tunnel_encap_type
                                
                                	Tunnel Encap Type
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: unknown_attribute
                                
                                	Unknown attributes
                                	**type**\: list of    :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.aggregator_address = None
                                    self.aggregator_as = None
                                    self.aigp_metric_value = None
                                    self.as_path = None
                                    self.cluster = YList()
                                    self.cluster.parent = self
                                    self.cluster.name = 'cluster'
                                    self.community = YList()
                                    self.community.parent = self
                                    self.community.name = 'community'
                                    self.connector_type = None
                                    self.connector_value = YList()
                                    self.connector_value.parent = self
                                    self.connector_value.name = 'connector_value'
                                    self.extended_community = YList()
                                    self.extended_community.parent = self
                                    self.extended_community.name = 'extended_community'
                                    self.extended_community_flags = None
                                    self.is_aggregator_present = None
                                    self.is_aigp_present = None
                                    self.is_as_path_present = None
                                    self.is_atomic_aggregate_present = None
                                    self.is_community_present = None
                                    self.is_connector_present = None
                                    self.is_extended_community_present = None
                                    self.is_label_index_present = None
                                    self.is_local_pref_present = None
                                    self.is_ls_attribute_present = None
                                    self.is_metric_present = None
                                    self.is_origin_present = None
                                    self.is_pe_distinguisher_label_present = None
                                    self.is_pmsi_present = None
                                    self.is_pppmp_present = None
                                    self.is_ssa_present = None
                                    self.is_tunnel_encap_present = None
                                    self.l2tpv3_cookie = YList()
                                    self.l2tpv3_cookie.parent = self
                                    self.l2tpv3_cookie.name = 'l2tpv3_cookie'
                                    self.l2tpv3_session_id = None
                                    self.label_index_attr = YList()
                                    self.label_index_attr.parent = self
                                    self.label_index_attr.name = 'label_index_attr'
                                    self.local_preference = None
                                    self.ls_attr = YList()
                                    self.ls_attr.parent = self
                                    self.ls_attr.name = 'ls_attr'
                                    self.metric = None
                                    self.neighbor_as = None
                                    self.origin = None
                                    self.originator = None
                                    self.pe_distinguisher_label = YList()
                                    self.pe_distinguisher_label.parent = self
                                    self.pe_distinguisher_label.name = 'pe_distinguisher_label'
                                    self.pmsi_flags = None
                                    self.pmsi_label = None
                                    self.pmsi_type = None
                                    self.pmsi_value = YList()
                                    self.pmsi_value.parent = self
                                    self.pmsi_value.name = 'pmsi_value'
                                    self.ppm_pvalue = None
                                    self.sr_policy_allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyAllocatedBindingSid()
                                    self.sr_policy_allocated_binding_sid.parent = self
                                    self.sr_policy_binding_sid = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyBindingSid()
                                    self.sr_policy_binding_sid.parent = self
                                    self.sr_policy_explicit_path = YList()
                                    self.sr_policy_explicit_path.parent = self
                                    self.sr_policy_explicit_path.name = 'sr_policy_explicit_path'
                                    self.sr_policy_preference = None
                                    self.sr_tunnel_request_state = None
                                    self.sr_tunnel_state = None
                                    self.tunnel_encap_type = None
                                    self.unknown_attribute = YList()
                                    self.unknown_attribute.parent = self
                                    self.unknown_attribute.name = 'unknown_attribute'


                                class SrPolicyBindingSid(object):
                                    """
                                    SR Policy Binding sid
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPv6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: label
                                    
                                    	MPLS Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv6_address = None
                                        self.label = None
                                        self.type = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-binding-sid'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv6_address is not None:
                                            return True

                                        if self.label is not None:
                                            return True

                                        if self.type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyBindingSid']['meta_info']


                                class SrPolicyAllocatedBindingSid(object):
                                    """
                                    SR Policy allocated Binding sid by the router
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPv6 Addr
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: label
                                    
                                    	MPLS Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`BgpBindingSidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSidEnum>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv6_address = None
                                        self.label = None
                                        self.type = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-allocated-binding-sid'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv6_address is not None:
                                            return True

                                        if self.label is not None:
                                            return True

                                        if self.type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyAllocatedBindingSid']['meta_info']


                                class Community(object):
                                    """
                                    Community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:community'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.Community']['meta_info']


                                class ExtendedCommunity(object):
                                    """
                                    Extended community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:extended-community'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity']['meta_info']


                                class UnknownAttribute(object):
                                    """
                                    Unknown attributes
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:unknown-attribute'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute']['meta_info']


                                class Cluster(object):
                                    """
                                    Cluster list attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:cluster'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.Cluster']['meta_info']


                                class L2Tpv3Cookie(object):
                                    """
                                    L2TPv3 Cookie
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2tpv3-cookie'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.L2Tpv3Cookie']['meta_info']


                                class ConnectorValue(object):
                                    """
                                    Connector Value
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:connector-value'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue']['meta_info']


                                class PmsiValue(object):
                                    """
                                    PMSI Value
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pmsi-value'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue']['meta_info']


                                class LsAttr(object):
                                    """
                                    BGP LS attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ls-attr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr']['meta_info']


                                class LabelIndexAttr(object):
                                    """
                                    Label Index attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.entry = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:label-index-attr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.entry is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.LabelIndexAttr']['meta_info']


                                class PeDistinguisherLabel(object):
                                    """
                                    PE distinguisher label attribute
                                    
                                    .. attribute:: label
                                    
                                    	Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pe_address
                                    
                                    	 PE address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.label = None
                                        self.pe_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:pe-distinguisher-label'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.label is not None:
                                            return True

                                        if self.pe_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel']['meta_info']


                                class SrPolicyExplicitPath(object):
                                    """
                                    SR Policy Explicit paths
                                    
                                    .. attribute:: sid
                                    
                                    	Sidlist for explicit path
                                    	**type**\: list of    :py:class:`Sid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyExplicitPath.Sid>`
                                    
                                    .. attribute:: weight
                                    
                                    	Weight of explicit path
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.sid = YList()
                                        self.sid.parent = self
                                        self.sid.name = 'sid'
                                        self.weight = None


                                    class Sid(object):
                                        """
                                        Sidlist for explicit path
                                        
                                        .. attribute:: ipv4
                                        
                                        	IP Address sid
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6
                                        
                                        	IPv6 address sid
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: label
                                        
                                        	MPLS Label sid
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: type
                                        
                                        	Sid Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2015-08-27'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4 = None
                                            self.ipv6 = None
                                            self.label = None
                                            self.type = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sid'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4 is not None:
                                                return True

                                            if self.ipv6 is not None:
                                                return True

                                            if self.label is not None:
                                                return True

                                            if self.type is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyExplicitPath.Sid']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:sr-policy-explicit-path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.sid is not None:
                                            for child_ref in self.sid:
                                                if child_ref._has_data():
                                                    return True

                                        if self.weight is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.SrPolicyExplicitPath']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attr-set'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.aggregator_address is not None:
                                        return True

                                    if self.aggregator_as is not None:
                                        return True

                                    if self.aigp_metric_value is not None:
                                        return True

                                    if self.as_path is not None:
                                        return True

                                    if self.cluster is not None:
                                        for child_ref in self.cluster:
                                            if child_ref._has_data():
                                                return True

                                    if self.community is not None:
                                        for child_ref in self.community:
                                            if child_ref._has_data():
                                                return True

                                    if self.connector_type is not None:
                                        return True

                                    if self.connector_value is not None:
                                        for child_ref in self.connector_value:
                                            if child_ref._has_data():
                                                return True

                                    if self.extended_community is not None:
                                        for child_ref in self.extended_community:
                                            if child_ref._has_data():
                                                return True

                                    if self.extended_community_flags is not None:
                                        return True

                                    if self.is_aggregator_present is not None:
                                        return True

                                    if self.is_aigp_present is not None:
                                        return True

                                    if self.is_as_path_present is not None:
                                        return True

                                    if self.is_atomic_aggregate_present is not None:
                                        return True

                                    if self.is_community_present is not None:
                                        return True

                                    if self.is_connector_present is not None:
                                        return True

                                    if self.is_extended_community_present is not None:
                                        return True

                                    if self.is_label_index_present is not None:
                                        return True

                                    if self.is_local_pref_present is not None:
                                        return True

                                    if self.is_ls_attribute_present is not None:
                                        return True

                                    if self.is_metric_present is not None:
                                        return True

                                    if self.is_origin_present is not None:
                                        return True

                                    if self.is_pe_distinguisher_label_present is not None:
                                        return True

                                    if self.is_pmsi_present is not None:
                                        return True

                                    if self.is_pppmp_present is not None:
                                        return True

                                    if self.is_ssa_present is not None:
                                        return True

                                    if self.is_tunnel_encap_present is not None:
                                        return True

                                    if self.l2tpv3_cookie is not None:
                                        for child_ref in self.l2tpv3_cookie:
                                            if child_ref._has_data():
                                                return True

                                    if self.l2tpv3_session_id is not None:
                                        return True

                                    if self.label_index_attr is not None:
                                        for child_ref in self.label_index_attr:
                                            if child_ref._has_data():
                                                return True

                                    if self.local_preference is not None:
                                        return True

                                    if self.ls_attr is not None:
                                        for child_ref in self.ls_attr:
                                            if child_ref._has_data():
                                                return True

                                    if self.metric is not None:
                                        return True

                                    if self.neighbor_as is not None:
                                        return True

                                    if self.origin is not None:
                                        return True

                                    if self.originator is not None:
                                        return True

                                    if self.pe_distinguisher_label is not None:
                                        for child_ref in self.pe_distinguisher_label:
                                            if child_ref._has_data():
                                                return True

                                    if self.pmsi_flags is not None:
                                        return True

                                    if self.pmsi_label is not None:
                                        return True

                                    if self.pmsi_type is not None:
                                        return True

                                    if self.pmsi_value is not None:
                                        for child_ref in self.pmsi_value:
                                            if child_ref._has_data():
                                                return True

                                    if self.ppm_pvalue is not None:
                                        return True

                                    if self.sr_policy_allocated_binding_sid is not None and self.sr_policy_allocated_binding_sid._has_data():
                                        return True

                                    if self.sr_policy_binding_sid is not None and self.sr_policy_binding_sid._has_data():
                                        return True

                                    if self.sr_policy_explicit_path is not None:
                                        for child_ref in self.sr_policy_explicit_path:
                                            if child_ref._has_data():
                                                return True

                                    if self.sr_policy_preference is not None:
                                        return True

                                    if self.sr_tunnel_request_state is not None:
                                        return True

                                    if self.sr_tunnel_state is not None:
                                        return True

                                    if self.tunnel_encap_type is not None:
                                        return True

                                    if self.unknown_attribute is not None:
                                        for child_ref in self.unknown_attribute:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet']['meta_info']


                            class RnhAddr(object):
                                """
                                RNH Address
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPv6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: len
                                
                                	len
                                	**type**\:   :py:class:`BgpRnhAddrLenEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLenEnum>`
                                
                                .. attribute:: mac_address
                                
                                	MAC Addr
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self.len = None
                                    self.mac_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rnh-addr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    if self.len is not None:
                                        return True

                                    if self.mac_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RnhAddr']['meta_info']


                            class RibrnhIp(object):
                                """
                                RIB RNH IP Address
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:   :py:class:`BgpAfiEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfiEnum>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\:  str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\:  str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: ipv4sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:   :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv6sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:   :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:   :py:class:`L2VpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress>`
                                
                                .. attribute:: l2vpnvpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:   :py:class:`L2VpnvplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnvplsAddress>`
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\:  str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2015-08-27'

                                def __init__(self):
                                    self.parent = None
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4mdt_address = None
                                    self.ipv4mvpn_address = None
                                    self.ipv4sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress()
                                    self.ipv4sr_policy_address.parent = self
                                    self.ipv4vpn_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv6sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress()
                                    self.ipv6sr_policy_address.parent = self
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_flowspec_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.l2vpn_evpn_address = None
                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self.l2vpnvpls_address = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnvplsAddress()
                                    self.l2vpnvpls_address.parent = self
                                    self.ls_ls_address = None
                                    self.rt_constraint_address = None


                                class L2VpnvplsAddress(object):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpnvpls-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnvplsAddress']['meta_info']


                                class L2VpnMspwAddress(object):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.l2vpn_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:l2vpn-mspw-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.l2vpn_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.L2VpnMspwAddress']['meta_info']


                                class Ipv4SrPolicyAddress(object):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv4sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress']['meta_info']


                                class Ipv6SrPolicyAddress(object):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2015-08-27'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv6_srpolicy_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ipv6sr-policy-address'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv6_srpolicy_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:ribrnh-ip'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.afi is not None:
                                        return True

                                    if self.ipv4_address is not None:
                                        return True

                                    if self.ipv4_flowspec_address is not None:
                                        return True

                                    if self.ipv4_label_address is not None:
                                        return True

                                    if self.ipv4_mcast_address is not None:
                                        return True

                                    if self.ipv4_tunnel_address is not None:
                                        return True

                                    if self.ipv4mdt_address is not None:
                                        return True

                                    if self.ipv4mvpn_address is not None:
                                        return True

                                    if self.ipv4sr_policy_address is not None and self.ipv4sr_policy_address._has_data():
                                        return True

                                    if self.ipv4vpn_address is not None:
                                        return True

                                    if self.ipv4vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv4vpna_mcastddress is not None:
                                        return True

                                    if self.ipv6_address is not None:
                                        return True

                                    if self.ipv6_flowspec_address is not None:
                                        return True

                                    if self.ipv6_label_address is not None:
                                        return True

                                    if self.ipv6_mcast_address is not None:
                                        return True

                                    if self.ipv6mvpn_address is not None:
                                        return True

                                    if self.ipv6sr_policy_address is not None and self.ipv6sr_policy_address._has_data():
                                        return True

                                    if self.ipv6vpn_address is not None:
                                        return True

                                    if self.ipv6vpn_flowspec_address is not None:
                                        return True

                                    if self.ipv6vpn_mcast_address is not None:
                                        return True

                                    if self.l2vpn_evpn_address is not None:
                                        return True

                                    if self.l2vpn_mspw_address is not None and self.l2vpn_mspw_address._has_data():
                                        return True

                                    if self.l2vpnvpls_address is not None and self.l2vpnvpls_address._has_data():
                                        return True

                                    if self.ls_ls_address is not None:
                                        return True

                                    if self.rt_constraint_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attribute-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.attr_set is not None and self.attr_set._has_data():
                                    return True

                                if self.attribute_key_number is not None:
                                    return True

                                if self.attribute_reuse_id_config is not None:
                                    return True

                                if self.attribute_reuse_id_current is not None:
                                    return True

                                if self.attribute_reuse_id_keys is not None:
                                    return True

                                if self.attribute_reuse_id_max_id is not None:
                                    return True

                                if self.attribute_reuse_id_node is not None:
                                    return True

                                if self.attribute_reuse_id_recover_sec is not None:
                                    return True

                                if self.common_attributes is not None and self.common_attributes._has_data():
                                    return True

                                if self.is_application_gateway_present is not None:
                                    return True

                                if self.is_as_path2_byte is not None:
                                    return True

                                if self.is_attr_set_present is not None:
                                    return True

                                if self.is_ribrnh_present is not None:
                                    return True

                                if self.is_rnh_present is not None:
                                    return True

                                if self.ribrnh_encap is not None:
                                    return True

                                if self.ribrnh_ip is not None and self.ribrnh_ip._has_data():
                                    return True

                                if self.ribrnh_mac is not None:
                                    return True

                                if self.ribrnh_table is not None:
                                    return True

                                if self.ribrnh_vni is not None:
                                    return True

                                if self.ribrnhip_table is not None:
                                    return True

                                if self.rnh_addr is not None and self.rnh_addr._has_data():
                                    return True

                                if self.rnh_addr_len is not None:
                                    return True

                                if self.rnh_len is not None:
                                    return True

                                if self.rnh_type is not None:
                                    return True

                                if self.set_aigp_inbound_igp is not None:
                                    return True

                                if self.set_aigp_inbound_metric is not None:
                                    return True

                                if self.vpn_distinguisher is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attribute'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.attribute_cache_bucket is not None:
                                return True

                            if self.attribute_cache_id is not None:
                                return True

                            if self.attribute_iid is not None:
                                return True

                            if self.attribute_info is not None and self.attribute_info._has_data():
                                return True

                            if self.attribute_instance_id is not None:
                                return True

                            if self.attribute_structure_hash_value is not None:
                                return True

                            if self.attribute_structure_id is not None:
                                return True

                            if self.process_instance_id is not None:
                                return True

                            if self.reference_count is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attributes'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.attribute is not None:
                            for child_ref in self.attribute:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.Attributes']['meta_info']


                class RtEntries(object):
                    """
                    BGP Route Target Sets Table
                    
                    .. attribute:: rt_entry
                    
                    	BGP Route Target Set Entry
                    	**type**\: list of    :py:class:`RtEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.RtEntries.RtEntry>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2015-08-27'

                    def __init__(self):
                        self.parent = None
                        self.rt_entry = YList()
                        self.rt_entry.parent = self
                        self.rt_entry.name = 'rt_entry'


                    class RtEntry(object):
                        """
                        BGP Route Target Set Entry
                        
                        .. attribute:: af_name
                        
                        	Address family
                        	**type**\:   :py:class:`BgpAddressFamilyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamilyEnum>`
                        
                        .. attribute:: afs
                        
                        	afs
                        	**type**\:  str
                        
                        .. attribute:: request_id
                        
                        	Random Request ID
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: route_target_lower_bytes
                        
                        	Lower 4 bytes of RT
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: route_target_upper_bytes
                        
                        	Upper 4 bytes of RT
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: rt
                        
                        	rt
                        	**type**\:   :py:class:`Rt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.RtEntries.RtEntry.Rt>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.af_name = None
                            self.afs = None
                            self.request_id = None
                            self.route_target_lower_bytes = None
                            self.route_target_upper_bytes = None
                            self.rt = Bgp.Instances.Instance.InstanceStandby.RtEntries.RtEntry.Rt()
                            self.rt.parent = self


                        class Rt(object):
                            """
                            rt
                            
                            .. attribute:: route_target
                            
                            	route target
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.route_target = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rt'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.route_target is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.RtEntries.RtEntry.Rt']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rt-entry'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.af_name is not None:
                                return True

                            if self.afs is not None:
                                return True

                            if self.request_id is not None:
                                return True

                            if self.route_target_lower_bytes is not None:
                                return True

                            if self.route_target_upper_bytes is not None:
                                return True

                            if self.rt is not None and self.rt._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.RtEntries.RtEntry']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rt-entries'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.rt_entry is not None:
                            for child_ref in self.rt_entry:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.RtEntries']['meta_info']


                class AttributeFilterGroups(object):
                    """
                    All attribute\-filter groups in this instance
                    
                    .. attribute:: attribute_filter_group
                    
                    	Attribute\-filter group
                    	**type**\: list of    :py:class:`AttributeFilterGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.AttributeFilterGroups.AttributeFilterGroup>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2015-08-27'

                    def __init__(self):
                        self.parent = None
                        self.attribute_filter_group = YList()
                        self.attribute_filter_group.parent = self
                        self.attribute_filter_group.name = 'attribute_filter_group'


                    class AttributeFilterGroup(object):
                        """
                        Attribute\-filter group
                        
                        .. attribute:: group_name  <key>
                        
                        	Attribute\-filter group name
                        	**type**\:  str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: attribute_filter_entry
                        
                        	List of attriute\-filter entries
                        	**type**\: list of    :py:class:`AttributeFilterEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.AttributeFilterGroups.AttributeFilterGroup.AttributeFilterEntry>`
                        
                        .. attribute:: attribute_filter_group_name
                        
                        	Attribute\-filter group name
                        	**type**\:  str
                        
                        .. attribute:: attribute_filter_total_group_count
                        
                        	Total number of attriute\-filter groups
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.group_name = None
                            self.attribute_filter_entry = YList()
                            self.attribute_filter_entry.parent = self
                            self.attribute_filter_entry.name = 'attribute_filter_entry'
                            self.attribute_filter_group_name = None
                            self.attribute_filter_total_group_count = None


                        class AttributeFilterEntry(object):
                            """
                            List of attriute\-filter entries
                            
                            .. attribute:: attribute_filter_entry_range_end
                            
                            	End of attribute range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_filter_entry_range_start
                            
                            	Start of attribute range
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_filter_entry_requested_action
                            
                            	Requested filtering action
                            	**type**\:   :py:class:`BgpBagUpdFilterActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterActionEnum>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.attribute_filter_entry_range_end = None
                                self.attribute_filter_entry_range_start = None
                                self.attribute_filter_entry_requested_action = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attribute-filter-entry'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.attribute_filter_entry_range_end is not None:
                                    return True

                                if self.attribute_filter_entry_range_start is not None:
                                    return True

                                if self.attribute_filter_entry_requested_action is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.AttributeFilterGroups.AttributeFilterGroup.AttributeFilterEntry']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.group_name is None:
                                raise YPYModelError('Key property group_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attribute-filter-group[Cisco-IOS-XR-ipv4-bgp-oper:group-name = ' + str(self.group_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.group_name is not None:
                                return True

                            if self.attribute_filter_entry is not None:
                                for child_ref in self.attribute_filter_entry:
                                    if child_ref._has_data():
                                        return True

                            if self.attribute_filter_group_name is not None:
                                return True

                            if self.attribute_filter_total_group_count is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.AttributeFilterGroups.AttributeFilterGroup']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:attribute-filter-groups'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.attribute_filter_group is not None:
                            for child_ref in self.attribute_filter_group:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.AttributeFilterGroups']['meta_info']


                class RpkiServerList(object):
                    """
                    RPKI Server Table
                    
                    .. attribute:: rpki_server
                    
                    	Array of RPKI servers
                    	**type**\: list of    :py:class:`RpkiServer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.RpkiServerList.RpkiServer>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2015-08-27'

                    def __init__(self):
                        self.parent = None
                        self.rpki_server = YList()
                        self.rpki_server.parent = self
                        self.rpki_server.name = 'rpki_server'


                    class RpkiServer(object):
                        """
                        Array of RPKI servers
                        
                        .. attribute:: close_reason
                        
                        	Server close reason
                        	**type**\:   :py:class:`BgpRpkiCreasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiCreasonEnum>`
                        
                        .. attribute:: close_time
                        
                        	Server close elapsed time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: close_time_real
                        
                        	Server close real timestamp (unix time)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv4roa
                        
                        	Total IPv4 ROAs currently recv'd from server
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv4roa_announce
                        
                        	Total IPv4 ROAs announced by the server
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv4roa_withdraw
                        
                        	Total IPv4 ROAs withdrawn by the server
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv6roa
                        
                        	Total IPv6 ROAs currently recv'd from server
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv6roa_announce
                        
                        	Total IPv6 ROAs announced by the server
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv6roa_withdraw
                        
                        	Total IPv6 ROAs withdrawn by the server
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	Server Name
                        	**type**\:  str
                        
                        .. attribute:: nonce
                        
                        	Server nonce
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: password
                        
                        	Server SSH password
                        	**type**\:  str
                        
                        .. attribute:: port
                        
                        	Server TCP Port number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: preference
                        
                        	Server Preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proto_error
                        
                        	Protocol Error Reason
                        	**type**\:   :py:class:`BgpRpkiPerrorEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiPerrorEnum>`
                        
                        .. attribute:: proto_state
                        
                        	Server Protocol state
                        	**type**\:   :py:class:`BgpRpkiPstateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiPstateEnum>`
                        
                        .. attribute:: proto_state_time
                        
                        	Server Protocol state timestamp (unix time)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: purge_time
                        
                        	Server purge time (seconds)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: read_bytes
                        
                        	Number of bytes read from the server
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: refresh_time
                        
                        	Server refresh time (seconds)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: response_time
                        
                        	Server response time (seconds)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: retries
                        
                        	Number of connection retries
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: serial
                        
                        	Server serial number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: shutdown
                        
                        	Server Shutdown
                        	**type**\:  bool
                        
                        .. attribute:: sshpid
                        
                        	Server SSH process ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Server Internal State
                        	**type**\:   :py:class:`BgpRpkiStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiStateEnum>`
                        
                        .. attribute:: state_time
                        
                        	Server Internal State timestamp (unix time)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: transport
                        
                        	Server transport type
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: username
                        
                        	Server SSH username
                        	**type**\:  str
                        
                        .. attribute:: write_bytes
                        
                        	Number of bytes written to the server
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.close_reason = None
                            self.close_time = None
                            self.close_time_real = None
                            self.ipv4roa = None
                            self.ipv4roa_announce = None
                            self.ipv4roa_withdraw = None
                            self.ipv6roa = None
                            self.ipv6roa_announce = None
                            self.ipv6roa_withdraw = None
                            self.name = None
                            self.nonce = None
                            self.password = None
                            self.port = None
                            self.preference = None
                            self.proto_error = None
                            self.proto_state = None
                            self.proto_state_time = None
                            self.purge_time = None
                            self.read_bytes = None
                            self.refresh_time = None
                            self.response_time = None
                            self.retries = None
                            self.serial = None
                            self.shutdown = None
                            self.sshpid = None
                            self.state = None
                            self.state_time = None
                            self.transport = None
                            self.username = None
                            self.write_bytes = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rpki-server'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.close_reason is not None:
                                return True

                            if self.close_time is not None:
                                return True

                            if self.close_time_real is not None:
                                return True

                            if self.ipv4roa is not None:
                                return True

                            if self.ipv4roa_announce is not None:
                                return True

                            if self.ipv4roa_withdraw is not None:
                                return True

                            if self.ipv6roa is not None:
                                return True

                            if self.ipv6roa_announce is not None:
                                return True

                            if self.ipv6roa_withdraw is not None:
                                return True

                            if self.name is not None:
                                return True

                            if self.nonce is not None:
                                return True

                            if self.password is not None:
                                return True

                            if self.port is not None:
                                return True

                            if self.preference is not None:
                                return True

                            if self.proto_error is not None:
                                return True

                            if self.proto_state is not None:
                                return True

                            if self.proto_state_time is not None:
                                return True

                            if self.purge_time is not None:
                                return True

                            if self.read_bytes is not None:
                                return True

                            if self.refresh_time is not None:
                                return True

                            if self.response_time is not None:
                                return True

                            if self.retries is not None:
                                return True

                            if self.serial is not None:
                                return True

                            if self.shutdown is not None:
                                return True

                            if self.sshpid is not None:
                                return True

                            if self.state is not None:
                                return True

                            if self.state_time is not None:
                                return True

                            if self.transport is not None:
                                return True

                            if self.username is not None:
                                return True

                            if self.write_bytes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.RpkiServerList.RpkiServer']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rpki-server-list'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.rpki_server is not None:
                            for child_ref in self.rpki_server:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.RpkiServerList']['meta_info']


                class RpkiRoutes(object):
                    """
                    BGP RPKI ROA table
                    
                    .. attribute:: rpki_route
                    
                    	RPKI Path Group
                    	**type**\: list of    :py:class:`RpkiRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.RpkiRoutes.RpkiRoute>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2015-08-27'

                    def __init__(self):
                        self.parent = None
                        self.rpki_route = YList()
                        self.rpki_route.parent = self
                        self.rpki_route.name = 'rpki_route'


                    class RpkiRoute(object):
                        """
                        RPKI Path Group
                        
                        .. attribute:: address
                        
                        	Route Address (IPv4 / IPv6)
                        	**type**\:  str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: af_name
                        
                        	Address family
                        	**type**\:   :py:class:`BgpRpkiEdmAfEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiEdmAfEnum>`
                        
                        .. attribute:: maximum
                        
                        	Maximum Prefix Length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: minimum
                        
                        	Minimum Prefix Length
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: rpki_route
                        
                        	Array or RPKI routes
                        	**type**\: list of    :py:class:`RpkiRoute_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.RpkiRoutes.RpkiRoute.RpkiRoute_>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.address = None
                            self.af_name = None
                            self.maximum = None
                            self.minimum = None
                            self.rpki_route = YList()
                            self.rpki_route.parent = self
                            self.rpki_route.name = 'rpki_route'


                        class RpkiRoute_(object):
                            """
                            Array or RPKI routes
                            
                            .. attribute:: address
                            
                            	Address Prefix
                            	**type**\:  str
                            
                            .. attribute:: af_name
                            
                            	Address Family
                            	**type**\:   :py:class:`BgpRpkiAfEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiAfEnum>`
                            
                            .. attribute:: as_
                            
                            	AS number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_prefix_len
                            
                            	Maximum Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: min_prefix_len
                            
                            	Minimum Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: refcount
                            
                            	Refcount
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: server
                            
                            	Source Server
                            	**type**\:  str
                            
                            .. attribute:: stale
                            
                            	ROA is stale
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2015-08-27'

                            def __init__(self):
                                self.parent = None
                                self.address = None
                                self.af_name = None
                                self.as_ = None
                                self.max_prefix_len = None
                                self.min_prefix_len = None
                                self.refcount = None
                                self.server = None
                                self.stale = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rpki-route'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.address is not None:
                                    return True

                                if self.af_name is not None:
                                    return True

                                if self.as_ is not None:
                                    return True

                                if self.max_prefix_len is not None:
                                    return True

                                if self.min_prefix_len is not None:
                                    return True

                                if self.refcount is not None:
                                    return True

                                if self.server is not None:
                                    return True

                                if self.stale is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                                return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.RpkiRoutes.RpkiRoute.RpkiRoute_']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rpki-route'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.address is not None:
                                return True

                            if self.af_name is not None:
                                return True

                            if self.maximum is not None:
                                return True

                            if self.minimum is not None:
                                return True

                            if self.rpki_route is not None:
                                for child_ref in self.rpki_route:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.RpkiRoutes.RpkiRoute']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rpki-routes'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.rpki_route is not None:
                            for child_ref in self.rpki_route:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.RpkiRoutes']['meta_info']


                class UpdateInboundErrorProcess(object):
                    """
                    Update inbound error information for the process
                    
                    .. attribute:: last_update_malformed_age
                    
                    	Time since last malformed messages received event (in seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: last_update_malformed_timestamp
                    
                    	Last malformed messages received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                    	**type**\:   :py:class:`LastUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.UpdateInboundErrorProcess.LastUpdateMalformedTimestamp>`
                    
                    .. attribute:: update_error_handling_basic_ebgp
                    
                    	Is basic error\-handling for EBGP enabled
                    	**type**\:  bool
                    
                    .. attribute:: update_error_handling_basic_ibgp
                    
                    	Is basic error\-handling for IBGP enabled
                    	**type**\:  bool
                    
                    .. attribute:: update_error_handling_extended_ebgp
                    
                    	Is extended error\-handling for EBGP enabled
                    	**type**\:  bool
                    
                    .. attribute:: update_error_handling_extended_ibgp
                    
                    	Is extended error\-handling for IBGP enabled
                    	**type**\:  bool
                    
                    .. attribute:: update_malformed_message_count
                    
                    	Malformed messages count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update_malformed_neighbor_count
                    
                    	Count of neighbors that received malformed messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2015-08-27'

                    def __init__(self):
                        self.parent = None
                        self.last_update_malformed_age = None
                        self.last_update_malformed_timestamp = Bgp.Instances.Instance.InstanceStandby.UpdateInboundErrorProcess.LastUpdateMalformedTimestamp()
                        self.last_update_malformed_timestamp.parent = self
                        self.update_error_handling_basic_ebgp = None
                        self.update_error_handling_basic_ibgp = None
                        self.update_error_handling_extended_ebgp = None
                        self.update_error_handling_extended_ibgp = None
                        self.update_malformed_message_count = None
                        self.update_malformed_neighbor_count = None


                    class LastUpdateMalformedTimestamp(object):
                        """
                        Last malformed messages received time\: time
                        elapsed since 00\:00\:00 UTC, January 1, 1970
                        
                        .. attribute:: nanoseconds
                        
                        	Nanoseconds part of time value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: seconds
                        
                        	Seconds part of time value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2015-08-27'

                        def __init__(self):
                            self.parent = None
                            self.nanoseconds = None
                            self.seconds = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:last-update-malformed-timestamp'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.nanoseconds is not None:
                                return True

                            if self.seconds is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                            return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.UpdateInboundErrorProcess.LastUpdateMalformedTimestamp']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:update-inbound-error-process'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.last_update_malformed_age is not None:
                            return True

                        if self.last_update_malformed_timestamp is not None and self.last_update_malformed_timestamp._has_data():
                            return True

                        if self.update_error_handling_basic_ebgp is not None:
                            return True

                        if self.update_error_handling_basic_ibgp is not None:
                            return True

                        if self.update_error_handling_extended_ebgp is not None:
                            return True

                        if self.update_error_handling_extended_ibgp is not None:
                            return True

                        if self.update_malformed_message_count is not None:
                            return True

                        if self.update_malformed_neighbor_count is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.UpdateInboundErrorProcess']['meta_info']


                class RpkiSummary(object):
                    """
                    RPKI Summary Info
                    
                    .. attribute:: ipv4roa_nets
                    
                    	Number of IPv4 ROA Nets
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ipv4roa_paths
                    
                    	Number of IPv4 ROA Paths
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ipv6roa_nets
                    
                    	Number of IPv6 ROA Nets
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ipv6roa_paths
                    
                    	Number of IPv6 ROA Paths
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rpki_allow_invalid
                    
                    	Allow invalid paths
                    	**type**\:  bool
                    
                    .. attribute:: rpki_disabled
                    
                    	RPKI Knob disabled
                    	**type**\:  bool
                    
                    .. attribute:: rpki_signal_ibgp
                    
                    	Signal RPKI validity to iBGP peers
                    	**type**\:  bool
                    
                    .. attribute:: rpki_use_validity
                    
                    	Use RPKI validity for bestpath calculation
                    	**type**\:  bool
                    
                    .. attribute:: servers
                    
                    	Number of RPKI Servers configured
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2015-08-27'

                    def __init__(self):
                        self.parent = None
                        self.ipv4roa_nets = None
                        self.ipv4roa_paths = None
                        self.ipv6roa_nets = None
                        self.ipv6roa_paths = None
                        self.rpki_allow_invalid = None
                        self.rpki_disabled = None
                        self.rpki_signal_ibgp = None
                        self.rpki_use_validity = None
                        self.servers = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:rpki-summary'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ipv4roa_nets is not None:
                            return True

                        if self.ipv4roa_paths is not None:
                            return True

                        if self.ipv6roa_nets is not None:
                            return True

                        if self.ipv6roa_paths is not None:
                            return True

                        if self.rpki_allow_invalid is not None:
                            return True

                        if self.rpki_disabled is not None:
                            return True

                        if self.rpki_signal_ibgp is not None:
                            return True

                        if self.rpki_use_validity is not None:
                            return True

                        if self.servers is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                        return meta._meta_table['Bgp.Instances.Instance.InstanceStandby.RpkiSummary']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-ipv4-bgp-oper:instance-standby'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.attribute_filter_groups is not None and self.attribute_filter_groups._has_data():
                        return True

                    if self.attributes is not None and self.attributes._has_data():
                        return True

                    if self.default_vrf is not None and self.default_vrf._has_data():
                        return True

                    if self.rpki_refresh_afs is not None and self.rpki_refresh_afs._has_data():
                        return True

                    if self.rpki_routes is not None and self.rpki_routes._has_data():
                        return True

                    if self.rpki_server_list is not None and self.rpki_server_list._has_data():
                        return True

                    if self.rpki_summary is not None and self.rpki_summary._has_data():
                        return True

                    if self.rt_entries is not None and self.rt_entries._has_data():
                        return True

                    if self.update_generation_process is not None and self.update_generation_process._has_data():
                        return True

                    if self.update_inbound_error_process is not None and self.update_inbound_error_process._has_data():
                        return True

                    if self.update_inbound_filter_process is not None and self.update_inbound_filter_process._has_data():
                        return True

                    if self.vrfs is not None and self.vrfs._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                    return meta._meta_table['Bgp.Instances.Instance.InstanceStandby']['meta_info']

            @property
            def _common_path(self):
                if self.instance_name is None:
                    raise YPYModelError('Key property instance_name is None')

                return '/Cisco-IOS-XR-ipv4-bgp-oper:bgp/Cisco-IOS-XR-ipv4-bgp-oper:instances/Cisco-IOS-XR-ipv4-bgp-oper:instance[Cisco-IOS-XR-ipv4-bgp-oper:instance-name = ' + str(self.instance_name) + ']'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.instance_name is not None:
                    return True

                if self.instance_active is not None and self.instance_active._has_data():
                    return True

                if self.instance_standby is not None and self.instance_standby._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                return meta._meta_table['Bgp.Instances.Instance']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-ipv4-bgp-oper:bgp/Cisco-IOS-XR-ipv4-bgp-oper:instances'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.instance is not None:
                for child_ref in self.instance:
                    if child_ref._has_data():
                        return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
            return meta._meta_table['Bgp.Instances']['meta_info']


    class BpmInstancesTable(object):
        """
        BGP instances information
        
        .. attribute:: bpm_instances
        
        	BGP instances information
        	**type**\:   :py:class:`BpmInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.BpmInstancesTable.BpmInstances>`
        
        

        """

        _prefix = 'ipv4-bgp-oper'
        _revision = '2015-08-27'

        def __init__(self):
            self.parent = None
            self.bpm_instances = Bgp.BpmInstancesTable.BpmInstances()
            self.bpm_instances.parent = self


        class BpmInstances(object):
            """
            BGP instances information
            
            .. attribute:: instance
            
            	Array of instance information
            	**type**\: list of    :py:class:`Instance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.BpmInstancesTable.BpmInstances.Instance>`
            
            

            """

            _prefix = 'ipv4-bgp-oper'
            _revision = '2015-08-27'

            def __init__(self):
                self.parent = None
                self.instance = YList()
                self.instance.parent = self
                self.instance.name = 'instance'


            class Instance(object):
                """
                Array of instance information
                
                .. attribute:: af_array
                
                	Array of Address Families
                	**type**\: list of    :py:class:`AfArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.BpmInstancesTable.BpmInstances.Instance.AfArray>`
                
                .. attribute:: as_number
                
                	AS Number
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: install_diversion_enabled
                
                	Install diversion is enabled
                	**type**\:  bool
                
                .. attribute:: instance_identifier
                
                	Instance Identifier
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: instance_name_str
                
                	Instance Name
                	**type**\:  str
                
                .. attribute:: number_of_vrfs
                
                	Number of VRFs
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: placed_group_id
                
                	Placed Group Identifier
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: read_only_enabled
                
                	Read\-only is enabled
                	**type**\:  bool
                
                .. attribute:: srgb_end_configured
                
                	Configured end value of Segment\-routing global block
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: srgb_start_configured
                
                	Configured start value of Segment\-routing global block
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-bgp-oper'
                _revision = '2015-08-27'

                def __init__(self):
                    self.parent = None
                    self.af_array = YList()
                    self.af_array.parent = self
                    self.af_array.name = 'af_array'
                    self.as_number = None
                    self.install_diversion_enabled = None
                    self.instance_identifier = None
                    self.instance_name_str = None
                    self.number_of_vrfs = None
                    self.placed_group_id = None
                    self.read_only_enabled = None
                    self.srgb_end_configured = None
                    self.srgb_start_configured = None


                class AfArray(object):
                    """
                    Array of Address Families
                    
                    .. attribute:: entry
                    
                    	Array entry
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2015-08-27'

                    def __init__(self):
                        self.parent = None
                        self.entry = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-ipv4-bgp-oper:bgp/Cisco-IOS-XR-ipv4-bgp-oper:bpm-instances-table/Cisco-IOS-XR-ipv4-bgp-oper:bpm-instances/Cisco-IOS-XR-ipv4-bgp-oper:instance/Cisco-IOS-XR-ipv4-bgp-oper:af-array'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.entry is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                        return meta._meta_table['Bgp.BpmInstancesTable.BpmInstances.Instance.AfArray']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-ipv4-bgp-oper:bgp/Cisco-IOS-XR-ipv4-bgp-oper:bpm-instances-table/Cisco-IOS-XR-ipv4-bgp-oper:bpm-instances/Cisco-IOS-XR-ipv4-bgp-oper:instance'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.af_array is not None:
                        for child_ref in self.af_array:
                            if child_ref._has_data():
                                return True

                    if self.as_number is not None:
                        return True

                    if self.install_diversion_enabled is not None:
                        return True

                    if self.instance_identifier is not None:
                        return True

                    if self.instance_name_str is not None:
                        return True

                    if self.number_of_vrfs is not None:
                        return True

                    if self.placed_group_id is not None:
                        return True

                    if self.read_only_enabled is not None:
                        return True

                    if self.srgb_end_configured is not None:
                        return True

                    if self.srgb_start_configured is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                    return meta._meta_table['Bgp.BpmInstancesTable.BpmInstances.Instance']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-ipv4-bgp-oper:bgp/Cisco-IOS-XR-ipv4-bgp-oper:bpm-instances-table/Cisco-IOS-XR-ipv4-bgp-oper:bpm-instances'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.instance is not None:
                    for child_ref in self.instance:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
                return meta._meta_table['Bgp.BpmInstancesTable.BpmInstances']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-ipv4-bgp-oper:bgp/Cisco-IOS-XR-ipv4-bgp-oper:bpm-instances-table'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.bpm_instances is not None and self.bpm_instances._has_data():
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
            return meta._meta_table['Bgp.BpmInstancesTable']['meta_info']

    @property
    def _common_path(self):

        return '/Cisco-IOS-XR-ipv4-bgp-oper:bgp'

    def is_config(self):
        ''' Returns True if this instance represents config data else returns False '''
        return False

    def _has_data(self):
        if not self.is_config():
            return False
        if self.bpm_instances_table is not None and self.bpm_instances_table._has_data():
            return True

        if self.config_instances is not None and self.config_instances._has_data():
            return True

        if self.instances is not None and self.instances._has_data():
            return True

        return False

    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_ipv4_bgp_oper as meta
        return meta._meta_table['Bgp']['meta_info']


